DROP DATABASE IF EXISTS cndb_sql_db;
CREATE DATABASE IF NOT EXISTS cndb_sql_db;
USE cndb_sql_db;

DROP TABLE IF EXISTS `cndb_ctgnme`;
CREATE TABLE `cndb_ctgnme` (
  `food_category_code` int NOT NULL,
  `category_description` varchar(100) DEFAULT NULL,
  `date_added` date NOT NULL,
  `last_modified` date NOT NULL,
  PRIMARY KEY (`food_category_code`),
  CONSTRAINT `food_category_code_length` CHECK ((`food_category_code` between 0 and 99))
);

DROP TABLE IF EXISTS `cndb_fdes`;
CREATE TABLE `cndb_fdes` (
  `food_category_code` int DEFAULT NULL,
  `descriptor` varchar(255) DEFAULT NULL,
  `descriptor_abbreviated` varchar(60) DEFAULT NULL,
  `cn_code` int NOT NULL,
  `product_code` varchar(15) DEFAULT NULL,
  `gtin` varchar(255) DEFAULT NULL,
  `brand_owner_name` varchar(80) DEFAULT NULL,
  `brand_name` varchar(80) DEFAULT NULL,
  `fns_material_number` varchar(6) DEFAULT NULL,
  `source_code` int DEFAULT NULL,
  `date_added` date DEFAULT NULL,
  `last_modified` date DEFAULT NULL,
  `discontinued_date` date DEFAULT NULL,
  `form_of_food` varchar(100) DEFAULT NULL,
  `fdc_id` int DEFAULT NULL,
  `gpc_product_code` varchar(8) DEFAULT NULL,
  PRIMARY KEY (`cn_code`),
  KEY `food_category_code` (`food_category_code`),
  KEY `gpc_product_code` (`gpc_product_code`),
  CONSTRAINT `cn_code_length2` CHECK ((`cn_code` between 0 and 999999)),
  CONSTRAINT `fdc_id_length` CHECK ((`fdc_id` between 0 and 99999999)),
  CONSTRAINT `food_category_code_length1` CHECK ((`food_category_code` between 0 and 99)),
  CONSTRAINT `source_code_length2` CHECK ((`source_code` between 0 and 9))
);

DROP TABLE IF EXISTS `cndb_gpcnme`;
CREATE TABLE `cndb_gpcnme` (
  `gpc_code` varchar(8) NOT NULL,
  `gpc_description` varchar(100) NOT NULL,
  `date_added` date NOT NULL,
  `last_modified` date NOT NULL,
  PRIMARY KEY (`gpc_code`)
);

DROP TABLE IF EXISTS `cndb_nutdes`;
CREATE TABLE `cndb_nutdes` (
  `nutrient_code` int NOT NULL,
  `nutrient_description` varchar(30) NOT NULL,
  `nutrient_description_abbreviated` varchar(9) NOT NULL,
  `nutrient_unit` varchar(5) NOT NULL,
  `date_added` date NOT NULL,
  `last_modified` date NOT NULL,
  PRIMARY KEY (`nutrient_code`),
  CONSTRAINT `nutrient_code_length` CHECK ((`nutrient_code` between 0 and 99999))
);

DROP TABLE IF EXISTS `cndb_nutval`;
CREATE TABLE `cndb_nutval` (
  `cn_code` int NOT NULL,
  `nutrient_code` int NOT NULL,
  `nutrient_value` decimal(13,3) DEFAULT NULL,
  `per_unit` varchar(5) DEFAULT NULL,
  `value_type_code` int DEFAULT NULL,
  `source_code` int DEFAULT NULL,
  `date_added` date DEFAULT NULL,
  `last_modified` date DEFAULT NULL,
  KEY (`cn_code`),
  KEY `nutrient_code` (`nutrient_code`),
  CONSTRAINT `cn_code_length1` CHECK ((`cn_code` between 0 and 999999)),
  CONSTRAINT `nutrient_code_length1` CHECK ((`nutrient_code` between 0 and 99999)),
  CONSTRAINT `source_code_length1` CHECK ((`source_code` between 0 and 9)),
  CONSTRAINT `value_type_code_length` CHECK ((`value_type_code` between 0 and 999))
);

DROP TABLE IF EXISTS `cndb_wght`;
CREATE TABLE `cndb_wght` (
  `cn_code` int NOT NULL,
  `weights_sequence_number` int NOT NULL,
  `amount` decimal(9,3) DEFAULT NULL,
  `measure_description` varchar(100) DEFAULT NULL,
  `unit_amount` decimal(10,2) DEFAULT NULL,
  `type_of_unit` varchar(2) DEFAULT NULL,
  `source_code` int DEFAULT NULL,
  `date_added` date DEFAULT NULL,
  `last_modified` date DEFAULT NULL,
  KEY (`cn_code`),
  KEY `weights_sequence_number` (`weights_sequence_number`),
  CONSTRAINT `cn_code_length` CHECK ((`cn_code` between 0 and 999999)),
  CONSTRAINT `source_code_length` CHECK ((`source_code` between 0 and 9)),
  CONSTRAINT `weights_sequence_number_length` CHECK ((`weights_sequence_number` between 0 and 99))
);
LOCK TABLES `cndb_ctgnme` WRITE;
/*!40000 ALTER TABLE `cndb_ctgnme` DISABLE KEYS */;
INSERT INTO `cndb_ctgnme` VALUES (1,'Dairy and Egg Products','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (2,'Spices and Herbs','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (3,'Baby Foods','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (4,'Fats and Oils','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (5,'Poultry Products','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (6,'Soups, Sauces, and Gravies','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (7,'Sausages and Luncheon Meats','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (8,'Breakfast Cereals','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (9,'Fruits and Fruit Juices','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (10,'Pork Products','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (11,'Vegetables and Vegetable Products','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (12,'Nut and Seed Products','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (13,'Beef Products','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (14,'Beverages','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (15,'Finfish and Shellfish Products','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (16,'Legumes and Legume Products','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (17,'Lamb, Veal, and Game Products','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (18,'Baked Products','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (19,'Sweets','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (20,'Cereal Grains and Pasta','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (21,'Fast Foods','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (22,'Meals, Entrees, and Side Dishes','1997-10-29','2012-12-26');
INSERT INTO `cndb_ctgnme` VALUES (25,'Snacks','1997-10-29','2012-04-09');
INSERT INTO `cndb_ctgnme` VALUES (35,'American Indian/Alaska Native Foods','1997-10-29','2016-03-22');
INSERT INTO `cndb_ctgnme` VALUES (36,'Restaurant Foods','1997-10-29','2012-04-09');
UNLOCK TABLES;
/*!40000 ALTER TABLE `cndb_ctgnme` ENABLE KEYS */;
LOCK TABLES `cndb_gpcnme` WRITE;
/*!40000 ALTER TABLE `cndb_gpcnme` DISABLE KEYS */;
INSERT INTO `cndb_gpcnme` VALUES ('50101800','Nuts/Seeds - Prepared/Processed','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50101900','Fruit/Nuts/Seeds Combination','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50102000','Fruit - Prepared/Processed','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50102100','Vegetables - Prepared/Processed','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50102200','Fruits/Vegetables/Nuts/Seeds Variety Packs','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50121500','Fish - Unprepared/Unprocessed','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50121700','Shellfish Unprepared/Unprocessed','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50121800','Aquatic Plants Unprepared/Unprocessed','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50121900','Fish - Prepared/Processed','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50122000','Aquatic Invertebrates - Prepared/Processed','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50122100','Shellfish Prepared/Processed','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50122200','Aquatic Plants Prepared/Processed','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50122300','Aquatic Invertebrates - Unprepared/Unprocessed','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50122400','Seafood Variety Packs','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50122500','Aquatic Invertebrates/Fish/Shellfish/Seafood Combination','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50131700','Milk/Milk Substitutes','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50131800','Cheese/Cheese Substitutes','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50131900','Butter/Butter Substitutes','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50132000','Cream/Cream Substitutes','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50132100','Yogurt/Yogurt Substitutes','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50132200','Milk/Butter/Cream/Yogurts/Cheese/Eggs/Substitutes Variety Packs','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50132300','Eggs/Eggs Extracts (Industrial Process)','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50132500','Eggs/Eggs Substitutes','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50132600','Dairy Derivatives/By Products','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50151500','Oils Edible','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50151600','Fats Edible','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50151700','Oils/Fats Edible Variety Packs','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50161500','Sugars/Sugar Substitute Products','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50161800','Confectionery Products','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50161900','Confectionery/Sugar Sweetening Products Variety Packs','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50171500','Herbs/Spices/Extracts','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50171700','Vinegars/Cooking Wines','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50171800','Sauces/Spreads/Dips/Condiments','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50171900','Pickles/Relishes/Chutneys/Olives','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50172000','Seasonings/Preservatives/Extracts Variety Packs','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50172100','Casings for Food Items','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50181700','Baking/Cooking Mixes/Supplies','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50181900','Bread','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50182000','Sweet Bakery Products','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50182100','Biscuits/Cookies','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50182200','Savoury Bakery Products','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50182300','Bread/Bakery Products Variety Packs','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50191500','Prepared Soups','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50192100','Snacks','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50192300','Desserts/Dessert Sauces/Toppings','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50192400','Sweet Spreads','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50192500','Sandwiches/Filled Rolls/Wraps','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50192900','Pasta/Noodles','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50193000','Baby/Infant - Foods/Beverages','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50193100','Vegetable Based Products / Meals','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50193200','Grain Based Products / Meals','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50193300','Dough Based Products / Meals','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50193400','Prepared/Preserved Foods Variety Packs','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50193500','Dairy/Egg Based Products / Meals','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50193800','Ready-Made Combination Meals','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50201700','Coffee/Tea/Substitutes','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50202200','Alcoholic Beverages (Includes De-Alcoholised Variants)','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50202300','Non Alcoholic Beverages - Ready to Drink','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50202400','Non Alcoholic Beverages - Not Ready to Drink','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50202500','Beverages Variety Packs','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50202600','Coffee/Coffee Substitutes','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50202700','Tea and Infusions/Tisanes','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50221000','Grains/Flour','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50221200','Processed Cereal Products','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50221300','Cereal/Grain/Pulse Products Variety Packs','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50230100','Food/Beverage/Tobacco Variety Packs','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50240100','Meat/Poultry/Other Animals - Prepared/Processed','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50240200','Meat/Poultry/Other Animals - Unprepared/Unprocessed','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50240300','Meat/Poultry/Other Animals Sausages - Prepared/Processed','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50250600','Citrus','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50250700','Bananas','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50250800','Pome Fruits','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50250900','Stone Fruit','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50251000','Berries/Small Fruit','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50251100','Pineapples','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50251200','Kiwifruits','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50251300','Annona','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50251400','Avocados','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50251500','Persimmon','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50251600','Passionfruits','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50251700','Papayas','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50251800','Pitayas','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50251900','Miscellaneous Fruit','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50252000','Fruits - Unprepared/Unprocessed (Fresh) Variety Packs','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50260100','Root/Tuber Vegetables','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50260200','Bulb Vegetables','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50260300','Tomatoes','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50260400','Peppers','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50260500','Solanacea/Others','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50260600','Cucumbers','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50260700','Cucurbits - Edible Peel','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50260800','Melons','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50260900','Cucurbits - Inedible Peel','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50261000','Other Vegetables','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50261100','Brassica Vegetables','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50261300','Herbs','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50261400','Beans (With Pods)','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50261500','Peas (With Pods)','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50261600','Stem Vegetables','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50261700','Fungi','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50261800','Vegetables - Unprepared/Unprocessed (Fresh) Variety Packs','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50261900','Micro Vegetables','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50262000','Edible Flowers','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50262100','Tidal Sea Vegetables','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50262200','Chickpeas','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50262300','Succulent','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50262400','Ferns','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50262500','Sapote','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50262600','Sugar Canes','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50262700','Sedges','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50270100','Fruits - Unprepared/Unprocessed (Frozen)','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50290100','Vegetables - Unprepared/Unprocessed (Frozen)','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50310100','Fruits - Unprepared/Unprocessed (Shelf Stable)','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50320100','Vegetables - Unprepared/Unprocessed (Shelf Stable)','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50330100','Nuts/Seeds - Unprepared/Unprocessed (Perishable)','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50340100','Nuts/Seeds - Unprepared/Unprocessed (In Shell)','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50350100','Chicory Leaves','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50350200','Head Lettuce','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50350300','Loose Leaf/Multileaf Salad Greens','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50350400','Single Leaf Salad Greens','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50350500','Spinach (Fresh)','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50350600','Leaf Vegetables - Unprepared/Unprocessed Variety Packs','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50350700','Stem Lettuce','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50360100','Fresh Garnish (Food)','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50370100','Fruits/Vegetables Variety Packs Unprepared/Unprocessed (Fresh)','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50370200','Vegetables/Fruits Variety Pack - Fresh Cut','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50380100','Fruits - Fresh Cut','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50380200','Vegetables - Fresh Cut','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50390100','Meat Substitutes','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50390200','Fish Substitutes','2022-04-01','2022-04-01');
INSERT INTO `cndb_gpcnme` VALUES ('50390300','Seafood Substitutes','2022-04-01','2022-04-01');
UNLOCK TABLES;
/*!40000 ALTER TABLE `cndb_gpcnme` ENABLE KEYS */;
LOCK TABLES `cndb_nutdes` WRITE;
/*!40000 ALTER TABLE `cndb_nutdes` DISABLE KEYS */;
INSERT INTO `cndb_nutdes` VALUES (203,'Protein','Pro','g','1997-10-29','1997-10-29');
INSERT INTO `cndb_nutdes` VALUES (204,'Total Fat','Fat','g','1997-10-29','1997-10-29');
INSERT INTO `cndb_nutdes` VALUES (205,'Carbohydrate','Carb','g','1997-10-29','1997-10-29');
INSERT INTO `cndb_nutdes` VALUES (207,'Ash','Ash','g','1997-10-29','1997-10-29');
INSERT INTO `cndb_nutdes` VALUES (208,'Food Energy','FE','kcal','1997-10-29','1997-10-29');
INSERT INTO `cndb_nutdes` VALUES (255,'Moisture','Mois','g','1997-10-29','1997-10-29');
INSERT INTO `cndb_nutdes` VALUES (269,'Total Sugars','Sug','g','2013-12-17','2013-12-17');
INSERT INTO `cndb_nutdes` VALUES (291,'Total Dietary Fiber','TDF','g','1997-10-29','1997-10-29');
INSERT INTO `cndb_nutdes` VALUES (301,'Calcium','Ca','mg','1997-10-29','1997-10-29');
INSERT INTO `cndb_nutdes` VALUES (303,'Iron','Fe','mg','1997-10-29','1997-10-29');
INSERT INTO `cndb_nutdes` VALUES (306,'Potassium','K','mg','2017-05-02','2017-05-02');
INSERT INTO `cndb_nutdes` VALUES (307,'Sodium','Na','mg','1997-10-29','1997-10-29');
INSERT INTO `cndb_nutdes` VALUES (320,'Vitamin A, RAE','VitA, RAE','mcg','2024-10-24','2024-10-24');
INSERT INTO `cndb_nutdes` VALUES (328,'Vitamin D (D2 + D3)','VitD','mcg','2017-05-02','2017-05-02');
INSERT INTO `cndb_nutdes` VALUES (401,'Vitamin C','VitC','mg','1997-10-29','1997-10-29');
INSERT INTO `cndb_nutdes` VALUES (539,'Added Sugars','SugA','g','2022-04-01','2022-04-01');
INSERT INTO `cndb_nutdes` VALUES (601,'Cholesterol','Chol','mg','1997-10-29','1997-10-29');
INSERT INTO `cndb_nutdes` VALUES (605,'Total Trans','Trans','g','2005-11-24','2005-11-24');
INSERT INTO `cndb_nutdes` VALUES (606,'Saturated Fat','Sfat','g','1997-10-29','1997-10-29');
UNLOCK TABLES;
/*!40000 ALTER TABLE `cndb_nutdes` ENABLE KEYS */;
LOCK TABLES `cndb_wght` WRITE;
/*!40000 ALTER TABLE `cndb_wght` DISABLE KEYS */;
INSERT INTO `cndb_wght` VALUES (1001,1,1,'pat (1" sq, 1/3" high)',5,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1001,2,1,'TBSP',14.2,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1001,3,1,'cup',227,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1001,4,1,'stick',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1002,1,1,'pat (1" sq, 1/3" high)',3.8,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1002,2,1,'TBSP',9.4,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1002,3,1,'cup',151,'g',1,'1995-06-19','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1002,4,1,'stick',76,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1003,1,1,'tbsp',12.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1003,2,1,'cup',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1004,1,1,'oz',28.35,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1004,2,1,'cubic inch',17,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1004,3,1,'cup, crumbled, not packed',135,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1005,1,1,'cup, diced',132,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1005,2,1,'cup, shredded',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1005,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1005,4,1,'cubic inch',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1005,5,1,'slice (1 oz)',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1006,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1006,2,1,'cup, sliced',144,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1006,3,1,'cup, melted',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1006,4,1,'cubic inch',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1006,5,1,'package (4.5 oz)',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1007,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1007,2,1,'cup',246,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1007,3,1,'cubic inch',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1007,4,1,'wedge (1.33 oz)',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1008,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1009,1,1,'cup, diced',132,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1009,2,1,'cup, melted',244,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1009,3,1,'cup, shredded',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1009,4,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1009,5,1,'cubic inch',17,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1009,6,1,'slice (1 oz)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1010,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1011,1,1,'cup, diced',132,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1011,2,1,'cup, shredded',113,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1011,3,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1011,4,1,'cubic inch',17,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1011,5,1,'slice (1 oz)',28,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1012,1,4,'oz',113,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1012,2,1,'cup, large curd (not packed)',210,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1012,3,1,'cup, small curd (not packed)',225,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1013,1,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1013,2,1,'cup (not packed)',226,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1014,1,1,'cup (not packed)',145,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1014,2,4,'oz',113,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1015,1,4,'oz',113,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1015,2,1,'cup (not packed)',226,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1016,1,4,'oz',113,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1016,2,1,'cup (not packed)',226,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1017,1,1,'tbsp',14.5,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1017,2,1,'cup',232,'g',1,'1995-06-19','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1017,3,1,'tbsp, whipped',10,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1017,4,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1017,5,1,'cubic inch',16,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1017,6,1,'package, small (3 oz)',85,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1018,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1018,2,1,'package (7 oz)',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1019,1,1,'cup, crumbled',150,'g',1,'2001-07-04','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1019,2,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1019,3,1,'cubic inch',17,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1019,4,1,'wedge (1.33 oz)',38,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1020,1,1,'cup, diced',132,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1020,2,1,'cup, shredded',108,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1020,3,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1020,4,1,'cubic inch',15,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1020,5,1,'slice (1 oz)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1020,6,1,'package (8 oz)',227,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1021,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1021,2,1,'package (8 oz)',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1022,1,1,'oz',28.35,'g',1,'2001-07-04','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1022,2,1,'package (7 oz)',198,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1023,1,1,'oz',28.35,'g',1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1023,2,1,'slice (1 oz)',28,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1023,3,1,'cubic inch',15,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1023,4,1,'cup, diced',132,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1023,5,1,'cup, shredded',108,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1023,6,1,'package (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1024,1,1,'cup',134,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1024,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1024,3,1,'cubic inch',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1024,4,1,'box',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1024,5,1,'package (8 oz)',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1025,1,1,'cup, diced',132,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1025,2,1,'cup, shredded',113,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1025,3,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1025,4,1,'cubic inch',17,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1025,5,1,'slice (1 oz)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1025,6,1,'package (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1026,1,1,'cup, shredded',112,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1026,2,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1026,3,6,'slices',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1027,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1027,2,1,'cubic inch',18,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1028,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1029,1,1,'cup, diced',132,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1029,2,1,'cup, shredded',113,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1029,3,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1029,4,1,'cubic inch',18,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1029,5,1,'slice (1 oz)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1030,1,1,'cup, diced',132,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1030,2,1,'cup, shredded',113,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1030,3,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1030,4,1,'cubic inch',18,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1030,5,1,'slice (1 oz)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1030,6,1,'package (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1031,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1031,2,1,'package (3 oz)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1032,1,1,'cup',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (1032,2,1,'TBSP',5,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1032,3,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1033,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1033,2,1,'cubic inch',10.3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1033,3,5,'package (5 oz)',142,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1034,1,1,'cup, diced',132,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1034,2,1,'cup, shredded',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1034,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1034,4,1,'cubic inch',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1034,5,1,'slice (1 oz)',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1034,6,1,'package (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1035,1,1,'cup, diced',132,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1035,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1035,3,1,'cubic inch',17,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1035,4,1,'slice (1 oz)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1035,5,1,'package (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1036,1,0.5,'cup',124,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1036,2,1,'cup',246,'g',1,'2007-11-27','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1037,1,0.5,'cup',124,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1037,2,1,'oz',28.35,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (1037,3,1,'cup',246,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1038,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1038,2,5,'package (5 oz)',142,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1039,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1039,2,1,'package (3 oz)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1040,1,1,'cup, diced',132,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1040,2,1,'cup, melted',244,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1040,3,1,'cup, shredded',108,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1040,4,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1040,5,1,'cubic inch',15,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1040,6,1,'slice (1 oz)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1041,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1041,2,1,'package (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1042,1,1,'oz',28.35,'g',1,'1995-06-19','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1042,2,1,'slice (1 oz)',28,'g',1,'1998-01-15','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1042,3,1,'slice (3/4 oz)',21,'g',1,'1999-03-22','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1042,4,1,'cubic inch',18,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1042,5,1,'cup, shredded',113,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1042,6,1,'cup, diced',140,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1042,7,1,'cup, melted',244,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1043,1,1,'cup, diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1043,2,1,'cup, melted',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1043,3,1,'cup, shredded',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1043,4,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1043,5,1,'cubic inch',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1043,6,1,'slice (3/4 oz)',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1044,1,1,'cup, diced',140,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1044,2,1,'cup, shredded',113,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1044,3,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1044,4,1,'cubic inch',18,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1044,5,1,'slice (3/4 oz)',21,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1045,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1045,2,1,'package (8 oz)',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1046,1,1,'CUP',113,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1046,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1046,3,1,'slice (3/4 oz)',21,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1046,4,1,'package (8 oz)',227,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1047,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1047,2,1,'package (8 oz)',227,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1048,1,1,'cup, diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1048,2,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1048,3,1,'jar (5 oz)',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1048,4,1,'cubic inch',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1048,5,1,'jar (5 oz)',142,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1048,6,1,'slice',34,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1048,7,1,'slice, thin',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1049,1,1,'fl oz',30.2,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1049,2,1,'TBSP',15,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1049,3,1,'cup',242,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1049,4,1,'container, individual (.5 fl oz)',15,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1050,1,1,'fl oz',30,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1050,2,1,'TBSP',15,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1050,3,1,'cup',240,'g',1,'1994-11-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1050,4,1,'container, individual',11.1,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1052,1,1,'cup, whipped',120,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1052,2,1,'cup, fluid (yields 2 cups whipped)',239,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1052,3,1,'TBSP',15,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1053,1,1,'cup, whipped',120,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1053,2,1,'cup, fluid (yields 2 cups whipped)',238,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1053,3,1,'TBSP',15,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1053,4,1,'FL OZ',29.8,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (1054,1,1,'CUP',60,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1054,2,1,'TBSP',3,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1055,1,1,'tbsp',15,'g',1,'1994-11-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1055,2,1,'cup',242,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1056,1,1,'tbsp',12,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1056,2,1,'cup',230,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1057,1,1,'CUP',254,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1057,2,1,'FL OZ',31.8,'g',1,'1994-01-31','2010-01-05');
INSERT INTO `cndb_wght` VALUES (1057,3,1,'quart',1016,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1058,1,1,'tbsp',12,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1058,2,1,'cup',235,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1059,1,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1059,2,1,'quart',976,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1060,1,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1060,2,1,'fl oz',30.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1060,3,1,'quart',976,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1061,1,1,'serving',19,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1067,1,1,'container, individual',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1067,2,1,'fl oz',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1067,3,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1067,4,0.5,'cup',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1068,1,1,'container, individual',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1068,2,0.5,'cup',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1069,1,1,'cup',94,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1069,2,1,'tsp',2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1069,3,1,'packet',3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1070,1,1.5,'oz',43,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1070,2,1,'portion, amount to make 1 tbsp',1.3,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1071,1,1,'CUP',80,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1071,2,1,'TBSP',4,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1071,3,1,'package yields',160,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1072,1,1,'CUP',70,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1072,2,1,'TBSP',4,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1073,1,1,'CUP',75,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1073,2,1,'TBSP',4,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1074,1,1,'oz',28.35,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1074,2,1,'cup',230,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1076,1,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1076,2,1,'quart',976,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1077,1,1,'CUP',244,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1077,2,1,'fl oz',30.5,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1077,3,1,'tbsp',15,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1077,4,1,'quart',976,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1078,1,1,'CUP',244,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1078,2,1,'quart',976,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1079,1,1,'CUP',244,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1079,2,1,'FL OZ',30.5,'g',1,'1998-01-15','2010-01-05');
INSERT INTO `cndb_wght` VALUES (1079,3,1,'quart',976,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1080,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1080,2,1,'quart',980,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1081,1,1,'cup',246,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1081,2,1,'quart',984,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1082,1,1,'CUP',244,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1082,2,1,'FL OZ',30.5,'g',1,'1998-01-15','2010-01-05');
INSERT INTO `cndb_wght` VALUES (1082,3,1,'quart',976,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1083,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1083,2,1,'quart',980,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1084,1,1,'CUP',246,'g',1,'2001-07-04','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1084,2,1,'quart',984,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1085,1,1,'CUP',245,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1085,2,1,'FL OZ',30.6,'g',1,'1998-01-15','2010-01-05');
INSERT INTO `cndb_wght` VALUES (1085,3,1,'quart',980,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1086,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1086,2,1,'fl oz',30.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1086,3,1,'quart',980,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1087,1,1,'CUP',246,'g',1,'2001-07-04','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1087,2,1,'quart',984,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1088,1,1,'CUP',245,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1088,2,1,'FL OZ',30.6,'g',1,'1998-01-15','2010-01-05');
INSERT INTO `cndb_wght` VALUES (1088,3,1,'quart',980,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1089,1,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1089,2,1,'fl oz',30.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1089,3,1,'quart',976,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1090,1,0.25,'CUP',32,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1090,2,1,'CUP',128,'g',1,'2007-11-28','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1091,1,0.25,'CUP',30,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1091,2,1,'CUP',120,'g',1,'2007-11-28','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1091,3,5,'tbsp',23,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (1092,1,1,'CUP',68,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1092,2,1,'envelope (1-1/3 cup)',91,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1092,3,0.333,'cup (makes 1 cup reconstituted milk)',23,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1093,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1093,2,0.25,'lb',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1094,1,0.25,'cup',30,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1094,2,1,'cup',120,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1094,3,1,'tbsp',6.5,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (1095,1,1,'fl oz',38.2,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1095,2,1,'cup',306,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1096,1,1,'fl oz',31.5,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1096,2,1,'cup',252,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1096,3,1,'can (13 oz)',369,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (1096,4,0.5,'CUP',126,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (1097,1,1,'fl oz',31.9,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1097,2,1,'cup',256,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1097,3,0.5,'CUP',128,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (1102,1,1,'CUP',250,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1102,2,1,'FL OZ',31.2,'g',1,'1994-01-31','2010-01-05');
INSERT INTO `cndb_wght` VALUES (1102,3,1,'quart',1000,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1103,1,1,'CUP',250,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1103,2,1,'FL OZ',31.2,'g',1,'1994-01-31','2010-01-05');
INSERT INTO `cndb_wght` VALUES (1103,3,1,'quart',1000,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1104,1,1,'CUP',250,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1104,2,1,'quart',1000,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1105,1,1,'CUP',250,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1105,2,1,'FL OZ',31.2,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (1106,1,1,'fl oz',30.5,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1106,2,1,'cup',244,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1106,3,1,'quart',976,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1108,1,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1108,2,1,'quart',976,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1109,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1109,2,1,'quart',980,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1110,1,1,'FL OZ',28.4,'g',1,'1999-03-22','2010-01-05');
INSERT INTO `cndb_wght` VALUES (1110,2,1,'container (10.6 oz)',300,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1111,1,1,'FL OZ',28.4,'g',1,'1999-03-22','2010-01-05');
INSERT INTO `cndb_wght` VALUES (1111,2,1,'container (11 oz)',313,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1112,1,1,'cup',246,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1112,2,1,'quart',984,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1113,1,1,'cup',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1113,2,1,'tbsp',2.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1114,1,1,'cup',246,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1114,2,1,'quart',984,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1115,1,1,'cup',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1115,2,1,'tbsp',7.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1116,1,1,'container (6 oz)',170,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1116,2,1,'container (8 oz)',227,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1116,3,0.5,'container (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1116,4,1,'cup (8 fl oz)',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1117,1,1,'container (6 oz)',170,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1117,2,1,'container (8 oz)',227,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1117,3,0.5,'container (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1117,4,1,'cup (8 fl oz)',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1118,1,1,'container (6 oz)',170,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1118,2,1,'container (8 oz)',227,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1118,3,1,'cup (8 fl oz)',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1119,1,1,'container (6 oz)',170,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1119,2,1,'container (8 oz)',227,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1119,3,1,'cup (8 fl oz)',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1120,1,1,'container (6 oz)',170,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1120,2,1,'container (4.4 oz)',125,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1120,3,1,'container (5 oz)',142,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1120,4,1,'cup (8 fl oz)',245,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1120,5,1,'container (8 oz)',227,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1120,6,0.5,'container (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1121,1,1,'container (6 oz)',170,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1121,2,1,'cup (8 fl oz)',245,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1121,3,1,'container (8 oz)',227,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1121,5,1,'container, Dannon Sprinkl''ins (4.1 oz)',116,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1121,6,0.5,'container (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1122,1,1,'container (6 oz)',170,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1122,2,0.5,'container (4 oz)',113,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1122,3,1,'container (8 oz)',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1123,1,1,'large',50,'g',1,'2007-11-27','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1123,2,1,'extra large',56,'g',1,'2007-11-27','2007-11-27');
INSERT INTO `cndb_wght` VALUES (1123,3,1,'jumbo',63,'g',1,'2007-11-27','2007-11-27');
INSERT INTO `cndb_wght` VALUES (1123,5,1,'cup (4.86 large eggs)',243,'g',1,'2007-11-27','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1123,6,1,'medium',44,'g',1,'2007-11-27','2007-11-27');
INSERT INTO `cndb_wght` VALUES (1123,7,1,'small',38,'g',1,'2007-11-27','2007-11-27');
INSERT INTO `cndb_wght` VALUES (1124,1,1,'large',33,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1124,2,1,'cup',243,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1125,1,1,'large',17,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1125,2,1,'cup',243,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1126,1,1,'oz',28.35,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1126,2,0.5,'lb',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1127,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1127,2,0.5,'lb',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1128,1,1,'large',46,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1129,1,1,'cup, chopped',136,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1129,2,1,'TBSP',8.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1129,3,1,'large',50,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1130,1,1,'TBSP',15,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1130,2,1,'large',61,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1131,1,1,'large',50,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1132,1,1,'large',61,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1132,2,1,'TBSP',13.7,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1132,3,1,'cup',220,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1133,1,1,'cup, sifted',85,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1133,2,1,'TBSP',5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1134,1,1,'cup, sifted',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1134,2,1,'tbsp',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1135,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1135,2,0.5,'lb',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1136,1,1,'cup, sifted',107,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1136,2,1,'tbsp',7,'g',1,'1997-08-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (1137,1,1,'cup, sifted',67,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1137,2,1,'TBSP',4,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1138,1,1,'egg',70,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1139,1,1,'egg',144,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1140,1,1,'egg',9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1141,1,1,'egg',79,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1144,1,0.35,'oz',9.9,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1144,2,0.7,'oz',20,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (1145,1,1,'pat (1" sq, 1/3" high)',5,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1145,2,1,'TBSP',14.2,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1145,3,1,'cup',227,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1145,4,1,'stick',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1146,1,1,'TBSP',5,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1151,1,1,'CUP',245,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1151,2,1,'quart',980,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1152,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1152,2,1,'quart',980,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1153,1,1,'FL OZ',31.5,'g',1,'1994-01-31','2010-01-05');
INSERT INTO `cndb_wght` VALUES (1153,2,0.5,'CUP',126,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1154,1,0.25,'CUP',30,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1154,2,1,'CUP',120,'g',1,'2007-11-28','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1155,1,1,'CUP',68,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1155,2,1,'envelope (1-1/3 cup)',91,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1156,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1157,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1159,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1160,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1160,2,0.5,'lb',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1161,1,1,'cup, shredded',113,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (1161,2,1,'oz',28.35,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1161,3,1,'cubic inch',18,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (1161,4,1,'slice',28,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (1161,5,3,'oz',85,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (1164,1,2,'tbsp',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1164,2,1,'cup',243,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1165,1,1,'cup, crumbled',132,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1165,2,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1166,1,1,'cup, diced',132,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1166,2,1,'cup, shredded',113,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1166,3,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1166,4,1,'cubic inch',18,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1166,5,1,'slice (1 oz)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1167,1,1,'cup, diced',132,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1167,2,1,'cup, shredded',113,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1167,3,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1167,4,1,'cubic inch',17,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1167,5,1,'slice (1 oz)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1168,1,1,'cup, diced',132,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1168,2,1,'cup, shredded',113,'g',1,'1995-05-23','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1168,3,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1168,4,1,'cubic inch',17,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1168,5,1,'slice (1 oz)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1169,1,1,'cup, diced',132,'g',1,'2001-07-04','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1169,2,1,'cup, shredded',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1169,3,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1169,4,1,'cubic inch',17,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1169,5,1,'slice (1 oz)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1171,1,1,'oz',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1172,1,1,'oz',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1173,1,1,'oz',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1174,1,1,'cup',246,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1174,2,1,'quart',984,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1175,1,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1175,2,1,'quart',976,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1178,1,1,'tablespoon',12,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1178,2,1,'cup',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1179,1,1,'tablespoon',12,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1179,2,1,'cup',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1180,1,1,'tablespoon',12,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1180,2,1,'cup',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1184,1,1,'container (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1185,1,1,'tablespoon',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1186,1,1,'tbsp',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1187,1,1,'container (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1199,1,2,'tbsp',29,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1199,2,1,'pint',484,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1202,1,1,'CUP',250,'g',1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1202,2,1,'FL OZ',31.2,'g',1,'2006-02-23','2010-01-05');
INSERT INTO `cndb_wght` VALUES (1202,3,1,'quart',1000,'g',1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1203,1,1,'container (6 oz)',170,'g',1,'2006-02-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1203,2,1,'cup (8 fl oz)',245,'g',1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_wght` VALUES (1203,3,1,'container (8 oz)',227,'g',1,'2006-02-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1204,1,1,'cup',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (1204,2,1,'tbsp',5,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (1204,3,1,'oz',28.35,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (1205,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1206,1,4,'tsp',12,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1208,1,1,'cup, diced',132,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (1208,2,1,'oz',28.35,'g',1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1208,3,1,'cup, shredded',113,'g',1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1208,4,1,'cubic inch',14.3,'g',1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1208,5,1,'slice (1 oz)',28,'g',1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1208,6,1,'package (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1209,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1209,2,0.25,'cup',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1211,1,1,'cup',244,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1211,2,1,'tbsp',15,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1211,3,1,'fl oz',30.5,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1211,4,1,'quart',976,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1212,1,1,'cup',128,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1212,2,0.25,'cup',32,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1215,1,1,'slice 3/4 oz',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1215,2,1,'slice 2/3 oz',19,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1216,1,1,'container (6 oz)',170,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1216,2,1,'container (4.4 oz)',125,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1216,3,1,'container (5 oz)',142,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1216,4,1,'cup (8 fl oz)',245,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1216,5,1,'container (8 oz)',227,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1216,6,0.5,'container (4 oz)',113,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1217,1,1,'container (6 oz)',170,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1217,2,1,'cup (8 fl oz)',245,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1217,3,1,'container (8 oz)',227,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1217,5,1,'container, Dannon Sprinkl''ins (4.1 oz)',116,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1217,6,0.5,'container (4 oz)',113,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1218,1,1,'container (6 oz)',170,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1218,2,1,'container (4.4 oz)',125,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1218,3,1,'cup (8 fl oz)',245,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1218,4,1,'container (8 oz)',227,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1219,1,1,'container (6 oz)',170,'g',1,'2010-01-04','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1219,2,1,'cup (8 fl oz)',245,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1219,3,1,'container (8 oz)',227,'g',1,'2010-01-04','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1220,1,1,'container (6 oz)',170,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1220,2,1,'container (8 oz)',227,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1220,3,0.5,'container (4 oz)',113,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (1220,4,1,'cup (8 fl oz)',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1221,1,1,'container (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1222,1,1,'container (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1225,1,1,'tbsp',19,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1226,1,0.25,'cup',60,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1226,2,1,'cup',240,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (1227,1,1,'cup grated',97,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1228,1,1,'cup, crumbled',122,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1229,1,1,'cup, crumbled',118,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1230,1,1,'cup',245,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1231,1,1,'container',170,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1235,1,0.5,'cup',68,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1236,1,0.5,'cup',86,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1237,1,1,'bar',50,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1238,1,1,'serving',70,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1239,1,1,'serving',82,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1240,1,1,'unit',96,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1241,1,1,'serving',70,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1242,1,1,'serving',70,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1243,1,0.5,'cup',68,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1244,1,1,'bar',68,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1250,1,1,'can',227,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1251,1,0.25,'cup shredded',28,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1252,1,1,'slice (2/3 oz)',19,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1252,2,1,'slice (3/4 oz)',21,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1253,1,1,'oz',28.35,'g',1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1253,2,1,'slice (3/4 oz)',21,'g',1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1253,3,1,'slice (1 oz)',28,'g',1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1253,4,1,'cubic inch',18,'g',1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1253,5,1,'cup, diced',140,'g',1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1253,6,1,'cup, shredded',113,'g',1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1253,7,1,'cup, melted',244,'g',1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_wght` VALUES (1254,1,1,'cup',113,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1254,2,1,'oz',28.35,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1254,3,1,'slice (3/4 oz)',21,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1254,4,1,'package (8 oz)',227,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (1255,1,1,'oz',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1256,1,1,'container',170,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (1258,1,1,'cup, sifted',107,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (1258,2,1,'tbsp',7,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (1259,1,1,'piece',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1259,2,1,'package',566,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1260,1,1,'slice',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1263,1,1,'medium',298,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1264,1,26,'pieces',95,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1265,1,1,'serving',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1266,1,1,'serving',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1267,1,2,'tsp',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (1270,1,1,'slice (2/3 oz)',19,'g',1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1270,2,1,'slice (3/4 oz)',21,'g',1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1270,3,1,'slice (1 oz)',28,'g',1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1271,1,1,'cup',86,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (1284,1,1,'container (5.3 oz)',150,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1284,2,1,'cup (8 fl oz)',245,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (1284,3,1,'container (6 oz)',170,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (1284,4,1,'container (8 oz)',227,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (1284,5,1,'container, Dannon Sprinkl''ins (4.1 oz)',116,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (1284,6,0,'container (4 oz)',113,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (1285,1,1,'container (5.3 oz)',150,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1286,1,1,'container (5.3 oz)',150,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1287,1,1,'container (7 oz)',200,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1291,1,1,'cup',252,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1291,2,1,'fl oz',31.5,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1291,3,1,'can (13 oz)',369,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1291,4,0.5,'cup',126,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1292,1,1,'cup',250,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (1292,2,1,'fl oz',31.2,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (1292,3,1,'quart',1000,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (1295,1,1,'cup (8 fl oz)',245,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1295,2,1,'container (8 oz)',227,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (1295,3,0.5,'container (4 oz)',113,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (2001,1,1,'tsp',1.9,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2001,2,1,'tbsp',6,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2002,1,1,'tsp, whole',2.1,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2002,2,1,'tbsp, whole',6.7,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2003,1,1,'tsp, leaves',0.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2003,2,1,'tbsp, leaves',2.1,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2003,3,1,'tsp, ground',1.4,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2003,4,1,'tbsp, ground',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2004,1,1,'tsp, crumbled',0.6,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2004,2,1,'tbsp, crumbled',1.8,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2005,1,1,'tsp',2.1,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2005,2,1,'tbsp',6.7,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2006,1,1,'tsp, ground',2,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2006,2,1,'tbsp, ground',5.8,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2007,1,1,'tsp',2,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2007,2,1,'tbsp',6.5,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2008,1,1,'tsp',0.6,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2008,2,1,'tbsp',1.9,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2009,1,1,'tsp',2.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2009,2,1,'tbsp',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2010,1,1,'tsp',2.6,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2010,2,1,'tbsp',7.8,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2011,1,1,'tsp',2.1,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2011,2,1,'tbsp',6.5,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2012,1,1,'tsp',0.6,'g',1,'1994-11-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2012,2,1,'tbsp',1.8,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2013,1,1,'tsp',1.8,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2013,2,1,'tbsp',5,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2014,1,1,'tsp, whole',2.1,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2014,2,1,'tbsp, whole',6,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2015,1,1,'tsp',2,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2015,2,1,'tbsp',6.3,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2016,1,1,'tsp',2.1,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2016,2,1,'tbsp',6.6,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2017,1,1,'tsp',1,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2017,2,1,'tbsp',3.1,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2018,1,1,'tsp, whole',2,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2018,2,1,'tbsp, whole',5.8,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2019,1,1,'tsp',3.7,'g',1,'1994-11-17','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2019,2,1,'tbsp',11.1,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2020,1,1,'tsp',3.1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2020,2,1,'tbsp',9.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2021,1,1,'tsp',1.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2021,2,1,'tbsp',5.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2022,1,1,'tsp',1.7,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2022,2,1,'tbsp',5.3,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2023,1,1,'tsp',0.6,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2023,2,1,'tbsp',1.7,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2024,1,1,'tsp',2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2024,2,1,'tbsp',6.3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2025,1,1,'tsp',2.2,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2025,2,1,'tbsp',7,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2026,1,1,'tsp',2.4,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2026,2,1,'tbsp',6.9,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2027,1,1,'tsp, leaves',1,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2027,2,1,'tsp, ground',1.8,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2028,1,1,'tsp',2.3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2028,2,1,'tbsp',6.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2029,1,1,'tsp',0.5,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2029,2,1,'TBSP',1.6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2030,1,1,'tsp, ground',2.3,'g',1,'2012-04-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2030,2,1,'tbsp, ground',6.9,'g',1,'2012-04-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2030,3,1,'tsp, whole',2.9,'g',1,'2002-09-06','2012-04-04');
INSERT INTO `cndb_wght` VALUES (2030,4,1,'dash',0.1,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (2031,1,1,'tsp',1.8,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2031,2,1,'tbsp',5.3,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2032,1,1,'tsp, ground',2.4,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2032,2,1,'tbsp, ground',7.1,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2033,1,1,'tsp',2.8,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2033,2,1,'tbsp',8.8,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2034,1,1,'tsp',1.5,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2034,2,1,'tbsp',4.4,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2035,1,1,'tsp',1.7,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2035,2,1,'tbsp',5.6,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2036,1,1,'tsp',1.2,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2036,2,1,'tbsp',3.3,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2037,1,1,'tsp',0.7,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2037,2,1,'tbsp',2.1,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2038,1,1,'tsp',0.7,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2038,2,1,'tbsp',2,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2039,1,1,'tsp',1.4,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2039,2,1,'tbsp',4.4,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2041,1,1,'tsp, leaves',0.6,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2041,2,1,'tbsp, leaves',1.8,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2041,3,1,'tsp, ground',1.6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2041,4,1,'tbsp, ground',4.8,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2042,1,1,'tsp, leaves',1,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2042,2,1,'tbsp, leaves',2.7,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2042,3,1,'tsp, ground',1.4,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2042,4,1,'tbsp, ground',4.3,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2043,1,1,'tsp',3,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2043,2,1,'tbsp',9.4,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2044,1,5,'leaves',2.5,'g',1,'1994-11-17','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2044,2,2,'tbsp, chopped',5.3,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2044,3,0.25,'cup leaves, whole',6,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (2045,1,5,'sprigs',1,'g',1,'1994-11-17','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2045,2,1,'cup sprigs',8.9,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2046,1,1,'tsp or 1 packet',5,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2046,2,1,'CUP',249,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2047,1,1,'tsp',6,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2047,2,1,'TBSP',18,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2047,3,1,'cup',292,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2047,4,1,'dash',0.4,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2048,1,1,'tbsp',14.9,'g',1,'1994-11-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2048,2,1,'cup',239,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2048,3,1,'tsp',5,'g',1,'2005-12-28','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2049,1,1,'tsp',0.8,'g',1,'2001-07-04','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2049,2,0.5,'tsp',0.4,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (2050,1,1,'tsp',4.2,'g',1,'1994-11-17','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2050,2,1,'TBSP',13,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2050,3,1,'cup',208,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2052,1,1,'tsp',4.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2052,2,1,'tbsp',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2053,1,1,'tbsp',14.9,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2053,2,1,'cup',238,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2053,3,1,'tsp',5,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (2054,1,1,'tbsp, drained',8.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2055,1,1,'tsp',5,'g',1,'1994-11-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2055,2,1,'tbsp',15,'g',1,'1999-02-12','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2063,1,1,'tsp',0.7,'g',1,'2001-07-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2063,2,1,'tbsp',1.7,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2064,1,2,'leaves',0.1,'g',1,'2005-12-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2064,2,2,'tbsp',3.2,'g',1,'2005-12-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2065,1,2,'leaves',0.3,'g',1,'2005-12-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2065,2,2,'tbsp',11.4,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2066,1,1,'tsp',0.5,'g',1,'2005-12-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2066,2,1,'tbsp',1.6,'g',1,'2005-12-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (2068,1,1,'tbsp',14.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2068,2,1,'cup',239,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2068,3,1,'tsp',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2069,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2069,2,1,'cup',255,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2069,3,1,'tsp',5.3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2074,1,0.25,'tsp',1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2075,1,2,'tsp',5.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (2076,1,1.33,'tbsp',9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3001,1,1,'packet',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3002,1,1,'tbsp',14.7,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3002,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3002,3,1,'jar',71,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3003,1,1,'oz',28.35,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3003,2,1,'tbsp',14.7,'g',1,'1999-03-22','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3003,3,1,'jar',71,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3005,1,1,'tbsp',16,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3005,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3005,3,1,'jar',71,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3007,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3007,2,1,'jar',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3008,1,1,'TBSP',15,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3008,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3008,3,1,'jar',71,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3008,4,1,'jar Gerber Second Foods (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3009,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3009,2,1,'jar',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3010,1,1,'tbsp',22,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3010,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3010,3,1,'jar',71,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3010,4,1,'container',70,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3011,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3011,2,1,'jar',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3012,1,1,'TBSP',15,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3012,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3012,3,1,'jar',71,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3012,4,1,'jar Beech-Nut Stage 1 (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3012,5,1,'jar Gerber Second Foods (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3012,6,1,'jar Heinz Strained-2 (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3013,1,1,'TBSP',15,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3013,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3013,3,1,'jar',71,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3013,4,1,'jar Gerber Third Foods (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3013,5,1,'jar Heinz Junior-3 (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3014,1,1,'stick',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3014,2,1,'jar',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3014,3,1,'jar Gerber Graduate (2.5 oz)',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3015,1,1,'TBSP',15,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3015,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3015,3,1,'jar',71,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3015,4,1,'jar Beech-Nut Stage 1 (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3015,5,1,'jar Gerber Second Foods (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3015,6,1,'jar Heinz Strained-2 (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3016,1,1,'tbsp',19,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3016,2,1,'container',68,'g',1,'1999-03-22','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3017,1,1,'stick',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3017,2,1,'jar',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3017,3,1,'jar Gerber Graduate (2.5 oz)',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3021,1,1,'stick',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3021,2,1,'jar',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3021,3,1,'jar Gerber Graduate (2.5 oz)',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3026,1,1,'serving',88,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (3044,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3044,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3044,3,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3044,4,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3044,5,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3044,6,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3045,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3045,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3045,3,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3045,4,1,'jar Beech-Nut Stage 3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3045,5,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3046,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3046,2,1,'piece',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3047,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3047,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3047,3,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3047,4,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3047,5,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3047,6,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3048,1,1,'container',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3050,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3050,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3050,3,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3050,4,1,'jar Beech-Nut Stage 3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3050,5,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3050,6,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3053,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3053,2,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3053,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3053,4,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3053,5,1,'jar Earth''s Best (4.5 oz)',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3053,6,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3053,7,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3053,8,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3054,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3054,2,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3054,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3054,4,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3054,5,1,'jar Beech-Nut Stage 3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3054,6,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3054,7,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3055,1,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3067,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3067,2,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3068,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3068,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3068,3,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3068,4,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3068,5,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3068,6,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3069,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3069,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3069,3,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3069,4,1,'jar Beech-Nut Stage 3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3069,5,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3069,6,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3070,1,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3070,2,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3070,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3070,4,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3070,5,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3072,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3072,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3072,3,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3073,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3073,2,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3073,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3073,4,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3073,5,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3073,6,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3073,7,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3077,1,1,'jar, Gerber (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3082,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3082,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3082,3,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3082,4,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3082,5,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3082,6,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3083,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3083,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3083,3,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3083,4,1,'jar Beech-Nut Stage 3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3083,5,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3083,6,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3084,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3084,2,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3084,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3084,4,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3084,5,1,'jar Earth''s Best (4.5 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3084,6,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3085,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3085,2,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3085,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3085,4,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3085,5,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3089,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3089,2,1,'jar',113,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3090,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3090,2,1,'jar',170,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3091,1,1,'CUP',240,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3091,2,1,'TBSP',15,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3091,3,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3091,4,1,'jar',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3091,5,1,'jar Beech-Nut Stage I (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3091,6,1,'jar Gerber First Foods (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3091,7,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3091,8,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3091,9,1,'jar Heinz Beginner-1 (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3092,1,1,'CUP',240,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3092,2,1,'TBSP',15,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3092,3,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3092,4,1,'jar',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3092,5,1,'jar Beech-Nut Stage 3 (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3093,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3093,2,1,'jar',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3096,1,1,'jar, Gerber (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3098,1,1,'CUP',224,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3098,2,1,'TBSP',14,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3098,3,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3098,4,1,'jar',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3098,5,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3098,6,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3099,1,1,'CUP',224,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3099,2,1,'TBSP',14,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3099,3,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3099,4,1,'jar',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3099,5,1,'jar Beech-Nut Baby''s First (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3099,6,1,'jar Beech-Nut Stage I (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3099,7,1,'jar Gerber First Foods (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3099,8,1,'jar Earth''s Best (4.5 oz)',128,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3099,9,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3099,10,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3099,11,1,'jar Heinz Beginner-1 (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3100,1,1,'CUP',224,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3100,2,1,'TBSP',14,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3100,3,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3100,4,1,'jar',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3100,5,1,'jar Beech-Nut Stage 3 (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3100,6,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3100,7,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3104,1,1,'tbsp',16,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3104,2,1,'oz',28.35,'g',1,'1999-03-22','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3104,3,1,'jar',113,'g',1,'1998-01-15','2011-01-18');
INSERT INTO `cndb_wght` VALUES (3105,1,1,'tbsp',16,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3105,2,1,'oz',28.35,'g',1,'1999-03-22','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3105,3,1,'jar',99,'g',1,'1998-01-15','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3105,4,1,'container',67,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3108,1,1,'CUP',224,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3108,2,1,'TBSP',14,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3108,3,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3108,4,1,'jar',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3108,5,1,'jar Beech-Nut Baby''s First (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3108,6,1,'jar Beech-Nut Stage I (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3108,7,1,'jar Gerber First Foods (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3108,8,1,'jar Earth''s Best (4.5 oz)',128,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3108,9,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3108,10,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3108,11,1,'jar Heinz Beginner-1 (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3109,1,1,'CUP',224,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3109,2,1,'TBSP',14,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3109,3,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3109,4,1,'jar',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3109,5,1,'jar Beech-Nut Stage 3 (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3109,6,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3109,7,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3112,1,1,'cup',163,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3112,2,1,'tbsp',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3112,3,1,'jar Gerber Graduate (4.5 oz)',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3114,1,1,'jar, Gerber (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3115,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3116,1,1,'TBSP',16,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3116,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3116,3,1,'jar',113,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3116,4,1,'jar Beech-Nut Baby''s First (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3116,5,1,'jar Beech-Nut Stage I (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3116,6,1,'jar Gerber First Foods (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3116,7,1,'jar Earth''s Best (4.5 oz)',128,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3116,8,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3116,9,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3116,10,1,'jar Heinz Beginner-1 (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3117,1,1,'TBSP',16,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3117,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3117,3,1,'jar',170,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3117,4,1,'jar Beech-Nut Stage 3 (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3117,5,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3117,6,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3118,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3118,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3118,3,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3118,4,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3118,5,1,'jar Heinz Strained-2 (4.25 oz)',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3119,1,1,'jar',113,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (3119,2,1,'TBSP',15,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3119,3,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3119,4,1,'cup',240,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (3119,5,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3119,6,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3119,7,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3120,1,1,'CUP',240,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3120,2,1,'TBSP',15,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3120,3,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3120,4,1,'jar',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3120,5,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3121,1,1,'tbsp',16,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3121,2,1,'oz',28.35,'g',1,'1999-03-22','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3121,3,1,'jar',95,'g',1,'1998-01-15','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3121,4,1,'CUP',240,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3121,5,1,'container',91,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3122,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3127,1,1,'CUP',240,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3127,2,1,'TBSP',15,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3127,3,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3127,4,1,'jar',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3127,5,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3128,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3128,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3128,3,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3128,4,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3128,5,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3129,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3129,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3129,3,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3129,4,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3129,5,1,'jar Heinz Strained-2 (4.25 oz)',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3130,1,1,'tbsp',17,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3130,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3130,3,1,'jar',95,'g',1,'1998-01-15','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3130,4,1,'container',67,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3131,1,1,'tbsp',17,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3131,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3131,3,1,'jar',95,'g',1,'1998-01-15','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3131,4,1,'container',67,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3132,1,1,'TBSP',16,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3132,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3132,3,1,'jar',113,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3132,4,1,'jar Beech-Nut Baby''s First (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3132,5,1,'jar Beech-Nut Stage I (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3132,6,1,'jar Gerber First Foods (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3132,7,1,'jar Earth''s Best (4.5 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3132,8,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3132,9,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3132,10,1,'jar Heinz Beginner-1 (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3133,1,1,'TBSP',16,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3133,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3133,3,1,'jar',170,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3133,4,1,'jar Beech-Nut Stage 3 (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3133,5,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3133,6,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3134,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3134,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3134,3,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3134,4,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3134,5,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3135,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3135,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3135,3,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3135,4,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3136,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3136,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3136,3,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3136,4,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3136,5,1,'jar Heinz Strained-2 (4.25 oz)',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3137,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3137,2,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3139,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3139,2,1,'jar Gerber First Foods (2.5 oz)',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3140,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3140,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3140,3,1,'jar, Gerber (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3140,4,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3141,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3141,2,1,'jar Gerber',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3142,1,1,'TBSP',16,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3142,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3142,3,1,'jar',113,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3142,4,1,'jar Earth''s Best (4.5 oz)',128,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3142,5,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3142,6,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3142,7,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3143,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3143,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3143,3,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3143,4,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3144,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3144,2,1,'jar',113,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3145,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3145,2,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3147,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3147,2,1,'jar NFS',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3147,3,1,'jar Beech-Nut Stage 3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3150,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3150,2,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3151,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3151,2,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3152,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3152,2,1,'jar',113,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3153,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3153,2,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3154,1,1,'jar, Gerber (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3156,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3156,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3156,3,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3156,4,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3156,5,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3157,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3157,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3157,3,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3157,4,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3157,5,1,'jar Heinz Strained-2 (4.25 oz)',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3158,1,1,'TBSP',16,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3158,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3158,3,1,'jar',113,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3158,4,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3158,5,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3158,6,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3159,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3159,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3159,3,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3159,4,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3161,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3161,2,1,'jar Gerber',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3163,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3163,2,1,'jar NFS',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3163,3,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3164,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3164,2,1,'jar',113,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3165,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3165,2,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3166,1,1,'fl oz',31.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3166,2,1,'jar',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3166,3,1,'bottle Earth''s Best (4.2 fl oz)',131,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3166,4,1,'bottle Heinz Strained (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3166,5,1,'bottle Gerber First Food (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3166,6,1,'bottle Beech-Nut Stage I (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3167,1,1,'fl oz',31.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3167,2,1,'bottle Earth''s Best (4.2 fl oz)',131,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3167,3,1,'bottle Heinz Strained (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3167,4,1,'bottle NFS',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3167,5,1,'bottle Beech-Nut Stage 2 (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3167,6,1,'bottle Gerber Second Foods (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3168,1,1,'fl oz',31.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3168,2,1,'jar',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3171,1,1,'fl oz',31.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3171,2,1,'jar',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3171,3,1,'bottle (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3172,1,1,'fl oz',31.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3172,2,1,'jar',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3172,3,1,'bottle Heinz Strained (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3172,4,1,'bottle Gerber Second Foods (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3172,5,1,'bottle Beech-Nut Stage 3 (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3174,1,1,'fl oz',31.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3174,2,1,'jar',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3174,3,1,'bottle Heinz Strained (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3175,1,1,'fl oz',31.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3175,2,1,'jar',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3177,1,1,'fl oz',31.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3177,2,1,'jar',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3179,1,1,'fl oz',31.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3179,2,1,'jar',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3179,3,1,'bottle (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3181,1,1,'tbsp',2.4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3181,2,0.5,'oz',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3184,1,0.5,'oz',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3185,1,1,'TBSP',2.5,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3185,2,0.5,'oz',15,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3186,1,1,'tbsp',2.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3186,2,0.5,'oz',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3187,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3187,2,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3188,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3188,2,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3189,1,1,'tbsp',3.2,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (3189,2,0.5,'oz',15,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3189,3,0.25,'CUP',12.2,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (3189,4,1,'box',223,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (3190,1,1,'serving',15,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (3190,2,0.5,'oz',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3190,3,1,'tbsp',2.5,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (3191,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3191,2,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3192,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3192,2,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3194,1,1,'TBSP',2.5,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3194,2,0.5,'oz',15,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3195,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3195,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3195,3,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3195,4,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3195,5,1,'jar Heinz Strained-2 (4.25 oz)',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3197,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3197,2,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3198,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3198,2,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3199,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3199,2,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3201,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3201,2,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3205,1,1,'tbsp',5.3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3205,2,1,'packet (.75 oz)',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3206,1,1,'cookie',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3209,1,1,'cracker',0.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3211,1,1,'tbsp',2.4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3211,2,0.5,'oz',14.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3212,1,1,'TBSP',2.5,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3212,2,0.5,'oz',15,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3213,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3213,2,1,'cookie',6.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3214,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3214,2,1,'cookie',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3215,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3215,2,1,'pretzel',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3220,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3220,2,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3221,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3221,2,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3222,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3224,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3224,2,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3225,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3225,2,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3226,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3226,2,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3227,1,1,'TBSP',15,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3227,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3227,3,1,'jar',113,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3227,4,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3227,5,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3228,1,1,'TBSP',15,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3228,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3228,3,1,'jar',220,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3228,4,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3233,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3233,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3233,3,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3233,4,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3235,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3235,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3235,3,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3235,4,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3235,5,1,'jar Heinz Strained-2 (4.25 oz)',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3236,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3236,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3236,3,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3236,4,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3236,5,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3245,1,1,'cup',229,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3245,2,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3245,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3245,4,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3245,5,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3245,6,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3245,7,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3246,1,1,'CUP',229,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3246,2,1,'TBSP',14,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3246,3,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3246,4,1,'jar',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3246,5,1,'jar Beech-Nut Stage 3 (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3246,6,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3246,7,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3265,1,1,'fl oz',31.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3265,2,1,'jar',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3265,3,1,'bottle Earth''s Best (4.2 fl oz)',131,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3265,4,1,'bottle Heinz Strained (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3265,5,1,'bottle Beech-Nut Stage 2 (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3265,6,1,'bottle Gerber Second Foods (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3267,1,1,'fl oz',31.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3269,1,1,'serving',189,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3274,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3274,2,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3274,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3274,4,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3274,5,1,'jar Beech-Nut Stage 3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3274,6,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3279,1,1,'serving',99,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (3280,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3280,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3280,3,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3280,4,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3280,5,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3282,1,1,'serving 3.5 oz serving',99,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (3282,2,1,'TBSP',15,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3282,3,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3282,4,1,'cup',240,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (3282,5,1,'package 7 oz',198,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (3283,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3283,2,1,'jar',113,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3286,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3286,2,1,'jar',113,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3287,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3287,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3287,3,1,'jar',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3287,4,1,'jar Beech-Nut Stage 3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3287,5,1,'jar Gerber Third Foods (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3287,6,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3289,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3289,2,1,'jar NFS',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3289,3,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3290,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3290,2,1,'jar NFS',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3290,3,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3293,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3293,2,1,'jar Earth''s Best',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3296,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3296,2,1,'jar Beech nut',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3297,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3297,2,1,'jar',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3297,3,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3297,4,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3297,5,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3298,1,1,'tbsp',29,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3298,2,1,'container',162,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3303,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3303,2,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3681,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3685,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3686,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3689,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3690,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3694,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3712,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (3934,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3956,1,1,'oz',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3956,2,1,'container',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3959,1,1,'container',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3964,1,1,'bar',19,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3965,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3965,2,1,'container',69,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3994,1,1,'bottle',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3995,1,1,'packet',99,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (3996,1,3,'tbsp',16,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (4001,1,1,'tbsp',12.8,'g',1,'1994-11-17','2013-12-26');
INSERT INTO `cndb_wght` VALUES (4001,2,1,'cup',205,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (4002,1,1,'tbsp',12.8,'g',1,'1994-11-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (4002,2,1,'cup',205,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (4015,1,1,'tbsp',15,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4015,2,1,'cup',245,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4015,3,1,'serving (2 tbsp)',30,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4016,1,1,'tablespoon',15,'g',1,'1994-11-17','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4016,2,1,'CUP',245,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4017,1,1,'tbsp',16,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4017,2,1,'cup',250,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4017,3,1,'serving (2 tbsp)',30,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4018,1,1,'tbsp',14.7,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4018,2,1,'cup',235,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4020,1,1,'tablespoon',16,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4020,2,1,'CUP',260,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4020,3,1,'serving (2 tbsp)',30,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4021,1,1,'tablespoon',15,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4021,2,1,'CUP',240,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4022,1,1,'tablespoon',16,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4022,2,1,'CUP',260,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4023,1,1,'tablespoon',15,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4023,2,1,'CUP',245,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4023,3,1,'serving (2 tbsp)',15,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4025,1,1,'tbsp',13.8,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4025,2,1,'cup',220,'g',1,'1998-01-15','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4025,3,1,'packet',10,'g',1,'2004-07-15','2009-02-11');
INSERT INTO `cndb_wght` VALUES (4026,1,1,'tablespoon',13.8,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4026,2,1,'CUP',220,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4027,1,1,'tbsp',15,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (4027,2,1,'cup',240,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (4028,1,1,'tablespoon',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4028,2,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4029,1,1,'tablespoon',14.1,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4029,2,1,'CUP',225,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4030,1,1,'tablespoon',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4030,2,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4031,1,1,'tbsp',12.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4031,2,1,'cup',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4034,1,1,'tbsp',13.6,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4034,2,1,'cup',218,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4034,3,1,'tsp',4.5,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (4037,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4037,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4037,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4038,1,1,'tsp',4.5,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4038,2,1,'tablespoon',13.6,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4038,3,1,'cup',218,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4042,1,1,'tbsp',13.5,'g',1,'1994-11-02','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4042,2,1,'cup',216,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4042,3,1,'tsp',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4044,1,1,'tbsp',13.6,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4044,2,1,'cup',218,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4044,3,1,'tsp',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4047,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4047,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4047,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4053,1,1,'tablespoon',13.5,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4053,2,1,'CUP',216,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4053,3,1,'tsp',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4055,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4055,2,1,'cup',216,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4055,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4058,1,1,'tablespoon',13.6,'g',1,'1994-11-02','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4058,2,1,'CUP',218,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4058,3,1,'tsp',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4060,1,1,'TBSP',13.6,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4060,2,1,'CUP',218,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4060,3,1,'tsp',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4073,1,1,'tsp',4.7,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4073,2,1,'stick',113,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4114,1,1,'tbsp',14.7,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4114,2,1,'cup',235,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4120,1,1,'cup',250,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (4120,2,1,'tbsp',16,'g',1,'2002-09-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (4120,3,1,'individual packet',12.3,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (4128,1,1,'cup',232,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (4128,2,1,'tsp',4.8,'g',1,'2002-09-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (4133,1,1,'tablespoon',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4133,2,1,'cup',220,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4135,1,1,'tablespoon',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4135,2,1,'cup',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4141,1,1,'tablespoon',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4142,1,1,'tablespoon',16,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4142,2,1,'CUP',260,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4143,1,1,'tablespoon',14.7,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4143,2,1,'CUP',235,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4144,1,1,'tablespoon',15,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4144,2,1,'CUP',240,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4145,1,1,'tablespoon',13.8,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4145,2,1,'CUP',220,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4146,1,1,'tablespoon',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4146,2,1,'cup',220,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4367,1,1,'tablespoon',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4367,2,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4501,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4501,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4501,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4502,1,1,'tablespoon',13.6,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4502,2,1,'CUP',218,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4502,3,1,'tsp',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4506,1,1,'TBSP',13.6,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4506,2,1,'CUP',218,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4506,3,1,'tsp',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4510,1,1,'tbsp',13.6,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4510,2,1,'cup',218,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4510,3,1,'tsp',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4511,1,1,'tablespoon',13.6,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4511,2,1,'CUP',218,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4511,3,1,'tsp',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4513,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4513,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4513,3,2,'tbsp (1/8 cup)',27,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4514,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4514,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4514,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4515,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4515,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4515,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4516,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4516,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4516,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4517,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4517,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4517,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4518,1,1,'TBSP',13.6,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4518,2,1,'CUP',218,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4518,3,1,'tsp',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4528,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4528,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4528,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4529,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4529,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4529,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4530,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4530,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4530,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4531,1,1,'tablespoon',13.6,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4531,2,1,'CUP',218,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4531,3,1,'tsp',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4532,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4532,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4532,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4534,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4534,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4534,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4536,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4536,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4536,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4539,1,1,'tbsp',15,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4539,2,1,'cup',245,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4541,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4541,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4541,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4542,1,1,'tbsp',12.8,'g',1,'1994-11-17','2013-12-26');
INSERT INTO `cndb_wght` VALUES (4542,2,1,'cup',205,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (4543,1,1,'tablespoon',13.6,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4543,2,1,'CUP',218,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4543,3,1,'tsp',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4544,1,1,'tablespoon',12.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4544,2,1,'cup',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4545,1,1,'TBSP',13.6,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4545,2,1,'CUP',218,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4545,3,1,'tsp',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4546,1,1,'tablespoon',12.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4546,2,1,'cup',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4548,1,1,'tbsp',12.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4548,2,1,'cup',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4549,1,1,'TBSP',12.8,'g',1,'2001-07-04','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4549,2,1,'CUP',205,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4550,1,1,'TBSP',12.8,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4550,2,1,'CUP',205,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4551,1,1,'tbsp',12.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4551,2,1,'cup',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4554,1,1,'TBSP',12.8,'g',1,'2001-07-04','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4554,2,1,'CUP',205,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4556,1,1,'TBSP',12.8,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4556,2,1,'CUP',205,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4559,1,1,'tbsp',12.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4559,2,1,'cup',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4560,1,1,'TBSP',12.8,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4560,2,1,'CUP',205,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4570,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4570,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4572,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4572,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4572,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4573,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4573,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4573,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4575,1,1,'tbsp',12.8,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (4575,2,1,'tsp',4.3,'g',1,'1994-11-17','2013-12-26');
INSERT INTO `cndb_wght` VALUES (4575,3,1,'cup',205,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (4576,1,1,'tbsp',12.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4576,2,1,'cup',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4581,1,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4581,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4581,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4582,1,1,'tbsp',14,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4582,2,1,'cup',218,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4582,3,1,'tsp',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4583,1,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4583,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4583,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4584,1,1,'TBSP',14,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4584,2,1,'CUP',218,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4584,3,1,'tsp',4.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4585,1,1,'tbsp',14.1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4585,2,1,'cup',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4585,3,1,'tsp',4.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4585,4,1,'stick',111,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4586,1,1,'TBSP',12.8,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4586,2,1,'CUP',205,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4587,1,1,'TBSP',12.8,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4587,2,1,'CUP',205,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4588,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4588,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4588,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4589,1,1,'tsp',4.5,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4589,2,1,'tbsp',13.6,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4589,3,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4590,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4590,2,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4590,3,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4591,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4591,2,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4591,3,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4592,1,1,'tbsp',12.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4592,2,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4592,3,1,'cup',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4593,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4593,2,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4593,3,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4594,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4594,2,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4594,3,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4595,1,1,'TBSP',12.8,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4595,2,1,'CUP',205,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (4600,1,1,'tablespoon',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4601,1,1,'tablespoon',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4602,1,1,'tablespoon',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4609,1,1,'tsp',4.3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4610,1,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4610,2,1,'cup',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4610,3,1,'tsp',4.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4610,4,1,'pat (1" sq, 1/3" high)',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4610,5,1,'stick',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4611,1,1,'tbsp',14.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4611,2,1,'cup',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4612,1,1,'tbsp',14.3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4612,2,1,'cup',229,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4612,3,1,'tsp',4.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4613,1,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4613,2,1,'cup',229,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4613,3,1,'tsp',4.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4614,1,1,'tbsp',14.3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4614,2,1,'cup',229,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4614,3,1,'tsp',4.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4615,1,1,'tbsp',12.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4615,2,1,'cup',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4617,1,1,'tbsp',14.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4617,2,1,'cup',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4617,3,1,'pat (1" sq, 1/3" high)',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4617,4,1,'stick',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4618,1,1,'tbsp',14.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4618,2,1,'cup',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4620,1,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4624,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4626,1,1,'tablespoon',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4627,1,1,'tablespoon',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4628,1,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4629,1,1,'tbsp (1 NLEA serving)',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4631,1,1,'tbsp',14.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4631,2,1,'cup',233,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4633,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4633,2,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4634,1,1,'tbsp',12.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4634,2,1,'cup',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4635,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4635,2,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4636,1,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4636,2,1,'cup',231,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4638,1,1,'tablespoon',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4639,1,1,'tablespoon',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4639,2,1,'serving',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4640,1,1,'tablespoon',15,'g',1,'2005-02-05','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4640,2,1,'serving (2 tbsp)',30,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4641,1,1,'tablespoon',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4642,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4642,2,1,'teaspoon',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4642,3,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4643,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4643,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4644,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4644,2,1,'teaspoon',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4644,3,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4645,1,1,'tablespoon',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4645,2,1,'teaspoon',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4645,3,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4646,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4646,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4646,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4648,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4648,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4648,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4649,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4649,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4649,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4650,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4650,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4650,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4651,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4651,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4651,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4652,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4652,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4652,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4653,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4653,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4653,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4654,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4654,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4654,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4655,1,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4656,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4656,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4656,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4657,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4657,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4657,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4658,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4658,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4658,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4659,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4659,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4659,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4660,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4660,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4660,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4661,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4661,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4661,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4662,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4662,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4662,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4663,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4663,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4663,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4664,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4664,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4664,3,1,'tsp',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4665,1,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4666,1,1,'tbsp',12.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4666,2,1,'cup',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4667,1,1,'tbsp',12.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4667,2,1,'cup',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4668,1,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4668,2,1,'cup',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4668,3,1,'tsp',4.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4669,1,1,'tablespoon',13.6,'g',1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (4669,2,1,'CUP',218,'g',1,'2006-02-23','2007-03-25');
INSERT INTO `cndb_wght` VALUES (4669,3,1,'teaspoon',4.5,'g',1,'2006-02-23','2007-03-25');
INSERT INTO `cndb_wght` VALUES (4678,1,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4683,1,1,'tbsp (1 NLEA serving)',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4686,1,2,'tbsp (1 serving)',30,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (4688,1,1,'serving (approximately 10 sprays)',8,'g',1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_wght` VALUES (4690,1,1,'tbsp',14.9,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (4691,1,1,'tablespoon',14,'g',1,'2010-01-04','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4691,2,1,'cup',227,'g',1,'2010-01-04','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4691,3,1,'teaspoon',4,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (4692,1,1,'tbsp',14,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (4693,1,1,'tbsp',14,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (4694,1,1,'tbsp',14,'g',1,'2010-01-04','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4694,2,1,'cup',229,'g',1,'2010-01-04','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4694,3,1,'teaspoon',4.8,'g',1,'2010-01-04','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4695,1,1,'tbsp',14,'g',1,'2010-01-04','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4695,2,1,'cup',229,'g',1,'2010-01-04','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4695,3,1,'teaspoon',4.8,'g',1,'2010-01-04','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4696,1,1,'tbsp',14,'g',1,'2010-01-04','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4696,2,1,'cup',229,'g',1,'2010-01-04','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4696,3,1,'teaspoon',4.8,'g',1,'2010-01-04','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4697,1,1,'tbsp',14,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (4698,1,1,'tablespoon',14,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4698,2,1,'cup',218,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4698,3,1,'teaspoon',4.5,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4699,1,1,'tablespoon',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4699,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4699,3,1,'teaspoon',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4700,1,1,'tablespoon',13.6,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4700,2,1,'cup',218,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4700,3,1,'teaspoon',4.5,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4701,1,1,'tablespoon',13.6,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4701,2,1,'cup',218,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4701,3,1,'teaspoon',4.5,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (4702,1,1,'tablespoon',13.6,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (4702,2,1,'cup',218,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (4702,3,1,'teaspoon',4.5,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (4703,1,2,'tbsp',30,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (4704,1,2,'tbsp',33,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4705,1,2,'tbsp (1 NLEA serving)',34,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (4706,1,2,'tbsp (1 NLEA serving)',30,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (4707,1,1,'tablespoon',13.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4707,2,1,'cup',219,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4708,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (4708,2,1,'cup',232,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5000,1,3,'oz',85,'g',1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5000,2,1,'breast',384,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5001,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5001,2,1,'chicken',1046,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5002,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5002,2,1,'unit (yield from 1 lb ready-to-cook chicken)',308,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5002,3,1,'chicken',1028,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5003,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5003,2,1,'unit (yield from 1 lb ready-to-cook chicken)',212,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5003,3,1,'chicken',708,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5004,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5004,2,1,'unit (yield from 1 lb ready-to-cook chicken)',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5004,3,1,'chicken',682,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5005,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5005,2,1,'unit (yield from 1 lb ready-to-cook chicken)',225,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5005,3,1,'chicken',751,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5006,1,4,'oz',113,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5006,2,1,'unit (yield from 1 lb ready-to-cook chicken)',276,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5006,3,0.5,'chicken, bone removed',460,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5007,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5007,2,1,'unit (yield from 1 lb ready-to-cook chicken)',280,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5007,3,0.5,'chicken, bone removed',466,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5008,1,3,'oz',85,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5008,2,1,'unit (yield from 1 lb ready-to-cook chicken)',188,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5008,3,0.5,'chicken, bone removed',314,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5009,1,3,'oz',85,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5009,2,1,'cup, chopped or diced',140,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5009,3,0.5,'unit (yield from 1 lb ready-to-cook chicken)',178,'g',1,'2002-09-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5009,4,0,'chicken, bone removed',299,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5010,1,1,'cup, chopped or diced',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5010,2,1,'unit (yield from 1 lb ready-to-cook chicken)',200,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5010,3,0.5,'chicken, bone removed',334,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5011,1,4,'oz',113,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5011,2,1,'unit (yield from 1 lb ready-to-cook chicken)',197,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5011,3,0.5,'chicken, bone and skin removed',329,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5012,1,1,'cup, chopped or diced',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5012,2,1,'unit (yield from 1 lb ready-to-cook chicken)',155,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5012,3,0.5,'chicken, bone and skin removed',258,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5013,1,1,'cup, chopped or diced',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5013,2,1,'TBSP',8.7,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5013,3,1,'unit (yield from 1 lb ready-to-cook chicken)',146,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5014,1,1,'cup, chopped or diced',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5014,2,1,'TBSP',8.7,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5014,3,1,'unit (yield from 1 lb ready-to-cook chicken)',157,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5015,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5015,2,0.5,'unit (yield from 1 lb ready-to-cook chicken)',47,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5015,3,0,'chicken, skin only',79,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5016,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5016,2,0.5,'unit (yield from 1 lb ready-to-cook chicken)',114,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5016,3,0,'chicken, skin only',190,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5017,1,1,'unit (yield from 1 lb ready-to-cook chicken)',33,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5017,2,0.5,'chicken, skin only',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5018,1,1,'unit (yield from 1 lb ready-to-cook chicken)',34,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5018,2,0.5,'chicken, skin only',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5019,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5019,2,0.5,'unit (yield from 1 lb ready-to-cook chicken)',44,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5019,3,0,'chicken, skin only',72,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5020,1,1,'unit (yield from 1 lb ready-to-cook chicken)',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5020,2,1,'giblets',75,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5021,1,1,'cup, chopped or diced',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5021,2,1,'unit (yield from 1 lb ready-to-cook chicken)',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5022,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5022,2,1,'cup chopped or dice',145,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5023,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5023,2,1,'lb',453,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5024,1,1,'cup chopped or dice',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5025,1,1,'heart',6.1,'g',1,'2001-07-04','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5025,2,1,'unit (yield from 1 lb ready-to-cook chicken)',1.8,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5026,1,1,'cup, chopped or diced',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5026,2,1,'unit (yield from 1 lb ready-to-cook chicken)',1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5027,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5027,2,1,'liver',44,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5028,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5028,2,1,'liver',44,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5029,1,4,'oz',113,'g',1,'2001-07-04','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5029,2,0.5,'unit (yield from 1 lb ready-to-cook chicken)',116,'g',1,'2002-09-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5029,3,0,'chicken, bone removed',194,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5030,1,1,'unit (yield from 1 lb ready-to-cook chicken)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5030,2,0.5,'chicken, bone removed',188,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5031,1,1,'unit (yield from 1 lb ready-to-cook chicken)',78,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5031,2,0.5,'chicken, bone removed',130,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5032,1,1,'unit (yield from 1 lb ready-to-cook chicken)',79,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5032,2,0.5,'chicken, bone removed',132,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5033,1,1,'unit (yield from 1 lb ready-to-cook chicken)',90,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5033,2,0.5,'chicken, bone removed',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5034,1,4,'oz',113,'g',1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5034,2,1,'unit (yield from 1 lb ready-to-cook chicken)',160,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5034,3,0.5,'chicken, bone removed',266,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5035,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5035,2,1,'unit (yield from 1 lb ready-to-cook chicken)',167,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5035,3,0.5,'chicken, bone removed',278,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5036,1,1,'unit (yield from 1 lb ready-to-cook chicken)',110,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5036,2,0.5,'chicken, bone removed',184,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5037,1,1,'unit (yield from 1 lb ready-to-cook chicken)',101,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5037,2,0.5,'chicken, bone removed',167,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5038,1,1,'unit (yield from 1 lb ready-to-cook chicken)',110,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5038,2,0.5,'chicken, bone removed',184,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5039,1,1,'unit (yield from 1 lb ready-to-cook chicken)',88,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5039,2,0.5,'chicken, bone and skin removed',147,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5040,1,1,'cup',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5040,2,1,'unit (yield from 1 lb ready-to-cook chicken)',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5041,1,1,'cup, chopped or diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5041,2,1,'unit (yield from 1 lb ready-to-cook chicken)',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5041,3,0.5,'chicken, bone and skin removed',107,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5042,1,1,'cup, chopped or diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5042,2,1,'unit (yield from 1 lb ready-to-cook chicken)',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5042,3,0.5,'chicken, bone and skin removed',119,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5043,1,1,'unit (yield from 1 lb ready-to-cook chicken)',109,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5043,2,0.5,'chicken, bone and skin removed',182,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5044,1,1,'cup',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5044,2,1,'unit (yield from 1 lb ready-to-cook chicken)',91,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5045,1,1,'cup, chopped or diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5045,2,1,'unit (yield from 1 lb ready-to-cook chicken)',81,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5045,3,0.5,'chicken, bone and skin removed',136,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5046,1,1,'cup, chopped or diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5046,2,1,'unit (yield from 1 lb ready-to-cook chicken)',86,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5046,3,0.5,'chicken, bone and skin removed',143,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5047,1,1,'tbsp',12.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5047,2,1,'unit (yield from 1 lb ready-to-cook chicken)',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5047,3,0.5,'chicken, separable fat',52,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5048,1,1,'unit (yield from 1 lb ready-to-cook chicken)',59,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5048,2,0.5,'back, bone removed',99,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5049,1,1,'unit (yield from 1 lb ready-to-cook chicken)',72,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5049,2,0.5,'back, bone removed',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5050,1,1,'unit (yield from 1 lb ready-to-cook chicken)',44,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5050,2,0.5,'back, bone removed',72,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5051,1,1,'unit (yield from 1 lb ready-to-cook chicken)',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5051,2,0.5,'back, bone removed',53,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5052,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5052,2,1,'unit (yield from 1 lb ready-to-cook chicken)',36,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5052,3,1,'cup, chopped or diced',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5053,1,4,'oz',113,'g',1,'1998-01-15','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5053,2,0.5,'unit (yield from 1 lb ready-to-cook chicken)',31,'g',1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5053,3,0,'back, bone and skin removed',51,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5054,1,1,'unit (yield from 1 lb ready-to-cook chicken)',35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5054,2,0.5,'back, bone and skin removed',58,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5055,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5055,2,0.5,'unit (yield from 1 lb ready-to-cook chicken)',24,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5055,3,0,'back, bone and skin removed',40,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5056,1,1,'unit (yield from 1 lb ready-to-cook chicken)',26,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5056,2,0.5,'back, bone and skin removed',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5057,1,0.5,'breast, bone removed (yield from 1 lb ready-to-cook chicken)',87,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5057,2,0.5,'breast, bone removed',145,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5058,1,3,'oz',85,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5058,2,0.5,'unit (yield from 1 lb ready-to-cook chicken)',84,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5058,3,0,'breast, bone removed',140,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5059,1,1,'unit (yield from 1 lb ready-to-cook chicken)',59,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5059,2,0.5,'breast, bone removed',98,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5060,1,1,'cup, chopped or diced',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5060,2,1,'unit (yield from 1 lb ready-to-cook chicken)',58,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5060,3,0.5,'breast, bone removed',98,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5061,1,1,'cup, chopped or diced',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5061,2,1,'unit (yield from 1 lb ready-to-cook chicken)',66,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5061,3,0.5,'breast, bone removed',110,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5062,1,4,'oz',113,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5062,2,1,'piece',272,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5062,3,1,'package',926,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5063,1,1,'unit (yield from 1 lb ready-to-cook chicken)',52,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5063,2,0.5,'breast, bone and skin removed',86,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5064,1,1,'cup, chopped or diced',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5064,2,1,'unit (yield from 1 lb ready-to-cook chicken)',52,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5064,3,0.5,'breast, bone and skin removed',86,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5065,1,1,'cup, chopped or diced',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5065,2,1,'unit (yield from 1 lb ready-to-cook chicken)',57,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5065,3,0.5,'breast, bone and skin removed',95,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5066,1,4,'oz',113,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5066,2,1,'drumstick with skin',133,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5066,3,1,'drumstick',130,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5067,1,1,'unit (yield from 1 lb ready-to-cook chicken)',43,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5067,2,1,'drumstick, bone removed',72,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5068,1,1,'unit (yield from 1 lb ready-to-cook chicken)',29,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5068,2,1,'drumstick, bone removed',49,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5069,1,3,'oz',85,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5069,2,1,'drumstick with skin (yield from 1 lb ready-to-cook chicken)',105,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5069,3,1,'drumstick without skin',96,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5070,1,1,'cup, chopped or diced',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5070,2,1,'unit (yield from 1 lb ready-to-cook chicken)',34,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5070,3,1,'drumstick, bone removed',57,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5071,1,4,'oz',113,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5071,2,1,'drumstick  with skin',130,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5071,3,1,'drumstick without skin',122,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5072,1,1,'unit (yield from 1 lb ready-to-cook chicken)',25,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5072,2,1,'drumstick, bone and skin removed',42,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5073,1,3,'oz',85,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5073,2,1,'drumstick without skin',96,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5073,3,1,'drumstick with skin',105,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5074,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5074,2,1,'drumstick, bone and skin removed',46,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5074,3,1,'cup, chopped or diced',160,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5074,4,1,'unit (yield from 1 lb ready-to-cook chicken)',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5075,1,4,'oz',113,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5075,2,1,'leg, with skin (Sum of drumstick+thigh+back)',344,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5075,3,1,'drumstick with skin',111,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5075,4,1,'thigh with skin',185,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5075,5,1,'back with skin',49,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5076,1,1,'unit (yield from 1 lb ready-to-cook chicken)',95,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5076,2,1,'leg, bone removed',158,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5077,1,1,'unit (yield from 1 lb ready-to-cook chicken)',67,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5077,2,1,'leg, bone removed',112,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5078,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5078,2,1,'leg, with skin (Sum of drumstick+thigh+back)',258,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5078,3,1,'thigh with skin',133,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5078,4,1,'drumstick with skin',91,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5078,5,1,'back with skin',35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5079,1,1,'cup, chopped or diced',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5079,2,1,'unit (yield from 1 lb ready-to-cook chicken)',75,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5079,3,1,'leg, bone removed',125,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5080,1,4,'oz',113,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5080,2,1,'leg, bone and skin removed (Sum of drumstick+thigh+back meat only)',265,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5080,3,1,'thigh bone and skin removed',147,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5080,4,1,'drumstick bone and skin removed',88,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5080,5,1,'back bone and skin removed',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5081,1,1,'unit (yield from 1 lb ready-to-cook chicken)',56,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5081,2,1,'leg, bone and skin removed',94,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5082,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5082,2,1,'leg (Sum of drumstick+thigh+back meat only)',199,'g',1,'1997-08-29','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5082,3,1,'drumstick bone and skin',105,'g',1,'2002-09-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5082,4,1,'thigh bone and skin',72,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5082,5,1,'back bone and skin',22,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5083,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5083,2,1,'cup, chopped or diced',160,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5083,3,1,'unit (yield from 1 lb ready-to-cook chicken)',60,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5083,4,1,'leg, bone and skin removed',101,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5084,1,1,'unit (yield from 1 lb ready-to-cook chicken)',15,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5084,2,1,'neck, bone removed',50,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5085,1,1,'unit (yield from 1 lb ready-to-cook chicken)',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5085,2,1,'neck, bone removed',52,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5086,1,1,'unit (yield from 1 lb ready-to-cook chicken)',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5086,2,1,'neck, bone removed',36,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5087,1,1,'unit (yield from 1 lb ready-to-cook chicken)',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5087,2,1,'neck, bone removed',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5088,1,1,'unit (yield from 1 lb ready-to-cook chicken)',6,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5088,2,1,'neck, bone and skin removed',20,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5089,1,1,'unit (yield from 1 lb ready-to-cook chicken)',7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5089,2,1,'neck, bone and skin removed',22,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5090,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5090,2,1,'unit (yield from 1 lb ready-to-cook chicken)',5,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5090,3,1,'neck, bone and skin removed',18,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5091,1,4,'oz',113,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5091,2,1,'thigh with skin',193,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5092,1,1,'unit (yield from 1 lb ready-to-cook chicken)',52,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5092,2,1,'thigh, bone removed',86,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5093,1,1,'unit (yield from 1 lb ready-to-cook chicken)',38,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5093,2,1,'thigh, bone removed',62,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5094,1,3,'oz',85,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5094,2,1,'thigh with skin',137,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5094,3,1,'thigh without skin',116,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5095,1,1,'unit (yield from 1 lb ready-to-cook chicken)',41,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5095,2,1,'thigh, bone removed',68,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5096,1,4,'oz',113,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5096,2,1,'thigh without skin',149,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5097,1,3,'oz',85,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5097,2,1,'unit (yield from 1 lb ready-to-cook chicken)',31,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5097,3,1,'thigh, bone and skin removed',52,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5098,1,3,'oz',85,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5098,2,1,'thigh without skin',116,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5098,3,1,'thigh with skin',137,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5099,1,1,'cup, chopped or diced',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5099,2,1,'unit (yield from 1 lb ready-to-cook chicken)',33,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5099,3,1,'thigh, bone and skin removed',55,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5100,1,4,'oz',113,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5100,2,1,'piece',107,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5100,3,1,'package',1150,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5101,1,1,'unit (yield from 1 lb ready-to-cook chicken)',29,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5101,2,1,'wing, bone removed',49,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5102,1,1,'unit (yield from 1 lb ready-to-cook chicken)',19,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5102,2,1,'wing, bone removed',32,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5103,1,3,'oz',85,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5103,2,1,'piece',85,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5104,1,1,'cup, chopped or diced',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5104,2,1,'unit (yield from 1 lb ready-to-cook chicken)',24,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5104,3,1,'wing, bone removed',40,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5105,1,1,'wing, bone and skin removed (yield from 1 lb ready-to-cook chicken)',17,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5105,2,1,'wing, bone and skin removed',29,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5106,1,3,'oz',85,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5106,2,1,'unit (yield from 1 lb ready-to-cook chicken)',12,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5106,3,1,'wing, bone and skin removed',20,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5107,1,1,'unit (yield from 1 lb ready-to-cook chicken)',13,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5107,2,1,'wing, bone and skin removed',21,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5108,1,3,'oz',85,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5108,2,1,'cup, chopped or diced',140,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5108,3,1,'unit (yield from 1 lb ready-to-cook chicken)',14,'g',1,'2002-09-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5108,4,1,'wing, bone and skin removed',24,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5109,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5109,2,1,'chicken',1509,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5110,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5110,2,1,'unit (yield from 1 lb ready-to-cook chicken)',235,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5110,3,1,'chicken',1072,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5111,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5111,2,1,'breast',635,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5111,3,1,'bird',4405,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5112,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5112,2,1,'unit (yield from 1 lb ready-to-cook chicken)',210,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5112,3,0.5,'chicken, bone removed',480,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5113,1,3,'oz',85,'g',1,'2001-07-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5113,2,1,'unit (yield from 1 lb ready-to-cook chicken)',209,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5113,3,0.5,'chicken, bone and skin removed',477,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5114,1,1,'cup, chopped or diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5114,2,1,'unit (yield from 1 lb ready-to-cook chicken)',171,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5115,1,1,'unit (yield from 1 lb ready-to-cook chicken)',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5115,2,1,'giblets',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5116,1,1,'cup, chopped or diced',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5116,2,1,'unit (yield from 1 lb ready-to-cook chicken)',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5117,1,1,'unit (yield from 1 lb ready-to-cook chicken)',99,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5117,2,0.5,'chicken, bone and skin removed',220,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5118,1,1,'cup, chopped or diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5118,2,1,'unit (yield from 1 lb ready-to-cook chicken)',78,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5119,1,1,'unit (yield from 1 lb ready-to-cook chicken)',113,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5119,2,0.5,'chicken, bone and skin removed',258,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5120,1,1,'cup, chopped or diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5120,2,1,'unit (yield from 1 lb ready-to-cook chicken)',94,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5121,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5121,2,1,'chicken',905,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5122,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5122,2,1,'cup, chopped or diced',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5122,3,1,'unit (yield from 1 lb ready-to-cook chicken)',202,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5122,4,1,'chicken, bone removed',593,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5123,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5123,2,1,'unit (yield from 1 lb ready-to-cook chicken)',271,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5123,3,0.5,'chicken, bone removed',398,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5124,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5124,2,1,'unit (yield from 1 lb ready-to-cook chicken)',178,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5124,3,0.5,'chicken, bone removed',261,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5125,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5125,2,1,'unit (yield from 1 lb ready-to-cook chicken)',194,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5125,3,0.5,'chicken, bone and skin removed',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5126,1,3,'oz',85,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5126,2,1,'cup, chopped or diced',140,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5126,3,1,'unit (yield from 1 lb ready-to-cook chicken)',137,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5127,1,1,'unit (yield from 1 lb ready-to-cook chicken)',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5127,2,1,'giblets',81,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5128,1,1,'cup, chopped or diced',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5128,2,1,'unit (yield from 1 lb ready-to-cook chicken)',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5129,1,1,'unit (yield from 1 lb ready-to-cook chicken)',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5129,2,0.5,'chicken, bone and skin removed',130,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5130,1,1,'cup, chopped or diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5130,2,1,'unit (yield from 1 lb ready-to-cook chicken)',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5131,1,1,'unit (yield from 1 lb ready-to-cook chicken)',105,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5131,2,0.5,'chicken, bone and skin removed',154,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5132,1,1,'cup, chopped or diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5132,2,1,'unit (yield from 1 lb ready-to-cook chicken)',73,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5133,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5133,2,1,'capon',2152,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5134,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5134,2,1,'capon',1418,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5134,3,1,'unit (yield from 1 lb ready-to cook capon)',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5135,1,3,'oz',85,'g',1,'2001-07-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5135,2,1,'unit (yield from 1 lb ready-to cook capon)',297,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5135,3,0.5,'capon, bone removed',964,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5136,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5136,2,1,'unit (yield from 1 lb ready-to cook capon)',196,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5136,3,0.5,'capon, bone removed',637,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5137,1,1,'giblets',115,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5137,2,1,'unit (yield from 1 lb ready-to cook capon)',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5138,1,1,'cup, chopped or diced',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5138,2,1,'unit (yield from 1 lb ready-to cook capon)',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5139,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5139,2,1,'unit (yield from 1 lb ready-to-cook duck)',287,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5139,3,0.5,'duck',634,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5140,1,1,'cup, chopped or diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5140,2,1,'unit (yield from 1 lb ready-to-cook duck)',173,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5140,3,0.5,'duck',382,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5141,1,1,'unit (yield from 1 lb ready-to-cook duck)',137,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5141,2,0.5,'duck',303,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5142,1,1,'cup, chopped or diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5142,2,1,'unit (yield from 1 lb ready-to-cook duck)',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (5142,3,0.5,'duck',221,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5143,1,1,'liver',44,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5143,2,1,'unit (yield from 1 lb ready-to-cook duck)',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5144,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5144,2,1,'unit (yield from 1 lb ready-to-cook duck)',239,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5144,3,0.5,'duck',270,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5145,1,1,'unit (yield from 1 lb ready-to-cook duck)',73,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5145,2,0.5,'breast, bone and skin removed',83,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5146,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5146,2,1,'unit (yield from 1 lb ready-to-cook goose)',320,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5146,3,0.5,'goose',1319,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5147,1,1,'cup, chopped or diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5147,2,1,'unit (yield from 1 lb ready-to-cook goose)',188,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5147,3,0.5,'goose',774,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5148,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5148,2,1,'unit (yield from 1 lb ready-to-cook goose)',185,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5148,3,0.5,'goose',766,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5149,1,1,'unit (yield from 1 lb ready-to-cook goose)',143,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5149,2,0.5,'goose',591,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5150,1,1,'liver',94,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5150,2,1,'unit (yield from 1 lb ready-to-cook goose)',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5151,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5151,2,1,'unit (yield from 1 lb ready-to-cook guinea)',359,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5151,3,0.5,'guinea',345,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5152,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5152,2,1,'unit (yield from 1 lb ready-to-cook guinea)',275,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5152,3,0.5,'guinea',264,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5153,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5153,2,1,'unit (yield from 1 lb ready-to-eat pheasant)',371,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5153,3,0.5,'pheasant',400,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5154,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5154,2,1,'unit (yield from 1 lb ready-to-eat pheasant)',326,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5154,3,0.5,'pheasant',352,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5155,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5155,2,1,'unit (yield from 1 lb ready-to-eat pheasant)',169,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5155,3,0.5,'breast, bone and skin removed',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5156,1,1,'unit (yield from 1 lb ready-to-eat pheasant)',99,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5156,2,1,'leg, bone and skin removed',107,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5157,1,1,'quail',109,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5157,2,1,'unit (yield from 1 lb ready-to cook quail)',405,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5158,1,1,'quail',92,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5158,2,1,'unit (yield from 1 lb ready-to cook quail)',342,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5159,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5159,2,1,'unit (yield from 1 lb ready-to cook quail)',208,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5159,3,1,'breast',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5160,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5160,2,1,'unit (yield from 1 lb ready-to-cook squab)',297,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5160,3,1,'squab',199,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5161,1,1,'unit (yield from 1 lb ready-to-cook squab)',251,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5161,2,1,'squab',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5162,1,1,'breast, bone removed',101,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5162,2,1,'unit (yield from 1 lb ready-to-cook squab)',151,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5165,1,4,'oz',113,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5165,2,1,'bird',5002,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5166,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5166,2,1,'bird',3812,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5167,1,4,'oz',113,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5167,2,1,'bird',5002,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5168,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5168,2,1,'bird',3812,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5169,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5169,2,1,'lb',453,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5170,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5171,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5171,2,1,'giblets',157,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5172,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5172,2,1,'giblets',95,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5173,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5173,2,1,'raw gizzard',63,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5174,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5174,2,1,'gizzard cooked',45,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5175,1,4,'oz',113,'g',1,'2011-01-18','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5175,2,1,'piece',24,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5176,1,3,'oz',85,'g',1,'2011-01-18','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5176,2,1,'heart',20,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5177,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5177,2,1,'raw liver',78,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5178,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5178,2,1,'liver cooked',53,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5179,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5179,2,1,'lb',453,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5180,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5181,1,4,'oz',113,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5181,2,1,'lb',453,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5182,1,3,'oz',85,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5183,1,4,'oz',113,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5183,2,1,'lb',453,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (5184,1,3,'oz',85,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5185,1,1,'serving',85,'g',1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (5186,1,3,'oz',85,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5187,1,4,'oz',113,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5187,2,1,'serving',85,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5188,1,3,'oz',85,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5190,1,1,'cup, chopped or diced',140,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5190,2,0.5,'back, bone removed',262,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5190,3,1,'unit (yield from 1 lb ready-to-cook turkey)',34,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5191,1,1,'unit (yield from 1 lb ready-to-cook turkey)',146,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5191,2,0.5,'breast, bone removed',1132,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5192,1,3,'oz',85,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5192,2,0.5,'unit (yield from 1 lb ready-to-cook turkey)',112,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5192,3,0,'breast, bone removed',864,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5193,1,1,'unit (yield from 1 lb ready-to-cook turkey)',105,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5193,2,1,'leg, bone removed',816,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5194,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5194,2,1,'unit (yield from 1 lb ready-to-cook turkey)',71,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5194,3,1,'leg, bone removed',546,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5195,1,1,'unit (yield from 1 lb ready-to-cook turkey)',33,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5195,2,1,'wing, bone removed',256,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5196,1,3,'oz',85,'g',1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5196,2,1,'unit (yield from 1 lb ready-to-cook turkey)',24,'g',1,'1998-01-15','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5196,3,1,'wing, bone removed',186,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5200,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5200,2,0.5,'turkey, bone removed',808,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5200,3,1,'unit (yield from 1 lb ready-to-cook turkey)',229,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5216,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5216,2,1,'back',911,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5219,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5219,2,1,'breast',1769,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5220,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5220,2,1,'breast',1413,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5227,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5227,2,1,'wing',346,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5228,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5228,2,1,'wing',213,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5236,1,1,'unit (yield from 1 lb ready-to-cook turkey)',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5236,2,0.5,'turkey, skin only',196,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5277,1,3,'oz',85,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5277,2,1,'can (5 oz)',142,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5282,1,1,'tbsp',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5282,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5284,1,3,'oz',85,'g',1,'1994-09-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5284,2,1,'cup, drained',135,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5284,3,1,'can (5 oz)',142,'g',1,'2002-09-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5284,4,1,'can (5 oz) yields',125,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5285,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5285,2,0.5,'lb',227,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5286,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5286,2,1,'package (net weight, 5 oz)',142,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5293,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5293,2,0.5,'breast, bone removed',864,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5294,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5294,2,1,'thigh, bone removed',314,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5295,1,3,'oz',85,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5295,2,1,'box (net weight, 2.5 lb)',1134,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5300,1,1,'stick (2.25 oz)',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5301,1,0.5,'lb',227,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5302,1,0.5,'lb',227,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (5303,1,0.5,'lb',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5304,1,0.5,'lb',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5305,1,4,'oz',113,'g',1,'1999-03-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5305,2,1,'lb',453.6,'g',1,'2002-09-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5305,3,1,'patty, 4 oz',114,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5306,1,3,'oz',85,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5306,2,1,'patty (4 oz, raw) (yield after cooking)',82,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5306,3,1,'unit, yield from 1 lb raw',330,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5307,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5307,2,0.5,'bird',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5308,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5308,2,0.5,'bird',129,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5308,3,1,'bird whole',257,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5309,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5309,2,0.5,'bird',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5309,3,1,'bird whole',239,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5310,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5310,2,0.5,'bird',110,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5310,3,1,'bird whole',220,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5311,1,3,'oz',85,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5311,2,1,'cup',205,'g',1,'2004-07-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5311,3,1,'can (5 oz) yields',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5312,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5312,2,1,'piece',29,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5312,3,1,'serving',86,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5313,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5313,2,1,'serving',74,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5314,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5314,2,1,'piece',263,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5314,3,0.5,'breast',118,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5315,1,1,'unit (yield from 1 lb ready-to-cook duck)',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5315,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5315,3,0.5,'breast, bone removed',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5316,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5316,2,0.5,'breast, bone and skin removed',95,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5316,3,1,'cup, chopped or diced',174,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5316,4,1,'unit (yield from 1 lb ready-to-cook duck)',44,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5317,1,1,'leg, bone removed (yield after cooking)',92,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5317,2,1,'unit (yield from 1 lb ready-to-cook duck)',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5317,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5318,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5318,2,1,'cup chopped or diced, cooked',174,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5318,3,1,'unit (yield from 1 lb ready-to-cook duck)',35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5318,4,1,'leg, bone and skin removed',75,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5319,1,3,'oz',85,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5319,2,1,'drumstick',71,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5320,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5320,2,1,'serving',96,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5323,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5323,2,1,'patty',60,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5324,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5324,2,1,'patty',60,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5326,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5326,2,1,'piece',15,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5326,3,4,'pieces',62,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5327,1,3,'oz',85,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5327,2,1,'piece',15,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5327,3,4,'pieces',62,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5332,1,4,'oz crumbled',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5333,1,3,'oz crumbled',85,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (5334,1,3,'oz',85,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5334,2,1,'thigh',95,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5335,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5335,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5339,1,3,'oz',85,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5339,2,1,'wing',51,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5341,1,1,'serving (3 oz)',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5341,2,1,'back',102,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5341,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5342,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5342,2,1,'breast breast with skin and bone',483,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5342,3,1,'oz',28.35,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (5343,1,1,'drumstick',53,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5343,2,1,'serving (3oz)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5343,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5344,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5345,1,1,'thigh',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5345,2,1,'serving (3 oz)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5345,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5346,1,1,'wing',53,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5346,2,1,'serving (3 oz)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5346,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5347,1,1,'back',102,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5347,2,1,'serving (3 oz)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5347,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5348,1,1,'serving (3 oz)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5348,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5348,3,1,'breast',343,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5349,1,1,'drumstick',53,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5349,2,1,'serving (3 oz)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5349,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5351,1,1,'thigh',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5351,2,1,'serving',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5352,1,1,'wing',53,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5352,2,1,'serving (3 oz)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5352,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5356,1,1,'serving',85,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (5357,1,3,'oz',85,'g',1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5357,2,1,'back',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5358,1,3,'oz',85,'g',1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5358,2,1,'breast',384,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5359,1,3,'oz',85,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5359,2,1,'drumstick',71,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5361,1,3,'oz',85,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5361,2,1,'thigh',95,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5362,1,3,'oz',85,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5362,2,1,'wing',51,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5363,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (5363,2,1,'breast',219,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (5363,3,1,'bird',627,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (5621,1,1,'patty',117,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5622,1,1,'patty (yield from 135.8 g raw meat)',109,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5622,2,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5623,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5623,2,1,'fan fillet',513,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5624,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5624,2,1,'steak',394,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5625,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5625,2,1,'flat fillet',354,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5626,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5626,2,1,'full rump',695,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5627,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5627,2,1,'full rump cooked ( yield from 695 g raw meat )',496,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5628,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5628,2,1,'inside drum',572,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5629,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5629,2,1,'inside drum cooked ( yield from 572 g raw meat )',416,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5630,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5630,2,1,'outside drum',422,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5631,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5631,2,1,'steak',300,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5632,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5632,2,1,'steak',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5641,1,1,'patty',109,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5641,2,4,'patty',435,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5642,1,1,'patty',93,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5642,2,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5643,1,1,'serving ( cooked from 4oz raw)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5643,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5644,1,1,'serving ( cooked from 4 oz raw )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5644,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5645,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5646,1,1,'serving (cooked from 4 oz raw)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5646,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5647,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5648,1,1,'serving (cooked from 4 oz raw)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5648,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5649,1,1,'serving (cooked from 4 oz raw)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5649,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5650,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5651,1,1,'serving ( cooked from 4 oz raw)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5651,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5652,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5653,1,1,'serving (cooked from 4 oz raw)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5653,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5653,3,1,'lb',453,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5654,1,1,'serving (cooked from 4 oz raw)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5654,2,1,'lb',456,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5654,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5655,1,1,'serving ( cooked from 4 oz raw)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5655,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5655,3,1,'lb',453,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5656,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5657,1,1,'serving (cooked from 4 oz raw)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5657,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5657,3,1,'lb',453,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5658,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5661,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5661,2,1,'liver',44,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5662,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5662,2,1,'patty (cooked from 4 oz raw)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5662,3,1,'lb',453,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5663,1,3,'oz',85,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (5664,1,3,'oz',85,'g',1,'2011-01-18','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5664,2,1,'patty',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5665,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5665,2,1,'lb',453,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5665,3,1,'serving (cooked from 4 oz)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5666,1,3,'oz',85,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (5667,1,3,'oz',85,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (5668,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5668,2,1,'patty (cooked from 4 oz raw)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5668,3,1,'lb',453,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5669,1,3,'oz',85,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (5670,1,3,'oz',85,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (5671,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5671,2,1,'drumstick without skin',95,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5671,3,1,'drumstick with skin',105,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5672,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5672,2,1,'thigh without skin',111,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5672,3,1,'thigh with skin',129,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5673,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5673,2,1,'lb',453,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (5674,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5674,2,1,'lb',453,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (5675,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5675,2,1,'lb',453,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (5676,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5676,2,1,'drumstick without skin',95,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5676,3,1,'drumstick with skin',105,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5677,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5677,2,1,'thigh without skin',111,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5677,3,1,'thigh with skin',129,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5678,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5678,2,1,'drumstick with skin',143,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5678,3,1,'drumstick without skin',136,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5679,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5679,2,1,'drumstick without skin',91,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5679,3,1,'drumstick with skin',129,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5680,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5680,2,1,'drumstick without skin',95,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5680,3,1,'drumstick with skin',106,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5681,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5681,2,1,'thigh without skin',132,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5681,3,1,'thigh with skin',158,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5682,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5682,2,1,'thigh without skin',148,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5682,3,1,'thigh with skin',191,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5683,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5683,2,1,'thigh with skin',130,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5683,3,1,'thigh without skin',112,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5684,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5685,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5686,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5687,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5687,2,1,'drumstick with skin',106,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5687,3,1,'drumstick without skin',95,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5688,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5688,2,1,'drumstick with skin',143,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5688,3,1,'drumstick without skin',130,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5689,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5689,2,1,'drumstick with skin',129,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5689,3,1,'drumstick without skin',91,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5690,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5690,2,1,'thigh without skin',132,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5690,3,1,'thigh with skin',158,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5691,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5691,2,1,'thigh without skin',148,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5691,3,1,'thigh',181,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5692,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5692,2,1,'thigh with skin',130,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5692,3,1,'thigh without skin',112,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5693,1,3,'oz',85,'g',1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5693,2,1,'back',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5694,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5695,1,3,'oz',85,'g',1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5696,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5697,1,3,'oz',85,'g',1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5698,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5699,1,1,'oz',28.35,'g',1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5700,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5700,2,1,'lb',453,'g',1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5701,1,3,'oz',85,'g',1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5702,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5702,2,1,'lb',453,'g',1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5703,1,3,'oz',85,'g',1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_wght` VALUES (5703,2,1,'lb',453,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (5704,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5704,2,1,'bird',5717,'g',1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5705,1,3,'oz',85,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5705,2,1,'bird',4147,'g',1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5706,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5706,2,1,'bird',5717,'g',1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5707,1,3,'oz',85,'g',1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5707,2,1,'bird',4147,'g',1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5707,3,1,'lb',453,'g',1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (5708,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5708,2,1,'breast',1171,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5709,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5709,2,1,'breast',852,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5710,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5710,2,1,'breast',1150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5711,1,1,'breast',863,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5711,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5712,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5712,2,1,'wing',518,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5713,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5713,2,1,'wing',375,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5714,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5715,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5716,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5716,2,1,'drumstick',356,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5717,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5717,2,1,'thigh',454,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5718,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5718,2,1,'breast',1654,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5719,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5719,2,1,'back',1245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5720,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5720,2,1,'back',949,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5721,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5721,2,1,'breast',2110,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5721,3,1,'lb',453,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5722,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5722,2,1,'thigh',348,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5723,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5723,2,1,'drumstick',275,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5724,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5724,2,1,'drumstick',359,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5725,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5725,2,1,'drumstick',217,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5726,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5726,2,1,'thigh',424,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5727,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5727,2,1,'breast',1171,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5728,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5728,2,1,'thigh',327,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5729,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5729,2,1,'wing',358,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5730,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5730,2,1,'wing',219,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5732,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5732,2,1,'breast',1150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5733,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5733,2,1,'breast',863,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5734,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5734,2,1,'wing',518,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5735,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5735,2,1,'wing',375,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5736,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5736,2,1,'drumstick',356,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5737,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5737,2,1,'drumstick',275,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5738,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5738,2,1,'drumstick',337,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5739,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5739,2,1,'drumstick',206,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5740,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5740,2,1,'thigh',367,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5741,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5741,2,1,'thigh',319,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5742,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5742,2,1,'thigh',454,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5743,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5743,2,1,'thigh',348,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5744,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (5744,2,1,'back',1245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5745,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5745,2,1,'back',949,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5746,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5746,2,1,'piece',181,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5747,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5747,2,1,'piece',196,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5748,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5748,2,1,'piece',195,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5749,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (5749,2,1,'piece',192,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6001,1,0.5,'cup (4 fl oz)',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6001,2,1,'can (10.75 oz)',305,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6002,1,1,'cup (8 fl oz)',257,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6002,2,1,'can (11 oz), undiluted',312,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6004,1,0.5,'cup',130,'g',1,'1996-09-30','2013-12-26');
INSERT INTO `cndb_wght` VALUES (6004,2,1,'can 11.5 oz',326,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (6006,1,1,'cup (8 fl oz)',263,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6006,2,1,'can (11.25 oz)',319,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6007,1,1,'cup (8 fl oz)',243,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6007,2,1,'can (19.25 oz)',546,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6008,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6008,2,1,'can 14.5 oz',435,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6008,3,1,'container 32 oz',960,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6009,1,0.5,'CUP',125,'g',1,'1996-09-30','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6009,2,1,'can (10.75 oz)',305,'g',1,'1998-01-15','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6010,1,0.5,'cup',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6010,2,1,'can (10.75 oz)',305,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6011,1,0.5,'cup',124,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6013,1,0.5,'cup (4 fl oz)',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6013,2,1,'can (10.75 oz)',305,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6015,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6016,1,0.5,'cup (4 fl oz)',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6016,2,1,'can (10.75 oz)',305,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6017,1,0.5,'cup (4 fl oz)',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6017,2,1,'can (10.75 oz)',305,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6018,1,1,'can',530,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6018,2,1,'cup',243,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6019,1,0.5,'cup',124,'g',1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_wght` VALUES (6022,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6022,2,1,'can 19 oz',539,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6023,1,0.5,'cup',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6024,1,1,'cup',255,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6025,1,0.5,'cup',121,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6025,2,1,'can (10.7 oz)',303,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6026,1,1,'cup (8 fl oz)',263,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6026,2,1,'can (11.25 oz)',319,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6027,1,1,'cup (8 fl oz)',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6027,2,1,'can (19 oz)',539,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6028,1,0.5,'cup (4 fl oz)',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6028,2,1,'can (10.75 oz)',305,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6030,1,0.5,'cup',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6030,2,1,'can (10.7 oz)',303,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6032,1,0.5,'CUP',124,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6032,2,1,'can (10.5 oz)',310,'g',1,'1997-08-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6037,1,1,'cup (8 fl oz)',248,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6037,2,1,'can (20 oz)',567,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6039,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6039,2,1,'can (19 oz)',539,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6040,1,0.5,'cup (4 fl oz)',123,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6040,2,1,'can (10.5 oz)',298,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6042,1,0.5,'cup (4 fl oz)',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6042,2,1,'can (10.75 oz)',305,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6043,1,0.5,'CUP',126,'g',1,'1994-09-29','2015-06-19');
INSERT INTO `cndb_wght` VALUES (6044,1,0.5,'cup (4 fl oz)',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6044,2,1,'can (10.75 oz)',305,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6045,1,0.5,'cup (4 fl oz)',123,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6045,2,1,'can (10.5 oz)',298,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6046,1,0.5,'cup',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6046,2,1,'can (10.75 oz)',305,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6048,1,0.5,'cup (4 fl oz)',123,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6048,2,1,'can (10.5 oz)',298,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6049,1,0.5,'cup',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6049,2,1,'can (11.2 oz)',319,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6050,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6050,2,1,'can (19 oz)',539,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6051,1,0.5,'cup (4 fl oz)',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6051,2,1,'can (11.5 oz)',326,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6053,1,0.5,'cup',124,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6056,1,0.5,'cup',126,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6056,2,1,'can',305,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6061,1,1,'cup (8 fl oz)',251,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6061,2,1,'can (10.75 oz)',305,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6063,1,0.5,'cup (4 fl oz)',129,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6063,2,1,'can (11 oz), undiluted',312,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6064,1,1,'cup (8 fl oz)',236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6064,2,1,'can (18.75 oz)',532,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6067,1,1,'cup',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6068,1,0.5,'cup',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6068,2,1,'can (10.5 oz)',298,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6070,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6070,2,1,'can (19 oz)',539,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6071,1,0.5,'cup',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6071,2,1,'can (10.75 oz)',305,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6072,1,0.5,'cup',123,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6072,2,1,'can (10.5 oz)',298,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6075,1,1,'cube',3.6,'g',1,'1997-08-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6075,2,1,'packet',6,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6076,1,1,'cube',3.6,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6080,1,1,'cube',4,'g',1,'1997-08-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6080,2,1,'teaspoon',2,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6081,1,1,'cube',4.8,'g',1,'1997-08-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6094,1,1,'serving 1 tbsp',7.5,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6094,2,1,'packet',39,'g',1,'1997-08-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6101,1,1,'packet',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6112,1,1,'tbsp',18,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (6112,2,1,'fl oz',36,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (6112,3,1,'cup',288,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (6114,1,0.25,'CUP',59,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (6114,2,1,'can',298,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6115,1,1,'tsp',3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6116,1,1,'CUP',233,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6116,2,1,'can',291,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6118,1,1,'tbsp',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6119,1,0.25,'CUP',57,'g',1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6119,2,1,'cup',228,'g',1,'2002-09-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6119,3,1,'jar 10.5 oz',273,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6119,4,1,'jar 12 oz',324,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6120,1,1,'tbsp',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6120,2,1,'serving',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6121,1,1,'cup',238,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6121,2,1,'can',298,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6122,1,1,'cup (8 fl oz)',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6123,1,1,'cup (8 fl oz)',24,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6124,1,1,'serving',6.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6125,1,1,'CUP',238,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6125,2,1,'TBSP',14.9,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6125,3,1,'tsp',5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6125,4,1,'can',298,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6126,1,1,'serving',7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6127,1,1,'cup (8 fl oz)',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6128,1,1,'packet',74,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6128,2,1,'packet (6 fl oz)',11.1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6147,1,0.5,'cup (4 fl oz)',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6147,2,1,'can (10.75 oz)',305,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6149,1,0.5,'cup',124,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6150,1,1,'tbsp',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6150,2,0.5,'cup',143,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6150,3,1,'cup',279,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6151,1,1,'tbsp',19,'g',1,'1996-09-30','2013-12-26');
INSERT INTO `cndb_wght` VALUES (6151,2,1,'cup',305,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (6152,1,0.25,'cup',63,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6158,1,0.5,'cup (4 fl oz)',129,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6158,2,1,'can (11 oz), undiluted',312,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6159,1,1,'cup',148,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6159,2,1,'can',294,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6164,1,2,'tbsp',36,'g',1,'1994-11-02','2015-01-07');
INSERT INTO `cndb_wght` VALUES (6164,2,0.5,'cup',130,'g',1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (6164,3,1,'cup',259,'g',1,'2007-11-28','2015-01-07');
INSERT INTO `cndb_wght` VALUES (6166,1,1,'cup',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6166,2,0.5,'cup',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6167,1,1,'cup',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6167,2,0.5,'cup',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6168,1,1,'tsp',4.7,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6168,2,0.25,'tsp',1.2,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (6170,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6172,1,1,'CUP',240,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6174,1,1,'cup',233,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6175,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6176,1,1,'tbsp',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6177,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6179,1,1,'tbsp',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6180,1,1,'cup',216,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6182,1,1,'cup',251,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6183,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6188,1,1,'cup',219,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6188,2,1,'can (14.5 oz)',407,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6188,3,1,'carton (32 oz)',923,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6189,1,2,'Tbsp',36,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6190,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6192,1,1,'CUP',253,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6193,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6194,1,1,'cup',249,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6201,1,1,'cup (8 fl oz)',248,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6201,2,1,'can (10.75 oz), prepared',602,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6208,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6210,1,1,'cup (8 fl oz)',248,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6210,2,1,'can (10.75 oz), prepared',602,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6211,1,1,'CUP',251,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6211,2,1,'can (11 oz), prepared',609,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6216,1,1,'cup (8 fl oz)',248,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6216,2,1,'FL OZ',31,'g',1,'1997-08-29','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6216,3,1,'can (10.75 oz), prepared',602,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6217,1,0.5,'cup',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6230,1,1,'serving 1 cup',252,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6230,2,1,'FL OZ',31.5,'g',1,'1999-03-22','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6243,1,1,'serving 1 cup',252,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6243,2,1,'FL OZ',31.5,'g',1,'1997-08-29','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6246,1,1,'cup (8 fl oz)',248,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6246,2,1,'can (10.75 oz), prepared',602,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6248,1,1,'cup (8 fl oz)',245,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6248,2,1,'can (10.5 oz), prepared',595,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6249,1,1,'cup (8 fl oz)',254,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6249,2,1,'can (11.25 oz), prepared',616,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6253,1,1,'cup (8 fl oz)',248,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6253,2,1,'can (10.75 oz), prepared',602,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6256,1,1,'cup (8 fl oz)',253,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6256,2,1,'fl oz',31.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6358,1,1,'cup (8 fl oz)',251,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6358,2,1,'can (11 oz), prepared',609,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6359,1,1,'serving 1 cup',252,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6359,2,1,'FL OZ',31.5,'g',1,'1997-08-29','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6401,1,1,'cup (8 fl oz)',244,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6401,2,1,'can (10.75 oz), prepared',593,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6402,1,1,'CUP',247,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6402,2,1,'can (11 oz), prepared',600,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6404,1,1,'serving 1 cup',266,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6404,2,1,'FL OZ',33.3,'g',1,'1997-08-29','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6406,1,1,'cup (8 fl oz)',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6406,2,1,'can (11.25 oz), prepared',607,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6409,1,1,'cup (8 fl oz)',244,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6409,2,1,'can (10.75 oz), prepared',593,'g',1,'1997-08-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6410,1,1,'cup',248,'g',1,'1994-09-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (6410,2,1,'can (10.75 oz), prepared',593,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6411,1,1,'cup (8 fl oz)',247,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6411,2,1,'can (11 oz), prepared',600,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6413,1,1,'cup (8 fl oz)',244,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6413,2,1,'can (10.75 oz), prepared',593,'g',1,'1999-03-22','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6416,1,1,'CUP',244,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6416,2,1,'FL OZ',30.5,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6416,3,1,'can (10.75 oz), prepared',593,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6417,1,1,'CUP',244,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6417,2,1,'can (10.75 oz), prepared',593,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6419,1,1,'serving 1 cup',248,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (6423,1,1,'serving 1 cup',243,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6426,1,1,'CUP',261,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6426,2,1,'FL OZ',32.6,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6428,1,1,'serving 1 cup',249,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6428,2,1,'FL OZ',31.1,'g',1,'1997-08-29','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6430,1,1,'serving 1 cup',248,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6430,2,1,'FL OZ',31,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6432,1,1,'cup (8 fl oz)',241,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6432,2,1,'can (10.5 oz), prepared',586,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6440,1,1,'cup (8 fl oz)',241,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6440,2,1,'can (10.5 oz), prepared',586,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6442,1,1,'cup (8 fl oz)',244,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6442,2,1,'can (10.75 oz), prepared',593,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6443,1,1,'serving 1 cup',248,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6443,2,1,'FL OZ',31,'g',1,'1997-08-29','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6444,1,1,'cup (8 fl oz)',244,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6444,2,1,'can (10.75 oz), prepared',593,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6446,1,1,'cup (8 fl oz)',244,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6446,2,1,'can (10.75 oz), prepared',593,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6448,1,1,'cup (8 fl oz)',241,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6448,2,1,'can (10.5 oz), prepared',586,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6449,1,1,'serving 1 cup',259,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6449,2,1,'FL OZ',32.4,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6451,1,1,'cup (8 fl oz)',253,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6451,2,1,'can (11.5 oz), prepared',614,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6453,1,1,'cup (8 fl oz)',244,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6453,2,1,'can (10.75 oz), prepared',593,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6456,1,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6456,2,1,'can (10.75 oz), prepared',593,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6461,1,1,'CUP',244,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6461,2,1,'can (10.75 oz), prepared',593,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6463,1,1,'CUP',247,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6463,2,1,'can (11 oz), prepared',600,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6465,1,1,'CUP',244,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6465,2,1,'FL OZ',30.5,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6465,3,1,'can (10.75 oz), prepared',593,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6466,1,1,'cup (8 fl oz)',241,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6466,2,1,'FL OZ',30.1,'g',1,'1997-08-29','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6466,3,1,'can (10.5 oz), prepared',586,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6468,1,1,'CUP',241,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6468,2,1,'can (10.5 oz), prepared',586,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6471,1,1,'cup (8 fl oz)',244,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6471,2,1,'can (10.75 oz), prepared',593,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6472,1,1,'cup (8 fl oz)',241,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6472,2,1,'can (10.5 oz), prepared',586,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6475,1,1,'serving 1 cup',240,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6475,2,1,'FL OZ',29.9,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6476,1,1,'serving 1 cup',240,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6476,2,1,'FL OZ',29.9,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6480,1,1,'cup 8 fl oz',241,'g',1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6480,2,1,'FL OZ',30.1,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6481,1,1,'cup (8 fl oz)',243,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6481,2,1,'cube (6 fl oz prepared)',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6483,1,1,'cup 8 fl oz',261,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6483,2,1,'fl oz',32.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6494,1,1,'serving 1 cup',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6494,2,1,'fl oz',28.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6498,1,1,'cup 8 fl oz',265,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6528,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6547,1,1,'cup (8 fl oz)',244,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6547,2,1,'can (10.75 oz), prepared',593,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6549,1,1,'cup (8 fl oz)',244,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6549,2,1,'can (10.75 oz), prepared',593,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6558,1,1,'cup (8 fl oz)',247,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6558,2,1,'can (11 oz), prepared',600,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6559,1,1,'serving 1 cup',248,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (6559,2,1,'FL OZ',31,'g',1,'1997-08-29','2010-01-05');
INSERT INTO `cndb_wght` VALUES (6583,1,1,'package without flavor packet',81,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6583,2,1,'packet',5.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6584,1,1,'serving 1/2 cup',121,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6584,2,1,'can 10.7 oz (10.75 oz)',303,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6618,1,1,'tbsp',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6626,1,0.25,'cup',63,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6627,1,0.25,'cup',61,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6700,1,1,'cup',221,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6700,2,1,'can',390,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6700,3,1,'carton (32 oz)',926,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (6725,1,1,'serving',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6725,2,1,'package yields',539,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6731,1,1,'serving 1/2 cup',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6742,1,1,'serving',292,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6742,2,1,'package yields',292,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6749,1,1,'cup',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6749,2,1,'can',528,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6930,1,0.25,'CUP',63,'g',1,'2002-06-08','2006-11-30');
INSERT INTO `cndb_wght` VALUES (6931,1,1,'serving 1/2 cup',132,'g',1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_wght` VALUES (6955,1,0.5,'cup',124,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6956,1,1,'serving 1/2 cup',121,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6956,2,1,'can 10.7 oz',303,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6957,1,1,'serving',6.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6957,2,1,'package',454,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6958,1,1,'serving',6.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6958,2,1,'package (16 oz)',454,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6959,1,1,'serving',6.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6959,2,1,'package (16 oz)',454,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6961,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6961,2,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6962,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6962,2,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6963,1,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6963,2,1,'fl oz',30.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6964,1,1,'serving 1 cup',248,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6964,2,1,'fl oz',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6965,1,1,'cup',259,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6965,2,1,'fl oz',32.4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6966,1,1,'serving 1 cup',248,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6966,2,1,'fl oz',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6967,1,1,'cup',253,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6968,1,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6968,2,1,'can (10.75 oz)',305,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6969,1,1,'serving 1/3 cup',39,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6970,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6971,1,1,'tbsp',17,'g',1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_wght` VALUES (6971,2,1,'cup',275,'g',1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_wght` VALUES (6972,1,1,'packet',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6972,2,1,'cup',273,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6974,1,1,'cup',241,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6976,1,1,'serving 1/2 cup',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6976,2,1,'cup',257,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6977,1,1,'cup',236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6978,1,1,'cup',251,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6980,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6981,1,1,'tsp',2.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6981,2,1,'cube',3.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6982,1,1,'package without flavor packet',82,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6982,2,1,'packet',5.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6983,1,1,'package without flavor packet',81,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (6983,2,1,'packet',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7001,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7001,2,1,'slice (5-7/8" x 3-1/2" x 1/16")',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7002,1,2,'oz',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7003,1,1,'slice (4" dia x 1/8" thick)',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7003,2,1,'slice (2-3/4" dia x 1/16")',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7004,1,1,'slice',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7004,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7005,1,4,'slices',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (7006,1,1,'sausage',91,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7007,1,1,'slice',30,'g',1,'1994-09-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (7007,2,1,'serving',28,'g',1,'2007-11-28','2015-01-07');
INSERT INTO `cndb_wght` VALUES (7008,1,3.527,'oz',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (7010,1,1,'slice, medium (4-1/2" dia x 1/8" thick) (1 oz)',28,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7010,2,1,'slice (4" dia x 1/8" thick)',23,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7011,1,0.99,'oz 1 serving',28,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7011,2,1,'serving',28,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7011,3,1,'package',454,'g',1,'2007-11-28','2009-02-11');
INSERT INTO `cndb_wght` VALUES (7013,1,1,'link cooked',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7014,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7014,2,1,'slice (2-1/2" dia x 1/4" thick)',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7015,1,1,'link',70,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7016,1,2.33,'links',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (7018,1,1,'serving (1 serving)',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7019,1,1,'oz',28.35,'g',1,'1996-09-30','2009-02-11');
INSERT INTO `cndb_wght` VALUES (7019,2,1,'link (4" long)',60,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (7020,1,1,'slice (1 oz) (4" x 4" x 3/32" thick)',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7020,2,2,'slices',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7021,1,1,'slice',38,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7022,1,1,'hot dog',49,'g',1,'1994-09-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (7022,2,1,'package',446,'g',1,'1997-08-29','2012-03-02');
INSERT INTO `cndb_wght` VALUES (7024,1,3,'oz',85,'g',1,'1997-08-29','2016-02-06');
INSERT INTO `cndb_wght` VALUES (7024,2,1,'link',45,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (7025,1,1,'oz',28.35,'g',1,'1997-08-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (7025,2,1,'frankfurter',45,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (7026,1,1,'oz',28.35,'g',1,'1996-09-30','2009-02-11');
INSERT INTO `cndb_wght` VALUES (7026,2,1,'slice (4-1/4" x 4-1/4" x 1/16")',21,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (7027,1,1,'slice (1 oz) (4" x 4" x 3/32" thick)',28,'g',1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (7027,2,1,'slice (4-1/4" x 4-1/4" x 1/16")',21,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (7028,1,1,'slice',13,'g',1,'1995-06-19','2019-02-13');
INSERT INTO `cndb_wght` VALUES (7029,1,56,'grams 1 serving',56,'g',1,'1995-06-19','2009-02-11');
INSERT INTO `cndb_wght` VALUES (7029,2,1,'slice',28,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7030,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7030,2,1,'slice (4-1/4" x 4-1/4" x 1/16")',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7031,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7031,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7032,1,1,'slice (1 oz) (4" x 4" x 3/32" thick)',28,'g',1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_wght` VALUES (7032,2,2,'slices',57,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (7033,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7033,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7034,1,1,'slice (1 oz) (4" x 4" x 3/32" thick)',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7034,2,45,'g',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7036,1,1,'link',101,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (7038,1,1,'link',72,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7038,2,1,'oz',28.35,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7039,1,1,'serving 2 slices',57,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7039,2,1,'oz',28.35,'g',1,'1998-01-15','2009-02-11');
INSERT INTO `cndb_wght` VALUES (7039,3,2,'oz',57,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (7040,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7040,2,1,'slice',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7041,1,1,'slice (2-1/2" dia x 1/4" thick)',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7041,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7043,1,1,'slice oval',9.3,'g',1,'1999-03-22','2009-02-11');
INSERT INTO `cndb_wght` VALUES (7043,2,1,'slice rectangle',13.8,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (7045,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7045,2,1,'slice (4-1/4" x 4-1/4" x 1/16")',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7046,1,1,'slice',28,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (7046,2,1,'slice NFS',28,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (7046,3,1,'cup wafer slices or shaved',81,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (7046,4,1,'cubic inch',14,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (7046,5,2,'oz',57,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (7050,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7050,2,1,'slice (15 per 8 oz package)',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7051,1,1,'slice (1 oz) (4" x 4" x 3/32" thick)',28,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7051,2,2,'slices',57,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7052,1,2,'slices',57,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (7052,2,1,'package (8 oz)',227,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (7053,1,1,'tbsp',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7053,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7054,1,1,'tbsp',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7054,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7055,1,1,'tbsp',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7055,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7056,1,3.52,'slices',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (7057,1,3,'oz',85,'g',1,'2007-11-28','2016-02-06');
INSERT INTO `cndb_wght` VALUES (7057,2,1,'piece',2,'g',1,'1998-01-15','2016-02-06');
INSERT INTO `cndb_wght` VALUES (7057,3,1,'oz',28,'g',1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (7058,1,1,'slice',38,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7058,2,2,'slices',57,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (7059,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7059,2,1,'sausage (10" long x 1-1/4" dia)',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7060,1,1,'slice (1 oz) (4" x 4" x 3/32" thick)',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7060,2,2,'slices',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7061,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7061,2,1,'slice (4-1/4" x 4-1/4" x 1/16")',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7062,1,1,'slice (1 oz) (4" x 4" x 3/32" thick)',28,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7062,2,2,'slices',57,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7063,1,1,'link',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7064,1,1,'patty',27,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7064,2,1,'link',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7064,3,1,'serving',48,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7065,1,1,'link (raw dimensions: 4" long x 7/8" dia), cooked',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7065,2,1,'patty, cooked (raw dimensions: 3-7/8" dia x 1/4" thick)',27,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7066,1,1,'cup',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7067,1,1,'tbsp',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7067,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7068,1,1,'slice',26,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7068,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7069,1,1,'slice round',12.3,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (7070,1,1,'serving',28,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7071,1,1,'package (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7071,2,1,'slice (3-1/8" dia x 1/16" thick)',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7072,1,1,'slice',9.8,'g',1,'1998-01-15','2015-01-07');
INSERT INTO `cndb_wght` VALUES (7072,2,1,'oz',28,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (7072,3,3,'slices 1 serving',27,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7073,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7073,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7074,1,1,'link (4" long x 1-1/8" dia)',68,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7074,2,1,'link, little (2" long x 3/4" dia)',16,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (7075,1,3,'oz',85,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (7077,1,1,'link (4" long x 1-1/8" dia)',68,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7077,2,1,'link,  little (2" long x 3/4" dia)',16,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7078,1,2,'oz 1 serving',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7081,1,1,'slice',16,'g',1,'1995-06-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (7083,1,1,'sausage (7/8" dia x 2" long)',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7083,2,7,'sausages (drained contents from can, net wt 4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7088,1,1,'slice (4" dia x 1/8" thick)',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7088,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7089,1,1,'link',87,'g',1,'1999-03-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (7090,1,1,'slice (4" dia x 1/8" thick)',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7090,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7254,1,1,'serving',14,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (7254,2,1,'slice 12 oz pkg',16,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (7254,3,1,'slice 6 oz pkg',9.8,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (7900,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7900,2,1,'lb 16 oz',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7905,1,1,'frank 1 NLEA serving',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7906,1,2,'oz 1 NLEA serving',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7908,1,2,'oz 1 NLEA serving',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7909,1,2,'oz (1 serving)',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7910,1,1,'serving 2.96 oz',84,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7911,1,0.25,'cup',55,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7912,1,1,'serving .25 cup',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7913,1,3.527,'oz',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (7914,1,1,'link 3 oz',84,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7915,1,1,'serving 5 pieces',55,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7915,2,5,'pieces',55,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7916,1,1,'serving 2.67 oz',76,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7917,1,12,'oz serving 2.7 oz',77,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7918,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7919,1,1,'link',28,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (7919,2,1,'package',450,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (7921,1,1,'oz',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7922,1,1,'serving 2.33 oz',66,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7925,1,1,'serving 6 slices',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7926,1,1,'oz',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7927,1,1,'serving 2 oz',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7928,1,1,'link',84,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7929,1,2,'oz',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7930,1,1,'serving 2 oz',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7931,1,1,'serving 2 oz',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7932,1,1,'serving 2 slices',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7933,1,1,'serving 2 slices',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7934,1,1,'serving 2 oz',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7935,1,1,'serving 2 oz',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7936,1,1,'serving 2 oz',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7937,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7938,1,1.94,'oz (1 serving)',55,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7939,1,1,'link',76,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7940,1,1,'slice',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7941,1,1,'serving 5 slices',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7942,1,1,'serving 2 oz',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7943,1,1,'slice',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7944,1,1.69,'oz (1 serving)',48,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7945,1,1,'frankfurter',48,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7945,2,1,'package',451,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7949,1,1,'serving (1 hot dog)',52,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7950,1,1,'serving (1 hot dog)',52,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7951,1,1,'cubic inch',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7951,2,1,'oz cooked',25,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (7951,3,2,'oz',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7952,1,1,'serving',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7952,2,1,'slice',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7953,1,1,'patty',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7953,2,1,'link',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7953,3,1,'serving',48,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7954,1,1,'link',19,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (7955,1,1,'serving',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7956,1,1,'serving',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7957,1,1,'serving',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7958,1,1,'serving',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7959,1,1,'serving',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7959,2,1,'slice',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7960,1,1,'serving',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7960,2,1,'slice',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7961,1,1,'slice',12,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (7962,1,1,'frankfurter',51,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (7963,1,1,'frankfurter',50,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (7964,1,1,'frankfurter',48,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (7965,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7965,2,1,'package',343,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7966,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (7966,2,1,'package',343,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7967,1,1,'link',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7967,2,1,'patty',37,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7968,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7968,2,1,'link',367,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7969,1,1,'link',370,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7970,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7970,2,1,'link',396,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7971,1,1,'slice',33,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (7972,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (7972,2,3,'pieces',56,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (7973,1,1,'slice',8.1,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (7974,1,1,'serving',15,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (7978,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (7979,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (7979,2,1,'serving',56,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (8037,1,1,'CUP',122,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8037,2,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8084,1,1,'oz',28.35,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (8084,2,1,'cup',113,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (8090,1,1,'tbsp',9.7,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (8090,2,1,'cup',156,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (8091,1,1,'cup',257,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (8091,2,1,'TBSP',16,'g',1,'2007-11-28','2010-01-04');
INSERT INTO `cndb_wght` VALUES (8120,1,1,'CUP',81,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8120,2,0.333,'CUP',27,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (8121,1,1,'CUP',234,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8121,2,1,'tbsp',14.6,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (8121,3,0.75,'CUP',175,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (8122,1,1,'packet',28,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8123,1,1,'cup, cooked',234,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8123,2,1,'cup, dry, yields',501,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8123,3,1,'oz, dry, yields',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (8123,4,1,'packet, dry, yields',177,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (8128,1,1,'packet',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (8129,1,1,'CUP',240,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8129,2,1,'TBSP',15,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8129,3,1,'packet, prepared',161,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8133,1,1,'CUP',240,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8133,2,1,'TBSP',15,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8133,3,1,'packet, prepared',158,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8144,1,1,'CUP',94,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8144,2,0.333,'CUP',31,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (8145,1,1,'CUP',242,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8145,2,0.75,'CUP',182,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (8156,1,1,'CUP',14,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8156,2,0.5,'oz',14.2,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8157,1,1,'CUP',12,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8157,2,0.5,'oz',14.2,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8160,1,1,'tbsp',9.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (8160,2,1,'cup',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (8161,1,1,'CUP',257,'g',1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_wght` VALUES (8161,2,1,'tablespoon',16,'g',1,'2007-11-28','2015-01-07');
INSERT INTO `cndb_wght` VALUES (8164,1,1,'cup',233,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (8165,1,1,'CUP',233,'g',1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_wght` VALUES (8172,1,1,'tbsp',10.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (8172,2,1,'cup',176,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (8173,1,1,'CUP',233,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8180,1,1,'cup',234,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (8180,2,0.75,'cup',175,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (8183,1,1,'CUP',242,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (8183,2,0.75,'CUP',182,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (8204,1,1,'cup',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (8510,1,1,'bar',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (8546,1,1,'bar',22,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (8680,1,1,'packet',43,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (9001,1,1,'CUP',98,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9001,2,1,'fruit without refuse',4.8,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9002,1,1,'CUP',242,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9002,2,1,'FL OZ',30.2,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9003,1,1,'cup, quartered or chopped',125,'g',1,'1994-09-29','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9003,2,1,'cup slices',109,'g',1,'1999-03-22','2009-02-11');
INSERT INTO `cndb_wght` VALUES (9003,3,1,'large (3-1/4" dia)',223,'g',1,'1998-01-15','2015-01-07');
INSERT INTO `cndb_wght` VALUES (9003,4,1,'medium (3" dia)',182,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (9003,5,1,'small (2-3/4" dia)',149,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (9003,6,1,'extra small (2-1/2" dia)',101,'g',1,'2004-07-15','2015-01-07');
INSERT INTO `cndb_wght` VALUES (9003,7,1,'NLEA serving',242,'g',1,'2007-11-28','2009-02-11');
INSERT INTO `cndb_wght` VALUES (9004,1,1,'cup slices',110,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9004,2,1,'large (3-1/4" dia)',216,'g',1,'1999-03-22','2015-01-07');
INSERT INTO `cndb_wght` VALUES (9004,3,1,'medium (3" dia)',161,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (9004,4,1,'small (2-3/4" dia)',132,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (9005,1,1,'cup slices',171,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9006,1,1,'cup slices',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9008,1,1,'cup slices',204,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9009,1,1,'CUP',60,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9010,1,1,'CUP',193,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9011,1,1,'CUP',86,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9011,2,1,'ring',6.4,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9012,1,1,'CUP',255,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9013,1,1,'CUP',280,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9014,1,1,'cup slices',173,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9015,1,1,'cup slices',206,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9016,1,1,'CUP',248,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9016,2,1,'FL OZ',31,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9016,3,1,'drink box (8.45 fl oz)',262,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9017,1,1,'can (6 fl oz)',211,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9018,1,1,'CUP',239,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9018,2,1,'FL OZ',29.9,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9019,1,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9020,1,1,'CUP',246,'g',1,'1999-03-22','2009-02-11');
INSERT INTO `cndb_wght` VALUES (9021,1,1,'cup, halves',155,'g',1,'1994-01-31','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9021,2,1,'cup, sliced',165,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9021,3,1,'apricot',35,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9022,1,1,'cup, halves',243,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9022,2,1,'apricot half with liquid',36,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9023,1,1,'cup, whole, without pits',227,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9024,1,1,'cup, halves',244,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9024,2,1,'apricot half with liquid',36,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9025,1,1,'cup, halves',247,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9026,1,1,'cup, halves',253,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9026,2,1,'apricot half with liquid',40,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9027,1,1,'cup, halves',258,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9027,2,1,'cup, whole',240,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9027,3,1,'apricot half with liquid',40,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9028,1,1,'cup, whole, without pits',258,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9029,1,1,'cup, whole, without pits',246,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9030,1,1,'cup',119,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9031,1,1,'cup',249,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9032,1,1,'cup, halves',130,'g',1,'1994-10-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9032,2,1,'half',3.5,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9033,1,1,'cup, halves',250,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9034,1,1,'cup, halves',270,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9035,1,1,'CUP',242,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9036,1,1,'cup',266,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9036,2,1,'fl oz',30.4,'g',1,'2002-09-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9037,1,1,'cup, cubes',150,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9037,2,1,'cup, pureed',230,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9037,3,1,'cup, sliced',146,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9037,4,1,'avocado, NS as to Florida or California',201,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9037,5,1,'NLEA Serving',50,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9038,1,1,'cup, pureed',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9038,2,1,'fruit, without skin and seed',136,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9038,3,1,'NLEA serving',50,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9039,1,1,'cup, pureed',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9039,2,1,'fruit without skin and seeds',304,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9039,3,1,'NLEA Serving',50,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9040,1,1,'cup, mashed',225,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9040,2,1,'cup, sliced',150,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9040,3,1,'extra small (less than 6" long)',81,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9040,4,1,'small (6" to 6-7/8" long)',101,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9040,5,1,'medium (7" to 7-7/8" long)',118,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9040,6,1,'large (8" to 8-7/8" long)',136,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9040,7,1,'extra large (9" or longer)',152,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9040,8,1,'NLEA serving',126,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9041,1,1,'cup',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (9041,2,1,'tbsp',6.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9042,1,1,'CUP',144,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9043,1,1,'cup',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9044,1,0.25,'cup',40,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9046,1,1,'CUP',256,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9048,1,1,'cup, unthawed',151,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9048,2,1,'package (18 oz)',510,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9050,1,1,'CUP',148,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9050,2,50,'berries',68,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (9052,1,1,'CUP',256,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9053,1,1,'cup, frozen',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9054,1,1,'cup, unthawed',155,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9054,2,1,'package (20 oz)',567,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9055,1,1,'cup, thawed',230,'g',1,'1994-10-18','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9055,2,1,'package (10 oz)',284,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9056,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9057,1,1,'cup, unthawed',132,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9057,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9059,1,1,'CUP',220,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9059,2,0.25,'fruit, small',96,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9060,1,1,'cup, cubes',132,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9060,2,1,'cup, sliced',108,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9060,3,1,'large (4-1/2" long)',124,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9060,4,1,'medium (3-5/8" long)',91,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9060,5,1,'small (3-1/8" long)',70,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9062,1,1,'cup, pieces',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9062,2,1,'fruit without skin and seeds',235,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9063,1,1,'cup, without pits',155,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9063,2,1,'cup, with pits, yields',103,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9064,1,1,'CUP',244,'g',1,'1999-03-22','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9065,1,1,'cup',252,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9066,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9067,1,1,'cup',261,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9068,1,1,'cup, unthawed',155,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9068,2,1,'package (18 oz)',510,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9070,1,1,'cup, with pits, yields',138,'g',1,'1997-08-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (9070,2,1,'cup, without pits',154,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (9070,3,1,'cherry',8.2,'g',1,'1998-01-15','2009-02-11');
INSERT INTO `cndb_wght` VALUES (9070,4,1,'NLEA serving',140,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9071,1,1,'cup, pitted',248,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9072,1,1,'cup, pitted',250,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9073,1,1,'cup, pitted',252,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9074,1,1,'CUP',253,'g',1,'1995-06-19','2009-02-11');
INSERT INTO `cndb_wght` VALUES (9075,1,1,'cup, pitted',261,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9077,1,1,'cup slices',110,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9078,1,1,'cup, chopped',110,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9078,2,1,'cup, whole',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (9079,1,0.25,'cup',40,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (9081,1,1,'CUP',277,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9081,2,1,'slice (1/2" thick, approx 8 slices per can)',57,'g',1,'1994-10-18','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9082,1,1,'CUP',275,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9083,1,1,'cup',112,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9084,1,1,'CUP',112,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9085,1,1,'cup',144,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9087,1,1,'cup, chopped',147,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (9087,2,1,'date, pitted',7.1,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (9088,1,1,'cup',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9089,1,1,'large (2-1/2" dia)',64,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9089,2,1,'medium (2-1/4" dia)',50,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9089,3,1,'small (1-1/2" dia)',40,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9090,1,1,'CUP',248,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9090,2,1,'fig with liquid',27,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9091,1,1,'CUP',252,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9091,2,1,'fig with liquid',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9092,1,1,'CUP',259,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9092,2,1,'fig with liquid',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9093,1,1,'cup',261,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9094,1,1,'CUP',149,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9094,2,1,'fig',8.4,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9095,1,1,'CUP',259,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9096,1,1,'CUP',237,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9097,1,1,'CUP',237,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9098,1,0.5,'CUP',123,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9099,1,1,'CUP',242,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9100,1,1,'CUP',248,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9101,1,0.5,'cup',130,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (9101,2,1,'cup',260,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (9102,1,1,'CUP',245,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9103,1,1,'CUP',249,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9104,1,1,'CUP',252,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9106,1,1,'CUP',259,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9107,1,1,'cup',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9109,1,1,'cup',252,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9110,1,5,'tbsp',28,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (9111,1,1,'cup sections, with juice',230,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9111,2,0.5,'large (approx 4-1/2" dia)',166,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9111,3,0.5,'medium (approx 4" dia)',128,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9111,4,0.5,'small (approx 3-1/2" dia)',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (9112,1,1,'cup sections, with juice',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9112,2,0.5,'fruit (3-3/4" dia)',123,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9112,3,1,'NLEA serving',154,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9113,1,1,'cup sections, with juice',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9113,2,0.5,'fruit (3-3/4" dia)',123,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9114,1,1,'cup sections, with juice',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9114,2,0.5,'fruit (3-3/4" dia)',123,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9116,1,1,'cup sections, with juice',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9116,2,0.5,'fruit (3-3/4" dia)',118,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9117,1,1,'cup sections, with juice',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9117,2,0.5,'fruit (3-3/4" dia)',118,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9118,1,1,'cup sections, with juice',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9118,2,0.5,'fruit (3-3/4" dia)',118,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9119,1,1,'CUP',244,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9120,1,1,'CUP',249,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9121,1,1,'CUP',254,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9123,1,1,'cup',257,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9123,2,8,'fl oz',246,'g',1,'2002-09-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9124,1,1,'CUP',250,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9124,2,1,'FL OZ',31.2,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9125,1,1,'can (6 fl oz)',207,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9126,1,1,'CUP',247,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9126,2,1,'FL OZ',30.9,'g',1,'1997-08-29','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9127,1,8,'fl oz',240,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (9127,2,1,'cup',252,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9128,1,1,'cup',247,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9128,2,1,'fl oz',30.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9128,3,1,'fruit yields',196,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9130,1,1,'CUP',253,'g',1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_wght` VALUES (9130,2,1,'FL OZ',31.6,'g',1,'2009-01-25','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9131,1,1,'CUP',92,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9131,2,1,'grape',2.4,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9132,1,1,'cup',151,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9132,2,10,'grapes',49,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9132,3,1,'NLEA serving',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9133,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9134,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9135,1,1,'CUP',253,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9135,2,1,'FL OZ',31.6,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9139,1,1,'CUP',165,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9139,2,1,'fruit, without refuse',55,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9140,1,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9140,2,1,'fruit without refuse',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9143,1,1,'CUP',238,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9144,1,1,'cup, sliced',165,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9144,2,1,'cup 1" pieces',151,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9148,1,1,'cup, sliced',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9148,2,1,'fruit (2" dia)',69,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9148,3,1,'NLEA serving',148,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9149,1,1,'fruit without refuse',19,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9150,1,1,'cup, sections',212,'g',1,'1994-09-29','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9150,2,1,'fruit (2-1/8" dia)',58,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9150,3,1,'fruit (2-3/8" dia)',84,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9150,4,1,'wedge or slice (1/8 of one 2-1/8" dia lemon)',7,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9150,5,1,'NLEA serving',58,'g',1,'2004-07-15','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9152,1,1,'CUP',244,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9152,2,1,'FL OZ',30.5,'g',1,'1998-01-15','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9152,3,1,'lemon yields',48,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9152,4,1,'wedge yields',5.9,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9153,1,1,'tbsp',15,'g',1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_wght` VALUES (9153,2,1,'tsp',5,'g',1,'1999-03-22','2016-02-06');
INSERT INTO `cndb_wght` VALUES (9153,3,1,'FL OZ',30.5,'g',1,'1998-01-15','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9153,4,1,'cup',244,'g',1,'2002-09-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (9156,1,1,'TBSP',6,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9156,2,1,'tsp',2,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9159,1,1,'fruit (2" dia)',67,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9159,2,1,'NLEA serving',67,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9160,1,1,'CUP',242,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9160,2,1,'FL OZ',30.8,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9160,3,1,'lime yields',44,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9161,1,1,'CUP',246,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9161,2,1,'FL OZ',30.8,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9163,1,0.25,'cup',40,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9164,1,1,'CUP',190,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9164,2,1,'fruit without refuse',9.6,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9165,1,1,'fruit',2.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9167,1,1,'cup, unthawed',147,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9174,1,1,'cup, cubed',149,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9174,2,1,'large',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9174,3,1,'medium',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9174,4,1,'small',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9175,1,1,'fruit without refuse',846,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9176,1,1,'cup pieces',165,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9176,2,1,'fruit without refuse',336,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9181,1,1,'cup, balls',177,'g',1,'1994-09-29','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9181,2,1,'cup, cubes',160,'g',1,'1998-01-15','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9181,3,1,'cup, diced',156,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9181,4,1,'melon, large (about 6-1/2" dia)',814,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9181,5,1,'wedge, large (1/8 of large melon)',102,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9181,6,1,'melon, medium (about 5" dia)',552,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9181,7,1,'wedge, medium (1/8 of medium melon)',69,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9181,8,1,'melon, small (about 4-1/4" dia)',441,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9181,9,1,'wedge, small (1/8 of small melon)',55,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9181,10,10,'cantaloupe balls',138,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9181,11,1,'NLEA serving',134,'g',1,'2004-07-15','2007-03-25');
INSERT INTO `cndb_wght` VALUES (9183,1,1,'cup, cubes',170,'g',1,'1994-10-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9183,2,1,'melon',1640,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9183,3,0.1,'fruit',164,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9184,1,1,'cup, diced (approx 20 pieces per cup)',170,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (9184,2,1,'cup, balls',177,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (9184,3,1,'melon (5-1/4" dia)',1000,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9184,4,1,'melon (6" - 7" dia)',1280,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9184,5,1,'wedge (1/8 of 5-1/4" dia melon)',125,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9184,6,1,'wedge (1/8 of 6" to 7" dia melon)',160,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9184,7,10,'honeydew balls',138,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9184,8,1,'NLEA serving',134,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9185,1,1,'cup, unthawed',173,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9190,1,1,'cup',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9190,2,10,'fruit',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9191,1,1,'cup slices',143,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9191,2,1,'small (2-1/3" dia)',129,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9191,3,1,'medium (2-1/2" dia)',142,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9191,4,1,'large (2-3/4" dia)',156,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (9191,5,1,'NLEA serving',140,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (9193,1,1,'TBSP',8.4,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9193,2,1,'large',4.4,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9193,3,1,'small',3.2,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9194,1,1,'super colossal',15,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (9194,2,1,'jumbo',8.3,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (9195,1,1,'olive',2.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9200,1,1,'cup, sections',180,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9200,2,1,'large (3-1/16" dia)',184,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9200,3,1,'small (2-3/8" dia)',96,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9200,4,1,'fruit (2-5/8" dia)',131,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9201,1,1,'cup sections, without membranes',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9201,2,1,'fruit (2-5/8" dia)',121,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9202,1,1,'cup sections, without membranes',165,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9202,2,1,'fruit (2-7/8" dia)',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9202,3,1,'NLEA serving',154,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9203,1,1,'cup sections, without membranes',185,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9203,2,1,'fruit (2-5/8" dia)',141,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9203,3,1,'fruit (2-11/16" dia)',151,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9205,1,1,'cup',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9205,2,1,'fruit without seeds',159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9206,1,1,'CUP',248,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9206,2,1,'FL OZ',31,'g',1,'1999-03-22','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9206,3,1,'fruit yields',86,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9207,1,1,'CUP',249,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9207,2,1,'FL OZ',31.1,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9207,3,1,'drink box (8.45 fl oz)',263,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9209,1,1,'CUP',249,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9209,2,1,'FL OZ',31.1,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9210,1,1,'cup',249,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9210,2,1,'fl oz',31.1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9211,1,1,'cup',249,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (9211,2,1,'fl oz',31.1,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (9212,1,1,'cup',249,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (9212,2,1,'fl oz',31.1,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (9213,1,1,'cup',262,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (9213,2,1,'fl oz',33,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (9214,1,1,'CUP',262,'g',1,'1994-09-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (9214,2,1,'FL OZ',33,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (9215,1,1,'CUP',249,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9215,2,1,'FL OZ',31.1,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9216,1,1,'TBSP',6,'g',1,'1995-06-27','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9216,2,1,'tsp',2,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9217,1,1,'CUP',247,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9217,2,1,'FL OZ',30.9,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9218,1,1,'cup, sections',195,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9218,2,1,'small (2-1/4" dia)',76,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9218,3,1,'medium (2-1/2" dia)',88,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9218,4,1,'large (2-3/4" dia)',120,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9218,5,1,'NLEA serving',109,'g',1,'2004-07-15','2009-02-11');
INSERT INTO `cndb_wght` VALUES (9219,1,1,'CUP',249,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9220,1,1,'CUP',252,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9221,1,1,'cup',247,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9221,2,1,'fl oz',30.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9226,1,1,'cup 1" pieces',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9226,2,1,'cup, mashed',230,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9226,3,1,'fruit, small',157,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9226,4,1,'fruit, large',781,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9228,1,1,'piece',39,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9229,1,1,'CUP',250,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9229,2,1,'FL OZ',31.2,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9231,1,1,'cup',236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9231,2,1,'fruit without refuse',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9232,1,1,'cup',247,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9232,2,1,'fl oz',30.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9233,1,1,'cup',247,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9233,2,1,'fl oz',30.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9236,1,1,'cup slices',154,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9236,2,1,'small (2-1/2" dia)',130,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9236,3,1,'medium (2-2/3" dia)',150,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9236,4,1,'large (2-3/4" dia)',175,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9236,5,1,'extra large (3" dia)',224,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9236,6,1,'NLEA serving',147,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (9237,1,1,'cup, halves or slices',244,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9237,2,1,'half, with liquid',98,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9238,1,1,'CUP',250,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9238,2,1,'cup, halves or slices',248,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9238,3,1,'half, with liquid',98,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9239,1,1,'cup, halves or slices',247,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9240,1,1,'cup, halves or slices',251,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9240,2,1,'half, with liquid',98,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9241,1,1,'CUP',262,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9241,2,1,'half, with liquid',98,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9242,1,1,'cup, halves or slices',262,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9243,1,1,'cup, whole',242,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9244,1,1,'cup',116,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9245,1,1,'cup',242,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9246,1,1,'cup, halves',160,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9246,2,1,'half',13,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9247,1,1,'CUP',258,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9248,1,1,'CUP',270,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9250,1,1,'cup, thawed',250,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9250,2,10,'slices',155,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9250,3,1,'package (10 oz)',284,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9251,1,1,'cup',258,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9252,1,1,'cup, slices',140,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (9252,2,1,'cup, cubes',161,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (9252,3,1,'small',148,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (9252,4,1,'medium',178,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (9252,5,1,'large',230,'g',1,'2004-07-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (9252,6,1,'NLEA serving',166,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (9253,1,1,'cup, halves',244,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9253,2,1,'half, with liquid',76,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9254,1,1,'cup, halves',248,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9254,2,1,'half, with liquid',76,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9255,1,1,'cup, halves',247,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9255,2,1,'half, with liquid',76,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9256,1,1,'cup, halves',251,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9256,2,1,'half, with liquid',76,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9257,1,1,'CUP',266,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9257,2,1,'half, with liquid',76,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9258,1,1,'cup, halves',266,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9258,2,1,'half, with liquid',79,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9259,1,1,'cup, halves',180,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9259,2,1,'half',18,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9259,3,10,'halves',175,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9260,1,1,'cup, halves',255,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9261,1,1,'cup, halves',280,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9262,1,1,'CUP',250,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9262,2,1,'FL OZ',31.2,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9263,1,1,'fruit (2-1/2" dia)',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9266,1,1,'cup, chunks',165,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (9266,2,1,'fruit',905,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (9266,3,1,'slice (4-2/3" dia x 3/4" thick)',166,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (9266,4,1,'slice (3-1/2" dia x 3/4" thick)',84,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (9266,5,1,'slice, thin (3-1/2" dia x 1/2" thick)',56,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (9267,1,1,'cup, crushed, sliced, or chunks',246,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9267,2,1,'slice or ring (3" dia) with liquid',47,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9268,1,1,'cup, crushed, sliced, or chunks',249,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9268,2,1,'slice or ring (3" dia) with liquid',47,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9269,1,1,'cup, crushed, sliced, or chunks',252,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9269,2,1,'slice or ring (3" dia) with liquid',48,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9270,1,1,'cup, crushed, sliced, or chunks',254,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9270,2,1,'slice or ring (3" dia) with liquid',49,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9271,1,1,'cup, crushed, sliced, or chunks',260,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9272,1,1,'cup, chunks',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9273,1,1,'CUP',250,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9273,2,1,'FL OZ',31.3,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9274,1,1,'can (6 fl oz)',216,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9275,1,1,'CUP',250,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9275,2,1,'FL OZ',31.2,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9277,1,1,'plantain',270,'g',1,'1994-09-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9277,2,1,'cup, sliced',148,'g',1,'2002-09-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9278,1,1,'cup',139,'g',1,'1994-09-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9278,2,10,'slice',105,'g',1,'1999-03-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9279,1,1,'cup, sliced',165,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9279,2,1,'fruit (2-1/8" dia)',66,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9279,3,1,'NLEA serving',151,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9281,1,1,'cup, pitted',249,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9281,2,1,'plum with liquid',46,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9282,1,1,'cup, pitted',252,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9282,2,1,'plum with liquid',46,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9283,1,1,'cup, pitted',252,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9283,2,1,'plum with liquid',46,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9284,1,1,'cup, pitted',258,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9284,2,1,'plum with liquid',46,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9285,1,1,'cup, pitted',261,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9286,1,0.5,'cup arils (seed/juice sacs)',87,'g',1,'1996-09-30','2013-12-26');
INSERT INTO `cndb_wght` VALUES (9286,2,1,'pomegranate (4" dia)',282,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (9287,1,1,'cup',149,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9287,2,1,'fruit without refuse',103,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9288,1,1,'CUP',234,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9288,2,5,'prunes with liquid',86,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (9289,1,1,'cup',132,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9290,1,1,'cup',280,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9291,1,1,'cup, pitted',174,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9291,2,1,'prune, pitted',9.5,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9292,1,1,'cup, pitted',248,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9293,1,1,'cup, pitted',248,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9294,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9294,2,1,'fl oz',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9296,1,1,'fruit without refuse',92,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9297,1,1,'cup, packed',165,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9297,2,1,'cup (not packed)',145,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9298,1,1,'cup, packed',165,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9298,2,1,'cup (not packed)',145,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9298,3,1,'miniature box (.5 oz)',14,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9298,4,1,'small box (1.5 oz)',43,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9298,5,50,'raisins',26,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9298,6,1,'oz (60 raisins)',28.35,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (9299,1,1,'cup, packed',165,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9299,2,1,'cup (not packed)',145,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9302,1,1,'CUP',123,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9302,2,1,'pint as purchased, yields',312,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9302,3,10,'raspberries',19,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9304,1,1,'CUP',256,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9306,1,1,'cup, thawed',250,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (9306,2,1,'package (10 oz)',284,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9307,1,1,'cup, diced',122,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9307,2,1,'stalk',51,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9309,1,1,'cup, diced',137,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9310,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9313,1,1,'cup, pulp',241,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9313,2,1,'sapodilla',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9314,1,1,'cup 1" pieces',175,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9314,2,1,'fruit without refuse',558,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9315,1,1,'cup, pulp',225,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9315,2,1,'fruit (7" x 5-1/4" dia)',625,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9316,1,1,'cup, halves',152,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9316,2,1,'cup, pureed',232,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9316,3,1,'cup, sliced',166,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9316,4,1,'cup, whole',144,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9316,5,1,'extra large (1-5/8" dia)',27,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9316,6,1,'large (1-3/8" dia)',18,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9316,7,1,'medium (1-1/4" dia)',12,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9316,8,1,'pint as purchased, yields',357,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9316,9,1,'small (1" dia)',7,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9316,10,1,'NLEA serving',147,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9317,1,1,'CUP',254,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9318,1,1,'cup, thawed',221,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9318,2,1,'cup, unthawed',149,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9318,3,1,'berry',10.6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9318,4,1,'package (20 oz)',567,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9320,1,1,'cup, thawed',255,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9320,2,1,'package (10 oz)',284,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9321,1,1,'cup, pulp',250,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9321,2,1,'fruit (2-7/8" dia)',155,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9322,1,1,'cup, pulp',120,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9322,2,1,'fruit (3" x 1")',2,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9325,1,1,'CUP',257,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9326,1,1,'cup, balls',154,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9326,2,1,'cup, diced',152,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9326,3,1,'melon (15" long x 7-1/2" dia)',4518,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9326,4,1,'wedge (approx 1/16 of melon)',286,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9326,5,10,'watermelon balls',122,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9326,6,1,'NLEA serving',280,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9328,1,1,'cherry (NLEA serving)',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9334,1,1,'cup, pureed',243,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9334,2,1,'fruit without peel',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9334,3,1,'cup 1/2" chunks',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9340,1,1,'fruit 2-1/4" high x 2-1/2" dia',122,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9340,2,1,'fruit 3-3/8" high x 3" diameter',275,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9351,1,1,'CUP',214,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9352,1,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9354,1,1,'cup, chunks',181,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9354,2,1,'cup, crushed',195,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9354,3,1,'cup, sliced',162,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9354,5,1,'spear',26,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9357,1,1,'cup, halves',219,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9357,2,1,'cup, whole',182,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9367,1,1,'CUP',179,'g',1,'1994-11-02','2009-02-11');
INSERT INTO `cndb_wght` VALUES (9370,1,1,'CUP',222,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9370,2,1,'half',73,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9370,3,1,'slice',12.7,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9374,1,1,'CUP',201,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9374,2,1,'half',48,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9379,1,1,'cup, with pits, yields',183,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9383,1,1,'CUP',189,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9400,1,1,'CUP',248,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9400,2,1,'FL OZ',31,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9401,1,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9402,1,1,'cup',255,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9404,1,1,'cup',247,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9404,2,1,'fruit yields',196,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9407,1,1,'cup',220,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9408,1,1,'CUP',250,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9408,2,1,'FL OZ',31.2,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9409,1,1,'CUP',250,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9409,2,1,'FL OZ',31.3,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9410,1,1,'can (6 fl oz)',211,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9411,1,1,'CUP',239,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (9411,2,1,'FL OZ',29.9,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9423,1,2,'tbsp',36,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (9427,1,0.5,'cup',114,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9428,1,0.5,'cup',114,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9434,1,1,'cup',251,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9435,1,1,'cup',251,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (9436,1,1,'cup',251,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9442,1,1,'CUP',249,'g',1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_wght` VALUES (9442,2,1,'FL OZ',31.4,'g',1,'2009-01-25','2010-01-05');
INSERT INTO `cndb_wght` VALUES (9443,1,8,'fl oz',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9444,1,8,'fl oz',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9446,1,1,'cup',118,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9446,2,10,'slices (1/4" thick)',53,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9447,1,1,'cup',169,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (9452,1,8,'fl oz',246,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (9506,1,1,'cup',249,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (9506,2,1,'fl oz',31.1,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (9512,1,1,'cup',253,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (9512,2,1,'fl oz',31.6,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (9517,1,6,'fl oz',177,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (9517,2,10,'fl oz',295,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (9518,1,1,'cup, unthawed',140,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9519,1,11.3,'fl oz',335,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (9522,1,6.75,'fl oz',200,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (9522,2,8,'fl oz',240,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (9542,1,1,'plantain',267,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (9543,1,1,'cup',137,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10000,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10001,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10001,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10002,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10002,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10003,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10003,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10004,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10004,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10005,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10005,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10006,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10006,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10007,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10007,2,1,'oz',28.35,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10008,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10008,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10009,1,1,'cup, diced',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10009,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10010,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10010,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10011,1,1,'cup, diced',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10011,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10012,1,4,'oz',113,'g',1,'2001-07-04','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10012,2,1,'lb',453.6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10013,1,1,'cup, diced',135,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10013,2,3,'oz',85,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10014,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10014,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10014,3,1,'roast',3952,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10015,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10015,2,1,'roast',3027,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10016,1,4,'oz',113,'g',1,'2001-07-04','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10016,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10016,3,1,'roast',3868,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10017,1,3,'oz',85,'g',1,'1996-09-30','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10017,2,1,'roast',2900,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10018,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10018,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10018,3,1,'roast',3868,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10019,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10019,2,1,'roast',2900,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10020,1,4,'oz',113,'g',1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10020,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 151 g)',117,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10021,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10021,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 151 g)',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10022,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10022,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 151 g)',87,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10023,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10023,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 151 g)',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10024,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10024,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 151 g)',106,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10025,1,3,'oz',85,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10025,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 151 g)',80,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10026,1,3,'oz',85,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10026,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 151 g)',79,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10027,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10027,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 151 g)',81,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10028,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10028,2,1,'chop',263,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10029,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10029,2,1,'chop',206,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10030,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10030,2,1,'chop',219,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10031,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10031,2,1,'roast',830,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10032,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10032,2,1,'chop',263,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10033,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10033,2,1,'chop',206,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10034,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10034,2,1,'chop',219,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10035,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10035,2,1,'roast',830,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10036,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10036,2,1,'chop without refuse (Yield from 1 raw chop, with refuse, weighing 259g)',199,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10037,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10037,2,1,'chop',187,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10038,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10038,2,1,'chop without refuse (Yield from 1 cooked chop, with refuse, weighing 209g)',157,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10039,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10039,2,1,'roast',900,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10040,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10040,2,1,'chop without refuse (Yield from 1 raw chop, with refuse, weighing 259g)',178,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10041,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10041,2,1,'chop',187,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10042,1,1,'chop without refuse (Yield from 1 cooked chop, with refuse, weighing 209g)',146,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10042,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10043,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10043,2,1,'roast',900,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10044,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10044,2,1,'chop without refuse (Yield from 1 raw chop, with refuse, weighing 201g)',133,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10044,3,1,'lb',453.6,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10045,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10045,2,1,'chop',187,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10046,1,1,'chop without refuse (Yield from 1 cooked chop, with refuse, weighing 172g)',112,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10046,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10047,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10047,2,1,'roast',783,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10048,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10048,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 151 g)',86,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10049,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10049,2,1,'chop',187,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10050,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10050,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 151 g)',67,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10051,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10051,2,1,'roast',783,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10052,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10052,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10052,3,1,'roast without refuse (Yield from 1 raw roast, with refuse, weighing 1817g)',1327,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10053,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10053,2,1,'chop',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10054,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10054,2,1,'chop',195,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10055,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10055,2,1,'roast without refuse (Yield from 1 cooked roast, with refuse, weighing 1515g)',1046,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10057,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10057,2,1,'chop',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10058,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10058,2,1,'chop',195,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10059,1,3,'oz (Yield from 1 cooked roast, with refuse, weighing 1515g)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10059,2,1,'roast without refuse',985,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10060,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10060,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10060,3,1,'roast',505,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10061,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10061,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',333,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10061,3,1,'roast',402,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10062,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10062,2,1,'chop',185,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10063,1,1,'chop',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10064,1,1,'chop',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10064,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10065,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10065,2,1,'roast',848,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10066,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10066,2,1,'chop',185,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10066,3,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10067,1,1,'chop',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10068,1,1,'chop',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10069,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10070,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10070,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10071,1,1,'cup, diced',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10071,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10072,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10072,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10073,1,1,'cup, diced',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10073,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10074,1,4,'oz',113,'g',1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10074,2,1,'roast',2745,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10075,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10075,2,1,'roast',2252,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10076,1,1,'cup, diced',135,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10076,2,3,'oz',85,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10077,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10077,2,1,'roast',2745,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10078,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10078,2,1,'roast',2252,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10079,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10079,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',191,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10080,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10080,2,1,'steak without refuse (Yield from 1 raw steak, with refuse, weighing 380g)',288,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10080,3,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10081,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10081,2,1,'steak without refuse (Yield from 1 cooked steak, with refuse, weighing 249g)',185,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10082,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10082,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 300 g)',169,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10083,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10083,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',262,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10084,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10084,2,1,'steak without refuse (Yield from 1 raw steak, with refuse, weighing 379g)',258,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10085,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10085,2,1,'steak',249,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10086,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10086,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 300 g)',147,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10087,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10087,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',238,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10088,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10089,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10089,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10093,1,3,'oz',85,'g',1,'2004-07-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10093,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',231,'g',1,'2004-07-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10094,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10094,2,1,'chop',170,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (10096,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10096,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10097,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10098,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10099,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10100,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10100,2,1,'ear',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10101,1,1,'ear (yield after cooking)',111,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10101,2,1,'unit, cooked (yield from 1 lb raw meat)',422,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10102,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10103,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10103,2,1,'heart',226,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10104,1,1,'cup',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10104,2,1,'heart',129,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10105,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10105,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10106,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10106,2,1,'kidney',233,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10107,1,1,'cup',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10107,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10109,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10109,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10110,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10110,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10111,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10112,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10112,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10113,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10114,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10114,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10115,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10115,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10116,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10117,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10117,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10118,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10119,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10119,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10120,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10120,2,1,'chop',215,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10121,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10121,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10122,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10122,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',231,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10123,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10123,2,1,'slice raw',28,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10123,3,1,'package',442,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10128,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10128,2,3,'slices',68,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10128,3,1,'package (12 oz)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10130,1,3,'oz',85,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10130,2,2,'slices (6 per 6-oz pkg.)',57,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10130,3,1,'package (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10132,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10132,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10134,1,1,'CUP',140,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10134,2,3,'oz',85,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10136,1,1,'CUP',140,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10136,2,3,'oz',85,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10137,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10137,2,1,'cup',140,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10138,1,1,'cup',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10138,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10140,1,1,'cup',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10140,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10141,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10141,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10142,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10142,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10146,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10146,2,1,'patty',65,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10149,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10149,2,1,'slice',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10150,1,1,'cup',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10150,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10152,1,3,'oz',85,'g',1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10152,2,1,'cup',140,'g',1,'1998-01-15','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10153,1,1,'CUP',140,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10153,2,3,'oz',85,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10163,1,3,'oz',85,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10163,2,1,'chop',137,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (10164,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10164,2,1,'chop',170,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (10165,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10165,2,8,'oz',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10166,1,1,'oz',28.35,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10166,2,3,'oz',85,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (10167,1,1,'oz',28.35,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10167,2,3,'oz',85,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (10168,1,1,'CUP',140,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10168,2,3,'oz',85,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10169,1,1,'CUP',140,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10169,2,3,'oz',85,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10170,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10170,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10171,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10171,2,1,'piece, cooked (yield from 1 lb unheated product)',376,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10173,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10174,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10174,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10175,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10175,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',275,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10176,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10176,2,1,'chop',172,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10177,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10177,2,1,'chop',169,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10178,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10178,2,1,'chop',215,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10179,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10179,2,1,'chop',172,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10180,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10180,2,1,'chop',169,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10181,1,1,'chop',142,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10181,2,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (10182,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10182,2,1,'cup',140,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10182,3,1,'slice (6-1/4" x 4" x 1/16") (1 oz)',28,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10183,1,1,'cup',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10183,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10184,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10184,2,1,'cup',140,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10185,1,1,'cup',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10185,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10186,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10186,2,1,'chop',142,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10187,1,1,'oz',28.35,'g',1,'2001-07-04','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10187,2,1,'lb',453.6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10188,1,3,'oz',85,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10188,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',247,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10189,1,3,'oz',85,'g',1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (10189,2,1,'chop',137,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (10192,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10193,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10194,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10194,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 113 g)',101,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10195,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10195,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 113 g)',81,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10196,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10196,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 113 g)',80,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10197,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10197,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 113 g)',75,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10198,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10198,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',317,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10199,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10199,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 113 g)',88,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10200,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10200,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 113 g)',72,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10201,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10201,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 113 g)',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10202,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10202,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 113 g)',66,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10203,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10203,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',283,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10204,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10204,2,1,'rib without refuse (Yield from 1 raw rib, with refuse, weighing 196g)',128,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10205,1,1,'rib without refuse (Yield from 1 cooked rib, with refuse, weighing 140g)',86,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10205,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10206,1,1,'rack',138,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10207,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10207,2,1,'rib',197,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10208,1,1,'rib without refuse (yield from 1 cooked rib, with refuse, weighing 141g)',80,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10208,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10209,1,1,'rack',138,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10210,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10210,2,1,'chop',210,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10211,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10211,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 113 g)',82,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10212,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10212,2,1,'chop',159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10213,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10213,2,1,'roast',638,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10214,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10214,2,1,'chop',210,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10215,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10215,2,1,'chop',161,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10216,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10216,2,1,'chop',159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10217,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10217,2,1,'roast',638,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10218,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10218,2,1,'roast (Yield from 1 raw roast, with refuse, weighing 504g)',505,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10219,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (10219,2,4,'oz',113,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (10220,1,3,'oz',85,'g',1,'1996-09-30','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10221,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10221,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 113 g)',76,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10222,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10222,2,1,'roast',402,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10223,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10223,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 113 g)',73,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10224,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10224,2,1,'roast',2195,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10225,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10225,2,1,'roast',2195,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10226,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10226,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10227,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10227,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',261,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10228,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10228,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10229,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10229,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10858,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10858,2,1,'chop boneless',150,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10859,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10859,2,1,'chop boneless (yield from 189g raw meat)',150,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10860,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10860,2,1,'slice cooked',8.1,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10861,1,1,'slice cooked',9.1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10862,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10862,2,1,'slice',11.5,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10863,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10864,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10865,1,3,'serving (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10865,2,1,'roast rump',2970,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10866,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10867,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10867,2,1,'roast shank',3054,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10868,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10868,2,1,'slice',436,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10869,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10869,2,1,'slice',446,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10870,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10870,2,1,'slice',138,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10871,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10871,2,1,'serving (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10871,3,1,'roast',1995,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10872,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10873,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10873,2,1,'roast rump',2673,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10874,1,1,'serving (3 oz)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10874,2,1,'roast shank',3170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10875,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10875,2,1,'slice',445,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10876,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10876,2,1,'slice',145,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10876,3,1,'roast',920,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10876,4,1,'serving (3 oz)',85,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10877,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10877,2,1,'roast rump',2533,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10878,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10878,2,1,'slice',189,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10879,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10879,2,1,'roast whole',1867,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10880,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10881,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10881,2,1,'roast shank',3204,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10882,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10882,2,1,'slice',277,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10883,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10883,2,1,'roast',1497,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10884,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10884,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10885,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10886,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10887,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10887,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10888,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10889,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10890,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10891,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10892,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10892,2,1,'slice',430,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10893,1,3,'oz spiral slice',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10893,2,1,'lb spiral slice',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10894,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10895,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10898,1,3,'oz',117,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10899,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10899,2,1,'slice',366,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10900,1,3,'oz whole',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10900,2,1,'lb whole',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10901,1,3,'oz spiral slice',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10901,2,1,'lb spiral slice',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10902,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10903,1,3,'oz shank',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10903,2,1,'lb shank',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10904,1,3,'oz rump',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10904,2,1,'lb rump',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10905,1,3,'oz whole',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10905,2,1,'lb whole',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10906,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10906,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10907,1,3,'oz shank',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10907,2,1,'lb shank',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10908,1,3,'oz rump',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10908,2,1,'lb rump',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10909,1,3,'oz whole',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10909,2,1,'lb whole',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10910,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10910,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10911,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10911,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10912,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10912,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10913,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10913,2,1,'roast rump',2970,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10914,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10914,2,1,'roast shank',3054,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10915,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10915,2,1,'slice',436,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10916,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10916,2,1,'slice',189,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10917,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10917,2,1,'roast',1867,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10918,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10918,2,1,'roast rump',2533,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10919,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10919,2,1,'roast shank',3204,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10920,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10920,2,1,'slice',446,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10921,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10921,2,1,'slice',136,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10922,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10922,2,1,'roast',1995,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10923,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10923,2,1,'roast rump',2673,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10924,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10924,2,1,'roast shank',3170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10925,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10925,2,1,'slice',445,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10926,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10926,2,1,'slice',277,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10927,1,1,'slice',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10927,2,1,'roast',920,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10927,3,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10928,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10928,2,1,'roast',1497,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10929,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10929,2,1,'roast rump',2874,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10931,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10931,2,1,'roast rump',2874,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10932,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10932,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10933,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10933,2,1,'roast shank',2800,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10934,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10934,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10935,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10935,2,1,'roast shank',2800,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10936,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10936,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10937,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10937,2,1,'slice',366,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10938,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10938,2,1,'slice',425,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10939,1,3,'oz (3 oz)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10939,2,1,'slice',425,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10940,1,3,'oz',85,'g',1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10942,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10942,2,1,'lb',453,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10943,1,3,'oz',85,'g',1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10944,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10945,1,3,'oz',85,'g',1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10946,1,4,'oz',113,'g',1,'2007-12-03','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10947,1,3,'oz',85,'g',1,'2007-12-03','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10947,2,1,'chop',107,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10948,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10948,2,1,'chop',146,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (10949,1,1,'chop',146,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (10950,1,3,'oz',85,'g',1,'2007-12-03','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10950,2,1,'chop',107,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10951,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10951,2,1,'roast',537,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10952,1,3,'oz',85,'g',1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10952,2,1,'roast',508,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10953,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10953,2,1,'steak',393,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10954,1,3,'oz',85,'g',1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10954,2,1,'steak',264,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10955,1,3,'oz',85,'g',1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10956,1,3,'oz',85,'g',1,'2009-01-25','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10956,2,1,'piece',194,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10957,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10957,2,1,'piece',231,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10958,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10958,2,1,'piece',430,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10959,1,3,'oz',85,'g',1,'2009-01-25','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10959,2,1,'piece',373,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10960,1,1,'piece',92,'g',1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_wght` VALUES (10961,1,1,'piece',105,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10962,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10962,2,1,'piece',609,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10963,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10963,2,1,'piece',765,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10972,1,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10973,1,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10974,1,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10975,1,3,'oz grilled patties',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10976,1,3,'oz grilled patties',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10977,1,3,'oz grilled patties',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10978,1,3,'oz grilled patties',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10979,1,3,'oz grilled patties',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10980,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10980,2,1,'ribs',1071,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (10981,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (10981,2,1,'ribs',878,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (10982,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10982,2,1,'chop',176,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10983,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10983,2,1,'roast',848,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (10984,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10984,2,1,'chop',131,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (10985,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10985,2,1,'rack',122,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10986,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10986,2,1,'rack',122,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10987,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10987,2,1,'rack',138,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10988,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10988,2,1,'chop',131,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10989,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10989,2,1,'chop',176,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10990,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (10990,2,1,'roast',848,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (10991,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10991,2,1,'rack',122,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10992,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10992,2,1,'rack',122,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10993,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10993,2,1,'rack',138,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (10998,1,1,'slice',13.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11001,1,1,'CUP',33,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11001,2,1,'TBSP',3,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11003,1,1,'cup',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11003,2,1,'leaf',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11004,1,1,'cup',132,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11007,1,1,'artichoke, medium',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11007,2,1,'artichoke, large',162,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11008,1,1,'artichoke, medium',120,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11008,2,0.5,'cup hearts',84,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11009,1,0.33,'package',84,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11009,2,1,'package (9 oz)',255,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11010,1,1,'cup',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11010,2,1,'package (9 oz), yields',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11010,3,0.333,'package (9 oz) yields',80,'g',1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_wght` VALUES (11011,1,1,'CUP',134,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11011,2,1,'spear, small (5" long or less)',12,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11011,3,1,'spear, medium (5-1/4" to 7" long)',16,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11011,4,1,'spear, large (7-1/4" to 8-1/2")',20,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11011,5,1,'spear, extra large (8-3/4" to 10" long)',24,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11011,6,1,'spear tip (2" long or less)',3.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11012,1,0.5,'CUP',90,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11012,2,4,'spears (1/2" base)',60,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11013,1,0.5,'CUP',122,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11013,2,1,'can (300 x 407)',411,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11015,1,1,'CUP',242,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11015,2,1,'spear (about 5" long)',18,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11015,3,1,'can (300 x 407)',248,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11018,1,4,'spears',58,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11018,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11019,1,1,'CUP',180,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11019,2,1,'package (10 oz) yields',293,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11019,3,4,'spears',60,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11023,1,1,'cup',58,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11025,1,1,'cup (1/2" pieces)',124,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11025,2,0.5,'cup (1/2" pieces)',62,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11026,1,1,'cup (1/2" slices)',151,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11026,2,0.5,'cup (1/2" pieces)',76,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11027,1,1,'cup (1/2" slices)',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11027,2,1,'shoot',144,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11028,1,1,'cup (1/8" slices)',131,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11028,2,1,'can (303 x 406)',262,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11029,1,1,'cup',184,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11031,1,1,'cup',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11032,1,1,'CUP',170,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11033,1,0.5,'CUP',124,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11033,2,1,'can (303 x 406)',454,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11037,1,1,'cup',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11037,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11038,1,1,'cup',170,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11038,2,1,'package (10 oz) yields',311,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11039,1,1,'cup',164,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11039,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11040,1,1,'cup',180,'g',1,'1999-03-22','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11040,2,1,'package (10 oz) yields',311,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11043,1,1,'cup',104,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11043,2,1,'package (12 oz)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11044,1,1,'cup',124,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11045,1,1,'cup',124,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11046,1,1,'cup',104,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11048,1,0.333,'package (10 oz)',94,'g',1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_wght` VALUES (11048,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11049,1,0.333,'package (10 oz) yields',94,'g',1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_wght` VALUES (11049,2,1,'package (10 oz) yields',284,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11050,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11052,1,1,'cup 1/2" pieces',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11052,2,10,'beans (4" long)',55,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11053,1,1,'CUP',125,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11054,1,1,'cup',240,'g',1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_wght` VALUES (11054,2,1,'can total can contents',423,'g',1,'2002-09-06','2012-03-02');
INSERT INTO `cndb_wght` VALUES (11056,1,1,'cup',135,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (11056,2,10,'beans',62,'g',1,'1994-09-29','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11056,3,1,'can (303 x 406)',262,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11058,1,0.5,'CUP',114,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11058,2,1,'can (303 x 406)',439,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11060,1,1,'CUP',121,'g',1,'1996-09-30','2009-02-11');
INSERT INTO `cndb_wght` VALUES (11060,2,1,'package (10 oz)',284,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11061,1,1,'CUP',135,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11062,1,1,'cup',111,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11080,1,1,'cup',136,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11080,2,1,'beet (2" dia)',82,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11081,1,0.5,'cup slices',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11081,2,2,'beets (2" dia, sphere)',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11082,1,1,'CUP',246,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11084,1,1,'cup, diced',157,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11084,2,1,'cup, shredded',195,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11084,3,1,'cup slices',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11084,4,1,'cup, whole',163,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11084,5,1,'slice',8,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11084,6,1,'beet',24,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11084,7,1,'can (303 x 406)',294,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11086,1,1,'CUP',38,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11086,2,1,'leaf',32,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11086,3,0.5,'cup (1" pieces)',19,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11087,1,1,'cup (1" pieces)',144,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11087,2,0.5,'cup (1" pieces)',72,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11088,1,1,'cup',109,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11088,2,1,'broadbean',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11090,1,1,'cup chopped',91,'g',1,'2009-02-11','2009-02-11');
INSERT INTO `cndb_wght` VALUES (11090,2,1,'bunch',608,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11090,3,1,'spear (about 5" long)',31,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11090,4,1,'stalk',151,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11090,5,0.5,'cup, chopped or diced',44,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11090,6,1,'NLEA serving',148,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11091,1,0.5,'cup, chopped',78,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11091,2,1,'stalk, large (11"-12" long)',280,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11091,3,1,'stalk, medium (7-1/2" - 8" long)',180,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11091,4,1,'stalk, small (5" long)',140,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11091,5,1,'spear (about 5" long)',37,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11092,1,1,'CUP',156,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11092,2,1,'package (10 oz)',284,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11093,1,1,'CUP',184,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11094,1,0.33,'package (10 oz)',95,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11094,2,1,'package (10 oz)',284,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11094,3,1,'package (2 lb)',907,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11095,1,0.5,'cup',92,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11095,2,1,'package (10 oz) yields',250,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11096,1,1,'cup chopped',40,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11096,2,1,'stalk',19,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11097,1,1,'NLEA serving',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11097,2,1,'bunch cooked',437,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11098,1,1,'cup',88,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11098,2,1,'sprout',19,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11099,1,1,'sprout',21,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11099,2,0.5,'CUP',78,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11100,1,0.33,'package (10 oz)',95,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11100,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11100,3,1,'package (2 lb)',907,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11101,1,1,'CUP',155,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11104,1,1,'cup (1" pieces)',118,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11104,2,1,'root',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11105,1,1,'cup (1" pieces)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11105,2,1,'root',166,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11109,1,1,'cup, chopped',89,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11109,2,1,'cup, shredded',70,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11109,3,1,'head, large (about 7" dia)',1248,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11109,4,1,'leaf, large',33,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11109,5,1,'head, medium (about 5-3/4" dia)',908,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11109,6,1,'leaf, medium',23,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11109,7,1,'head, small (about 4-1/2" dia)',714,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11109,8,1,'leaf',15,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11110,1,0.5,'cup, shredded',75,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11110,2,1,'head',1262,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11112,1,1,'cup, chopped',89,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11112,2,1,'cup, shredded',70,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11112,3,1,'head, large (about 5-1/2" dia)',1134,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11112,4,1,'leaf',23,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11112,5,1,'head, medium (about 5" dia)',839,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11112,6,1,'head, small (4" dia)',567,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11113,1,1,'leaf',22,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11113,2,0.5,'cup, shredded',75,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11114,1,1,'cup, shredded',70,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11115,1,1,'cup, shredded',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11116,1,1,'cup, shredded',70,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11116,2,1,'head',840,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11116,3,1,'leaf',14,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11117,1,1,'cup, shredded',170,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11118,1,1,'cup',150,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (11119,1,1,'cup, shredded',76,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11120,1,1,'cup, shredded',119,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11120,2,1,'leaf',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11122,1,1,'cup, shredded',178,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11124,1,1,'cup chopped',128,'g',1,'1994-09-29','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11124,2,1,'cup grated',110,'g',1,'1998-01-15','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11124,3,1,'cup strips or slices',122,'g',1,'1999-03-22','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11124,4,1,'large (7-1/4" to 8-/1/2" long)',72,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11124,5,1,'medium',61,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11124,6,1,'small (5-1/2" long)',50,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11124,7,1,'slice',3,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11124,8,1,'strip large (3" long)',7,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11124,9,1,'strip medium',4,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11125,1,1,'TBSP',9.7,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11125,2,0.5,'cup slices',78,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11125,3,1,'carrot',46,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11126,1,0.5,'cup slices',123,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11126,2,1,'can (303 x 406)',454,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11128,1,1,'cup, sliced',146,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11128,2,1,'cup, mashed',228,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11128,3,1,'slice',2.8,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11128,4,1,'can (303 x 406)',284,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11130,1,0.5,'cup slices',64,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11130,2,1,'package (10 oz)',284,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11131,1,1,'cup, sliced',146,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11134,1,1,'CUP',206,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11134,2,1,'root',408,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11135,1,1,'cup chopped (1/2" pieces)',107,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11135,2,1,'floweret',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11135,3,1,'head large (6-7" dia.)',840,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11135,4,1,'head medium (5-6" dia.)',588,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11135,5,1,'head small (4" dia.)',265,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11136,1,0.5,'cup (1" pieces)',62,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11136,2,3,'flowerets',54,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11137,1,0.5,'cup (1" pieces)',66,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11137,2,1,'package (10 oz)',284,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11138,1,1,'cup (1" pieces)',180,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11141,1,1,'cup',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11143,1,1,'cup chopped',101,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11143,2,1,'NLEA serving',110,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11143,3,1,'TBSP',7.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11143,4,1,'stalk, large (11"-12" long)',64,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11143,5,1,'stalk, medium (7-1/2" - 8" long)',40,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11143,6,1,'stalk, small (5" long)',17,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11143,7,1,'strip (4" long)',4,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11144,1,1,'cup, diced',150,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11144,2,2,'stalks',75,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11147,1,1,'cup',36,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11147,2,1,'leaf',48,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11148,1,1,'cup, chopped',175,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11149,1,1,'cup (1" pieces)',132,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11149,2,1,'chayote (5-3/4")',203,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11150,1,1,'cup (1" pieces)',160,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11151,1,1,'head',53,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11151,2,0.5,'cup',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11152,1,1,'cup, chopped',29,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11154,1,1,'root',60,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11154,2,0.5,'cup (1" pieces)',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11156,1,1,'tbsp chopped',3,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11156,2,1,'tsp chopped',1,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11158,1,1,'cup (1" pieces)',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11161,1,1,'cup, chopped',36,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11162,1,1,'cup, chopped',190,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11163,1,0.33,'package (10 oz)',95,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11163,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11163,3,1,'package (3 lb)',1361,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11164,1,1,'cup, chopped',170,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11165,1,0.25,'cup',4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11165,2,9,'sprigs',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11167,1,1,'cup',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11167,2,1,'ear, large (7-3/4" to 9" long) yields',143,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (11167,3,1,'ear, medium (6-3/4" to 7-1/2" long) yields',102,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11167,4,1,'ear, small (5-1/2" to 6-1/2" long)',73,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (11168,1,1,'ear small (5-1/2" to 6-1/2" long)',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11168,2,1,'ear medium (6-3/4" to 7-1/2" long)',103,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11168,3,1,'ear large (7-3/4" to 9" long)',118,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11168,4,1,'cup cut',149,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11168,5,1,'baby ear',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11170,1,1,'cup',256,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11170,2,1,'can (303 x 406)',482,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11172,1,1,'CUP',164,'g',1,'1994-09-29','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11172,2,1,'can (12 oz) yields',211,'g',1,'1997-08-29','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11172,3,1,'can (303 x 406)',298,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11174,1,1,'CUP',256,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11174,2,1,'can (303 x 406)',482,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11176,1,1,'cup',210,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11176,2,1,'can, 15 oz (303 x 406)',425,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11176,3,1,'can (303 x 406)',340,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11177,1,1,'cup drained, rinsed',150,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11177,2,1,'can drained, rinsed',266,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11178,1,1,'CUP',136,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (11178,2,1,'package',284,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (11179,1,1,'cup',165,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11179,2,1,'package (10 oz) yields',284,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11180,1,1,'cup kernels',165,'g',1,'1996-09-30','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11180,2,1,'ear, yields',125,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11181,1,1,'cup kernels',165,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11181,2,1,'ear, yields',63,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11182,1,1,'cup',141,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11184,1,1,'cup',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11191,1,1,'cup',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11192,1,1,'cup',165,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11195,1,1,'cup',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11195,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11196,1,1,'cup',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11197,1,1,'cup',94,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11197,2,1,'pod',12,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11198,1,1,'cup',95,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11199,1,1,'cup slices',91,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11199,2,1,'pod',12,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11200,1,1,'cup slices',104,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11200,2,1,'pod',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11201,1,1,'cup, chopped',36,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11201,2,1,'leaf',3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11202,1,1,'cup, chopped',53,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11203,1,1,'cup',50,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11203,2,1,'sprig',1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11204,1,1,'cup',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11204,2,0.5,'cup',68,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11205,1,0.5,'cup slices',52,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11205,2,1,'cucumber (8-1/4")',301,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11206,1,1,'cup, pared, chopped',133,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11206,2,1,'cup, sliced',119,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11206,3,1,'large (8-1/4" long)',280,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11206,4,1,'medium',201,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11206,5,1,'slice',7,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11206,6,1,'small (6-3/8" long)',158,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11206,7,1,'stick (4" long)',9,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11207,1,1,'cup, chopped',55,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11208,1,1,'cup, chopped',105,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11209,1,1,'cup, cubes',82,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11209,2,1,'eggplant, peeled (yield from 1-1/4 lb)',458,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11209,3,1,'eggplant, unpeeled (approx 1-1/4 lb)',548,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11210,1,1,'cup (1" cubes)',99,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11212,1,1,'cup',155,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11213,1,0.5,'cup, chopped',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11213,2,1,'head',513,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11214,1,1,'cup',150,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (11215,1,1,'CUP',136,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11215,2,1,'tsp',2.8,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11215,3,1,'clove',3,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11215,4,3,'cloves',9,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11216,1,1,'tsp',2,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11216,2,0.25,'cup slices (1" dia)',24,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11216,3,5,'slices (1" dia)',11,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11218,1,0.5,'cup (1" pieces)',58,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11218,2,1,'gourd',771,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11219,1,1,'cup (1" cubes)',146,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11220,1,1,'cup (1" pieces)',95,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11220,2,1,'gourd',178,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11221,1,1,'cup (1" pieces)',178,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11221,2,0.5,'cup (1" slices)',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11223,1,1,'cup, chopped',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11224,1,1,'cup',80,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11225,1,1,'cup',87,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11226,1,1,'cup slices',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11231,1,1,'cup',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11232,1,1,'cup',87,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11233,1,1,'cup',21,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (11234,1,1,'cup',118,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (11235,1,0.333,'cup',67,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (11235,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (11236,1,1,'cup',118,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (11237,1,1,'strip',6.3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11237,2,0.5,'cup',27,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11240,1,1,'cup',66,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11240,2,1,'piece',12.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11241,1,1,'cup',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11241,2,1,'slice',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11242,1,1,'cup slices',165,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11243,1,1,'cup sliced',121,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11245,1,1,'cup, chopped',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11246,1,1,'CUP',89,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11246,2,1,'leek',89,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11246,3,1,'slice',6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11247,1,1,'leek',124,'g',1,'1998-03-27','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11247,2,0.25,'cup, chopped or diced',26,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11248,1,1,'cup',77,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11250,1,1,'cup, shredded or chopped',55,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11250,2,1,'head (5" dia)',163,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11250,3,1,'leaf, large',15,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11250,4,1,'leaf, medium',7.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11250,5,1,'leaf',5,'g',1,'2005-12-28','2009-02-11');
INSERT INTO `cndb_wght` VALUES (11251,1,1,'cup shredded',47,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11251,2,1,'leaf inner',6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11251,3,1,'leaf outer',28,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11251,4,1,'head',626,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11251,5,1,'NLEA serving',85,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11252,1,1,'cup shredded',72,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11252,2,1,'cup, chopped (1/2" pieces, loosely packed)',57,'g',1,'1997-08-29','2010-03-24');
INSERT INTO `cndb_wght` VALUES (11252,3,1,'head, large',755,'g',1,'2002-09-06','2010-03-24');
INSERT INTO `cndb_wght` VALUES (11252,4,1,'head, medium (6" dia)',539,'g',1,'2002-09-06','2010-03-24');
INSERT INTO `cndb_wght` VALUES (11252,5,1,'head, small',324,'g',1,'2002-09-06','2010-03-24');
INSERT INTO `cndb_wght` VALUES (11252,6,1,'leaf, large',15,'g',1,'2002-09-06','2010-03-24');
INSERT INTO `cndb_wght` VALUES (11252,7,1,'leaf, medium',8,'g',1,'2005-12-28','2010-03-24');
INSERT INTO `cndb_wght` VALUES (11252,8,1,'leaf, small',5,'g',1,'2002-09-06','2010-03-24');
INSERT INTO `cndb_wght` VALUES (11252,9,1,'NLEA Serving',89,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11253,1,1,'cup shredded',36,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11253,2,1,'head',360,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11253,3,1,'leaf inner',4.8,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11253,4,1,'leaf outer',24,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11254,1,10,'slices (2-1/2" dia)',81,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11254,2,1,'root (9-1/2" long)',115,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11255,1,0.5,'cup',60,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11255,2,10,'slices (2-1/2" dia)',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11257,1,1,'cup shredded',28,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11257,2,1,'leaf inner',2.6,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11257,3,1,'leaf outer',17,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11257,4,1,'head',309,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11257,5,1,'NLEA serving',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11258,1,0.5,'cup, cubes',68,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11258,2,1,'yam',420,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11259,1,1,'cup, cubes',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11260,1,1,'cup, pieces or slices',70,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11260,2,1,'cup, whole',96,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11260,3,1,'large',23,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11260,4,1,'medium',18,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11260,5,1,'slice',6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11260,6,1,'small',10,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11260,7,0.5,'cup pieces',35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11261,1,1,'cup pieces',156,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11261,2,1,'tbsp',9.8,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11261,3,1,'mushroom',12,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11263,1,1,'cup sliced',108,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11264,1,1,'CUP',156,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11264,2,1,'can',132,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11264,3,1,'large',16,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11264,4,1,'medium',12,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11264,5,1,'small',7,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11264,6,10,'slices',40,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11264,7,8,'caps',47,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11264,8,0.5,'cup pieces',78,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11265,1,1,'cup diced',86,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11265,2,1,'piece whole',84,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11266,1,1,'cup whole',87,'g',1,'2002-06-08','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11266,2,1,'cup sliced',72,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11266,3,1,'piece whole',20,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11267,1,1,'cup whole',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11267,2,1,'cup sliced',97,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11267,3,1,'piece whole',19,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11268,1,1,'mushroom',3.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11268,2,4,'mushrooms',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11269,1,1,'cup pieces',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11269,2,4,'mushrooms',72,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11270,1,1,'cup, chopped',56,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11271,1,1,'cup, chopped',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11272,1,1,'cup, chopped',146,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11272,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11273,1,1,'cup, chopped',150,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11273,2,1,'package (10 oz) yields',212,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11274,1,1,'cup, chopped',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11276,1,1,'cup, chopped',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11277,1,1,'cup, chopped',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11278,1,1,'cup',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11278,2,8,'pods (3" long)',95,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11279,1,0.5,'cup slices',80,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11279,2,8,'pods (3" long)',85,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11280,1,0.33,'package (10 oz)',95,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11280,2,1,'package (10 oz)',284,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11280,3,1,'package (3 lb)',1361,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11281,1,0.5,'cup slices',92,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11281,2,1,'package (10 oz) yields',255,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11282,1,1,'cup, chopped',160,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11282,2,1,'cup, sliced',115,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11282,3,1,'tbsp chopped',10,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11282,4,1,'large',150,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11282,5,1,'slice, large (1/4" thick)',38,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11282,6,1,'medium (2-1/2" dia)',110,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11282,7,1,'slice, medium (1/8" thick)',14,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11282,8,1,'small',70,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11282,9,1,'slice, thin',9,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11282,10,10,'rings',60,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11283,1,1,'CUP',210,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11283,2,1,'tbsp chopped',15,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11283,3,1,'large',128,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11283,4,1,'slice, large (1/4" thick)',32,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11283,5,1,'medium',94,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11283,6,1,'slice, medium (1/8" thick)',12,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11283,7,1,'small',60,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11283,8,1,'slice, thin',8,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11284,1,1,'TBSP',5,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11284,2,0.25,'CUP',14,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11285,1,1,'onion',63,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11285,2,0.5,'cup, chopped or diced',112,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11286,1,1,'cup chopped',87,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11287,1,0.33,'package (10 oz)',95,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11287,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11288,1,1,'tbsp chopped',15,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11288,2,0.5,'cup, chopped or diced',105,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11289,1,0.33,'package (10 oz)',95,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11289,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11290,1,1,'CUP',210,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11291,1,1,'cup, chopped',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11291,2,1,'tbsp chopped',6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11291,3,1,'large',25,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11291,4,1,'medium (4-1/8" long)',15,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11291,5,1,'small (3" long)',5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11292,1,1,'tbsp',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11292,2,1,'stalk',12,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11292,3,1,'cup chopped',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11295,1,6,'rings',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11295,2,1,'package (16 oz)',454,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11295,3,1,'package (9 oz)',255,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11296,1,1,'CUP',48,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11296,2,10,'rings, large (3-4" dia)',71,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11296,3,10,'rings, medium (2-3" dia)',60,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11296,4,10,'rings, small (1-2" dia)',48,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11297,1,1,'cup chopped',60,'g',1,'1994-09-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11297,2,1,'TBSP',3.8,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11297,3,10,'sprigs',10,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11298,1,1,'cup slices',133,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11299,1,0.5,'cup slices',78,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11299,2,1,'parsnip (9" long)',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11300,1,1,'cup, chopped',98,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11300,2,1,'cup, whole',63,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11300,3,10,'pea pods',34,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11301,1,1,'CUP',160,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11302,1,1,'cup',144,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11302,2,1,'package (10 oz)',284,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11303,1,1,'CUP',160,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11303,2,1,'package (10 oz) yields',253,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11304,1,1,'cup',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11305,1,1,'CUP',160,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11306,1,0.5,'CUP',124,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11306,2,1,'can (303 x 406)',482,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11308,1,1,'CUP',175,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (11308,2,1,'can (303 x 406)',313,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11310,1,1,'CUP',227,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11310,2,0.5,'CUP',114,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11311,1,1,'can',257,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (11311,2,1,'cup',163,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (11312,1,1,'CUP',134,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (11312,2,1,'package',284,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (11313,1,0.5,'CUP',80,'g',1,'1997-08-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (11313,2,1,'package (10 oz) yields',253,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (11316,1,1,'cup',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11318,1,1,'CUP',255,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11322,1,0.5,'CUP',70,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11322,2,1,'package (10 oz)',284,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11323,1,1,'package (10 oz) yields',278,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11323,2,0.5,'CUP',80,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11324,1,1,'CUP',120,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11326,1,0.5,'CUP',69,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11326,2,1,'package (10 oz)',284,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11327,1,1,'CUP',180,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11329,1,1,'pepper',73,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11329,2,0.5,'cup, chopped or diced',68,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11333,1,1,'cup, chopped',149,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11333,2,1,'cup, sliced',92,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11333,3,1,'TBSP',9.3,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11333,4,1,'large (2-1/4 per lb, approx 3-3/4" long, 3" dia)',164,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11333,5,1,'medium (approx 2-3/4" long, 2-1/2" dia)',119,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11333,6,1,'ring (3" dia, 1/4" thick)',10,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11333,7,1,'small',74,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11333,8,10,'strips',27,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11334,1,1,'cup, chopped or strips',135,'g',1,'1994-11-02','2009-02-11');
INSERT INTO `cndb_wght` VALUES (11334,2,1,'tablespoon, chopped',11.6,'g',1,'1997-08-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (11335,1,1,'cup, halves',140,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (11337,1,0.33,'package (10 oz)',95,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11337,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11339,1,1,'cup chopped',115,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11344,1,1,'CUP',154,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11344,2,10,'seeds',4,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11345,1,1,'CUP',153,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11349,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11351,1,1,'cup',165,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11351,2,1,'tbsp',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11352,1,0.5,'cup, diced',75,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11352,2,1,'Potato large (3" to 4-1/4" dia)',369,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11352,3,1,'Potato medium (2-1/4" to 3-1/4" dia)',213,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11352,4,1,'Potato small (1-3/4" to 2-1/2" dia)',170,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11353,1,0.5,'cup, diced',75,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11353,2,1,'potato large (3" to 4-1/4" dia)',369,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11353,3,1,'Potato medium (2-1/4" to 3-1/4" dia)',213,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11353,4,1,'Potato small (1-3/4" to 2-1/4" dia)',170,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11354,1,0.5,'cup, diced',75,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11354,2,1,'large (3" to 4-1/4" dia.)',369,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11354,3,1,'medium (2+-1/4" to 3-1/4" dia.)',213,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11354,4,1,'small (1-3/4" to 2-1/4" dia.)',92,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11355,1,0.5,'cup, diced',75,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11355,2,1,'potato large (3" to 4-1/4" dia)',369,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11355,3,1,'potato medium (2-1/4" to 3-1/4" dia)',213,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11355,4,1,'potato small (1-3/4" to 2-1/4" dia)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11356,1,1,'potato large (3" to 4-1/4" dia.',299,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11356,2,1,'potato medium (2-1/4" to 3-1/4" dia.)',173,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11356,3,1,'potato small (1-3/4" to 2-1/2" dia.)',138,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11357,1,1,'potato large (3" to 4-1/4" dia)',299,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11357,2,1,'potato medium (2-1/4" to 3-1/4" dia)',173,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11357,3,1,'potato small (1-3/4" to 2-1/2" dia)',138,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11358,1,1,'potato large (3" to 4-1/4" dia.',299,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11358,2,1,'potato medium (2-1/4" to 3-1/4" dia.)',173,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11358,3,1,'potato small (1-3/4" to 2-1/2" dia.)',138,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11359,1,10,'strip',82,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11359,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11360,1,10,'strip',69,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11361,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11362,1,1,'skin',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11363,1,0.5,'cup',61,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11363,2,1,'potato (2-1/3" x 4-3/4")',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11364,1,1,'skin',58,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11365,1,0.5,'CUP',78,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11365,2,1,'potato (2-1/2" dia, sphere)',136,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11366,1,1,'skin',34,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11367,1,0.5,'cup',78,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11367,2,1,'large (3" to 4-1/4" dia.)',300,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11367,3,1,'medium (2-1/4" to 3-1/4" dia.)',167,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11367,4,1,'small (1-3/4" to 2-1/2" dia.)',125,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11368,1,0.5,'cup',78,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11368,2,1,'potato (2-1/3" x 4-3/4")',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11369,1,1,'skin',58,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11370,1,1,'cup',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11371,1,1,'cup',210,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11372,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11373,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11374,1,1,'cup, whole',300,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11374,2,1,'can (303 x 406)',454,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11376,1,1,'CUP',180,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11376,2,1,'potato',35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11378,1,1,'CUP',60,'g',1,'1999-03-22','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11379,1,1,'CUP',210,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11380,1,1,'CUP',200,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11381,1,1,'CUP',210,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11382,1,1,'cup',200,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11383,1,1,'CUP',210,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11384,1,0.167,'package (5.5 oz)',26,'g',1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_wght` VALUES (11384,2,1,'package (5.5 oz)',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11385,1,0.167,'package (5.5 oz) yields',137,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11385,2,1,'package yield, 5.5 oz',822,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11386,1,0.167,'package (5.5 oz)',26,'g',1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_wght` VALUES (11386,2,1,'package (5.5 oz)',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11387,1,1,'cup (unprepared)',245,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11387,2,0.167,'package (5.5 oz) yields',137,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11387,3,1,'package yield, 5.5 oz',822,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11390,1,0.5,'cup',105,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11390,2,1,'package (12 oz)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11391,1,1,'cup prepared',150,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11391,2,1,'patty, oval (approx 3" x 1-1/2" x 1/2")',29,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11391,3,1,'package yield, 12 oz',205,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11392,1,1,'package (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11394,1,10,'strip',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11395,1,10,'strip',21,'g',1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11398,1,1,'cup',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11398,2,10,'pieces',91,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11399,1,10,'puffs',79,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11399,2,10,'Crispy Crowns',60,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11399,3,1,'puff',7,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11399,4,1,'cup',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11402,1,10,'strip',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11402,2,1,'package (9 oz)',255,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11403,1,10,'fries',76,'g',1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (11403,2,1,'package (9 oz), yields',198,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11406,1,10,'strips',65,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11406,2,1,'package (9 oz)',255,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11407,1,10,'strips',50,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11407,2,1,'package (9 oz), yields',198,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11408,1,10,'strips',65,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11408,2,1,'package (9 oz)',255,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11409,1,10,'strips',50,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11409,2,1,'package (9 oz), yields',198,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11411,1,10,'strip',153,'g',1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11412,1,10,'strip',133,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11413,1,1,'cup',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11414,1,1,'CUP',250,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11416,1,1,'cup',33,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11416,2,1,'flower',2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11417,1,1,'cup',134,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11418,1,1,'cup',39,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11419,1,1,'cup',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11422,1,1,'cup (1" cubes)',116,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11423,1,1,'cup, mashed',245,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11424,1,1,'CUP',245,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11426,1,1,'CUP',270,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11429,1,1,'cup slices',116,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11429,2,1,'large (1" to 1-1/4" dia)',9,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11429,3,1,'medium (3/4" to 1" dia)',4.5,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11429,4,1,'slice',1,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11429,5,1,'small',2,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11429,6,0.5,'cup slices',58,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11430,1,1,'cup slices',116,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11430,2,1,'radish (7" long)',338,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11431,1,1,'cup, sliced',147,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11432,1,1,'cup',116,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11435,1,1,'cup, cubes',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11435,2,1,'large',772,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11435,3,1,'medium',386,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11435,4,1,'small',192,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11436,1,1,'cup, cubes',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11436,2,1,'cup, mashed',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11438,1,1,'cup, sliced',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11439,1,1,'CUP',142,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11439,2,1,'cup, undrained',236,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11442,1,2,'tbsp (1/8 cup)',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11444,1,2,'tbsp (1/8 cup)',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11445,1,2,'tbsp (1/8 cup)',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11446,1,10,'sheets',26,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11446,2,2,'tbsp (1/8 cup)',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11450,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11451,1,1,'cup',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11452,1,0.5,'CUP',35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11452,2,10,'sprouts',10,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11453,1,1,'cup',94,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11457,1,1,'CUP',30,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11457,2,1,'bunch',340,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11457,3,1,'leaf',10,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11457,4,1,'package (10 oz)',284,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11458,1,1,'CUP',180,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11459,1,1,'CUP',234,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11461,1,1,'CUP',214,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11463,1,1,'CUP',156,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11463,2,1,'package (10 oz)',284,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11464,1,0.5,'cup',95,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11464,2,1,'package (10 oz) yields',220,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11467,1,1,'cup sliced',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11468,1,1,'cup, sliced',180,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11468,2,0.5,'cup slices',90,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11471,1,1,'cup, diced',210,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11471,2,1,'cup, mashed',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11471,3,1,'cup slices',216,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11471,4,1,'slice',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11471,5,1,'can (303 x 406)',241,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11473,1,1,'cup slices',130,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11474,1,1,'cup slices',192,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11475,1,1,'cup slices',130,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11476,1,1,'cup, mashed',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11476,2,1,'cup, sliced',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11477,1,1,'cup, chopped',124,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11477,2,1,'cup, sliced',113,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11477,3,1,'large',323,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11477,4,1,'medium',196,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11477,5,1,'slice',9.9,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11477,6,1,'small',118,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11478,1,1,'cup, sliced',180,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11478,2,0.5,'cup, mashed',120,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11479,1,0.33,'package (10 oz)',95,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11479,2,1,'package (10 oz)',284,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11479,3,1,'package (3 lb)',1361,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11480,1,1,'CUP',223,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11481,1,1,'cup',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11482,1,1,'cup, cubes',140,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11482,2,1,'squash (4 inch dia)',431,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11483,1,1,'cup, cubes',205,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11484,1,1,'cup, mashed',245,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11485,1,1,'cup, cubes',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11486,1,1,'cup, cubes',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11487,1,0.33,'package (12 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11487,2,1,'package (12 oz)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11487,3,1,'package (4 lb)',1814,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11488,1,1,'cup, mashed',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11489,1,1,'cup, cubes',116,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11490,1,1,'cup, cubes',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11491,1,1,'cup, mashed',236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11492,1,1,'cup, cubes',101,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11493,1,1,'cup',155,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11496,1,1,'cup',192,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11497,1,1,'CUP',266,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11499,1,1,'CUP',255,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11501,1,1,'CUP',156,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11501,2,1,'package (10 oz)',284,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11502,1,1,'CUP',170,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11504,1,1,'cup, chopped',98,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11505,1,1,'cup, chopped',35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11505,2,1,'leaf (12-1/4" long)',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11506,1,1,'cup',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11507,1,1,'cup, cubes',133,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11507,2,1,'sweetpotato, 5" long',130,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11508,1,1,'CUP',200,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11508,2,1,'large',180,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11508,3,1,'medium (2" dia, 5" long, raw)',114,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11508,4,1,'small',60,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11510,1,1,'cup, mashed',328,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11510,2,1,'medium',151,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11512,1,1,'cup, mashed',255,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11512,2,1,'cup pieces',200,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11514,1,1,'CUP',255,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11514,2,1,'can (404 x 307)',496,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11516,1,1,'cup, cubes',176,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11517,1,1,'cup, cubes',176,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11518,1,1,'cup, sliced',104,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11519,1,1,'cup, sliced',132,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11520,1,1,'cup',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11520,2,1,'leaf (11" x 6-1/2")',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11521,1,1,'cup',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11522,1,0.5,'cup slices',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11522,2,1,'shoot',83,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11523,1,1,'cup slices',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11525,1,1,'cup slices',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11526,1,1,'cup slices',137,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11527,1,1,'cup',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11527,2,1,'large',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11527,3,1,'medium',123,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11527,4,1,'slice or wedge',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11527,5,1,'small',91,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11529,1,1,'cup cherry tomatoes',149,'g',1,'1994-09-29','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11529,2,1,'cup, chopped or sliced',180,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11529,3,1,'Italian tomato',62,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11529,4,1,'cherry',17,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11529,5,1,'large whole (3" dia)',182,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11529,6,1,'medium whole (2-3/5" dia)',123,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11529,7,1,'slice, medium (1/4" thick)',20,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11529,8,1,'plum tomato',62,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11529,9,1,'small whole (2-2/5" dia)',91,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11529,10,1,'slice, thick/large (1/2" thick)',27,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11529,11,1,'wedge (1/4 of medium tomato)',31,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11529,12,1,'slice, thin/small',15,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11529,13,1,'NLEA serving',148,'g',1,'2004-07-15','2007-03-25');
INSERT INTO `cndb_wght` VALUES (11530,1,1,'CUP',240,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11530,2,2,'medium',246,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11531,1,1,'CUP',240,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11531,2,1,'TBSP',15,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11531,3,1,'can',190,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11531,4,1,'large',164,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11531,5,1,'medium',111,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11531,6,1,'small',82,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11533,1,1,'CUP',255,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11537,1,1,'cup',241,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11540,1,1,'CUP',243,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11540,2,6,'FL OZ',182,'g',1,'1999-03-22','2010-01-05');
INSERT INTO `cndb_wght` VALUES (11546,1,0.25,'cup',66,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11546,2,1,'cup',262,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11546,3,1,'tbsp',16,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11546,4,1,'can (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11547,1,1,'CUP',250,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11547,2,1,'can (29 oz) (401 x 411)',822,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11549,1,1,'CUP',245,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11551,1,1,'CUP',245,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11553,1,1,'CUP',245,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11555,1,0.5,'CUP',122,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11555,2,1,'can, 15 oz (303 x 406)',425,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11557,1,1,'CUP',250,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11557,2,1,'can, 15 oz (303 x 406)',411,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11559,1,1,'CUP',244,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11559,2,1,'can, 15 oz (303 x 406)',425,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11563,1,0.5,'cup, chopped',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11563,2,1,'frond (6-1/2" long)',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11564,1,1,'cup, cubes',130,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11564,2,1,'large',183,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11564,3,1,'medium',122,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11564,4,1,'slice',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11564,5,1,'small',61,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11564,6,0.5,'cup, cubes',65,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11565,1,1,'cup, cubes',156,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11565,2,1,'cup, mashed',230,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11566,1,0.333,'package, mashed (10 oz)',94,'g',1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_wght` VALUES (11566,2,1,'package, mashed (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11567,1,1,'cup',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11568,1,1,'cup, chopped',55,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11569,1,1,'cup, chopped',144,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11570,1,0.5,'CUP',117,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11570,2,1,'can, 15 oz (303 x 406)',425,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11574,1,0.5,'cup, chopped or diced',82,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11574,2,1,'package (10 oz)',284,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11575,1,1,'CUP',164,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11575,2,1,'package (10 oz) yields',220,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11576,1,0.33,'package (10 oz)',95,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11576,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11576,3,1,'package (3 lb)',1361,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11577,1,1,'CUP',163,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11578,1,1,'cup',253,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11578,2,6,'FL OZ',182,'g',1,'1999-03-22','2010-01-05');
INSERT INTO `cndb_wght` VALUES (11579,1,1,'CUP',245,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11581,1,1,'CUP',163,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11583,1,0.33,'package (10 oz)',95,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11583,2,1,'package (10 oz)',284,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11583,3,1,'pack (2-1/2 lb)',1134,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11584,1,0.5,'cup',91,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11584,2,1,'package (10 oz) yields',275,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11585,1,1,'cup',254,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11585,2,6,'fl oz',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11588,1,0.5,'cup slices',62,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11588,2,4,'waterchestnuts',36,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11590,1,0.5,'cup slices',70,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11590,2,4,'waterchestnuts',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11591,1,1,'cup, chopped',34,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11591,2,1,'sprig',2.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11591,3,10,'sprigs',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11593,1,1,'cup, cubes',132,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11593,2,1,'waxgourd',5700,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11594,1,1,'cup, cubes',175,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11595,1,1,'cup slices',44,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11595,2,1,'pod',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11596,1,1,'cup',62,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11601,1,1,'cup, cubes',150,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11602,1,1,'cup, cubes',136,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11602,2,0.5,'cup, cubes',68,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11603,1,1,'cup slices',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11603,2,1,'cup',130,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11603,3,1,'large',1200,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11603,4,1,'medium',659,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11603,5,1,'slice',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11603,6,1,'small',365,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11605,1,1,'cup slices',246,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11609,1,1,'cup slices',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11613,1,1,'cup (1" pieces)',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11615,1,1,'TBSP',0.2,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11615,2,0.25,'CUP',0.8,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11620,1,1,'cup slices',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11620,2,1,'pod (15-1/3" long)',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11621,1,1,'cup slices',118,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11624,1,1,'tbsp',0.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11624,2,0.25,'cup',0.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11626,1,1,'CUP',125,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11632,1,1,'cup, chopped',136,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11632,2,1,'cup, sliced',104,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11632,3,1,'pepper',22,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11637,1,0.5,'cup slices',50,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11637,2,1,'radish (7" long)',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11640,1,1,'tbsp',0.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11640,2,0.25,'cup',3.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11641,1,1,'cup, sliced',113,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11641,2,1,'large',323,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11641,3,1,'medium',196,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11641,4,1,'slice',9.9,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11641,5,1,'small',118,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11642,1,1,'cup, sliced',180,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11643,1,1,'cup, cubes',116,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11644,1,1,'cup, cubes',205,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11645,1,1,'CUP',228,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11645,2,1,'can (404 x 307)',638,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11647,1,1,'CUP',196,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11649,1,1,'CUP',244,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11649,2,1,'can, 15 oz (303 x 406)',425,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11655,1,1,'cup',236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11655,2,1,'fl oz',29.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11656,1,1,'cup',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11656,2,0.667,'cup (#6 scoop)',167,'g',1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_wght` VALUES (11657,1,1,'cup',210,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11658,1,1,'cup',136,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11658,2,1,'recipe yield',813,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11659,1,1,'piece (2-1/2" x 2" dia)',105,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11660,1,1,'cup',101,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11660,2,1,'recipe yield',604,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11667,1,1,'cup',112,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11667,2,1,'tablespoon',7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11669,1,2,'tbsp (1/8 cup)',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11670,1,1,'pepper',45,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11670,2,0.5,'cup, chopped or diced',75,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11671,1,1,'cup',194,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11671,2,1,'recipe yield',1162,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11672,1,1,'small 2-3/4 in. dia., 5/8 in. thick.',22,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11672,2,1,'medium 3-1/4 in. x 3-5/8 in., 5/8 in. thick.',37,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11674,1,1,'NLEA serving',148,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11674,2,1,'potato large',299,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11674,3,1,'potato medium',173,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11674,4,1,'potato small',138,'g',1,'2004-07-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11675,1,1,'potato (2-3/4" dia by 4-3/4" long)',202,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11676,1,1,'cup',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11677,1,1,'tbsp chopped',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11683,1,1,'cup',74,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11693,1,0.5,'cup',121,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11695,1,1,'cup, chopped',158,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11695,2,1,'tomato',111,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11696,1,1,'cup, chopped',139,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11696,2,1,'tomato',212,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11697,1,1,'cup, sliced',120,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11697,2,1,'root',33,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11700,1,1,'cup',132,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11702,1,1,'artichoke, medium',120,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11702,2,0.5,'cup hearts',84,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11703,1,1,'cup',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11703,2,1,'package (9 oz), yields',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11703,3,0.333,'package (9 oz) yields',80,'g',1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_wght` VALUES (11705,1,0.5,'CUP',90,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11705,2,4,'spears (1/2" base)',60,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11707,1,0.5,'cup',122,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11707,2,1,'can (300 x 407)',411,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11709,1,1,'CUP',180,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11709,2,1,'package (10 oz) yields',293,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11709,3,4,'spears',60,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11712,1,1,'cup (1/2" slices)',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11712,2,1,'shoot',144,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11714,1,1,'CUP',170,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11715,1,1,'cup',248,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11715,2,1,'can (303 x 406)',454,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11716,1,1,'cup',180,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11716,2,1,'package (10 oz) yields',311,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11717,1,1,'cup',170,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11717,2,1,'package (10 oz) yields',311,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11718,1,1,'CUP',124,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11720,1,0.333,'package (10 oz) yields',94,'g',1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_wght` VALUES (11720,2,1,'package (10 oz) yields',284,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11722,1,1,'cup 1/2" pieces',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11722,2,10,'beans (4" long)',55,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11723,1,1,'CUP',125,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11724,1,1,'cup',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11725,1,1,'cup',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11726,1,0.5,'cup',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11726,2,1,'can (303 x 406)',439,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11727,1,0.5,'CUP',120,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11727,2,1,'can (303 x 406)',439,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11728,1,0.5,'cup',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11728,2,1,'can (303 x 406)',439,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11729,1,1,'cup',153,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11729,2,10,'beans',62,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11729,3,1,'can (303 x 406)',262,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11730,1,1,'CUP',121,'g',1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_wght` VALUES (11730,2,1,'package (10 oz)',284,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11731,1,1,'CUP',135,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11732,1,1,'cup',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11733,1,1,'cup',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11734,1,0.5,'cup slices',85,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11734,2,2,'beets (2" dia, sphere)',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11735,1,1,'cup',246,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11736,1,1,'cup (1" pieces)',144,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11740,1,1,'cup flowerets',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11740,2,1,'floweret',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11741,1,1,'stalk',114,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11742,1,0.5,'cup, chopped',78,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11742,2,1,'stalk, large (11"-12" long)',280,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11742,3,1,'stalk, medium (7-1/2" - 8" long)',180,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11742,4,1,'stalk, small (5" long)',140,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11742,5,1,'spear (about 5" long)',37,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11743,1,1,'CUP',184,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11744,1,0.5,'cup',92,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11744,2,1,'package (10 oz) yields',250,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11745,1,1,'sprout',21,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11745,2,0.5,'CUP',78,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11746,1,1,'CUP',155,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11749,1,0.5,'cup, shredded',35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11749,2,1,'head',908,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11750,1,0.5,'cup, shredded',35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11750,2,1,'head',908,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11751,1,0.5,'cup, shredded',75,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11751,2,1,'head',1262,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11752,1,1,'leaf',22,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11752,2,0.5,'cup, shredded',75,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11753,1,1,'cup, shredded',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11754,1,1,'cup, shredded',170,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11755,1,1,'cup, shredded',119,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11755,2,1,'leaf',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11757,1,1,'TBSP',9.7,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11757,2,0.5,'cup slices',78,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11757,3,1,'carrot',46,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11758,1,0.5,'cup slices',123,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11758,2,1,'can (303 x 406)',454,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11759,1,1,'cup, sliced',146,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11759,2,1,'cup, mashed',228,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11759,3,1,'slice',2.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11759,4,1,'can (303 x 406)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11760,1,1,'cup slices',146,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11761,1,0.5,'cup (1" pieces)',62,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11761,2,3,'flowerets',54,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11762,1,1,'cup (1" pieces)',180,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11764,1,1,'cup, diced',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11764,2,2,'stalks',75,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11766,1,1,'cup (1" pieces)',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11768,1,1,'cup, chopped',190,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11769,1,1,'cup, chopped',170,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11770,1,1,'ear small (5-1/2" to 6-1/2" long)',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11770,2,1,'ear medium (6-3/4" to 7-1/2" long)',103,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11770,3,1,'ear large (7-3/4" to 9" long)',118,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11770,4,1,'cup',149,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11770,5,1,'baby ear',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11770,6,1,'ear, yields',77,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11771,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11771,2,1,'can (303 x 406)',482,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11772,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11772,2,1,'can (303 x 406)',482,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11773,1,1,'cup',210,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11773,2,1,'can (303 x 406)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11774,1,1,'cup',165,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11774,2,1,'package (10 oz) yields',284,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11775,1,1,'cup kernels',165,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11775,2,1,'ear, yields',63,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11777,1,1,'cup',165,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11778,1,1,'cup',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11779,1,1,'cup',95,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11780,1,1,'cup, chopped',53,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11781,1,1,'cup',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11783,1,1,'cup (1" cubes)',99,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11784,1,1,'cup (1" cubes)',146,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11785,1,1,'cup (1" pieces)',178,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11785,2,0.5,'cup (1" slices)',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11788,1,1,'cup',87,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11789,1,1,'cup',87,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11790,1,1,'cup',118,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (11791,1,1,'cup',118,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (11793,1,1,'cup slices',165,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11794,1,1,'cup, chopped',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11795,1,1,'leek',124,'g',1,'1998-03-27','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11795,2,0.25,'cup, chopped',26,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11796,1,0.5,'cup',60,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11796,2,10,'slices (2-1/2" dia)',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11797,1,1,'cup pieces',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11797,2,1,'tbsp',9.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11797,3,1,'mushroom',12,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11798,1,1,'cup pieces',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11798,2,4,'mushrooms',72,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11799,1,1,'cup, chopped',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11800,1,1,'cup, chopped or diced',150,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11800,2,1,'package (10 oz) yields',212,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11802,1,1,'cup, chopped',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11803,1,0.5,'cup slices',80,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11803,2,8,'pods (3" long)',85,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11804,1,0.5,'cup slices',92,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11804,2,1,'package (10 oz) yields',255,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11805,1,1,'CUP',210,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11805,2,1,'tbsp chopped',15,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11805,3,1,'large',128,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11805,4,1,'slice large (1/4" thick)',32,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (11805,5,1,'medium',94,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11805,6,1,'slice medium (1/8" thick)',12,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11805,7,1,'small',60,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11805,8,1,'slice thin',8,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11806,1,1,'tbsp chopped',15,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11806,2,0.5,'cup, chopped or diced',105,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11807,1,1,'CUP',210,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11808,1,0.5,'cup slices',78,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11808,2,1,'parsnip (9" long)',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11809,1,1,'CUP',160,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11810,1,1,'CUP',160,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11810,2,1,'package (10 oz) yields',253,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11811,1,1,'cup',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11812,1,0.5,'cup',124,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11812,2,1,'can (303 x 406)',482,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11813,1,0.5,'cup',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11813,2,1,'can (303 x 406)',313,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11814,1,0.5,'CUP',80,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (11814,2,1,'package (10 oz) yields',253,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (11816,1,1,'cup',255,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11817,1,0.5,'cup',80,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11817,2,1,'package (10 oz) yields',278,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11818,1,1,'CUP',180,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11819,1,1,'pepper',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11819,2,0.5,'cup, chopped or diced',75,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11820,1,1,'pepper',73,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11820,2,0.5,'cup, chopped or diced',68,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11821,1,1,'cup, chopped',149,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11821,2,1,'cup, sliced',92,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11821,3,1,'tablespoon',9.3,'g',1,'1998-01-15','2015-01-07');
INSERT INTO `cndb_wght` VALUES (11821,4,1,'large (2-1/4 per pound, approx 3-3/4" long, 3" dia.)',164,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11821,5,1,'medium (approx 2-3/4" long, 2-1/2 dia.)',119,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11821,6,1,'small',74,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11821,7,1,'ring (3" dia., 1/4" thick)',10,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11822,1,1,'tbsp',11.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11822,2,1,'pepper',73,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11822,3,0.5,'cup, chopped',92,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11823,1,1,'cup, strips',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11823,2,1,'tbsp',11.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11823,3,0.5,'cup, chopped',68,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11824,1,1,'tbsp',12,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11824,2,1,'pepper',73,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11824,3,0.5,'cup, chopped',92,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11825,1,1,'cup, chopped or strips',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11825,2,1,'tablespoon, chopped',11.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11826,1,1,'CUP',153,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11828,1,0.5,'cup',61,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11828,2,1,'potato large (3" to 4-1/4" dia)',299,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11828,3,1,'potato medium (2-1/4" to 3-1/4" dia)',173,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11828,4,1,'potato small (1-3/4" to 2-1/2" dia)',138,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11828,5,1,'NLEA serving',148,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11829,1,0.5,'cup',61,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11829,2,1,'potato (2-1/3" x 4-3/4")',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11830,1,1,'skin',58,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11831,1,0.5,'CUP',78,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11831,2,1,'potato (2-1/2" dia, sphere)',136,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11832,1,1,'skin',34,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11833,1,0.5,'cup',78,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11833,2,1,'large (3" to 4-1/4" dia.)',300,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11833,3,1,'medium (2-1/4" to 2-1/4" dia.)',167,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11833,4,1,'small (1-3/4" to 2-1/2" dia.)',125,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11834,1,1,'potato (2-1/3" x 4-3/4")',202,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11835,1,0.5,'cup',78,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11835,2,1,'potato (2-1/3" x 4-3/4")',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11836,1,1,'skin',58,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11840,1,10,'strips',50,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11840,2,1,'package (9 oz) yields',198,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11841,1,10,'strip',74,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11842,1,10,'strips',65,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11842,2,1,'package (9 oz)',255,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11843,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11844,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11845,1,1,'cup, mashed',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11846,1,1,'CUP',245,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11847,1,1,'cup',134,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11848,1,1,'cup',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11850,1,1,'cup slices',147,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11851,1,0.5,'cup, mashed',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11853,1,1,'cup',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11854,1,1,'CUP',180,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11855,1,1,'cup',234,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11856,1,0.5,'cup',95,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11856,2,1,'package (10 oz) yields',220,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11857,1,1,'cup slices',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11858,1,1,'cup slices',180,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11859,1,1,'cup slices',192,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11860,1,0.5,'cup slices',90,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11860,2,0.5,'cup, mashed',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11861,1,0.5,'cup slices',90,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11861,2,0.5,'cup, mashed',120,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11862,1,1,'CUP',223,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11863,1,1,'cup, cubes',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11864,1,1,'cup, cubes',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11865,1,1,'cup, mashed',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11866,1,1,'cup, cubes',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11867,1,1,'cup, mashed',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11868,1,1,'cup, cubes',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11869,1,1,'cup, mashed',236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11870,1,1,'cup',155,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11871,1,1,'cup',192,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11872,1,1,'CUP',170,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11874,1,1,'cup',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11875,1,1,'medium (2" dia, 5" long, raw)',114,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11875,2,0.5,'cup, mashed',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11876,1,1,'cup, mashed',328,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11876,2,1,'medium',151,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11877,1,1,'cup, cubes',176,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11878,1,1,'cup slices',132,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11879,1,1,'cup',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11880,1,1,'cup slices',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11881,1,1,'cup slices',137,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11884,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11884,2,0.5,'cup',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11884,3,1,'NLEA serving',121,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11885,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11885,2,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11885,3,1,'can',190,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11885,4,1,'large',164,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11885,5,1,'medium',111,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11885,6,1,'small',82,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11885,7,0.5,'cup',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11886,1,1,'CUP',243,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11886,2,1,'FL OZ',30.4,'g',1,'1997-08-29','2010-01-05');
INSERT INTO `cndb_wght` VALUES (11886,3,6,'FL OZ',182,'g',1,'2007-11-28','2010-01-05');
INSERT INTO `cndb_wght` VALUES (11888,1,1,'CUP',250,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11888,2,1,'can (29 oz) (401 x 411)',822,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11889,1,1,'cup, cubes',156,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11889,2,1,'cup, mashed',230,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11890,1,1,'cup',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11891,1,1,'cup, chopped',144,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11892,1,0.5,'cup',82,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11892,2,1,'package (10 oz) yields',220,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11893,1,1,'CUP',163,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11893,2,0.5,'CUP',86,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11894,1,0.5,'cup',91,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11894,2,1,'package (10 oz) yields',275,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11895,1,1,'cup, cubes',175,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11896,1,1,'cup',62,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11896,2,0.5,'cup',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11897,1,1,'cup, cubes',136,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11897,2,0.5,'cup, cubes',68,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (11899,1,1,'cup slices',104,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11899,2,1,'pod',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11900,1,1,'ear, small (5-1/2" to 6-1/2" long)',73,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11900,2,1,'ear, medium (6-3/4" to 7-1/2" long)',90,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11900,3,1,'ear, large (7-3/4" to 9" long)',143,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11900,4,1,'cup kernels',154,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11901,1,1,'ear, small (5-1/2" to 6-1/2" long)',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11901,2,1,'ear, medium (6-3/4" to 7-1/2" long)',103,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11901,3,1,'ear, large (7-3/4" to 9" long)',116,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11901,4,1,'cup cut',157,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11901,5,1,'ear, yields',77,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11902,1,1,'ear, small (5-1/2" to 6-1/2" long)',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11902,2,1,'ear, medium (6-3/4" to 7-1/2" long)',103,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11902,3,1,'ear, large (7-3/4" to 9" long)',118,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11902,4,1,'cup cut',157,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11902,5,1,'ear, yields',77,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11903,1,1,'cup',256,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11903,2,1,'can (303 x 406)',482,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11904,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11904,2,1,'can (303 x 406)',482,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11905,1,1,'CUP',164,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11905,2,1,'can (303 x 406)',298,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11906,1,1,'CUP',256,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11906,2,1,'can (303 x 406)',482,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11907,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11907,2,1,'can (303 x 406)',482,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11908,1,1,'cup',210,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11908,2,1,'can (303 x 406)',340,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11909,1,1,'cup',210,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11909,2,1,'can (303 x 406)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11910,1,1,'cup',165,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11910,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11911,1,1,'cup',165,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11911,2,1,'package (10 oz) yields',284,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11912,1,1,'cup',165,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11912,2,1,'package (10 oz) yields',284,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11913,1,1,'cup kernels',165,'g',1,'1996-09-30','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11913,2,1,'ear, yields',125,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11914,1,1,'cup kernels',165,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11914,2,1,'ear, yields',63,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11915,1,1,'cup kernels',165,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11915,2,1,'ear, yields',63,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (11916,1,1,'cup, halves',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11916,2,0.5,'cup, halves',70,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11917,1,0.33,'package (10 oz)',95,'g',1,'1996-09-30','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11917,2,1,'package (10 oz)',284,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11918,1,1,'cup, chopped or strips',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11918,2,1,'tablespoon, chopped',11.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11919,1,1,'cup, chopped or strips',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11919,2,1,'tablespoon, chopped',11.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11921,1,1,'cup chopped',106,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11923,1,1,'cup',94,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11927,1,1,'cup, cubes',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11929,1,1,'CUP',210,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11930,1,1,'CUP',210,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11931,1,1,'tbsp',0.4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11931,2,0.25,'cup',1.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11932,1,1,'cup',153,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11932,2,10,'beans',62,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11932,3,1,'can (303 x 406)',262,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11933,1,1,'cup',153,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11933,2,10,'beans',62,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11933,3,1,'can (303 x 406)',262,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11934,1,1,'cup',210,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11935,1,1,'tbsp',17,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11935,2,1,'packet',9,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11935,3,1,'cup',240,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11936,1,1,'cup whole',87,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (11936,2,1,'cup sliced',72,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (11936,3,1,'piece whole',20,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (11937,1,1,'spear, small',35,'g',1,'1994-09-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (11937,2,1,'slice',7,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (11937,3,1,'large (4" long)',135,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11937,4,1,'cup, chopped or diced',143,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (11937,5,1,'cup (about 23 slices)',155,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (11938,1,1,'cup pieces or slices',70,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (11938,2,1,'cup whole',96,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (11938,3,1,'large',23,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (11938,4,1,'slice',6,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (11938,5,1,'medium',18,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (11938,6,1,'small',10,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (11939,1,1,'cup sliced',121,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11940,1,1,'cup, chopped',160,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11940,2,1,'cup sliced or chips',153,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11940,3,1,'large Gherkin (3" long)',35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11940,4,1,'Gherkin (2-3/4" long)',25,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11940,5,1,'midget Gherkin (2-1/8" long)',6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11940,6,1,'chip',7.5,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (11940,7,1,'small Gherkin (2-1/2" long)',15,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11940,8,1,'spear Gherkin',20,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11941,1,1,'CUP',155,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11941,2,1,'large (4" long)',135,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11941,3,1,'medium (3-3/4" long)',65,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11941,4,1,'slice',7,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11941,5,1,'small',37,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11941,6,1,'spear',30,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11943,1,1,'tbsp',12,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11943,2,1,'cup',192,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11943,3,1,'slice',1,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11943,4,1,'pimiento, whole',66,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11944,1,1,'TBSP',15,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11944,2,0.5,'CUP',122,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11945,1,1,'tbsp',15,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11945,2,1,'packet (2/3 tbsp)',10,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11945,3,1,'cup',245,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11946,1,1,'cup, chopped or diced',143,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11946,2,1,'cup (about 23 slices)',155,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11946,3,1,'large (4" long)',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11946,4,1,'medium (3-3/4" long)',65,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11946,5,1,'slice',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11946,6,1,'small',37,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11946,7,1,'spear',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11947,1,1,'spear, small',35,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (11947,2,1,'slice',7,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (11947,3,1,'large (4" long)',135,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11947,4,1,'cup, chopped or diced',143,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11947,5,1,'cup, (about 23 slices)',155,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (11948,1,1,'slice',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11948,2,1,'medium',35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11948,3,1,'small',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11948,4,1,'large',35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11948,5,1,'cup, sliced',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11948,6,1,'cup, chopped or diced',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11949,1,1,'tbsp',17,'g',1,'1994-11-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11949,2,1,'packet',9,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11949,3,1,'cup',240,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (11950,1,1,'large',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11950,2,1,'medium',3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11950,3,1,'cup whole',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11950,4,1,'cup sliced',65,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11951,1,1,'pepper, large (3-3/4" long, 3" dia)',186,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11951,2,10,'strips',52,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11952,1,1,'cup, shredded',40,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11952,2,1,'leaf',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11953,1,1,'large',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11953,2,1,'medium',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11954,1,1,'medium',34,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11954,2,0.5,'cup, chopped or diced',66,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11955,1,1,'CUP',54,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11955,2,1,'piece',2,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11956,1,1,'cup',110,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11956,2,1,'piece',3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11957,1,1,'cup, sliced',87,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11957,2,1,'bulb',234,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11958,1,1,'TBSP',15,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11958,2,0.5,'CUP',122,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11959,1,1,'leaf',2,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11959,2,0.5,'CUP',10,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11960,1,1,'large',15,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11960,2,1,'medium',10,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11960,3,1,'NLEA serving',85,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11961,1,1,'cup',146,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11961,2,1,'piece',33,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11962,1,1,'cup',37,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11962,2,1,'pepper',0.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11963,1,1,'cup, sliced',86,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11964,1,1,'cup',149,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11964,2,1,'pad',29,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11965,1,1,'cup',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11965,2,1,'floweret',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11965,3,1,'head, large (6-7" dia)',511,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11965,4,1,'head, medium (5-6" dia)',431,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11965,5,1,'head, small (4" dia)',325,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11967,1,0.2,'head',90,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11968,1,0.5,'cup (1" pieces)',62,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11969,1,1,'CUP',88,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11972,1,1,'cup',67,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11972,2,1,'tbsp',4.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11973,1,1,'cup',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11973,2,1,'pod',6.1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11974,1,1,'CUP',14,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11974,2,1,'leaf',3,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11975,1,1,'leaf',4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11976,1,1,'cup',124,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11976,2,1,'small (4" long)',33,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11976,3,1,'medium (4-1/2" long)',46,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11976,4,1,'large (5" long)',75,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11977,1,1,'cup, chopped',105,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11977,2,1,'pepper',6.1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11978,1,1,'pepper',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11979,1,1,'cup, sliced',90,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11979,2,1,'pepper',14,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11980,1,1,'CUP',139,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11981,1,1,'pepper',27,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11983,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11987,1,1,'large',148,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11987,2,1,'small',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11987,3,1,'cup sliced',86,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11989,1,1,'CUP',182,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11989,2,1,'piece',5.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11991,1,1,'cup, sliced',135,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11991,2,1,'root',305,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (11993,1,1,'cup diced',70,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11993,2,1,'piece whole',1.1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11998,1,1,'cup diced',86,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (11998,2,1,'piece whole',84,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12001,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12003,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12004,1,1,'oz (8-14 seeds)',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12005,1,1,'cup',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12005,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12006,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12007,1,1,'cup',94,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12007,2,1,'tbsp',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12008,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12011,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12012,1,3,'tbsp',30,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (12013,1,1,'cup',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12013,2,1,'oz (42 medium seeds)',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12014,1,1,'cup',129,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12014,2,1,'OZ',28.35,'g',1,'2002-09-06','2010-01-04');
INSERT INTO `cndb_wght` VALUES (12016,1,1,'cup',118,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12016,2,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12021,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12022,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12023,1,1,'CUP',144,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12023,2,1,'TBSP',9,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12024,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12029,1,1,'CUP',128,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12029,2,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12032,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12033,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12034,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12036,1,1,'cup, with hulls, edible yield',46,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12036,2,1,'CUP',140,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (12037,1,1,'cup',128,'g',1,'1999-03-22','2011-01-18');
INSERT INTO `cndb_wght` VALUES (12037,2,1,'oz',28.35,'g',1,'1994-10-18','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12038,1,1,'CUP',135,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12038,2,1,'oz',28.35,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12039,1,1,'CUP',134,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12039,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12040,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12040,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12041,1,1,'cup',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12041,2,1,'tbsp',4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12058,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12059,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12060,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12061,1,1,'cup, whole',143,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (12061,2,1,'cup, sliced',92,'g',1,'1994-09-29','2007-03-25');
INSERT INTO `cndb_wght` VALUES (12061,3,1,'cup, slivered',108,'g',1,'1998-01-15','2007-03-25');
INSERT INTO `cndb_wght` VALUES (12061,4,1,'cup, ground',95,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (12061,5,1,'oz (23 whole kernels)',28.35,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (12061,6,1,'almond',1.2,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (12062,1,1,'cup whole kernels',145,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12062,2,1,'TBSP',9.1,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12062,3,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12063,1,1,'cup whole kernels',138,'g',1,'1994-10-19','2007-03-25');
INSERT INTO `cndb_wght` VALUES (12063,2,1,'oz (22 whole kernels)',28.35,'g',1,'1999-03-22','2007-03-25');
INSERT INTO `cndb_wght` VALUES (12065,1,1,'cup whole kernels',157,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12065,2,1,'oz (22 whole kernels)',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12071,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12071,2,1,'cup, firmly packed',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12077,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12078,1,1,'cup, whole',133,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12078,2,1,'kernel',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12078,3,1,'oz (6 kernels)',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12084,1,1,'cup',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12084,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12084,3,1,'nutmeat',3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12085,1,1,'cup, halves and whole',137,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12085,2,1,'TBSP',8.6,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12085,3,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12086,1,1,'cup, whole',129,'g',1,'1994-10-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12086,2,1,'cup, halves and pieces',129,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12086,3,1,'oz (18 kernels)',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12087,1,1,'oz',28.35,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (12088,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12088,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12093,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12094,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12095,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12096,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12097,1,1,'cup',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12097,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12098,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12099,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12100,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12101,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12104,1,1,'cup, shredded',80,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12104,2,1,'medium',397,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12104,3,1,'piece (2" x 2" x 1/2")',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12108,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12109,1,1,'CUP',85,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12109,2,1,'oz',28.35,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12110,1,1,'CUP',77,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12110,2,4,'oz',114,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12114,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12115,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12115,2,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12116,1,1,'tbsp',19,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12116,2,1,'cup',296,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12117,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12117,2,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12118,1,1,'cup',226,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12118,2,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12119,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12119,2,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12119,3,1,'coconut yields',206,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12120,1,1,'cup, chopped',115,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12120,2,1,'cup, ground',75,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12120,3,1,'cup, whole',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12120,4,1,'oz (21 whole kernels)',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12120,5,10,'nuts',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12121,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12122,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12127,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12128,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12129,1,1,'cup (78 kernels)',155,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12129,2,1,'oz (14 kernels)',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12130,1,1,'cup',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12130,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12130,3,1,'nut',3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12131,1,1,'cup, whole or halves',134,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12131,2,1,'oz (10-12 kernels)',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12132,1,1,'cup, whole or halves',132,'g',1,'2002-06-08','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12132,2,1,'oz (10-12 kernels)',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12135,1,1,'cup',131,'g',1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_wght` VALUES (12135,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12137,1,1,'cup',134,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12137,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12138,1,1,'cup',144,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12138,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12140,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12142,1,1,'cup, chopped',109,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12142,2,1,'cup, halves',99,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12142,3,1,'oz (19 halves)',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12143,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12144,1,1,'CUP',110,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12144,2,1,'oz (15 halves)',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12145,1,1,'cup',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12145,2,1,'oz (15 kernels)',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12147,1,1,'cup',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12147,2,1,'oz (167 kernels)',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12147,3,10,'nuts',1.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12149,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12149,2,10,'nuts',1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12151,1,1,'cup',123,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12151,2,1,'oz (49 kernels)',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12151,3,1,'kernel',0.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12152,1,1,'cup',123,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12152,2,1,'oz (49 kernels)',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12152,3,1,'kernel',0.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12154,1,1,'cup, chopped',125,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12154,2,1,'TBSP',7.8,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12154,3,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12155,1,1,'cup, chopped',117,'g',1,'1999-03-22','2007-03-25');
INSERT INTO `cndb_wght` VALUES (12155,2,1,'cup, ground',80,'g',1,'1995-06-19','2007-03-25');
INSERT INTO `cndb_wght` VALUES (12155,3,1,'cup, in shell, edible yield (7 nuts)',28,'g',1,'1998-01-15','2007-03-25');
INSERT INTO `cndb_wght` VALUES (12155,4,1,'cup shelled (50 halves)',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (12155,5,1,'cup pieces or chips',120,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (12155,6,1,'oz (14 halves)',28.35,'g',1,'2002-09-06','2007-03-25');
INSERT INTO `cndb_wght` VALUES (12156,1,1,'oz',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12157,1,1,'oz',28,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (12158,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12160,1,1,'cup',149,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12160,2,1,'tbsp',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12163,1,1,'cup',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12163,2,1,'oz (85 seeds)',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12166,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12166,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12167,1,1,'cup',143,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12167,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12167,3,10,'kernels',84,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12169,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12170,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12171,1,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12171,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12174,1,1,'cup',108,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12174,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12175,1,1,'cup',155,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12175,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12176,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12176,2,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12177,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12179,1,1,'cup, shredded',93,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12179,2,1,'package (7 oz)',199,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12193,1,1,'cup',74,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12193,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12195,1,1,'tbsp',16,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (12195,2,1,'cup',250,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (12198,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12198,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12200,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12201,1,1,'CUP',150,'g',1,'1995-06-13','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12201,2,1,'TBSP',8,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12201,3,1,'tsp',2.7,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12202,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12203,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12204,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12205,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12206,1,1,'cup whole kernels',144,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12206,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12220,1,1,'tbsp, whole',10.3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12220,2,1,'cup, whole',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12220,3,1,'tbsp, ground',7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12220,4,1,'tsp, whole',3.4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12220,5,1,'tsp, ground',2.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12516,1,1,'cup',118,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12516,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12529,1,1,'cup',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12529,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12536,1,1,'cup',128,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (12536,2,1,'oz',28.35,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (12536,3,1,'package (1.875 oz) yields',27,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (12537,1,1,'CUP',128,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12537,2,1,'oz',28.35,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12538,1,1,'CUP',135,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12538,2,1,'oz',28.35,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12539,1,1,'CUP',134,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12539,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12540,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12540,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12563,1,1,'cup whole kernels',138,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12563,2,1,'oz (22 whole kernels)',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12565,1,1,'cup whole kernels',157,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12565,2,1,'oz (22 whole kernels)',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12567,1,1,'oz (28 almonds)',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12585,1,1,'cup, halves and whole',137,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12585,2,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12586,1,1,'cup, whole',129,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12586,2,1,'cup, halves and pieces',129,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12586,3,1,'oz (18 kernels)',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12588,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12588,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12632,1,1,'cup, whole or halves',132,'g',1,'2002-06-08','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12632,2,1,'oz (10-12 kernels)',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12635,1,1,'CUP',137,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12635,2,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12637,1,1,'cup',134,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12637,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12637,3,10,'nuts, assorted',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12638,1,1,'cup',144,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12638,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12643,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12644,1,1,'CUP',110,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12644,2,1,'oz (15 halves)',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12652,1,1,'cup',123,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12652,2,1,'oz (49 kernels)',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12652,3,1,'kernel',0.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12663,1,1,'cup',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12663,2,1,'oz (85 seeds)',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (12665,1,1,'cup whole kernels',157,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (12665,2,1,'oz (22 whole kernels)',28.35,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (12695,1,1,'tbsp',16,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (12695,2,1,'cup',250,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (12698,1,1,'TBSP',15,'g',1,'2002-06-08','2006-11-30');
INSERT INTO `cndb_wght` VALUES (12737,1,1,'oz',28.35,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (12738,1,1,'oz',28.35,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (13000,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13000,2,1,'steak',214,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13001,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13001,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13002,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13002,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13019,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13019,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13020,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13020,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13023,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13023,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13047,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13047,2,1,'serving',85,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13055,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13055,2,1,'steak',350,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13065,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13065,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13065,3,1,'steak',202,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13066,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13066,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',262,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13067,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13067,2,1,'steak (yield from 483 g raw meat)',387,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13068,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13068,2,1,'steak',202,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13069,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13069,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',246,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13070,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13070,2,1,'steak',387,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13095,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13095,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13096,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13096,2,1,'steak (yield from 297 g raw meat)',236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13097,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13097,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13098,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13098,2,1,'steak (yield from 297g raw meat)',236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13147,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13147,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13148,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13148,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',225,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13149,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13149,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13150,1,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',121,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13150,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13156,1,3,'oz',85,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13156,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',285,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13158,1,3,'oz',85,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13158,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',282,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13165,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13165,2,1,'steak (Yield from 448 g raw meat)',293,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13227,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13227,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13228,1,3,'oz',85,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13228,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',170,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13231,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13231,2,1,'steak',539,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13232,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13232,2,1,'steak',417,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13235,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13235,2,1,'steak',461,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13236,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13236,2,1,'steak',360,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13284,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13285,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13285,2,1,'roast',647,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13293,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13293,2,1,'steak',679,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13293,3,1,'roast',960,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13294,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13294,2,1,'steak',648,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13294,3,1,'roast',949,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13317,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13317,2,1,'unit, cooked (yield from 1 lb raw meat)',313,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13318,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13318,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13319,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13319,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',351,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13320,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13320,2,1,'piece, cooked, excluding refuse',391,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13321,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13321,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13322,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13323,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13323,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13324,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13325,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13326,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13326,2,1,'slice',68,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13327,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13327,2,1,'slice',81,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13328,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13328,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13329,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13329,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',303,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13330,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13330,2,8,'oz',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13331,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13331,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13332,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13332,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',222,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13333,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13333,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13334,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13334,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',308,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13335,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13335,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13337,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13337,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13338,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13338,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',381,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13339,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13339,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13340,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13341,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13341,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13342,1,4,'oz',113,'g',1,'2002-06-08','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13342,2,1,'steak',56,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13342,3,1,'package',396,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13343,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13343,2,1,'steak',293,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13344,1,3,'slices',68,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13344,2,1,'package (net weight, 12 oz)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13345,1,3,'slices',34,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (13345,2,1,'package, cooked (yield from 12 oz raw product)',170,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (13346,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (13346,2,1,'lb',453.6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (13347,1,3,'oz',85,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13347,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',320,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13348,1,1,'oz',28.35,'g',1,'1999-03-22','2009-02-11');
INSERT INTO `cndb_wght` VALUES (13348,2,1,'slice (3/4 oz)',21,'g',1,'1995-06-19','2009-02-11');
INSERT INTO `cndb_wght` VALUES (13349,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13349,2,1,'steak',732,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13349,3,1,'roast',977,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13350,1,10,'slices',28,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (13351,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13351,2,1,'steak',353,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13352,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13352,2,1,'steak',356,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13353,1,1,'slice (1 oz) (4" x 4" x 3/32" thick)',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13354,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13354,2,1,'steak',349,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13355,1,1,'package, 2.5 oz',71,'g',1,'1999-03-22','2009-02-11');
INSERT INTO `cndb_wght` VALUES (13355,2,1,'slice (1 oz)',28,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (13356,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13356,2,1,'steak',473,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13357,1,1,'sausage',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13357,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13358,1,1,'slice (1 oz)',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13359,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13359,2,1,'steak',483,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13361,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13362,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13363,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13364,1,3,'oz',85,'g',1,'2004-07-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13365,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13366,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13367,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13367,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',314,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13368,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13368,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',264,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13369,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13369,2,1,'steak (Yield from 418 g raw meat)',270,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13370,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13370,2,1,'steak (yield from 418g raw meat)',270,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13371,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13371,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',314,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13372,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13372,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',232,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13373,1,3,'oz',85,'g',1,'2006-02-23','2011-01-18');
INSERT INTO `cndb_wght` VALUES (13373,2,1,'roast (yield from 1601 g raw meat)',1166,'g',1,'2006-02-23','2011-01-18');
INSERT INTO `cndb_wght` VALUES (13375,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13375,2,1,'roast (yield from 1675 g raw meat)',1236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13377,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13377,2,1,'roast (yield from 1528g raw meat)',1095,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13378,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13378,2,1,'roast (yield from 1675 g raw meat)',1236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13379,1,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',235,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13379,2,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13380,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13380,2,1,'roast',658,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13381,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13381,2,1,'roast',629,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13382,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13382,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',191,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13383,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13383,2,1,'roast',658,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13384,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13384,2,1,'roast',629,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13386,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13386,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',290,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13387,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13387,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',286,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13388,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13388,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',214,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13389,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13389,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',207,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13390,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13390,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',217,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13391,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13391,2,1,'steak (yield from 233 g raw meat)',233,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13392,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13392,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',272,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13393,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13393,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',265,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13394,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13394,2,1,'steak (yield from 296 g raw meat)',233,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13395,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13395,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',220,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13396,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13396,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',220,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13398,1,3,'oz',85,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13398,2,1,'steak (yield from 290 g raw meat)',185,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13399,1,3,'oz',85,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13399,2,1,'roast (yield from 600 g raw meat)',489,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13401,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13401,2,1,'steak (yield from 299 g raw meat)',191,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13402,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13402,2,1,'roast (yield from 627 g raw meat)',515,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13404,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13404,2,1,'steak (yield from 281 g raw meat)',179,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13405,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13405,2,1,'roast (yield from 572 g raw meat)',464,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13407,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13407,2,1,'steak (yield from 290 g raw meat)',185,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13408,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13408,2,1,'roast (yield from 600 g raw meat)',489,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13410,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13410,2,1,'steak (yield from 299 g raw meat)',191,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13411,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13411,2,1,'roast (yield from 627 g raw meat)',515,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13413,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13413,2,1,'steak (yield from 281 g raw meat)',179,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13414,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13414,2,1,'roast (yield from 572 g raw meat)',464,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13415,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13415,2,1,'roast (yield from 436 g raw meat)',346,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13415,3,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',333,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13416,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13416,2,1,'roast (yield from 445 g raw meat)',355,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13417,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13417,2,1,'roast (yield from 426 g raw meat)',337,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13418,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13418,2,1,'roast (yield from 436 g raw meat)',346,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13418,3,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',330,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13419,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13419,2,1,'roast (yield from 445 g raw meat)',355,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13419,3,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',331,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13420,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13420,2,1,'roast (yield from 426 g raw meat)',337,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13420,3,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',296,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13421,1,3,'oz',85,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13421,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',330,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13422,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13422,2,1,'roast (yield from 1405 g raw meat)',1138,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13423,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13423,2,1,'roast (yield from 1388 g raw meat)',1141,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13424,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13424,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',320,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13425,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13425,2,1,'roast (yield from 1405 g raw meat)',1138,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13426,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13426,2,1,'roast (yield from 1388 g raw meat)',1141,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13428,1,3,'oz',85,'g',1,'1996-09-30','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13428,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',267,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13430,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13430,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',267,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13432,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13432,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',267,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13436,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13436,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',261,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13438,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13438,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',261,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13439,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13439,2,1,'steak',117,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13440,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13440,2,1,'steak (yield from 161 g raw meat)',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13441,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13441,2,1,'steak (yield from 136 g raw meat)',108,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13442,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13442,2,1,'steak',119,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13443,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13443,2,1,'steak',121,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13444,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13444,2,1,'steak',117,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13445,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13445,2,1,'steak',119,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13446,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13446,2,1,'steak (yield from 203 g raw meat)',164,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13447,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13447,2,1,'steak (yield from 186 g raw meat)',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13448,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13448,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 223 g)',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13449,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13449,2,1,'steak (yield from 203 g raw meat)',164,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13450,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13450,2,1,'steak (yield from 186 g raw meat)',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13451,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13451,2,1,'steak (yield from 518 g raw meat)',384,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13452,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13452,2,1,'steak (yield from 532 g raw meat)',393,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13453,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13453,2,1,'steak (yield from 505 g raw meat)',375,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13454,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13454,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',292,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13455,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13455,2,1,'steak (yield from 532 g raw meat)',393,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13456,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13456,2,1,'steak (yield from 505 g raw meat)',375,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13459,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13459,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13460,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13460,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13463,1,3,'oz ( 1serving )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13463,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13464,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13464,2,1,'steak',534,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13465,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13465,2,1,'steak',421,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13466,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13466,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13467,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13467,2,1,'serving',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13467,3,1,'piece, cooked, excluding refuse',266,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13468,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13468,2,1,'steak',526,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13469,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13469,2,1,'steak',426,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13470,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13470,2,1,'serving',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13470,3,1,'piece, cooked, excluding refuse',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13473,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13473,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13474,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13474,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13477,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13477,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13478,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13478,2,1,'steak',460,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13479,1,3,'oz',85,'g',1,'2010-01-04','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13479,2,1,'steak',363,'g',1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13481,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13481,2,1,'serving',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13481,3,1,'piece, cooked, excluding refuse',271,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13482,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13482,2,1,'steak',458,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13483,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13483,2,1,'steak',368,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13484,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13484,2,1,'serving',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13484,3,1,'piece, cooked, excluding refuse',264,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13485,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13485,2,1,'steak',247,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13486,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13486,2,1,'roast',1289,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13487,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13487,2,1,'roast',1392,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13488,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13488,2,1,'roast',1187,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13490,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13490,2,1,'steak',231,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13491,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13491,2,1,'steak',277,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13492,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13492,2,1,'steak',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13493,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (13493,2,1,'steak',269,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (13494,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (13494,2,1,'portion (yield from 1/2 lb raw meat )',139,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13495,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (13495,2,1,'loaf ( yield from 1 lb raw meat )',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13496,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (13496,2,1,'patty',77,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13497,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (13497,2,1,'patty',70,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13498,1,4,'oz',113,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (13498,2,1,'oz',28.35,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13499,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13499,2,1,'steak',458,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13500,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13500,2,1,'steak',186,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13501,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13501,2,1,'steak',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13502,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13502,2,1,'steak',199,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13519,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13519,2,1,'steak',1438,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13520,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13520,2,1,'steak',1432,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13523,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13523,2,1,'steak',1446,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13595,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13595,2,1,'piece',1855,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13596,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13596,2,1,'piece',1780,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13597,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13597,2,1,'piece',1967,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13598,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13598,2,1,'steak',186,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13647,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13647,2,1,'steak',1027,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13647,3,1,'roast',1316,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13648,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13649,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13649,2,1,'steak',1106,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13649,3,1,'roast',1320,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13650,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13650,2,1,'steak',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13786,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13786,2,1,'roast',723,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13788,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13788,2,1,'roast',698,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13791,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13791,2,1,'roast',761,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13795,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13796,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13797,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13798,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13799,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13800,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13803,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13803,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13804,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13804,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',329,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13805,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13805,2,1,'steak',452,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13806,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13806,2,1,'steak (yield from raw steak weighing 550 g)',380,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13807,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13807,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13808,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13808,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',332,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13809,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13809,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13810,1,3,'oz',85,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13810,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',258,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13811,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13811,2,1,'roast',1801,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13811,3,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13812,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13812,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',258,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13813,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13813,2,1,'roast',1783,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13813,3,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13814,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13814,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',257,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13815,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13815,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13816,1,3,'oz',85,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13816,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',247,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13817,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13817,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13818,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13818,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',247,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13819,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13819,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13820,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13820,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',247,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13821,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13821,2,1,'roast',609,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13822,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13822,2,1,'roast',586,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13823,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13823,2,1,'roast',645,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13824,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13824,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13825,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13825,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',267,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13826,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13826,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',289,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13827,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13827,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13828,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13828,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',267,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13829,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13829,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',289,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13830,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13830,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13831,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13831,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',264,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13832,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13832,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',289,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13833,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13833,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13834,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13834,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',274,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13835,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13835,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',278,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13838,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13838,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13839,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13839,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',267,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13840,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13840,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',292,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13841,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13841,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13842,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13842,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',267,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13843,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13843,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',296,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13844,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13844,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13845,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13845,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',267,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13846,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13846,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',292,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13847,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13847,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13848,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13848,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',278,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13849,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13849,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',281,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13850,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13850,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13851,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13851,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',268,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13852,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13852,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',282,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13853,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13853,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13854,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13854,2,1,'steak (yield from 320 g raw meat)',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13855,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13855,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',278,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13856,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13856,2,1,'steak',335,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13857,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13857,2,1,'steak (yield from 1 raw steak weighing 321g)',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13858,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13858,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',285,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13859,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13859,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13860,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13860,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',268,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13861,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13861,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',276,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13862,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13862,2,1,'steak',199,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13863,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13863,2,1,'steak',239,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13864,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13864,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13865,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13865,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',313,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13866,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13866,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13867,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13867,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',313,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13868,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13868,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13869,1,3,'oz',85,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13869,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',281,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13870,1,3,'oz',85,'g',1,'2006-02-23','2011-01-18');
INSERT INTO `cndb_wght` VALUES (13870,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',338,'g',1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_wght` VALUES (13870,3,1,'roast (yield from 1 raw roast weighing 776g)',632,'g',1,'2006-02-23','2011-01-18');
INSERT INTO `cndb_wght` VALUES (13871,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13871,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13872,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13872,2,1,'steak (yield from 341 g raw meat)',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13873,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13873,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',338,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13873,3,1,'roast (yield from raw roast weighing 766g)',627,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13874,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13874,2,1,'steak',312,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13875,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13875,2,1,'steak (yield from raw steak weighing 340g)',226,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13876,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13876,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',338,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13876,3,1,'roast (yield from 1 raw roast weighing 786g)',636,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13877,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13877,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13878,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13878,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',333,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13879,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13879,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13880,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13880,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',333,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13881,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13881,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13882,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13882,2,1,'roast (yield from 530 g raw meat)',417,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13883,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13883,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13884,1,3,'oz',85,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13884,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',326,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13885,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13885,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13886,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13886,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',325,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13887,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13887,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13888,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13888,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',327,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13889,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13889,2,1,'steak',231,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13890,1,3,'oz',85,'g',1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13890,2,1,'piece cooked, excluding refuse (yield from 1 lb raw meat with refuse)',283,'g',1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13891,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13891,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13892,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13892,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',286,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13893,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13893,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',326,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13894,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13894,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13895,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13895,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',289,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13896,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13896,2,1,'steak (yield from raw steak weighing 492 g)',347,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13896,3,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',326,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13897,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13897,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',283,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13898,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13898,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13899,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13899,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',286,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13900,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13900,2,1,'steak (yield from raw steak weighing 491g)',359,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13900,3,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',329,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13901,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13901,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13902,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13902,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',332,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13903,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13903,2,1,'steak',252,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13904,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13904,2,1,'piece',1855,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13905,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13905,2,1,'steak',539,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13906,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13906,2,1,'steak',417,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13907,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13907,2,1,'steak',461,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13908,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13908,2,1,'steak',360,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13909,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13910,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13910,2,1,'steak',213,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13911,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13911,2,1,'steak',301,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13912,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13912,2,1,'steak (yield from 270 g raw meat)',221,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13913,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13914,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13915,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13915,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 242 g)',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13916,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13916,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 242 g)',167,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13917,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13917,2,1,'steak',164,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13918,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13918,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 154 g)',104,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13919,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13919,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',330,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13920,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13920,2,1,'steak',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13921,1,1,'steak (yield from 181 g raw meat)',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13921,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13922,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13922,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',329,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13923,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13923,2,1,'steak (yield from 1 raw steak weighing149g)',149,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13923,3,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13924,1,1,'steak (yield from 1 raw steak weighing 151g)',119,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13924,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13924,3,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 154 g)',104,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13925,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13925,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',329,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13926,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13926,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13927,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13927,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 154 g)',106,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13928,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13928,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',326,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13929,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13929,2,1,'steak',608,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13930,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13930,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',306,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13931,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13931,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13932,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13932,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',306,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13933,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13933,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',307,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13934,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13934,2,1,'steak',594,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13935,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13935,2,1,'steak (yield from 1 raw steak weighing 624g)',485,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13937,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13940,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13943,1,3,'oz ( 1 serving )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13946,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13948,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13948,2,1,'steak (yield from 475 g raw meat)',383,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13949,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13949,2,1,'steak (yield from 467 g raw meat)',379,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13950,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13950,2,1,'steak (yield from 388 g raw meat)',247,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13951,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13951,2,1,'steak (yield from 294 g raw meat)',231,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13952,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13952,2,1,'steak (yield from 295 g raw meat)',233,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13954,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13954,2,1,'roast',261,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13955,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13955,2,1,'roast (yield from 714 g raw meat)',591,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13956,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13956,2,1,'roast',271,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13957,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13957,2,1,'roast (yield from 666 g raw meat)',547,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13958,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13958,2,1,'roast',252,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13959,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13959,2,1,'steak (yield from 381 g raw meat)',277,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13961,1,3,'oz (1 serving)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13963,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13965,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13967,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13968,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13968,2,1,'steak (yield from 396 g raw meat)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13969,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13969,2,1,'steak (yield from 368 g meat)',269,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13970,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13970,2,1,'steak',188,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13971,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13971,2,1,'steak',173,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13972,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13972,2,1,'roast',1289,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13973,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13973,2,1,'roast',1263,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13974,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13974,2,1,'roast',1327,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13975,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13975,2,1,'piece',1780,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13977,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13979,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (13980,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13980,2,1,'piece',272,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13981,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13981,2,1,'piece',315,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13982,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (13982,2,1,'piece',289,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13983,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13983,2,1,'piece',514,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (13985,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13985,2,1,'serving',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (13985,3,1,'roast',569,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (14021,1,8,'fl oz',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14031,1,8,'fl oz',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14054,1,8,'fl oz',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14054,2,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14056,1,8,'fl oz',266,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14056,2,2,'fl oz',60,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14058,1,3,'scoop',86,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14060,1,8,'fl oz',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14061,1,8,'fl oz',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14063,1,2,'tbsp',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14064,1,8,'fl oz',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14066,1,0.33,'cup',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14067,1,1,'scoop',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14079,1,16,'fl oz',473,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14083,1,1,'serving',256,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (14090,1,1,'cup',245,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (14091,1,1,'cup',262,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14092,1,1,'cup',240,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14119,1,8,'fl oz',247,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14121,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14121,2,1,'can or bottle (16 fl oz)',474,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14121,3,1,'can or bottle (12 fl oz)',355,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14130,1,1,'fl oz',30.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14130,2,1,'can or bottle (16 fl oz)',494,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14130,3,1,'can or bottle (12 fl oz)',371,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14136,1,1,'fl oz',30.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14136,2,1,'can or bottle (16 fl oz)',488,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14136,3,1,'can or bottle (12 fl oz)',366,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14142,1,1,'fl oz',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14142,2,1,'can or bottle (12 fl oz)',372,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14143,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14143,2,1,'can (12 fl oz)',355,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14144,1,1,'fl oz',30.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14144,4,1,'drink (12 fl oz)',368,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14144,5,1,'drink, small (16 fl oz)',491,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14144,6,1,'drink, medium (22 fl oz)',675,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14144,7,1,'drink, large (32 fl oz)',982,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14144,8,1,'drink, extra large (44 fl oz)',1351,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14146,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14146,2,1,'can or bottle (16 fl oz)',474,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14146,3,1,'can (12 fl oz)',355,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14146,4,1,'drink, small (16 fl oz)',474,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14146,5,1,'drink, medium (22 fl oz)',651,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14146,6,1,'drink, large (32 fl oz)',947,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14146,7,1,'drink, extra large (44 fl oz)',1302,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14147,1,1,'fl oz',30.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14147,2,1,'serving 12 fl oz',368,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14147,3,1,'serving 16 fl oz',491,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14148,1,1,'fl oz',30.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14148,2,1,'can or bottle (12 fl oz)',370,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14148,3,1,'can or bottle (16 fl oz)',492,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14148,4,1,'drink, small (16 fl oz)',492,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14148,5,1,'drink, medium (22 fl oz)',676,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14148,6,1,'drink, large (32 fl oz)',984,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14148,7,1,'drink, extra large (44 fl oz)',1353,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14149,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14149,2,1,'can (8 fl oz)',355,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14150,1,1,'fl oz',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14150,2,1,'can or bottle (16 fl oz)',496,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14150,3,1,'can or bottle (12 fl oz)',372,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14151,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14151,2,1,'can (12 fl oz)',355,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14153,1,1,'fl oz',30.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14153,2,1,'can or bottle (16 fl oz)',491,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14153,3,1,'can or bottle (12 fl oz)',368,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14155,1,1,'fl oz',30.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14155,2,1,'bottle (11 fl oz)',336,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14155,3,1,'can or bottle (16 fl oz)',488,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14155,4,1,'can or bottle (12 fl oz)',366,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14157,1,1,'fl oz',30.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14157,2,1,'can or bottle (16 fl oz)',493,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14157,3,1,'can or bottle (12 fl oz)',370,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14161,1,16,'fl oz',473,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14163,1,8,'fl oz',237,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14164,1,1,'cup dry mix',98,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14164,2,1,'cup prepared',251,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14165,1,1,'cup',253,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14166,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14166,2,1,'bottle (16 fl oz)',474,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14166,3,1,'can (12 fl oz)',355,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14168,1,1,'tbsp',12,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14169,1,1,'cup (8 fl oz)',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14171,1,1,'cup',240,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14173,1,9.5,'fl oz',281,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14174,1,8,'fl oz',240,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14177,1,1,'cup (8 fl oz)',266,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (14179,1,1,'cup',262,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14180,1,1,'cup',248,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14181,1,1,'serving 2 tbsp',39,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14181,2,1,'cup',300,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14182,1,1,'cup (8 fl oz)',282,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14183,1,1,'cup',265,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14187,1,1,'fl oz',30.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14187,2,1,'can (5.5 oz)',166,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14188,1,1,'cup',260,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14190,1,1,'cup',269,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14191,1,1,'cup',265,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14192,1,1,'serving (3 heaping tsp or 1 envelope)',28,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (14194,1,1,'fl oz',34.3,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14194,2,1,'serving 6 fl oz',206,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14196,1,1,'envelope Alba (.675 oz)',19,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14196,2,1,'envelope  Swiss Miss (.53 oz)',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14199,1,1,'cup',271,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14201,1,1,'fl oz',29.6,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14201,2,6,'fl oz',178,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14201,3,1,'cup (8 fl oz)',237,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14202,1,1,'fl oz',29.6,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14203,1,1,'tsp',1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14203,2,1,'packet',2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14204,1,1,'tsp dry',6.4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14206,1,1,'cup',270,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14207,1,1,'cup',266,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14207,2,16,'fl oz',473,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14209,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14209,2,6,'fl oz',178,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14209,3,1,'cup (8 fl oz)',237,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14210,1,1,'fl oz',29.6,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14211,1,1,'cup',265,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14214,1,1,'tsp',1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14214,2,1,'packet',2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14215,1,1,'fl oz',29.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14215,2,1,'serving 6 fl oz',179,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14216,1,8,'fl oz',240,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14218,1,1,'tsp rounded',1.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14219,1,1,'fl oz',29.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14219,2,1,'serving 6 fl oz',179,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14222,1,1,'tsp, rounded',1.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14223,1,1,'fl oz',29.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14223,2,1,'serving 6 fl oz',179,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14224,1,1,'serving 2 tbsp',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14236,1,1,'tsp (1 serving)',3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14237,1,1,'fl oz',30.1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14237,2,1,'serving 6 fl oz',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14238,1,1,'fl oz',30.6,'g',1,'1995-06-19','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14238,2,1,'cup (8 fl oz)',245,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14240,1,1,'fl oz',30.6,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14240,2,1,'cup (8 fl oz)',245,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14241,1,1,'fl oz',30.6,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14241,2,1,'cup (8 fl oz)',245,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14242,1,1,'fl oz',31.6,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14242,2,1,'cup (8 fl oz)',253,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14243,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14243,2,1,'cup (8 fl oz)',237,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14245,1,1,'cup (8 fl oz)',272,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14246,1,2,'tbsp',4.5,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14260,1,240,'ml',240,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14261,1,16,'fl oz',473,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14262,1,1,'fl oz',35.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14262,2,1,'can (12 fl oz)',423,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14263,1,1,'fl oz',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14263,2,1,'serving 8 fl oz',248,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14264,1,6.75,'fl oz',210,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14264,2,1,'cup (8 fl oz)',248,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14267,1,1,'fl oz',31,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14267,2,1,'cup (8 fl oz)',248,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14268,1,1,'fl oz',34.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14268,2,1,'can (12 fl oz)',418,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14269,1,1,'fl oz',30.9,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14269,2,1,'cup',247,'g',1,'1997-08-29','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14270,1,1,'serving',15,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14277,1,1,'fl oz',31.3,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14277,2,1,'cup (8 fl oz)',250,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14278,1,1,'cup',245,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14278,2,1,'fl oz',29.6,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14279,1,1,'cup',268,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14280,1,1,'cup',240,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14281,1,1,'cup',240,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14282,1,1,'fl oz',31.3,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14282,2,6,'fl oz',188,'g',1,'1997-08-29','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14282,3,8,'fl oz',250,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14282,4,1,'serving',227,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14287,1,1,'serving',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14287,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14288,1,1,'fl oz',33,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14288,2,1,'cup 8 fl oz',264,'g',1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14292,1,1,'fl oz',36.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14292,2,1,'can (12 fl oz)',438,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14292,3,1,'can (6 fl oz)',219,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14293,1,1,'fl oz',30.9,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14293,2,1,'cup 8 fl oz',247,'g',1,'1997-08-29','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14296,1,1,'serving',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14296,2,0.5,'scoop (2 tbsp)',29,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14297,1,1,'fl oz',31.8,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14297,2,1,'cup 8 fl oz',255,'g',1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14303,1,1,'fl oz',30.9,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14303,2,1,'cup 8 fl oz',247,'g',1,'1997-08-29','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14305,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14305,2,1,'cup',237,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14310,1,1,'cup (8 fl oz)',265,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14311,1,1,'serving (3 heaping tsp or 1 envelope)',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14312,1,1,'cup (8 fl oz)',265,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14316,1,1,'cup (8 fl oz)',265,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14317,1,1,'serving (3 heaping tsp or 1 envelope)',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14318,1,1,'cup (8 fl oz)',265,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14323,1,1,'fl oz',31,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14323,2,1,'cup (8 fl oz)',248,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14327,1,1,'fl oz',31.2,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14327,2,1,'cup (8 fl oz)',250,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14334,1,1,'fl oz',31.3,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14334,2,1,'cup (8 fl oz)',250,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14341,1,1,'fl oz',31.3,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14341,2,1,'cup (8 fl oz)',250,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14350,1,1,'serving (2-3 heaping tsp)',22,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14351,1,1,'cup (8 fl oz)',266,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (14352,1,1,'FL OZ',29.6,'g',1,'2002-09-06','2010-01-05');
INSERT INTO `cndb_wght` VALUES (14352,2,6,'FL OZ',178,'g',1,'2007-11-28','2010-01-05');
INSERT INTO `cndb_wght` VALUES (14352,3,1,'cup (8 fl oz)',237,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (14353,1,1,'serving 2 tsp',0.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14355,1,1,'fl oz',29.6,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14355,2,6,'fl oz',178,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14355,3,1,'cup (8 fl oz)',237,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14356,1,2,'tsp',1.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14357,1,1,'serving (3 heaping tsp)',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14357,2,1,'cup',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14366,1,1,'serving 1 tsp',0.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14367,1,1,'fl oz',29.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14367,2,1,'serving 6 fl oz',178,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14367,3,1,'serving 8 fl oz',238,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14368,1,1,'tsp, rounded',1.4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14368,2,2,'tbsp, rounded',11.3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14370,1,1,'serving (3 heaping tsp)',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14370,2,1,'cup',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14371,1,1,'cup (8 fl oz)',259,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14375,1,2,'tsp',1.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14375,2,4,'tbsp (1/4 cup)',14.4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14376,1,1,'fl oz',29.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14376,2,1,'serving 6 fl oz',179,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14376,3,1,'serving 8 fl oz',238,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14381,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14381,2,6,'fl oz',178,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14381,3,1,'cup (8 fl oz)',237,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14390,1,1,'fl oz',32.1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14390,2,1,'serving dry mix with 6 fl oz water',192,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14400,1,1,'serving child 12 fl oz, without ice',258,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14400,2,1,'serving small 16 fl oz, without ice',347,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14400,3,1,'serving medium 21 fl oz,  without ice',486,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14400,4,1,'serving large 32 fl oz,  without ice',722,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14405,1,1,'fl oz',35.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14405,2,1,'can (12 fl oz)',423,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14406,1,1,'fl oz',29.3,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14406,2,8,'fl oz',234,'g',1,'1997-08-29','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14407,1,1,'serving 2 tbsp',26,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14408,1,1,'fl oz',33.9,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14408,2,6,'fl oz',203,'g',1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14409,1,1,'portion, amount of dry mix to make 8 fl oz prepared',2.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14411,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14411,2,1,'serving 8 fl oz',237,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14411,3,1,'liter',1000,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14416,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14416,2,1,'can can 12 fl oz',355,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14416,3,1,'bottle bottle 16 fl oz',473,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14416,4,1,'serving child 12 fl oz',258,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14416,5,1,'serving small 16 fl oz',347,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14416,6,1,'serving medium 21 fl oz',486,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14416,7,1,'serving large 32 fl oz',722,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14421,1,6,'fl oz',185,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14422,1,1,'packet (.75 oz)',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14422,2,1,'envelope',21,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14423,1,1,'serving',243,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14424,1,1,'fl oz',35.3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14424,2,1,'can',424,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14425,1,1,'fl oz',31,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14425,2,8,'fl oz',248,'g',1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14426,1,1,'fl oz',36.3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14426,2,1,'can',436,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14427,1,1,'fl oz',31.3,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14427,2,8,'fl oz',250,'g',1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14429,1,1,'FL OZ',29.6,'g',1,'1994-01-31','2010-01-05');
INSERT INTO `cndb_wght` VALUES (14429,2,1,'bottle 8 fl oz',237,'g',1,'1997-08-29','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14429,3,1,'liter',1000,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (14429,4,3,'ice cube (3/4 fl oz)',64,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (14430,1,1,'fl oz',36.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14430,2,1,'can (12 fl oz)',435,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14431,1,1,'fl oz',29.6,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14431,2,8,'fl oz',237,'g',1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14436,1,1,'fl oz',31.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14436,2,1,'cup (8 fl oz)',253,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14537,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14537,2,1,'can (12 fl oz)',355,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14538,1,1,'envelope  Swiss Miss (.53 oz)',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14538,2,1,'packet (0.675 oz)',19,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14541,1,1,'fl oz',32.7,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14541,2,8,'fl oz',262,'g',1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14542,1,1,'fl oz',36.4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14542,2,1,'can (12 fl oz)',437,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14542,3,1,'can (6 fl oz)',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14543,1,1,'fl oz',30.9,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (14543,2,1,'bottle 8 fl oz',247,'g',1,'1997-08-29','2016-02-06');
INSERT INTO `cndb_wght` VALUES (14544,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14544,2,6,'fl oz',178,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14545,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14545,2,6,'fl oz',178,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14545,3,1,'cup (8 fl oz)',237,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14548,1,1,'serving (3 heaping tsp)',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14548,2,1,'cup',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14552,1,1,'fl oz',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14552,2,1,'can or bottle (16 fl oz)',492,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14552,3,1,'can (12 fl oz)',369,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14555,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14555,2,1,'cup',237,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14555,3,1,'ml',1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14557,1,1,'serving',22,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14558,1,1,'serving',266,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14604,1,1,'fl oz',29.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14604,2,1,'serving (8 fl oz)',237,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14604,3,1,'ml',1.1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14605,1,8,'fl oz (1 NLEA serving)',237,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14605,2,1,'serving',237,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14632,1,1,'cup',158,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14632,2,1,'can',391,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14633,1,1,'serving',238,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14634,1,1,'cup',244,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (14635,1,1,'serving 8 oz',246,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (14636,1,1,'container',209,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (14636,2,1,'ml',1,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (14637,1,1,'pouch',200,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (14639,1,8,'fl oz (approximate weight, 1 serving)',240,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (14645,1,1,'cup (8 fl oz)',238,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (14646,1,1,'cup (8 fl oz)',238,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (14647,1,8,'fl oz',240,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (14647,2,1,'fl oz',31.1,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (14648,1,8,'fl oz',237,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (14649,1,8,'fl oz',237,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (14651,1,1,'cup (8 fl oz)',238,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (14654,1,1,'tbsp',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (14654,2,1,'serving',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15001,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15002,1,1,'oz, boneless',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15002,2,1,'anchovy',4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15002,3,1,'can (2 oz)',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15002,4,5,'anchovies',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15003,1,1,'fillet',79,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15003,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15004,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15004,2,1,'fillet',159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15005,1,1,'fillet',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15005,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15006,1,1,'fillet',116,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15006,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15007,1,1,'fillet',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15007,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15008,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15008,2,1,'fillet',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15009,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15009,2,1,'fillet',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15010,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15010,2,1,'fillet',159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15011,1,1,'fillet',87,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15011,2,3,'oz',85,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15012,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15012,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15013,1,1,'fillet',79,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15013,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15014,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15014,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15015,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15015,2,1,'fillet',231,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15016,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15016,2,1,'fillet',180,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15017,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15017,2,1,'can',312,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15018,1,1,'oz',28.35,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15018,2,1,'piece (5-1/2" x 1-1/2" x 1/2")',80,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (15018,3,3,'oz',85,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (15019,1,1,'fillet',116,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15019,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15020,1,1,'fillet',79,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15020,2,3,'oz',85,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15021,1,1,'fillet',87,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15021,2,3,'oz',85,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15022,1,1,'fillet',122,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15022,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15023,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15023,2,1,'fillet',204,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15024,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15024,2,1,'fillet',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15025,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15025,2,1,'fillet',204,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15026,1,1,'oz, boneless',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15026,2,1,'oz with bone (yield after bone removed)',22,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15026,3,1,'cubic inch, boneless',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15026,4,1,'fillet',159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15026,5,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15027,1,1,'piece (4" x 2" x 1/2")',57,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15027,2,1,'stick (4" x 1" x 1/2")',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15028,1,1,'oz, boneless',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15028,2,1,'fillet',163,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15028,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15029,1,1,'fillet',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15029,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15030,1,1,'piece',42,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15031,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15031,2,1,'fillet',259,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15032,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15032,2,1,'fillet',202,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15033,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15033,2,1,'fillet',193,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15034,1,1,'fillet',150,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15034,2,3,'oz',85,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15035,1,1,'oz, boneless',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15035,2,1,'cubic inch, boneless',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15035,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15036,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15036,2,0.5,'fillet',204,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15037,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15037,2,0.5,'fillet',159,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15038,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15038,2,0.5,'fillet',204,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15039,1,1,'oz, boneless',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15039,2,1,'fillet',184,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15039,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15040,1,1,'fillet',143,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15040,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15041,1,1,'cup',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15041,2,1,'oz, boneless',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15041,3,1,'cubic inch',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15041,4,1,'piece (1-3/4" x 7/8" x 1/2")',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15042,1,1,'oz, boneless',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15042,2,1,'cubic inch, boneless',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15042,3,1,'fillet, large (7" x 2-1/4" x 1/4")',65,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15042,4,1,'fillet, medium (5" x 1-3/4" x 1/4")',40,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15042,5,1,'fillet, small (2-3/8" x 1-3/8" x 1/4")',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15043,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15043,2,1,'fillet',184,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15044,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15044,2,1,'fillet',193,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15045,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15045,2,0.5,'fillet',193,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15046,1,1,'fillet',112,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15046,2,3,'oz',85,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15047,1,1,'fillet',88,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15047,2,3,'oz',85,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15048,1,1,'oz, boneless',28.35,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15048,2,1,'cup',190,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15048,3,1,'cubic inch',16,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15048,4,1,'can (15 oz)',361,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15049,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15049,2,0.5,'fillet',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15050,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15050,2,1,'fillet',225,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15051,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15051,2,1,'fillet',187,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15052,1,1,'fillet',146,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15052,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15053,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15054,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15055,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15055,2,1,'fillet',119,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15055,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15056,1,1,'fillet',93,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15056,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15057,1,1,'oz, boneless',28.35,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15057,2,1,'fillet',64,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15057,3,3,'oz',85,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15058,1,1,'fillet',50,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15058,2,3,'oz',85,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15059,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15059,2,0.5,'fillet',176,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15060,1,1,'fillet',60,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15060,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15061,1,1,'fillet',46,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15061,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15062,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15062,2,0.5,'fillet',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15063,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15063,2,0.5,'fillet',155,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15064,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15064,2,1,'fillet',159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15065,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15065,2,0.5,'fillet',193,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15066,1,1,'fillet',77,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15066,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15067,1,1,'fillet',60,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15067,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15068,1,1,'oz, boneless',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15068,2,1,'fillet',112,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15068,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15069,1,1,'fillet',88,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15069,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15070,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15070,2,1,'fillet',191,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15071,1,1,'fillet',149,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15071,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15072,1,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15072,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15072,3,1,'can (8 oz), solids and liquid',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15072,4,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15073,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15074,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15074,2,0.5,'fillet',193,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15075,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15075,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15076,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15076,2,0.5,'fillet',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15077,1,1,'oz, boneless',28.35,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (15077,2,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (15077,3,1,'cubic inch, boneless',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15077,4,1,'cup, cooked',136,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (15078,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15078,2,0.5,'fillet',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15079,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15079,2,0.5,'fillet',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15080,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15080,2,1,'can',369,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15081,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15081,2,0.5,'fillet',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15082,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15082,2,0.5,'fillet',155,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15083,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15083,2,0.5,'fillet',159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15084,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15084,2,1,'can',411,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15085,1,1,'oz, boneless',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15085,2,0.5,'fillet',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15085,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15086,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15086,2,0.5,'fillet',155,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15087,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15087,2,1,'can',337,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15088,1,1,'cup, drained',149,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15088,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15088,3,1,'cubic inch',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15088,4,1,'can (3.75 oz)',92,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15088,5,1,'small (2-2/3" x 1/2" x 1/4")',12,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15088,6,2,'sardines',24,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15089,1,1,'cup',89,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15089,2,1,'can',370,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15089,3,1,'sardine',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15090,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15090,2,1,'oz, boneless',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15090,3,1,'fillet',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15090,4,1,'cup',166,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15091,1,1,'fillet',129,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15091,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15092,1,1,'fillet',101,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15092,2,3,'oz',85,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15093,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15093,2,1,'fillet',238,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15094,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15094,2,1,'fillet',184,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15095,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15096,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15097,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15097,2,1,'fillet',238,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15098,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15098,2,1,'fillet',186,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15099,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15100,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15101,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15101,2,1,'fillet',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15102,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15102,2,1,'fillet',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15103,1,1,'fillet',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15103,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15104,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15105,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (15105,2,1,'cup, cooked',136,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (15105,3,1,'piece (4-1/2" x 2-1/8" x 7/8")',145,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (15105,4,1,'oz, boneless',28.35,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (15105,5,1,'cubic inch, boneless',17,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (15106,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15106,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15107,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15107,2,1,'fillet',159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15108,1,1,'fillet',48,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15108,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15109,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15109,2,3,'oz',85,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (15110,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (15110,2,1,'piece (4-1/2" x 2-1/8" x 7/8")',136,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (15111,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (15111,2,1,'piece',106,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (15112,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15112,2,0.5,'fillet',193,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15113,1,0.5,'fillet',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15113,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15114,1,1,'fillet',79,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15114,2,3,'oz',85,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15115,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15115,2,1,'fillet',159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15116,1,1,'fillet',143,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15116,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15117,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15118,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15119,1,1,'cup, solid or chunks',146,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (15119,2,1,'oz',28.35,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15119,3,1,'can',171,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (15119,4,3,'oz',85,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (15119,5,1,'can (12.5 oz), drained',321,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (15121,1,1,'oz',28.35,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15121,2,3,'oz',85,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15121,3,1,'can',165,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (15121,4,1,'cup, solid or chunks',154,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15121,5,1,'can (12.5 oz), drained',315,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (15123,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15123,2,0.5,'fillet',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15124,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15124,2,1,'can',178,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15126,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15126,2,1,'can',172,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15127,1,1,'oz, boneless',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15127,2,1,'cubic inch, boneless',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15127,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15128,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15128,2,1,'cup',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15129,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15129,2,0.5,'fillet',204,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15130,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15130,2,1,'fillet',198,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15131,1,1,'cup, cooked',136,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15131,2,1,'oz, boneless',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15131,3,1,'cubic inch, boneless',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15131,4,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15132,1,1,'fillet',92,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15132,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15133,1,1,'fillet',72,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15133,2,3,'oz',85,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15134,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15134,2,0.5,'fillet',153,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15135,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15135,2,0.5,'fillet',187,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15136,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15136,2,1,'leg',172,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15137,1,1,'leg',134,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15137,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15138,1,3,'oz',85,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15139,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15139,2,1,'crab',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15140,1,1,'cup, flaked and pieces',118,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15140,2,1,'cup (not packed)',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15140,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15140,4,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15141,1,1,'cup',135,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15141,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15141,3,1,'can (6.5 oz), drained',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15141,4,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15142,1,1,'cake',60,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15143,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15143,2,1,'crab',163,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15144,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15145,1,3,'oz',85,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15145,2,8,'crayfish',27,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15146,1,3,'oz',85,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15147,1,1,'lobster',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15147,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15148,1,1,'cup',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15148,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15149,1,1,'medium',6,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15149,2,1,'small',5,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15149,3,3,'oz',85,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15149,4,4,'large',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15150,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15150,2,4,'large',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15151,1,3,'oz',85,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15151,2,4,'large',22,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15152,1,1,'CUP',128,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (15152,2,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15152,3,1,'can (4.5 oz), drained',128,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (15152,4,10,'shrimp',32,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (15152,5,3,'oz',85,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (15153,1,3,'oz',85,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15154,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15154,2,1,'lobster',209,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15155,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15156,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15157,1,3,'oz',85,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15157,2,1,'large',20,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15157,3,1,'lb (with shell), yield after shell removed',68,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15157,4,1,'medium',14.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15157,5,1,'small',9,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15157,6,1,'cup (with liquid and clams)',227,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15158,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15158,2,20,'small',188,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15159,1,3,'oz',85,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15159,2,20,'small',190,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15160,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15160,2,1,'cup',160,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15162,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15162,2,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15163,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15164,1,1,'cup',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15164,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15164,3,1,'large',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15164,4,1,'medium',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15164,5,1,'small',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15164,6,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15165,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15166,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15167,1,6,'medium',84,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15167,2,1,'cup',248,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15168,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15168,2,6,'medium',88,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15169,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15169,2,6,'medium',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15170,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15170,2,1,'cup, undrained',248,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15170,3,1,'oz, drained',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15170,4,1,'can (12 oz), oysters and liquid',272,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15170,5,1,'oyster',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15170,6,1,'cup, drained',162,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15171,1,1,'medium',50,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15171,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15172,1,1,'unit 2 large or 5 small',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15172,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15173,1,2,'large',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15174,1,3,'oz',85,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15175,1,1,'oz, boneless',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15175,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15176,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15177,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15178,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15179,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15179,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15180,1,3,'oz',85,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15180,2,1,'can',369,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15181,1,3,'oz',85,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15181,2,1,'can',454,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15182,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15182,2,1,'can',369,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15183,1,3,'oz',85,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15183,2,1,'can',171,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15184,1,3,'oz',85,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15184,2,1,'can',165,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15185,1,3,'oz',85,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15185,2,1,'can',178,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15186,1,3,'oz',85,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15186,2,1,'can',172,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15187,1,1,'fillet',62,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15187,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15188,1,1,'fillet',124,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15188,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15189,1,1,'fillet',117,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15189,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15190,1,1,'fillet',90,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15190,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15192,1,1,'fillet',90,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15192,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15194,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15194,2,1,'fillet',159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15195,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15195,2,1,'fillet',154,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15196,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15196,2,0.5,'fillet',159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15197,1,1,'fillet',144,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15197,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15199,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15199,2,0.5,'fillet',151,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15200,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15200,2,0.5,'fillet',154,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15201,1,1,'oz, boneless',28.35,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15201,2,1,'cubic inch, boneless',17,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15201,3,1,'fillet',176,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15201,4,3,'oz',85,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15204,1,1,'fillet',124,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15204,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15205,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15205,2,0.5,'fillet',151,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15206,1,0.5,'fillet',137,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15206,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15207,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15207,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15208,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15208,2,0.5,'fillet',151,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15209,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15209,2,0.5,'fillet',154,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15210,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15210,2,0.5,'fillet',154,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15211,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15211,2,0.5,'fillet',154,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15212,1,3,'oz',85,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (15212,2,0.5,'fillet',124,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (15214,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15214,2,1,'fillet',186,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15216,1,1,'fillet',50,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15216,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15217,1,1,'fillet',124,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15217,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15218,1,1,'fillet',37,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15218,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15219,1,1,'fillet',62,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15219,2,3,'oz',85,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15220,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15220,2,0.5,'fillet',154,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15221,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15223,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15223,2,1,'fillet',154,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15224,1,0.5,'fillet',119,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15224,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15226,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15226,2,1,'crab',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15227,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15228,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15228,2,1,'lobster',163,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15229,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15230,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15231,1,1,'medium',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15231,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15232,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15233,1,1,'fillet',143,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15233,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15234,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15234,2,1,'fillet',159,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15235,1,1,'fillet',143,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15235,2,3,'oz',85,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15236,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15236,2,0.5,'fillet',198,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15237,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15237,2,0.5,'fillet',178,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15238,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15238,2,1,'fillet',159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15239,1,1,'fillet',143,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15239,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15240,1,1,'fillet',79,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15240,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15241,1,1,'fillet',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15241,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15242,1,3,'oz',85,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15242,2,8,'crayfish',27,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15243,1,3,'oz',85,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15244,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15244,2,6,'medium',59,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15245,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15245,2,6,'medium',84,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15246,1,3,'oz',85,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15246,2,6,'medium',59,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (15247,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15247,2,0.5,'fillet',178,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15250,1,1,'cup, sliced',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15250,2,1,'oz cooked, yield',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15251,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15252,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15253,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15253,2,1,'can total can contents',417,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15260,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15260,2,1,'can drained solids (total)',315,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15261,1,1,'fillet',116,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15262,1,1,'fillet',87,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15264,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15264,2,1,'can drained solids, bone and skin removed',247,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15265,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (15265,2,1,'can drained solids, bone and skin removed',242,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15266,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (15267,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (15269,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (15270,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (15271,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (15274,1,1,'filet',149,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (15274,2,1,'fish',332,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16001,1,1,'cup',197,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16002,1,1,'cup',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16003,1,1,'cup',296,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16004,1,1,'slice',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16005,1,1,'cup',253,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16006,1,1,'CUP',254,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16007,1,1,'cup',266,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16008,1,1,'cup',259,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16009,1,1,'CUP',253,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16010,1,1,'CUP',249,'g',1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_wght` VALUES (16011,1,1,'CUP',246,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (16014,1,1,'cup',194,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16014,2,1,'tbsp',12.1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16015,1,1,'CUP',172,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16016,1,1,'cup',184,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16017,1,1,'cup',185,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16018,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16019,1,1,'cup',195,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16020,1,1,'cup',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16021,1,1,'cup',260,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16022,1,1,'cup',184,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16023,1,1,'cup',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16024,1,1,'CUP',183,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16025,1,1,'CUP',177,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16026,1,1,'CUP',262,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16027,1,1,'CUP',184,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16028,1,1,'CUP',177,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16028,2,1,'TBSP',11,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16029,1,1,'CUP',256,'g',1,'1994-01-31','2007-03-25');
INSERT INTO `cndb_wght` VALUES (16030,1,1,'cup',184,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16031,1,1,'cup',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16032,1,1,'cup',184,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16032,2,1,'tbsp',12.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16033,1,1,'CUP',177,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16033,2,1,'TBSP',11,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16034,1,1,'CUP',256,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16034,2,1,'TBSP',16,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16034,3,1,'can',436,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16035,1,1,'cup',184,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16036,1,1,'cup',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16037,1,1,'cup',208,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16038,1,1,'cup',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16039,1,1,'CUP',262,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16040,1,1,'cup',210,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16041,1,1,'CUP',169,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16042,1,1,'CUP',193,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16042,2,1,'TBSP',12,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16043,1,1,'CUP',171,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16043,2,1,'TBSP',10.6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16044,1,1,'CUP',240,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16044,2,1,'can',442,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16045,1,1,'cup',215,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16046,1,1,'cup',179,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16047,1,1,'cup',196,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16048,1,1,'cup',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16049,1,1,'cup',202,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16049,2,1,'tbsp',12.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16050,1,1,'CUP',179,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16050,2,1,'TBSP',11.2,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16051,1,1,'cup',262,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16052,1,1,'cup',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16052,2,1,'tbsp',9.4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16053,1,1,'cup',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16054,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16055,1,1,'cup',103,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16055,2,1,'tbsp',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16056,1,1,'cup',200,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16056,2,1,'tbsp',12.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16057,1,1,'cup',164,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16058,1,1,'CUP',240,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16058,2,1,'can (total can contents)',448,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16059,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16059,2,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16060,1,1,'cup',167,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16061,1,1,'cup',171,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16062,1,1,'CUP',167,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16062,2,1,'TBSP',10.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16063,1,1,'cup',171,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (16064,1,1,'CUP',240,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16065,1,1,'CUP',240,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16067,1,1,'cup',210,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16068,1,1,'cup',194,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16069,1,1,'CUP',192,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16069,2,1,'tablespoon',12,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (16070,1,1,'CUP',198,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16070,2,1,'TBSP',12.3,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16071,1,1,'CUP',178,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16071,2,1,'TBSP',11.1,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16072,1,1,'CUP',188,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16072,2,1,'TBSP',11.7,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16073,1,1,'CUP',241,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16074,1,1,'CUP',202,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16075,1,1,'CUP',182,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16076,1,1,'cup',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16077,1,1,'cup',166,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16078,1,1,'cup',196,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16079,1,1,'cup',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16080,1,1,'cup',207,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16080,2,1,'tbsp',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16081,1,1,'CUP',202,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16082,1,1,'cup',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16083,1,1,'cup',207,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16084,1,1,'cup',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16084,2,1,'oz dry, yield after cooking',69,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16085,1,1,'cup',196,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (16086,1,1,'CUP',196,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16086,2,1,'TBSP',12.2,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16087,1,1,'oz',28.35,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (16087,2,1,'cup',146,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (16088,1,1,'cup in shell, edible yield',63,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16088,2,1,'cup, shelled',180,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16088,3,1,'oz shelled',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16088,4,33,'nuts',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16089,1,1,'cup, chopped',144,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16089,2,1,'oz shelled (32 nuts)',28.35,'g',1,'1998-01-15','2015-01-07');
INSERT INTO `cndb_wght` VALUES (16090,1,1,'oz',28.35,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16090,2,1,'peanut',1,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16091,1,1,'cup',146,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16091,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16092,1,1,'cup',147,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16092,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16093,1,1,'cup',146,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16093,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16094,1,1,'cup',144,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16094,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16095,1,1,'cup',146,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16095,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16096,1,1,'cup',143,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16096,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16097,1,2,'tbsp',32,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16097,2,1,'cup',258,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16098,1,2,'tbsp',32,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16098,2,1,'cup',258,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16099,1,1,'cup',60,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16099,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16100,1,1,'cup',60,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16100,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16101,1,1,'CUP',205,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16102,1,1,'CUP',168,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16103,1,1,'CUP',238,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (16103,2,1,'can',442,'g',1,'2002-09-06','2015-06-19');
INSERT INTO `cndb_wght` VALUES (16104,1,1,'cup',144,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16104,2,1,'oz cooked, yield',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16104,3,1,'strip',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16106,1,1,'CUP',88,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16106,2,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16107,1,1,'link',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16107,2,1,'patty',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16107,3,1,'slice',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16108,1,1,'cup',186,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16109,1,1,'cup',172,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16109,2,1,'tbsp',10.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16110,1,1,'cup',172,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16111,1,1,'cup',93,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16112,1,1,'tbsp',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16112,2,1,'cup',275,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16113,1,1,'cup',175,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16114,1,1,'cup',166,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16115,1,1,'cup, stirred',84,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16115,2,1,'tbsp',5.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16116,1,1,'cup, stirred',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16117,1,1,'cup',105,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16117,2,1,'tbsp',6.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16118,1,1,'cup, stirred',88,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16118,2,1,'tbsp',5.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16119,1,1,'cup',122,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16120,1,1,'cup',243,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16120,2,1,'fl oz',30.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16121,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16122,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16123,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16123,2,1,'tsp',5.3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16123,3,1,'cup',255,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16123,4,1,'individual packet',8.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16124,1,1,'tbsp',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16124,2,1,'tsp',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16125,1,1,'tbsp',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16125,2,1,'tsp',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16125,3,0.25,'cup',58,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16126,1,0.5,'CUP',126,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (16126,2,0.25,'block',81,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (16126,3,0.2,'block',91,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (16127,1,1,'piece (2-1/2" x 2-3/4" x 1")',120,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16127,2,1,'cup (1/2" cubes)',248,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16127,3,1,'cubic inch',18,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16127,4,0.25,'block',116,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16127,5,0.2,'block',90,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (16128,1,1,'piece',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16129,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16129,2,1,'piece',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16130,1,1,'cup',122,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16132,1,1,'block',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16133,1,1,'cup',167,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16134,1,1,'cup',171,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16135,1,1,'cup',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16136,1,1,'cup',172,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16137,1,1,'tablespoon',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16137,2,1,'cup',246,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16138,1,1,'patty (approx 2-1/4" dia)',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16139,1,1,'cup',243,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16139,2,1,'fl oz',30.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16144,1,1,'CUP',192,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16145,1,1,'can drained solids',266,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (16146,1,1,'can drained solids',277,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (16147,1,1,'pattie',70,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16149,1,2,'tbsp',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16150,1,2,'tablespoon',36,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16155,1,2,'tbsp',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16155,2,1,'cup',258,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16156,1,2,'tbsp',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16156,2,1,'cup',258,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16157,1,1,'CUP',92,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16158,1,1,'tbsp',15,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16158,2,1,'cup',246,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16159,1,0.2,'block',91,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16160,1,0.25,'block',122,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16166,1,1,'cup',243,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16166,2,1,'fl oz',30.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16167,1,2,'tbsp',32,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (16167,2,1,'CUP',258,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (16168,1,1,'CUP',243,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (16168,2,1,'FL OZ',30.6,'g',1,'2007-12-03','2010-01-05');
INSERT INTO `cndb_wght` VALUES (16171,1,1,'cup',242,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16171,2,1,'can',444,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16172,1,1,'cup',231,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16172,2,1,'can',445,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16173,1,1,'cup',233,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16173,2,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16222,1,1,'cup',243,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (16223,1,1,'CUP',243,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (16225,1,1,'CUP',243,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (16227,1,1,'CUP',243,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (16228,1,1,'CUP',243,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (16229,1,1,'CUP',243,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (16230,1,1,'cup',243,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (16231,1,1,'cup',243,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (16302,1,1,'cup',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16315,1,1,'CUP',172,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16316,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16317,1,1,'cup',185,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16320,1,1,'cup',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16323,1,1,'cup',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16325,1,1,'CUP',177,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16326,1,1,'cup',262,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16328,1,1,'CUP',177,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16331,1,1,'cup',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16333,1,1,'cup',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16335,1,1,'cup cup rinsed solids',158,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (16336,1,1,'cup',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16337,1,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16337,2,1,'can total can contents',436,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16338,1,1,'cup',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16341,1,1,'CUP',169,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16343,1,1,'CUP',171,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16346,1,1,'cup',179,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16347,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16347,2,1,'can total can contents',442,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16348,1,1,'cup',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16350,1,1,'cup',179,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16353,1,1,'cup',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16357,1,1,'cup',164,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16358,1,1,'can drained',253,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (16359,1,1,'can drained, rinsed',254,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (16359,2,1,'cup drained, rinsed',152,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (16360,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16360,2,1,'can total can contents',448,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16361,1,1,'cup',171,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16363,1,1,'CUP',171,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16368,1,1,'cup',194,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16370,1,1,'CUP',198,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16372,1,1,'CUP',188,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16375,1,1,'CUP',182,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16377,1,1,'cup',166,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16379,1,1,'cup',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16381,1,1,'CUP',202,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16384,1,1,'cup',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16386,1,1,'CUP',196,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16389,1,1,'cup,',144,'g',1,'1994-09-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (16389,2,1,'oz shelled (32 nuts)',28.35,'g',1,'1998-01-15','2015-01-07');
INSERT INTO `cndb_wght` VALUES (16390,1,1,'CUP',146,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16390,2,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16390,3,1,'peanut',1,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16392,1,1,'cup',147,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16392,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16394,1,1,'cup',144,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16394,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16396,1,1,'cup',143,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16396,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16397,1,2,'tbsp',32,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16397,2,1,'cup',258,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16398,1,2,'tbsp',32,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16398,2,1,'cup',258,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16399,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16402,1,1,'CUP',168,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16403,1,1,'cup',238,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16403,2,1,'tablespoon',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16409,1,1,'cup',172,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16410,1,1,'cup',172,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16420,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16422,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16424,1,1,'tbsp',14.2,'g',1,'1994-11-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16424,2,1,'tsp',4.5,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16424,3,1,'cup',255,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (16425,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16425,2,1,'tsp',4.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16425,3,0.25,'cup',58,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16426,1,0.5,'CUP',126,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16426,2,0.25,'block',81,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16427,1,0.5,'CUP',124,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16427,2,0.25,'block',116,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (16428,1,1,'piece',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16429,1,1,'piece',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16432,1,1,'block',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16434,1,1,'cup',171,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (16436,1,1,'cup',172,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17000,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17000,2,1,'roast with bone',325,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17001,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17001,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17002,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17002,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',242,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17003,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17003,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17004,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17004,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',187,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17005,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17005,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17006,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17006,2,1,'unit, cooked (yield from 1 lb raw meat)',286,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17007,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17007,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17008,1,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',148,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17008,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17009,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17009,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17010,1,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17010,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17011,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (17011,2,1,'lb',453.6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (17012,1,3,'oz',85,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (17012,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',265,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (17013,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17013,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17014,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17014,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17015,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17015,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17016,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17016,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',269,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17017,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17017,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17018,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17018,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',238,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17019,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17019,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17020,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17020,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',262,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17021,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17021,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17022,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17022,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',201,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17023,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17023,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 120 g)',95,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17024,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17024,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 120 g)',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17025,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17025,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',269,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17026,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17026,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 120 g)',65,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17027,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17027,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 120 g)',46,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17028,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17028,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',193,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17029,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17029,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17030,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17030,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',229,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17031,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17031,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',255,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17032,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17032,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17033,1,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',147,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17033,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17034,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17034,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17035,1,4,'oz',113,'g',1,'1999-03-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17035,2,1,'lb',453.6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (17036,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17036,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17037,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17037,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',248,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17038,1,3,'oz',85,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (17038,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',269,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (17039,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17039,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17040,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17040,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',174,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17041,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17041,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',202,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17042,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17042,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',217,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17043,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17043,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 160 g)',133,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17044,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17044,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 160 g)',70,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17045,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17045,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 160 g)',93,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17046,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17046,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',286,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17047,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17047,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 160 g)',101,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17048,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17048,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 160 g)',55,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17049,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17049,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 160 g)',74,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17050,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17050,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',224,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17051,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17051,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17052,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17052,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',209,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17053,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17053,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',252,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17054,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17054,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',258,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17055,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17055,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17056,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17056,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17057,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17057,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',207,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17058,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17058,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',210,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17059,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (17059,2,1,'lb',453.6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (17060,1,3,'oz',85,'g',1,'1994-11-17','2013-12-26');
INSERT INTO `cndb_wght` VALUES (17060,2,1,'unit, cooked (yield from 1 lb raw meat)',272,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (17061,1,3,'oz',85,'g',1,'1994-11-17','2013-12-26');
INSERT INTO `cndb_wght` VALUES (17061,2,1,'unit, cooked (yield from 1 lb raw meat)',327,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (17062,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17062,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17063,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17063,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',222,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17064,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17064,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17065,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17065,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',164,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17066,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17066,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17067,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17067,2,1,'unit, cooked (yield from 1 lb raw meat)',286,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17068,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17068,2,1,'serving',115,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17069,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17069,2,1,'serving',85,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17070,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17070,2,1,'serving',115,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17071,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17071,2,1,'serving',85,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17072,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17072,2,1,'serving',115,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17073,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17073,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',258,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17074,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17074,2,1,'serving',115,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17075,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17075,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17076,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17076,2,1,'serving',115,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17077,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17077,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 85 g)',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17078,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17078,2,1,'serving',115,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17079,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17079,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 85 g)',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17080,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17080,2,1,'serving',115,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17081,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17081,2,1,'serving',85,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17082,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17082,2,1,'serving',115,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17083,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17083,2,1,'serving',85,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17084,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17084,2,1,'serving',115,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17085,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17085,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',206,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17086,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17086,2,1,'serving',115,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17087,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17087,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',157,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17088,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17088,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17089,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17089,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',209,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17090,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17090,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17091,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17091,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',192,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17092,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17092,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17093,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17093,2,1,'unit, cooked (yield from 1 lb raw meat)',290,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17094,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17094,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17095,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17095,2,1,'unit, cooked (yield from 1 lb raw meat)',272,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17096,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17096,2,1,'unit, cooked (yield from 1 lb raw meat)',295,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17097,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17097,3,1,'unit, cooked (yield from 1 lb raw meat)',304,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17098,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17098,2,1,'unit, cooked (yield from 1 lb raw meat)',358,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17099,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17099,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17100,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17100,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',267,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17101,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17101,2,1,'unit, cooked (yield from 1 lb raw meat)',295,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17102,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17102,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',289,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17103,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17103,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',351,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17104,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17104,2,1,'roast',1495,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (17105,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17105,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 195 g)',80,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17106,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17106,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',229,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17107,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17107,2,1,'roast',1495,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (17107,3,1,'oz',28.35,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17108,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17108,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 195 g)',69,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17109,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17109,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',208,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17110,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17110,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17111,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17111,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17112,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17112,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17113,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17113,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17114,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17114,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',163,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17115,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17115,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',215,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17116,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17116,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17117,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17117,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',191,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17118,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17118,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',258,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17119,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17119,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17120,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17120,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17121,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17121,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',251,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17122,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17122,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 385 g)',304,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17123,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17123,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 385 g)',173,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17124,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17124,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',283,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17125,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17125,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 385 g)',289,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17126,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17126,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 385 g)',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17127,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17127,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',272,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17128,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17128,2,1,'chop',450,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (17129,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17129,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',186,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17130,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17130,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17131,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17131,2,1,'chop',450,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (17131,3,1,'oz',28.35,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17132,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17132,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',174,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17133,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17133,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17134,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17134,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17135,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17135,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17136,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17136,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',269,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17137,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17137,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17138,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17138,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',183,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17139,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17139,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',251,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17140,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17140,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17141,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17141,2,1,'unit, cooked (yield from 1 lb raw meat)',263,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17142,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (17142,2,1,'oz',28.35,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (17142,3,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17143,1,3,'oz',85,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (17143,2,1,'unit, cooked (yield from 1 lb raw meat)',299,'g',1,'1996-09-30','2013-12-26');
INSERT INTO `cndb_wght` VALUES (17144,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17144,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17145,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17145,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17147,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17147,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',277,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17148,1,3,'oz',85,'g',1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_wght` VALUES (17149,1,1,'patty (cooked from 4 oz raw)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17149,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17151,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17151,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',313,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17152,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17152,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17153,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17153,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17154,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17155,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17155,2,1,'roast with bone',325,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17156,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17156,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17157,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17157,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17159,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17159,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17160,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17160,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17161,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17161,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17162,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17162,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17163,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17163,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17164,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17164,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17165,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17165,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17166,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17166,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17167,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17167,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17168,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (17168,2,1,'lb',453.6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (17169,1,3,'oz',85,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (17169,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',340,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (17170,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17170,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17171,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17171,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17172,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17172,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17173,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17173,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17176,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17176,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',399,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17177,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17177,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17178,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17178,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',313,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17179,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17179,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',299,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17180,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17180,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17181,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17181,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',299,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17182,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17182,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',399,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17183,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17183,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17184,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17184,2,1,'piece, cooked (yield from 1 lb raw meat, boneless)',313,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17185,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17185,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17186,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17186,2,1,'unit, cooked (yield from 1 lb raw meat)',347,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17187,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17187,2,1,'unit, cooked (yield from 1 lb raw meat)',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17188,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17188,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17189,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17189,2,1,'unit, cooked (yield from 1 lb raw meat)',339,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17190,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17190,2,1,'unit, cooked (yield from 1 lb raw meat)',330,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17191,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17191,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17192,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17192,2,1,'unit, cooked (yield from 1 lb raw meat)',191,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17193,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17193,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17194,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17194,2,1,'unit, cooked (yield from 1 lb raw meat)',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17195,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17195,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17196,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17196,2,1,'unit, cooked (yield from 1 lb raw meat)',255,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17197,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17197,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17198,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17198,2,1,'unit, cooked (yield from 1 lb raw meat)',184,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17199,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17199,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17200,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17200,2,1,'unit, cooked (yield from 1 lb raw meat)',336,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17201,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17201,2,1,'unit, cooked (yield from 1 lb raw meat)',322,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17202,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17202,2,1,'lb',453,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17203,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17203,2,1,'slice',80,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17204,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17204,2,1,'slice',67,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17205,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17205,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17206,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17206,2,1,'unit, cooked (yield from 1 lb raw meat)',381,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17207,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17207,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17208,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17208,2,1,'unit, cooked (yield from 1 lb raw meat)',300,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17209,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17209,2,8,'oz',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17210,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17210,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17211,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17211,2,1,'unit, cooked (yield from 1 lb raw meat)',231,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17212,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17212,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17213,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17213,2,1,'unit, cooked (yield from 1 lb raw meat)',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17214,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17214,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17215,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17215,2,1,'unit, cooked (yield from 1 lb raw meat)',295,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17216,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17216,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17217,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17217,2,1,'unit, cooked (yield from 1 lb raw meat)',345,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17218,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17218,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17219,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17220,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17220,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17221,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17221,2,1,'unit, cooked (yield from 1 lb raw meat)',255,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17222,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17222,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17223,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17223,2,1,'unit, cooked (yield from 1 lb raw meat)',255,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17224,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17224,2,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17225,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17225,2,1,'unit, cooked (yield from 1 lb raw meat)',313,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17226,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17226,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17227,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17227,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17228,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17228,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17229,1,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',148,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17229,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17230,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17230,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17231,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17231,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',260,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17232,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17232,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17233,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17233,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',267,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17234,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17234,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17235,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17235,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',260,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17236,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17236,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 102 g)',79,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17237,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17237,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 102 g)',53,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17238,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17238,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',265,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17239,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17239,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17240,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17240,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',222,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17241,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17241,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',248,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17242,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17242,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17243,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17243,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',213,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17244,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17244,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',242,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17245,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17245,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',263,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17246,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17246,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 102 g)',84,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17247,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17247,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 102 g)',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17248,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17248,2,1,'steak, excluding refuse (yield from 1 raw steak, with refuse, weighing 102 g)',59,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17249,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17249,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17250,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17250,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17251,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17251,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',207,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17252,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17252,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17253,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17253,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17254,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17254,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17255,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17255,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',242,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17256,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17256,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17257,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17257,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17258,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17258,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17259,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17259,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',253,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17260,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17260,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 85 g)',63,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17261,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17261,2,1,'chop, excluding refuse (yield from 1 raw chop, with refuse, weighing 85 g)',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17262,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17262,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17263,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17263,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',233,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17264,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17264,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17265,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17265,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',233,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17267,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17267,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17267,3,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17268,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17268,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17268,3,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17269,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17269,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17269,3,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17270,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17271,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17271,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17272,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17272,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',283,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17273,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17273,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',291,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17274,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17274,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',274,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17275,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17275,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',237,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17276,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17276,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17277,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17277,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',194,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17278,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17278,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17279,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17279,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',223,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17280,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17280,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17280,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17281,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17281,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',270,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17282,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17282,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17282,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17283,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17283,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17284,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17284,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17284,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17285,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17285,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',248,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17286,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17286,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17286,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17287,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17287,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',211,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17288,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17288,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17288,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17289,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17289,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17290,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17290,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17290,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17291,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17291,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17292,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17292,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17292,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17293,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17293,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',251,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17294,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17294,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17294,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17295,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17295,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',277,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17296,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17296,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17296,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17297,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17297,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',246,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17298,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17298,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17298,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17299,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17299,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',306,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17300,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17300,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17300,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17301,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17301,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',259,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17302,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17303,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17304,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17305,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17306,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17307,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17308,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17309,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17310,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17310,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17311,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17312,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17312,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17313,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17314,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17314,2,1,'chop',63,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17315,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17315,2,1,'chop',54,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17316,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17316,2,1,'chop',63,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17316,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17317,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17317,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',241,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17317,3,1,'chop',54,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17318,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17318,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17318,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17319,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17319,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',262,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17320,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17320,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17320,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17321,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17321,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',222,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17322,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17322,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17323,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17324,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17324,2,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17325,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17326,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17326,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17326,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17327,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17327,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',273,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17328,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17328,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17328,3,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17329,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17329,2,1,'piece, cooked, excluding refuse (yield from 1 lb raw meat with refuse)',233,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17330,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17330,2,1,'patty',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17331,1,1,'patty ( yield from 112.7 g raw meat )',87,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17331,2,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17332,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17332,2,1,'steak ( yield from 309.7 g raw meat )',194,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17333,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17333,2,1,'roast ( yield from 1247 g raw meat ) ( 3 to 5 lb roast)',774,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17334,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17334,2,1,'roast (3 to 5 lb roast)',1237,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17335,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17335,2,1,'steak ( yield from 232.8 g raw meat )',179,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17336,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17336,2,1,'steak',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17337,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17337,2,1,'steak',489,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17338,1,1,'patty ( yield from 102.2 g raw meat )',102,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17339,1,1,'patty ( yield from 104.1 g raw meat )',95,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17339,2,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17340,1,1,'steak ( yield from 148.1 g raw meat )',114,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17340,2,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17341,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17341,2,1,'steak ( yield from 233.1 g raw meat )',176,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17342,1,1,'steak ( yield from 123.5 g raw meat )',92,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17342,2,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17343,1,1,'patty (cooked from 4 oz raw)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17343,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17344,1,1,'patty',93,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17344,2,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17345,1,1,'steak',54,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17345,2,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17346,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17346,2,1,'roast (3 to 5 lb roast)',293,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17347,1,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17347,2,1,'roast ( yield from 271.8 g raw meat ) (0.5 to 1 lb roast)',202,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17348,1,1,'steak ( yield from 134.9 g raw meat )',102,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17348,2,1,'serving ( 3 oz )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17349,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17349,2,1,'roast with bone',235,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17350,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17350,2,1,'roast with bone',235,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17351,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17351,2,1,'roast with bone',330,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17352,1,3,'oz',85,'g',1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (17352,2,1,'roast with bone',330,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (17353,1,1,'serving (4 oz)',113,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (17354,1,3,'oz',85,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17357,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17358,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17359,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17360,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17361,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17362,1,3,'oz',85,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17363,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17364,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17365,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17366,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17367,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17368,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17369,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17370,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17371,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17372,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17373,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17374,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17375,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17376,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17377,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17378,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17379,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17380,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17381,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17382,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17383,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17384,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17385,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17386,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17387,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17388,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17389,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17390,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17391,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17392,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17393,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17394,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17395,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17396,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17397,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17398,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17399,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17400,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17401,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17402,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17403,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17404,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17405,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17406,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17407,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17408,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17409,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17410,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17411,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17412,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17413,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17414,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17415,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17416,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17417,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17418,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17419,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17420,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17421,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17422,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17423,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17424,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17425,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17425,2,1,'cutlet',44,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17426,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17426,2,1,'cutlet',55,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17426,3,1,'serving',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17427,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17427,2,1,'chop',153,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17428,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17428,2,1,'serving',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17428,3,1,'shank whole',1270,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17429,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17429,2,1,'shank cross cut',187,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17430,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17430,2,1,'chop',352,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17431,1,4,'oz',113,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17432,1,3,'oz',85,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17433,1,4,'oz',113,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17434,1,3,'oz',85,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17435,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17435,2,1,'serving',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17435,3,1,'shank whole',1270,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17436,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17436,2,1,'shank cross cut',187,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17437,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17437,2,1,'chop',153,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17438,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17438,2,1,'chop',352,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (17439,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17439,2,1,'leg bottom, boneless',723,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17440,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17440,2,1,'leg hindshank, heel on',418,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17441,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17441,2,1,'leg hindshank, heel on',530,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17442,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17442,2,1,'roast',121,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17443,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17443,2,1,'roast',146,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17444,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17444,2,1,'leg bottom, boneless',989,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17445,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17445,2,1,'leg trotter off',1808,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17446,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17446,2,1,'leg trotter off',2674,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17447,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17447,2,1,'roast',329,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17448,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17448,2,1,'roast',447,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17449,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17450,1,4,'oz',113,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17452,1,4,'oz',113,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17453,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17453,2,1,'leg bottom, boneless',723,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17454,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17454,2,1,'leg bottom, boneless',989,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17455,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17455,2,1,'leg hindshank, heel on',418,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17456,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17456,2,1,'leg hindshank, heel on',530,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17457,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17457,2,1,'leg trotter off',1808,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17458,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17458,2,1,'leg trotter off',2674,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17459,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17459,2,1,'roast',121,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17460,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (17460,2,1,'roast',146,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17461,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17461,2,1,'chop',43,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17462,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17462,2,1,'roast',329,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17463,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17463,2,1,'roast',447,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17464,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (17464,2,1,'chop',43,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (18001,1,1,'bagel',99,'g',1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18001,2,1,'mini bagel (2-1/2" dia)',26,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18001,3,1,'small bagel (3" dia)',69,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18001,4,1,'medium bagel (3-1/2" to 4" dia)',105,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18001,5,1,'large bagel (4-1/2")',131,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18001,6,1,'oz',28.35,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (18002,1,1,'mini bagel (2-1/2" dia)',24,'g',1,'1997-08-29','2010-03-24');
INSERT INTO `cndb_wght` VALUES (18002,2,1,'small bagel (3" dia)',65,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18002,3,1,'medium bagel (3-1/2" to 4" dia)',99,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18002,4,1,'large bagel (4-1/2")',123,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18002,5,1,'OZ',28.35,'g',1,'2002-09-06','2010-01-04');
INSERT INTO `cndb_wght` VALUES (18003,1,1,'oz',28.35,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18003,2,1,'mini bagel (2-1/2" dia)',26,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18003,3,1,'small bagel (3" dia)',69,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18003,4,1,'medium bagel (3-1/2" to 4" dia)',105,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18003,5,1,'large bagel (4-1/2" dia)',131,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18005,1,1,'mini bagel (2-1/2" dia)',26,'g',1,'1997-08-29','2010-03-24');
INSERT INTO `cndb_wght` VALUES (18005,2,1,'small bagel (3" dia)',69,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18005,3,1,'medium bagel (3-1/2" to 4" dia)',105,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18005,4,1,'large bagel (4-1/2" dia)',131,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18005,5,1,'OZ',28.35,'g',1,'2002-09-06','2010-01-04');
INSERT INTO `cndb_wght` VALUES (18006,1,1,'mini bagel (2-1/2" dia)',24,'g',1,'1997-08-29','2010-03-24');
INSERT INTO `cndb_wght` VALUES (18006,2,1,'small bagel (3-1/2" to 4"dia)',65,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18006,3,1,'medium bagel (4" dia)',99,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18006,4,1,'large bagel (4-1/2" dia)',123,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18006,5,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18007,1,1,'mini bagel (2-1/2" dia)',26,'g',1,'1997-08-29','2010-03-24');
INSERT INTO `cndb_wght` VALUES (18007,2,1,'small bagel (3" dia)',69,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18007,3,1,'medium bagel (3-1/2" to 4" dia)',105,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18007,4,1,'large bagel (4-1/2" dia)',131,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18007,5,1,'OZ',28.35,'g',1,'2002-09-06','2010-01-04');
INSERT INTO `cndb_wght` VALUES (18009,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18009,2,1,'large',77,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18009,3,1,'medium',51,'g',1,'1998-01-15','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18009,4,1,'small',35,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18009,5,1,'biscuit (2-1/2" dia)',35,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18010,1,1,'cup, purchased',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18010,2,1,'cup, homemade',114,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18010,3,1,'cup, poured from box',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18010,4,1,'cup, spooned into cup',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18010,5,0.33,'cup (NLEA serving size)',40,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18010,6,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18011,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18012,1,1,'serving 1 biscuit',58,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18012,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18013,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18013,2,1,'biscuit (2-1/4" dia)',21,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18014,1,1,'biscuit',58,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18014,2,1,'biscuit',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18014,3,1,'package',398,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18014,4,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18015,1,1,'biscuit',51,'g',1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18015,2,1,'biscuit (2-1/2" dia)',27,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18015,3,1,'oz',28.35,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (18016,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18016,2,1,'biscuit (4" dia)',101,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18016,3,1,'small (1-1/2" dia)',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18016,4,1,'biscuit (2-1/2" dia)',60,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18017,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18017,2,1,'biscuit (2-1/2" dia)',44,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18019,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18019,2,1,'individual loaf (include Keebler Elfin Loaves)',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18019,3,1,'slice',60,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18021,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18021,2,1,'slice',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18022,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18022,2,1,'package (8.5 oz)',241,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18023,1,1,'muffin',51,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18023,2,1,'piece',60,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18023,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18024,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18024,2,1,'piece',65,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18025,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18025,2,1,'cubic inch',3.2,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18025,3,1,'slice, large or thick',30,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18025,4,1,'slice, regular',25,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18025,5,1,'slice regular, crust not eaten',12.2,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18025,6,1,'slice',25,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18025,7,1,'slice, thin',20,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18025,8,1,'slice thin, crust not eaten',9.4,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18027,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18027,2,1,'slice (5" x 3" x 1/2")',40,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18028,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18028,2,1,'slice (5" x 3" x 1/2")',37,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18029,1,1,'oz',28.35,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18029,2,1,'slice',139,'g',1,'1994-09-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18030,1,1,'oz',28.35,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18030,2,1,'slice, small',29,'g',1,'1994-09-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18030,3,1,'slice, medium',59,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18030,4,1,'slice, large',88,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18032,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18033,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18033,2,1,'slice',29,'g',1,'1994-09-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (18036,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18036,2,1,'slice regular',24,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (18036,3,1,'slice large',38,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (18037,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18037,2,1,'slice',30,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18038,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18038,2,1,'slice',27,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18039,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18039,2,1,'slice',27,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18040,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18040,2,1,'slice',25,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18041,1,1,'pita, large (6-1/2" dia)',60,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18041,2,1,'pita, small  (4" dia)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18042,1,1,'pita, large (6-1/2" dia)',64,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18042,2,1,'pita, small  (4" dia)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18043,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18043,2,1,'slice',19,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18044,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18044,2,1,'slice, regular',26,'g',1,'1994-10-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18044,3,1,'slice, snack-size',7,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18044,4,1,'slice, thin',20,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18044,5,1,'slice (5" x 4" x 3/8")',32,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18047,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18047,2,1,'slice, large',32,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18047,3,1,'slice',26,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18047,4,1,'slice, thin',23,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18048,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18048,2,1,'slice, large',29,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18048,3,1,'slice',24,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18048,4,1,'slice, thin',21,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18049,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18049,2,1,'slice',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18050,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18050,2,1,'slice',19,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18051,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18051,2,1,'slice',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18053,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18053,2,1,'slice',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18053,3,1,'slice, thick',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18053,4,1,'slice, thin',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18055,1,1,'oz',28.35,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18055,2,1,'slice',21,'g',1,'1998-01-15','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18057,1,1,'oz',28.35,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18057,2,1,'slice',23,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18059,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18059,2,1,'slice',27,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18060,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18060,2,1,'slice, regular',32,'g',1,'1994-09-29','2010-03-24');
INSERT INTO `cndb_wght` VALUES (18060,3,1,'slice, snack-size',7,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18060,4,1,'slice, thin',25,'g',1,'2002-09-06','2010-03-24');
INSERT INTO `cndb_wght` VALUES (18061,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18061,2,1,'slice, large',29,'g',1,'1994-10-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18061,3,1,'slice, regular',24,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18061,4,1,'slice, thin',18,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18064,1,1,'slice',29,'g',1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_wght` VALUES (18065,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18065,2,1,'slice',24,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18069,1,1,'slice',29,'g',1,'1997-08-29','2015-06-19');
INSERT INTO `cndb_wght` VALUES (18069,2,1,'oz',28.35,'g',1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18069,3,1,'cup, crumbs',45,'g',1,'2002-09-06','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18069,4,1,'cup, cubes',35,'g',1,'2002-09-06','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18069,5,1,'slice, large',30,'g',1,'2002-09-06','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18069,6,1,'slice',25,'g',1,'2002-09-06','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18069,7,1,'slice crust not eaten',12,'g',1,'2002-09-06','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18069,8,1,'slice, thin',20,'g',1,'2002-09-06','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18069,9,1,'slice thin, crust not eaten',9,'g',1,'2002-09-06','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18069,10,1,'slice, very thin',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18070,1,1,'oz',28.35,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18070,2,1,'cup, crumbs',45,'g',1,'1994-09-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18070,3,1,'cup, cubes',42,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18070,4,1,'slice, large',27,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18070,5,1,'slice crust not eaten',11,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18070,6,1,'slice, thin',17,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18070,7,1,'slice thin, crust not eaten',8,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18070,8,1,'slice, very thin',13,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18070,9,1,'slice',22,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18071,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18071,2,1,'slice',44,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18073,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18073,2,1,'slice',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18073,3,1,'slice, thin (3-3/4" x 5" x 3/8")',33,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18075,1,1,'slice',32,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18075,2,1,'oz',28.35,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18076,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18076,2,1,'slice',25,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18077,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18077,2,1,'slice, regular (4" x 5" x 3/4")',46,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18077,3,1,'slice, thin (3-3/4" x 5" x 3/8")',33,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18078,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18078,2,1,'slice',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18078,3,1,'slice, thin (3-3/4" x 5" x 3/8")',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18079,1,1,'oz',28.35,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18079,2,1,'cup',108,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18080,1,1,'cup, small pieces',46,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18080,2,1,'stick, small (approx 4-1/4" long)',5,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18080,3,1,'stick (7-5/8" x 5/8")',10,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18080,4,1,'stick (9-1/4" x 3/8")',6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18081,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18081,2,1,'package (6 oz)',170,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18082,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18082,2,0.5,'cup',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (18084,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18084,2,1,'package (6 oz)',170,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18085,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18085,2,0.5,'cup',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (18086,1,1,'piece (1/12 of 12 oz cake)',28,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18086,2,1,'cake (9" dia x 4")',340,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18088,1,1,'piece (1/12 of 10" dia)',50,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18088,2,1,'tube cake (10" dia, 4-3/8" high)',596,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18090,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18090,2,1,'piece (1/6 of pie)',92,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18092,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18092,2,1,'package (18 oz)',510,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18095,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18095,2,1,'piece (1/8 cake)',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18096,1,1,'piece (1/12 of a cake)',138,'g',1,'1997-08-29','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18096,2,1,'cake',1660,'g',1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18096,3,1,'piece (1/8 of 18 oz cake)',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18096,4,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18097,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18097,2,1,'package (18.25 oz)',517,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18101,1,1,'piece (1/12 of 9" dia)',95,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18101,2,1,'cake, 2-layer (8" or 9" dia)',1137,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18102,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18102,2,1,'piece (1/12 of 9" dia)',112,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18103,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18103,2,1,'piece (1/6 of 16 oz cake)',76,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18104,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18104,2,1,'individual cake',57,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18104,3,1,'piece (1/9 of 20 oz cake)',63,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18105,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18105,2,1,'piece (1/6 of 19 oz cake)',90,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18106,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18106,2,1,'piece (1/8 cake)',50,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18108,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18108,2,1,'piece (1/8 of 8" x 5-3/4" cake)',56,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18110,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18110,2,1,'piece',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18114,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18114,2,1,'package (14.5 oz)',411,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18116,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18116,2,1,'piece (1/9 of 8" square)',74,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18119,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18119,2,1,'piece (1/9 of 8" square)',115,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18120,1,0.167,'loaf 1/6 of the loaf',61,'g',1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_wght` VALUES (18120,2,1,'piece individually wrapped cake',49,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18121,1,1,'piece (1/10 of 10.6 oz cake)',30,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18121,2,1,'piece (1/12 of 12 oz cake)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18121,3,1,'snack cake (2.5 oz)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18126,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18127,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18127,2,1,'cupcake',50,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18128,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18128,2,1,'cake',42,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (18131,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18131,2,1,'package (8 oz)',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18133,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18133,2,1,'piece (1/12 of 16 oz cake)',38,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18134,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18134,2,1,'piece (1/12 of 10 inch cake)',63,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18135,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18135,2,1,'package (18.50 oz)',524,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18139,1,1,'piece (1/12 of 9" dia)',74,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18139,2,1,'cake, 2-layer (8" or 9" dia)',887,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18140,1,1,'piece (1/12 of a cake)',144,'g',1,'1997-08-29','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18140,2,1,'cake',1729,'g',1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18140,3,1,'piece (1/8 of 18 oz cake)',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18140,4,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18141,1,1,'serving',67,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18141,2,1,'oz',28.35,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18142,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18142,2,1,'package (18.50 oz)',524,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18144,1,1,'serving',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18144,2,1,'package (18.50 oz)',524,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18144,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18146,1,1,'piece (1/12 of 8" dia)',68,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18146,2,1,'cake, 2-layer (8" dia)',817,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18147,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18147,2,1,'piece (1/6 of 17 oz cake)',80,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18147,3,1,'piece (1 NLEA serving)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18148,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18148,2,1,'piece (1/12 of 9" dia)',99,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18151,1,1,'oz',28.35,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18151,2,1,'square, large (2-3/4" sq x 7/8")',56,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18151,3,1,'package, Little Debbie (twin wrapped)',61,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18152,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18152,2,1,'package (21.5 oz)',610,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18154,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18154,2,1,'brownie (2" square)',24,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18155,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18155,2,1,'cookie',5,'g',1,'1994-10-20','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18156,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18156,2,1,'cookie',21,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18157,1,1,'oz',28.35,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18157,2,1,'cup, crumbs',112,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18157,3,1,'wafer',6,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18158,1,1,'serving 3 cookies',34,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18158,2,1,'oz',28.35,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18159,1,1,'cookie',12.9,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18159,2,1,'cookie Pepperidge Farm Chocolate Chunk Pecan',12,'g',1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18159,3,1,'oz',28.35,'g',1,'1994-09-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18159,4,1,'cookie (average weight of 1 cookie, variety of brands)',12.2,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18159,6,1,'cookie, big (3-1/2" - 4" dia) (include Grandma brand)',40,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18159,7,1,'cookie, medium (2-1/4" dia)',10,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18159,8,1,'cookie, large (include Keebler Rich ''n Chips, Pecan Chips Delux)',14,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18159,9,1,'cookie, bite size (include Mini Chips Ahoy!)',2.2,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (18160,1,1,'cookie',14.2,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18160,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18160,3,1,'cookie',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18160,4,1,'cookie (average weight of 1 cookie)',12.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18161,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18161,2,1,'package (17.5 oz)',496,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18163,1,1,'serving',33,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18163,2,1,'portion, dough spoon from roll',29,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18163,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18164,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18164,2,1,'cookie, medium (2-1/4" dia)',12,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18165,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18165,2,1,'bar (2" square)',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18165,3,1,'cookie, medium (2-1/4" dia)',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18166,1,3,'cookie',36,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18166,2,1,'oz',28.35,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18167,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18167,2,1,'cookie',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18168,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18168,2,1,'cookie',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18170,1,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18170,2,1,'Figaroo (2 square halves)',43,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18170,3,1,'cookie',16,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18170,4,1,'individual package (2 oz package containing 2 3" bars)',57,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18171,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18171,2,1,'cookie',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18172,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18172,2,1,'cookie',7,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18172,3,1,'large (approx 3-1/2" to 4" dia)',32,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18173,1,1,'oz',28.35,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18173,2,1,'cracker',15,'g',1,'1994-09-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18173,3,1,'cup, crushed',84,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18173,4,1,'large rectangular piece or 2 squares or 4 small rectangular pieces',14,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18174,1,3,'pieces',27,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18174,2,1,'oz',28.35,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18175,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18175,2,1,'anisette sponge (4" x 1-1/8" x 7/8")',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18175,3,1,'breakfast treat (approx 4" x 2" x 7/8")',24,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18175,4,1,'ladyfinger',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18176,1,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18176,2,1,'Fudge Marshmallow',28,'g',1,'1997-08-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (18176,3,1,'pie, marshmallow (3" dia x 3/4")',39,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18176,4,1,'cookie, small (1-3/4" dia x 3/4")',13,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18177,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18177,2,1,'large (3-1/2" to 4" dia) (include Archway brand)',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18177,3,1,'medium',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18177,4,1,'cookie, Little Debbie',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18178,1,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18178,2,1,'cookie, big (3-1/2" - 4" dia) (include Archway brand, Grandma brand)',25,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18178,3,1,'large',18,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18179,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18179,2,1,'cookie',15,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18180,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18180,2,1,'package (17.5 oz)',496,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18182,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18182,2,1,'portion, dough for 1 cookie',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18183,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18183,2,1,'cookie',12,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18184,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18184,2,1,'cookie',24,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (18185,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18185,2,1,'cookie',31,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18186,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18186,2,1,'cookie',15,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18187,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18187,2,1,'portion, dough for 1 cookie',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18188,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18188,2,1,'cookie',12,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18189,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18189,2,1,'cookie (3" dia)',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18190,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18190,2,1,'cookie',14,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18191,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18191,2,1,'cookie',15,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18192,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18192,2,1,'cookie',11.8,'g',1,'1994-09-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18193,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18193,2,1,'cookie (2" dia)',14,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18196,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18196,2,1,'package (8.5 oz)',241,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18198,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18198,2,1,'cookie, medium (1-5/8" dia)',7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18199,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18199,2,1,'cookie',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18200,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18200,2,1,'cookie, medium (1-5/8" dia)',7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18201,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18201,2,1,'cookie',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18202,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18202,2,1,'wafer',4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18204,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18204,2,1,'cookie',17,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18205,1,1,'serving',33,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18205,2,1,'cookie dough for 1rolled cookie',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18205,3,1,'cookie 1 pre-sliced cookie dough',26,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18205,4,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18206,1,1,'oz',28.35,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18206,2,1,'cookie 1 rolled cookie dough',15,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18206,3,1,'cookie 1 pre-sliced cookie dough',23,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18209,1,3,'cookies',36,'g',1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18209,2,1,'cookie',10.1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18209,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18210,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18210,2,1,'cookie, oval (3-1/8" x 1-1/4" x 3/8")',15,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18210,3,1,'cookie, round (1-3/4" dia)',10,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18211,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18211,2,1,'sheet',245,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18211,3,1,'shell',40,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18212,1,1,'oz',28.35,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18212,2,1,'cup, crumbs',80,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18212,3,1,'large',6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18212,4,1,'medium',4,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18212,5,1,'small',3,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18213,1,8,'wafers',30,'g',1,'1997-08-29','2016-02-06');
INSERT INTO `cndb_wght` VALUES (18213,2,8,'wafers mini wafers',11.6,'g',1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_wght` VALUES (18214,1,0.5,'oz',14.2,'g',1,'1998-01-15','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18214,2,1,'cup, bite size',62,'g',1,'1995-06-19','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18214,3,1,'cup, crushed',72,'g',1,'1999-03-22','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18214,4,1,'gold fish',0.6,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18214,5,1,'bag, single serving',28,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18214,6,1,'snack stick',2,'g',1,'2002-09-06','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18214,7,1,'cracker (1" square)',1,'g',1,'2002-09-06','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18215,1,0.5,'oz',14.2,'g',1,'1994-10-20','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18215,2,1,'cup, crushed',83,'g',1,'1998-01-15','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18215,3,6,'cracker',39,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18215,4,1,'sandwich',6.5,'g',1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18216,1,0.5,'oz',14.2,'g',1,'1994-09-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18216,2,1,'cup, crushed',55,'g',1,'1999-03-22','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18216,3,1,'crispbread',10,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18216,4,1,'wafer, thin',2,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18216,5,1,'wafer',10,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18216,6,1,'cracker, Norwegian flatbread (4-3/4" x 2-3/4" x 1/16")',5.8,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18216,7,1,'wafer, Rye Krisp (triple cracker)',25,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18216,8,1,'crispbread, Wasa rye',10,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18217,1,0.5,'oz',14.2,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18217,2,1,'matzo',28,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18218,1,0.5,'oz',14.2,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18218,2,1,'matzo',28,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18219,1,0.5,'oz',14.2,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18219,2,1,'matzo',28,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18220,1,0.5,'oz',14.2,'g',1,'1994-09-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18220,2,1,'cup pieces',30,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18220,3,1,'cup, rounds',33,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18220,4,1,'melba round',3,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18220,5,1,'piece (3-3/4" x 1-3/4" x 1/8")',5,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18221,1,0.5,'oz',14.2,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18221,2,1,'toast',5,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18222,1,0.5,'oz',14.2,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18222,2,1,'toast',5,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18223,1,0.5,'oz',14.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18223,2,1,'cracker',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18224,1,0.5,'oz',14.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18224,2,1,'rusk',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18225,1,0.5,'oz',14.2,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18225,2,1,'cracker, sandwich',7,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18226,1,0.5,'oz',14.2,'g',1,'1994-10-20','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18226,2,1,'cup, crushed',61,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18226,3,1,'cracker (4-1/2" x 2-1/2" x 1/8")',11,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18226,4,1,'cracker, triple',25,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18227,1,0.5,'oz',14.2,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18227,2,1,'cracker, triple',22,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18228,1,5,'crackers',14.9,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18228,2,0.5,'oz',14.2,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18228,3,1,'cup, crushed',70,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18228,4,5,'crackers square (1 serving)',15,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18228,5,1,'cracker square',3,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18228,6,1,'cracker, round large',10,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18228,7,1,'cracker, oyster',1,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18228,8,1,'cracker, rectangle',6,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18228,9,1,'cup oyster crackers',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18229,1,5,'crackers',16,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18229,2,5,'crackers, regular size, round (1 serving)',16,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18229,3,1,'cracker, round',3.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18229,4,1,'cracker, rectangular',4,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18229,5,1,'cup crushed',52,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18230,1,0.5,'oz',14.2,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18230,2,1,'cracker, sandwich',7,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18231,1,0.5,'oz',14.2,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18231,2,1,'cracker, sandwich',7,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18232,1,16,'crackers 1 serving',34,'g',1,'1998-01-15','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18232,2,2,'crackers 1 serving',14.5,'g',1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18233,1,0.5,'oz',14.2,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18233,2,1,'cracker, sandwich',7,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18234,1,0.5,'oz',14.2,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18234,2,1,'cracker, sandwich',7,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18235,1,1,'serving',28,'g',1,'1998-01-15','2010-03-24');
INSERT INTO `cndb_wght` VALUES (18235,2,6,'crackers, Triscuits, regular size',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18235,3,1,'cracker',4.6,'g',1,'1997-08-29','2010-03-24');
INSERT INTO `cndb_wght` VALUES (18235,4,0.5,'oz',14.2,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18235,5,1,'cup, crushed',94,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18235,6,10,'Triscuit Bits',10,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18236,1,1,'oz',28.35,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18236,2,1,'cup',115,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18237,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18237,2,1,'eclair (5" x 2" x 1-3/4")',48,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18237,3,1,'cream puff shell',66,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18239,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18239,2,1,'croissant, mini',28,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18239,3,1,'croissant, small',42,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18239,4,1,'croissant, medium',57,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18239,5,1,'croissant, large',67,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18240,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18240,2,1,'croissant, medium',57,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18241,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18241,2,1,'croissant, small',42,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18241,3,1,'croissant, medium',57,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18241,4,1,'croissant, large',67,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18242,1,0.5,'oz',14.2,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18242,2,1,'cup',30,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18243,1,0.5,'oz',14.2,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18243,2,1,'cup',40,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18243,3,1,'package, fast food',10,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18243,4,4,'cubes',1,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18244,1,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18244,2,1,'large (approx 7" dia)',142,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18244,3,1,'small or frozen (approx 3" dia)',35,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18244,4,1,'pastry (4-1/4" dia)',65,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18244,5,1,'Toaster Strudel',53,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18244,6,1,'piece (1/8 of 15 oz ring)',53,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18245,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18245,2,1,'pastry',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18246,1,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18246,2,1,'large (approx 7" dia)',142,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18246,3,1,'small or frozen (approx 3" dia)',35,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18246,4,1,'pastry (4-1/4" dia)',71,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18246,5,1,'Toaster Strudel',53,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18246,6,1,'piece (1/8 of 15 oz ring)',53,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18248,1,1,'donut',40,'g',1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18248,2,1,'oz',28.35,'g',1,'1994-09-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18248,3,1,'doughnut stick',52,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18248,4,1,'doughnut, long type (twist) (4-1/2" long)',52,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18248,5,1,'doughnut medium (3-1/4" dia)',54,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18248,6,1,'doughnut, mini (1-1/2" dia) or doughnut hole',14,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18248,7,1,'doughnut, large (4" dia)',71,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (18249,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18249,2,1,'donettes (2" dia)',18,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18249,3,1,'doughnut, medium (approx 3" dia)',43,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18249,4,1,'doughnut large (approx 3-1/2" dia)',67,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18250,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18250,2,1,'doughnut, medium (approx 3" dia)',45,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18251,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18251,2,1,'doughnut (3-3/4" dia)',60,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18251,3,1,'doughnut, medium (approx 3" dia)',42,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18253,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18253,2,1,'cruller (3" dia)',41,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18254,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18254,2,1,'doughnut oval (3-1/2" x 2-1/2")',85,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18255,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18255,2,1,'doughnut hole',13,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18255,3,1,'doughnut stick',56,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18255,4,1,'extra large (approx 5" dia)',122,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18255,5,1,'jumbo (approx 6" dia)',157,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18255,6,1,'doughnut, large (approx 4-1/4" dia)',75,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18255,7,1,'doughnut, long type (twist) approx 5-1/4" x 2-1/2" x 1-1/2" high)',90,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18255,8,1,'doughnut medium (approx 3-3/4" dia)',64,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18255,9,1,'doughnut, small (approx 3" dia)',31,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18255,10,1,'doughnut (approx 1-1/2 oz)',42,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18255,11,1,'doughnut (3-3/4" dia)',60,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18255,12,1,'honeybun (4" x 3")',65,'g',1,'2007-11-28','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18255,13,1,'honeybun (4-1/2" x 3-1/2")',78,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18255,14,1,'honeybun (5" x 3-1/2")',85,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18255,15,1,'doughnut, medium (approx 3-3/4" dia)',60,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18255,16,1,'doughnut',63,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18256,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18256,2,1,'doughnut oval (3-1/2" x 2-1/2")',85,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18258,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18258,2,1,'muffin',57,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18259,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18259,2,1,'muffin',52,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18260,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18260,2,1,'muffin',66,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18262,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18262,2,1,'muffin',57,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18263,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18263,2,1,'muffin',52,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18264,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18264,2,1,'muffin',57,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18266,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18266,2,1,'muffin',66,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18268,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18268,2,1,'piece',59,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18269,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18269,2,1,'slice',65,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18270,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18270,2,1,'cup',152,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18270,3,1,'hush puppy',22,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18271,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18271,2,1,'cone',4,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18271,3,1,'large waffle cone',29,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18272,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18272,2,1,'cone',10,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18273,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18273,2,1,'muffin',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18274,1,1,'oz',28.35,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18274,2,1,'mini (1-1/4" dia)',17,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18274,3,1,'small (2-3/4" dia x 2")',66,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18274,4,1,'medium',113,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18274,5,1,'large (3-1/4" dia x 2-3/4")',139,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18274,6,1,'extra large',168,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18274,7,1,'muffin',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18275,1,1,'serving',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18275,2,1,'package, mix + drained berries',356,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18275,3,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18277,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18277,2,1,'muffin, toaster',33,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18278,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18278,2,1,'muffin',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18279,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18279,2,1,'mini',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18279,3,1,'small',66,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18279,4,1,'medium',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18279,5,1,'large',139,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18279,6,1,'extra large',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18280,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18281,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18281,2,1,'muffin, toaster',33,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18282,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18282,2,1,'muffin (2-3/4" dia x 2")',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18283,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18283,2,1,'mini',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18283,3,1,'small',66,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18283,4,1,'medium',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18283,5,1,'large',139,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18283,6,1,'extra large',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18284,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18284,2,1,'package (7 oz)',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18288,1,1,'oz',28.35,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18288,2,1,'pancake',41,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18288,3,1,'pancake (6" dia)',73,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18288,4,1,'mini pancake',10.1,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18288,5,1,'pancake',40,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18289,1,0.333,'cup',52,'g',1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_wght` VALUES (18289,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18289,3,1,'cup, poured from box',130,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18290,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18290,2,1,'pancake (4" dia)',38,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18290,3,1,'pancake (6" dia)',77,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18291,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18291,2,1,'cup, poured from box',112,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18292,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18292,2,1,'pancake (4" dia)',38,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18292,3,1,'pancake (6" dia)',77,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18293,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18293,2,1,'pancake (4" dia)',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18293,3,1,'pancake (6" dia)',77,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18294,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18294,2,1,'pancake (4" dia)',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18294,3,1,'pancake (6" dia)',77,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18295,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18295,2,1,'cup, poured from box',122,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18297,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18297,2,1,'package (8 oz)',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18299,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18299,2,1,'cup, poured from box',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18300,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18300,2,1,'pancake (4" dia)',44,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18300,3,1,'pancake (6" dia)',129,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18301,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18301,2,1,'piece (1/8 of 9" dia)',125,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18301,3,1,'piece (1/6 of 8" pie)',117,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18302,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18302,2,1,'piece (1/8 of 9" dia)',155,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18303,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18303,2,1,'piece (1/8 of 9" dia)',92,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18303,3,1,'piece (1/6 of 8" pie)',123,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18304,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18304,2,1,'pie (9" dia)',1186,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18304,3,1,'piece (1/8 of 9" dia)',144,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18305,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18305,2,1,'piece (1/8 of 9" dia)',125,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18305,3,1,'piece (1/6 of 8" pie)',117,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18306,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18306,2,1,'piece (1/8 of 9" dia)',147,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18308,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18308,2,1,'piece (1/8 of 9" dia)',125,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18308,3,1,'piece (1/6 of 8" pie)',117,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18309,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18309,2,1,'piece (1/8 of 9" dia)',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18310,1,1,'serving .167 pie',120,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18310,2,1,'oz',28.35,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18310,3,1,'piece (1/4 of 6" pie)',99,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18310,4,1,'piece (1/6 of 8" pie)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18312,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18312,2,1,'piece (1/8 of 9" dia)',95,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18313,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18313,2,1,'piece (1/6 of 7" pie)',64,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18313,3,1,'piece (1/8 of 7" pie)',48,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18314,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18314,2,1,'piece (1/8 of 9" dia)',94,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18316,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18316,2,1,'piece (1/6 of 8" pie)',104,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18317,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18317,2,1,'piece (1/6 of 8" pie)',105,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18319,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18319,2,1,'pie (5" x 3-3/4")',128,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18320,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18320,2,1,'piece (1/6 of 8" pie)',113,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18321,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18321,2,1,'piece (1/8 of 9" dia)',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18322,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18322,2,1,'piece (1/8 of 9" dia)',165,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18323,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18323,2,1,'piece (1/6 of 8" pie)',117,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18324,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18324,2,1,'slice',133,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (18324,3,1,'pie',833,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18325,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18325,2,1,'piece (1/8 of 9" dia)',122,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18326,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18326,2,1,'slice',133,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (18326,3,1,'pie',995,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18327,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18327,2,1,'piece (1/8 of 9" dia)',155,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18328,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18328,2,1,'piece (1/8 of 9" dia)',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18332,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18332,2,1,'package (10 oz)',284,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18333,1,1,'piece (1/8 of 9" crust)',20,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18333,2,1,'crust, single 9"',160,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18334,1,1,'piece (1/8 of 9" crust)',18,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18334,2,1,'pie crust (average weight of 1 frozen crust)',173,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18335,1,1,'pie crust (average weight of 1 baked crust)',154,'g',1,'1994-01-31','2009-02-11');
INSERT INTO `cndb_wght` VALUES (18336,1,1,'piece (1/8 of 9" crust)',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18336,2,1,'crust, single 9"',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18337,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18337,2,1,'shell',47,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18338,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18338,2,1,'sheet dough',19,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18339,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18339,2,1,'package (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18342,1,1,'roll (1 oz)',28,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18342,2,1,'each (pan, dinner, or small roll) (2" square, 2" high)',25,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18342,3,1,'roll (hamburger, frankfurter, onion roll, bun, large roll)',43,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18342,4,1,'roll (foot long frankfurter roll)',86,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18344,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18344,2,1,'roll (2-1/2" dia)',35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18345,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18345,2,1,'roll',33,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18346,1,1,'large (approx 3-1/2" to 4" dia)',43,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18346,2,1,'medium',36,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18346,3,1,'small (2-3/8" dia)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18347,1,1,'roll (1 oz)',28,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18348,1,1,'roll (1 oz)',28,'g',1,'1994-09-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18348,2,1,'roll (hamburger, frankfurter roll)',43,'g',1,'1999-03-22','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18348,3,1,'roll, large submarine, hoagie',135,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18348,4,1,'medium (2-1/2" dia)',36,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18348,5,1,'roll medium submarine, hoagie',94,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18348,6,1,'roll (small submarine, hoagie roll)',65,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18349,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18349,2,1,'roll',38,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18350,1,1,'roll 1 serving',44,'g',1,'1997-08-29','2016-02-06');
INSERT INTO `cndb_wght` VALUES (18350,2,1,'oz',28.35,'g',1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_wght` VALUES (18351,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18351,2,1,'roll',43,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18353,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18353,2,1,'roll (3-1/2" dia)',57,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18354,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18354,2,1,'piece',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18355,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18355,2,1,'roll',66,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18356,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18356,2,1,'large',83,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18356,3,1,'roll (2-3/4" square)',60,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18357,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18357,2,1,'roll',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18358,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18358,2,1,'roll',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18360,1,1,'shell',12.9,'g',1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18360,2,1,'taco',12.7,'g',1,'1994-09-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18360,3,1,'medium (approx 5" dia)',13.3,'g',1,'2002-09-06','2015-06-19');
INSERT INTO `cndb_wght` VALUES (18360,4,1,'large (6-1/2" dia)',21,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18360,5,1,'miniature (3" dia)',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18360,6,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18362,1,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18362,2,1,'pastry',54,'g',1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18363,1,1,'oz',28.35,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18363,2,1,'enchilada',19,'g',1,'1994-09-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18363,3,1,'tortilla',24,'g',1,'1998-01-15','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18364,1,1,'tortilla',48,'g',1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_wght` VALUES (18364,2,1,'oz',28.35,'g',1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18364,3,1,'tortilla medium (approx 6" dia)',30,'g',1,'2002-09-06','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18364,4,1,'package',407,'g',1,'2002-09-06','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18364,5,1,'tortilla (approx 10" dia)',72,'g',1,'2002-09-06','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18364,6,1,'tortilla (approx 12" dia)',117,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18364,7,1,'tortilla (approx 7-8" dia)',49,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18365,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18365,2,1,'waffle, square (4" square) (include frozen)',35,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (18367,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18367,2,1,'waffle, round (7" dia)',75,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18368,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18368,2,1,'wrapper, eggroll (7" square)',32,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18368,3,1,'wrapper, wonton (3-1/2" square)',8,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18369,1,1,'tsp',4.6,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18369,2,0.5,'tsp',2.3,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (18370,1,1,'tsp',4.6,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18370,2,0.5,'tsp',2.3,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (18371,1,1,'tsp',5,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18371,2,0.5,'tsp',2.5,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (18372,1,1,'tsp',4.6,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18372,2,0.5,'tsp',2.3,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (18373,1,1,'tsp',3,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18373,2,0.5,'tsp',1.5,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (18374,1,1,'cake (0.6 oz)',17,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18375,1,1,'tsp',4,'g',1,'1999-03-22','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18375,2,1,'tbsp',12,'g',1,'1995-06-19','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18375,3,1,'packet',7.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18376,1,1,'oz',28.35,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18376,2,1,'cup',120,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18377,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18377,2,1,'cookie (2-5/8" dia)',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18378,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18378,2,1,'cookie, medium (2-1/4" dia)',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18383,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18383,2,1,'slice',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18384,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18384,2,1,'slice',25,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18386,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18386,2,1,'muffin, toaster',31,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18388,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18388,2,1,'muffin, toaster',34,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18390,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18390,2,1,'pancake (4" dia)',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18390,3,1,'pancake (6" dia)',77,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18396,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18396,2,1,'large roll or bun (3-1/2" dia)',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18396,3,1,'roll (2-1/2" dia)',35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18399,1,1,'piece (1/8 of 9" crust)',30,'g',1,'1994-11-17','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18399,2,1,'crust, single 9"',244,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18400,1,0.5,'oz',14.2,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18400,2,1,'matzo',28,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18401,1,1,'CUP',129,'g',1,'1994-11-02','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18401,2,1,'crust, single 9"',176,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18401,3,1,'piece (1/8 of 9" crust)',22,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18402,1,1,'piece (1/8 of 9" crust)',24,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18402,2,1,'crust, single 9"',194,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18403,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18403,2,1,'waffle, round (4" dia)',33,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18403,3,1,'waffle, square (4" square)',33,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18406,1,1,'oz',28.35,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18406,2,1,'mini bagel (2-1/2" dia)',26,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18406,3,1,'small bagel (3" dia)',69,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18406,4,1,'medium bagel (3-1/2" to 4" dia)',105,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18406,5,1,'large bagel (4-1/2" dia)',131,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18407,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18407,2,1,'mini bagel (2-1/2" dia)',26,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18407,3,1,'small bagel (3" dia)',69,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18407,4,1,'medium bagel (3-1/2" to 4")',105,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18407,5,1,'large bagel (4-1/2" dia)',131,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18408,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18408,2,1,'mini bagel (2-1/2" dia)',26,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18408,3,1,'small bagel (3" dia)',69,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18408,4,1,'medium bagel (3-1/2" to 4" dia)',105,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18408,5,1,'large bagel (4-1/2" dia)',131,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18412,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18412,2,1,'package (8.5 oz)',241,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18413,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18413,2,1,'pita, large (6-1/2" dia)',60,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18414,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18414,2,1,'slice, large',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18414,3,1,'slice',26,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18414,4,1,'slice, thin',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18416,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18416,2,1,'cup, crumbs',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18416,3,1,'cup, cubes',35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18416,4,1,'slice, large',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18416,5,1,'slice',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18416,6,1,'slice, thin',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18417,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18417,2,1,'individual cake',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18417,3,1,'piece (1/9 of 20 oz cake)',63,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18418,1,1,'piece (1/10 of 10.6 oz cake)',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18418,2,1,'piece (1/12 of 12 oz cake)',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18418,3,1,'snack cake (2.5 oz)',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18419,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18419,2,1,'package (18.50 oz)',524,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18420,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18420,2,1,'package (18.50 oz)',524,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18421,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18421,2,1,'cookie',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18422,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18422,2,1,'cookie, medium (2-1/4" dia)',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18422,3,1,'cookie, bite size (include Mini Chips Ahoy!)',2.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18423,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18423,2,1,'anisette sponge (4" x 1-1/8" x 7/8")',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18423,3,1,'breakfast treat (approx 4" x 2" x 7/8")',24,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18423,4,1,'ladyfinger',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18424,1,0.5,'oz',14.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18424,2,1,'cup, crushed',70,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18424,3,1,'cup pieces',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18424,4,1,'cup, rounds',33,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18424,5,1,'melba round',3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18424,6,1,'piece (3-3/4" x 1-3/4" x 1/8")',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18424,7,1,'toast',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18425,1,0.5,'oz',14.2,'g',1,'1994-09-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18425,2,1,'cup oyster crackers',45,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18425,3,1,'cracker',3,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18425,4,1,'cracker, round large',10,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18425,5,1,'cracker, oyster',1,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18425,6,1,'cracker, rectangle',6,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18426,1,0.5,'oz',14.2,'g',1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18426,2,1,'cracker',3,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18427,1,0.5,'oz',14.2,'g',1,'1994-09-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18427,2,1,'cup, bite size',62,'g',1,'1998-01-15','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18427,3,1,'cup, crushed',72,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18427,4,1,'cracker, rectangular',4,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18427,5,1,'cracker, oval',3,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18427,6,1,'cracker, round',3,'g',1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18428,1,0.5,'oz',14.2,'g',1,'1997-08-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18428,2,1,'cup, crushed',83,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18428,3,1,'cracker',2,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18428,4,1,'cracker, thin square',2,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18429,1,0.5,'oz',14.2,'g',1,'1994-09-29','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18429,2,1,'cup, crushed',94,'g',1,'1998-01-15','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18429,3,1,'cracker',4,'g',1,'1999-03-22','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18429,4,1,'cracker, square',4,'g',1,'2002-09-06','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18429,5,10,'Triscuit Bits',10,'g',1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18430,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18430,2,1,'large (approx 7" dia)',142,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18430,3,1,'small or frozen (approx 3" dia)',35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18430,4,1,'pastry (4-1/4" dia)',65,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18430,5,1,'Toaster Strudel',53,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18430,6,1,'piece (1/8 of 15 oz ring)',53,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18431,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18431,2,1,'container (3 oz)',142,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18431,3,1,'small or frozen (approx 3" dia)',35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18431,4,1,'pastry (4-1/4" dia)',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18431,5,1,'Toaster Strudel',53,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18431,6,1,'piece (1/8 of 15 oz ring)',53,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18432,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18432,2,1,'slice',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18433,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18433,2,1,'pastry',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18434,1,0.5,'oz',14.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18434,2,1,'cup Cheez-its',62,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18434,3,1,'cup, crushed',72,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18434,4,1,'gold fish',0.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18434,5,1,'cracker (1" square)',1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18435,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18435,2,1,'pastry (4-1/4" dia)',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18436,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18436,2,1,'doughnut, medium (3-1/4" dia)',60,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18437,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18437,2,1,'muffin',57,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18438,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18438,2,1,'muffin',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18439,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18439,2,1,'muffin',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18443,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18443,2,1,'piece (1/8 of 9" dia)',125,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18443,3,1,'piece (1/6 of 8" pie)',117,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18444,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18444,2,1,'pie (5" x 3-3/4")',128,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18445,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18445,2,1,'pie (5" x 3-3/4")',128,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18446,1,1,'crust, single 9"',142,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18446,2,1,'piece (1/8 of 9" crust)',16,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18447,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18447,2,1,'package (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18448,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18448,2,1,'medium (approx 5" dia)',13,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18448,3,1,'miniature (3" dia)',5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18449,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18449,2,1,'tortilla, medium (approx 6" dia)',26,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18450,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18450,2,1,'tortilla, medium (approx 6" dia)',32,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18450,3,1,'tortilla (approx 10" dia)',72,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18450,4,1,'tortilla (approx 12" dia)',117,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18450,5,1,'tortilla (approx 7-8" dia)',49,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18451,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18451,2,1,'cake',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18453,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18453,2,1,'package (18.50 oz)',524,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18457,1,3,'saltines',15,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (18457,2,6,'saltines',30,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (18459,1,1,'tart',52,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18566,1,1,'muffin',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18927,1,6,'cracker 1 cracker = 6.5g',39,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18927,2,1,'sandwich',6.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18932,1,1,'waffle, square',39,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18932,2,1,'waffle, round',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18933,1,1,'oz',28,'g',1,'2006-02-23','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18933,2,1,'waffle round (4" dia)',33,'g',1,'2006-02-23','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18934,1,1,'waffle',35,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (18935,1,1,'waffle, round (4"dia)',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18936,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18936,2,1,'pancake',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18936,3,1,'serving (3 pancakes)',144,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18938,1,1,'piece',53,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18938,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18939,1,1,'pastry',51,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18940,1,1,'muffin small',71,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (18940,2,1,'oz',28.35,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (18942,1,1,'oz',28.35,'g',1,'2009-01-25','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18942,2,1,'crust',183,'g',1,'2009-01-25','2013-12-26');
INSERT INTO `cndb_wght` VALUES (18943,1,1,'crust',182,'g',1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_wght` VALUES (18944,1,0.125,'pie 1 pie (1/8 of 9" pie)',131,'g',1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_wght` VALUES (18944,2,1,'slice',137,'g',1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_wght` VALUES (18944,3,1,'pie',1137,'g',1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_wght` VALUES (18944,4,1,'oz',28.35,'g',1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_wght` VALUES (18945,1,1,'pie crust (average weight)',225,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18946,1,1,'pie crust',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18947,1,1,'pie crust (average weight)',202,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18948,1,1,'pie crust (average weight)',229,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18949,1,1,'serving',29,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (18949,2,1,'cracker',4.2,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (18949,3,6,'Triscuits, regular size',29,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (18950,1,1,'serving',29,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (18950,2,1,'cracker',1.8,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (18950,3,16,'crackers, Wheat Thins',29,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (18951,1,2,'waffles',70,'g',1,'2010-01-04','2015-01-07');
INSERT INTO `cndb_wght` VALUES (18952,1,1,'piece',12.3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18952,2,3,'pieces (mean serving weight, aggregated over brands)',37,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18953,1,1,'serving (approximate serving size)',55,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (18953,2,1,'cake square (average weight of whole item)',399,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (18954,1,1,'serving',55,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18954,2,1,'cake square',622,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18955,1,1,'slice (average weight of 1 slice)',63,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18959,1,1,'piece',86,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (18963,1,1,'slice presliced',43,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18963,2,1,'slice',59,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18964,1,1,'bun',65,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18965,1,1,'serving',30,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18966,1,1,'serving',14,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18967,1,1,'slice',28,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18968,1,1,'bagel',98,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18969,1,4,'oz',113,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18970,1,1,'tortilla',49,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18970,2,1,'package',484,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18971,1,1,'slice',32,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18972,1,1,'slice',48,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (18973,1,1,'piece',57,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (19002,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19002,2,1,'piece, large',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19003,1,1,'oz',28,'g',1,'1999-03-22','2015-06-19');
INSERT INTO `cndb_wght` VALUES (19003,2,1,'oz',28.35,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (19003,3,1,'bag (7 oz)',198,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (19004,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19004,2,1,'bag (7 oz)',198,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19005,1,1,'oz',28.35,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19007,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19007,2,2,'oz',57,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (19008,1,1,'oz crunchy (about 21 pieces)',28.35,'g',1,'1999-03-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (19008,2,1,'oz puffs (about 13 pieces)',28.35,'g',1,'1994-09-29','2019-02-13');
INSERT INTO `cndb_wght` VALUES (19010,1,1,'bar (1 oz)',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19013,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19013,2,1,'package',27,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19013,3,1,'packet (.75 oz)',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19014,1,1,'large',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19014,2,1,'small',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19015,1,1,'bar',21,'g',1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_wght` VALUES (19015,2,1,'bar (1 oz)',28,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19015,3,1,'bar',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19016,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19016,2,1,'bar',24,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19017,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19017,2,1,'bar',24,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19018,1,1,'cup',334,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (19018,2,0.25,'cup',84,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (19020,1,1,'bar (1 oz)',28,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19021,1,1,'bar (1 oz)',28,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19022,1,1,'bar (1.5 oz)',43,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19022,2,1,'bar (1 oz)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19024,1,1,'bar (1.25 oz)',35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19024,2,1,'bar (1 oz)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19025,1,1,'serving',40,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (19026,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19026,2,1,'bar',37,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19027,1,1,'bar (1 oz)',28,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19030,1,1,'serving',20,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (19031,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19031,2,2,'oz',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19034,1,1,'CUP',8,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19034,2,1,'oz',28.35,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19035,1,1,'CUP',11,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19035,2,1,'oz',28.35,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19036,1,1,'cake',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19036,2,2,'cakes',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19038,1,1,'oz (approx 2/3 cup)',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19038,2,2,'oz',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19039,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19040,1,1,'cup',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19040,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19041,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19041,2,0.5,'oz',14.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19042,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19042,2,1,'bag (7 oz)',198,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19043,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19043,2,1,'bag (7 oz)',198,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19045,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19045,2,1,'can (6 oz)',170,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19046,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19046,2,1,'can (6.75 oz)',198,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19047,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19047,2,10,'twists',60,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19048,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19048,2,1,'pretzel',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19050,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19050,2,2,'oz',57,'g',1,'2007-11-27','2007-11-27');
INSERT INTO `cndb_wght` VALUES (19051,1,1,'cake',9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19051,2,2,'cakes',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19052,1,1,'cake',9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19052,2,2,'cakes',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19053,1,1,'cake',9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19053,2,2,'cakes',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19056,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19056,2,1,'bag',213,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19057,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19058,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19058,2,1,'bag (7 oz)',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19059,1,1,'cup',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19059,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19059,3,1.5,'oz',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19061,1,1,'cup',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19061,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19061,3,1.5,'oz',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19062,1,1,'cup',146,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19062,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19062,3,1.5,'oz',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19063,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19063,2,1,'bag (8 oz)',227,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19070,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19070,2,3,'pieces',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19071,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19071,2,1,'bar (3 oz)',87,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19074,1,1,'package (2.5 oz)',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19074,2,1,'piece',10.1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19076,1,1,'piece',6.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19076,2,1,'bar 2.25 oz',64,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19076,3,1,'serving 6 pieces',40,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19077,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19078,1,1,'oz square Bakers',29,'g',1,'1994-11-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19078,2,1,'cup, grated',132,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (19078,3,0.5,'oz Hersheys',14.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19079,1,1,'cup chips',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19080,1,1,'serving',14.5,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19080,2,1,'cup large chips',182,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19080,3,1,'cup mini chips',173,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19080,4,1,'oz (approx 60 pcs)',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19080,5,1,'cup chips (6 oz package)',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19081,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19081,2,1,'bar (1.45 oz)',41,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19083,1,1,'patty, large',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19083,2,1,'patty, small',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19085,1,1,'cup chips',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19085,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19086,1,1,'cup chips',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19086,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19087,1,1,'bar (3 oz)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19087,2,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19087,3,1,'cup chips',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19088,1,1,'serving 1/2 cup',76,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19089,1,0.5,'CUP',107,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19090,1,0.5,'cup (4 fl oz)',86,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19094,1,0.5,'cup',153,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19094,2,1,'recipe yield',1531,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19095,1,1,'serving 1/2 cup',66,'g',1,'1994-09-29','2009-02-11');
INSERT INTO `cndb_wght` VALUES (19096,1,1,'serving 1/2 cup',88,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19097,1,0.5,'cup (4 fl oz)',74,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19097,2,1,'bar (2.75 fl oz)',66,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19099,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19100,1,1,'piece',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19101,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19102,1,1,'piece',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19103,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19104,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19106,1,1,'cup gumdrops',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19106,2,10,'gumdrops',36,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19106,3,10,'gummy bears',22,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19106,4,10,'gummy dinosaurs',63,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19106,5,10,'gummy fish',50,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19106,6,10,'gummy worms',74,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19106,7,1,'spice stick',9.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19106,8,1,'spice drop',24,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19106,9,1,'gumdrop, small (1/2" dia)',3.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19106,10,1,'gumdrop, medium (3/4" dia)',4.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19106,11,1,'gumdrop, large (1" dia)',11.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19106,12,1,'jelly ring (1-1/4" dia)',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19107,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19107,2,1,'piece',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19107,3,1,'piece, small',3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19108,1,10,'small',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19108,2,10,'large (1 oz)',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19113,1,1,'serving 1/4 cup',73,'g',1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_wght` VALUES (19114,1,1,'serving',68,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19114,2,1,'unit',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (19116,1,1,'cup of miniature',50,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19116,2,10,'miniatures',7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19116,3,1,'regular',7.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19117,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19120,1,1,'bar, miniature',7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19120,2,1,'bar (1.55 oz)',44,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19120,3,1,'cup chips',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19121,1,0.5,'cup From 19191',147,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19122,1,0.5,'cup From 19211',142,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19123,1,0.5,'cup From 19211',142,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19124,1,1,'tablet',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19125,1,1,'serving 2 TBSP',37,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19126,1,1,'cup',149,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19126,2,10,'pieces',40,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19127,2,1,'cup',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19127,3,10,'pieces',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19128,1,1,'serving 1/4 cup',73,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19128,2,1,'TBSP',15,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19128,3,1,'oz',28.35,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19128,4,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19129,1,1,'CUP',314,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19129,2,1,'TBSP',20,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19132,1,1,'bar (1.45 oz)',41,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19132,2,1,'bar (1.55 oz)',44,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19134,1,1,'bar (1.4 oz)',40,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19134,2,1,'bar (1.45 oz)',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19134,3,1,'bar (1.65 oz)',47,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19134,4,1,'bar, miniature',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19134,5,1,'bar (1.55 oz)',44,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19137,1,2,'tbsp',42,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19137,2,1,'serving',40,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19137,3,1,'cup',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19138,1,1,'piece',12,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19138,2,1,'recipe yield, recipe makes 49     1 " x 1"     pieces',612,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19147,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19147,2,1,'bar (1.4 oz)',40,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19147,3,1,'bar (1.6 oz)',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19147,4,1,'bar (1.75 fl oz)',50,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19148,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19154,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19154,2,1,'piece',1.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19154,3,20,'pieces',35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19163,1,1,'stick',3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19163,2,10,'Chiclets',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19163,3,1,'block',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19165,1,1,'CUP',86,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19165,2,1,'TBSP',5.4,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19166,1,1,'CUP',86,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19166,2,1,'TBSP',5.4,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19168,1,0.5,'cup',141,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19168,2,1,'recipe yield',563,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19169,1,1,'package (3 oz)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19169,2,1,'portion, amount to make 1/2 cup',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19170,1,0.5,'cup',141,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19172,1,1,'package (3 oz)',85,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19172,2,1,'portion, amount to make 1/2 cup',21,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19173,1,0.5,'cup',135,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19173,2,1,'serving',21,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19173,3,1,'package 3 oz, yields 2 cups',540,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19175,1,1,'serving',6.4,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19176,1,0.5,'CUP',117,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19176,2,1,'package yield (2 cups)',469,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19177,1,1,'envelope (1 tbsp)',7,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19177,2,1,'package (1 oz)',28,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19182,1,1,'recipe yield',808,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19182,2,0.5,'cup',202,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19183,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19183,2,1,'container refrigerated, 4 oz',108,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (19183,3,1,'container shelf stable, 3.5 oz',98,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (19184,1,1,'package (3.5 oz)',99,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19184,2,1,'portion, amount to make 1/2 cup',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19185,1,0.5,'CUP',147,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19185,2,1,'package yield (2 cups)',587,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19186,1,0.5,'cup',141,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19186,2,1,'recipe yield',844,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19188,1,1,'package (3.5 oz)',99,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19188,2,1,'portion, amount to make 1/2 cup',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19189,1,0.5,'CUP',142,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19189,2,1,'package yield (2 cups)',570,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19190,1,0.5,'cup',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19191,1,0.5,'CUP',147,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19191,2,1,'package yield (2 cups)',587,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19193,1,1,'serving 4 oz pudding cup',113,'g',1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19193,2,1,'oz',28.35,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19193,3,1,'can (5 oz)',142,'g',1,'2007-11-28','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19193,4,1,'cup',172,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19193,5,0.5,'cup',92,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19195,1,0.5,'cup',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19199,1,0.5,'cup',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19201,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19201,2,1,'container refrigerated 4 oz',110,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19201,3,1,'container shelf stable 3.5 oz',97,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19202,1,1,'package (3.5 oz)',99,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19202,2,1,'portion, amount to make 1/2 cup',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19203,1,0.5,'CUP',142,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19203,2,1,'package yield (2 cups)',569,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19204,1,1,'serving',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19204,2,1,'package',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19205,1,0.5,'cup',141,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19206,1,1,'package (3.12 oz)',88,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19206,2,1,'portion, amount to make 1/2 cup',22,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19207,1,0.5,'CUP',140,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19207,2,1,'package yield (2 cups)',559,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19208,1,0.5,'cup',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19209,1,0.5,'cup',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19212,1,0.5,'cup',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19213,1,0,'cup',142,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (19214,1,0,'cup',142,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (19216,1,1,'piece',39,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19216,2,1,'recipe yield',907,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19217,1,1,'bar',51,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19218,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19218,2,1,'container refrigerated 4 oz',110,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19218,3,1,'container',97,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (19219,1,0.5,'CUP',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19219,2,1,'package yield (2 cups)',559,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19220,1,1,'tbsp',9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19220,2,1,'package (2 oz)',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19221,1,0,'cup',142,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (19225,1,1,'package (0.35 oz)',9.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19226,1,2,'tbsp creamy',41,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19227,1,0.083,'package',38,'g',1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_wght` VALUES (19227,2,2,'tbsp',35,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19227,3,1,'package (16 oz)',462,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19228,1,2,'tbsp creamy',33,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19228,2,2,'tbsp whipped',24,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19230,1,0.083,'package',38,'g',1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_wght` VALUES (19230,2,2,'tbsp creamy',33,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19230,3,1,'package (16 oz)',462,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19231,1,0,'cup',141,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (19232,1,0,'cup',141,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (19233,1,1,'serving 3.5 oz shelf stable',99,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19234,1,1,'container refrigerated 4 oz',112,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19235,1,1,'serving 4 oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19241,1,2,'tablespoon',33,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19247,1,1,'package yields',315,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19247,2,0.083,'package',26,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19260,1,1,'serving 1/2 cup',68,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19263,1,1,'bar (2.5 fl oz)',77,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19263,2,1,'bar (3 fl oz)',92,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19265,1,1,'serving 1/2 cup',72,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19268,1,1,'serving 28 pieces',40,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19270,1,1,'individual (3.5 fl oz)',58,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19270,2,0.5,'cup (4 fl oz)',66,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19271,1,1,'individual (3.5 fl oz)',58,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19271,2,0.5,'cup (4 fl oz)',66,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19274,1,1,'serving',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19274,2,1,'packet',14.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19279,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19280,1,0.5,'cup (4 fl oz)',99,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19283,1,1,'serving 1.75 fl oz pop',52,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19293,1,0.5,'CUP',72,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19294,1,1,'tbsp',17,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19294,2,1,'serving',17,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19294,3,1,'cup',282,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19296,1,1,'CUP',339,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19296,2,1,'TBSP',21,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19296,3,1,'packet (0.5 oz)',14,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19297,1,1,'TBSP',20,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19297,2,1,'packet (0.5 oz)',14,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19300,1,1,'serving 1 tbsp',21,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19300,2,1,'packet (0.5 oz)',14,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19301,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19303,1,1,'tbsp',20,'g',1,'1994-09-29','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19303,2,1,'package (0.5 oz)',14,'g',1,'1999-03-22','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19303,3,1,'serving',20,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19303,4,1,'cup',320,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19304,1,1,'CUP',337,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19304,2,1,'serving 1 tbsp',20,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19310,1,1,'package (1.75 oz)',50,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19312,1,0.125,'can',74,'g',1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_wght` VALUES (19312,2,1,'serving',85,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19312,3,1,'can (21 oz)',595,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19314,1,0.125,'can',74,'g',1,'1999-03-22','2016-03-09');
INSERT INTO `cndb_wght` VALUES (19314,2,1,'can (21 oz)',595,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19318,1,1,'package (3.5 oz)',99,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19318,2,1,'portion, amount to make 1/2 cup',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19319,1,0.5,'cup',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19320,1,1,'package (3.12 oz)',88,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19320,2,1,'portion, amount to make 1/2 cup',22,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19321,1,0.5,'cup',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19322,1,1,'package (3.5 oz)',99,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19322,2,1,'portion, amount to make 1/2 cup',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19323,1,0.5,'CUP',147,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19323,2,1,'package yield (2 cups)',587,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19324,1,1,'package (3.12 oz)',88,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19324,2,1,'portion, amount to make 1/2 cup',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19325,1,0.5,'CUP',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19325,2,1,'package yield (2 cups)',559,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19330,1,1,'package (3.5 oz)',99,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19330,2,1,'portion, amount to make 1/2 cup',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19331,1,0.5,'CUP',147,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19331,2,1,'package yield (2 cups)',587,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19333,1,0.5,'cup',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19334,1,1,'tsp unpacked',3,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19334,2,1,'cup packed',220,'g',1,'1998-01-15','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19334,3,1,'cup unpacked',145,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19334,4,1,'tsp packed',4.6,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (19334,5,1,'tsp brownulated',3.2,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19335,1,1,'serving packet',2.8,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19335,2,1,'tsp',4.2,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19335,3,1,'CUP',200,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19335,4,1,'serving 1 cube',2.3,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19336,1,1,'cup unsifted',120,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19336,2,1,'cup sifted',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (19336,3,1,'tbsp unsifted',8,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19336,4,1,'tsp',2.5,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19340,1,1,'tsp',3,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19340,2,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19340,3,1,'piece (1-3/4" x 1-1/4" x 1/2")',28,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19348,1,1,'CUP',304,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19348,2,2,'TBSP',38,'g',1,'1999-02-12','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19349,1,1,'CUP',328,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19349,2,1,'TBSP',20,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19350,1,1,'CUP',341,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19350,2,1,'tbsp',22,'g',1,'2002-09-06','2009-02-11');
INSERT INTO `cndb_wght` VALUES (19351,1,1,'CUP',310,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19351,2,1,'TBSP',19,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19352,1,1,'cup',332,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19352,2,1,'tbsp',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19353,1,1,'tbsp',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19353,2,1,'serving 1/4 cup',83,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19353,3,1,'cup',315,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19355,1,1,'cup',330,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19355,2,1,'tbsp',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19360,1,1,'tbsp',20,'g',1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19360,2,1,'serving 1/4 cup',83,'g',1,'2002-09-06','2013-12-26');
INSERT INTO `cndb_wght` VALUES (19360,3,1,'cup',315,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19362,1,1,'CUP',316,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19362,2,1,'TBSP',20,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19364,1,2,'TBSP',41,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19365,1,1,'oz',28.35,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19365,2,1,'jar',198,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19366,1,1,'CUP',340,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19366,2,2,'TBSP',42,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19367,1,1,'CUP',328,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19367,2,2,'TBSP',41,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19371,1,2,'tablespoon',33,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19372,1,2,'tablespoon',33,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19375,1,1,'recipe yield',327,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19379,1,1,'piece',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19379,2,1,'recipe yield (60 pieces)',1229,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19382,1,1,'piece',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19383,1,1,'piece',12,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19384,1,1,'piece',11,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19387,1,0.5,'cup (4 fl oz)',99,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19393,1,0.5,'cup (4 fl oz)',72,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19400,1,1,'oz',28.35,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19400,2,3,'oz',85,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (19400,3,1.5,'oz',42,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (19401,1,1,'oz',28.35,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19401,2,2,'oz',57,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (19403,1,1,'bar (1 oz)',28,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (19404,1,1,'bar (1.5 oz)',43,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19404,2,1,'bar (1 oz)',28,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19405,1,1,'bar (1 oz)',28,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19406,1,1,'bar (1 oz)',28,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19407,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19407,2,1,'stick',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19408,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19408,2,0.5,'oz',14.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19410,1,1,'oz',28,'g',1,'2015-01-06','2015-06-19');
INSERT INTO `cndb_wght` VALUES (19410,2,16,'chips',26,'g',1,'1994-09-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (19410,3,1,'oz',28.35,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (19410,4,1,'can (7 oz)',198,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (19411,1,1,'oz',28,'g',1,'2015-01-06','2015-06-19');
INSERT INTO `cndb_wght` VALUES (19411,2,22,'chips',28,'g',1,'1994-09-29','2015-01-07');
INSERT INTO `cndb_wght` VALUES (19411,3,1,'oz',28.35,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (19411,4,1,'bag (8 oz)',227,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (19412,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19412,2,1,'can (6.25 oz)',191,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19413,1,1,'cake',9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19413,2,2,'cakes',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19414,1,1,'cake',9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19414,2,2,'cakes',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19415,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19415,2,0.5,'cup',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19416,1,1,'cake',9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19416,2,2,'cakes',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19418,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19418,2,2,'oz',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19419,1,1,'cake',9,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (19419,2,2,'cakes',18,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (19420,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19420,2,1,'bar',24,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19421,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19421,2,1,'bag (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19422,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19422,2,1,'bag (6 oz)',170,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19423,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19424,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19424,2,1,'bag (6 oz)',170,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19433,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19434,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19436,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19437,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19437,2,1,'bag (8 oz)',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19444,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19445,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19524,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19524,2,10,'chips',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19701,1,1,'cup chips (6 oz package)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19701,2,1,'cup large chips',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19701,3,1,'cup mini chips',173,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19701,4,1,'oz (approx 60 pcs)',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19702,1,1,'package (3 oz)',85,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19702,2,1,'portion, amount to make 1/2 cup',21,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19703,1,1,'TBSP',9,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19703,2,1,'package (0.35 oz)',10,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19703,3,1,'portion, amount to make 1/2 cup',2.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19704,1,1,'TBSP',9,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19704,2,1,'package (0.35 oz)',10,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19704,3,1,'portion, amount to make 1/2 cup',2.5,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19705,1,1,'package (3.5 oz)',99,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19705,2,1,'portion, amount to make 1/2 cup',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19706,1,1,'package (3.12 oz)',88,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19706,2,1,'portion, amount to make 1/2 cup',22,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19708,1,1,'package (3 oz)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19708,2,1,'portion, amount to make 1/2 cup',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19710,1,1,'package (3.12 oz)',88,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19710,2,1,'portion, amount to make 1/2 cup',22,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19719,1,1,'TBSP',20,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19719,2,1,'packet (0.5 oz)',14,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19720,1,1,'CUP',315,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19720,2,1,'TBSP',20,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19800,1,1,'cake',9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19800,2,2,'cakes',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19802,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19802,2,1,'bag (8 oz)',227,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19804,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19806,1,1,'CUP',8,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19806,2,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19807,1,1,'CUP',11,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19807,2,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19809,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19809,2,1,'bag (8 oz)',227,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19810,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19810,2,1,'bag (8 oz)',227,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19811,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19811,2,1,'bag (8 oz)',227,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19812,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19812,2,10,'twists',60,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19813,1,1,'oz',28.35,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19813,2,10,'twists',60,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19814,1,1,'oz',28.35,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19814,2,10,'twists',60,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (19816,1,1,'cake',9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19816,2,2,'cakes',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19817,1,1,'cake',9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19817,2,2,'cakes',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19818,1,1,'cake',9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19818,2,2,'cakes',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19819,1,1,'cake',9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19819,2,2,'cakes',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19820,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19820,2,2,'oz',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19821,1,1,'cup',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19821,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19821,3,1.5,'oz',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19822,1,1,'cup',146,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19822,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19822,3,1.5,'oz',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19823,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19833,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19857,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19858,1,1,'piece',3.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19860,1,1,'tablespoon Ghirardelli label 2011',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19860,2,1,'tablespoon Hershey''s label 2011',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19860,3,1,'container Ghirardelli label 2011',283,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19866,1,3,'pieces',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19867,1,0.5,'cup',67,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19898,1,1,'individual (3.5 fl oz)',58,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (19898,2,0.5,'cup (4 fl oz)',66,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (19899,1,1,'individual (3.5 fl oz)',58,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (19902,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19902,2,1,'bar',162,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19903,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19903,2,1,'bar',112,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19904,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19904,2,1,'bar',101,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19905,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19905,2,1,'bar',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19910,1,1,'serving 1.5 oz',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19912,1,1,'tsp',6.9,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (19912,2,0.25,'cup',55,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (19918,1,1,'package',1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19919,1,1,'serving',44,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (19920,1,1,'tablespoon',19,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (19921,1,1,'serving',14,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (19922,1,1,'bar',47,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (20001,1,1,'cup',193,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20003,1,1,'cup',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20004,1,1,'CUP',184,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20005,1,1,'CUP',200,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20006,1,1,'CUP',157,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20008,1,1,'CUP',170,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20009,1,1,'cup',164,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20010,1,1,'cup',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20011,1,1,'CUP',120,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (20012,1,1,'CUP',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20013,1,1,'CUP',182,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20013,2,1,'TBSP',8.4,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20014,1,1,'cup',166,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20015,1,1,'cup',76,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20016,1,1,'CUP',117,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20017,1,1,'CUP',114,'g',1,'1998-01-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20018,1,1,'CUP',126,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20019,1,1,'cup',114,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (20020,1,1,'CUP',122,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20022,1,1,'cup',157,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20023,1,1,'CUP',122,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20024,1,1,'CUP',170,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20025,1,1,'CUP',138,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20027,1,1,'CUP',128,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20028,1,1,'CUP',173,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20029,1,1,'cup, cooked',157,'g',1,'1995-06-19','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20029,2,1,'cup, dry, yields',528,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20029,3,1,'oz, dry, yields',86,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20030,1,1,'CUP',165,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20031,1,1,'cup',200,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20032,1,1,'cup',174,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20033,1,1,'CUP',94,'g',1,'1994-09-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20034,1,1,'CUP',219,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20035,1,1,'cup',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20036,1,1,'CUP',185,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20037,1,1,'CUP',202,'g',1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_wght` VALUES (20038,1,1,'CUP',156,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20040,1,1,'CUP',190,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20041,1,1,'CUP',195,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20044,1,1,'CUP',185,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20045,1,1,'CUP',158,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20046,1,1,'cup',185,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20047,1,1,'CUP',158,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20048,1,1,'CUP',95,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20049,1,1,'CUP',165,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20050,1,1,'CUP',195,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20051,1,1,'CUP',186,'g',1,'1994-11-17','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20052,1,1,'cup',200,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20053,1,1,'cup',186,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20054,1,1,'cup',185,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20055,1,1,'cup',174,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20060,1,1,'cup',118,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20061,1,1,'cup',158,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20062,1,1,'cup',169,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20063,1,1,'cup',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20064,1,1,'cup',102,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20065,1,1,'cup',102,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20066,1,1,'CUP',167,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20067,1,1,'cup',192,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20068,1,1,'CUP',152,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20069,1,1,'cup',192,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20070,1,1,'cup',130,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20071,1,1,'cup',192,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20072,1,1,'cup',192,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20073,1,1,'cup',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20074,1,1,'cup',192,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20075,1,1,'cup',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20076,1,1,'cup',192,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20077,1,1,'cup',58,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20078,1,1,'CUP',115,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20080,1,1,'CUP',120,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20081,1,1,'CUP',125,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20082,1,1,'CUP',125,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20083,1,1,'CUP',137,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20084,1,1,'cup unsifted, dipped',137,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20086,1,1,'cup',111,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20087,1,1,'cup',108,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20088,1,1,'CUP',160,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20089,1,1,'CUP',164,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20090,1,1,'cup',158,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20091,1,1,'cup',105,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20091,2,2,'oz',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20092,1,1,'cup',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20093,1,4.5,'oz',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20094,1,2,'oz',128,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20095,1,4.5,'oz',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20096,1,2,'oz',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20097,1,2,'oz',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20098,1,2,'oz',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20105,1,1,'cup spiral shaped',84,'g',1,'1998-03-27','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20105,2,2,'oz',57,'g',1,'2002-09-06','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20106,1,1,'cup spiral shaped',134,'g',1,'1998-03-27','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20109,1,1,'CUP',38,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20109,2,2,'oz',57,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20110,1,1,'CUP',160,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20111,1,1,'CUP',38,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20111,2,2,'oz',57,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20112,1,1,'CUP',160,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20113,1,0.5,'cup dry',28,'g',1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_wght` VALUES (20113,2,1.5,'oz',43,'g',1,'1999-03-22','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20114,1,2,'oz',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20115,1,1,'cup',114,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20116,1,2,'oz',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20117,1,1,'cup',176,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20118,1,1,'cup',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20120,1,1,'cup spaghetti',91,'g',1,'1999-03-22','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20120,2,2,'oz',57,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20120,3,1,'cup elbows',122,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20120,4,1,'cup penne',95,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20120,5,1,'cup farfalle',81,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20120,6,1,'cup rotini',96,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20120,7,1,'cup shells',64,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20120,8,1,'cup lasagna',90,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20121,1,1,'cup spaghetti not packed',124,'g',1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20121,2,1,'cup spaghetti packed',151,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20121,3,1,'cup elbows not packed',120,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20121,4,1,'cup elbows packed',132,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20121,5,1,'cup penne',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20121,6,1,'cup farfalle',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20121,7,1,'cup rotini',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20121,8,1,'cup shells',105,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20121,9,1,'cup lasagne',116,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20124,1,1,'cup spaghetti',91,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20124,2,1,'cup elbows',122,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20124,3,1,'cup penne',95,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20124,4,1,'cup farfalle',81,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20124,5,1,'cup rotini',96,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20124,6,1,'cup shells',64,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20124,7,1,'cup lasagne',90,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20125,1,1,'cup spaghetti not packed',117,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20125,2,1,'cup spaghetti packed',151,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20125,3,1,'cup elbows',117,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20125,4,1,'cup penne',97,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20125,5,1,'cup shells',105,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20125,6,1,'cup lasagne',116,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20125,7,1,'cup rotini',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20125,8,1,'cup farfalle',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20126,1,2,'oz',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20127,1,1,'cup',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20129,1,1,'cup unsifted, dipped',137,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20130,1,1,'CUP',148,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20131,1,1,'CUP',162,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20132,1,1,'cup',104,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20133,1,2,'oz',57,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (20134,1,1,'CUP',176,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20135,1,1,'cup spaghetti',91,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20135,2,1,'cup elbows',122,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20135,3,1,'cup penne',95,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20135,4,1,'cup farfalle',81,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20135,5,1,'cup rotini',96,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20135,6,1,'cup shells',64,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20135,7,1,'cup lasagne',90,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20136,1,1,'cup spaghetti not packed',116,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20136,2,1,'cup spaghetti packed',151,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20136,3,1,'cup elbows not packed',117,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20136,4,1,'cup farfalle',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20136,5,1,'cup penne',97,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20136,6,1,'cup shells',105,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20136,7,1,'cup lasagne',116,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20136,8,1,'cup rotini',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20137,1,1,'cup',185,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20140,1,1,'CUP',174,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (20142,1,1,'cup',193,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20310,1,1,'CUP',160,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20314,1,1,'cup',166,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20316,1,1,'CUP',117,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20317,1,1,'cup',114,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20320,1,1,'CUP',122,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20321,1,1,'cup spaghetti not packed',124,'g',1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20321,2,1,'cup packed',151,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20321,3,1,'cup elbows not packed',120,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20321,4,1,'cup elbows packed',132,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20321,5,1,'cup penne',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20321,6,1,'cup farfalle',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20321,7,1,'cup rotini',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20321,8,1,'cup shells',105,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20321,9,1,'cup lasagne',116,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20322,1,1,'cup',157,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20323,1,1,'CUP',122,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20324,1,1,'CUP',170,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20325,1,1,'CUP',138,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20330,1,1,'CUP',160,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20345,1,1,'CUP',158,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20381,1,1,'CUP',125,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20409,1,1,'cup',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20410,1,1,'cup',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20420,1,1,'cup spaghetti',91,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20420,2,2,'oz',57,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20420,3,1,'cup elbows',122,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20420,4,1,'cup penne',95,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20420,5,1,'cup farfalle',81,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20420,6,1,'cup rotini',96,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20420,7,1,'cup shells',64,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20420,8,1,'cup lasagna',90,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20421,1,1,'cup spaghetti not packed',124,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20421,2,1,'cup spaghetti packed',151,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20421,3,1,'cup elbows not packed',120,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20421,4,1,'cup elbows packed',132,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20421,5,1,'cup penne',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20421,6,1,'cup rotini',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20421,7,1,'cup farfalle',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20421,8,1,'cup shells',105,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20421,9,1,'cup lasagne',116,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20422,1,1,'cup',157,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20444,1,1,'cup',185,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20445,1,1,'cup',158,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20446,1,1,'cup',185,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20447,1,1,'cup',158,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20450,1,1,'cup',195,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20451,1,1,'cup',186,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20452,1,1,'cup',200,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20453,1,1,'cup',205,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20466,1,1,'CUP',167,'g',1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20481,1,1,'cup',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20510,1,1,'cup',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20521,1,1,'cup spaghetti not packed',124,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20521,2,1,'cup spaghetti packed',151,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20521,3,1,'cup elbows not packed',120,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20521,4,1,'cup elbows packed',132,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20521,5,1,'cup penne',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20521,6,1,'cup rotini',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20521,7,1,'cup farfalle',107,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20521,8,1,'cup shells',105,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20521,9,1,'cup lasagne',116,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20522,1,1,'cup',157,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20523,1,1,'CUP',140,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20545,1,1,'cup',158,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20581,1,1,'CUP',125,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20622,1,2,'oz',57,'g',1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_wght` VALUES (20647,1,1,'cup',119,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20648,1,1,'cup',121,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (20650,1,1,'cup',161,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (20653,1,1,'cup spaghetti',91,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20653,2,1,'cup elbows',122,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20653,3,1,'cup penne',95,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20653,4,1,'cup farfalle',81,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20653,5,1,'cup rotini',96,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20653,6,1,'cup shells',64,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (20653,7,1,'cup lasagne',90,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (21224,1,1,'serving 9 servings per 24 oz package',81,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21224,2,1,'serving 3 servings per 15.1 oz package',151,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21224,3,1,'serving 2 servings per 9.8 oz package',146,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21224,4,1,'serving 1 serving per 8 oz box',199,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21224,5,1,'package 24 oz pizza',727,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21224,6,1,'package 15.1 oz pizza',452,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21224,7,1,'package 9.8 oz pizza',293,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21224,8,1,'package 8 oz pizza',199,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21225,1,1,'serving 6 servings per 29.25 oz package',139,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21225,2,1,'serving 4 servings per 19.7 oz package',149,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21225,3,1,'package 29.25 oz pizza',834,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21225,4,1,'package 19.7 oz pizza',595,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21226,1,1,'serving 5 servings per 24.2 oz package',143,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21226,2,1,'serving 5 servings per 22.85 oz package',129,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21226,3,1,'serving 2 servings per 10.9 oz package',177,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21226,4,1,'package 24.2 oz pizza',713,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21226,5,1,'package 22.85 oz pizza',644,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21226,6,1,'package 10.9 oz pizza',354,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21227,1,1,'serving 6 servings per 34.98 oz package',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21227,2,1,'serving 6 servings per 30.7 oz package',149,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21227,3,1,'serving 3 servings per 14.3 oz package',138,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21227,4,1,'package 34.98 oz pizza',1020,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21227,5,1,'package 30.7 oz pizza',891,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21227,6,1,'package 14.3 oz pizza',415,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (21412,1,12,'fl oz cup',348,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (21413,1,12,'fl oz cup',337,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (21463,1,1,'item',149,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (21505,1,1,'slice',69,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (21505,2,1,'pie',556,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (22247,1,1,'serving',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22401,1,1,'serving',283,'g',1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_wght` VALUES (22401,2,1,'oz',28.35,'g',1,'2007-11-28','2007-11-28');
INSERT INTO `cndb_wght` VALUES (22402,1,1,'serving',269,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22402,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22522,1,1,'serving (1 cup)',252,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22528,1,1,'package yields',397,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22528,2,1,'serving',397,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22529,1,1,'pie, cooked (average weight)',268,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22899,1,1,'cup',242,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (22900,1,1,'cup',262,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (22901,1,0.75,'cup',81,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22902,1,1,'slice 1/8 of 12" pizza',103,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (22902,2,1,'slice 1/8 of 14" pizza',127,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (22903,1,0.25,'pizza 12" diameter',127,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (22903,2,1,'pizza 12" diameter',532,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (22904,1,1,'cup',242,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22905,1,1,'cup (1 serving)',196,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22906,1,1,'pie',302,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22910,1,1,'cup 1 serving',225,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22911,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22912,1,1,'cup',246,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22912,2,1,'can',411,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22914,1,1,'serving (1 NLEA serving)',252,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22914,2,1,'cup',238,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22915,1,1,'package',309,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22915,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22916,1,1,'piece side',134,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22916,2,1,'piece corner',115,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22916,3,1,'piece center',278,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22917,1,1,'burrito frozen',139,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22917,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22918,1,1,'burrito',129,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22919,1,7.5,'oz 1 serving',213,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22928,1,1,'burrito cooked',116,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22928,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22953,1,1,'roll',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22953,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22954,1,1,'roll',80,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22954,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22955,1,1,'egg roll',68,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (22955,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22956,1,1,'serving',227,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (22956,2,1,'CUP',226,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (22956,3,1,'oz',28.35,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (22957,1,1,'serving',385,'g',1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_wght` VALUES (22957,2,1,'package',422,'g',1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_wght` VALUES (22957,3,1,'oz',28.35,'g',1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_wght` VALUES (22958,1,1,'bowl',340,'g',1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_wght` VALUES (22959,1,1,'serving (makes about 1 cup prepared)',70,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22960,1,1,'cup',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (22969,1,1,'cup',244,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (22969,2,1,'container',422,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (22970,1,1,'cup',137,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (22970,2,1,'container (mean weight over brands)',283,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (22971,1,0.5,'cup',125,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (22972,1,1,'cup',249,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (22973,1,1,'corndog',78,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (22973,2,1,'corndog mini',17,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (22974,1,1,'serving',87,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (22974,2,1,'piece',18,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (22975,1,1,'serving',82,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (22975,2,1,'piece',20,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (22976,1,1,'cup',159,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (22977,1,1,'piece side',123,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (22977,2,1,'piece corner',114,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (22977,3,1,'piece center',255,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (22978,1,1,'piece',21,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (22999,1,1,'cup',233,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (23000,1,4,'oz',113,'g',1,'2011-01-18','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23000,2,1,'steak',369,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23000,3,1,'roast',1159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23001,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23001,2,1,'steak',534,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23002,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23002,2,1,'steak',421,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23003,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23003,2,1,'steak',526,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23004,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23004,2,1,'steak',426,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23005,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23005,2,1,'steak',460,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23006,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23006,2,1,'steak',363,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23007,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23007,2,1,'steak',458,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23008,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23008,2,1,'steak',368,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23030,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23030,2,1,'steak',191,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23031,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23031,2,1,'steak',141,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23032,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23032,2,1,'steak',200,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23033,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23033,2,1,'steak',174,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23034,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23034,2,1,'medallion',40,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23035,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23035,2,1,'medallion',30,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23036,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23036,2,1,'medallion',44,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23037,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23037,2,1,'steak',246,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23038,1,1,'serving (3 oz)',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23038,2,1,'steak',188,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23039,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23039,2,1,'steak',233,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23040,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23040,2,1,'steak',179,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23041,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23041,2,1,'steak',254,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23042,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23042,2,1,'steak',193,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23043,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23043,2,1,'steak',243,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23044,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23044,2,1,'steak',186,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23045,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23045,2,1,'steak',209,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23046,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23046,2,1,'steak',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23047,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23047,2,1,'steak',203,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23048,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23048,2,1,'steak',160,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23049,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23049,2,1,'steak',293,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23050,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23050,2,1,'steak',225,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23051,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23051,2,1,'steak',324,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23052,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23052,2,1,'steak',253,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23053,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23054,1,3,'oz',85,'g',1,'2006-02-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23054,2,1,'medallion',32,'g',1,'2006-02-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23055,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23055,2,1,'steak',207,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23056,1,3,'oz',85,'g',1,'2006-02-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23056,2,1,'steak',168,'g',1,'2006-02-23','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23057,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23057,2,1,'steak',241,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23058,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23058,2,1,'steak',184,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23059,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23059,2,1,'steak',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23060,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23060,2,1,'steak',190,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23061,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23061,2,1,'steak',197,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23062,1,3,'oz',85,'g',1,'2006-02-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23062,2,1,'steak',150,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23063,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23063,2,1,'steak',305,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23064,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23064,2,1,'steak',236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23065,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23065,2,1,'medallion',34,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23066,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23066,2,1,'piece',434,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23067,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23067,2,1,'piece',429,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23068,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23068,2,1,'piece',432,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23069,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23069,2,1,'piece',224,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23070,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23070,2,1,'piece',231,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23071,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23071,2,1,'piece',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23072,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23072,2,1,'piece',325,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23073,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23073,2,1,'piece',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23074,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23074,2,1,'piece',331,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23075,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23075,2,1,'steak',307,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23076,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23076,2,1,'steak',309,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23077,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23077,2,1,'steak',308,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23078,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23078,2,1,'steak',382,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23079,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23079,2,1,'steak',386,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23080,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23080,2,1,'steak',384,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23081,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23081,2,1,'roast',793,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23082,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23082,2,1,'roast',779,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23083,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23083,2,1,'roast',787,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23084,1,3,'oz',85,'g',1,'2011-01-18','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23084,2,1,'steak',141,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23085,1,3,'oz',85,'g',1,'2011-01-18','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23085,2,1,'steak',141,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23086,1,3,'oz',85,'g',1,'2011-01-18','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23086,2,1,'steak',141,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23087,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23087,2,1,'steak',204,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23088,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23088,2,1,'steak',191,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23089,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23089,2,1,'steak',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23090,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23090,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23091,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23092,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23093,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23094,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23095,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23096,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23096,2,1,'steak',445,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23097,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23098,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23099,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23100,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23100,2,1,'steak',291,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23101,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23101,2,1,'roast',2044,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23102,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23102,2,1,'steak',679,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23102,3,1,'roast',960,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23103,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23103,2,1,'steak',648,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23103,3,1,'roast',949,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23104,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23104,2,1,'steak',732,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23104,3,1,'roast',977,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23105,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23105,2,1,'steak',353,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23106,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23106,2,1,'steak',356,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23107,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23107,2,1,'steak',349,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23108,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23108,2,1,'steak',473,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23109,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23109,2,1,'steak',483,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23110,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23110,2,1,'steak',458,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23111,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23111,2,1,'steak',361,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23111,3,1,'roast',1173,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23112,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23112,2,1,'steak',381,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23112,3,1,'roast',1139,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23113,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23113,2,1,'roast',609,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23114,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23114,2,1,'roast',586,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23115,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23115,2,1,'roast',645,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23116,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23116,2,1,'steak',449,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23117,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23117,2,1,'steak',445,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23118,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23118,2,1,'steak',454,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23119,1,3,'oz',85,'g',1,'2011-01-18','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23119,2,1,'steak',141,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23120,1,3,'oz',85,'g',1,'2011-01-18','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23120,2,1,'steak',141,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23121,1,3,'oz',85,'g',1,'2011-01-18','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23121,2,1,'steak',141,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23122,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23122,2,1,'steak',198,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23123,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23123,2,1,'steak',204,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23124,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23124,2,1,'steak',191,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23125,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23125,2,1,'piece',289,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23126,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23126,2,1,'piece',272,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23127,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23127,2,1,'piece',315,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23128,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23128,2,1,'piece',432,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23129,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23129,2,1,'piece',434,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23130,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23130,2,1,'piece',429,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23131,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23131,2,1,'roast',787,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23132,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23132,2,1,'roast',793,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23133,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23133,2,1,'roast',779,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23134,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23134,2,1,'piece',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23135,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23135,2,1,'piece',224,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23136,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23136,2,1,'piece',231,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23137,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23137,2,1,'piece',331,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23138,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23138,2,1,'piece',325,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23139,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23139,2,1,'piece',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23140,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23140,2,1,'steak',308,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23141,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23141,2,1,'steak',307,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23142,1,3,'oz',85,'g',1,'2011-01-18','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23142,2,1,'steak',309,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23143,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23143,2,1,'steak',384,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23144,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23144,2,1,'steak',382,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23145,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23145,2,1,'steak',386,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23146,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23146,2,1,'roast',2130,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23147,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23147,2,1,'roast',2259,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23148,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23148,2,1,'steak',281,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23149,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23149,2,1,'steak',306,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23150,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23150,2,1,'steak',462,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23150,3,1,'roast',2627,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23151,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23151,2,1,'steak',456,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23151,3,1,'roast',2674,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23152,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23152,2,1,'steak',471,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23152,3,1,'roast',2557,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23153,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23153,2,1,'steak',361,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23153,3,1,'roast',2155,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23154,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23154,2,1,'steak',350,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23154,3,1,'roast',2124,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23155,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23155,2,1,'steak',376,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23155,3,1,'roast',2203,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23156,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23156,2,1,'steak',381,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23157,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23157,2,1,'steak',378,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23158,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23158,2,1,'steak',385,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23159,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23159,2,1,'roast',1601,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23160,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23160,2,1,'roast',1555,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23161,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23161,2,1,'roast',1669,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23162,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23162,2,1,'steak',254,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23163,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23163,2,1,'steak',382,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23164,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23164,2,1,'steak',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23165,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23165,2,1,'steak',388,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23166,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23166,2,1,'steak',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23167,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23167,2,1,'steak',373,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23168,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23168,2,1,'steak',174,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23169,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23169,2,1,'steak',266,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23170,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23170,2,1,'steak',173,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23171,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23171,2,1,'steak',268,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23172,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23172,2,1,'steak',175,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23173,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23173,2,1,'steak',264,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23174,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23175,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23176,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23176,2,1,'steak',242,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23177,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23177,2,1,'steak',316,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23178,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23178,2,1,'steak',266,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23179,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23180,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23180,2,1,'ribs',1159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23181,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23181,2,1,'ribs',1587,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23182,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23182,2,1,'ribs',1197,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23183,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23183,2,1,'ribs',1604,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23184,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23184,2,1,'ribs',1102,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23185,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23185,2,1,'ribs',1562,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23186,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23186,2,1,'steak',378,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23187,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23187,2,1,'steak',385,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23188,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23188,2,1,'steak',381,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23189,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23189,2,1,'roast',2044,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23190,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23190,2,1,'roast',2259,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23191,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23191,2,1,'roast',2130,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23192,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23192,2,1,'steak',462,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23192,3,1,'roast',2627,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23193,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23193,2,1,'steak',456,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23193,3,1,'roast',2674,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23194,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23194,2,1,'steak',471,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23194,3,1,'roast',2557,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23195,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23195,2,1,'steak',281,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23196,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23196,2,1,'steak',306,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23197,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23197,2,1,'steak',291,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23198,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23198,2,1,'roast',1601,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23199,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23199,2,1,'roast',1555,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23200,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23200,2,1,'roast',1669,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23201,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23201,2,1,'steak',361,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23201,3,1,'roast',2155,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23202,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23202,2,1,'steak',350,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23202,3,1,'roast',2124,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23213,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23213,2,1,'steak',376,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23213,3,1,'roast',2203,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23214,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23214,2,1,'steak',254,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23215,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23215,2,1,'steak',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23216,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23216,2,1,'steak',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23217,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23217,2,1,'steak',382,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23218,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23218,2,1,'steak',388,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23219,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23219,2,1,'steak',373,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23220,1,3,'oz',85,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (23221,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23221,2,1,'steak',174,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23222,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23222,2,1,'steak',173,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23223,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23223,2,1,'steak',175,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23224,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23224,2,1,'steak',266,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23225,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23225,2,1,'steak',268,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23226,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23226,2,1,'steak',264,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23227,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23227,2,1,'steak',251,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23228,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23228,2,1,'steak',242,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23229,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23229,2,1,'steak',266,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23230,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23230,2,1,'steak',326,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23231,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23231,2,1,'steak',316,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23232,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23232,2,1,'steak',340,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23233,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23233,2,1,'ribs',1159,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23234,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23234,2,1,'ribs',1197,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23235,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23235,2,1,'ribs',1102,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23236,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23236,2,1,'ribs',1587,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23237,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23237,2,1,'ribs',1604,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23238,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23238,2,1,'ribs',1562,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23239,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23239,2,1,'roast',806,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23240,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23240,2,1,'fillet',190,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23240,3,1,'roast',1013,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23241,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23241,2,1,'steak',161,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23242,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23242,2,1,'steak',165,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23243,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23243,2,1,'steak',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23244,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23244,2,1,'steak',223,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23245,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23245,2,1,'steak',238,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23246,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23246,2,1,'steak',199,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23247,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23247,2,1,'fillet',135,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23248,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23248,2,1,'fillet',135,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23249,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23249,2,1,'fillet',135,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23250,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23250,2,1,'roast',634,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23251,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23251,2,1,'roast',677,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23252,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23252,2,1,'roast',571,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23253,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23253,2,1,'fillet',173,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23253,3,1,'roast',852,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23254,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23254,2,1,'fillet',178,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23254,3,1,'roast',844,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23255,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23255,2,1,'fillet',166,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23255,3,1,'roast',866,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23256,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23256,2,1,'fillet',121,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23257,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23257,2,1,'fillet',124,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23258,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23258,2,1,'fillet',115,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23259,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23259,2,1,'roast',768,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23260,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23260,2,1,'roast',765,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23261,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23261,2,1,'fillet',180,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23261,3,1,'roast',970,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23262,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23262,2,1,'fillet',186,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23262,3,1,'roast',955,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23263,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23263,2,1,'fillet',164,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23263,3,1,'roast',901,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23264,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23264,2,1,'fillet',163,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23264,3,1,'roast',938,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23265,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23265,2,1,'fillet',167,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23265,3,1,'roast',847,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23266,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23266,2,1,'steak',209,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23267,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23267,2,1,'steak',208,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23268,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23268,2,1,'steak',211,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23269,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23269,2,1,'steak',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23270,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23270,2,1,'steak',249,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23271,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23271,2,1,'steak',267,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23272,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23272,2,1,'fillet',135,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23273,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23273,2,1,'fillet',138,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23274,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23274,2,1,'fillet',129,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23275,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23275,2,1,'roast',699,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23276,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23276,2,1,'roast',714,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23277,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23277,2,1,'roast',675,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23278,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23278,2,1,'steak',161,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23279,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23279,2,1,'steak',165,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23280,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23280,2,1,'steak',156,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23281,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23281,2,1,'steak',223,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23282,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23282,2,1,'steak',238,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23283,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23283,2,1,'steak',199,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23284,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23284,2,1,'fillet',135,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23285,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23285,2,1,'fillet',135,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23286,1,3,'oz',85,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23286,2,1,'fillet',135,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23287,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23287,2,1,'roast',634,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23288,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23288,2,1,'roast',677,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23289,1,3,'oz',85,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23289,2,1,'roast',571,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23290,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23290,2,1,'fillet',173,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23290,3,1,'roast',852,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23291,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23291,2,1,'fillet',178,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23291,3,1,'roast',844,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23292,1,4,'oz',113,'g',1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23292,2,1,'fillet',166,'g',1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_wght` VALUES (23292,3,1,'roast',866,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23293,1,4,'oz (4 oz)',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23294,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23294,2,1,'steak',150,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23295,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23295,2,1,'steak',152,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23296,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23297,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23298,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23299,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23300,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23301,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23302,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23302,2,1,'steak',150,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23303,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23303,2,1,'roast',339,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23304,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23304,2,1,'steak',152,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23305,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23305,2,1,'roast',339,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23306,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23306,2,1,'roast',449,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23307,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23307,2,1,'roast',350,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23308,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23308,2,1,'roast',337,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23309,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23309,2,1,'roast',763,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23310,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23310,2,1,'steak',173,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23311,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23311,2,1,'roast',348,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23312,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23312,2,1,'roast',359,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23313,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23313,2,1,'roast',342,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23314,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23314,2,1,'roast',377,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23315,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23315,2,1,'roast',449,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23316,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23316,2,1,'roast',350,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23317,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23317,2,1,'roast',337,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23318,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23318,2,1,'roast',763,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23319,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23319,2,1,'roast',348,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23320,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23320,2,1,'roast',359,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23321,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23321,2,1,'roast',342,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23322,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23322,2,1,'roast',377,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23323,1,4,'oz',113,'g',1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23323,2,1,'steak',173,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23324,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23324,2,1,'steak',344,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23325,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23325,2,1,'steak',344,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23326,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23326,2,1,'steak',344,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23327,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23327,2,1,'roast',758,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23328,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23328,2,1,'roast',770,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23329,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23329,2,1,'roast',740,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23330,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23330,2,1,'roast',675,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23331,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23331,2,1,'roast',658,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23332,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23332,2,1,'roast',699,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23333,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23333,2,1,'steak',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23334,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23334,2,1,'steak',133,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23335,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23335,2,1,'steak',151,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23336,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23336,2,1,'roast',644,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23337,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23337,2,1,'roast',625,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23338,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23338,2,1,'roast',673,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23339,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23339,2,1,'steak',267,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23340,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23340,2,1,'steak',266,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23341,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23341,2,1,'steak',268,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23342,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23342,2,1,'steak',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23343,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23343,2,1,'steak',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23344,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23344,2,1,'steak',172,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23345,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23345,2,1,'roast',481,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23346,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23346,2,1,'roast',478,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23347,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23347,2,1,'roast',487,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23348,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23349,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23350,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23351,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23352,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23353,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23354,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23354,2,1,'steak',344,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23355,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23355,2,1,'steak',344,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23356,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23356,2,1,'steak',344,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23357,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23357,2,1,'roast',758,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23358,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23358,2,1,'roast',770,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23359,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23359,2,1,'roast',740,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23360,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23360,2,1,'roast',675,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23361,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23361,2,1,'roast',658,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23362,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23362,2,1,'roast',699,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23363,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23363,2,1,'steak',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23364,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23364,2,1,'steak',133,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23365,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23365,2,1,'steak',151,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23366,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23366,2,1,'roast',644,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23367,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23367,2,1,'roast',625,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23368,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23368,2,1,'roast',673,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23369,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23369,2,1,'steak',267,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23370,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23370,2,1,'steak',266,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23370,3,1,'oz',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23371,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23371,2,1,'steak',268,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23372,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23372,2,1,'steak',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23373,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23373,2,1,'steak',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23374,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23374,2,1,'steak',172,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23375,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23375,2,1,'roast',481,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23376,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23376,2,1,'roast',478,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23377,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23377,2,1,'roast',487,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23378,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23379,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23380,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23381,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23382,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23383,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23384,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23384,2,1,'steak',304,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23385,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23385,2,1,'steak',301,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23386,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23386,2,1,'steak',302,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23387,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23387,2,1,'steak',304,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23388,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23388,2,1,'steak',302,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23389,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23389,2,1,'steak',236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23390,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23390,2,1,'steak',234,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23391,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23391,2,1,'steak',235,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23392,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23392,2,1,'steak',236,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23393,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23393,2,1,'steak',234,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23394,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23394,2,1,'steak',235,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23395,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23395,2,1,'steak',301,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23397,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23398,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23399,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23401,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23402,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23403,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23404,1,4,'oz',113,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23405,1,1,'serving',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23406,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23407,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23408,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23409,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23410,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23411,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23412,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23413,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23414,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23415,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23416,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23417,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23418,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23419,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23420,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23421,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23422,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23423,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23424,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23425,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23426,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23427,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23428,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23429,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23430,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23431,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23432,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23433,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23434,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23435,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23436,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23437,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23438,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23439,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23440,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23441,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23442,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23443,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23444,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23445,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23446,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23447,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23448,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23449,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23450,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23451,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23452,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23453,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23454,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23455,1,4,'oz',113,'g',1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23456,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23457,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23458,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23459,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23460,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23461,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23462,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23463,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23464,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23465,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23466,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23467,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23468,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23469,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23470,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23471,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23472,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23473,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23474,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23475,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23476,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23477,1,4,'oz',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23478,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23478,2,1,'patty',70,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23479,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23479,2,1,'portion (yield from 1/2 lb raw meat )',139,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23480,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23481,1,3,'oz',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23482,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23483,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23484,1,3,'oz',85,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23485,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23490,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23491,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23494,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23495,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23496,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23497,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23498,1,3,'oz',85,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23499,1,4,'oz',113,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23509,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23509,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23511,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23511,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23513,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23513,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23514,1,3,'oz ( 1 serving  )',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23514,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23515,1,3,'oz',85,'g',1,'2010-01-04','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23515,2,1,'lb',453.6,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (23516,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23517,1,3,'oz',85,'g',1,'2010-01-04','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23517,2,1,'lb',453.6,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (23519,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23519,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23521,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23521,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23523,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23523,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23525,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23525,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23528,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23528,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23531,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23531,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23536,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23536,2,1,'steak',297,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23540,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23540,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23541,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23541,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23545,1,3,'oz',85,'g',1,'2006-02-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23545,2,1,'lb',453.6,'g',1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23547,1,3,'oz',85,'g',1,'2006-02-24','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23547,2,1,'lb',453.6,'g',1,'2006-02-24','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23549,1,3,'oz',85,'g',1,'2006-02-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23549,2,1,'lb',453.6,'g',1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23552,1,3,'oz',85,'g',1,'2006-02-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23552,2,1,'lb',453.6,'g',1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23554,1,3,'oz',85,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (23554,2,1,'steak',287,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23557,1,4,'oz',113,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23558,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23559,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23560,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23561,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23562,1,4,'oz',113,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23563,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23564,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23565,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23565,2,1,'portion ( yield from 1/2 lb raw meat )',154,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23566,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23567,1,4,'oz',113,'g',1,'2011-01-18','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23568,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23568,2,1,'patty (yield from 1/4 lb raw meat)',77,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23569,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23569,2,1,'patty ( yield from 1/4 lb raw meat )',83,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23570,1,3,'oz',85,'g',1,'2004-07-15','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23571,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23572,1,4,'oz',113,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23573,1,3,'oz',85,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23574,1,3,'oz',85,'g',1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23575,1,3,'oz',85,'g',1,'2004-07-15','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23576,1,3,'oz',85,'g',1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23577,1,4,'oz',113,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23577,2,1,'serving (3 oz)',85,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (23578,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23579,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23580,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23581,1,3,'oz',85,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (23582,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23582,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23583,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23584,1,4,'oz',113,'g',1,'2004-07-15','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23584,2,1,'lb',453.6,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23585,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23585,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23586,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23586,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23587,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23587,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23588,1,3,'oz',85,'g',1,'2004-07-15','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23588,2,1,'lb',453.6,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23589,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23589,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23590,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23590,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23591,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23591,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23592,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23592,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23593,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23593,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23594,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23594,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23595,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23595,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23596,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23596,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23597,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23597,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23598,1,3,'oz',85,'g',1,'2011-01-18','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23598,2,1,'lb',453.6,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (23599,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23599,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23600,1,3,'oz',85,'g',1,'2004-07-15','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23600,2,1,'lb',453.6,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23601,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23601,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23602,1,3,'oz',85,'g',1,'2004-07-15','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23602,2,1,'lb',453.6,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23603,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23603,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23604,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23604,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23605,1,3,'oz',85,'g',1,'2004-07-15','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23605,2,1,'lb',453.6,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23606,1,3,'oz',85,'g',1,'2004-07-15','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23606,2,1,'lb',453.6,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23607,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23607,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23608,1,3,'oz',85,'g',1,'2004-07-15','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23608,2,1,'lb',453.6,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23609,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23609,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23610,1,3,'oz',85,'g',1,'2004-07-15','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23610,2,1,'lb',453.6,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23611,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23611,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23612,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23612,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23613,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23613,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23614,1,3,'oz',85,'g',1,'2004-07-15','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23614,2,1,'lb',453.6,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23615,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23615,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23616,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23616,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23617,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23617,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23618,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23618,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23619,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23619,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23620,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23620,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23621,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23621,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23622,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23622,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23623,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23623,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23624,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23624,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23625,1,4,'oz',113,'g',1,'2004-07-15','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23625,2,1,'lb',453.6,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23626,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23626,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23627,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23627,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23628,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23628,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23629,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23629,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23630,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23630,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23631,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23631,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23632,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23632,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23633,1,3,'oz',85,'g',1,'2004-07-15','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23633,2,1,'lb',453.6,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23634,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23634,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23635,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23635,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23636,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23636,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23637,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23637,2,1,'lb',453.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23638,1,3,'oz',85,'g',1,'2004-07-15','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23638,2,1,'lb',453.6,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (23640,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23640,2,1,'serving',85,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23646,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23646,2,1,'roast',261,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23647,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23647,2,1,'roast',591,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23648,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23648,2,1,'roast',271,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23649,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23649,2,1,'roast (yield from 666 g raw meat)',547,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23650,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23650,2,1,'roast',252,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23651,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23651,2,1,'roast',1289,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23652,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23652,2,1,'roast',1392,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23653,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23653,2,1,'roast',1187,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23654,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23654,2,1,'steak',383,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23655,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23655,2,1,'steak (yield from 467 g raw meat)',379,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23656,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23656,2,1,'steak',188,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23657,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23657,2,1,'steak',173,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23658,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23658,2,1,'steak',434,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23659,1,4,'oz',113,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (23659,2,1,'steak',470,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23660,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (23660,2,1,'steak (yield from 593 g raw meat)',409,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25000,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25001,1,1,'oz',28.35,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (25003,1,1,'Roll',23,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25012,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25012,2,1,'Bag',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25012,3,1,'package',34,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25014,1,1,'cup',7.9,'g',1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_wght` VALUES (25014,2,1,'bag',87,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25024,1,1,'large',143,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (25024,2,1,'medium',115,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (25024,3,1,'small',62,'g',1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_wght` VALUES (25025,1,1,'oz',28.35,'g',1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_wght` VALUES (25026,1,1,'cup',7.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25026,2,1,'bag',87,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25027,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25028,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25035,1,1,'bar',24,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25036,1,1,'package',20,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (25037,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25037,2,1,'bag',262,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25038,1,1,'bar',35,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (25040,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25043,1,1,'package',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25045,1,1,'bar',40,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25046,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25046,2,1,'bag',175,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25046,3,6,'piece chips',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25050,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25050,2,10,'chips',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25050,3,1,'bag',105,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25059,1,1,'cake',9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25059,2,2,'cakes',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25060,1,1,'serving',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25062,1,1,'bar',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25063,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25063,2,16.5,'pieces average',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25064,1,23,'pieces',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25064,2,1,'bag',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (25065,1,1,'serving',30,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (25066,1,1,'serving',28,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (25070,1,1,'serving',28,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (25071,1,1,'serving',30,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (27035,1,1.41,'oz dry (half noodle block)',40,'g',1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_wght` VALUES (27043,1,1,'can',519,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (27043,2,1,'cup',256,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (27044,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (27044,2,1,'can',516,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (27046,1,2,'Tbsp',33,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (27047,1,2,'Tbsp',30,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (27048,1,2,'Tbsp',34,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (27049,1,2,'tablespoons',30,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (27050,1,2,'Tbsp',35,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (27051,1,0.25,'cup',60,'g',1,'2012-03-02','2012-03-02');
INSERT INTO `cndb_wght` VALUES (27052,1,2,'Tbsp',30,'g',1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_wght` VALUES (27052,2,0.5,'cup',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (27059,1,1,'tbsp',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (27060,1,1,'cup',240,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (27062,1,1,'cup',208,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (27062,2,1,'can',527,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (27063,1,0.25,'cup',56,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (27063,2,1,'cup',224,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (27063,3,1,'can',283,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (27064,1,1,'tablespoon',20,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (27064,2,1,'teaspoon',6.5,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (27065,1,2,'tbsp',36,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (27065,2,1,'container (9 oz)',259,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (27066,1,1,'tsp',5.6,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28285,1,1,'piece',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28286,1,1,'piece',79,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28287,1,1,'piece',106,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28288,1,1,'piece',98,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28289,1,2,'cookies',29,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28290,1,2,'cookies',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28291,1,8,'cookies 1 serving',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28291,2,1,'package (40 g)',40,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28292,1,4,'crackers',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28293,1,3,'cookies',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28294,1,4,'cookies',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28295,1,1,'tortilla 1 serving',41,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28296,1,1,'cake 1 serving',27,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28297,1,1,'cake 1 serving',27,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28298,1,1,'brownie 1 serving',36,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28299,1,1,'serving',34,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28300,1,1,'cookie 1 serving',38,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28301,1,1,'serving 3 cookies',29,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28302,1,1,'serving',35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28303,1,1,'serving 55 pieces',31,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28304,1,1,'serving 2 waffles',70,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28305,1,1,'serving 3 pancakes',105,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28306,1,1,'piece',68,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28307,1,1,'piece',90,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (28308,1,5,'crackers 1 serving',15,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (28309,1,2,'cookie 1 serving',36,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (28310,1,1,'cookie',11.8,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28311,1,3,'cookie',29,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28312,1,1,'roll',51,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28313,1,1,'roll',56,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28314,1,1,'package',36,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28315,1,1,'slice 1 serving',28,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28316,1,1,'slice 1 serving',38,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28317,1,1,'slice 1 serving',38,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28318,1,1,'slice 1 serving',48,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28319,1,0.5,'piece bagel 1 serving',43,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28320,1,1,'muffin 1 serving',57,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28321,1,1,'piece roll',43,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28322,1,1,'piece bagel',81,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28324,1,0.25,'cup mix 1 serving',38,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28325,1,1,'serving',31,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28326,1,6,'cracker 1 serving',43,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28327,1,4,'cracker 1 serving',14,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28328,1,1,'cookie',34,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28329,1,1,'cookie',62,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28330,1,1,'bar',22,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28331,1,10,'goldfish',5.2,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28332,1,3,'cookies',44,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28333,1,3,'cookies',23,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28334,1,3,'cookies',30,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28335,1,3,'cookies',44,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28336,1,1,'slice',34,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28337,1,1,'slice',35,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28338,1,1,'slice',28,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28339,1,1,'slice',25,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28341,1,1,'roll',78,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28343,1,1,'roll',44,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28344,1,3,'crackers',10.7,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28345,1,3,'crackers',6.1,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28346,1,1,'waffle',45,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28346,2,1,'box',242,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28347,1,1,'pancake',48,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28347,2,1,'box',352,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28348,1,1,'roll',30,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28348,2,1,'slice',39,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28349,1,1,'cookie',25,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28350,1,1,'serving',40,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28351,1,5,'cookie',28,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28352,1,1,'serving cookie',48,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28397,1,1,'oz',28.35,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28397,2,1,'slice regular',26,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28397,3,1,'slice large',41,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28399,1,1,'oz',28.35,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28399,2,1,'Arrowroot biscuit (include Arrowroot cookie)',4.9,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28399,3,1,'cracker',2.5,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (28399,4,1,'individual box (2 oz)',57,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (31022,1,1,'cup prepared',130,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (31023,1,12,'fries',51,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (31024,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (31025,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (31026,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (31027,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (31028,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (31029,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (31030,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (31031,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (31033,1,2,'tablespoon',25,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (31034,1,0.25,'cup drained',34,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (31036,1,1,'cup',229,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (31036,2,1,'container',700,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32000,1,0.333,'cup',61,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32000,2,1,'tbsp',9,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32001,1,1,'cup',247,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (32002,1,0.333,'cup',68,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32002,2,1,'tbsp',9.6,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32003,1,1,'cup',238,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (32004,1,1,'serving (3.5 oz)',25,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32004,2,1,'serving (4 oz)',37,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32005,1,1,'cup prepared',189,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (32006,1,1,'piece',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (32007,1,1,'piece',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (32008,1,1,'package',123,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (32008,2,1,'packet',51,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (32009,1,1,'package',122,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (32009,2,1,'packet',44,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (32010,1,1,'package',141,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (32010,2,1,'packet',79,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (32011,1,1,'serving (2 oz)',57,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32012,1,1,'serving 6 rolls',80,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (32013,1,5,'pieces 1 serving',145,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (32014,1,1,'serving (3.5 oz)',99,'g',1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32015,1,1,'serving 4.5 oz',127,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (32016,1,1,'serving 1 pouch',61,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (32017,1,1,'package',117,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (32017,2,1,'packet',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (32018,1,0.5,'cup',70,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (32018,2,0.33,'cup',56,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (32018,3,1,'tbsp',8.8,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (32019,1,1,'cup 1 serving',237,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (32020,1,1,'thigh with bone and breading',133,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (32021,1,1,'cup',198,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (32024,1,0.25,'cup dry rice mix',57,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32025,1,3,'pieces pierogies',114,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32026,1,1,'piece turnover 1 serving',127,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32027,1,1,'piece turnover 1 serving',127,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32028,1,1,'piece turnover 1 serving',127,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32029,1,1,'cup',191,'g',1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_wght` VALUES (32031,1,1,'patty',63,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32032,1,1,'biscuit',126,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (32032,2,1,'box',526,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (35009,1,1,'strip',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35140,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35141,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35142,1,1,'piece',152,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35143,1,1,'serving',197,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35144,1,1,'serving',308,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35145,1,1,'serving',411,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35146,1,1,'serving',303,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35147,1,1,'piece',186,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35183,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35190,1,1,'filet',108,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35190,2,1,'strip',136,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35211,1,0.5,'cup',66,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35211,2,1,'piece',102,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35232,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35234,1,1,'piece',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35234,2,1,'piece',19,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35235,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35236,1,8,'oz',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35237,1,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (35239,1,1,'piece',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42040,1,1,'tbsp',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42040,2,1,'tsp',6.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42055,1,1,'tsp',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42063,1,1,'fl oz assumed specific gravity of honey',28.4,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (42074,1,1,'bar',78,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42116,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42116,2,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42117,1,1,'cup, shredded',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42117,2,1,'cubic inch',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42119,1,1,'fl oz',31.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42119,2,1,'bottle NFS',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42120,1,1,'fl oz',31.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42120,2,1,'bottle NFS',126,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42128,1,1,'cup pieces',138,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42128,2,1,'cubic inch',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42129,1,1,'cup pieces',138,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42129,2,1,'cubic inch',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42129,3,1,'slice, medium',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42129,5,1,'slice, thick',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42129,6,1,'slice, thin',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42131,1,1,'cup',137,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42135,1,1,'cup',75,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42136,1,1,'cup',94,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42136,2,1,'packet',3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42137,1,1,'tbsp',13.4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42137,2,1,'fl oz',26,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42138,1,1,'tbsp',14.6,'g',1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_wght` VALUES (42138,2,1,'cup',231,'g',1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_wght` VALUES (42139,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42140,1,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42140,2,1,'cup',216,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42141,1,1,'fl oz',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42141,2,1,'cup',242,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42150,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42150,2,1,'jar NFS',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42150,3,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42151,1,1,'tbsp',13,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42151,2,1,'cup',207,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42153,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42153,2,1,'cup',249,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42155,1,1,'cup, diced',132,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (42155,2,1,'cup, shredded',113,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (42155,3,1,'cubic inch',17,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (42155,4,1,'slice (1 oz)',28,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (42157,1,1,'tbsp',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42157,2,1,'cup',264,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42158,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42158,2,1,'cup',234,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42161,1,1,'slice',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42161,2,1,'cubic inch',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42161,3,1,'slice, medium',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42161,5,1,'slice, thick',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42161,6,1,'slice, thin',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42171,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42171,2,1,'cup',260,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42173,1,1,'cup, cooked',130,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42173,2,1,'oz',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42173,3,1,'oz cooked, yield',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42173,4,1,'patty, cooked',25,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42178,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42178,2,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42179,1,1,'frankfurter',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42179,2,1,'cup, sliced',151,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42185,1,1,'cup',186,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42186,1,1,'cup',174,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42187,1,1,'cup',174,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42189,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42189,2,1,'fl oz',30.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42190,1,2,'links 1 NLEA serving',45,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42190,2,3,'links 1 NLEA serving',60,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42192,1,1,'tbsp',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42192,2,1,'cup',265,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42193,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42193,2,1,'cup',256,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42204,1,1,'cubic inch',4.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42230,1,1,'tbsp',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42230,2,1,'cup',269,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42231,1,1,'tbsp',13.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42231,2,1,'cup',218,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42235,1,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42235,2,1,'cup',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42236,1,0.75,'cup (1 NLEA serving)',30,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (42256,1,1,'tablespoon',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42259,1,1,'cup',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42259,2,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42266,1,1,'fl oz',30.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42266,3,1,'bottle NFS',246,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42267,1,1,'fl oz',30.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42267,3,1,'bottle NFS',246,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42270,1,1,'cup',249,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42270,2,1,'fl oz',31.1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42270,3,1,'drink box (8.45 fl oz)',263,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42272,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42278,1,1,'cup',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42278,2,1,'tbsp',14.4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42278,3,1,'jar Earth''s Best (4.5 oz)',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42279,1,1,'cup',230,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42279,2,1,'tbsp',14.4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42279,3,1,'jar Earth''s Best (4.5 oz)',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42280,1,1,'cup, sliced',143,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42281,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42283,1,1,'cup',34,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42283,2,10,'chips',12,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42284,1,1,'cookie',1.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42285,1,1,'tbsp',3.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42286,1,1,'tbsp',14,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (42286,2,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_wght` VALUES (42289,1,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42289,2,1,'cup',224,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42289,3,1,'teaspoon',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42290,1,1,'cup',247,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42290,2,1,'fl oz',30.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42291,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42303,1,1,'cup, shredded',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42303,2,1,'cubic inch',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42303,3,1,'slice',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42304,1,1,'cup, shredded',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42307,1,1,'tablespoon',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42309,1,1,'tablespoon',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (42316,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43004,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43004,2,1,'jar NFS',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43004,3,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43004,4,1,'jar Heinz Strained-2 (4.25 oz)',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43006,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43006,2,1,'jar NFS',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43006,3,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43007,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43007,2,1,'jar NFS',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43007,3,1,'jar Heinz Junior-3 (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43008,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43008,2,1,'jar, Gerber (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43008,3,1,'jar NFS',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43008,4,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43015,1,1,'tbsp',14.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43015,2,1,'cup',235,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43015,3,1,'serving (2 tbsp)',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43016,1,1,'tbsp',19,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (43016,2,1,'cup',289,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (43017,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43017,2,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43019,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43019,2,1,'cup',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43020,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43020,2,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43021,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43021,2,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43026,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43026,2,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43027,1,1,'cup',300,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (43027,2,1,'tbsp',19,'g',1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_wght` VALUES (43028,1,1,'cup',224,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43028,2,1,'tbsp',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43031,1,1,'piece',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43046,1,1,'piece',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43057,1,1,'cup',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43057,2,1,'piece',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43058,1,1,'piece',3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43059,1,1,'serving',36,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (43060,1,1,'piece',2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43075,1,1,'fl oz',31.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43075,2,1,'cup (8 fl oz)',250,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43098,1,1,'serving',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43098,2,1,'cup',264,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43100,1,1,'bar',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43109,1,1,'large',143,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43109,2,1,'medium',115,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43109,3,1,'small',62,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43112,1,1,'cup',253,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43114,1,1,'cup',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43125,1,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43128,1,1,'cup',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43130,1,1,'cup, sliced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43130,2,1,'frankfurter',70,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43131,1,1,'slice, thin',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43132,1,1,'cup',144,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43134,1,1,'fillet',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43135,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43137,1,1,'slice',56,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43142,1,1,'cup',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43143,1,1,'cup',150,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43144,1,1,'cup',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43146,1,1,'cup',136,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43154,1,1,'tsp',4.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43154,2,1,'fl oz',29,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43158,1,1,'serving 1 packet',1,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43158,2,1,'serving 1 packet SUGAR TWIN',0.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43205,1,1,'tbsp',7.4,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43205,2,1,'envelope',37,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43212,1,1,'tbsp',7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43214,1,1,'cup',80,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43215,1,1,'tablespoon',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43215,2,1,'serving (2 tbsp)',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43216,1,1,'cup',196,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43216,2,1,'tsp',4.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43216,3,1,'individual packet',3,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43217,1,1,'cup',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43245,1,1,'cup (1 NLEA serving)',55,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43260,1,1,'tbsp',5.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43260,2,1,'envelope',20,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43261,1,1,'container (6 oz)',170,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43261,2,1,'container (4.4 oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43261,3,1,'cup (8 fl oz)',245,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43261,4,1,'container (8 oz)',227,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43268,1,1,'cup',80,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43269,1,1,'serving',74,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (43273,1,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43273,2,1,'cup',226,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43274,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43274,2,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43274,3,1,'tbsp, whipped',10,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43275,1,1,'cup, diced',140,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (43275,2,1,'cup, shredded',113,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (43275,3,1,'cubic inch',18,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (43275,4,1,'slice (3/4 oz)',21,'g',1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_wght` VALUES (43276,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43276,2,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43278,1,1,'slice',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43278,2,1,'cubic inch',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43278,3,1,'cup',224,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43282,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43282,2,1,'lb',453,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43283,1,1,'cup, chopped or diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43285,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43287,1,1,'cup, chopped or diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43297,1,1,'cup',22,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43299,1,1,'cup',225,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43311,1,1,'cup',180,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43312,1,1,'cup',182,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43325,1,3,'oz, boneless',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (43325,2,1,'cubic inch, boneless',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43326,1,3,'oz, boneless',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (43326,2,1,'cubic inch, boneless',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43327,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (43327,2,1,'lb',453,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43329,1,1,'tbsp',14.5,'g',1,'2011-03-28','2011-03-28');
INSERT INTO `cndb_wght` VALUES (43329,2,1,'cup',232,'g',1,'2011-03-28','2011-03-28');
INSERT INTO `cndb_wght` VALUES (43331,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43331,2,1,'cup',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43340,1,1,'cup, grated',100,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (43340,2,1,'tbsp',5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43344,1,1,'tablespoon',17,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (43345,1,1,'tsp',2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43346,1,1,'fl oz',29.8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43346,4,1,'bar',74,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43352,1,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43352,2,1,'cup',226,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43355,1,1,'tbsp',14,'g',1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_wght` VALUES (43355,2,1,'cup',224,'g',1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_wght` VALUES (43364,1,1,'cup',26,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43364,2,1,'bag, single serving',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43364,3,10,'chips',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43365,1,1,'cup',242,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43365,2,1,'fl oz',30.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43366,1,3,'oz with bone, cooked (yield after bone removed)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (43366,2,1,'cubic inch, boneless',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43367,1,3,'oz with bone, cooked (yield after bone removed)',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (43367,2,1,'cubic inch, boneless',17,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43369,1,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43369,2,1,'fl oz',30.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43378,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (43378,2,1,'slice cooked',8,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (43382,1,1,'cup',253,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43382,2,1,'fl oz',31.6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43384,1,1,'cup pieces',138,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43384,2,1,'slice, medium',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43384,4,1,'slice, thick',43,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43384,5,1,'slice, thin',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43387,1,1,'cup',144,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43390,1,3,'oz, boneless',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43390,2,1,'medium slice (approx 3" x 2" x 1/4")',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43390,3,1,'thick slice (approx 3" x 2" x 3/8")',42,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43391,1,3,'oz',85,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (43391,2,1,'medium slice (approx 3" x 2" x 1/4")',28,'g',1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_wght` VALUES (43391,3,1,'thick slice (approx 3" x 2" x 3/8")',42,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (43396,1,4,'oz',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43396,2,1,'cup',226,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43398,1,1,'cup, diced',140,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43398,2,1,'cup, shredded',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43398,3,1,'cubic inch',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43398,4,1,'slice',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43401,1,1,'tsp dry',1.7,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43404,1,1,'cup (8 fl oz)',240,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43404,2,1,'fl oz',30,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43405,1,1,'slice',28,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (43405,2,1,'cubic inch',15,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (43405,3,1,'cup, shredded',108,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (43405,4,1,'cup, diced',132,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (43406,1,1,'tsp',6,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43408,1,1,'fl oz',31.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43408,2,1,'bottle Earth''s Best (4.2 fl oz)',131,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43408,3,1,'bottle Heinz Strained (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43408,4,1,'bottle Gerber First Food (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43408,5,1,'bottle Beech-Nut Stage I (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43408,6,1,'bottle NFS',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43410,1,1,'cup, diced',130,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43410,2,1,'cup pieces',168,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43410,3,1,'piece',36,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43417,1,1,'jar NFS',179,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43432,1,1,'tbsp',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43441,1,1,'medium (2-1/2" dia)',36,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43441,2,1,'roll (pan, dinner, or small roll) (2" square, 2" high)',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43447,1,1,'cup, crushed',88,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43447,2,1,'bag, single serving',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43447,3,10,'chips',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43449,1,1,'cup',253,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43450,1,2.5,'oz',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43476,1,1,'cup',262,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43483,1,1,'cup',21,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43497,1,1,'cup',58,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43506,1,1,'bar',54,'g',1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_wght` VALUES (43507,1,1,'frankfurter',57,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43507,2,1,'cup, sliced',151,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43514,1,1,'serving 1.75 fl oz pop',55,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43523,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43523,2,1,'jar NFS',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43523,3,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43523,4,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43523,5,1,'jar Heinz Strained-2 (4.25 oz)',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43529,1,1,'tbsp',2.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43535,1,1,'fl oz',31.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43535,2,1,'bottle Heinz Strained (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43535,3,1,'bottle NFS',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43535,4,1,'bottle Beech-Nut Stage 2 (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43535,5,1,'bottle Gerber Second Foods (4 fl oz)',125,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43536,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43536,2,1,'jar NFS',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43536,3,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43536,4,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43536,5,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43537,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43537,2,1,'jar NFS',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43537,3,1,'jar Heinz Strained-2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43539,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43539,2,1,'jar NFS',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43539,3,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43539,4,1,'jar Beech-Nut Stage 2 (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43539,5,1,'jar Heinz Strained-2 (4.25 oz)',120,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43541,1,1,'cup',148,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43541,2,1,'cubic inch',10.2,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43543,1,1,'cup',244,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43543,2,1,'fl oz',30.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43544,1,1,'serving',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43546,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43546,2,1,'jar NFS',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43546,3,1,'jar Beech-Nut Baby''s First (2.5 oz)',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43546,4,1,'jar Beech-Nut Stage I (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43546,5,1,'jar Gerber First Foods (2.5 oz)',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43546,6,1,'jar Earth''s Best (4.5 oz)',128,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43546,7,1,'jar Heinz Beginner-1 (2.5 oz)',71,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43550,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43550,2,1,'jar NFS',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43550,3,1,'jar Gerber Second Food (4 oz)',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43566,1,1,'cup, crushed',63,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43566,2,10,'chips',16,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43572,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43585,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43589,1,1,'slice (1 oz)',28,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (43589,2,1,'cubic inch',15,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (43589,3,1,'cup, shredded',108,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (43589,4,1,'cup, diced',132,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (43595,1,1,'oz',28.35,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43595,2,1,'bar',37,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43597,1,1,'cup, diced',132,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43597,2,1,'cup, shredded',113,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43597,3,1,'cubic inch',18,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43597,4,1,'slice (1 oz)',28,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43598,1,1,'tbsp',15,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (43598,2,1,'cup',239,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (44005,1,1,'tablespoon',14,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (44005,2,1,'teaspoon',4.5,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (44018,1,1,'serving',0.1,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (44061,1,1,'serving',9.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (44061,2,1,'package 1.4 oz box, 4 servings',40,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (44074,1,4,'fl oz',118,'g',1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_wght` VALUES (44110,1,1,'tbsp',19,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (44110,2,1,'cup',300,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (44158,1,1,'serving',151,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (44158,2,1,'cup',262,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (44258,1,1,'serving',9.9,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (44258,2,1,'package',40,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (44259,1,1,'serving',113,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (44259,2,1,'cup',260,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (44260,1,1,'serving',8,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (44260,2,1,'package 4 servings',32,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (51385,1,1.5,'cups',168.35,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51386,1,2,'wraps',343.37,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51387,1,1,'cup',136.24,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51388,1,1,'cup',244.51,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51389,1,0.75,'cup',216.09,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51390,1,1,'cup',251.83,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51391,1,1,'wrap',193.51,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51392,1,1,'each',206.21,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51393,1,1,'piece (5" x 5")',271.56,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51394,1,1,'wrap',119.87,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51395,1,0.5,'cup',118.93,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51396,1,0.75,'cup',200.65,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51397,1,0.25,'cup',107.28,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51398,1,0.75,'cup',147.14,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51399,1,1,'cup',294.18,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51400,1,0.5,'cup',88.28,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51401,1,1,'slider',124.11,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51402,1,1,'wrap',190.14,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51403,1,1,'cup',169.34,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51404,1,1,'wrap',298.16,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51405,1,1.25,'cup',289.06,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51406,1,1,'cup',253.12,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51407,1,1,'piece (5" x 5")',184.17,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51408,1,1,'cup',196.45,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51409,1,1.25,'cup',413.28,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51410,1,1,'cup',364.57,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51411,1,6,'tots',148.72,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51412,1,1,'cup',271.47,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51413,1,0.75,'cup',161.15,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51414,1,0.5,'cup',122.37,'g',2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_wght` VALUES (51566,1,0.5,'Cup',177.25,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51567,1,1,'Biscuit',72.78,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51568,1,1,'piece',56.08,'g',2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_wght` VALUES (51570,1,1,'piece',45.56,'g',2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_wght` VALUES (51571,1,0.75,'Cup',133.7,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51572,1,1,'Portion (7/8" Thick Slice)',58.51,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51573,1,1,'Slice',60,'g',2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (51574,1,1,'Pancake',59.41,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51575,1,1,'Portion',55.6,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51576,1,1,'piece',90.8,'g',2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_wght` VALUES (51577,1,0.5,'Cup',220.57,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51578,1,1,'square',74,'g',2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (51579,1,0.5,'Cup',195.92,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51580,1,0.5,'Cup',192.88,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51581,1,1,'Piece (2"x3-3/4")',62.49,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51582,1,0.5,'Cup',188.5,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51583,1,1,'Piece (2"x3-3/4")',109.66,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51584,1,1,'Piece (2"x3-3/4")',112.51,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51585,1,1,'piece',64.74,'g',2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_wght` VALUES (51587,1,1,'Burrito',174.33,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51588,1,1,'Burrito',119.43,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51589,1,1,'Burrito',199.32,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51590,1,2,'Tostadas',191.18,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51591,1,2,'Tacos (Includes 3/8 Cup Lettuce/Tomato Mixture & 1 Tablespoon + 1 Teaspoon Shredded Cheese)',268.61,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51593,1,1,'Portion',181.58,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51594,1,1,'Portion',231.16,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51595,1,1,'Portion',197.75,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51596,1,0.75,'Cup',261.81,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51597,1,1,'Cup',295.92,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51598,1,0.75,'Cup',223.62,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51599,1,0.66,'Cup',232.78,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51600,1,0.5,'Cup',172.32,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51601,1,0.5,'Cup',226.64,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51602,1,0.75,'Cup',182.68,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51603,1,1,'Piece (2"x 3 3/4")',172.65,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51604,1,1,'Slice, 3/4" (Includes 1 Roll)',160.07,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51605,1,2,'Meatball Cupcakes',225.57,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51606,1,1,'Plate Nachos',122.55,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51607,1,1,'Portion (1 Breast, Or 1 Drumstick And Wing, Or 1 Thigh With Back).',94.2,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51608,1,1,'Piece (2"x 3 3/4")',224.12,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51609,1,1,'Piece (2"x 3 3/4")',184.68,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51610,1,2,'Pizza Muffins (Includes 2 Tablespoons Tomato Sauce)',151.55,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51611,1,1,'Piece (2"x 3 3/4")',146.14,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51612,1,1,'Steak',123.15,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51613,1,1,'Cup',251.13,'g',2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_wght` VALUES (51614,1,1,'Cup',222.69,'g',2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_wght` VALUES (51615,1,0.75,'Cup',234.6,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51616,1,1,'Cup',201.7,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51617,1,1,'Piece (2"x 3 3/4")',152.2,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51618,1,1,'Cup',286.03,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51619,1,1,'Cup',219.33,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51620,1,1,'Portion (Includes 3/4 Cup Stir Fry & 1/2 Cup Rice)',309.9,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51621,1,1,'Fajita',160.81,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51622,1,1,'Cup',239.03,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51623,1,1,'Cup',250.58,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51624,1,1,'Piece (2"x 3 3/4")',244.18,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51625,1,1,'Piece (2"x 3 3/4")',290.42,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51627,1,1,'Piece (2"x 3 3/4")',317.06,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51628,1,1,'Piece (2"x 3 3/4")',343.37,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51629,1,0.75,'Cup',288.71,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51630,1,0.75,'Cup',231.47,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51631,1,1,'Portion (Includes 2/3 Cup Beans & 1/2 Cup Rice)',268.6,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51632,1,1,'Cup',235.03,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51633,1,1,'Cup',283.7,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51634,1,1,'Taco Boat (Includes 3 Oz Meat, 3 Oz (16 Fries) Fries, 1 Tablespoons Tomatoes, 1 Teaspoon Cheese)',195.54,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51635,1,1,'Cup',186.23,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51636,1,1,'Chicken Breast',61.39,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51637,1,1,'Meatball',103.06,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51638,1,1,'Piece (2"x 3 3/4")',260.5,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51639,1,1,'chicken breast',66,'g',2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (51640,1,0.5,'Cup',144.64,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51641,1,0.5,'Cup',130.07,'g',2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_wght` VALUES (51642,1,0.5,'Cup',106.9,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51643,1,0.75,'Cup',137.7,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51644,1,1,'Cup',140.93,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51645,1,0.66,'Cup',112.33,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51646,1,1,'Souffle Cup (Includes 2 Lettuce Leaves)',232.02,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51647,1,0.5,'Cup',101.15,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51648,1,0.5,'Cup',82.04,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51649,1,0.5,'Cup',136.46,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51650,1,0.75,'Cup',167.87,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51651,1,0.375,'Cup',110,'g',2,'2017-05-01','2020-04-03');
INSERT INTO `cndb_wght` VALUES (51652,1,0.25,'Cup',66.33,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51653,1,1,'Portion (Includes 1 Cup Soup And 1 Souffle Cup [1/4 Cup + 2 1/2 Teaspoons] Chicken)',293.95,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51654,1,1,'Cup',225.11,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51655,1,1,'Cup',211.89,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51656,1,1,'Cup',205.47,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51657,1,1,'Cup',182.04,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51658,1,1,'Cup',253.99,'g',2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_wght` VALUES (51660,1,0.5,'Cup',134.53,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51661,1,0.5,'Cup',248.08,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51662,1,0.5,'Cup',103.73,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51663,1,0.5,'Cup',167.29,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51664,1,0.5,'Cup',213.31,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51665,1,0.33,'Cup',118.08,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51666,1,1,'Broccoli Bite',145.98,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51667,1,0.25,'Cup',59.6,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51668,1,1,'piece (2" X 3-3/4")',110.13,'g',2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_wght` VALUES (51669,1,0.33,'Cup',166.05,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51670,1,0.25,'Cup',53.79,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51671,1,0.5,'cup',186,'g',2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (51672,1,0.5,'Cup',136,'g',2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (51673,1,0.5,'Cup',140.4,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51674,1,0.33,'Cup',201.41,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51675,1,0.66,'Cup',240.34,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51676,1,0.5,'Cup',84.2,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51677,1,0.33,'Cup',71.22,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51678,1,3,'Plantains',87.52,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51679,1,1,'Serving (2-3 Baby Potatoes)',96.07,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51680,1,0.75,'Cup',123.79,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51681,1,0.5,'Cup',115.07,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51682,1,1,'Portion (3/8 Cup [2-3 Sticks] Zucchini & 2 Tablespoons Tomato Sauce)',155.9,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51683,1,0.25,'Cup',75.64,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51684,1,1,'Piece (3-1/2" X 2-1/2")',93.26,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51685,1,1,'Piece (3 1/2" X 2 1/2")',173.36,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51686,1,1,'Piece (2"x 3 3/4")',134.22,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51687,1,1,'Piece (2"x 3 3/4")',103.18,'g',2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_wght` VALUES (51688,1,1,'burrito bowl',406.23,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51689,1,0.75,'cup',167.26,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51691,1,0.25,'cup',78.95,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51692,1,1,'wrap',260,'g',2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (51693,1,1,'Piece (2"x 3 3/4")',298.29,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51694,1,1,'Piece (2"x 3 3/4")',295.67,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51695,1,1,'plate',166.41,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51696,1,2,'muffins',144.97,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51697,1,1,'portion (1/4 cup  beef mixture + 1/2 cup  rice)',341.26,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51698,1,1,'patty',79.91,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51699,1,1,'frittata bite',102,'g',2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (51700,1,1,'Piece (2"x 3 3/4")',244.26,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51701,1,1,'quesadilla',123.21,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51702,1,1,'Piece (2"x 3 3/4")',177.45,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51703,1,0.5,'cup',170.36,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51704,1,1,'Piece (2"x 3 3/4")',197.86,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51705,1,1,'portion (approx. 3 potato wedges)',89.42,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51706,1,0.33,'cup',135.27,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51707,1,1,'Piece (2"x 3 3/4")',156.39,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51708,1,1,'spring roll (with souffle cup)',78.64,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51709,1,0.5,'cup',218.81,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51710,1,0.75,'cup',184.8,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51711,1,0.125,'cup',20.16,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51713,1,0.125,'cup',34.01,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51714,1,1,'salad shaker',208.43,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51715,1,0.5,'cup',118.66,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51716,1,1,'cup',243.08,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51717,1,1,'cup',211.48,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51718,1,1,'cup',250.43,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51719,1,1,'cup',221.96,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51720,1,1,'burger',157.81,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51721,1,1,'sandwich',157.51,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51722,1,1,'sandwich',131.44,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51723,1,1,'stacker',114.25,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51724,1,1,'portion (1 pita pocket + 1 souffle cup)',273.6,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51725,1,1,'sandwich',148.03,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51726,1,1,'sandwich',144.51,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51727,1,1,'sandwich',174.25,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51728,1,1,'sandwich',106.23,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51729,1,1,'wrap',145.79,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51730,1,0.5,'cup',131.42,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51731,1,1,'roll',39.2,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51732,1,1,'burrito',157.09,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51733,1,1,'muffin',76.15,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51735,1,0.25,'cup',41.91,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51736,1,1,'bowl',208.48,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51738,1,0.75,'cup',278.51,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51739,1,0.66,'cup',144.32,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51740,1,1,'parfait',212.3,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51741,1,0.75,'cup',143.51,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51742,1,1,'patty',53.85,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51761,1,1,'Tbsp',26.12,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51762,1,0.33,'cup',128.28,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51763,1,0.25,'cup',61.78,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51764,1,1,'scoop',24.16,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51765,1,1,'souffle cup',25.53,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (51766,1,1,'ladle',23.97,'g',2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_wght` VALUES (80200,1,1,'leg',45,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (83110,1,1,'piece (5-1/2" x 1-1/2" x 1/2")',80,'g',1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_wght` VALUES (83110,2,1,'cubic inch, boneless',17,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (83110,3,1,'cup, cooked',136,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (90240,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (90480,1,1,'serving',21,'g',1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_wght` VALUES (90560,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (93600,1,3,'oz',85,'g',1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_wght` VALUES (119936,1,1.0,'Pizza',94.00,'g',3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (119937,1,1.0,'Pizza',104.00,'g',3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_wght` VALUES (119940,1,1.0,'Pizza',145.00,'g',3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_wght` VALUES (119951,1,2.0,'oz. of chicken with .8 oz. sauce',79.00,'g',3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_wght` VALUES (119952,1,2.9,'oz Chicken with 1.1 oz Sauce (109g)',112.00,'g',3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (119976,1,1.0,'Pizza',156.00,'g',3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_wght` VALUES (119977,1,1.0,'Pizza',153.00,'g',3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_wght` VALUES (119981,1,0.125,'pizza',153.00,'g',3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_wght` VALUES (119982,1,0.125,'pizza',154.00,'g',3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_wght` VALUES (119983,1,1.0,'PIZZA',130.00,'g',3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_wght` VALUES (119984,1,1.0,'pizza',127.00,'g',3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_wght` VALUES (119989,1,2.0,'Sticks',119.00,'g',3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_wght` VALUES (119990,1,1.0,'Piece',85.00,'g',3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_wght` VALUES (119991,1,1.0,'Piece',84.00,'g',3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_wght` VALUES (119992,1,1.0,'Pizza',140.00,'g',3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_wght` VALUES (119993,1,1.0,'Pizza',140.00,'g',3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_wght` VALUES (119994,1,1.0,'Pizza',122.00,'g',3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_wght` VALUES (119996,1,1.0,'Pizza',122.00,'g',3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_wght` VALUES (119999,1,1.0,'Pizza',126.00,'g',3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_wght` VALUES (120000,1,1.0,'Pizza',127.00,'g',3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_wght` VALUES (120001,1,1.0,'Pizza',126.00,'g',3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_wght` VALUES (120002,1,1.0,'Pizza',127.00,'g',3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_wght` VALUES (120003,1,1.0,'Pizza',141.00,'g',3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_wght` VALUES (120004,1,1.0,'Pizza',141.00,'g',3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_wght` VALUES (120007,1,2.0,'Pieces',125.00,'g',3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_wght` VALUES (120008,1,2.0,'Pieces',125.00,'g',3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_wght` VALUES (120019,1,0.125,'Pizza',147.00,'g',3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_wght` VALUES (120020,1,0.125,'Pizza',147.00,'g',3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_wght` VALUES (120033,1,1.0,'Pizza',133.00,'g',3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_wght` VALUES (120036,1,0.125,'Pizza',158.00,'g',3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_wght` VALUES (120037,1,0.125,'Pizza',159.00,'g',3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_wght` VALUES (120242,1,1.0,'Amount per serving',120.00,'ml',3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120256,1,1.0,'Amount per serving',120.00,'ml',3,'2017-05-02','2025-03-20');
INSERT INTO `cndb_wght` VALUES (120257,1,1.0,'Amount per serving',120.00,'ml',3,'2017-05-02','2025-03-20');
INSERT INTO `cndb_wght` VALUES (120258,1,1.0,'Amount per serving',120.00,'ml',3,'2017-05-02','2025-03-20');
INSERT INTO `cndb_wght` VALUES (120261,1,1.0,'Amount per serving',120.00,'ml',3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120266,1,1.0,'Amount per serving',120.00,'ml',3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120287,1,1.0,'Amount per serving',120.00,'ml',3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120289,1,1.0,'Amount per serving',120.00,'ml',3,'2017-05-01','2024-09-13');
INSERT INTO `cndb_wght` VALUES (120296,1,1.0,'Amount per serving',21.00,'g',3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120297,1,1.0,'Amount per serving',21.00,'g',3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120298,1,1.0,'Amount per serving',28.00,'g',3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120299,1,1.0,'Amount per serving',30.00,'g',3,'2017-05-02','2023-10-26');
INSERT INTO `cndb_wght` VALUES (120300,1,1.0,'Amount per serving',21.00,'g',3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120301,1,1.0,'Amount per serving',21.00,'g',3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120304,1,1.0,'Amount per serving',26.00,'g',3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120306,1,1.0,'Amount per serving',26.00,'g',3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120347,1,1.0,'Amount per serving',195.00,'g',3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120348,1,1.0,'Amount per serving',163.00,'g',3,'2017-05-01','2023-03-16');
INSERT INTO `cndb_wght` VALUES (120447,1,0.667,'Cup',93.00,'g',3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (120453,1,0.5,'cup',120.00,'g',3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (120472,1,4.5,'oz cup',128.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (120601,1,1.0,'Piece',154.00,'g',3,'2017-01-26','2025-01-23');
INSERT INTO `cndb_wght` VALUES (120605,1,0.125,'Pizza',148.00,'g',3,'2017-01-26','2024-12-19');
INSERT INTO `cndb_wght` VALUES (120607,1,0.125,'Pizza',150.00,'g',3,'2017-01-26','2025-01-23');
INSERT INTO `cndb_wght` VALUES (120608,1,0.125,'Pizza',147.00,'g',3,'2017-01-26','2024-12-19');
INSERT INTO `cndb_wght` VALUES (120609,1,0.125,'Pizza',147.00,'g',3,'2017-01-26','2024-12-19');
INSERT INTO `cndb_wght` VALUES (120612,1,8.0,'Pieces',114.00,'g',3,'2017-01-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (120617,1,1.0,'BAR',64.00,'g',3,'2017-01-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120618,1,1.0,'bar',64.00,'g',3,'2017-01-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120620,1,0.125,'Pizza',145.00,'g',3,'2017-01-30','2025-01-23');
INSERT INTO `cndb_wght` VALUES (120622,1,0.125,'Pizza',145.00,'g',3,'2017-01-30','2025-01-23');
INSERT INTO `cndb_wght` VALUES (120668,1,1.0,'Amount per serving',21.00,'g',3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120765,1,1.0,'Calzone',155.00,'g',3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (120766,1,1.0,'Brownie Bite',57.00,'g',3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (120767,1,1.0,'Calzone',154.00,'g',3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (120768,1,1.0,'Calzone',154.00,'g',3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_wght` VALUES (120769,1,1.0,'Piece',82.00,'g',3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_wght` VALUES (120771,1,1.0,'Cookie',43.00,'g',3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (120772,1,1.0,'Cookie',43.00,'g',3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_wght` VALUES (120783,1,1.0,'Cookie',34.00,'g',3,'2021-04-01','2023-11-16');
INSERT INTO `cndb_wght` VALUES (120785,1,1.0,'Cookie',43.00,'g',3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_wght` VALUES (120786,1,1.0,'Cookie',52.00,'g',3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_wght` VALUES (120790,1,1.0,'Cookie',43.00,'g',3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (120792,1,1.0,'Cookie',43.00,'g',3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (120803,1,1.0,'Calzone',156.00,'g',3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (120804,1,1.0,'Calzone',155.00,'g',3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (120805,1,1.0,'Cookie',34.00,'g',3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_wght` VALUES (120806,1,1.0,'Cookie',34.00,'g',3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (120807,1,1.0,'Cookie',34.00,'g',3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (120808,1,1.0,'Cookie',34.00,'g',3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_wght` VALUES (120809,1,1.0,'Cookie',34.00,'g',3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_wght` VALUES (120810,1,1.0,'Cookie',34.00,'g',3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (120811,1,1.0,'Cookie',34.00,'g',3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (120813,1,1.0,'Muffin Top',90.00,'g',3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (120814,1,1.0,'Muffin Top',91.00,'g',3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (120815,1,1.0,'Muffin Top',90.00,'g',3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (120818,1,1.0,'Muffin',85.00,'g',3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (120819,1,1.0,'Muffin',51.00,'g',3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_wght` VALUES (120820,1,1.0,'Muffin',70.00,'g',3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_wght` VALUES (120821,1,1.0,'Muffin',99.00,'g',3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (120831,1,1.0,'Loaf',40.00,'g',3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_wght` VALUES (120832,1,1.0,'Muffin',51.00,'g',3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_wght` VALUES (120837,1,1.0,'Muffin Top',91.00,'g',3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (120838,1,1.0,'Cookie',43.00,'g',3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_wght` VALUES (120839,1,1.0,'Muffin Top',71.00,'g',3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (120858,1,1.0,'Piece',102.00,'g',3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_wght` VALUES (120869,1,0.5,'cup',120.00,'g',3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (120873,1,0.5,'cup',125.00,'g',3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (120876,1,0.5,'cup',125.00,'g',3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (120884,1,0.5,'cup',130.00,'g',3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (120885,1,0.5,'cup',130.00,'g',3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (120909,1,1.0,'Omelet (2.1 oz./ 60g)',60.00,'g',3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120916,1,1.0,'Patty (1.25 oz./ 35g)',35.00,'g',3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (120931,1,3.9,'oz',110.56,'g',3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_wght` VALUES (120932,1,3.9,'oz',110.56,'g',3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (120933,1,3.9,'oz',110.56,'g',3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_wght` VALUES (120935,1,3.9,'oz',110.56,'g',3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_wght` VALUES (120942,1,5.0,'Slices',85.00,'g',3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_wght` VALUES (121018,1,4.0,'pieces',113.00,'g',3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121019,1,4.0,'PIECES',113.00,'g',3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121020,1,1.0,'PIECE',102.00,'g',3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121021,1,3.0,'PIECES',128.00,'g',3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121022,1,4.0,'PIECES',113.00,'g',3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121023,1,4.0,'PIECES',113.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121024,1,1.0,'piece',113.00,'g',3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (121034,1,1.0,'PIECE',85.00,'g',3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121035,1,1.0,'PIECE',102.00,'g',3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121036,1,4.0,'PIECES',113.00,'g',3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_wght` VALUES (121037,1,1.0,'PIECE',102.00,'g',3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121038,1,1.0,'piece',113.00,'g',3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121039,1,4.0,'PIECES',113.00,'g',3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121040,1,4.0,'pieces',113.00,'g',3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121041,1,1.0,'PIECE',102.00,'g',3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121042,1,4.0,'PIECES',113.00,'g',3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121043,1,1.0,'PIECE',102.00,'g',3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121044,1,4.0,'pieces',113.00,'g',3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121045,1,1.0,'PIECE',102.00,'g',3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121111,1,1.0,'Biscuit',62.00,'g',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121114,1,2.0,'oz',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121115,1,2.0,'oz',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121116,1,2.0,'oz',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121117,1,2.0,'oz',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121120,1,3.6,'oz',102.00,'g',3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121121,1,1.0,'Muffin',51.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121122,1,1.0,'Muffin',51.00,'g',3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121124,1,1.0,'Muffin',51.00,'g',3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121128,1,3.0,'oz',85.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121129,1,1.8,'oz',51.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121136,1,4.0,'oz',113.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121137,1,2.0,'oz',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121138,1,2.0,'oz',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121139,1,4.0,'oz',113.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121140,1,4.0,'oz',113.00,'g',3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_wght` VALUES (121141,1,4.0,'oz',113.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121144,1,2.0,'oz',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121147,1,2.0,'oz',57.00,'g',3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_wght` VALUES (121152,1,1.0,'Muffin',113.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121153,1,1.0,'Muffin',113.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121154,1,2.2,'oz',62.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121155,1,1.0,'Hoagie Roll',57.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121156,1,1.0,'Muffin',57.00,'g',3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_wght` VALUES (121157,1,1.0,'Hoagie',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121158,1,1.0,'Waffle',37.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121159,1,1.0,'Pancake',38.00,'g',3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (121161,1,1.0,'Waffle',37.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121162,1,2.0,'Waffles',74.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121163,1,1.0,'Pancake',37.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121164,1,2.0,'Pancakes',74.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121165,1,2.0,'Pancakes',74.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121168,1,1.0,'Muffin',28.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121169,1,1.0,'oz',28.00,'g',3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121170,1,1.0,'Waffle',40.00,'g',3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (121171,1,1.0,'Waffle',40.00,'g',3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121174,1,2.0,'Waffles',79.00,'g',3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (121175,1,2.0,'Waffles',74.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121176,1,2.0,'Pancakes',74.00,'g',3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (121177,1,2.0,'Pancakes',40.00,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121179,1,2.0,'Waffles',40.00,'g',3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (121180,1,4.0,'mini waffles',79.00,'g',3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (121181,1,2.0,'waffles',74.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121184,1,1.0,'Slice',37.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121185,1,1.0,'Slice',34.00,'g',3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (121187,1,1.0,'Slice',37.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121188,1,1.0,'Bread Stick',85.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121190,1,1.0,'Bread Stick',57.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121194,1,1.0,'slice',34.00,'g',3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (121195,1,1.96,'oz',56.00,'g',3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (121196,1,1.0,'Bread Stick',34.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121197,1,1.0,'Roll',28.00,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121198,1,1.0,'Slice',51.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121199,1,1.0,'Croissant',68.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121201,1,1.0,'Croissant',85.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121203,1,4.0,'pieces',78.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121204,1,4.0,'pieces',78.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121209,1,1.0,'Donut',71.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121211,1,1.0,'Donut',62.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121215,1,3.0,'oz',85.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121226,1,2.2,'oz',62.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121228,1,1.0,'Breakfast Bun',43.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121229,1,3.2,'oz',91.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121235,1,3.2,'oz',91.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121237,1,1.6,'oz',45.00,'g',3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_wght` VALUES (121238,1,2.1,'oz',60.00,'g',3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_wght` VALUES (121243,1,2.0,'oz',57.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121247,1,1.0,'Breakfast Bun',85.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121248,1,1.0,'Biscuit',57.00,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121250,1,1.0,'Biscuit',28.00,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121257,1,1.0,'Mini Loaf',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121258,1,2.0,'oz',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121260,1,1.0,'Apple Fritter',85.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121261,1,1.0,'bun',85.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121265,1,2.0,'oz',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121266,1,1.0,'Muffin',88.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121267,1,1.0,'Muffin',88.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121268,1,3.1,'oz',88.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121269,1,1.0,'Muffin',88.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121271,1,1.0,'Muffin',71.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121272,1,1.0,'Pack',28.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121273,1,1.0,'oz. portion',28.00,'g',3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121299,1,1.0,'Croissant',43.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121300,1,1.0,'Croissant',62.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121301,1,1.0,'Croissant',62.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121304,1,1.0,'Roll',57.00,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121305,1,1.0,'Hot Dog Bun',43.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121306,1,1.0,'oz',28.00,'g',3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121308,1,1.0,'Slice',28.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121309,1,1.0,'Slice (26 usable slices per loaf)',28.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121310,1,1.0,'Slice (26 usable slices per loaf)',28.00,'g',3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121313,1,2.0,'oz',57.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121315,1,1.0,'Bun',34.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121319,1,1.0,'Bun',57.00,'g',3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_wght` VALUES (121321,1,1.0,'Roll',51.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121323,1,1.8,'oz',51.00,'g',3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (121324,1,1.0,'Roll',142.00,'g',3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121326,1,1.0,'hoagie',198.00,'g',3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121328,1,1.0,'Dinner Roll',28.00,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121329,1,3.0,'oz',85.00,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121333,1,3.0,'oz',85.00,'g',3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (121334,1,1.0,'Hoagie Roll',51.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121335,1,3.0,'oz',85.00,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121336,1,3.0,'oz',85.00,'g',3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_wght` VALUES (121337,1,1.0,'Hoagie',184.00,'g',3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (121338,1,1.0,'oz',28.00,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121339,1,2.0,'oz',57.00,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121341,1,1.0,'Dinner Roll',57.00,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121342,1,2.0,'oz',57.00,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121352,1,1.0,'Hoagie',184.00,'g',3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (121353,1,1.0,'Hoagie',85.00,'g',3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (121356,1,1.0,'Roll',57.00,'g',3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_wght` VALUES (121357,1,1.0,'Bun',28.00,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121359,1,2.0,'oz',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121360,1,2.0,'oz',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121361,1,2.0,'oz',57.00,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121362,1,1.5,'oz',43.00,'g',3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (121363,1,1.0,'Hot Dog Bun',51.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121364,1,3.0,'Sticks, 3.3 oz',94.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121365,1,2.0,'Sticks',84.00,'g',3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121366,1,2.0,'Sticks',85.00,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121367,1,1.0,'Hamburger Bun',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121368,1,3.0,'Sticks, 3.3 oz',94.00,'g',3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_wght` VALUES (121369,1,1.0,'Sandwich',91.00,'g',3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (121370,1,1.0,'French Toast Stick',42.00,'g',3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_wght` VALUES (121371,1,2.0,'French Toast Sticks',85.00,'g',3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_wght` VALUES (121372,1,2.2,'oz',62.00,'g',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121378,1,1.0,'Hot Dog Bun',58.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121382,1,1.0,'Hamburger Bun',57.00,'g',3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (121388,1,1.8,'oz',51.00,'g',3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121390,1,1.0,'Hamburger Bun',51.00,'g',3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (121392,1,1.5,'oz',43.00,'g',3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (121393,1,1.0,'Bread Stick',28.00,'g',3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (121394,1,1.1,'oz',31.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121395,1,1.0,'Pack',31.00,'g',3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (121396,1,1.0,'Pack',31.00,'g',3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_wght` VALUES (121398,1,1.8,'oz',51.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121401,1,0.8,'oz',23.00,'g',3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121407,1,1.0,'Bagel',79.00,'g',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121408,1,3.0,'oz',85.00,'g',3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_wght` VALUES (121412,1,1.0,'Sandwich',92.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121413,1,1.0,'Sandwich',91.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121414,1,1.0,'Sandwich',147.00,'g',3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_wght` VALUES (121415,1,1.0,'Sandwich',67.00,'g',3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_wght` VALUES (121416,1,1.0,'sandwich',142.00,'g',3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_wght` VALUES (121417,1,1.0,'Sandwich',128.00,'g',3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_wght` VALUES (121418,1,1.0,'Sandwich',128.00,'g',3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_wght` VALUES (121419,1,1.0,'Sandwich',133.00,'g',3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_wght` VALUES (121420,1,1.0,'Sandwich',122.00,'g',3,'2021-04-01','2022-04-01');
INSERT INTO `cndb_wght` VALUES (121421,1,1.0,'Sandwich',142.00,'g',3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_wght` VALUES (121422,1,1.0,'Sandwich',85.00,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121423,1,1.0,'Sandwich',71.00,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121424,1,1.0,'Sandwich 3.15 oz',89.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121425,1,1.0,'Sandwich 4.15 oz',118.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121428,1,1.0,'Sandwich',128.00,'g',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121429,1,2.8,'oz',79.00,'g',3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_wght` VALUES (121431,1,1.0,'Bagel',57.00,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121432,1,1.0,'Bagel',57.00,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121438,1,1.0,'Biscuit',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121461,1,1.0,'Croffin',113.00,'g',3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121481,1,1.0,'Roll',43.00,'g',3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_wght` VALUES (121491,1,5.0,'French Toast Sticks',110.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121492,1,1.0,'bagel',57.00,'g',3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121499,1,2.0,'oz',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121501,1,2.0,'oz',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121502,1,1.0,'Biscuit',57.00,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121505,1,1.0,'Sandwich',71.00,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121506,1,1.0,'Biscuit',57.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121507,1,1.6,'oz',45.00,'g',3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121508,1,2.0,'oz',57.00,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121509,1,1.0,'bagel',57.00,'g',3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121510,1,1.0,'Bagel',57.00,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121511,1,1.0,'Bagel',57.00,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121516,1,1.0,'Bagel',57.00,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121518,1,1.0,'Dinner Roll',62.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121520,1,1.0,'oz',28.00,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121521,1,1.0,'Bagel',57.00,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121522,1,1.0,'oz',28.00,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121523,1,5.0,'MEATBALLS',79.38,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121525,1,4.0,'MEATBALLS',73.71,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121526,1,4.0,'MEATBALLS',77.10,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121527,1,5.0,'Meatballs',70.87,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121531,1,1.0,'serving',73.71,'g',3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121533,1,1.0,'serving',114.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121534,1,6.0,'oz',170.10,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121536,1,4.8,'oz',136.08,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121537,1,5.58,'oz.',158.19,'g',3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_wght` VALUES (121538,1,2.9,'oz.',82.21,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121539,1,3.45,'OZ',97.81,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121540,1,3.17,'oz.',89.87,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121543,1,2.89,'oz.',81.93,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121544,1,3.0,'TBSP.',97.81,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121545,1,2.71,'oz.',76.83,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121546,1,3.0,'oz',89.87,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121547,1,2.94,'oz.',83.35,'g',3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_wght` VALUES (121548,1,1.0,'serving',92.42,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121549,1,4.6,'oz.',130.41,'g',3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_wght` VALUES (121552,1,5.0,'oz.',141.75,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121555,1,4.0,'oz.',172.93,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121559,1,3.63,'oz.',102.91,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121563,1,5.91,'oz.',167.55,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121565,1,1.0,'serving',170.10,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121566,1,5.64,'oz',159.89,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121567,1,5.6,'oz.',158.76,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121568,1,7.44,'oz',210.92,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121569,1,7.44,'oz',210.92,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121575,1,2.46,'oz.',69.74,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121576,1,1.0,'PATTY',35.44,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121577,1,1.0,'PATTY',37.71,'g',3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_wght` VALUES (121580,1,1.0,'PATTY',70.90,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121581,1,1.0,'PATTY',62.37,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121584,1,1.0,'PATTY',69.50,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121587,1,1.0,'serving',61.52,'g',3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121588,1,1.0,'Patty',63.79,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121589,1,1.0,'PATTY',85.05,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121591,1,1.0,'PATTY',79.38,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121592,1,1.0,'PATTY',95.00,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121593,1,1.0,'PATTY',95.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121594,1,3.5,'oz.',99.22,'g',3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121595,1,1.0,'oz',28.35,'g',3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121596,1,1.82,'oz.',51.60,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121598,1,1.82,'oz',51.60,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121600,1,1.0,'serving',35.44,'g',3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121601,1,1.9,'oz.',53.87,'g',3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_wght` VALUES (121602,1,2.0,'oz.',56.70,'g',3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121603,1,2.0,'TABLESPOONS',30.00,'g',3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121604,1,1.83,'ounces',51.88,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121605,1,1.89,'oz',53.58,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121606,1,2.0,'oz.',56.70,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121607,1,1.79,'oz',50.75,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121608,1,2.0,'oz',56.70,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121609,1,6.0,'oz.',170.10,'g',3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121610,1,6.0,'oz.',170.10,'g',3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (121611,1,6.0,'oz.',170.09,'g',3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121612,1,6.0,'oz.',170.10,'g',3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121613,1,6.0,'oz.',170.10,'g',3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121614,1,6.0,'oz.',170.10,'g',3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_wght` VALUES (121615,1,6.0,'oz',170.10,'g',3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_wght` VALUES (121616,1,6.0,'oz',170.10,'g',3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_wght` VALUES (121617,1,6.0,'oz.',170.09,'g',3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121618,1,6.0,'oz.',170.10,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121619,1,1.0,'serving',170.10,'g',3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121621,1,1.0,'serving',170.10,'g',3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121622,1,1.0,'serving',170.10,'g',3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121623,1,6.0,'oz',170.10,'g',3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121624,1,5.83,'oz.',165.28,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121626,1,2.44,'oz.',69.17,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121628,1,4.0,'Bites',48.76,'g',3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121632,1,5.0,'MEATBALLS',79.38,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121634,1,4.0,'MEATBALLS',73.71,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121635,1,4.0,'MEATBALLS',77.10,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121636,1,5.0,'MEATBALLS',70.87,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121640,1,4.8,'oz',136.08,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121641,1,6.0,'oz',170.10,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121642,1,5.58,'oz.',158.19,'g',3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_wght` VALUES (121644,1,3.17,'oz.',89.87,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121646,1,2.89,'oz.',81.93,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121647,1,2.71,'oz.',76.83,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121648,1,3.17,'oz',89.87,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121649,1,2.94,'oz.',83.35,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121651,1,4.6,'oz.',130.41,'g',3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_wght` VALUES (121652,1,5.15,'oz.',146.00,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121657,1,3.63,'oz.',102.91,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121658,1,1.0,'serving',226.80,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121659,1,1.0,'serving',226.80,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121661,1,5.91,'oz.',167.55,'g',3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_wght` VALUES (121663,1,5.64,'oz.',159.89,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121664,1,5.6,'oz.',158.76,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121665,1,7.44,'oz',210.92,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121666,1,7.44,'oz',210.92,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121669,1,2.5,'oz.',70.87,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121678,1,1.0,'PATTY',35.44,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121679,1,1.0,'PATTY',37.71,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121682,1,1.0,'PATTY',70.90,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121683,1,1.0,'PATTY',62.37,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121686,1,1.0,'PATTY',69.50,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121690,1,2.17,'oz.',61.52,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121691,1,1.0,'PATTY',63.79,'g',3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121692,1,1.0,'PATTY',85.05,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121693,1,1.0,'PATTY',79.00,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121694,1,1.0,'PATTY',95.00,'g',3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121695,1,1.0,'PATTY',95.00,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121696,1,5.83,'oz.',165.28,'g',3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121699,1,2.44,'oz.',69.17,'g',3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121766,1,1.0,'Calzone',155.00,'g',3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_wght` VALUES (121767,1,1.0,'Calzone',155.00,'g',3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121768,1,1.0,'Calzone',155.00,'g',3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121769,1,1.0,'Calzone',155.00,'g',3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121773,1,1.0,'Bowl',113.00,'g',3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121774,1,1.0,'Bowl',113.00,'g',3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121775,1,1.0,'Calzone',156.00,'g',3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121776,1,1.0,'Bowl',113.00,'g',3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121778,1,1.0,'Muffin',85.00,'g',3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121780,1,1.0,'Muffin',51.00,'g',3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121781,1,1.0,'Muffin',85.00,'g',3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121783,1,1.0,'Cookie',34.00,'g',3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121784,1,1.0,'Cookie',34.00,'g',3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121785,1,1.0,'Cookie',52.00,'g',3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121789,1,1.0,'Empanada',91.00,'g',3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121790,1,1.0,'Bowl',108.00,'g',3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121791,1,1.0,'Bowl',108.00,'g',3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_wght` VALUES (121792,1,1.0,'Bowl',108.00,'g',3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_wght` VALUES (121868,1,1.0,'Bar (1.3oz)',37.00,'g',3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_wght` VALUES (121869,1,1.0,'Bar (1.3 oz)',36.00,'g',3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121878,1,0.125,'Pizza',145.00,'g',3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121879,1,0.125,'Pizza',145.00,'g',3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121887,1,1.0,'Pizza',141.00,'g',3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_wght` VALUES (121893,1,1.0,'Stick',28.00,'g',3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (121896,1,1.0,'COOKIE',43.00,'g',3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121908,1,4.0,'pieces',113.00,'g',3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121909,1,1.0,'PIECE',102.00,'g',3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_wght` VALUES (121941,1,2.73,'oz',77.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121943,1,2.06,'oz',58.00,'g',3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_wght` VALUES (121954,1,2.0,'Waffles',40.00,'g',3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_wght` VALUES (121955,1,2.0,'Waffles',40.00,'g',3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121956,1,1.0,'Serving',37.00,'g',3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121957,1,1.0,'Pancake',37.00,'g',3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121958,1,1.0,'pancake',37.00,'g',3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121959,1,2.0,'pancakes',74.00,'g',3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_wght` VALUES (121961,1,2.0,'Waffles',74.00,'g',3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_wght` VALUES (121962,1,1.0,'Donut',78.00,'g',3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121963,1,1.0,'Donut',78.00,'g',3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_wght` VALUES (121965,1,1.0,'Cornbread Bowl',71.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121966,1,1.0,'Pack',28.00,'g',3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_wght` VALUES (121972,1,1.0,'Sandwich',68.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121985,1,2.0,'Pack Hamburger Sliders',119.00,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (121986,1,2.0,'Pack Cheeseburger Sliders',133.00,'g',3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_wght` VALUES (121987,1,2.0,'Pack Hamburger Sliders',119.00,'g',3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_wght` VALUES (121988,1,2.0,'Pack Cheeseburger Sliders',133.00,'g',3,'2021-04-01','2024-03-14');
INSERT INTO `cndb_wght` VALUES (121989,1,3.0,'French Toast Sticks',100.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121990,1,1.0,'Sandwich',81.00,'g',3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_wght` VALUES (121992,1,1.0,'Muffin',113.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (121993,1,1.0,'oz',28.00,'g',3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_wght` VALUES (121994,1,1.0,'oz',28.00,'g',3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_wght` VALUES (122011,1,2.0,'slices',28.00,'g',3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_wght` VALUES (122013,1,28.0,'g',28.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122016,1,28.0,'g',28.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122017,1,28.0,'g',28.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122018,1,28.0,'g',28.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122019,1,28.0,'g',28.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122020,1,28.0,'g',28.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122023,1,28.0,'g',28.00,'g',3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_wght` VALUES (122024,1,28.0,'g',28.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122025,1,1.0,'slice',22.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122027,1,1.0,'slice',22.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122028,1,1.0,'slice',22.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122029,1,1.0,'slice',22.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122031,1,28.0,'g',28.00,'g',3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_wght` VALUES (122032,1,28.0,'g',28.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122036,1,28.0,'g',28.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122037,1,28.0,'g',28.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122039,1,28.0,'g',28.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122040,1,1.0,'Pocket',154.00,'g',3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122041,1,1.0,'Pocket',168.00,'g',3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_wght` VALUES (122042,1,1.0,'Pocket',154.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122052,1,1.0,'Muffin',51.00,'g',3,'2021-04-01','2023-11-16');
INSERT INTO `cndb_wght` VALUES (122063,1,1.0,'Cookie',43.00,'g',3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_wght` VALUES (122065,1,1.0,'Brookee',43.00,'g',3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122068,1,1.0,'Muffin',85.00,'g',3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122070,1,1.0,'Muffin',51.00,'g',3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122075,1,1.0,'Bowl',108.00,'g',3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122076,1,1.0,'Bowl',108.00,'g',3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_wght` VALUES (122077,1,1.0,'Amount per serving',240.00,'ml',3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (122079,1,1.0,'Amount per serving',240.00,'ml',3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_wght` VALUES (122080,1,1.0,'Amount per serving',21.00,'g',3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (122081,1,1.0,'PER SERVING',206.00,'g',3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_wght` VALUES (122089,1,1.0,'Amount per serving',28.00,'g',3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (122090,1,1.0,'Amount per serving',28.00,'g',3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (122092,1,1.0,'Amount per serving',240.00,'ml',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122096,1,1.0,'Amount per serving',120.00,'ml',3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_wght` VALUES (122109,1,5.75,'ounces',163.00,'g',3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122110,1,5.9,'ounces',167.00,'g',3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122111,1,2.0,'OZ',57.00,'g',3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_wght` VALUES (122112,1,2.0,'OZ',57.00,'g',3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_wght` VALUES (122113,1,8.9,'ounces',252.00,'g',3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_wght` VALUES (122114,1,4.4,'ounces',125.00,'g',3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_wght` VALUES (122115,1,6.0,'ounces',170.00,'g',3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122116,1,9.33,'ounces',265.00,'g',3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122117,1,11.0,'ounces',311.00,'g',3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122118,1,7.4,'ounces',209.00,'g',3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_wght` VALUES (122120,1,6.32,'ounces',179.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122123,1,1.0,'ounces',28.00,'g',3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_wght` VALUES (122124,1,4.3,'ounces',122.00,'g',3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122125,1,4.0,'ounces',113.00,'g',3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122126,1,4.1,'ounces',116.00,'g',3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122127,1,4.56,'ounces',129.00,'g',3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122128,1,4.5,'g',127.00,'g',3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122129,1,2.0,'oz',57.00,'g',3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122130,1,7.6,'ounces',215.00,'g',3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_wght` VALUES (122131,1,7.6,'Ounces',215.00,'g',3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_wght` VALUES (122132,1,1.1,'ounces',31.00,'g',3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_wght` VALUES (122133,1,3.9,'ounces',110.00,'g',3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122134,1,3.9,'ounces',111.00,'g',3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122135,1,1.0,'serving',114.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122136,1,1.0,'serving',103.48,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122225,1,3.0,'oz. cup',85.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122226,1,1.33,'oz box',37.24,'g',3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_wght` VALUES (122227,1,0.8,'oz bag',23.00,'g',3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122230,1,3.0,'oz. cup',85.00,'g',3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_wght` VALUES (122243,1,0.167,'Pizza',157.00,'g',3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_wght` VALUES (122244,1,1.0,'Pizza',141.00,'g',3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_wght` VALUES (122245,1,0.5,'Cup',125.00,'g',3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_wght` VALUES (122255,1,1.0,'Slice',85.60,'g',3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_wght` VALUES (122266,1,1.0,'PIECE',57.00,'g',3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_wght` VALUES (122267,1,3.0,'pieces',113.00,'g',3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_wght` VALUES (122268,1,3.0,'pieces',113.00,'g',3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_wght` VALUES (122271,1,3.15,'oz.',88.00,'g',3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_wght` VALUES (122348,1,3.0,'oz',85.00,'g',3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_wght` VALUES (122349,1,8.0,'bites 3 oz',85.00,'g',3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (122350,1,1.0,'package',31.00,'g',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122351,1,1.0,'Muffin',51.00,'g',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122353,1,1.0,'Breakfast Bun',91.00,'g',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122354,1,1.0,'Snack Bar',34.00,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122355,1,1.0,'Snack Bar',34.00,'g',3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_wght` VALUES (122356,1,1.0,'Snack Bar',34.00,'g',3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_wght` VALUES (122357,1,1.0,'Snack Bar',34.00,'g',3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (122358,1,1.0,'oz. portion',28.00,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122359,1,1.0,'Pack',28.00,'g',3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (122360,1,1.0,'Pack',57.00,'g',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122361,1,1.0,'Pack',57.00,'g',3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (122362,1,1.0,'Pack',57.00,'g',3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (122363,1,1.0,'oz. portion',28.00,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122364,1,1.0,'Muffin',69.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122365,1,1.0,'Breakfast Bun',65.00,'g',3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_wght` VALUES (122366,1,1.0,'Donut',65.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122367,1,1.0,'Breakfast Bun',80.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122368,1,1.0,'Muffin',84.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122369,1,2.0,'Slices',57.00,'g',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122370,1,1.0,'Roll',54.00,'g',3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (122371,1,1.0,'Hoagie Roll',57.00,'g',3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_wght` VALUES (122372,1,1.0,'Dinner Roll',28.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122373,1,1.0,'Dinner Roll',57.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122385,1,1.0,'Sandwich',126.00,'g',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122386,1,1.0,'Sandwich',94.00,'g',3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_wght` VALUES (122387,1,1.0,'Sandwich',99.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122391,1,1.0,'Sandwich',122.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122392,1,1.0,'Sandwich',113.00,'g',3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_wght` VALUES (122393,1,1.0,'Cheeseburger',128.00,'g',3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_wght` VALUES (122394,1,1.0,'Sandwich',131.00,'g',3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_wght` VALUES (122395,1,1.0,'Sandwich',119.00,'g',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122409,1,1.0,'Amount per serving',21.00,'g',3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (122417,1,2.0,'g',57.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122420,1,8.18,'ounces',232.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122421,1,11.65,'oz',330.00,'g',3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_wght` VALUES (122423,1,11.5,'ounces',326.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122424,1,6.15,'oz',172.20,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122425,1,6.45,'ounces',182.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122426,1,6.66,'ounces',188.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122427,1,6.17,'ounces',175.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122428,1,6.32,'ounces',179.00,'g',3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_wght` VALUES (122429,1,6.7,'ounces',189.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122430,1,8.5,'oz',241.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122431,1,9.5,'g',269.00,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122432,1,10.0,'oz',245.00,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122433,1,8.69,'oz',245.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122434,1,10.65,'oz',298.20,'g',3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_wght` VALUES (122435,1,12.7,'ounces',360.00,'g',3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_wght` VALUES (122436,1,1.0,'Kit',382.70,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122437,1,12.4,'oz',351.50,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122438,1,13.4,'oz',380.00,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122440,1,13.4,'ounces',380.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122441,1,12.82,'ounces',363.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122442,1,11.5,'ounces',326.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122443,1,9.33,'oz',264.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122444,1,9.43,'ounces',267.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122445,1,10.0,'ounces',283.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122446,1,6.1,'ounces',173.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122447,1,6.1,'g',173.00,'g',3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_wght` VALUES (122448,1,5.75,'oz',163.00,'g',3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_wght` VALUES (122449,1,6.1,'ounces',173.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122450,1,6.1,'ounces',173.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122451,1,6.1,'oz',170.80,'g',3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_wght` VALUES (122452,1,5.9,'oz',165.20,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122453,1,5.9,'ounces',167.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122454,1,6.4,'ounces',181.00,'g',3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_wght` VALUES (122455,1,6.66,'ounces',188.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122456,1,6.52,'ounces',184.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122457,1,3.41,'ounces',96.00,'g',3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_wght` VALUES (122458,1,7.8,'ounces',221.00,'g',3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_wght` VALUES (122459,1,7.65,'ounces',216.00,'g',3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_wght` VALUES (122460,1,6.75,'ounces',191.00,'g',3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_wght` VALUES (122461,1,7.85,'ounces',222.00,'g',3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_wght` VALUES (122462,1,12.9,'OZ',365.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122463,1,12.85,'ounces',364.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122464,1,12.9,'ounces',365.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122488,1,4.5,'oz. cup',128.00,'g',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122493,1,0.75,'oz bag',21.00,'g',3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (122494,1,0.75,'oz. pouch',21.00,'g',3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (122495,1,0.75,'oz. pouch',21.00,'g',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122533,1,1.0,'Piece',126.00,'g',3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_wght` VALUES (122534,1,1.0,'Piece',126.00,'g',3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_wght` VALUES (122535,1,1.0,'Piece',126.00,'g',3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_wght` VALUES (122546,1,1.0,'Empanada',146.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122547,1,1.0,'Pocket',154.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122548,1,1.0,'Calzone',155.00,'g',3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_wght` VALUES (122549,1,1.0,'Calzone',155.00,'g',3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_wght` VALUES (122551,1,1.0,'Calzone',155.00,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122552,1,1.0,'Cookie',43.00,'g',3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_wght` VALUES (122554,1,2.0,'ounces',56.00,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122555,1,1.0,'Cowboy Bread',96.00,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122558,1,4.0,'pieces',113.00,'g',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122560,1,0.5,'cup',85.00,'g',3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_wght` VALUES (122630,1,1.0,'Bar',34.00,'g',3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_wght` VALUES (122631,1,1.0,'bag',25.20,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122632,1,1.0,'bag',25.20,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122636,1,1.0,'Bar',33.60,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122637,1,1.0,'Bar',33.60,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122638,1,1.0,'Pack',28.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122639,1,1.0,'Pack',28.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122640,1,1.0,'Pack',28.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122641,1,1.0,'Pack',28.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122644,1,1.0,'Cookie',39.20,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122645,1,1.0,'Cookie',39.20,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122646,1,1.0,'Bar',67.20,'g',3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_wght` VALUES (122647,1,1.0,'Bar',67.20,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122648,1,1.0,'Bar',67.20,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122649,1,1.0,'Bar',67.20,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122650,1,1.0,'Bar',67.20,'g',3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_wght` VALUES (122651,1,1.0,'Pack',25.20,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122653,1,1.0,'Pack',28.00,'g',3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (122684,1,0.25,'cup',60.00,'g',3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_wght` VALUES (122707,1,1.0,'serving',106.31,'g',3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_wght` VALUES (122708,1,1.0,'frozen juice cup',132.00,'ml',3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (122709,1,1.0,'frozen juice cup',132.00,'ml',3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (122710,1,1.0,'frozen juice cup',132.00,'ml',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122711,1,1.0,'frozen juice cup',132.00,'ml',3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_wght` VALUES (122712,1,1.0,'frozen juice cup',132.00,'ml',3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (122713,1,1.0,'frozen juice cup',132.00,'ml',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122714,1,1.0,'frozen juice cup',130.00,'ml',3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (122715,1,1.0,'frozen juice cup',132.00,'ml',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122716,1,1.0,'frozen juice cup',132.00,'ml',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122717,1,1.0,'frozen juice cup',132.00,'ml',3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (122718,1,3.71,'ounce',105.00,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122719,1,3.67,'ounces',104.04,'g',3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (122722,1,5.38,'oz.',153.00,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122723,1,5.08,'ounces',144.08,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122724,1,5.08,'OUNCES',144.02,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (122725,1,7.03,'oz.',199.30,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123144,1,4.0,'ROLLS',113.00,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123146,1,1.0,'Bag',64.00,'g',3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123169,1,1.0,'PER SERVING',206.00,'g',3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123170,1,1.0,'Amount/serving',206.00,'g',3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123173,1,1.0,'Amount per serving',217.00,'g',3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123174,1,1.0,'Amount per serving',208.00,'g',3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123178,1,1.0,'Amount per serving',120.00,'ml',3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_wght` VALUES (123180,1,1.0,'Amount per serving',120.00,'ml',3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_wght` VALUES (123181,1,1.0,'Amount per serving',120.00,'ml',3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_wght` VALUES (123182,1,1.0,'Amount per serving',120.00,'ml',3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_wght` VALUES (123189,1,1.0,'Amount per serving',120.00,'ml',3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123198,1,1.0,'Piece',126.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123200,1,0.125,'Pizza',157.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123202,1,1.0,'Portion',80.00,'g',3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_wght` VALUES (123203,1,1.0,'Portion',79.00,'g',3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_wght` VALUES (123204,1,1.0,'Calzone',154.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123205,1,1.0,'Muffin',71.00,'g',3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_wght` VALUES (123210,1,1.0,'Tray',213.00,'g',3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_wght` VALUES (123211,1,1.0,'PITA',57.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123212,1,1.0,'PITA',56.00,'g',3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_wght` VALUES (123213,1,0.25,'cup',44.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123214,1,100.0,'Gram',100.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123215,1,1.0,'Biscuit',28.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123216,1,1.94,'ounce',55.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123217,1,1.0,'BAG',43.00,'g',3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123218,1,4.0,'Piece',91.00,'g',3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_wght` VALUES (123219,1,1.0,'LINK',21.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123220,1,3.0,'Piece',94.00,'g',3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_wght` VALUES (123221,1,1.0,'PIECE',89.00,'g',3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_wght` VALUES (123222,1,1.0,'Bar',34.00,'g',3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_wght` VALUES (123223,1,1.0,'Bagel',113.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123224,1,1.0,'Bagel',113.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123225,1,1.0,'bagel',113.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123228,1,0.5,'cup',130.00,'g',3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_wght` VALUES (123229,1,1.0,'Biscuit',62.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123230,1,1.0,'Bread Stick',51.00,'g',3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_wght` VALUES (123231,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123232,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123233,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123234,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123235,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123237,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123238,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123240,1,0.5,'cup',130.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123241,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123243,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123244,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123245,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123246,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123247,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123248,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123249,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123250,1,0.5,'cup',130.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123251,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123252,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123253,1,0.5,'cup',130.00,'g',3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_wght` VALUES (123254,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123255,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123256,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123257,1,1.0,'cup',235.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123258,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123260,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123261,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123262,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123263,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123266,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123267,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123268,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123269,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123270,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123271,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123272,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123273,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123274,1,0.5,'cup',130.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123275,1,1.0,'cup',235.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123276,1,0.5,'cup',130.00,'g',3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_wght` VALUES (123277,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123278,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123279,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123280,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123281,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123282,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123283,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123284,1,0.5,'cup',130.00,'g',3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_wght` VALUES (123285,1,0.5,'Cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123286,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123287,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123288,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123289,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123290,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123291,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123292,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123293,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123294,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123295,1,0.5,'cup',130.00,'g',3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123296,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123297,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123298,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123299,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123300,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123301,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123302,1,0.5,'Cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123303,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123304,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123305,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123306,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123307,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123308,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123309,1,1.0,'cup',235.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123310,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123311,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123312,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123313,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123314,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123315,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123316,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123317,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123318,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123319,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123320,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123321,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123322,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123323,1,0.5,'cup',130.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123324,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123325,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123326,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123327,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123328,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123329,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123330,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123331,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123332,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123333,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123334,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123335,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123337,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123338,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123339,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123340,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123341,1,0.5,'cup',130.00,'g',3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_wght` VALUES (123342,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123343,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123344,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123345,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123346,1,1.0,'cup',235.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123347,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123348,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123349,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123350,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123351,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123352,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123353,1,3.0,'oz',85.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123354,1,3.0,'oz',85.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123355,1,1.0,'Patty',70.00,'g',3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (123356,1,6.0,'ROLLS',128.00,'g',3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_wght` VALUES (123357,1,1.0,'Egg Roll',85.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123358,1,5.0,'Nuggets',85.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123359,1,1.0,'Sandwich',141.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123360,1,1.0,'Sandwich',145.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123361,1,3.0,'Piece',94.00,'g',3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_wght` VALUES (123362,1,1.0,'Cinnamon Swirl',71.00,'g',3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_wght` VALUES (123363,1,1.0,'Cinnamon Roll',85.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123364,1,3.0,'oz',85.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123365,1,3.0,'oz',85.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123366,1,3.46,'oz',98.00,'g',3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_wght` VALUES (123367,1,3.3,'oz',94.00,'g',3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_wght` VALUES (123368,1,3.3,'oz',94.00,'g',3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123369,1,4.1,'oz',116.00,'g',3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123370,1,2.9,'oz',82.00,'g',3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_wght` VALUES (123371,1,2.9,'oz',82.00,'g',3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123372,1,1.0,'Piece',74.00,'g',3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_wght` VALUES (123373,1,3.0,'oz',85.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123374,1,1.0,'Croissant',85.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123375,1,1.0,'Croissant',62.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123376,1,1.0,'Croissant',62.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123377,1,1.0,'Croissant',68.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123378,1,1.0,'Croissant',68.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123379,1,1.0,'Croissant',43.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123380,1,1.0,'Croissant',62.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123381,1,1.0,'croissant',43.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123382,1,1.0,'Croissant',62.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123383,1,1.0,'Dinner Roll',33.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123384,1,1.0,'Dinner Roll',28.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123385,1,1.0,'Donut',91.00,'g',3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123386,1,1.0,'Donut',91.00,'g',3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123387,1,1.0,'Donut',91.00,'g',3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123388,1,1.0,'Donut',91.00,'g',3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123389,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123390,1,1.0,'COOKIE DOUGH PIECE',28.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123391,1,3.0,'oz',85.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123392,1,3.0,'oz',85.00,'g',3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (123393,1,3.0,'oz',85.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123394,1,3.0,'oz (20 pieces',85.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123395,1,3.0,'oz',85.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123396,1,1.0,'COOKIE DOUGH PIECE',43.00,'g',3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_wght` VALUES (123397,1,1.0,'COOKIE DOUGH PIECE',43.00,'g',3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_wght` VALUES (123399,1,1.0,'COOKIE DOUGH PIECE',28.00,'g',3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123400,1,1.0,'COOKIE DOUGH PIECE',28.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123402,1,1.0,'COOKIE DOUGH PIECE',43.00,'g',3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_wght` VALUES (123403,1,1.0,'oz = Approximately 2 tbsp',28.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123404,1,1.0,'PATTY',43.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123405,1,1.0,'PATTY',42.00,'g',3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_wght` VALUES (123406,1,1.0,'LINK',40.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123407,1,2.0,'LINK',42.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123408,1,1.0,'LINK',28.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123409,1,1.0,'LINK',23.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123410,1,1.0,'LINK',28.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123411,1,1.0,'PATTY',42.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123412,1,1.0,'PATTY',28.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123414,1,1.0,'PATTY',28.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123415,1,1.0,'PATTY',42.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123416,1,1.0,'PATTY',56.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123417,1,1.0,'PATTY',42.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123418,1,1.0,'PATTY',42.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123419,1,1.0,'LINK',21.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123420,1,1.0,'Hamburger Bun',51.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123421,1,3.0,'oz',85.00,'g',3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123423,1,1.0,'Hoagie Roll',57.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123424,1,1.0,'Hoagie',85.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123425,1,1.0,'Hot Dog Bun',51.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123426,1,1.0,'Tray',195.00,'g',3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_wght` VALUES (123427,1,3.0,'oz',85.00,'g',3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_wght` VALUES (123428,1,1.0,'Pouch',28.00,'g',3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (123429,1,1.0,'Tray',209.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123430,1,1.0,'bar',64.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123432,1,1.0,'Mini Bread Stick',28.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123433,1,1.0,'Tray',204.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123434,1,1.0,'MUFFIN',57.00,'g',3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_wght` VALUES (123435,1,1.0,'MUFFIN',57.00,'g',3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_wght` VALUES (123436,1,1.0,'MUFFIN',113.00,'g',3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_wght` VALUES (123437,1,1.0,'MUFFIN',57.00,'g',3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_wght` VALUES (123438,1,1.0,'MUFFIN',113.00,'g',3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123439,1,1.0,'MUFFIN',57.00,'g',3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (123440,1,1.0,'MUFFIN',57.00,'g',3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_wght` VALUES (123441,1,2.0,'oz',57.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123442,1,1.0,'FiestaBoli',139.00,'g',3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_wght` VALUES (123443,1,1.0,'FiestaBoli',139.00,'g',3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_wght` VALUES (123444,1,1.0,'MUFFIN',113.00,'g',3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_wght` VALUES (123445,1,1.0,'Pancake',37.00,'g',3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_wght` VALUES (123446,1,1.0,'Pancake',37.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123447,1,1.0,'Pizzaboli',142.00,'g',3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_wght` VALUES (123448,1,4.0,'Pizzaboli Bites',168.00,'g',3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_wght` VALUES (123449,1,3.0,'oz (14 pieces',85.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123450,1,1.0,'Box',37.70,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123451,1,1.0,'Sandwich',128.00,'g',3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123452,1,1.0,'Sandwich',128.00,'g',3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_wght` VALUES (123453,1,1.0,'Sandwich',113.00,'g',3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_wght` VALUES (123454,1,1.0,'Sandwich',113.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123455,1,1.0,'Sandwich',156.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123456,1,1.0,'Sandwich',88.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123457,1,1.0,'Sandwich',88.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123458,1,1.0,'Sandwich',74.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123459,1,1.0,'Sandwich',74.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123460,1,1.0,'Sandwich',147.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123461,1,1.0,'Sandwich',131.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123462,1,1.0,'Sandwich',131.00,'g',3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_wght` VALUES (123463,1,1.0,'Sandwich',118.00,'g',3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (123464,1,1.0,'sandwich',115.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123465,1,1.0,'Sandwich',128.00,'g',3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_wght` VALUES (123466,1,1.0,'sandwich',115.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123467,1,1.0,'sandwich',115.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123468,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123469,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123470,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123471,1,0.5,'cup',130.00,'g',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123472,1,1.0,'Slider Bun',28.00,'g',3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (123473,1,1.0,'FiestaBoli',92.00,'g',3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_wght` VALUES (123474,1,1.0,'FiestaBoli',92.00,'g',3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_wght` VALUES (123475,1,1.0,'Tray',218.00,'g',3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_wght` VALUES (123478,1,3.0,'OZ',85.00,'g',3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (123479,1,1.0,'SweetBoli',82.00,'g',3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_wght` VALUES (123480,1,1.0,'SweetBoli',82.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123481,1,3.0,'oz',85.00,'g',3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (123482,1,1.0,'Breakfast Bun',85.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123483,1,1.0,'Egg Roll',85.00,'g',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123484,1,1.0,'Bottle',295.00,'ml',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123485,1,1.0,'Bottle',295.00,'ml',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123486,1,1.0,'Bottle',295.00,'ml',3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123487,1,1.0,'Can',340.00,'ml',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123488,1,1.0,'Can',340.00,'ml',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123489,1,1.0,'Can',162.00,'ml',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123490,1,1.0,'Can',162.00,'ml',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123491,1,1.0,'Can',162.00,'ml',3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123492,1,1.0,'Muffin',93.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123493,1,4.3,'OZ',121.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123494,1,5.34,'oz',151.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123495,1,4.36,'OZ',123.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123496,1,4.3,'OZ',122.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123497,1,4.36,'OZ',123.00,'g',3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123498,1,1.2,'oz bag',34.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123499,1,1.0,'Pouch',50.00,'g',3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123501,1,1.0,'Burger',82.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123502,1,1.0,'Pouch',25.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123505,1,1.0,'Bar',12.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123506,1,1.0,'Package',22.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123507,1,1.0,'Package',22.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123508,1,1.0,'Container',28.00,'g',3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123513,1,0.5,'cup',120.00,'g',3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_wght` VALUES (123515,1,1.0,'Sandwich',122.00,'g',3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_wght` VALUES (123516,1,6.0,'Mini Donuts',91.00,'g',3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_wght` VALUES (123517,1,6.0,'Mini Donuts',91.00,'g',3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_wght` VALUES (123520,1,1.0,'Slice',173.00,'g',3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_wght` VALUES (123521,1,1.0,'Slice',142.00,'g',3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_wght` VALUES (123522,1,1.0,'Slice',142.00,'g',3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_wght` VALUES (123524,1,1.0,'Muffin',99.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (123525,1,1.0,'SandwichThin',57.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (123526,1,1.0,'Crumble',96.00,'g',3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_wght` VALUES (123527,1,1.0,'Cookie',34.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (123528,1,1.0,'Muffin',85.00,'g',3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_wght` VALUES (123529,1,1.0,'Cookie',34.00,'g',3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_wght` VALUES (123531,1,1.5,'cups',140.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (123532,1,1.0,'Muffin',85.00,'g',3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_wght` VALUES (123533,1,1.0,'Calzone',142.00,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123534,1,1.0,'Cookie',28.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (123538,1,4.5,'oz cup',128.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (123543,1,4.5,'oz cup',128.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (123546,1,4.5,'oz cup',128.00,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123551,1,1.0,'Bar',62.00,'g',3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_wght` VALUES (123552,1,1.0,'Bar',62.00,'g',3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_wght` VALUES (123554,1,1.0,'EA',106.00,'g',3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_wght` VALUES (123555,1,1.0,'oz. bag',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123556,1,4.5,'oz. cup',128.00,'g',3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_wght` VALUES (123559,1,1.0,'bowl',28.00,'g',3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_wght` VALUES (123561,1,1.0,'Cookie',43.00,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123568,1,1.0,'Biscuit',60.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (123579,1,1.0,'Amount per serving',17.50,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (123584,1,1.0,'MUFFIN',113.00,'g',3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_wght` VALUES (123585,1,1.0,'MUFFIN',113.00,'g',3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_wght` VALUES (123586,1,1.0,'MUFFIN',113.00,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123592,1,1.0,'Amount per serving',30.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (123601,1,0.25,'CUP',63.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (123608,1,1.0,'serving',170.09,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (123609,1,1.0,'OZ',28.35,'g',3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_wght` VALUES (123610,1,2.0,'TABLESPOON',28.35,'g',3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_wght` VALUES (123611,1,2.0,'TABLESPOONS',28.35,'g',3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_wght` VALUES (123612,1,2.0,'TABLESPOON',28.35,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (123613,1,2.0,'TABLESPOONS',28.35,'g',3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_wght` VALUES (123614,1,2.0,'TABLESPOONS',28.35,'g',3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_wght` VALUES (123626,1,1.0,'Amount per serving',163.00,'g',3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_wght` VALUES (123631,1,1.0,'Amount per serving',120.00,'ml',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (123632,1,1.0,'Amount per serving',120.00,'ml',3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_wght` VALUES (123633,1,1.0,'Amount per serving',120.00,'ml',3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_wght` VALUES (123645,1,2.0,'slices',28.00,'g',3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_wght` VALUES (123677,1,1.0,'Calzone',155.00,'g',3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_wght` VALUES (123678,1,1.0,'Piece',102.00,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123686,1,32.0,'grams',32.00,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123687,1,1.0,'MUFFIN',113.00,'g',3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_wght` VALUES (123688,1,1.0,'MUFFIN',113.00,'g',3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_wght` VALUES (123689,1,1.0,'MUFFIN',113.00,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123690,1,1.0,'MUFFIN',113.00,'g',3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_wght` VALUES (123691,1,1.0,'Egg Patty',23.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123692,1,1.0,'oz.',28.00,'g',3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (123693,1,100.0,'Grams',100.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123694,1,1.0,'Roll',43.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123695,1,1.0,'Roll',57.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123696,1,1.0,'Roll',28.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123697,1,1.0,'Roll',43.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123698,1,1.0,'Roll',35.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123699,1,2.0,'Breadsticks',57.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123700,1,2.0,'Rolls',57.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123701,1,1.0,'Biscuit',64.00,'g',3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_wght` VALUES (123702,1,2.0,'Rolls',57.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123703,1,1.0,'Biscuit',57.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123704,1,1.0,'Biscuit',35.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123705,1,1.0,'Biscuit',31.00,'g',3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_wght` VALUES (123706,1,1.0,'Roll',68.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123707,1,1.0,'Biscuit',64.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123708,1,1.0,'Biscuit',64.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123709,1,1.0,'Biscuit',71.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123710,1,1.0,'Biscuit',71.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123711,1,1.0,'Biscuit',71.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123712,1,2.0,'Breadsticks',57.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123713,1,1.0,'Roll',28.00,'g',3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_wght` VALUES (123714,1,1.0,'Roll',57.00,'g',3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_wght` VALUES (123715,1,1.0,'Biscuit',64.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123716,1,1.0,'Breadstick',28.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123717,1,1.0,'Roll',71.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123718,1,1.0,'Biscuit',35.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123719,1,1.0,'Roll',57.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123720,1,3.95,'oz.',111.98,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123721,1,1.0,'serving',89.87,'g',3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (123722,1,5.83,'oz',137.21,'g',3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_wght` VALUES (123723,1,5.0,'oz.',141.75,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123724,1,3.44,'oz.',97.52,'g',3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (123725,1,1.0,'Amount/serving',120.00,'ml',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123726,1,1.0,'Amount per serving',354.00,'ml',3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_wght` VALUES (123727,1,1.0,'Amount per serving',340.00,'ml',3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_wght` VALUES (123728,1,1.0,'Amount per serving',120.00,'ml',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123729,1,1.0,'Amount per serving',120.00,'ml',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123730,1,1.0,'Amount per serving',252.00,'g',3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_wght` VALUES (123731,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123732,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123733,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123734,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123735,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123736,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123737,1,6.0,'slices',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123738,1,1.0,'slice',19.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123739,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123740,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123741,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123742,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123743,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123744,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123745,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123746,1,28.0,'g',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123747,1,28.0,'g',28.00,'g',3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_wght` VALUES (123748,1,28.0,'g',28.00,'g',3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_wght` VALUES (123749,1,28.0,'g',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123750,1,28.0,'g',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123751,1,28.0,'g',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123752,1,28.0,'g',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123753,1,28.0,'g',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123754,1,12.3,'OZ',348.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (123755,1,1.0,'Amount per serving',17.50,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (123756,1,3.95,'oz.',111.98,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123757,1,1.0,'serving',137.21,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123758,1,2.5,'oz',70.87,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123759,1,4.5,'oz. cup',128.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123760,1,2.27,'oz',65.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123761,1,1.33,'oz',37.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123762,1,1.45,'oz',41.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123763,1,1.45,'oz',41.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123764,1,2.2,'oz.bar',62.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123765,1,2.2,'oz. bar',62.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123766,1,2.2,'oz. bar',62.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123767,1,2.2,'oz. bar',62.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123768,1,1.3,'oz. bar',36.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123770,1,1.3,'oz. bar',36.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123771,1,1.3,'oz. bar',36.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123772,1,1.3,'oz. bar',36.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123773,1,1.3,'oz. bar',36.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (123774,1,1.45,'oz',41.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123775,1,1.0,'Amount per serving',38.00,'g',3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_wght` VALUES (123779,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123782,1,0.5,'cup',130.00,'g',3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_wght` VALUES (123783,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123784,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123785,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123788,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123789,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123790,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123791,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123792,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123793,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123794,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123795,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123798,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123799,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123801,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123802,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123804,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123805,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123807,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123808,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123809,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123810,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123811,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123813,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123814,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123819,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123820,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123821,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123823,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123824,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123825,1,0.5,'cup',130.00,'g',3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_wght` VALUES (123826,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123827,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123832,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123833,1,1.0,'frozen juice cup',132.00,'ml',3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_wght` VALUES (123835,1,0.5,'cup',130.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123836,1,1.0,'cup',235.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123837,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123838,1,1.0,'cup',235.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123839,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123840,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123841,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123842,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123843,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123845,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123847,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123850,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123855,1,0.5,'cup',130.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123856,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123857,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123858,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123859,1,4.0,'Piece',67.00,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (123861,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123863,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123864,1,0.5,'cup',130.00,'g',3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_wght` VALUES (123865,1,0.5,'cup',130.00,'g',3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_wght` VALUES (123866,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123869,1,1.0,'Bag',32.90,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123871,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123872,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123873,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123876,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123877,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123878,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123879,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123880,1,0.5,'cup',130.00,'g',3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_wght` VALUES (123882,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123883,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123886,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123887,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123889,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123890,1,1.0,'cup',235.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123891,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123892,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123893,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123896,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123897,1,0.5,'cup',130.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123898,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123900,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123903,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123904,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123905,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123907,1,0.5,'cup',130.00,'g',3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_wght` VALUES (123908,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123909,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123910,1,0.5,'cup',130.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (123911,1,100.0,'gram',100.00,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (123912,1,0.5,'cup',130.00,'g',3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_wght` VALUES (123913,1,0.5,'cup',130.00,'g',3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_wght` VALUES (123914,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123915,1,1.0,'cup',235.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123916,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123917,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123918,1,0.5,'Cup',126.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (123919,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123920,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123921,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123923,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123924,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123928,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123929,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123930,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123931,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123932,1,0.5,'Cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123933,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123936,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123939,1,0.5,'Cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123940,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123941,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123944,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123945,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123946,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123947,1,0.5,'cup',130.00,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (123949,1,3.44,'oz.',97.52,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123961,1,53.0,'fries',28.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123962,1,1.0,'PACKAGE',22.40,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123963,1,1.0,'PACKAGE',28.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123964,1,1.0,'Package',14.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123966,1,1.0,'PACKAGE',56.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123967,1,1.0,'EA',106.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123968,1,1.0,'EA',106.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123969,1,1.0,'EA',106.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123970,1,1.0,'EA',106.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123971,1,0.5,'cup',130.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123972,1,0.5,'cup',130.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123973,1,0.5,'cup',120.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123974,1,0.5,'cup',130.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123975,1,0.5,'cup',130.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123976,1,0.5,'cup',120.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123977,1,0.5,'cup',130.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123978,1,0.5,'cup',130.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123979,1,0.5,'cup',130.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123980,1,0.5,'cup',130.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123985,1,1.0,'Roll',28.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (123990,1,32.0,'g',32.00,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123991,1,27.0,'Grams',27.00,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (123992,1,27.0,'Grams',27.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (123993,1,27.0,'Grams',27.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (123994,1,1.0,'COOKIE DOUGH PIECE',52.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123995,1,1.0,'COOKIE DOUGH PIECE',52.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (123996,1,1.0,'COOKIE DOUGH PIECE',52.00,'g',3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_wght` VALUES (123997,1,1.0,'COOKIE DOUGH PIECE',52.00,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (123998,1,1.0,'COOKIE DOUGH PIECE',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124006,1,1.25,'oz.',35.00,'g',3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124007,1,1.0,'Biscuit',64.00,'g',3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124008,1,1.0,'Roll',43.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124009,1,1.0,'Biscuit',71.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124010,1,1.0,'Biscuit',71.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124011,1,1.0,'Biscuit',64.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124012,1,6.1,'ounces',173.00,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124013,1,4.5,'ounces',128.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124014,1,1.0,'cup',128.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124015,1,1.0,'cup',128.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124016,1,1.0,'cup',128.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124017,1,1.0,'cup',128.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124018,1,1.0,'package',57.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124019,1,0.5,'Cup',121.00,'g',3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124020,1,3.0,'oz. cup',85.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124021,1,3.0,'oz. cup',85.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124022,1,1.0,'bag (1oz)',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124023,1,1.33,'oz',37.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124024,1,1.2,'oz bag',35.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124025,1,1.2,'oz package',34.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124026,1,1.33,'oz',37.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124027,1,2.2,'oz. bar',62.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124028,1,1.8,'oz. bar',51.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124029,1,1.0,'oz bag',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124030,1,1.0,'COOKIE',37.24,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124032,1,1.0,'package',28.30,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124033,1,13.0,'chips',28.00,'g',3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_wght` VALUES (124037,1,1.0,'Packet',48.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124038,1,1.0,'Package',50.00,'g',3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_wght` VALUES (124039,1,1.0,'Packet',43.00,'g',3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_wght` VALUES (124040,1,1.0,'Package',51.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124041,1,0.5,'cup',130.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124042,1,1.0,'Can',162.00,'ml',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124043,1,26.0,'grams (approximately 0.9 oz)',25.20,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124044,1,1.0,'bag',25.20,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124045,1,26.0,'grams (approximately 0.9 oz)',25.20,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124046,1,1.0,'Bar',33.60,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124047,1,1.0,'Pack',28.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124048,1,1.0,'Pack',28.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124049,1,1.0,'Pack',51.80,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124050,1,1.0,'Pack',28.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124051,1,1.0,'Pack',51.80,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124052,1,1.0,'Pack',28.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124053,1,1.0,'Cookie',39.20,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124054,1,1.0,'Cookie',39.20,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124055,1,1.0,'Bar',67.20,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124056,1,1.0,'Bar',67.20,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124057,1,1.0,'Bar',67.20,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124058,1,1.0,'Pack',25.20,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124059,1,1.0,'Pack',25.20,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124060,1,1.0,'Pack',28.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124061,1,1.0,'Pack',51.80,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124062,1,1.0,'OZ',28.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124063,1,1.0,'Pack',28.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124064,1,1.0,'Pack',51.80,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124065,1,1.0,'Pack',28.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124066,1,1.0,'Pack',28.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124067,1,1.0,'Calzone',154.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124068,1,1.0,'Empanada',146.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124069,1,1.0,'Calzone',156.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124070,1,1.0,'Empanada',91.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124073,1,1.0,'oz. portion',28.00,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124074,1,1.0,'Waffle',67.20,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124075,1,1.0,'Waffle',67.20,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124076,1,2.0,'OZ',56.00,'g',3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_wght` VALUES (124077,1,13.0,'Pieces',64.00,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124078,1,1.0,'Waffle',67.20,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124081,1,2.85,'oz',79.80,'g',3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_wght` VALUES (124082,1,3.2,'OZ',89.60,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124083,1,1.0,'Bar',64.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124084,1,1.0,'Bar',64.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124085,1,1.0,'Bar',64.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124086,1,8.0,'Pieces',114.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124087,1,1.0,'MUFFIN',57.00,'g',3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124088,1,1.0,'MUFFIN',57.00,'g',3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124089,1,1.0,'MUFFIN',57.00,'g',3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124090,1,1.0,'MUFFIN',57.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124091,1,1.0,'MUFFIN',57.00,'g',3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124092,1,1.0,'MUFFIN',112.00,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124093,1,1.0,'COOKIE',37.24,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124094,1,1.0,'MUFFIN',57.00,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124095,1,1.0,'MUFFIN',113.00,'g',3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124096,1,100.0,'Gram',100.00,'g',3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_wght` VALUES (124097,1,1.0,'PACKAGE',56.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124098,1,1.0,'pkg (2oz)',56.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124099,1,53.0,'fries',28.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124100,1,1.0,'PACKAGE',22.40,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124101,1,1.0,'PACKAGE',28.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124102,1,1.0,'Package',14.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124103,1,1.0,'oz.',28.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124104,1,1.0,'oz.',28.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124105,1,1.0,'oz.',28.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124106,1,2.0,'oz.',57.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124107,1,1.0,'Patty (1.25 oz.)',35.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124108,1,1.0,'oz.',28.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124109,1,0.5,'Cup',110.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124111,1,1.0,'Patty (1.25 oz./ 35g)',35.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124112,1,1.0,'oz.',28.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124113,1,1.0,'cookie',36.40,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124114,1,1.33,'ounce carton',38.00,'g',3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_wght` VALUES (124115,1,1.0,'Can',162.00,'ml',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124116,1,1.0,'Can',162.00,'ml',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124117,1,1.0,'Bottle',295.00,'ml',3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124118,1,1.0,'Bottle',295.00,'ml',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124119,1,1.0,'Bottle',295.00,'ml',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124120,1,1.0,'Can',340.00,'ml',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124121,1,1.0,'Can',340.00,'ml',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124122,1,1.0,'Flatbread',57.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124123,1,1.0,'Flatbread',56.00,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124126,1,56.0,'g',56.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124127,1,56.0,'g',56.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124128,1,56.0,'g',56.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124129,1,56.0,'g',56.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124130,1,56.0,'g',56.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124131,1,56.0,'g',56.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124132,1,56.0,'g',56.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124133,1,56.0,'g',56.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124134,1,56.0,'g',56.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124135,1,48.0,'g',56.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124136,1,2.69,'OZ',75.32,'g',3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_wght` VALUES (124137,1,0.5,'cup dry',40.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124138,1,32.0,'g',32.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124139,1,4.4,'oz cup',124.74,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124140,1,4.0,'oz cup',113.40,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124141,1,4.5,'oz cup',128.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124142,1,1.0,'cup',140.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124143,1,2.17,'oz',60.76,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124144,1,4.68,'oz',131.04,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124145,1,4.68,'oz',131.04,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124146,1,3.5,'OZ',98.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124147,1,4.32,'oz',120.96,'g',3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_wght` VALUES (124148,1,4.52,'oz',126.56,'g',3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_wght` VALUES (124149,1,6.5,'OZ',182.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124150,1,5.25,'oz',147.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124151,1,1.0,'Kit',154.00,'g',3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_wght` VALUES (124152,1,4.5,'oz',126.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124153,1,4.5,'oz',126.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124154,1,3.65,'OZ',102.20,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124155,1,2.0,'Shells',130.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124156,1,4.4,'OZ',123.20,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124157,1,4.3,'OZ',120.40,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124158,1,4.45,'oz',124.60,'g',3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_wght` VALUES (124159,1,4.87,'oz',136.36,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124160,1,2.0,'oz',56.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124161,1,3.1,'oz',86.80,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124162,1,4.6,'oz',128.80,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124163,1,4.6,'oz',128.80,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124164,1,2.52,'oz',70.56,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124165,1,4.4,'oz',123.20,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124166,1,1.0,'oz',28.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124167,1,4.5,'oz',126.00,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124168,1,2.8,'OZ',78.40,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124169,1,2.0,'OZ',56.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124170,1,3.34,'oz',93.52,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124171,1,4.23,'oz',118.44,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124172,1,5.0,'oz',140.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124173,1,2.0,'ounce',56.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124174,1,3.81,'oz',106.68,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124175,1,1.0,'Waffle',67.20,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124176,1,1.0,'Waffle',67.20,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124177,1,4.65,'oz',130.20,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124178,1,4.75,'oz',133.00,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124179,1,4.2,'oz',117.60,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124180,1,4.87,'oz',136.36,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124181,1,4.6,'oz',128.80,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124182,1,4.85,'oz',135.80,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124183,1,2.27,'oz',63.56,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124184,1,27.0,'Grams',27.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124185,1,27.0,'Grams',27.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124186,1,1.0,'PACKAGE (1.66 ONZ / 47 GRM)',46.48,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124187,1,1.0,'package',56.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124188,1,19.0,'Chips',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124189,1,1.0,'package',42.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124190,1,22.0,'Chips',28.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124191,1,11.0,'CHIPS',28.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124192,1,22.0,'chips',28.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124193,1,1.0,'PACKAGE',56.00,'g',3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_wght` VALUES (124194,1,2.16,'oz',62.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124195,1,0.75,'oz pouch',21.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124196,1,27.0,'Grams',27.00,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124197,1,27.0,'Grams',27.00,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124198,1,27.0,'Grams',27.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124199,1,0.5,'Cup',55.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124200,1,1.0,'Burger',71.00,'g',3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_wght` VALUES (124201,1,1.0,'Burger',82.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124202,1,1.0,'Pouch',25.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124203,1,1.0,'Pouch',28.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124204,1,1.0,'Pouch',28.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124205,1,1.0,'Pouch',27.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124206,1,1.0,'Package',22.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124207,1,1.0,'Package',22.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124208,1,1.0,'Pouch',50.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124209,1,1.0,'Pouch',50.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124210,1,27.0,'Grams',27.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124211,1,27.0,'Grams',27.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124212,1,27.0,'Grams',27.00,'g',3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_wght` VALUES (124213,1,0.5,'Cup',130.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124214,1,4.5,'oz',128.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124216,1,1.0,'Bar',67.20,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124217,1,1.0,'Each',134.95,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124218,1,1.0,'Each',141.75,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124220,1,1.0,'Each',161.60,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124221,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124222,1,1.0,'Each',191.36,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124223,1,1.0,'Each',106.31,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124224,1,2.0,'slices',28.00,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124225,1,1.0,'Each',221.13,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124228,1,1.0,'Each',134.66,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124231,1,3.81,'oz',106.68,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124233,1,1.0,'Each',130.20,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124234,1,1.0,'Each',182.85,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124235,1,1.0,'Each',170.10,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124236,1,1.0,'Bar',33.60,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124237,1,1.0,'Each',102.06,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (124238,1,1.0,'Each',70.88,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124239,1,1.0,'Each',123.32,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124241,1,1.0,'Each',70.88,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124243,1,0.5,'cup',130.00,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124244,1,1.0,'Each',131.83,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124245,1,1.0,'Each',154.51,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124247,1,1.0,'Per 28g',28.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124248,1,1.0,'Bar',33.60,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124249,1,1.0,'Each',178.60,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124250,1,1.0,'Each',111.98,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124251,1,1.0,'Each',56.70,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124252,1,1.0,'Each',125.87,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124253,1,0.5,'cup',125.00,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124254,1,1.0,'Each',106.31,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124257,1,1.0,'Amount per serving',163.00,'ml',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124259,1,1.0,'Each',155.93,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124260,1,1.0,'Each',94.97,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124261,1,1.0,'Bar',33.60,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124262,1,1.0,'Each',163.10,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124263,1,0.5,'cup',125.00,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124264,1,1.0,'Each',102.06,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124266,1,1.0,'Each',199.87,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124267,1,1.0,'Each',141.75,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124269,1,1.0,'Each',92.14,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124270,1,1.0,'Pack',25.20,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124271,1,1.0,'Each',125.87,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124273,1,1.0,'Each',147.42,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124275,1,1.0,'Each',141.75,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124276,1,1.0,'Each',163.01,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124277,1,1.0,'Amount per serving',240.00,'ml',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124278,1,1.0,'Pastry',48.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124279,1,1.0,'Each',56.70,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124280,1,1.0,'Each',92.14,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124282,1,1.0,'Each',84.00,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124283,1,0.25,'cup',60.00,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124286,1,1.0,'Each',147.42,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124287,1,1.0,'Each',217.16,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124289,1,1.0,'Amount per serving',163.00,'ml',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124290,1,1.0,'Each',185.69,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124291,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124292,1,1.0,'Each',182.85,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124293,1,1.0,'Each',163.01,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124294,1,1.0,'each',106.31,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124295,1,1.0,'Each',151.67,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124296,1,1.0,'Burrito',182.00,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124297,1,1.0,'Each',56.70,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124298,1,1.0,'Each',155.93,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124299,1,1.0,'Each',151.67,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124300,1,1.0,'Each',151.67,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124301,1,1.0,'Each',217.16,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124302,1,1.0,'Each',147.42,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124303,1,1.0,'Each',56.70,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124305,1,1.0,'Pouch',96.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124306,1,1.0,'Each',70.88,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124307,1,1.0,'Each',147.42,'g',3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_wght` VALUES (124308,1,4.85,'oz',135.80,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124309,1,1.0,'Each',147.42,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124310,1,1.0,'Pouch',75.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124312,1,1.0,'Each',147.42,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124313,1,0.25,'cup',60.00,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124314,1,2.0,'slices',28.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124316,1,1.0,'Each',106.31,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124318,1,1.0,'Each',134.66,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124319,1,1.0,'Each',134.95,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124321,1,1.0,'Each',96.39,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124322,1,1.0,'Amount per serving',340.00,'ml',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124323,1,1.0,'Pastry',48.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124324,1,1.0,'Pastry',48.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124326,1,1.0,'Each',124.74,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124327,1,0.5,'cup',130.00,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124328,1,1.0,'Amount per serving',240.00,'ml',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124329,1,1.0,'Pack',25.20,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124330,1,1.0,'Each',148.84,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124331,1,1.0,'Each',159.60,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124332,1,1.0,'Each',70.88,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124333,1,1.0,'Pastry',48.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124335,1,1.0,'Each',62.37,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124336,1,100.0,'gram',100.00,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124337,1,1.0,'Each',56.70,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124338,1,1.0,'Each',147.42,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124340,1,1.0,'Each',131.83,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124341,1,1.0,'Each',150.26,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124342,1,1.0,'Amount per serving',355.00,'ml',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124343,1,1.0,'Each',70.00,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124344,1,1.0,'Each',154.51,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124347,1,1.0,'Each',96.39,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124349,1,1.0,'Each',85.05,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124355,1,1.0,'PER SERVING',252.00,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124356,1,1.0,'Amount per serving',240.00,'ml',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124357,1,1.0,'Each',102.06,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124358,1,1.0,'Each',163.01,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124365,1,1.0,'Amount per serving',240.00,'ml',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124366,1,1.0,'Each',147.42,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124367,1,1.0,'Each',63.79,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124368,1,0.25,'cup',60.00,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124369,1,0.5,'cup',130.00,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124371,1,1.0,'Each',150.26,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124372,1,1.0,'Each',70.88,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124373,1,1.0,'Pouch',96.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124374,1,1.0,'Amount per serving',340.00,'ml',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124377,1,1.0,'Each',145.60,'g',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124378,1,1.0,'Amount per serving',163.00,'ml',3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124379,1,0.5,'cup',125.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124380,1,1.0,'Each',124.60,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124381,1,1.0,'Amount per serving',120.00,'ml',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124382,1,1.0,'Bar',67.20,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124383,1,1.0,'Each',147.42,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124384,1,1.0,'Each',106.40,'g',3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124386,1,1.0,'Each',62.37,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124387,1,0.5,'cup',125.00,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124390,1,1.0,'Each',136.08,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124391,1,0.5,'cup',125.00,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124393,1,1.0,'Each',147.42,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124394,1,1.0,'Each',171.51,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124397,1,1.0,'Each',171.52,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124398,1,1.0,'Each',144.59,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124399,1,1.0,'Each',134.66,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124400,1,1.0,'Each',83.63,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124403,1,1.0,'Each',111.98,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124405,1,0.25,'cup',60.00,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124406,1,1.0,'Each',90.72,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124408,1,1.0,'Each',48.90,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124409,1,1.0,'cup',128.00,'g',3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124411,1,1.0,'Each',178.60,'g',3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124448,1,1.4,'oz.',40.00,'g',3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124449,1,1.0,'Slice (3 pieces/ 2.65 oz.)',74.20,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124450,1,1.0,'Slice (2.9 oz.)',81.20,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124452,1,1.0,'slice, 3 pieces',81.20,'g',3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_wght` VALUES (124453,1,3.0,'Pieces (2.90 oz.)',81.20,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124455,1,1.0,'Roll',43.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124456,1,1.0,'Roll',57.00,'g',3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124457,1,1.0,'Biscuit',62.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124458,1,1.0,'Roll',64.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124459,1,1.0,'Roll',57.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124460,1,0.083,'of Sheet',57.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124461,1,1.0,'Roll',71.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124462,1,1.0,'Breadstick',32.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124463,1,1.0,'Roll',28.00,'g',3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124464,1,11.0,'chips',28.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124465,1,4.5,'oz cup',128.00,'g',3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124466,1,1.0,'Pouch',28.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124467,1,1.0,'Pouch',21.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124468,1,1.0,'Container',28.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124469,1,1.0,'Pouch',28.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124470,1,1.0,'Pouch',28.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124471,1,1.0,'Pouch',28.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124472,1,1.0,'Bar',12.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124473,1,1.0,'Container',59.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124474,1,1.0,'Container',59.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124475,1,1.0,'Container',59.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124476,1,1.0,'Container',28.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124477,1,1.0,'Container',28.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124478,1,1.0,'Container',28.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124479,1,1.0,'Container',28.00,'g',3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124480,1,3.55,'oz.',99.00,'g',3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124483,1,27.0,'Grams',27.00,'g',3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_wght` VALUES (124484,1,4.0,'Nuggets',86.00,'g',3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124485,1,1.0,'Bar',33.60,'g',3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124486,1,1.0,'Bar',33.60,'g',3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124487,1,1.0,'Pack',25.20,'g',3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124488,1,1.0,'Bar',33.60,'g',3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_wght` VALUES (124489,1,0.5,'cup',93.00,'g',3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124490,1,0.5,'cup',120.00,'g',3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124491,1,0.5,'cup',93.00,'g',3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_wght` VALUES (124493,1,1.0,'patty',35.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124495,1,1.0,'Calzone',156.00,'g',3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_wght` VALUES (124496,1,1.1,'ounces',31.00,'g',3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124497,1,1.0,'Each',147.42,'g',3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_wght` VALUES (124498,1,1.0,'ounces',28.00,'g',3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124499,1,1.0,'ounces',28.00,'g',3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124505,1,0.5,'Cup',56.00,'g',3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124506,1,1.0,'Patty',61.60,'g',3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124507,1,6.1,'ounces',173.00,'g',3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124508,1,6.1,'ounces',173.00,'g',3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_wght` VALUES (124509,1,213.0,'Servings Per Container',84.00,'g',3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124510,1,3.0,'ounces',85.00,'g',3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_wght` VALUES (124511,1,0.9,'ounces',26.00,'g',3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124512,1,1.0,'Slice (138g)',136.36,'g',3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124513,1,1.0,'slice',137.00,'g',3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124514,1,4.5,'oz. cup',128.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124515,1,4.5,'oz cup',128.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124516,1,4.5,'oz cup',128.00,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124517,1,1.3,'oz. bar',36.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124518,1,1.0,'oz. bag',28.00,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124519,1,1.28,'oz',36.29,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124520,1,1.28,'oz bag',36.29,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124521,1,1.28,'oz. bag',36.29,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124522,1,1.5,'oz pouch',42.00,'g',3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124523,1,1.5,'oz pouch',42.00,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124527,1,1.0,'Amount per serving',120.00,'ml',3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124528,1,1.0,'Amount per serving',120.00,'ml',3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124529,1,1.0,'Amount per serving',120.00,'ml',3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124530,1,1.0,'Amount per serving',120.00,'ml',3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124531,1,1.0,'Amount per serving',120.00,'ml',3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124532,1,1.0,'Amount per serving',120.00,'ml',3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124533,1,1.0,'Amount per serving',120.00,'ml',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124551,1,1.0,'Amount per serving',120.00,'ml',3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124552,1,8.9,'ounces',252.00,'g',3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_wght` VALUES (124553,1,11.9,'OZ',337.00,'g',3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124554,1,1.0,'ounces',28.00,'g',3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124555,1,1.0,'Bar',37.00,'g',3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124556,1,1.0,'Bar',37.00,'g',3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124557,1,1.0,'Bar',37.00,'g',3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124558,1,1.0,'Bar',37.00,'g',3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_wght` VALUES (124569,1,4.5,'oz cup',128.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124570,1,4.5,'oz cup',128.00,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124571,1,5.15,'oz.',146.00,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124574,1,6.0,'OZ',170.10,'g',3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_wght` VALUES (124575,1,1.0,'serving',43.00,'g',3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_wght` VALUES (124576,1,1.0,'serving',85.90,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124577,1,1.0,'COOKIE DOUGH PIECE',43.00,'g',3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_wght` VALUES (124578,1,1.0,'Pattie',40.00,'g',3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124579,1,57.0,'GR',57.00,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124580,1,84.0,'GR',84.00,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124581,1,4.0,'OZ',112.00,'g',3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124582,1,56.0,'GR',56.00,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124583,1,2.0,'OZ',56.00,'g',3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124584,1,3.3,'oz',95.00,'g',3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124585,1,2.0,'Links',40.00,'g',3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124586,1,3.15,'Ounces',88.20,'g',3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_wght` VALUES (124587,1,3.58,'oz',102.00,'g',3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_wght` VALUES (124588,1,3.5,'oz',102.00,'g',3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124589,1,3.58,'oz',100.24,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124590,1,2.0,'OZ',45.00,'g',3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_wght` VALUES (124591,1,2.0,'links',39.48,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124592,1,1.0,'Patty',39.48,'g',3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_wght` VALUES (124593,1,102.0,'g',100.80,'g',3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124594,1,3.35,'oz',95.00,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124595,1,1.5,'oz pouch',42.50,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124598,1,1.0,'Package',75.00,'g',3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_wght` VALUES (124599,1,0.333,'cup Dry',45.00,'g',3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_wght` VALUES (124600,1,0.5,'Cup Dry',40.00,'g',3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_wght` VALUES (124601,1,0.5,'cup dry',40.00,'g',3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_wght` VALUES (124602,1,0.5,'cup dry',40.00,'g',3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_wght` VALUES (124603,1,1.0,'Pizza',122.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124604,1,1.0,'package',31.80,'g',3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_wght` VALUES (124611,1,2.0,'oz',56.00,'g',3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_wght` VALUES (124612,1,56.0,'GR',56.00,'g',3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124622,1,32.0,'Chips',28.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124626,1,1.0,'Amount per serving',354.00,'ml',3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124627,1,2.0,'SLICES',28.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124628,1,2.0,'SLICES',28.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124629,1,2.0,'SLICES',28.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124630,1,2.0,'SLICES',28.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124631,1,2.0,'SLICES',28.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124632,1,2.0,'SLICES',25.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124633,1,1.0,'Pouch',75.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124634,1,1.0,'Bar',44.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124635,1,1.0,'Pouch',86.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124636,1,1.0,'Bar',44.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124637,1,1.0,'Bar',44.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124638,1,1.0,'Pouch',86.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124639,1,1.0,'Container',35.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124640,1,1.0,'Patty',38.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124641,1,37.0,'g',37.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124642,1,37.0,'grams',37.00,'g',3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_wght` VALUES (124643,1,2.0,'oz',56.00,'g',3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124644,1,2.0,'oz',56.00,'g',3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124645,1,2.0,'oz',56.00,'g',3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124646,1,2.4,'ounces',68.00,'g',3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124647,1,6.1,'ounces',173.00,'g',3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124665,1,1.0,'Pouch',86.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124688,1,1.0,'Bottle',300.00,'ml',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124689,1,0.5,'Cup',56.00,'g',3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_wght` VALUES (124690,1,6.1,'ounces',173.00,'g',3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_wght` VALUES (124691,1,4.0,'ounces',113.00,'g',3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124692,1,6.1,'ounces',174.00,'g',3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124693,1,8.28,'ounces',234.00,'g',3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124694,1,5.9,'ounces',167.00,'g',3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124695,1,6.1,'ounces',173.00,'g',3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124697,1,1.0,'Bar',34.00,'g',3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_wght` VALUES (124698,1,0.5,'cup',120.00,'g',3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_wght` VALUES (124699,1,0.5,'cup',130.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124700,1,0.5,'cup',125.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124701,1,0.5,'cup',125.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124702,1,0.5,'cup',120.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124703,1,0.5,'cup',120.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124704,1,0.5,'cup',125.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124705,1,0.5,'cup',120.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124706,1,0.5,'cup',125.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124707,1,0.5,'cup',120.00,'g',3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124708,1,1.0,'COOKIE DOUGH PIECE',43.00,'g',3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_wght` VALUES (124709,1,3.35,'oz',95.00,'g',3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_wght` VALUES (124710,1,53.0,'Servings Per Container',84.00,'g',3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124711,1,4.5,'oz',128.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124712,1,1.0,'Bar',44.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124713,1,172.0,'Servings Per Container',78.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124714,1,1.0,'Piece',69.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124715,1,1.0,'Piece',69.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124716,1,343.0,'Servings Per Container',37.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124717,1,1.0,'Portion',80.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124718,1,1.0,'Portion',79.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124719,1,1.0,'slice',22.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124720,1,28.0,'g',28.00,'g',3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_wght` VALUES (124721,1,2.0,'slices',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124722,1,2.0,'slices',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124723,1,2.0,'slices',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124724,1,2.0,'slices',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124725,1,2.0,'slices',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124726,1,2.0,'slices',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124727,1,1.0,'slice',22.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124728,1,1.0,'slice',22.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124729,1,1.0,'slice',22.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124730,1,28.0,'g',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124731,1,28.0,'g',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124732,1,28.0,'g',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124733,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124734,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124735,1,1.0,'Pouch',21.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124736,1,2.0,'SLICES',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124737,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124738,1,0.25,'cup',61.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124739,1,1.5,'oz',43.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124740,1,1.0,'Amount per serving',120.00,'ml',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124741,1,1.0,'Amount per serving',240.00,'ml',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124742,1,8.0,'Fluid Ounces',8.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124743,1,1.0,'Packet',7.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124744,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124745,1,2.0,'Tbsp',36.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124746,1,1.0,'Cup',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124747,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124748,1,0.25,'Cup',61.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124749,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124750,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124751,1,0.25,'Cup',61.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124752,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124753,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124754,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124755,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124756,1,1.0,'Packet',9.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124757,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124758,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124759,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124760,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124761,1,1.0,'oz',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124762,1,1.0,'oz.',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124763,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124764,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124765,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124766,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124767,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124768,1,1.0,'Packet',9.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124769,1,1.0,'Packet',9.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124770,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124771,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124772,1,1.25,'oz.',35.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124773,1,0.5,'CUP',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124774,1,1.0,'oz',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124775,1,2.0,'Tbsp',29.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124776,1,2.0,'Tbsp',29.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124777,1,2.0,'Tbsp',29.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124778,1,1.0,'Tsp',5.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124779,1,0.5,'cup',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124780,1,0.25,'Cup',64.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124781,1,0.5,'Cup',123.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124782,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124783,1,8.0,'Fluid Ounces',8.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124784,1,2.0,'Tbsp',33.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124785,1,0.25,'Cup',61.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124786,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124787,1,0.5,'cup',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124788,1,0.5,'cup',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124789,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124790,1,0.25,'Cup',63.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124791,1,2.0,'Tbsp',34.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124792,1,0.25,'Cup',61.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124793,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124794,1,0.25,'Cup',63.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124795,1,0.5,'CUP',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124796,1,0.5,'Cup',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124797,1,0.5,'Cup',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124798,1,0.5,'Cup',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124799,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124800,1,2.0,'Tbsp',33.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124801,1,0.25,'Cup',61.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124802,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124803,1,0.5,'Cup',123.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124804,1,8.0,'Fluid Ounces',240.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124805,1,8.0,'Fluid Ounces',8.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124806,1,8.0,'Fluid Ounces',8.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124807,1,8.0,'Fluid Ounces',8.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124808,1,0.25,'Cup',61.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124809,1,0.5,'cUP',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124810,1,0.25,'CUP',60.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124811,1,3.0,'Fluid Ounces',3.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124812,1,0.5,'Cup',126.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124813,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124814,1,0.5,'Cup',128.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124815,1,101.0,'Servings Per Container',118.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124816,1,98.0,'Servings Per Container',95.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124817,1,1.0,'Piece',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124818,1,1.0,'Piece',130.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124819,1,1.0,'Piece',127.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124820,1,1.0,'Piece',127.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124821,1,1.0,'Roll',28.00,'g',3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_wght` VALUES (124822,1,1.0,'Bar',44.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124823,1,1.0,'Bar',44.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124824,1,1.0,'serving',51.60,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124825,1,1.0,'Cinnamon Roll',85.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124826,1,1.0,'Cinnamon Roll',71.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124827,1,1.0,'serving',51.88,'g',3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124828,1,1.0,'serving',56.70,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124829,1,1.0,'serving',28.35,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124830,1,1.0,'slice',141.00,'g',3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_wght` VALUES (124831,1,1.0,'Bag',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124832,1,2.0,'Tbsp',34.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124833,1,336.0,'Servings Per Container',40.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124834,1,173.0,'Servings Per Container',85.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124835,1,120.0,'Servings Per Container',112.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124836,1,1.0,'Pouch',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124837,1,192.0,'Servings Per Container',70.00,'g',3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124838,1,226.0,'Servings Per Container',59.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124839,1,1.0,'Portion',80.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124840,1,7.2,'fl oz',213.00,'ml',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124841,1,4.0,'oz cup',113.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124842,1,4.0,'oz cup',113.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124843,1,1.0,'Pastry',48.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124844,1,1.0,'Pastry',48.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124845,1,1.0,'Pastry',48.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124846,1,1.0,'Pouch',96.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124847,1,1.0,'Pouch',96.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124848,1,1.0,'Pouch',96.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124849,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124850,1,1.0,'Tsp',5.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124851,1,0.5,'cup',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124852,1,0.25,'Cup',61.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124853,1,0.25,'Cup',61.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124854,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124855,1,0.5,'cup',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124856,1,0.5,'Cup',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124857,1,0.5,'Cup',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124858,1,3.0,'Fluid Ounces',3.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124859,1,0.5,'cUP',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124860,1,0.5,'Cup',122.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124861,1,0.5,'Cup',122.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124862,1,0.5,'CUP',126.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124863,1,0.5,'CUP',126.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124864,1,156.0,'Servings Per Container',86.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124865,1,1.0,'Servings Per Container',136.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124866,1,96.0,'Servings Per Container',56.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124867,1,1.0,'Bar',44.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124868,1,1.0,'Bar',44.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124869,1,1.0,'Bar',44.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124870,1,1.0,'Bar',44.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124871,1,1.0,'Bar',44.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124872,1,1.0,'Bar',44.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124873,1,1.0,'Patty',38.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124874,1,4.0,'Nuggets',86.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124875,1,250.0,'Servings Per Container',56.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124876,1,160.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124877,1,100.0,'Servings Per Container',91.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124878,1,2.0,'SLICES',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124879,1,2.0,'SLICES',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124880,1,2.0,'SLICES',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124881,1,2.0,'SLICES',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124882,1,2.0,'SLICES',25.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124883,1,49.0,'Servings Per Container',91.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124884,1,58.0,'Servings Per Container',78.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124885,1,1.0,'Piece',126.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124886,1,1.0,'Piece',126.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124887,1,1.0,'Piece',126.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124888,1,1.0,'Pizza',141.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124889,1,1.0,'Pizza',141.00,'g',3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124890,1,1.33,'oz',38.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124891,1,85.0,'Servings Per Container',108.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124892,1,100.0,'Servings Per Container',91.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124893,1,133.0,'Servings Per Container',101.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124894,1,143.0,'Servings Per Container',94.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124895,1,192.0,'Servings Per Container',70.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124896,1,72.0,'Servings Per Container',107.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124897,1,72.0,'Servings Per Container',62.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124898,1,144.0,'Servings Per Container',61.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124899,1,72.0,'Servings Per Container',107.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124900,1,108.0,'Servings Per Container',85.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124901,1,144.0,'Servings Per Container',61.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124902,1,108.0,'Servings Per Container',80.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124903,1,1.0,'Servings Per Container',133.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124904,1,1.0,'Servings Per Container',133.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124905,1,1.0,'Servings Per Container',136.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124906,1,27.0,'Servings Per Container',84.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124907,1,27.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124908,1,1.0,'Servings Per Container',145.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124909,1,1.0,'Servings Per Container',145.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124910,1,320.0,'Servings Per Container',56.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124911,1,160.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124912,1,53.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124913,1,92.0,'Servings Per Container',94.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124914,1,154.0,'Servings Per Container',88.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124915,1,160.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124916,1,119.0,'Servings Per Container',77.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124917,1,95.0,'Servings Per Container',92.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124918,1,215.0,'Servings Per Container',63.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124919,1,95.0,'Servings Per Container',92.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124920,1,160.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124921,1,89.0,'Servings Per Container',102.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124922,1,123.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124923,1,134.0,'Servings Per Container',88.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124924,1,137.0,'Servings Per Container',92.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124925,1,180.0,'Servings Per Container',76.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124926,1,103.0,'Servings Per Container',114.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124927,1,144.0,'Servings Per Container',95.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124928,1,150.0,'Servings Per Container',92.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124929,1,158.0,'Servings Per Container',87.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124930,1,100.0,'Servings Per Container',90.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124931,1,173.0,'Servings Per Container',85.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124932,1,150.0,'Servings Per Container',95.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124933,1,152.0,'Servings Per Container',88.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124934,1,132.0,'Servings Per Container',105.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124935,1,240.0,'Servings Per Container',58.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124936,1,170.0,'Servings Per Container',86.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124937,1,51.0,'Servings Per Container',87.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124938,1,214.0,'Servings Per Container',62.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124939,1,165.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124940,1,149.0,'Servings Per Container',91.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124941,1,132.0,'Servings Per Container',105.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124942,1,173.0,'Servings Per Container',85.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124943,1,175.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124944,1,149.0,'Servings Per Container',96.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124945,1,158.0,'Servings Per Container',85.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124946,1,242.0,'Servings Per Container',57.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124947,1,144.0,'Servings Per Container',94.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124948,1,163.0,'Servings Per Container',82.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124949,1,154.0,'Servings Per Container',87.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124950,1,48.0,'Servings Per Container',112.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124951,1,167.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124952,1,196.0,'Servings Per Container',69.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124953,1,154.0,'Servings Per Container',88.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124954,1,120.0,'Servings Per Container',112.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124955,1,109.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124956,1,141.0,'Servings Per Container',99.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124957,1,142.0,'Servings Per Container',101.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124958,1,161.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124959,1,149.0,'Servings Per Container',91.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124960,1,133.0,'Servings Per Container',96.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124961,1,160.0,'Servings Per Container',88.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124962,1,161.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124963,1,118.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124964,1,91.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124965,1,54.0,'Servings Per Container',84.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124966,1,1.0,'Amount per serving',163.00,'ml',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124967,1,8.0,'bites',68.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124968,1,1.0,'Cup',113.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124969,1,1.0,'Pastry',48.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124970,1,1.0,'Pouch',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124971,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124972,1,0.5,'Cup',121.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124973,1,0.25,'Cup',60.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124974,1,1.0,'Tbsp',17.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124975,1,1.0,'Bottle',296.00,'ml',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124976,1,1.0,'Croissant',34.00,'g',3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_wght` VALUES (124977,1,0.5,'Cup',121.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124978,1,0.25,'Cup',63.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124979,1,0.25,'cup',61.00,'g',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124980,1,2.0,'Tbsp',36.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124981,1,2.0,'Tbsp',32.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124982,1,2.0,'Tbsp',33.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124983,1,2.0,'Tbsp',33.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124984,1,1.0,'Pouch',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124985,1,1.0,'Pouch',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124986,1,1.5,'oz. bar',43.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124987,1,1.0,'Amount per serving',120.00,'ml',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (124988,1,1.0,'Amount per serving',120.00,'ml',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124989,1,1.0,'Amount per serving',120.00,'ml',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124990,1,1.0,'Amount per serving',120.00,'ml',3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124991,1,0.25,'Cup',63.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124992,1,0.25,'Cup',63.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124993,1,0.25,'Cup',61.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124994,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124995,1,0.25,'Cup',63.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124996,1,2.0,'Tbsp',36.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (124997,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124998,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (124999,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125000,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125001,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125002,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125003,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125004,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125005,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125006,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125007,1,1.0,'Packet',7.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125008,1,1.0,'Tsp',5.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125009,1,1.0,'Tsp',5.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125010,1,0.5,'Cup',123.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125011,1,8.0,'Fluid Ounces',8.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125012,1,0.25,'Cup',63.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125013,1,0.25,'Cup',63.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125014,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125015,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125016,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125017,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125018,1,0.25,'Cup',64.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125019,1,0.5,'Cup',123.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125020,1,8.0,'Fluid Ounces',240.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125021,1,8.0,'Fluid Ounces',8.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125022,1,8.0,'Fluid Ounces',8.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125023,1,8.0,'Fluid Ounces',8.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125024,1,0.5,'cup',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125025,1,0.25,'Cup',61.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125026,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125027,1,0.5,'Cup',121.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125028,1,1.0,'Slice',69.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125029,1,1.0,'Slice',75.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125030,1,1.0,'Slice',132.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125031,1,1.0,'Slice',129.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125032,1,1.0,'Slice',129.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125033,1,160.0,'Servings Per Container',84.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125034,1,1.0,'Slice',136.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125035,1,1.0,'Stick',55.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125036,1,1.0,'Slice',136.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125037,1,1.0,'Slice',136.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125038,1,3.0,'Triangles',114.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125039,1,1.0,'Slice',137.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125040,1,1.0,'slice (132g)',130.76,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125041,1,1.0,'Slice',142.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125042,1,1.0,'Slice',140.00,'g',3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_wght` VALUES (125043,1,1.0,'Calzone',133.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125044,1,1.0,'Calzone',133.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125045,1,1.0,'Piece',126.00,'g',3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125046,1,1.0,'PER SERVING',252.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125047,1,1.0,'Slice',142.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125048,1,1.0,'Calzone',133.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125049,1,4.5,'oz cup',128.00,'g',3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125050,1,1.0,'Chocolate Swirl',85.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125051,1,1.0,'Garlic Knot',37.00,'g',3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125052,1,1.0,'Garlic Knot',57.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125053,1,1.0,'serving',170.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125054,1,1.0,'Pouch',27.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125055,1,1.0,'Slice (19 slices per loaf)',51.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125056,1,1.0,'Sandwich',82.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125057,1,1.0,'Per Serving',296.00,'ml',3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125058,1,1.0,'Slice',132.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125059,1,4.5,'oz cup',128.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125060,1,28.0,'g',28.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125061,1,1.0,'Slice',132.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125062,1,4.5,'oz cup',128.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125063,1,4.5,'oz cup',128.00,'g',3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125064,1,4.5,'oz cup',128.00,'g',3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125065,1,4.5,'oz cup',128.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125066,1,4.5,'oz cup',128.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125067,1,4.5,'oz cup',128.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125068,1,4.5,'oz cup',128.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125069,1,4.5,'oz cup',128.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125070,1,4.5,'oz cup',128.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125071,1,8.0,'Fluid Ounces',8.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125072,1,1.0,'Bar',37.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125073,1,1.0,'Bar',37.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125074,1,1.0,'Bar',37.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125075,1,1.0,'Bar',37.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125076,1,0.5,'Cup',55.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125077,1,1.0,'Bar',37.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125078,1,1.0,'Bar',37.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125079,1,1.0,'Stick',55.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125080,1,1.0,'Slice',132.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125081,1,1.0,'Slice',129.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125082,1,1.0,'Breadstick',65.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125083,1,1.0,'Slice',133.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125084,1,3.0,'Triangles',116.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125085,1,1.0,'Stick',55.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125086,1,1.0,'Slice',136.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125087,1,1.0,'slice',137.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125088,1,1.0,'Slice',137.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125089,1,1.0,'Slice',141.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125090,1,1.0,'Each',85.05,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125091,1,1.0,'Each',113.40,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125092,1,1.0,'Each',85.05,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125093,1,1.0,'Each',141.75,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125094,1,1.0,'Each',113.40,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125095,1,1.0,'Each',141.75,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125096,1,1.0,'Each',141.75,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125097,1,1.0,'Each',85.05,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125098,1,1.0,'Each',113.40,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125099,1,1.0,'Each',113.40,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125100,1,1.0,'Each',141.75,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125101,1,1.0,'Each',163.01,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125102,1,1.0,'Each',141.75,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125103,1,1.0,'Each',85.05,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125104,1,1.0,'Each',113.40,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125105,1,1.0,'Each',141.75,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125106,1,1.0,'Each',113.40,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125107,1,1.0,'Slice (142g)',140.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125108,1,1.0,'Each',141.75,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125109,1,1.0,'Each',113.40,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125110,1,1.0,'Each',144.59,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125111,1,1.0,'Stick',55.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125112,1,1.0,'Package',51.00,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125113,1,1.0,'Package',50.00,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125114,1,1.0,'Sandwich',77.00,'g',3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125115,1,1.0,'Slice',138.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125116,1,2.0,'slices',28.00,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125117,1,2.0,'slices',28.00,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125118,1,2.0,'slices',28.00,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125119,1,28.0,'g',28.00,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125120,1,28.0,'g',28.00,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125121,1,28.0,'g',28.00,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125122,1,6.0,'slices',28.00,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125123,1,2.0,'slices',28.00,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125124,1,2.0,'slices',28.00,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125125,1,4.5,'oz cup',128.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125126,1,1.0,'Amount per serving',240.00,'ml',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125127,1,1.0,'Amount per serving',240.00,'ml',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125128,1,1.0,'Chocolate Swirl',71.00,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125129,1,1.0,'Cinnamon Roll',85.00,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125130,1,1.0,'MUFFIN',57.00,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125131,1,1.0,'Bottle',295.00,'ml',3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125132,1,1.0,'Bottle',295.00,'ml',3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125133,1,0.8,'oz bag',23.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125134,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125135,1,1.0,'Tbsp',17.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125136,1,1.0,'Pouch',27.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125137,1,1.0,'Pouch',90.00,'g',3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_wght` VALUES (125138,1,92.0,'Servings Per Container',94.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125139,1,88.0,'Servings Per Container',103.00,'g',3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_wght` VALUES (125140,1,1.0,'Pouch',90.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125141,1,1.0,'Cup',113.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125142,1,1.0,'Bag',10.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125143,1,1.0,'Bag',10.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125144,1,1.0,'Bottle',296.00,'ml',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125145,1,1.0,'Bottle',296.00,'ml',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125146,1,1.0,'Pouch',90.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125147,1,1.0,'Juice Box',200.00,'ml',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125148,1,1.0,'Cup',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125149,1,1.0,'Cup',113.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125150,1,2.85,'oz',81.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125151,1,0.5,'Cup',110.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125152,1,1.0,'oz.',28.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125153,1,3.6,'oz',102.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125155,1,1.0,'egg',55.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125156,1,1.0,'Hot Dog Bun',35.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125157,1,1.0,'Bar',12.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125158,1,1.0,'Bar',37.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125159,1,1.0,'Bar',37.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125160,1,0.25,'cup',100.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125161,1,1.0,'Servings Per Container',144.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125162,1,1.0,'Servings Per Container',144.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125165,1,1.0,'Bar',37.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125166,1,1.0,'Bar',37.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125167,1,0.25,'cup',100.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125168,1,0.25,'cup',100.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125169,1,1.0,'Pouch',86.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125170,1,1.0,'Pouch',86.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125171,1,1.0,'Pouch',86.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125172,1,1.0,'Pouch',75.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125173,1,1.0,'Pouch',75.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125174,1,1.0,'Pouch',50.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125175,1,1.0,'Amount per serving',35.40,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125176,1,1.0,'Amount per serving',240.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125177,1,1.0,'Amount per serving',240.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125178,1,1.0,'Amount per serving',21.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125179,1,2.0,'slices',28.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125180,1,0.25,'CUP',44.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125181,1,1.0,'bag (approx 8 bites)',68.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125182,1,0.333,'cup Dry',45.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125183,1,2.2,'oz',62.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125184,1,1.0,'Amount per serving',30.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125185,1,19.0,'Chips',28.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125186,1,1.0,'Pouch',50.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125187,1,1.0,'Pouch',86.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125188,1,1.0,'Amount per serving',30.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125189,1,10.4,'OZ',291.20,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125190,1,4.5,'oz cup',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125191,1,1.0,'Pouch',96.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125192,1,1.0,'Pouch',96.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125193,1,1.0,'egg',50.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125194,1,1.0,'Amount per serving',240.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125195,1,1.0,'Amount per serving',85.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125196,1,1.0,'Amount per serving',354.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125197,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125198,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125199,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125200,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125201,1,1.0,'Amount per serving',60.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125202,1,1.0,'Amount per serving',127.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125203,1,1.0,'Amount per serving',30.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125204,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125205,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125206,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125207,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125208,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125209,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125210,1,1.0,'PER SERVING',206.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125211,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125212,1,1.0,'Amount per serving',38.00,'g',3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125213,1,1.0,'Amount per serving',35.40,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125214,1,1.0,'Amount per serving',35.40,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125215,1,1.0,'Amount per serving',35.40,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125216,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125217,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125218,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125219,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125220,1,1.0,'Amount per serving',21.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125221,1,1.0,'Amount per serving',21.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125222,1,1.0,'Amount per serving',240.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125223,1,1.0,'Amount per serving',30.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125224,1,1.0,'Amount per serving',26.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125225,1,1.0,'Amount per serving',28.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125226,1,1.0,'Amount per serving',240.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125227,1,1.0,'Amount per serving',240.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125230,1,1.0,'Amount per serving',354.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125231,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125232,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125233,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125234,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125235,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125236,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125237,1,1.0,'Amount/serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125238,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125239,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125240,1,1.0,'Amount per serving',120.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125241,1,1.0,'Amount per serving',195.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125242,1,1.0,'Amount per serving',217.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125243,1,1.0,'Amount per serving',208.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125244,1,1.0,'Amount per serving',60.00,'ml',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125245,1,1.0,'PER SERVING',206.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125246,1,1.0,'Amount/serving',206.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125247,1,1.0,'PER SERVING',206.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125248,1,1.0,'PER SERVING',206.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125249,1,1.0,'Amount per serving',21.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125250,1,1.0,'Amount per serving',21.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125251,1,1.0,'Amount per serving',21.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125252,1,1.0,'Amount per serving',21.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125253,1,1.0,'Amount per serving',26.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125254,1,1.0,'Amount per serving',28.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125255,1,1.0,'Amount per serving',28.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125256,1,1.0,'Container',35.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125257,1,0.5,'cup',125.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125258,1,28.0,'g',28.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125259,1,1.0,'Bar',40.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125260,1,1.0,'Bar',45.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125261,1,1.0,'package',28.30,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125262,1,1.0,'Container',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125263,1,1.0,'Container',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125264,1,1.0,'Pouch',86.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125265,1,1.0,'Pouch',86.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125266,1,1.0,'Pouch',86.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125267,1,1.0,'Pouch',86.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125268,1,1.0,'Pouch',86.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125269,1,1.0,'Pouch',75.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125270,1,1.0,'Pouch',75.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125271,1,1.0,'Container',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125272,1,1.0,'Container',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125273,1,1.0,'Container',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125274,1,1.0,'Container',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125275,1,1.0,'Container',59.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125276,1,1.0,'Container',59.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125277,1,1.0,'Container',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125278,1,1.0,'Container',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125279,1,1.0,'Pastry',48.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125280,1,1.0,'Pastry',48.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125281,1,1.0,'Pastry',48.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125282,1,1.0,'Pouch',96.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125283,1,1.0,'Pouch',96.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125284,1,1.0,'Bar',37.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125285,1,1.0,'Bar',37.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125286,1,1.0,'Container',59.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125287,1,1.0,'Container',59.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125288,1,1.0,'Container',59.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125289,1,1.0,'Container',59.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125290,1,1.0,'Pouch',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125291,1,1.0,'Pouch',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125292,1,1.0,'Pouch',86.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125293,1,1.0,'Pouch',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125294,1,1.0,'Pouch',50.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125295,1,1.0,'Container',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125296,1,1.0,'Pastry',48.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125297,1,1.0,'Pastry',48.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125298,1,1.0,'Pouch',96.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125299,1,1.0,'Pouch',96.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125300,1,1.0,'Pouch',96.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125301,1,1.0,'Pouch',96.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125302,1,1.0,'Container',35.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125303,1,1.0,'Bar',40.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125304,1,1.0,'Bar',40.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125305,1,1.0,'Bar',45.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125306,1,1.0,'Bar',45.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125307,1,1.0,'Pastry',48.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125308,1,1.0,'Pastry',48.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125309,1,1.0,'Pastry',48.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125310,1,1.0,'Pouch',21.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125311,1,1.0,'Package',22.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125312,1,1.0,'Package',22.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125313,1,1.0,'Pouch',25.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125314,1,1.0,'Pouch',28.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125315,1,1.0,'Pouch',28.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125316,1,1.0,'Pouch',28.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125317,1,1.0,'Burger',71.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125318,1,1.0,'slice',19.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125319,1,32.0,'g',32.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125320,1,1.0,'Empanada 2.8 oz.',79.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125321,1,1.0,'Pouch',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125322,1,1.0,'Croissant',57.00,'g',3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125323,1,1.0,'English Muffin',57.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125324,1,1.0,'Hot Dog Bun',57.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125325,1,0.5,'Cup',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125326,1,2.0,'Pancakes',85.00,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125327,1,1.0,'Slice (132g)',130.76,'g',3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_wght` VALUES (125328,1,1.0,'Slice',133.00,'g',3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125329,1,2.0,'OZ',57.00,'g',3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125330,1,1.0,'Each',170.10,'g',3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_wght` VALUES (125331,1,11.0,'CHIPS',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125332,1,10.4,'ounces',291.20,'g',3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_wght` VALUES (125333,1,32.0,'Tbsp',32.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125334,1,32.0,'Tbsp',32.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125335,1,32.0,'Tbsp',32.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125336,1,1.0,'Pouch',96.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125337,1,0.75,'Cup',89.00,'g',3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125338,1,0.667,'cup',93.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125339,1,1.0,'Apple Fritter',85.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125340,1,1.0,'Muffin Top',57.00,'g',3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125341,1,1.0,'Croissant',62.00,'g',3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125342,1,1.0,'oz. portion',28.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125343,1,1.0,'Hamburger Bun',57.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125344,1,4.0,'Garlic Mozzarella Dippinz Bites',117.00,'g',3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125345,1,1.0,'Pull Apart',116.00,'g',3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125346,1,4.0,'Bites',117.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125347,1,1.0,'Pull Apart',116.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125348,1,3.6,'oz',102.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125349,1,1.0,'Muffin Top',57.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125350,1,8.0,'bites',68.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125351,1,1.0,'bag (approx 8 bites)',68.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125352,1,1.0,'Slice 5.1 oz',145.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125353,1,1.0,'Slice 5.88 oz',167.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125354,1,1.0,'Slice 5.1 oz',145.00,'g',3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125355,1,1.0,'Slice 5.88 oz',167.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125356,1,1.0,'Slice 5.60 oz',159.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125357,1,1.0,'Slice 4.40 oz',125.00,'g',3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125358,1,1.0,'Slice 5.0 oz',142.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125359,1,1.0,'Slice 4.40 oz',125.00,'g',3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125360,1,1.0,'Slice 5.0 oz',142.00,'g',3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125361,1,1.0,'sandwich 2.90oz',82.00,'g',3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125362,1,1.0,'sandwich 2.5oz',71.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125363,1,1.0,'sandwich 2.5oz',71.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125364,1,1.0,'sandwich',115.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125365,1,1.0,'sandwich',115.00,'g',3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125366,1,28.0,'g',28.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125367,1,28.0,'g',28.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125368,1,28.0,'g',28.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125369,1,28.0,'g',28.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125370,1,28.0,'g',28.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125371,1,2.0,'slices',28.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125372,1,28.0,'g',28.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125373,1,28.0,'g',28.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125374,1,28.0,'g',28.00,'g',3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125375,1,28.0,'g',28.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125376,1,2.0,'slices',28.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125377,1,0.25,'cup (Dry), 1/2 cup, cooked, drained',49.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125378,1,0.25,'cup (Dry), 1/2 cup, cooked, drained',49.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125379,1,1.0,'Packet',43.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125380,1,0.5,'cup',130.00,'g',3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125381,1,0.5,'cup',130.00,'g',3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125382,1,2.0,'tbsp',30.00,'g',3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125383,1,2.0,'tbsp',30.00,'g',3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125384,1,2.0,'tbsp',30.00,'g',3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125385,1,2.0,'tbsp',30.00,'g',3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125386,1,1.0,'cup',140.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125387,1,0.5,'cup',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125388,1,1.0,'Per Serving',300.00,'ml',3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_wght` VALUES (125398,1,0.5,'cup',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125399,1,37.0,'g',37.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125400,1,0.667,'cup',90.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125401,1,0.5,'cup',120.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125402,1,0.5,'Cup Dry',40.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125403,1,32.0,'grams',32.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125404,1,0.5,'Cup',120.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125405,1,0.25,'cup',30.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125406,1,0.5,'cup',120.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125407,1,0.5,'Cup',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125408,1,0.5,'cup',130.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125409,1,0.667,'cup',165.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125410,1,0.5,'cup',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125411,1,0.25,'cup',30.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125412,1,0.5,'cup',125.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125413,1,0.5,'cup',120.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125414,1,0.25,'cup',30.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125415,1,0.25,'cup',30.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125416,1,0.5,'cup dry',40.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125417,1,1.0,'Per Serving',75.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125418,1,0.5,'cup dry',40.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125419,1,5.0,'oz.',142.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125420,1,5.0,'oz.',142.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125421,1,5.0,'oz.',142.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125422,1,5.0,'oz.',141.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125423,1,8.0,'oz',226.80,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125424,1,1.0,'serving',141.75,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125426,1,5.0,'Prunes',40.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125427,1,0.5,'cup',38.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125428,1,1.0,'Pizza',143.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125429,1,1.0,'frozen juice cup',132.00,'ml',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125430,1,1.0,'frozen juice cup',132.00,'ml',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125431,1,1.0,'frozen juice cup',132.00,'ml',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125432,1,1.0,'frozen juice cup',132.00,'ml',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125433,1,1.0,'frozen juice cup',132.00,'ml',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125434,1,1.0,'frozen juice cup',132.00,'ml',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125435,1,1.0,'frozen juice cup',132.00,'ml',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125436,1,1.0,'frozen juice cup',132.00,'ml',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125437,1,1.0,'frozen juice cup',132.00,'ml',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125438,1,1.0,'Slice (127g)',126.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125439,1,4.5,'oz cup',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125440,1,4.5,'oz cup',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125441,1,4.5,'oz cup',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125442,1,4.5,'oz cup',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125443,1,4.5,'oz cup',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125444,1,4.5,'oz cup',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125445,1,1.0,'serving',113.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125446,1,4.5,'oz cup',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125447,1,4.5,'oz cup',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125448,1,4.5,'oz cup',128.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125449,1,4.5,'oz cup',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125450,1,4.5,'oz cup',37.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125451,1,1.0,'Pizza (143g)',141.40,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125452,1,1.0,'Breadstick',63.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125453,1,1.0,'breadstick (62g)',61.88,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125454,1,1.0,'breadstix',85.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125455,1,1.0,'Pizza (90g)',89.32,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125456,1,1.0,'Slice',106.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125457,1,0.25,'cup',40.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125458,1,5.0,'dates',40.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125459,1,0.25,'cup',40.00,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125460,1,1.33,'oz. package',37.70,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125461,1,0.5,'Cup',100.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125462,1,0.5,'Cup',128.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125463,1,0.5,'cups',100.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125464,1,1.0,'pouch',32.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125465,1,32.0,'g',32.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125466,1,1.0,'pouch',32.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125467,1,1.0,'PACKAGE (1.66 ONZ / 47 GRM)',46.48,'g',3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_wght` VALUES (125468,1,1.0,'package',42.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125469,1,0.5,'cup dry',40.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125470,1,22.0,'Chips',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125471,1,1.0,'Per 28g',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125472,1,1.0,'Bag',32.90,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125473,1,1.0,'Juice Box',200.00,'ml',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125474,1,22.0,'chips',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125475,1,1.0,'package',56.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125476,1,1.0,'PACKAGE',56.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125477,1,11.0,'Chips',28.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125478,1,1.0,'PACKAGE',56.00,'g',3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_wght` VALUES (125479,1,1.0,'Pouch',86.00,'g',3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_wght` VALUES (125480,1,1.0,'Pull Apart',116.00,'g',3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125481,1,1.0,'Pull Apart',116.00,'g',3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125482,1,5.0,'Piece',92.00,'g',3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125483,1,16.9,'fl ozPer Serving',500.00,'ml',3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125484,1,0.5,'cup',125.00,'g',3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125485,1,41.0,'Gr, 3 slices',41.00,'g',3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_wght` VALUES (125486,1,1.0,'Amount per serving',189.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125487,1,1.0,'Amount per serving',189.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125488,1,4.0,'oz cup',113.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125489,1,98.0,'Servings Per Container',112.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125490,1,4.5,'oz cup',126.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125491,1,1.0,'oz',28.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125492,1,0.5,'cup',100.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125493,1,1.0,'Package',31.50,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125494,1,32.0,'Chips',28.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125495,1,1.0,'Packet',48.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125496,1,1.0,'Bottle',296.00,'ml',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125497,1,1.0,'package',75.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125498,1,14.0,'chips',28.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125499,1,10.0,'chips',28.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125500,1,1.0,'Bar',40.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125501,1,0.25,'cup dry',40.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125502,1,1.0,'Per serving',28.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125503,1,1.1,'oz pouch',31.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125504,1,4.5,'oz cup',128.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125505,1,5.5,'servings per container',36.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125506,1,1.0,'muffin (3oz)',85.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125507,1,4.0,'oz cup',113.00,'g',3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_wght` VALUES (125508,1,8.90,'ounces',252.000,'g',3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125509,1,8.90,'ounces',252.000,'g',3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125510,1,167.00,'Servings Per Container',81.000,'g',3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125511,1,150.00,'Servings Per Container',90.000,'g',3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125512,1,1.00,'Slice (18 slices per loaf)',51.000,'g',3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125513,1,1.00,'package',37.700,'g',3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125514,1,8.43,'ounces',239.000,'g',3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125515,1,1.00,'Liege Waffle',68.000,'g',3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125516,1,1.00,'Liege Waffle',68.000,'g',3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125517,1,1.00,'Liege Waffle',68.000,'g',3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125518,1,4.00,'oz',113.000,'g',3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (125519,1,1.00,'package',32.900,'g',3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (51767,1,1,'bowl',248,'g',2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (51768,1,0.5,'cup',88,'g',2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (51769,1,0.5,'cup',117,'g',2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (51770,1,1,'corn cake',76,'g',2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (51771,1,1,'bowl',375,'g',2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (51772,1,0.5,'cup',165,'g',2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (51773,1,1,'bowl',155,'g',2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_wght` VALUES (51774,1,1,'pancake',67,'g',2,'2025-04-24','2025-04-24');
UNLOCK TABLES;
/*!40000 ALTER TABLE `cndb_wght` ENABLE KEYS */;
LOCK TABLES `cndb_nutval` WRITE;
/*!40000 ALTER TABLE `cndb_nutval` DISABLE KEYS */;
INSERT INTO `cndb_nutval` VALUES (1001,203,0.85,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1001,204,81.11,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1001,205,0.06,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1001,207,2.11,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1001,208,717,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1001,255,16.17,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1001,269,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1001,291,0,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1001,301,24,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1001,303,0.02,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1001,306,24,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1001,307,643,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1001,320,684,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (1001,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1001,401,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1001,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1001,601,215,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1001,605,3.278,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1001,606,51.368,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1002,203,0.49,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1002,204,78.3,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1002,205,0,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1002,207,1.62,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1002,208,731,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1002,255,16.72,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1002,269,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1002,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1002,301,23,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1002,303,0.05,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1002,306,41,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1002,307,583,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1002,320,683,'100g',1,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (1002,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1002,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1002,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1002,601,225,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1002,605,2.669,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1002,606,45.39,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1003,203,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1003,204,99.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1003,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1003,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1003,208,876,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1003,255,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1003,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1003,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1003,301,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1003,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1003,306,5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1003,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1003,320,840,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1003,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1003,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1003,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1003,601,256,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1003,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1003,606,61.924,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1004,203,21.4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1004,204,28.74,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1004,205,2.34,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1004,207,5.11,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1004,208,353,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1004,255,42.41,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1004,269,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1004,291,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1004,301,528,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1004,303,0.31,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1004,306,256,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1004,307,1146,'100g',3,1,'1994-11-14','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1004,320,198,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1004,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1004,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1004,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1004,601,75,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1004,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1004,606,18.669,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1005,203,23.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1005,204,29.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1005,205,2.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1005,207,3.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1005,208,371,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1005,255,41.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1005,269,0.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1005,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1005,301,674,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1005,303,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1005,306,136,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1005,307,560,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1005,320,292,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1005,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1005,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1005,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1005,601,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1005,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1005,606,18.764,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1006,203,20.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1006,204,27.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1006,205,0.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1006,207,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1006,208,334,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1006,255,48.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1006,269,0.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1006,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1006,301,184,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1006,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1006,306,152,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1006,307,629,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1006,320,174,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1006,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1006,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1006,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1006,601,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1006,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1006,606,17.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1007,203,19.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1007,204,24.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1007,205,0.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1007,207,3.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1007,208,300,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1007,255,51.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1007,269,0.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1007,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1007,301,388,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1007,303,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1007,306,187,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1007,307,842,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1007,320,241,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1007,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1007,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1007,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1007,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1007,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1007,606,15.259,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1008,203,25.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1008,204,29.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1008,205,3.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1008,207,3.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1008,208,376,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1008,255,39.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1008,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1008,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1008,301,673,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1008,303,0.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1008,306,93,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1008,307,690,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1008,320,271,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1008,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1008,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1008,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1008,601,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1008,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1008,606,18.584,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1009,203,22.87,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1009,204,33.31,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1009,205,3.37,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1009,207,3.71,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1009,208,403,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1009,255,36.75,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1009,269,0.48,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1009,291,0,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1009,301,710,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1009,303,0.14,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1009,306,76,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1009,307,653,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1009,320,337,'100g',2,1,'2024-12-12','2017-01-01');
INSERT INTO `cndb_nutval` VALUES (1009,328,0.6,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1009,401,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1009,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1009,601,99,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1009,605,NULL,'100g',NULL,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1009,606,18.867,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1010,203,23.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1010,204,30.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1010,205,4.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1010,207,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1010,208,387,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1010,255,37.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1010,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1010,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1010,301,643,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1010,303,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1010,306,95,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1010,307,700,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1010,320,233,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1010,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1010,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1010,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1010,601,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1010,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1010,606,19.475,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1011,203,23.76,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1011,204,32.11,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1011,205,2.57,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1011,207,3.36,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1011,208,394,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1011,255,38.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1011,269,0.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1011,291,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1011,301,685,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1011,303,0.76,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1011,306,127,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1011,307,604,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1011,320,264,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1011,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1011,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1011,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1011,601,95,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1011,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1011,606,20.218,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1012,203,11.12,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1012,204,4.3,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1012,205,3.38,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1012,207,1.41,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1012,208,98,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1012,255,79.79,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1012,269,2.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1012,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1012,301,83,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1012,303,0.07,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1012,306,104,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1012,307,315,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1012,320,37,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1012,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1012,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1012,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1012,601,17,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1012,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (1012,606,1.718,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1013,203,10.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1013,204,3.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1013,205,4.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1013,207,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1013,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1013,255,79.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1013,269,2.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1013,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1013,301,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1013,303,0.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1013,306,90,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1013,307,344,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1013,320,38,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (1013,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1013,401,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1013,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1013,601,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1013,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1013,606,2.311,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1014,203,10.34,'100g',1,1,'1995-06-26','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1014,204,0.29,'100g',1,1,'1995-06-26','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1014,205,6.66,'100g',3,1,'1995-06-26','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1014,207,1.71,'100g',1,1,'1995-06-26','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1014,208,72,'100g',3,1,'1995-06-26','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1014,255,81.01,'100g',1,1,'1995-06-26','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1014,269,1.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1014,291,0,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1014,301,86,'100g',1,1,'1995-06-26','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1014,303,0.15,'100g',1,1,'1995-06-26','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1014,306,137,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1014,307,372,'100g',3,1,'1995-06-26','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1014,320,2,'100g',2,1,'2024-12-12','2008-01-05');
INSERT INTO `cndb_nutval` VALUES (1014,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1014,401,0,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1014,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1014,601,7,'100g',1,1,'1995-06-26','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1014,605,NULL,'100g',NULL,1,'1995-06-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1014,606,0.169,'100g',3,1,'1995-06-26','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1015,203,10.45,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1015,204,2.27,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1015,205,4.76,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1015,207,1.27,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1015,208,81,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1015,255,81.24,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1015,269,4,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1015,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1015,301,111,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1015,303,0.13,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1015,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1015,307,308,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1015,320,68,'100g',2,1,'2024-12-12','2017-01-02');
INSERT INTO `cndb_nutval` VALUES (1015,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1015,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1015,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1015,601,12,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1015,605,0.067,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1015,606,1.235,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1016,203,12.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1016,204,1.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1016,205,2.72,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1016,207,1.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1016,208,72,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1016,255,82.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1016,269,2.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1016,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1016,301,61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1016,303,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1016,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1016,307,406,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1016,320,11,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (1016,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1016,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1016,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1016,601,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1016,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (1016,606,0.645,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1017,203,6.15,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1017,204,34.44,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1017,205,5.52,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1017,207,1.27,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1017,208,350,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1017,255,52.62,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1017,269,3.76,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1017,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1017,301,97,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1017,303,0.11,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1017,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1017,307,314,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1017,320,308,'100g',1,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (1017,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1017,401,0,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1017,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1017,601,101,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1017,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (1017,606,20.213,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1018,203,24.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1018,204,28.57,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1018,205,1.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1018,207,4.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1018,208,357,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1018,255,41,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1018,269,0,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1018,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1018,301,731,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1018,303,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1018,306,188,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1018,307,973,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1018,320,243,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1018,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1018,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1018,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1018,601,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1018,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1018,606,18.67,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1019,203,14.21,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1019,204,21.49,'100g',6,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1019,205,3.88,'100g',3,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1019,207,5.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1019,208,265,'100g',3,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1019,255,55.22,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1019,269,0,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1019,291,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1019,301,493,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1019,303,0.65,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1019,306,62,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1019,307,1139,'100g',6,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1019,320,125,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1019,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1019,401,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1019,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1019,601,89,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1019,605,NULL,'100g',NULL,1,'1996-09-30','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (1019,606,13.3,'100g',6,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1020,203,25.6,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1020,204,31.14,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1020,205,1.55,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1020,207,3.79,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1020,208,389,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1020,255,37.92,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1020,269,1.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1020,291,0,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1020,301,550,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1020,303,0.23,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1020,306,64,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1020,307,800,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1020,320,261,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1020,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1020,401,0,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1020,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1020,601,116,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1020,605,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1020,606,19.196,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1021,203,9.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1021,204,29.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1021,205,42.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1021,207,4.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1021,208,466,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1021,255,13.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1021,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1021,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1021,301,400,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1021,303,0.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1021,306,1409,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1021,307,600,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1021,320,334,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1021,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1021,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1021,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1021,601,94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1021,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1021,606,19.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1022,203,24.94,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1022,204,27.44,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1022,205,2.22,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1022,207,3.94,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1022,208,356,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1022,255,41.46,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1022,269,2.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1022,291,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1022,301,700,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1022,303,0.24,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1022,306,121,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1022,307,819,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1022,320,165,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1022,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1022,401,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1022,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1022,601,114,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1022,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1022,606,17.614,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1023,203,29.81,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1023,204,32.34,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1023,205,0.36,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1023,207,4.3,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1023,208,413,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1023,255,33.19,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1023,269,0.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1023,291,0,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1023,301,1011,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1023,303,0.17,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1023,306,81,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1023,307,714,'100g',3,1,'1998-04-03','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1023,320,271,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1023,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1023,401,0,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1023,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1023,601,110,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1023,605,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1023,606,18.913,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1024,203,20.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1024,204,27.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1024,205,0.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1024,207,3.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1024,208,327,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1024,255,48.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1024,269,0.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1024,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1024,301,497,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1024,303,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1024,306,128,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1024,307,800,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1024,320,340,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1024,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1024,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1024,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1024,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1024,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1024,606,16.746,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1025,203,24.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1025,204,30.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1025,205,0.68,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1025,207,3.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1025,208,373,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1025,255,41.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1025,269,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1025,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1025,301,746,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1025,303,0.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1025,306,81,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1025,307,600,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1025,320,198,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1025,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1025,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1025,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1025,601,89,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1025,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1025,606,19.066,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1026,203,22.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1026,204,22.14,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1026,205,2.4,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1026,207,3.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1026,208,299,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1026,255,50.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1026,269,0,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1026,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1026,301,505,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1026,303,0.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1026,306,76,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1026,307,486,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1026,320,179,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1026,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1026,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1026,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1026,601,79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1026,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1026,606,13.9,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1027,203,21.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1027,204,24.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1027,205,2.47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1027,207,2.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1027,208,318,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1027,255,48.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1027,269,1.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1027,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1027,301,575,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1027,303,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1027,306,75,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1027,307,710,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1027,320,197,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1027,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1027,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1027,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1027,601,89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1027,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1027,606,15.561,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1028,203,24.26,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1028,204,15.92,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1028,205,2.77,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1028,207,3.27,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1028,208,254,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1028,255,53.78,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1028,269,1.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1028,291,0,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1028,301,782,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1028,303,0.22,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1028,306,84,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1028,307,619,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1028,320,127,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1028,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1028,401,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1028,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1028,601,64,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1028,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1028,606,10.114,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1029,203,23.75,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1029,204,19.78,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1029,205,5.58,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1029,207,3.83,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1029,208,295,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1029,255,47.07,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1029,269,1.9,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1029,291,0,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1029,301,697,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1029,303,0.22,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1029,306,188,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1029,307,666,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1029,320,227,'100g',2,1,'2024-12-12','2017-01-02');
INSERT INTO `cndb_nutval` VALUES (1029,328,0.4,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1029,401,0,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1029,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1029,601,64,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1029,605,0.72,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1029,606,11.295,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1030,203,23.41,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1030,204,30.04,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1030,205,1.12,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1030,207,3.66,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1030,208,368,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1030,255,41.77,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1030,269,1.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1030,291,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1030,301,717,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1030,303,0.41,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1030,306,134,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1030,307,628,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1030,320,298,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1030,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1030,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1030,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1030,601,96,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1030,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1030,606,19.113,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1031,203,9.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1031,204,22.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1031,205,3.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1031,207,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1031,208,253,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1031,255,63.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1031,269,3.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1031,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1031,301,117,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1031,303,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1031,306,152,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1031,307,334,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1031,320,241,'100g',2,1,'2024-12-12','2008-01-06');
INSERT INTO `cndb_nutval` VALUES (1031,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1031,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1031,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1031,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1031,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1031,606,12.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1032,203,28.42,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1032,204,27.84,'100g',1,1,'1994-11-14','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1032,205,13.91,'100g',3,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1032,207,7.18,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1032,208,420,'100g',3,1,'1994-11-14','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1032,255,22.65,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1032,269,0.07,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1032,291,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1032,301,853,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1032,303,0.49,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1032,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1032,307,1804,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1032,320,262,'100g',2,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (1032,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1032,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1032,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1032,601,86,'100g',1,1,'1994-11-14','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1032,605,0.876,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1032,606,15.371,'100g',3,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1033,203,35.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1033,204,25,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1033,205,3.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1033,207,6.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1033,208,392,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1033,255,30,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1033,269,0.11,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1033,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1033,301,1184,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1033,303,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1033,306,92,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1033,307,1175,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1033,320,207,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1033,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1033,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1033,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1033,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1033,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1033,606,14.85,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1034,203,23.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1034,204,28.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1034,205,0.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1034,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1034,208,352,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1034,255,45.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1034,269,0.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1034,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1034,301,650,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1034,303,0.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1034,306,136,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1034,307,534,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1034,320,315,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1034,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1034,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1034,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1034,601,123,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1034,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1034,606,16.691,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1035,203,25.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1035,204,26.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1035,205,2.14,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1035,207,4.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1035,208,351,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1035,255,40.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1035,269,0.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1035,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1035,301,756,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1035,303,0.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1035,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1035,307,727,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1035,320,236,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1035,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1035,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1035,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1035,601,69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1035,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1035,606,17.078,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1036,203,7.54,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1036,204,10.18,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1036,205,7.27,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1036,207,1.32,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1036,208,150,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1036,255,73.69,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1036,269,0.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1036,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1036,301,206,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1036,303,0.13,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1036,306,219,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1036,307,110,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1036,320,120,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1036,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1036,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1036,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1036,601,49,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1036,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1036,606,6.42,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1037,203,11.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1037,204,7.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1037,205,5.14,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1037,207,1.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1037,208,138,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1037,255,74.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1037,269,0.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1037,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1037,301,272,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1037,303,0.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1037,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1037,307,99,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1037,320,107,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1037,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1037,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1037,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1037,601,31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1037,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1037,606,4.927,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1038,203,31.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1038,204,26.94,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1038,205,3.63,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1038,207,6.72,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1038,208,387,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1038,255,30.91,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1038,269,0.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1038,291,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1038,301,1064,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1038,303,0.77,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1038,306,86,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1038,307,1433,'100g',3,1,'1994-11-14','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1038,320,96,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1038,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1038,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1038,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1038,601,104,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1038,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1038,606,17.115,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1039,203,21.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1039,204,30.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1039,205,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1039,207,6.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1039,208,369,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1039,255,39.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1039,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1039,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1039,301,662,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1039,303,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1039,306,91,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1039,307,1809,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1039,320,294,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1039,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1039,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1039,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1039,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1039,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1039,606,19.263,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1040,203,26.96,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1040,204,30.99,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1040,205,1.44,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1040,207,2.97,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1040,208,393,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1040,255,37.63,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1040,269,0,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1040,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1040,301,890,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1040,303,0.13,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1040,306,72,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1040,307,187,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1040,320,288,'100g',1,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (1040,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1040,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1040,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1040,601,93,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1040,605,0.987,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1040,606,18.227,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1041,203,24.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1041,204,25.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1041,205,1.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1041,207,4.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1041,208,340,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1041,255,42.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1041,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1041,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1041,301,700,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1041,303,0.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1041,306,65,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1041,307,753,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1041,320,249,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1041,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1041,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1041,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1041,601,102,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1041,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1041,606,16.775,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1042,203,18.13,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1042,204,30.71,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (1042,205,4.78,'100g',3,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (1042,207,6.78,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1042,208,366,'100g',3,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (1042,255,39.61,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1042,269,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1042,291,0,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1042,301,1045,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1042,303,0.63,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1042,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1042,307,1671,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1042,320,317,'100g',1,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (1042,328,7.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1042,401,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1042,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1042,601,100,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1042,605,1.144,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1042,606,18.057,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1043,203,22.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1043,204,31.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1043,205,1.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1043,207,5.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1043,208,375,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1043,255,39.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1043,269,0.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1043,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1043,301,614,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1043,303,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1043,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1043,307,915,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1043,320,244,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1043,328,0.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1043,401,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1043,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1043,601,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1043,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1043,606,19.663,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1044,203,24.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1044,204,25.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1044,205,2.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1044,207,5.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1044,208,334,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1044,255,42.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1044,269,1.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1044,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1044,301,772,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1044,303,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1044,306,216,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1044,307,1370,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1044,320,198,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1044,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1044,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1044,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1044,601,85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1044,605,NULL,'100g',NULL,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1044,606,16.045,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1045,203,19.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1045,204,24.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1045,205,8.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1045,207,4.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1045,208,331,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1045,255,43.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1045,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1045,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1045,301,497,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1045,303,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1045,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1045,307,966,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1045,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (1045,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1045,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1045,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1045,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1045,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1045,606,15.355,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1046,203,16.86,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1046,204,25.63,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1046,205,8.56,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1046,207,4.96,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1046,208,330,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1046,255,44,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1046,269,5.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1046,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1046,301,682,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1046,303,0.26,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1046,306,255,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1046,307,1284,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1046,320,201,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1046,328,2.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1046,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1046,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1046,601,98,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1046,605,0.917,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1046,606,15.057,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1047,203,21.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1047,204,24.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1047,205,4.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1047,207,5.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1047,208,323,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1047,255,43.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1047,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1047,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1047,301,723,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1047,303,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1047,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1047,307,1552,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1047,320,237,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1047,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1047,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1047,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1047,601,82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1047,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1047,606,15.487,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1048,203,16.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1048,204,21.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1048,205,8.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1048,207,5.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1048,208,290,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1048,255,47.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1048,269,7.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1048,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1048,301,562,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1048,303,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1048,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1048,307,1625,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1048,320,173,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1048,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1048,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1048,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1048,601,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1048,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1048,606,13.327,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1049,203,3.13,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1049,204,11.5,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1049,205,4.3,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1049,207,0.51,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1049,208,131,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1049,255,80.57,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1049,269,4.13,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1049,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1049,301,107,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1049,303,0.05,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1049,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1049,307,61,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1049,320,97,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1049,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1049,401,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1049,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1049,601,35,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1049,605,0.464,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1049,606,7.032,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1050,203,2.96,'100g',1,1,'1994-11-14','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1050,204,19.1,'100g',1,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1050,205,3.66,'100g',3,1,'1994-11-14','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1050,207,0.61,'100g',1,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1050,208,195,'100g',3,1,'1994-11-14','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1050,255,73.75,'100g',1,1,'1994-11-14','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1050,269,3.67,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1050,291,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1050,301,91,'100g',1,1,'1994-11-14','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1050,303,0.05,'100g',1,1,'1994-11-14','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1050,306,136,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1050,307,72,'100g',1,1,'1994-11-14','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1050,320,120,'100g',2,1,'2024-12-12','2016-01-02');
INSERT INTO `cndb_nutval` VALUES (1050,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1050,401,0.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1050,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1050,601,59,'100g',1,1,'1994-11-14','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1050,605,0.625,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1050,606,10.176,'100g',3,1,'1994-11-14','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1052,203,2.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1052,204,30.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1052,205,2.96,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1052,207,0.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1052,208,292,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1052,255,63.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1052,269,2.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1052,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1052,301,69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1052,303,0.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1052,306,97,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1052,307,34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1052,320,279,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1052,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1052,401,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1052,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1052,601,111,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1052,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1052,606,19.337,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1053,203,2.84,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1053,204,36.08,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1053,205,2.84,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1053,207,0.53,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1053,208,340,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1053,255,57.71,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1053,269,2.92,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1053,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1053,301,66,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1053,303,0.1,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1053,306,95,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1053,307,27,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1053,320,411,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1053,328,1.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1053,401,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1053,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1053,601,113,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1053,605,1.236,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1053,606,23.032,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1054,203,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1054,204,22.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1054,205,12.49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1054,207,0.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1054,208,257,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1054,255,61.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1054,269,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1054,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1054,301,101,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1054,303,0.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1054,306,147,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1054,307,8,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1054,320,188,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1054,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1054,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1054,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1054,601,76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1054,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1054,606,13.831,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1055,203,2.94,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1055,204,12,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1055,205,4.26,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1055,207,0.66,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1055,208,135,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1055,255,80.14,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1055,269,0.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1055,291,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1055,301,104,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1055,303,0.07,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1055,306,129,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1055,307,89,'100g',3,1,'1994-11-14','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1055,320,102,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1055,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1055,401,0.9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1055,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1055,601,39,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1055,605,NULL,'100g',NULL,1,'1995-06-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1055,606,7.47,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1056,203,2.44,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1056,204,19.35,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1056,205,4.63,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1056,207,0.51,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1056,208,198,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1056,255,73.07,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1056,269,3.41,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1056,291,0,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1056,301,101,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1056,303,0.07,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1056,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1056,307,31,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1056,320,124,'100g',1,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (1056,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1056,401,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1056,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1056,601,59,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1056,605,0.796,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1056,606,10.14,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1057,203,4.55,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1057,204,4.19,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1057,205,8.05,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1057,207,0.67,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1057,208,88,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1057,255,82.54,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1057,269,8.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1057,291,0,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1057,301,130,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1057,303,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1057,306,165,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1057,307,54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1057,320,59,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1057,328,1.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1057,401,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1057,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1057,601,59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1057,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1057,606,2.591,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1058,203,3.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1058,204,16.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1058,205,4.68,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1058,207,0.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1058,208,178,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1058,255,74.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1058,269,4.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1058,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1058,301,113,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1058,303,0.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1058,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1058,307,48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1058,320,3,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (1058,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1058,401,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1058,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1058,601,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1058,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1058,606,13.272,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1059,203,3.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1059,204,3.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1059,205,4.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1059,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1059,208,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1059,255,87.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1059,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1059,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1059,301,128,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1059,303,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1059,306,139,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1059,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1059,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1059,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1059,401,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1059,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1059,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1059,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1059,606,0.768,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1060,203,3.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1060,204,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1060,205,4.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1060,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1060,208,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1060,255,87.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1060,269,4.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1060,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1060,301,128,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1060,303,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1060,306,139,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1060,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1060,320,2,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (1060,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1060,401,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1060,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1060,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1060,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1060,606,3.101,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1061,203,21.05,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1061,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1061,205,10.53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1061,207,2.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1061,208,126,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1061,255,65.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1061,269,5.26,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1061,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1061,301,789,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1061,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1061,306,393,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1061,307,1316,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1061,320,56,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (1061,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1061,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1061,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1061,601,26,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1061,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1061,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1067,203,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1067,204,9.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1067,205,11.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1067,207,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1067,208,136,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1067,255,77.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1067,269,11.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1067,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1067,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1067,303,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1067,306,191,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1067,307,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1067,320,1,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (1067,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1067,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1067,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1067,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1067,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1067,606,1.937,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1068,203,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1068,204,9.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1068,205,11.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1068,207,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1068,208,136,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1068,255,77.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1068,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1068,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1068,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1068,303,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1068,306,191,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1068,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1068,320,4,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1068,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1068,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1068,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1068,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1068,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1068,606,9.304,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1069,203,2.48,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1069,204,32.92,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1069,205,59.29,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1069,207,2.34,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1069,208,529,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1069,255,2.98,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1069,269,7.77,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1069,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1069,301,2,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1069,303,0.26,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1069,306,669,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1069,307,124,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1069,320,0,'100g',1,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (1069,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1069,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1069,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1069,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1069,605,5.541,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1069,606,19.146,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1070,203,4.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1070,204,39.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1070,205,52.54,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1070,207,1.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1070,208,577,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1070,255,1.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1070,269,52.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1070,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1070,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1070,303,0.03,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1070,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1070,307,122,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1070,320,0,'100g',1,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1070,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1070,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1070,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1070,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1070,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1070,606,36.723,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1071,203,3.61,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1071,204,12.72,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1071,205,17.13,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1071,207,0.8,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1071,208,194,'100g',7,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1071,255,65.74,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1071,269,17.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1071,291,0,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1071,301,90,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1071,303,0.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1071,306,151,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1071,307,66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1071,320,34,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1071,328,0.9,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1071,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1071,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1071,601,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1071,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1071,606,10.684,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1072,203,0.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1072,204,22.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1072,205,16.07,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1072,207,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1072,208,264,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1072,255,60.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1072,269,16.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1072,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1072,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1072,303,0.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1072,306,19,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1072,307,62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1072,320,4,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (1072,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1072,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1072,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1072,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1072,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1072,606,18.912,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1073,203,1.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1073,204,25.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1073,205,23.05,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1073,207,0.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1073,208,318,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1073,255,50.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1073,269,23.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1073,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1073,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1073,303,0.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1073,306,18,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1073,307,25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1073,320,7,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (1073,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1073,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1073,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1073,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1073,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1073,606,21.783,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1074,203,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1074,204,19.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1074,205,6.63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1074,207,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1074,208,208,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1074,255,71.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1074,269,6.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1074,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1074,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1074,303,0.39,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1074,306,161,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1074,307,102,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1074,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (1074,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1074,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1074,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1074,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1074,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1074,606,17.791,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1076,203,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1076,204,3.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1076,205,6.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1076,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1076,208,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1076,255,88.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1076,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1076,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1076,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1076,303,0.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1076,306,114,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1076,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1076,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1076,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1076,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1076,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1076,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1076,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1076,606,3.037,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1077,203,3.15,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1077,204,3.25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1077,205,4.8,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1077,207,0.67,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1077,208,61,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1077,255,88.13,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1077,269,5.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1077,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1077,301,113,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1077,303,0.03,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1077,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1077,307,43,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1077,320,46,'100g',1,1,'2024-12-12','2009-01-01');
INSERT INTO `cndb_nutval` VALUES (1077,328,1.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1077,401,0,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1077,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1077,601,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1077,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1077,606,1.865,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1078,203,3.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1078,204,3.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1078,205,4.65,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1078,207,0.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1078,208,64,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1078,255,87.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1078,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1078,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1078,301,119,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1078,303,0.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1078,306,151,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1078,307,49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1078,320,33,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1078,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1078,401,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1078,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1078,601,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1078,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1078,606,2.278,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1079,203,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1079,204,1.98,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1079,205,4.8,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1079,207,0.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1079,208,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1079,255,89.21,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1079,269,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1079,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1079,301,120,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1079,303,0.02,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1079,306,140,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1079,307,47,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1079,320,55,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (1079,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1079,401,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1079,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1079,601,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1079,605,0.085,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1079,606,1.257,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1080,203,3.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1080,204,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1080,205,4.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1080,207,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1080,208,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1080,255,88.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1080,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1080,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1080,301,128,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1080,303,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1080,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1080,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1080,320,56,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1080,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1080,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1080,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1080,601,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1080,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1080,606,1.195,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1081,203,3.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1081,204,1.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1081,205,5.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1081,207,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1081,208,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1081,255,87.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1081,269,5.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1081,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1081,301,143,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1081,303,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1081,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1081,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1081,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (1081,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1081,401,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1081,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1081,601,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1081,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1081,606,1.232,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1082,203,3.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1082,204,0.97,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1082,205,4.99,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1082,207,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1082,208,42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1082,255,89.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1082,269,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1082,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1082,301,125,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1082,303,0.03,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1082,306,150,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1082,307,44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1082,320,58,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (1082,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1082,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1082,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1082,601,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1082,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1082,606,0.633,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1083,203,3.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1083,204,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1083,205,4.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1083,207,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1083,208,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1083,255,89.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1083,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1083,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1083,301,128,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1083,303,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1083,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1083,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1083,320,59,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1083,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1083,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1083,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1083,601,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1083,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1083,606,0.604,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1084,203,3.93,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1084,204,1.17,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1084,205,5.52,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1084,207,0.86,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1084,208,48,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1084,255,88.74,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1084,269,NULL,'100g',NULL,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1084,291,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1084,301,142,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1084,303,0.06,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1084,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1084,307,58,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1084,320,61,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1084,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1084,401,1.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1084,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1084,601,4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1084,605,NULL,'100g',NULL,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1084,606,0.728,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1085,203,3.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1085,204,0.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1085,205,4.96,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1085,207,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1085,208,34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1085,255,90.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1085,269,5.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1085,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1085,301,122,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1085,303,0.03,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1085,306,156,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1085,307,42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1085,320,61,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (1085,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1085,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1085,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1085,601,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1085,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1085,606,0.056,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1086,203,3.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1086,204,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1086,205,5.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1086,207,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1086,208,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1086,255,90.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1086,269,5.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1086,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1086,301,129,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1086,303,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1086,306,171,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1086,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1086,320,64,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1086,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1086,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1086,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1086,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1086,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1086,606,0.162,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1087,203,3.96,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1087,204,0.25,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1087,205,5.56,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1087,207,0.87,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1087,208,41,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1087,255,89.36,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1087,269,NULL,'100g',NULL,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1087,291,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1087,301,143,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1087,303,0.06,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1087,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1087,307,59,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1087,320,61,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1087,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1087,401,1.1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1087,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1087,601,2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1087,605,NULL,'100g',NULL,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1087,606,0.162,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1088,203,3.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1088,204,1.07,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1088,205,4.79,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1088,207,0.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1088,208,40,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1088,255,90.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1088,269,5.36,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1088,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1088,301,116,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1088,303,0.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1088,306,151,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1088,307,148,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1088,320,14,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1088,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1088,401,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1088,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1088,601,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1088,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (1088,606,0.66,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1089,203,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1089,204,3.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1089,205,4.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1089,207,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1089,208,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1089,255,88.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1089,269,4.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1089,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1089,301,101,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1089,303,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1089,306,253,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1089,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1089,320,29,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1089,328,1.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1089,401,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1089,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1089,601,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1089,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1089,606,2.154,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1090,203,26.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1090,204,26.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1090,205,38.42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1090,207,6.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1090,208,496,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1090,255,2.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1090,269,38.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1090,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1090,301,912,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1090,303,0.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1090,306,1330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1090,307,371,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1090,320,258,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1090,328,10.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1090,401,8.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1090,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1090,601,97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1090,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1090,606,16.742,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1091,203,36.16,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1091,204,0.77,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1091,205,51.98,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1091,207,7.93,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1091,208,362,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1091,255,3.16,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1091,269,51.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1091,291,0,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1091,301,1257,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1091,303,0.32,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1091,306,1794,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1091,307,535,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1091,320,6,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (1091,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1091,401,6.8,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1091,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1091,601,20,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1091,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1091,606,0.499,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1092,203,35.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1092,204,0.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1092,205,52.19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1092,207,8.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1092,208,358,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1092,255,3.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1092,269,52.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1092,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1092,301,1231,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1092,303,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1092,306,1705,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1092,307,549,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1092,320,709,'100g',2,1,'2024-12-12','2002-01-12');
INSERT INTO `cndb_nutval` VALUES (1092,328,11,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1092,401,5.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1092,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1092,601,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1092,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1092,606,0.467,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1093,203,35.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1093,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1093,205,51.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1093,207,7.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1093,208,354,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1093,255,4.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1093,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1093,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1093,301,280,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1093,303,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1093,306,680,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1093,307,2280,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1093,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1093,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1093,401,6.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1093,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1093,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1093,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1093,606,0.124,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1094,203,34.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1094,204,5.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1094,205,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1094,207,7.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1094,208,387,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1094,255,2.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1094,269,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1094,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1094,301,1184,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1094,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1094,306,1592,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1094,307,517,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1094,320,49,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1094,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1094,401,5.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1094,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1094,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1094,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1094,606,3.598,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1095,203,7.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1095,204,8.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1095,205,54.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1095,207,1.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1095,208,321,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1095,255,27.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1095,269,54.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1095,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1095,301,284,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1095,303,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1095,306,371,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1095,307,127,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1095,320,74,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1095,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1095,401,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1095,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1095,601,34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1095,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1095,606,5.486,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1096,203,6.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1096,204,7.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1096,205,10.04,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1096,207,1.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1096,208,134,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1096,255,74.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1096,269,10.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1096,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1096,301,261,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1096,303,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1096,306,303,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1096,307,106,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1096,320,65,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1096,328,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1096,401,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1096,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1096,601,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1096,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1096,606,4.591,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1097,203,7.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1097,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1097,205,11.35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1097,207,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1097,208,78,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1097,255,79.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1097,269,11.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1097,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1097,301,290,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1097,303,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1097,306,332,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1097,307,115,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1097,320,118,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1097,328,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1097,401,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1097,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1097,601,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1097,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1097,606,0.121,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1102,203,3.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1102,204,3.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1102,205,10.34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1102,207,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1102,208,83,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1102,255,82.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1102,269,9.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1102,291,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1102,301,112,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1102,303,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1102,306,167,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1102,307,60,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1102,320,27,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1102,328,1.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1102,401,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1102,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1102,601,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1102,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1102,606,2.104,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1103,203,2.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1103,204,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1103,205,12.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1103,207,0.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1103,208,76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1103,255,82.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1103,269,9.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1103,291,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1103,301,109,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1103,303,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1103,306,169,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1103,307,66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1103,320,64,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (1103,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1103,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1103,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1103,601,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1103,605,NULL,'100g',NULL,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1103,606,1.177,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1104,203,3.46,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1104,204,1.11,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1104,205,10.15,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1104,207,0.78,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1104,208,64,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1104,255,84.5,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1104,269,9.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1104,291,0.1,'100g',6,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1104,301,129,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1104,303,0.23,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1104,306,172,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1104,307,65,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1104,320,52,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1104,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1104,401,0.4,'100g',6,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1104,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1104,601,5,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1104,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1104,606,0.616,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1105,203,3.52,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1105,204,2.34,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1105,205,10.74,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1105,207,0.65,'100g',7,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1105,208,77,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1105,255,82.45,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1105,269,9.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1105,291,1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1105,301,114,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1105,303,0.42,'100g',7,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1105,306,197,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1105,307,44,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1105,320,51,'100g',2,1,'2024-12-12','2017-01-02');
INSERT INTO `cndb_nutval` VALUES (1105,328,1.1,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1105,401,0.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1105,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1105,601,8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1105,605,0.078,'100g',7,1,'2006-01-24','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1105,606,1.431,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1106,203,3.56,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1106,204,4.14,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1106,205,4.45,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1106,207,0.82,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1106,208,69,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1106,255,87.03,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1106,269,4.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1106,291,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1106,301,134,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1106,303,0.05,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1106,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1106,307,50,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1106,320,57,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1106,328,1.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1106,401,1.3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1106,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1106,601,11,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1106,605,NULL,'100g',NULL,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1106,606,2.667,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1108,203,3.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1108,204,6.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1108,205,5.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1108,207,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1108,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1108,255,83.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1108,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1108,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1108,301,169,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1108,303,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1108,306,178,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1108,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1108,320,53,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1108,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1108,401,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1108,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1108,601,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1108,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1108,606,4.597,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1109,203,5.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1109,204,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1109,205,5.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1109,207,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1109,208,108,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1109,255,80.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1109,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1109,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1109,301,193,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1109,303,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1109,306,137,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1109,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1109,320,44,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1109,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1109,401,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1109,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1109,601,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1109,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1109,606,4.603,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1110,203,3.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1110,204,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1110,205,21.15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1110,207,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1110,208,119,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1110,255,72.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1110,269,20.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1110,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1110,301,132,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1110,303,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1110,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1110,307,111,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1110,320,18,'100g',2,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (1110,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1110,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1110,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1110,601,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1110,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1110,606,1.681,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1111,203,3.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1111,204,3.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1111,205,17.75,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1111,207,0.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1111,208,112,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1111,255,74.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1111,269,17.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1111,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1111,301,146,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1111,303,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1111,306,183,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1111,307,95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1111,320,25,'100g',2,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (1111,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1111,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1111,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1111,601,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1111,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1111,606,1.886,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1112,203,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1112,204,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1112,205,5.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1112,207,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1112,208,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1112,255,93.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1112,269,5.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1112,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1112,301,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1112,303,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1112,306,143,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1112,307,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1112,320,2,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (1112,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1112,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1112,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1112,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1112,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1112,606,0.057,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1113,203,11.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1113,204,0.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1113,205,73.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1113,207,10.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1113,208,339,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1113,255,3.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1113,269,73.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1113,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1113,301,2054,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1113,303,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1113,306,2289,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1113,307,968,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1113,320,17,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (1113,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1113,401,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1113,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1113,601,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1113,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1113,606,0.342,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1114,203,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1114,204,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1114,205,5.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1114,207,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1114,208,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1114,255,93.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1114,269,5.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1114,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1114,301,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1114,303,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1114,306,161,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1114,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1114,320,3,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (1114,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1114,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1114,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1114,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1114,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1114,606,0.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1115,203,12.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1115,204,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1115,205,74.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1115,207,8.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1115,208,353,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1115,255,3.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1115,269,74.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1115,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1115,301,796,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1115,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1115,306,2080,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1115,307,1079,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1115,320,8,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (1115,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1115,401,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1115,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1115,601,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1115,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1115,606,0.684,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1116,203,3.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1116,204,3.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1116,205,4.66,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1116,207,0.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1116,208,61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1116,255,87.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1116,269,4.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1116,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1116,301,121,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1116,303,0.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1116,306,155,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1116,307,46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1116,320,27,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1116,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1116,401,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1116,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1116,601,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1116,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (1116,606,2.096,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1117,203,5.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1117,204,1.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1117,205,7.04,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1117,207,1.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1117,208,63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1117,255,85.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1117,269,7.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1117,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1117,301,183,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1117,303,0.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1117,306,234,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1117,307,70,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1117,320,14,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1117,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1117,401,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1117,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1117,601,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1117,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1117,606,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1118,203,5.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1118,204,0.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1118,205,7.68,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1118,207,1.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1118,208,56,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1118,255,85.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1118,269,7.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1118,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1118,301,199,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1118,303,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1118,306,255,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1118,307,77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1118,320,2,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1118,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1118,401,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1118,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1118,601,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1118,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1118,606,0.116,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1119,203,4.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1119,204,1.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1119,205,13.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1119,207,1.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1119,208,85,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1119,255,79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1119,269,13.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1119,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1119,301,171,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1119,303,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1119,306,219,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1119,307,66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1119,320,12,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1119,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1119,401,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1119,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1119,601,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1119,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1119,606,0.806,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1120,203,3.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1120,204,1.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1120,205,18.64,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1120,207,0.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1120,208,99,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1120,255,75.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1120,269,18.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1120,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1120,301,138,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1120,303,0.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1120,306,177,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1120,307,53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1120,320,11,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1120,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1120,401,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1120,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1120,601,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1120,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (1120,606,0.742,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1121,203,4.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1121,204,1.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1121,205,19.05,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1121,207,1.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1121,208,102,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1121,255,74.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1121,269,19.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1121,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1121,301,152,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1121,303,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1121,306,195,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1121,307,58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1121,320,10,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1121,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1121,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1121,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1121,601,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1121,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1121,606,0.697,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1122,203,4.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1122,204,1.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1122,205,18.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1122,207,1.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1122,208,105,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1122,255,74.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1122,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1122,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1122,301,169,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1122,303,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1122,306,216,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1122,307,65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1122,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (1122,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1122,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1122,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1122,601,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1122,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1122,606,0.909,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1123,203,12.56,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1123,204,9.51,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1123,205,0.72,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1123,207,1.06,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1123,208,143,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1123,255,76.15,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1123,269,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1123,291,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1123,301,56,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1123,303,1.75,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1123,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1123,307,142,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1123,320,160,'100g',1,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (1123,328,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1123,401,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1123,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1123,601,372,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1123,605,0.038,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1123,606,3.126,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1124,203,10.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1124,204,0.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1124,205,0.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1124,207,0.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1124,208,52,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1124,255,87.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1124,269,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1124,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1124,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1124,303,0.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1124,306,163,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1124,307,166,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1124,320,0,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (1124,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1124,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1124,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1124,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1124,605,NULL,'100g',NULL,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1124,606,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1125,203,15.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1125,204,26.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1125,205,3.59,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1125,207,1.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1125,208,322,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1125,255,52.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1125,269,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1125,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1125,301,129,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1125,303,2.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1125,306,109,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1125,307,48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1125,320,381,'100g',2,1,'2024-12-12','2010-01-09');
INSERT INTO `cndb_nutval` VALUES (1125,328,5.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1125,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1125,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1125,601,1085,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1125,605,NULL,'100g',NULL,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1125,606,9.551,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1126,203,15.53,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1126,204,25.6,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1126,205,0.81,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1126,207,1.62,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1126,208,296,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1126,255,56.44,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1126,269,0.16,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1126,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1126,301,134,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1126,303,4.55,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1126,306,121,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1126,307,67,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1126,320,422,'100g',2,1,'2024-12-12','2017-01-02');
INSERT INTO `cndb_nutval` VALUES (1126,328,6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1126,401,0,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1126,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1126,601,991,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (1126,605,0.098,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1126,606,8.615,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1127,203,13.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1127,204,22.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1127,205,10.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1127,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1127,208,307,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1127,255,51.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1127,269,10.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1127,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1127,301,124,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1127,303,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1127,306,105,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1127,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1127,320,316,'100g',2,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (1127,328,3.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1127,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1127,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1127,601,917,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1127,605,0.115,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1127,606,7.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1128,203,13.61,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1128,204,14.84,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1128,205,0.83,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1128,207,1.26,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1128,208,196,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1128,255,69.47,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1128,269,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1128,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1128,301,62,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1128,303,1.89,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1128,306,152,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1128,307,207,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1128,320,219,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (1128,328,2.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1128,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1128,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1128,601,401,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1128,605,0.041,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1128,606,4.323,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1129,203,12.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1129,204,10.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1129,205,1.12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1129,207,1.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1129,208,155,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1129,255,74.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1129,269,1.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1129,291,0,'100g',4,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1129,301,50,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1129,303,1.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1129,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1129,307,124,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1129,320,149,'100g',2,1,'2024-12-12','2010-01-09');
INSERT INTO `cndb_nutval` VALUES (1129,328,2.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1129,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1129,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1129,601,373,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1129,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (1129,606,3.267,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1130,203,10.57,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1130,204,11.66,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1130,205,0.64,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1130,207,1.01,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1130,208,154,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1130,255,76.13,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1130,269,0.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1130,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1130,301,48,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1130,303,1.48,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1130,306,117,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1130,307,155,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1130,320,172,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (1130,328,1.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1130,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1130,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1130,601,313,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1130,605,0.709,'100g',3,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1130,606,3.319,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1131,203,12.51,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1131,204,9.47,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1131,205,0.71,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1131,207,1.46,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1131,208,143,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1131,255,75.85,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1131,269,0.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1131,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1131,301,56,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1131,303,1.75,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1131,306,138,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1131,307,297,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1131,320,160,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (1131,328,2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1131,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1131,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1131,601,370,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1131,605,0.038,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1131,606,3.113,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1132,203,9.99,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1132,204,10.98,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1132,205,1.61,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1132,207,1.01,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1132,208,149,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1132,255,76.4,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1132,269,1.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1132,291,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1132,301,66,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1132,303,1.31,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1132,306,132,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1132,307,145,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1132,320,161,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (1132,328,1.8,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1132,401,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1132,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1132,601,277,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1132,605,0.624,'100g',3,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1132,606,3.331,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1133,203,48.05,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1133,204,43.9,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1133,205,1.13,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1133,207,4.13,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1133,208,592,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1133,255,2.78,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1133,269,0.56,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1133,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1133,301,244,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1133,303,7.2,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1133,306,540,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1133,307,476,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1133,320,301,'100g',2,1,'2024-12-12','2017-01-02');
INSERT INTO `cndb_nutval` VALUES (1133,328,8.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1133,401,0,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1133,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1133,601,1630,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (1133,605,0.265,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1133,606,15.069,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1134,203,48.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1134,204,43.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1134,205,2.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1134,207,3.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1134,208,615,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1134,255,1.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1134,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1134,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1134,301,222,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1134,303,8.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1134,306,515,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1134,307,548,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1134,320,616,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1134,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1134,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1134,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1134,601,2017,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1134,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1134,606,13.198,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1135,203,76.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1135,204,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1135,205,4.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1135,207,4.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1135,208,351,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1135,255,14.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1135,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1135,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1135,301,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1135,303,0.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1135,306,1042,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1135,307,1156,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1135,320,0,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (1135,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1135,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1135,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1135,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1135,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1135,606,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1136,203,82.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1136,204,0.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1136,205,4.47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1136,207,4.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1136,208,376,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1136,255,8.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1136,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1136,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1136,301,89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1136,303,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1136,306,1116,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1136,307,1238,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1136,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (1136,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1136,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1136,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1136,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1136,605,NULL,'100g',NULL,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1136,606,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1137,203,33.63,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1137,204,59.13,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1137,205,0.66,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1137,207,3.51,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1137,208,669,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1137,255,3.08,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1137,269,0.23,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1137,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1137,301,289,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1137,303,9.56,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1137,306,264,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1137,307,149,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1137,320,483,'100g',2,1,'2024-12-12','2017-01-02');
INSERT INTO `cndb_nutval` VALUES (1137,328,10.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1137,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1137,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1137,601,2307,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (1137,605,0.346,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1137,606,20.334,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1138,203,12.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1138,204,13.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1138,205,1.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1138,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1138,208,185,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1138,255,70.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1138,269,0.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1138,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1138,301,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1138,303,3.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1138,306,222,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1138,307,146,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1138,320,194,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1138,328,1.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1138,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1138,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1138,601,884,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1138,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1138,606,3.681,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1139,203,13.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1139,204,13.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1139,205,1.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1139,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1139,208,185,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1139,255,70.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1139,269,0.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1139,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1139,301,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1139,303,3.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1139,306,210,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1139,307,138,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1139,320,187,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1139,328,1.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1139,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1139,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1139,601,852,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1139,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1139,606,3.595,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1140,203,13.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1140,204,11.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1140,205,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1140,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1140,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1140,255,74.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1140,269,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1140,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1140,301,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1140,303,3.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1140,306,132,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1140,307,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1140,320,156,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1140,328,1.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1140,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1140,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1140,601,844,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1140,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1140,606,3.557,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1141,203,13.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1141,204,11.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1141,205,1.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1141,207,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1141,208,171,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1141,255,72.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1141,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1141,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1141,301,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1141,303,4.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1141,306,142,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1141,307,151,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1141,320,166,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1141,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1141,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1141,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1141,601,933,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1141,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1141,606,3.632,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1144,203,55.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1144,204,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1144,205,21.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1144,207,5.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1144,208,444,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1144,255,3.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1144,269,21.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1144,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1144,301,326,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1144,303,3.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1144,306,744,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1144,307,800,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1144,320,369,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (1144,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1144,401,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1144,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1144,601,572,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1144,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1144,606,3.766,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1145,203,0.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1145,204,81.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1145,205,0.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1145,207,0.09,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1145,208,717,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1145,255,16.17,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1145,269,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1145,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1145,301,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1145,303,0.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1145,306,24,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1145,307,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1145,320,684,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1145,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1145,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1145,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1145,601,215,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1145,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1145,606,50.489,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1146,203,37.86,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1146,204,27.34,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1146,205,3.41,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1146,207,6.39,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1146,208,415,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1146,255,25,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1146,269,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1146,291,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1146,301,1253,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1146,303,0.87,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1146,306,97,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1146,307,1696,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1146,320,229,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1146,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1146,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1146,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1146,601,72,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1146,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1146,606,17.37,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1151,203,3.37,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1151,204,0.18,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1151,205,4.86,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1151,207,0.75,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1151,208,35,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1151,255,90.84,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1151,269,5.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1151,291,0,'100g',4,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1151,301,122,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1151,303,0.03,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1151,306,156,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1151,307,42,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1151,320,2,'100g',2,1,'2024-12-12','2009-01-01');
INSERT INTO `cndb_nutval` VALUES (1151,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1151,401,0,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1151,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1151,601,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1151,605,NULL,'100g',NULL,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1151,606,0.117,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1152,203,3.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1152,204,1.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1152,205,5.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1152,207,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1152,208,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1152,255,87.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1152,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1152,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1152,301,143,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1152,303,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1152,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1152,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1152,320,17,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (1152,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1152,401,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1152,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1152,601,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1152,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1152,606,1.232,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1153,203,6.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1153,204,7.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1153,205,10.04,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1153,207,1.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1153,208,134,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1153,255,74.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1153,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1153,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1153,301,261,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1153,303,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1153,306,303,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1153,307,106,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1153,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (1153,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1153,401,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1153,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1153,601,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1153,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1153,606,4.591,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1154,203,36.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1154,204,0.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1154,205,51.98,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1154,207,7.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1154,208,362,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1154,255,3.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1154,269,51.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1154,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1154,301,1257,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1154,303,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1154,306,1794,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1154,307,535,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1154,320,653,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1154,328,11,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1154,401,6.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1154,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1154,601,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1154,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1154,606,0.499,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1155,203,35.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1155,204,0.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1155,205,52.19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1155,207,8.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1155,208,358,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1155,255,3.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1155,269,52.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1155,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1155,301,1231,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1155,303,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1155,306,1705,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1155,307,549,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1155,320,4,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1155,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1155,401,5.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1155,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1155,601,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1155,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1155,606,0.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1156,203,30.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1156,204,35.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1156,205,2.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1156,207,3.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1156,208,452,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1156,255,29.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1156,269,2.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1156,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1156,301,895,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1156,303,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1156,306,48,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1156,307,423,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1156,320,486,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1156,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1156,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1156,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1156,601,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1156,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1156,606,24.609,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1157,203,21.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1157,204,29.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1157,205,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1157,207,2.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1157,208,364,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1157,255,45.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1157,269,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1157,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1157,301,298,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1157,303,1.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1157,306,158,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1157,307,415,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1157,320,407,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1157,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1157,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1157,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1157,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1157,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1157,606,20.639,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1159,203,18.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1159,204,21.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1159,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1159,207,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1159,208,264,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1159,255,60.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1159,269,0,'100g',4,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1159,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1159,301,140,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1159,303,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1159,306,26,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1159,307,459,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1159,320,288,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1159,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1159,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1159,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1159,601,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1159,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1159,606,14.575,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1160,203,14.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1160,204,22.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1160,205,1.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1160,207,10.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1160,208,275,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1160,255,50.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1160,269,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1160,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1160,301,113,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1160,303,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1160,306,111,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1160,307,3487,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1160,320,313,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (1160,328,3.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1160,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1160,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1160,601,912,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1160,605,0.116,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1160,606,7.159,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1161,203,11.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1161,204,12.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1161,205,23.67,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1161,207,5.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1161,208,248,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1161,255,47.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1161,269,23.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1161,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1161,301,610,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1161,303,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1161,306,455,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1161,307,685,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1161,320,437,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (1161,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1161,401,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1161,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1161,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1161,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1161,606,3.711,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1164,203,10.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1164,204,14.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1164,205,5.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1164,207,2.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1164,208,197,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1164,255,66.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1164,269,0.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1164,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1164,301,311,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1164,303,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1164,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1164,307,493,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1164,320,82,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (1164,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1164,401,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1164,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1164,601,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1164,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1164,606,8.034,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1165,203,21.44,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1165,204,29.98,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1165,205,4.63,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1165,207,5.89,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1165,208,373,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1165,255,38.06,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1165,269,4.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1165,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1165,301,680,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1165,303,0.47,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1165,306,87,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1165,307,1131,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1165,320,64,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1165,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1165,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1165,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1165,601,105,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1165,605,NULL,'100g',NULL,1,'1994-09-20','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (1165,606,19.033,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1166,203,22.6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1166,204,25,'100g',6,1,'1994-11-14','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1166,205,4.13,'100g',3,1,'1994-11-14','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1166,207,4.11,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1166,208,356,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1166,255,44.16,'100g',6,1,'1994-11-14','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1166,269,0,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1166,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1166,301,661,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1166,303,0.51,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1166,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1166,307,607,'100g',6,1,'1994-11-14','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1166,320,55,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1166,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1166,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1166,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1166,601,105,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1166,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1166,606,14.85,'100g',6,1,'1994-11-14','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1167,203,21.56,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1167,204,29.68,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1167,205,5.56,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1167,207,4.06,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1167,208,374,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1167,255,39.13,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1167,269,5.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1167,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1167,301,651,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1167,303,0.47,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1167,306,52,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1167,307,617,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1167,320,56,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1167,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1167,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1167,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1167,601,105,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1167,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1167,606,18.843,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1168,203,24.35,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1168,204,7,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1168,205,1.91,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1168,207,3.64,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1168,208,173,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1168,255,63.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1168,269,0.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1168,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1168,301,415,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1168,303,0.42,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1168,306,66,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1168,307,873,'100g',3,1,'1994-11-14','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1168,320,60,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1168,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1168,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1168,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1168,601,21,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1168,605,NULL,'100g',NULL,1,'1995-06-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1168,606,4.342,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1169,203,24.35,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1169,204,32.62,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1169,205,1.91,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1169,207,2.13,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1169,208,398,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1169,255,38.98,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1169,269,0.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1169,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1169,301,703,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1169,303,0.72,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1169,306,112,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1169,307,21,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1169,320,264,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1169,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1169,401,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1169,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1169,601,100,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1169,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1169,606,20.768,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1171,203,12.33,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1171,204,9.95,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1171,205,1.01,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1171,207,0.91,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1171,208,147,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1171,255,75.81,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1171,269,0.25,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1171,291,0,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1171,301,62,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1171,303,1.74,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1171,306,135,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1171,307,128,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1171,320,171,'100g',1,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1171,328,2.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1171,401,0,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1171,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1171,601,372,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1171,605,0.054,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1171,606,3.382,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1172,203,10.2,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1172,204,0,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1172,205,1.04,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1172,207,0.6,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1172,208,48,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1172,255,88.17,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1172,269,0.25,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1172,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1172,301,8,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1172,303,0.04,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1172,306,169,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1172,307,169,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1172,320,0,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (1172,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1172,401,0,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1172,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1172,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1172,605,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1172,606,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1173,203,81.1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1173,204,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1173,205,7.8,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1173,207,5.3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1173,208,382,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1173,255,5.8,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1173,269,5.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1173,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1173,301,62,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1173,303,0.15,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1173,306,1125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1173,307,1280,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1173,320,0,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (1173,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1173,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1173,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1173,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1173,605,NULL,'100g',NULL,1,'1996-09-30','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (1173,606,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1174,203,3.3,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1174,204,1.98,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1174,205,4.8,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1174,207,0.71,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1174,208,50,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1174,255,89.21,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1174,269,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1174,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1174,301,120,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1174,303,0.02,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1174,306,140,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1174,307,47,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1174,320,28,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (1174,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1174,401,0.2,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1174,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1174,601,8,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1174,605,0.085,'100g',NULL,1,'2010-01-04','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1174,606,1.257,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1175,203,3.37,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1175,204,0.97,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1175,205,4.99,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1175,207,0.75,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1175,208,42,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1175,255,89.92,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1175,269,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1175,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1175,301,125,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1175,303,0.03,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1175,306,150,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1175,307,44,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1175,320,14,'100g',2,1,'2024-12-12','2009-01-01');
INSERT INTO `cndb_nutval` VALUES (1175,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1175,401,0,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1175,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1175,601,5,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1175,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1175,606,0.633,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1178,203,7,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1178,204,14.1,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1178,205,7,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1178,207,0.9,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1178,208,181,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1178,255,71,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1178,269,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1178,291,0,'100g',4,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1178,301,141,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1178,303,0.06,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1178,306,211,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1178,307,70,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1178,320,119,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1178,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1178,401,0.9,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1178,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1178,601,35,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1178,605,NULL,'100g',NULL,1,'1995-06-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1178,606,8.7,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1179,203,3.5,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1179,204,10.6,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1179,205,7.1,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1179,207,0.7,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1179,208,136,'100g',3,1,'1995-06-15','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1179,255,78.1,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1179,269,0.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1179,291,0,'100g',4,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1179,301,141,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1179,303,0.07,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1179,306,212,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1179,307,83,'100g',3,1,'1995-06-15','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1179,320,90,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1179,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1179,401,0.9,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1179,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1179,601,35,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1179,605,NULL,'100g',NULL,1,'1995-06-29','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (1179,606,6.6,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1180,203,3.1,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1180,204,0,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1180,205,15.6,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1180,207,0.7,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1180,208,74,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1180,255,80.6,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1180,269,0.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1180,291,0,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1180,301,125,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1180,303,0,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1180,306,129,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1180,307,141,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1180,320,73,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (1180,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1180,401,0,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1180,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1180,601,9,'100g',6,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1180,605,NULL,'100g',NULL,1,'1995-06-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1180,606,0,'100g',4,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1184,203,3.86,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1184,204,0.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1184,205,7.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1184,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1184,208,43,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1184,255,87.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1184,269,7.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1184,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1184,301,143,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1184,303,0.12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1184,306,177,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1184,307,59,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1184,320,2,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1184,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1184,401,1.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1184,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1184,601,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1184,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1184,606,0.116,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1185,203,40,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1185,204,5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1185,205,40,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1185,207,6.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1185,208,370,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1185,255,8.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1185,269,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1185,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1185,301,800,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1185,303,5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1185,306,600,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1185,307,1150,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1185,320,40,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (1185,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1185,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1185,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1185,601,20,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1185,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1185,606,3.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1186,203,15.69,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1186,204,1,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1186,205,7.66,'100g',3,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1186,207,3.77,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1186,208,105,'100g',3,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1186,255,71.87,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1186,269,5.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1186,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1186,301,351,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1186,303,0.19,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1186,306,278,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1186,307,702,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1186,320,11,'100g',2,1,'2024-12-12','2008-01-06');
INSERT INTO `cndb_nutval` VALUES (1186,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1186,401,0,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1186,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1186,601,12,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1186,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1186,606,0.644,'100g',3,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (1187,203,3.53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1187,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1187,205,23.53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1187,207,1.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1187,208,112,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1187,255,71.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1187,269,14.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1187,291,1.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1187,301,88,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1187,303,0.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1187,306,339,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1187,307,135,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1187,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1187,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1187,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1187,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1187,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1187,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1187,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1199,203,2.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1199,204,1.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1199,205,9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1199,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1199,208,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1199,255,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1199,269,5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1199,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1199,301,96,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1199,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1199,306,206,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1199,307,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1199,320,12,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (1199,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1199,401,0.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1199,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1199,601,5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1199,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1199,606,0.841,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1202,203,2.99,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1202,204,1.9,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1202,205,12.13,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1202,207,0.81,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1202,208,78,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1202,255,82.17,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1202,269,9.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1202,291,0.7,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1202,301,194,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1202,303,0.24,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1202,306,123,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1202,307,66,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1202,320,64,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (1202,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1202,401,0,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1202,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1202,601,8,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1202,605,NULL,'100g',NULL,1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1202,606,1.177,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1203,203,4.86,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1203,204,1.41,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1203,205,18.6,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1203,207,1.03,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1203,208,105,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1203,255,74.1,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1203,269,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1203,291,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1203,301,152,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1203,303,0.07,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1203,306,194,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1203,307,58,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1203,320,131,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1203,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1203,401,0.7,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1203,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1203,601,6,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1203,605,NULL,'100g',NULL,1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (1203,606,0.909,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (1204,203,20,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1204,204,20,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1204,205,1.37,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1204,207,8.03,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1204,208,265,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1204,255,50.6,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1204,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1204,291,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1204,301,1109,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1204,303,0.9,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1204,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1204,307,1529,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1204,320,160,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1204,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1204,401,0,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1204,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1204,601,88,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1204,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1204,606,13.317,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1205,203,0.69,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1205,204,13.5,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1205,205,35.07,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1205,207,0.55,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1205,208,251,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1205,255,50.06,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1205,269,33.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1205,291,1.1,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1205,301,6,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1205,303,0.59,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1205,306,96,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1205,307,67,'100g',3,1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1205,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1205,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1205,401,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1205,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1205,601,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1205,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1205,606,2.635,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1206,203,0.68,'100g',3,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1206,204,21.47,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1206,205,75.42,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1206,207,0.79,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1206,208,482,'100g',3,1,'2007-12-03','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1206,255,1.52,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1206,269,58.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1206,291,1.2,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1206,301,5,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1206,303,0.63,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1206,306,90,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1206,307,123,'100g',3,1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1206,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1206,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1206,401,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1206,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1206,601,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1206,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1206,606,19.446,'100g',3,1,'2007-12-03','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1208,203,24.7,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1208,204,17.6,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1208,205,3.5,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1208,207,3.6,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1208,208,274,'100g',6,1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1208,255,50.6,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1208,269,0.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1208,291,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1208,301,756,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1208,303,0.52,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1208,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1208,307,615,'100g',3,1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1208,320,141,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1208,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1208,401,0,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1208,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1208,601,55,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1208,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1208,606,11.3,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1209,203,24.69,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1209,204,19.4,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1209,205,3.41,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1209,207,4.3,'100g',1,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1209,208,282,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1209,255,48.2,'100g',1,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1209,269,0.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1209,291,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1209,301,1146,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1209,303,0.13,'100g',1,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1209,306,93,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1209,307,776,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1209,320,155,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1209,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1209,401,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1209,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1209,601,62,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1209,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (1209,606,11.58,'100g',1,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1211,203,3.15,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1211,204,3.27,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1211,205,4.78,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1211,207,0.67,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1211,208,61,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1211,255,88.13,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1211,269,5.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1211,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1211,301,113,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1211,303,0.03,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1211,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1211,307,43,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1211,320,46,'100g',1,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (1211,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1211,401,0,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1211,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1211,601,10,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1211,605,NULL,'100g',NULL,1,'2010-01-04','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (1211,606,1.865,'100g',3,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1212,203,26.32,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1212,204,26.71,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1212,205,38.42,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1212,207,6.08,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1212,208,496,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1212,255,2.47,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1212,269,38.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1212,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1212,301,912,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1212,303,0.47,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1212,306,1330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1212,307,371,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1212,320,258,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1212,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1212,401,8.6,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1212,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1212,601,97,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1212,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1212,606,16.742,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1215,203,17.6,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1215,204,14.1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1215,205,10.6,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1215,207,5.9,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1215,208,240,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1215,255,51.8,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1215,269,8.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1215,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1215,301,529,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1215,303,0.2,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1215,306,330,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1215,307,1201,'100g',3,1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1215,320,250,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (1215,328,5.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1215,401,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1215,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1215,601,53,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1215,605,NULL,'100g',NULL,1,'2010-01-04','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (1215,606,8.85,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1216,203,3.98,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1216,204,1.15,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1216,205,18.64,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1216,207,0.93,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1216,208,99,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1216,255,75.3,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1216,269,18.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1216,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1216,301,138,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1216,303,0.06,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1216,306,177,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1216,307,53,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1216,320,11,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1216,328,1.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1216,401,0.6,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1216,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1216,601,5,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1216,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1216,606,0.742,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1217,203,4.37,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1217,204,1.08,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1217,205,19.05,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1217,207,1.02,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1217,208,102,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1217,255,74.48,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1217,269,19.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1217,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1217,301,152,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1217,303,0.07,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1217,306,195,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1217,307,58,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1217,320,10,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1217,328,1.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1217,401,0.7,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1217,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1217,601,4,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1217,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1217,606,0.697,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1218,203,4.4,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1218,204,0.2,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1218,205,19,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1218,207,1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1218,208,95,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1218,255,75.4,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1218,269,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1218,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1218,301,152,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1218,303,0.07,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1218,306,194,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1218,307,58,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1218,320,2,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (1218,328,1.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1218,401,0.7,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1218,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1218,601,2,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1218,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1218,606,0.119,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1219,203,4.86,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1219,204,1.41,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1219,205,18.6,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1219,207,1.03,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1219,208,105,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1219,255,74.1,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1219,269,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1219,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1219,301,152,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1219,303,0.07,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1219,306,194,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1219,307,58,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1219,320,131,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1219,328,1.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1219,401,0.7,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1219,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1219,601,6,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1219,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1219,606,0.909,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1220,203,4.93,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1220,204,1.25,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1220,205,13.8,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1220,207,1.02,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1220,208,85,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1220,255,79,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1220,269,13.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1220,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1220,301,171,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1220,303,0.07,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1220,306,219,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1220,307,66,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1220,320,12,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1220,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1220,401,0.8,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1220,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1220,601,5,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1220,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1220,606,0.806,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1221,203,3.86,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1221,204,0.18,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1221,205,7.5,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1221,207,1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1221,208,43,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1221,255,87.43,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1221,269,7.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1221,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1221,301,143,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1221,303,0.12,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1221,306,177,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1221,307,59,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1221,320,2,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1221,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1221,401,1.1,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1221,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1221,601,2,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1221,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1221,606,0.116,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1222,203,3.53,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1222,204,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1222,205,23.53,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1222,207,1.37,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1222,208,112,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1222,255,71.57,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1222,269,14.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1222,291,1.2,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1222,301,88,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1222,303,0.42,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1222,306,339,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1222,307,135,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1222,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (1222,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1222,401,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1222,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1222,601,1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1222,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1222,606,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1225,203,6.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1225,204,7.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1225,205,55.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1225,207,1.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1225,208,315,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1225,255,28.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1225,269,49.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1225,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1225,301,251,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1225,303,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1225,306,350,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1225,307,129,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1225,320,74,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (1225,328,0.2,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1225,401,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1225,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1225,601,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1225,605,0.364,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1225,606,4.534,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1226,203,10,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1226,204,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1226,205,2,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1226,207,1.3,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1226,208,48,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1226,255,87,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1226,269,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1226,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1226,301,73,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1226,303,1.98,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1226,306,213,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1226,307,199,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1226,320,11,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (1226,328,1.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1226,401,0.5,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1226,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1226,601,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1226,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1226,606,0,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (1227,203,24.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1227,204,24.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1227,205,2.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1227,207,6.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1227,208,325,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1227,255,42.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1227,269,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1227,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1227,301,661,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1227,303,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1227,306,116,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1227,307,1808,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1227,320,226,'100g',1,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (1227,328,1.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1227,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1227,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1227,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1227,605,0.877,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1227,606,13.718,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1228,203,18.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1228,204,23.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1228,205,2.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1228,207,3.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1228,208,299,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1228,255,51.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1228,269,2.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1228,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1228,301,566,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1228,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1228,306,129,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1228,307,751,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1228,320,224,'100g',1,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (1228,328,2.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1228,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1228,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1228,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1228,605,0.834,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1228,606,12.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1229,203,20.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1229,204,24.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1229,205,2.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1229,207,4.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1229,208,310,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1229,255,48.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1229,269,1.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1229,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1229,301,690,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1229,303,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1229,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1229,307,704,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1229,320,157,'100g',1,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (1229,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1229,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1229,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1229,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1229,605,0.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1229,606,13.661,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1230,203,3.21,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1230,204,3.31,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1230,205,4.88,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1230,207,0.68,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1230,208,62,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1230,255,87.91,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1230,269,4.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1230,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1230,301,115,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1230,303,0.03,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1230,306,135,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1230,307,105,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1230,320,47,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (1230,328,1.3,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1230,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1230,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1230,601,11,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1230,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1230,606,1.899,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1231,203,4.93,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1231,204,1.25,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1231,205,13.8,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1231,207,1.02,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1231,208,86,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1231,255,79,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1231,269,5.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1231,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1231,301,171,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1231,303,0.07,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1231,306,219,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1231,307,66,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1231,320,12,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (1231,328,0,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1231,401,0.8,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1231,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1231,601,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1231,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1231,606,0.752,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1235,203,4.4,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1235,204,0.8,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1235,205,19.7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1235,207,1.6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1235,208,104,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1235,255,73.5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1235,269,12.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1235,291,2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1235,301,159,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1235,303,0.04,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1235,306,339,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1235,307,81,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1235,320,2,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (1235,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1235,401,0.7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1235,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1235,601,4,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1235,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1235,606,0.488,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1236,203,4.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1236,204,13,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1236,205,22.2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1236,207,0.9,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1236,208,222,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1236,255,59.8,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1236,269,21.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1236,291,0.7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1236,301,131,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1236,303,0.21,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1236,306,177,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1236,307,61,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1236,320,162,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (1236,328,0.7,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1236,401,0.8,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1236,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1236,601,91,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1236,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1236,606,7.46,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1237,203,4.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1237,204,24.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1237,205,24.5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1237,207,1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1237,208,331,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1237,255,46.3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1237,269,18.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1237,291,0.8,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1237,301,119,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1237,303,0.29,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1237,306,305,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1237,307,68,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1237,320,19,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (1237,328,0.2,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1237,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1237,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1237,601,28,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1237,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1237,606,13.202,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1238,203,4.29,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1238,204,8.57,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1238,205,37.14,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1238,207,1.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1238,208,237,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1238,255,48.9,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1238,269,18.57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1238,291,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1238,301,86,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1238,303,0.26,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1238,306,115,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1238,307,129,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1238,320,86,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (1238,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1238,401,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1238,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1238,601,21,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1238,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1238,606,2.317,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1239,203,3.7,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1239,204,7.4,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1239,205,39.6,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1239,207,0.55,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1239,208,240,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1239,255,48.7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1239,269,21.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1239,291,1.2,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1239,301,73,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1239,303,1.1,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1239,306,68,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1239,307,162,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1239,320,37,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (1239,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1239,401,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1239,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1239,601,6,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1239,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1239,606,1.663,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1240,203,5.21,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1240,204,21.88,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1240,205,34.38,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1240,207,1.11,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1240,208,354,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1240,255,37.43,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1240,269,25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1240,291,1,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1240,301,63,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1240,303,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1240,306,222,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1240,307,94,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1240,320,32,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (1240,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1240,401,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1240,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1240,601,21,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1240,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1240,606,11.458,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1241,203,4.29,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1241,204,3.04,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1241,205,39.64,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1241,207,0.39,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1241,208,186,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1241,255,52.63,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1241,269,17.86,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1241,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1241,301,30,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1241,303,0.09,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1241,306,41,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1241,307,146,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1241,320,96,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (1241,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1241,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1241,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1241,601,7,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1241,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1241,606,0.821,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1242,203,5.71,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1242,204,2.86,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1242,205,42.86,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1242,207,0.39,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1242,208,200,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1242,255,48.13,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1242,269,6.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1242,291,7.1,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1242,301,86,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1242,303,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1242,306,41,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1242,307,164,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1242,320,129,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (1242,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1242,401,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1242,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1242,601,21,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1242,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1242,606,0.821,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1243,203,4.41,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1243,204,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1243,205,28.86,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1243,207,1.2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1243,208,133,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1243,255,65.52,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1243,269,8.82,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1243,291,7.4,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1243,301,147,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1243,303,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1243,306,196,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1243,307,110,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1243,320,133,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (1243,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1243,401,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1243,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1243,601,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1243,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1243,606,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1244,203,4.41,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1244,204,1.47,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1244,205,32,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1244,207,0.69,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1244,208,147,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1244,255,61.43,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1244,269,22.06,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1244,291,6.6,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1244,301,184,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1244,303,0.53,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1244,306,316,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1244,307,92,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1244,320,71,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (1244,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1244,401,0.9,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1244,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1244,601,7,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1244,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1244,606,0.735,'100g',6,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1250,203,4.4,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1250,204,3.08,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1250,205,11.88,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1250,207,0.9,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1250,208,88,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1250,255,79.74,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1250,269,2.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1250,291,2.2,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1250,301,110,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1250,303,1.98,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1250,306,176,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1250,307,92,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1250,320,165,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (1250,328,1.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1250,401,26.4,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1250,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1250,601,2,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1250,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1250,606,0.232,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1251,203,23.54,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1251,204,32.14,'100g',6,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1251,205,0.13,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1251,207,3.72,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1251,208,384,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1251,255,40.48,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1251,269,0,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1251,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1251,301,659,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1251,303,0.59,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1251,306,85,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1251,307,607,'100g',6,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1251,320,174,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (1251,328,0.5,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1251,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1251,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1251,601,95,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1251,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1251,606,16.07,'100g',6,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1252,203,16.09,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1252,204,23.06,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1252,205,8.85,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1252,207,6.94,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1252,208,307,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1252,255,45.07,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1252,269,6.24,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1252,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1252,301,1375,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1252,303,0.95,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1252,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1252,307,1279,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1252,320,270,'100g',1,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1252,328,6.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1252,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1252,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1252,601,78,'100g',1,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1252,605,0.817,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1252,606,12.931,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1253,203,18.13,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1253,204,31.79,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1253,205,3.7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1253,207,6.78,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1253,208,371,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1253,255,39.61,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1253,269,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1253,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1253,301,1045,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1253,303,0.63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1253,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1253,307,1671,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1253,320,250,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (1253,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1253,401,0,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1253,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1253,601,100,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1253,605,1.144,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1253,606,18.057,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1254,203,16.86,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1254,204,25.63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1254,205,8.56,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1254,207,4.96,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1254,208,330,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1254,255,44,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1254,269,5.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1254,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1254,301,682,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1254,303,0.26,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1254,306,255,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1254,307,1441,'100g',3,1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (1254,320,240,'100g',1,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (1254,328,2.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1254,401,0,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1254,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1254,601,98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1254,605,0.917,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1254,606,15.057,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1255,203,10.97,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1255,204,10.07,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1255,205,0.83,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1255,207,10.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1255,208,138,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1255,255,67.83,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1255,269,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1255,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1255,301,55,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1255,303,1.71,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1255,306,128,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1255,307,3663,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1255,320,149,'100g',2,1,'2024-12-12','2017-01-02');
INSERT INTO `cndb_nutval` VALUES (1255,328,1.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1255,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1255,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1255,601,387,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1255,605,0.09,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1255,606,3.178,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (1256,203,10.19,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (1256,204,0.39,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (1256,205,3.6,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (1256,207,0.72,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (1256,208,59,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (1256,255,85.1,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (1256,269,3.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1256,291,0,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (1256,301,110,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (1256,303,0.07,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (1256,306,141,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1256,307,36,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (1256,320,1,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (1256,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1256,401,0,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (1256,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1256,601,5,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (1256,605,0.006,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (1256,606,0.117,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1258,203,84.08,'100g',1,1,'2013-02-22','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1258,204,0.32,'100g',1,1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1258,205,4.51,'100g',3,1,'2013-02-22','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1258,207,5.61,'100g',1,1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1258,208,357,'100g',3,1,'2013-02-22','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1258,255,5.48,'100g',1,1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1258,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1258,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (1258,301,101,'100g',1,1,'2013-02-22','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1258,303,0.18,'100g',1,1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1258,306,884,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1258,307,1299,'100g',1,1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1258,320,0,'100g',1,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (1258,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1258,401,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (1258,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1258,601,0,'100g',1,1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1258,605,0,'100g',NULL,1,'2013-02-22','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (1258,606,0.118,'100g',3,1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1259,203,13.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1259,204,8.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1259,205,10.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1259,207,5.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1259,208,176,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1259,255,61.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1259,269,7.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1259,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1259,301,557,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1259,303,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1259,306,250,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1259,307,1102,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1259,320,185,'100g',1,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (1259,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1259,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1259,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1259,601,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1259,605,0.327,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1259,606,5.647,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1260,203,27.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1260,204,20.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1260,205,2.67,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1260,207,3.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1260,208,316,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1260,255,44.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1260,269,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1260,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1260,301,761,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1260,303,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1260,306,63,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1260,307,628,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1260,320,145,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (1260,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1260,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1260,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1260,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1260,605,0.733,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1260,606,12.602,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1263,203,3.36,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1263,204,3.69,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1263,205,23.15,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1263,207,0.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1263,208,141,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1263,255,68.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1263,269,19.46,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1263,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1263,301,134,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1263,303,0.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1263,306,207,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1263,307,64,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1263,320,91,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (1263,328,0.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1263,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1263,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1263,601,15,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1263,605,0.168,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1263,606,2.349,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1264,203,2.11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1264,204,25.26,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1264,205,37.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1264,207,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1264,208,358,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1264,255,35.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1264,269,21.05,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1264,291,1.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1264,301,63,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1264,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1264,306,71,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1264,307,84,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1264,320,35,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (1264,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1264,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1264,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1264,601,16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1264,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1264,606,17.895,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (1265,203,32.14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1265,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1265,205,7.14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1265,207,3.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1265,208,157,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1265,255,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1265,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1265,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1265,301,893,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1265,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1265,306,66,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1265,307,1000,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1265,320,60,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (1265,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1265,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1265,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1265,601,18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1265,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1265,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1266,203,28.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1266,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1266,205,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1266,207,4.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1266,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1266,255,63.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1266,269,1.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1266,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1266,301,961,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1266,303,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1266,306,111,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1266,307,1000,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1266,320,40,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (1266,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1266,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1266,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1266,601,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1266,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1266,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1267,203,20,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1267,204,30,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1267,205,3.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1267,207,8.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1267,208,366,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1267,255,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1267,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1267,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1267,301,800,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1267,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1267,306,125,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1267,307,1400,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1267,320,229,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (1267,328,0.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1267,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1267,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1267,601,100,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1267,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1267,606,17.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (1270,203,24.25,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1270,204,33.82,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1270,205,2.13,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1270,207,3.66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1270,208,410,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1270,255,36.15,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1270,269,0.27,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1270,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1270,301,711,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1270,303,0.16,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1270,306,76,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1270,307,644,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1270,320,263,'100g',2,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (1270,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1270,401,0,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1270,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1270,601,99,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1270,605,1.179,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1270,606,19.368,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1271,203,23.63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1271,204,19.72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1271,205,8.06,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1271,207,3.78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1271,208,304,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1271,255,44.81,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1271,269,2.24,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1271,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1271,301,716,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1271,303,0.23,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1271,306,131,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1271,307,682,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1271,320,254,'100g',1,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (1271,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1271,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1271,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1271,601,65,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1271,605,0.709,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1271,606,11.472,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1284,203,8.17,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1284,204,2.57,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1284,205,12.29,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1284,207,0.56,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1284,208,105,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1284,255,76.41,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1284,269,11.23,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1284,291,1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1284,301,88,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1284,303,0.07,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1284,306,129,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1284,307,33,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1284,320,31,'100g',2,1,'2024-12-12','2015-01-05');
INSERT INTO `cndb_nutval` VALUES (1284,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1284,401,0.7,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1284,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1284,601,12,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1284,605,0.074,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1284,606,1.599,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1285,203,8.05,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1285,204,0.15,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1285,205,12.07,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1285,207,0.59,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1285,208,82,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1285,255,79.13,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1285,269,11.27,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1285,291,0.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1285,301,97,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1285,303,0.09,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1285,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1285,307,33,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1285,320,0,'100g',2,1,'2024-12-12','2017-01-02');
INSERT INTO `cndb_nutval` VALUES (1285,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1285,401,0.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1285,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1285,601,4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1285,605,0.001,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1285,606,0.105,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1286,203,8.64,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1286,204,0.18,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1286,205,10.37,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1286,207,0.55,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1286,208,78,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1286,255,80.26,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1286,269,9.54,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1286,291,0.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1286,301,99,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1286,303,0.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1286,306,123,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1286,307,34,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1286,320,0,'100g',2,1,'2024-12-12','2017-01-02');
INSERT INTO `cndb_nutval` VALUES (1286,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1286,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1286,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1286,601,3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1286,605,0.004,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1286,606,0.133,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1287,203,9.95,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1287,204,1.92,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1287,205,3.94,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1287,207,0.63,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1287,208,73,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1287,255,83.56,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1287,269,3.56,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1287,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1287,301,115,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1287,303,0.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1287,306,141,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1287,307,34,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1287,320,90,'100g',2,1,'2024-12-12','2015-01-05');
INSERT INTO `cndb_nutval` VALUES (1287,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1287,401,0.8,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1287,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1287,601,10,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1287,605,0.06,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1287,606,1.23,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1291,203,6.67,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1291,204,2,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1291,205,15.74,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1291,207,1.55,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1291,208,107,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1291,255,74.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1291,269,6.67,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1291,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1291,301,267,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1291,303,0.19,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1291,306,303,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1291,307,100,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1291,320,56,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1291,328,4,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1291,401,16,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1291,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1291,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1291,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1291,606,1.204,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1292,203,3.39,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1292,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1292,205,13.46,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1292,207,0.81,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1292,208,67,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1292,255,82.34,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1292,269,8.39,'100g',6,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1292,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1292,301,127,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1292,303,0.27,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1292,306,182,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1292,307,79,'100g',6,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1292,320,64,'100g',1,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1292,328,1.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1292,401,1,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1292,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1292,601,2,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1292,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1292,606,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1293,203,9,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1293,204,5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1293,205,3.98,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1293,207,0.72,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1293,208,97,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1293,255,81.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1293,269,4,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1293,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1293,301,100,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1293,303,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1293,306,141,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1293,307,35,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1293,320,2,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1293,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1293,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1293,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1293,601,13,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1293,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1293,606,2.395,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1294,203,7.33,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1294,204,3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1294,205,12.29,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1294,207,0.56,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1294,208,106,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1294,255,76.81,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1294,269,12,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1294,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1294,301,100,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1294,303,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1294,306,113,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1294,307,37,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1294,320,46,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1294,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1294,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1294,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1294,601,10,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1294,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1294,606,1.599,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1295,203,2.94,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1295,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1295,205,17.04,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1295,207,1.02,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1295,208,78,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1295,255,79,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1295,269,5.88,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1295,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1295,301,118,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1295,303,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1295,306,141,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1295,307,47,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1295,320,61,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1295,328,0.9,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1295,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1295,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1295,601,3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1295,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (1295,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1297,203,8.64,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1297,204,2.5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1297,205,9.54,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1297,207,0.55,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1297,208,95,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1297,255,78.76,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1297,269,9.54,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1297,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1297,301,100,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1297,303,0.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1297,306,123,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1297,307,40,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1297,320,110,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1297,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1297,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1297,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1297,601,5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1297,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1297,606,1.465,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1298,203,8,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1298,204,2.5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1298,205,21,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1298,207,0.42,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1298,208,139,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1298,255,68.08,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1298,269,21,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1298,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1298,301,200,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1298,303,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1298,306,108,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1298,307,45,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1298,320,34,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1298,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1298,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1298,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1298,601,45,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1298,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1298,606,1.509,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1300,203,5.62,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1300,204,25.84,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1300,205,11.89,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1300,207,1.52,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1300,208,303,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1300,255,55.14,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1300,269,10.8,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1300,291,1.1,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1300,301,90,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1300,303,1.21,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1300,306,304,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1300,307,56,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1300,320,61,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1300,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1300,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1300,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1300,601,56,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1300,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1300,606,15.904,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1301,203,3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1301,204,14,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1301,205,28.89,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1301,207,0.8,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1301,208,254,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1301,255,53.31,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1301,269,21.26,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1301,291,1,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1301,301,60,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1301,303,0.36,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1301,306,204,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1301,307,115,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1301,320,117,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (1301,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1301,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1301,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1301,601,15,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1301,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1301,606,2.717,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1303,203,3.33,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1303,204,5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1303,205,3.33,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1303,207,0.51,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1303,208,72,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1303,255,87.83,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1303,269,3.33,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1303,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1303,301,133,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1303,303,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1303,306,132,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1303,307,50,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1303,320,47,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1303,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1303,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1303,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1303,601,17,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1303,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1303,606,3.276,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1305,203,3.43,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1305,204,1.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1305,205,7.68,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1305,207,0.76,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1305,208,57,'100g',6,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1305,255,87.09,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1305,269,7.29,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1305,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1305,301,122,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1305,303,0.16,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1305,306,168,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1305,307,66,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1305,320,96,'100g',2,1,'2024-12-12','2016-01-02');
INSERT INTO `cndb_nutval` VALUES (1305,328,1.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1305,401,0,'100g',4,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1305,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1305,601,5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1305,605,0.036,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1305,606,0.616,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1306,203,5.33,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1306,204,9.33,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1306,205,40.01,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1306,207,1.48,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1306,208,265,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1306,255,43.85,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1306,269,10.67,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1306,291,9.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1306,301,133,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1306,303,0.48,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1306,306,213,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1306,307,113,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1306,320,26,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (1306,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (1306,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1306,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (1306,601,7,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1306,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1306,606,6.598,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (1323,203,0,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,204,100,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,205,0,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,207,0,'100g',4,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,208,900,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,255,0.5,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,269,0,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,291,0,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,301,0,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,303,0,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,306,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,307,0,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (1323,328,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,401,0,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (1323,601,300,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,605,0,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (1323,606,60,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (2001,203,6.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2001,204,8.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2001,205,72.12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2001,207,4.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2001,208,263,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2001,255,8.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2001,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2001,291,21.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2001,301,661,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2001,303,7.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2001,306,1044,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2001,307,77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2001,320,27,'100g',1,1,'2024-12-12','2001-01-11');
INSERT INTO `cndb_nutval` VALUES (2001,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2001,401,39.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2001,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2001,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2001,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2001,606,2.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2002,203,17.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2002,204,15.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2002,205,50.02,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2002,207,6.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2002,208,337,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2002,255,9.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2002,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2002,291,14.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2002,301,646,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2002,303,36.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2002,306,1441,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2002,307,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2002,320,16,'100g',2,1,'2024-12-12','2001-01-11');
INSERT INTO `cndb_nutval` VALUES (2002,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2002,401,21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2002,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2002,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2002,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2002,606,0.586,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2003,203,22.98,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2003,204,4.07,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2003,205,47.75,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2003,207,14.85,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2003,208,233,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2003,255,10.35,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2003,269,1.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2003,291,37.7,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2003,301,2240,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2003,303,89.8,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2003,306,2630,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2003,307,76,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2003,320,37,'100g',1,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (2003,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2003,401,0.8,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2003,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2003,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2003,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2003,606,2.157,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (2004,203,7.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2004,204,8.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2004,205,74.97,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2004,207,3.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2004,208,313,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2004,255,5.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2004,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2004,291,26.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2004,301,834,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2004,303,43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2004,306,529,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2004,307,23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2004,320,309,'100g',1,1,'2024-12-12','2001-01-11');
INSERT INTO `cndb_nutval` VALUES (2004,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2004,401,46.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2004,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2004,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2004,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2004,606,2.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2005,203,19.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2005,204,14.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2005,205,49.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2005,207,5.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2005,208,333,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2005,255,9.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2005,269,0.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2005,291,38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2005,301,689,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2005,303,16.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2005,306,1351,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2005,307,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2005,320,18,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (2005,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2005,401,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2005,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2005,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2005,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2005,606,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2006,203,10.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2006,204,6.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2006,205,68.47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2006,207,5.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2006,208,311,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2006,255,8.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2006,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2006,291,28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2006,301,383,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2006,303,13.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2006,306,1119,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2006,307,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2006,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (2006,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2006,401,21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2006,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2006,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2006,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2006,606,0.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2007,203,18.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2007,204,25.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2007,205,41.35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2007,207,9.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2007,208,392,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2007,255,6.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2007,269,0.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2007,291,11.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2007,301,1767,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2007,303,44.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2007,306,1400,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2007,307,160,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2007,320,3,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (2007,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2007,401,17.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2007,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2007,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2007,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2007,606,2.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2008,203,23.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2008,204,3.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2008,205,49.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2008,207,16.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2008,208,237,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2008,255,7.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2008,269,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (2008,291,11.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2008,301,1346,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2008,303,31.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2008,306,4740,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2008,307,83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2008,320,293,'100g',2,1,'2024-12-12','2002-01-02');
INSERT INTO `cndb_nutval` VALUES (2008,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2008,401,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2008,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2008,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2008,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2008,606,0.169,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2009,203,13.46,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2009,204,14.28,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2009,205,49.7,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2009,207,11.81,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2009,208,282,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2009,255,10.75,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2009,269,7.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2009,291,34.8,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2009,301,330,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2009,303,17.3,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2009,306,1950,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2009,307,2867,'100g',6,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2009,320,1483,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (2009,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2009,401,0.7,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2009,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2009,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2009,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2009,606,2.462,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (2010,203,3.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2010,204,1.24,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2010,205,80.59,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2010,207,3.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2010,208,247,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2010,255,10.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2010,269,2.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2010,291,53.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2010,301,1002,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2010,303,8.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2010,306,431,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2010,307,10,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2010,320,15,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (2010,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2010,401,3.8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2010,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2010,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2010,605,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2010,606,0.345,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2011,203,5.97,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (2011,204,13,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (2011,205,65.53,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (2011,207,5.63,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (2011,208,274,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (2011,255,9.87,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (2011,269,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2011,291,33.9,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (2011,301,632,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (2011,303,11.83,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (2011,306,1020,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2011,307,277,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (2011,320,8,'100g',1,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (2011,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2011,401,0.2,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (2011,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2011,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2011,605,0.254,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2011,606,3.952,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (2012,203,21.93,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2012,204,4.78,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2012,205,52.1,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2012,207,14.08,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2012,208,279,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2012,255,7.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2012,269,7.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2012,291,10.4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2012,301,1246,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2012,303,42.46,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2012,306,4466,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2012,307,211,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2012,320,293,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (2012,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2012,401,566.7,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2012,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2012,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2012,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2012,606,0.115,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2013,203,12.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2013,204,17.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2013,205,54.99,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2013,207,6.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2013,208,298,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2013,255,8.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2013,269,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (2013,291,41.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2013,301,709,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2013,303,16.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2013,306,1267,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2013,307,35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2013,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (2013,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2013,401,21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2013,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2013,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2013,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (2013,606,0.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2014,203,17.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2014,204,22.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2014,205,44.24,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2014,207,7.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2014,208,375,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2014,255,8.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2014,269,2.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2014,291,10.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2014,301,931,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2014,303,66.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2014,306,1788,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2014,307,168,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2014,320,64,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (2014,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2014,401,7.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2014,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2014,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2014,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2014,606,1.535,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2015,203,14.29,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (2015,204,14.01,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (2015,205,55.83,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (2015,207,7.07,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (2015,208,325,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2015,255,8.8,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2015,269,2.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2015,291,53.2,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (2015,301,525,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2015,303,19.1,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (2015,306,1170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2015,307,52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2015,320,1,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (2015,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2015,401,0.7,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (2015,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2015,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2015,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2015,606,1.648,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (2016,203,15.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2016,204,14.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2016,205,55.17,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2016,207,6.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2016,208,305,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2016,255,7.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2016,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2016,291,21.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2016,301,1516,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2016,303,16.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2016,306,1186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2016,307,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2016,320,3,'100g',1,1,'2024-12-12','2001-01-11');
INSERT INTO `cndb_nutval` VALUES (2016,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2016,401,21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2016,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2016,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2016,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2016,606,0.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2017,203,19.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2017,204,4.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2017,205,55.82,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2017,207,12.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2017,208,253,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2017,255,7.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2017,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2017,291,13.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2017,301,1784,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2017,303,48.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2017,306,3308,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2017,307,208,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2017,320,293,'100g',2,1,'2024-12-12','2002-01-02');
INSERT INTO `cndb_nutval` VALUES (2017,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2017,401,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2017,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2017,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2017,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2017,606,0.234,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2018,203,15.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2018,204,14.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2018,205,52.29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2018,207,8.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2018,208,345,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2018,255,8.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2018,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2018,291,39.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2018,301,1196,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2018,303,18.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2018,306,1694,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2018,307,88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2018,320,7,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (2018,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2018,401,21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2018,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2018,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2018,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2018,606,0.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2019,203,23,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2019,204,6.41,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2019,205,58.35,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2019,207,3.4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2019,208,323,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2019,255,8.84,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2019,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2019,291,24.6,'100g',3,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2019,301,176,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2019,303,33.53,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2019,306,770,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2019,307,67,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2019,320,3,'100g',2,1,'2024-12-12','2002-01-02');
INSERT INTO `cndb_nutval` VALUES (2019,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2019,401,3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2019,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2019,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2019,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2019,606,1.46,'100g',3,1,'1994-11-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2020,203,16.55,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2020,204,0.73,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2020,205,72.73,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2020,207,3.54,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2020,208,331,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2020,255,6.45,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2020,269,2.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2020,291,9,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2020,301,79,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2020,303,5.65,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2020,306,1193,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2020,307,60,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2020,320,0,'100g',1,1,'2024-12-12','2008-01-11');
INSERT INTO `cndb_nutval` VALUES (2020,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2020,401,1.2,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2020,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2020,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2020,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2020,606,0.249,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2021,203,8.98,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2021,204,4.24,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2021,205,71.62,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2021,207,5.22,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2021,208,335,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2021,255,9.94,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2021,269,3.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2021,291,14.1,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2021,301,114,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2021,303,19.8,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2021,306,1320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2021,307,27,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2021,320,2,'100g',1,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (2021,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2021,401,0.7,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2021,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2021,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2021,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2021,606,2.599,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (2022,203,6.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2022,204,32.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2022,205,50.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2022,207,2.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2022,208,475,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2022,255,8.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2022,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2022,291,20.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2022,301,252,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2022,303,13.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2022,306,463,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2022,307,80,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2022,320,40,'100g',1,1,'2024-12-12','2002-01-07');
INSERT INTO `cndb_nutval` VALUES (2022,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2022,401,21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2022,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2022,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2022,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2022,606,9.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2023,203,12.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2023,204,7.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2023,205,60.56,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2023,207,12.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2023,208,271,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2023,255,7.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2023,269,4.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2023,291,40.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2023,301,1990,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2023,303,82.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2023,306,1522,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2023,307,77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2023,320,403,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (2023,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2023,401,51.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2023,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2023,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2023,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2023,606,0.529,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2024,203,26.08,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2024,204,36.24,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2024,205,28.09,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2024,207,4.33,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2024,208,508,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2024,255,5.27,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2024,269,6.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2024,291,12.2,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2024,301,266,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2024,303,9.21,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2024,306,738,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2024,307,13,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2024,320,2,'100g',1,1,'2024-12-12','2008-01-11');
INSERT INTO `cndb_nutval` VALUES (2024,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2024,401,7.1,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2024,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2024,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2024,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2024,606,1.989,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2025,203,5.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2025,204,36.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2025,205,49.29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2025,207,2.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2025,208,525,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2025,255,6.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2025,269,2.99,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2025,291,20.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2025,301,184,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2025,303,3.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2025,306,350,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2025,307,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2025,320,5,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (2025,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2025,401,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2025,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2025,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2025,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2025,606,25.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2026,203,10.41,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2026,204,1.04,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2026,205,79.12,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2026,207,4.04,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2026,208,341,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2026,255,5.39,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2026,269,6.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2026,291,15.2,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2026,301,384,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2026,303,3.9,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2026,306,985,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2026,307,73,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2026,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (2026,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2026,401,23.4,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2026,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2026,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2026,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2026,606,0.219,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2027,203,9,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2027,204,4.28,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2027,205,68.92,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2027,207,7.87,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2027,208,265,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2027,255,9.93,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2027,269,4.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2027,291,42.5,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2027,301,1597,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2027,303,36.8,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2027,306,1260,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2027,307,25,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2027,320,85,'100g',1,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (2027,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2027,401,2.3,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2027,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2027,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2027,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2027,606,1.551,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2028,203,14.14,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2028,204,12.89,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2028,205,53.99,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2028,207,7.74,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2028,208,282,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2028,255,11.24,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2028,269,10.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2028,291,34.9,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2028,301,229,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2028,303,21.14,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2028,306,2280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2028,307,68,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2028,320,2463,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2028,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2028,401,0.9,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2028,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2028,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2028,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2028,606,2.14,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2029,203,26.63,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2029,204,5.48,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2029,205,50.64,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2029,207,11.36,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2029,208,292,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2029,255,5.89,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2029,269,7.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2029,291,26.7,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2029,301,1140,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2029,303,22.04,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2029,306,2683,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2029,307,452,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2029,320,97,'100g',1,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (2029,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2029,401,125,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2029,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2029,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2029,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2029,606,1.378,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (2030,203,10.39,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2030,204,3.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2030,205,63.95,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2030,207,4.49,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2030,208,251,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2030,255,12.46,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2030,269,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2030,291,25.3,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2030,301,443,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2030,303,9.71,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2030,306,1329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2030,307,20,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2030,320,27,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (2030,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2030,401,0,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (2030,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2030,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2030,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2030,606,1.392,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (2031,203,12.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2031,204,17.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2031,205,56.63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2031,207,6.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2031,208,318,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2031,255,8.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2031,269,10.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2031,291,27.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2031,301,148,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2031,303,7.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2031,306,2014,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2031,307,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2031,320,2081,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (2031,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2031,401,76.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2031,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2031,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2031,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2031,606,3.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2032,203,10.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2032,204,2.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2032,205,68.61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2032,207,1.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2032,208,296,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2032,255,11.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2032,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2032,291,26.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2032,301,265,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2032,303,14.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2032,306,73,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2032,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2032,320,0,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (2032,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2032,401,21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2032,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2032,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2032,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2032,606,0.626,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2033,203,17.99,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (2033,204,41.56,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (2033,205,28.13,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (2033,207,6.37,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (2033,208,525,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (2033,255,5.95,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (2033,269,2.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2033,291,19.5,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (2033,301,1438,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (2033,303,9.76,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (2033,306,719,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2033,307,26,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (2033,320,0,'100g',1,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (2033,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2033,401,1,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (2033,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2033,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2033,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2033,606,4.517,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (2034,203,9.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2034,204,7.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2034,205,65.59,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2034,207,5.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2034,208,307,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2034,255,9.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2034,269,1.8,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2034,291,11.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2034,301,996,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2034,303,35.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2034,306,684,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2034,307,27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2034,320,132,'100g',2,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (2034,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2034,401,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2034,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2034,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2034,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2034,606,3.29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2035,203,5.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2035,204,12.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2035,205,69.28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2035,207,3.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2035,208,342,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2035,255,8.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2035,269,7.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2035,291,14.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2035,301,682,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2035,303,19.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2035,306,663,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2035,307,52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2035,320,13,'100g',1,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (2035,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2035,401,23.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2035,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2035,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2035,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2035,606,6.53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2036,203,4.88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2036,204,15.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2036,205,64.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2036,207,6.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2036,208,331,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2036,255,9.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2036,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2036,291,42.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2036,301,1280,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2036,303,29.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2036,306,955,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2036,307,50,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2036,320,156,'100g',1,1,'2024-12-12','2002-01-07');
INSERT INTO `cndb_nutval` VALUES (2036,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2036,401,61.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2036,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2036,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2036,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2036,606,7.371,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2037,203,11.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2037,204,5.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2037,205,65.37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2037,207,5.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2037,208,310,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2037,255,11.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2037,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2037,291,3.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2037,301,111,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2037,303,11.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2037,306,1724,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2037,307,148,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2037,320,27,'100g',2,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (2037,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2037,401,80.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2037,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2037,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2037,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2037,606,1.586,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2038,203,10.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2038,204,12.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2038,205,60.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2038,207,7.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2038,208,315,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2038,255,7.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2038,269,1.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2038,291,40.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2038,301,1652,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2038,303,28.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2038,306,1070,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2038,307,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2038,320,295,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (2038,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2038,401,32.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2038,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2038,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2038,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2038,606,7.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2039,203,6.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2039,204,5.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2039,205,68.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2039,207,9.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2039,208,272,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2039,255,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2039,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2039,291,45.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2039,301,2132,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2039,303,37.88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2039,306,1051,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2039,307,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2039,320,257,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (2039,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2039,401,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2039,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2039,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2039,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2039,606,3.26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2041,203,22.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2041,204,7.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2041,205,50.22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2041,207,12.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2041,208,295,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2041,255,7.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2041,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2041,291,7.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2041,301,1139,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2041,303,32.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2041,306,3020,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2041,307,62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2041,320,210,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (2041,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2041,401,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2041,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2041,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2041,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2041,606,1.881,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2042,203,9.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2042,204,7.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2042,205,63.94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2042,207,11.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2042,208,276,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2042,255,7.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2042,269,1.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2042,291,37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2042,301,1890,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2042,303,123.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2042,306,814,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2042,307,55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2042,320,190,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (2042,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2042,401,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2042,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2042,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2042,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2042,606,2.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2043,203,9.68,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (2043,204,3.25,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (2043,205,67.14,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (2043,207,7.08,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (2043,208,312,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (2043,255,12.85,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (2043,269,3.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2043,291,22.7,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2043,301,168,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2043,303,55,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (2043,306,2080,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2043,307,27,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (2043,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (2043,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2043,401,0.7,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (2043,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2043,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2043,605,0.056,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2043,606,1.838,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (2044,203,3.15,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2044,204,0.64,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2044,205,2.65,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2044,207,1.49,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2044,208,23,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2044,255,92.06,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2044,269,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2044,291,1.6,'100g',1,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2044,301,177,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2044,303,3.17,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2044,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2044,307,4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2044,320,264,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (2044,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2044,401,18,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2044,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2044,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2044,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2044,606,0.041,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2045,203,3.46,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2045,204,1.12,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2045,205,7.02,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2045,207,2.45,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2045,208,43,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2045,255,85.95,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2045,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2045,291,2.1,'100g',3,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2045,301,208,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2045,303,6.59,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2045,306,738,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2045,307,61,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2045,320,386,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (2045,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2045,401,85,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2045,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2045,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2045,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2045,606,0.06,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2046,203,3.74,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2046,204,3.34,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2046,205,5.83,'100g',3,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2046,207,3.37,'100g',1,1,'1994-11-19','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2046,208,60,'100g',3,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2046,255,83.72,'100g',1,1,'1994-11-14','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (2046,269,0.92,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2046,291,4,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2046,301,63,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2046,303,1.61,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2046,306,152,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2046,307,1104,'100g',1,1,'1994-11-14','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (2046,320,5,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (2046,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2046,401,0.3,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2046,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2046,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2046,605,0.009,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2046,606,0.214,'100g',3,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2047,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2047,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2047,205,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2047,207,99.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2047,208,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2047,255,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2047,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2047,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2047,301,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2047,303,0.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2047,306,8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2047,307,38758,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2047,320,0,'100g',1,1,'2024-12-12','2006-01-02');
INSERT INTO `cndb_nutval` VALUES (2047,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2047,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2047,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2047,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2047,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2047,606,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2048,203,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2048,204,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2048,205,0.93,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2048,207,0.17,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2048,208,21,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2048,255,93.81,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2048,269,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2048,291,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2048,301,7,'100g',7,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2048,303,0.2,'100g',7,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2048,306,73,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2048,307,5,'100g',7,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2048,320,0,'100g',1,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (2048,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2048,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2048,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2048,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2048,605,0,'100g',4,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2048,606,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2049,203,5.56,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2049,204,1.68,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2049,205,24.45,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2049,207,3.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2049,208,101,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2049,255,65.11,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2049,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2049,291,14,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2049,301,405,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2049,303,17.45,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2049,306,609,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2049,307,9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2049,320,238,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (2049,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2049,401,160.1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2049,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2049,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2049,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2049,606,0.467,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2050,203,0.06,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2050,204,0.06,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2050,205,12.65,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2050,207,0.26,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2050,208,288,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2050,255,52.58,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2050,269,12.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2050,291,0,'100g',4,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2050,301,11,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2050,303,0.12,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2050,306,148,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2050,307,9,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2050,320,0,'100g',1,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (2050,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2050,401,0,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2050,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (2050,601,0,'100g',4,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2050,605,0,'100g',NULL,1,'1994-03-16','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2050,606,0.01,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2052,203,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2052,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2052,205,14.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2052,207,0.01,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2052,208,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2052,255,85.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2052,269,14.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2052,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2052,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2052,303,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2052,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2052,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2052,320,0,'100g',1,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (2052,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2052,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2052,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (2052,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2052,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2052,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2053,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2053,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2053,205,0.04,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2053,207,0.02,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2053,208,18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2053,255,94.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2053,269,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2053,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2053,301,6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2053,303,0.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2053,306,2,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2053,307,2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2053,320,0,'100g',1,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (2053,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2053,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2053,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2053,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2053,605,0,'100g',4,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2053,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2054,203,2.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2054,204,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2054,205,4.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2054,207,8.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2054,208,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2054,255,83.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2054,269,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2054,291,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2054,301,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2054,303,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2054,306,40,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2054,307,2348,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (2054,320,7,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (2054,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2054,401,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2054,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2054,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2054,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2054,606,0.233,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (2055,203,1.18,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2055,204,0.69,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2055,205,11.29,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2055,207,1.76,'100g',1,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2055,208,48,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2055,255,85.08,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2055,269,7.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2055,291,3.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2055,301,56,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2055,303,0.42,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2055,306,246,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2055,307,420,'100g',6,1,'1994-11-14','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (2055,320,0,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (2055,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2055,401,24.9,'100g',6,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2055,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (2055,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2055,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2055,606,0.09,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2063,203,3.31,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2063,204,5.86,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2063,205,20.7,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2063,207,2.35,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2063,208,131,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2063,255,67.77,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2063,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2063,291,14.1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2063,301,317,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2063,303,6.65,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2063,306,668,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2063,307,26,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2063,320,146,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (2063,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2063,401,21.8,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2063,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2063,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2063,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2063,606,2.838,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2064,203,3.75,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2064,204,0.94,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2064,205,14.89,'100g',3,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2064,207,1.76,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2064,208,70,'100g',3,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2064,255,78.65,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2064,269,NULL,'100g',NULL,1,'2005-12-28','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (2064,291,8,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2064,301,243,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2064,303,5.08,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2064,306,569,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2064,307,31,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2064,320,212,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (2064,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2064,401,31.8,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2064,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2064,601,0,'100g',4,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2064,605,0,'100g',NULL,1,'2005-12-28','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2064,606,0.246,'100g',3,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2065,203,3.29,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2065,204,0.73,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2065,205,8.41,'100g',3,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2065,207,2.03,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2065,208,44,'100g',3,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2065,255,85.55,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2065,269,NULL,'100g',NULL,1,'2005-12-28','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2065,291,6.8,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2065,301,199,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2065,303,11.87,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2065,306,458,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2065,307,30,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2065,320,203,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (2065,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2065,401,13.3,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2065,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2065,601,0,'100g',4,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2065,605,0,'100g',NULL,1,'2005-12-28','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2065,606,0.191,'100g',3,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2066,203,19.93,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2066,204,6.03,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2066,205,52.04,'100g',3,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2066,207,10.7,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2066,208,285,'100g',3,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2066,255,11.3,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2066,269,NULL,'100g',NULL,1,'2005-12-28','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (2066,291,29.8,'100g',6,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2066,301,1488,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2066,303,87.47,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2066,306,1924,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2066,307,344,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2066,320,529,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (2066,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2066,401,0,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2066,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2066,601,0,'100g',4,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2066,605,0,'100g',NULL,1,'2005-12-28','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (2066,606,1.577,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (2068,203,0.04,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2068,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2068,205,0.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2068,207,0.17,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2068,208,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2068,255,94.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2068,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2068,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2068,301,6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2068,303,0.45,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2068,306,39,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2068,307,8,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2068,320,0,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (2068,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2068,401,0.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2068,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2068,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2068,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2068,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2069,203,0.49,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2069,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2069,205,17.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2069,207,0.37,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2069,208,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2069,255,76.45,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2069,269,14.95,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2069,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2069,301,27,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2069,303,0.72,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2069,306,112,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2069,307,23,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2069,320,0,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (2069,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2069,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2069,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (2069,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2069,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2069,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2074,203,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2074,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2074,205,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2074,207,99.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2074,208,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2074,255,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2074,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2074,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2074,301,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2074,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2074,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2074,307,17000,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2074,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (2074,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2074,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2074,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (2074,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2074,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2074,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2075,203,4.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2075,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2075,205,58,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2075,207,31.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2075,208,322,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2075,255,5.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2075,269,10.83,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2075,291,13.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2075,301,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2075,303,7.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2075,306,1000,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2075,307,7203,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2075,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (2075,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2075,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2075,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (2075,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2075,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2075,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2076,203,10.82,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2076,204,7.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2076,205,56.56,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2076,207,14.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2076,208,335,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2076,255,10.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2076,269,8.67,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2076,291,10.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2076,301,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2076,303,3.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2076,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2076,307,4616,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2076,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (2076,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (2076,401,5.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2076,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (2076,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2076,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (2076,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3001,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3001,204,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3001,205,86.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3001,207,0.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3001,208,347,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3001,255,12.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3001,269,57.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3001,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3001,301,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3001,303,0.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3001,306,54,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3001,307,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3001,320,0,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (3001,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3001,401,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3001,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3001,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3001,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3001,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3002,203,12.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3002,204,2.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3002,205,2.43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3002,207,0.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3002,208,81,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3002,255,82.44,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3002,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3002,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3002,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3002,303,0.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3002,306,187,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3002,307,41,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3002,320,0,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (3002,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3002,401,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3002,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3002,601,51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3002,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3002,606,1.18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3003,203,12.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3003,204,2.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3003,205,2.43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3003,207,0.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3003,208,81,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3003,255,82.44,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3003,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3003,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3003,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3003,303,0.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3003,306,187,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3003,307,41,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3003,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (3003,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3003,401,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3003,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3003,601,51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3003,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3003,606,1.18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3005,203,13.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3005,204,2.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3005,205,1.51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3005,207,0.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3005,208,81,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3005,255,82.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3005,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3005,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3005,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3005,303,0.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3005,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3005,307,39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3005,320,0,'100g',1,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (3005,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3005,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3005,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3005,601,33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3005,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3005,606,1.063,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3007,203,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3007,204,7.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3007,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3007,207,1,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3007,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3007,255,78.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3007,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3007,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3007,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3007,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3007,306,223,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3007,307,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3007,320,11,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (3007,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3007,401,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3007,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3007,601,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3007,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3007,606,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3008,203,11.3,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3008,204,3.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3008,205,3.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3008,207,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3008,208,97,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3008,255,80.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3008,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3008,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3008,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3008,303,1.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3008,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3008,307,44,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3008,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (3008,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3008,401,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3008,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3008,601,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3008,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3008,606,1.267,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3009,203,11.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3009,204,3.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3009,205,3.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3009,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3009,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3009,255,80.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3009,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3009,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3009,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3009,303,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3009,306,210,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3009,307,44,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3009,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (3009,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3009,401,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3009,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3009,601,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3009,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3009,606,1.271,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3010,203,14.07,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3010,204,3.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3010,205,0.85,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3010,207,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3010,208,94,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3010,255,81.06,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3010,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3010,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3010,301,7,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3010,303,1.19,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3010,306,193,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3010,307,43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3010,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (3010,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3010,401,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3010,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3010,601,36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3010,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3010,606,1.65,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3011,203,15.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3011,204,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3011,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3011,207,0.37,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3011,208,112,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3011,255,79.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3011,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3011,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3011,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3011,303,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3011,306,211,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3011,307,42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3011,320,8,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (3011,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3011,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3011,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3011,601,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3011,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3011,606,2.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3012,203,13.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3012,204,7.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3012,205,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3012,207,0.49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3012,208,130,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3012,255,77.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3012,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3012,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3012,301,64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3012,303,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3012,306,141,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3012,307,49,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3012,320,6,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (3012,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3012,401,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3012,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3012,601,61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3012,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3012,606,2.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3013,203,14,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3013,204,9.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3013,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3013,207,0.49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3013,208,146,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3013,255,76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3013,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3013,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3013,301,55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3013,303,0.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3013,306,122,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3013,307,49,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3013,320,11,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (3013,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3013,401,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3013,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3013,601,59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3013,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3013,606,2.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3014,203,14.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3014,204,14.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3014,205,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3014,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3014,208,188,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3014,255,68.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3014,269,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3014,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3014,301,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3014,303,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3014,306,106,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3014,307,267,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3014,320,3,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (3014,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3014,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3014,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3014,601,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3014,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3014,606,4.094,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3015,203,11.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3015,204,6.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3015,205,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3015,207,0.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3015,208,111,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3015,255,80.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3015,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3015,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3015,301,41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3015,303,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3015,306,135,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3015,307,49,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3015,320,0,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (3015,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3015,401,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3015,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3015,601,58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3015,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3015,606,1.641,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3016,203,11.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3016,204,6.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3016,205,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3016,207,0.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3016,208,111,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3016,255,80.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3016,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3016,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3016,301,41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3016,303,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3016,306,135,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3016,307,49,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3016,320,0,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (3016,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3016,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3016,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3016,601,58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3016,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3016,606,1.641,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3017,203,13.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3017,204,14.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3017,205,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3017,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3017,208,188,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3017,255,69.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3017,269,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3017,291,0.2,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3017,301,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3017,303,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3017,306,120,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3017,307,295,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3017,320,6,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (3017,328,0.4,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3017,401,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3017,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3017,601,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3017,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3017,606,4.143,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3021,203,13.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3021,204,14.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3021,205,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3021,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3021,208,184,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3021,255,69.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3021,269,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3021,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3021,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3021,303,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3021,306,114,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3021,307,267,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3021,320,21,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3021,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3021,401,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3021,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3021,601,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3021,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3021,606,5.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3026,203,0.31,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3026,204,0.14,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3026,205,12.22,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3026,207,0.19,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3026,208,46,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3026,255,87.14,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3026,269,9.78,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3026,291,1.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3026,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3026,303,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3026,306,141,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3026,307,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3026,320,4,'100g',2,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (3026,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3026,401,15.9,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3026,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3026,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3026,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (3026,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3044,203,2.36,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3044,204,1.47,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3044,205,9.45,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3044,207,0.37,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3044,208,61,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3044,255,86.34,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3044,269,2.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3044,291,1.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3044,301,17,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3044,303,0.46,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3044,306,112,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3044,307,38,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3044,320,44,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (3044,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3044,401,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3044,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3044,601,7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3044,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3044,606,0.486,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3045,203,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3045,204,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3045,205,9.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3045,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3045,208,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3045,255,86.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3045,269,2.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3045,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3045,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3045,303,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3045,306,72,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3045,307,35,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3045,320,35,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (3045,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3045,401,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3045,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3045,601,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3045,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3045,606,0.411,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3046,203,3.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3046,204,2.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3046,205,16.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3046,207,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3046,208,99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3046,255,76.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3046,269,0.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3046,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3046,301,54,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3046,303,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3046,306,32,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3046,307,282,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3046,320,51,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (3046,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3046,401,0.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3046,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3046,601,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3046,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3046,606,0.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3047,203,2.44,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3047,204,2.26,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3047,205,8.18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3047,207,0.28,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3047,208,63,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3047,255,86.84,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3047,269,1.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3047,291,1.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3047,301,10,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3047,303,0.41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3047,306,87,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3047,307,15,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3047,320,36,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3047,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3047,401,0.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3047,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3047,601,8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3047,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3047,606,0.937,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3048,203,3.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3048,204,2.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3048,205,11.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3048,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3048,208,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3048,255,81.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3048,269,0.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3048,291,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3048,301,102,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3048,303,0.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3048,306,18,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3048,307,264,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3048,320,19,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (3048,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3048,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3048,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3048,601,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3048,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3048,606,1.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3050,203,2.57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3050,204,1.37,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3050,205,11.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3050,207,0.47,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3050,208,68,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3050,255,84.17,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3050,269,2.72,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3050,291,1.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3050,301,15,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3050,303,0.53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3050,306,122,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3050,307,30,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3050,320,63,'100g',2,1,'2024-12-12','2009-01-10');
INSERT INTO `cndb_nutval` VALUES (3050,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3050,401,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3050,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3050,601,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3050,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3050,606,0.543,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3053,203,2.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3053,204,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3053,205,8.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3053,207,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3053,208,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3053,255,84.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3053,269,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3053,291,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3053,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3053,303,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3053,306,145,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3053,307,31,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3053,320,246,'100g',2,1,'2024-12-12','2013-01-08');
INSERT INTO `cndb_nutval` VALUES (3053,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3053,401,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3053,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3053,601,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3053,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3053,606,0.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3054,203,2.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3054,204,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3054,205,8.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3054,207,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3054,208,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3054,255,84.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3054,269,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3054,291,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3054,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3054,303,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3054,306,145,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3054,307,31,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3054,320,246,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (3054,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3054,401,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3054,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3054,601,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3054,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3054,606,1.367,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3055,203,2.03,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3055,204,6.93,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3055,205,6.36,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3055,207,0.38,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3055,208,96,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3055,255,84.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3055,269,2.16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3055,291,1.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3055,301,19,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3055,303,0.33,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3055,306,127,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3055,307,38,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3055,320,222,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3055,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3055,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3055,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3055,601,12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3055,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3055,606,2.84,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3067,203,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3067,204,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3067,205,7.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3067,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3067,208,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3067,255,88.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3067,269,0.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3067,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3067,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3067,303,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3067,306,95,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3067,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3067,320,138,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (3067,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3067,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3067,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3067,601,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3067,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3067,606,0.696,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3068,203,3.53,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3068,204,3.22,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3068,205,7.81,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3068,207,0.39,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3068,208,74,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3068,255,85.05,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3068,269,2.69,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3068,291,1.7,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3068,301,27,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3068,303,0.49,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3068,306,143,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3068,307,25,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3068,320,110,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (3068,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3068,401,0.1,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3068,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3068,601,8,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3068,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3068,606,0.341,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,203,3.53,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,204,3.23,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,205,7.8,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,207,0.39,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,208,74,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,255,85.05,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,269,2.67,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,291,1.7,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,301,27,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,303,0.49,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,306,143,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,307,25,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,320,87,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3069,328,0,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,401,0.1,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3069,601,8,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3069,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3069,606,0.341,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3070,203,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3070,204,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3070,205,7.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3070,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3070,208,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3070,255,89.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3070,269,1.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3070,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3070,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3070,303,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3070,306,66,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3070,307,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3070,320,69,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3070,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3070,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3070,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3070,601,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3070,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3070,606,0.278,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3072,203,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3072,204,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3072,205,6.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3072,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3072,208,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3072,255,83.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3072,269,1.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3072,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3072,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3072,303,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3072,306,92,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3072,307,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3072,320,52,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3072,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3072,401,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3072,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3072,601,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3072,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3072,606,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3073,203,2.47,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3073,204,1.73,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3073,205,8.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3073,207,0.49,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3073,208,59,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3073,255,86.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3073,269,1.58,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3073,291,2.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3073,301,27,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3073,303,0.53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3073,306,158,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3073,307,24,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3073,320,207,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3073,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3073,401,0.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3073,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3073,601,11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3073,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3073,606,0.496,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3077,203,1.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3077,204,2.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3077,205,8.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3077,207,0.41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3077,208,60,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3077,255,87.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3077,269,1.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3077,291,1.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3077,301,14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3077,303,0.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3077,306,133,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3077,307,11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3077,320,41,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (3077,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3077,401,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3077,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3077,601,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3077,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3077,606,1.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3082,203,2.27,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3082,204,1.24,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3082,205,7.94,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3082,207,0.33,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3082,208,52,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3082,255,88.22,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3082,269,1.66,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3082,291,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3082,301,18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3082,303,0.29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3082,306,91,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3082,307,19,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3082,320,81,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3082,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3082,401,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3082,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3082,601,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3082,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3082,606,0.338,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3083,203,2.37,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3083,204,0.92,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3083,205,9.57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3083,207,0.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3083,208,56,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3083,255,86.64,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3083,269,1.25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3083,291,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3083,301,24,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3083,303,0.41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3083,306,86,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3083,307,23,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3083,320,94,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (3083,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3083,401,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3083,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3083,601,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3083,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3083,606,0.239,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3084,203,2.32,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3084,204,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3084,205,7.62,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3084,207,0.35,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3084,208,48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3084,255,88.82,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3084,269,1.54,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3084,291,1.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3084,301,27,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3084,303,0.37,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3084,306,102,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3084,307,20,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3084,320,220,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (3084,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3084,401,0.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3084,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3084,601,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3084,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3084,606,0.236,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3085,203,1.72,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3085,204,1.74,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3085,205,7.55,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3085,207,0.49,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3085,208,53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3085,255,88.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3085,269,1.36,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3085,291,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3085,301,16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3085,303,0.36,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3085,306,98,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3085,307,45,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3085,320,216,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (3085,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3085,401,0.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3085,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3085,601,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3085,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3085,606,0.485,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3089,203,3.14,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3089,204,2.11,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3089,205,8.95,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3089,207,0.55,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3089,208,67,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3089,255,85.25,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3089,269,1.27,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3089,291,0.7,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3089,301,66,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3089,303,0.21,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3089,306,67,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3089,307,88,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3089,320,15,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (3089,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3089,401,0.1,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3089,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3089,601,7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3089,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (3089,606,1.291,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3090,203,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3090,204,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3090,205,8.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3090,207,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3090,208,61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3090,255,86.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3090,269,1.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3090,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3090,301,51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3090,303,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3090,306,44,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3090,307,183,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3090,320,30,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (3090,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3090,401,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3090,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3090,601,6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3090,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3090,606,1.175,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3091,203,1.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3091,204,0.17,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3091,205,6.29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3091,207,0.49,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3091,208,27,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3091,255,91.85,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3091,269,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3091,291,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3091,301,39,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3091,303,0.67,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3091,306,146,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3091,307,7,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3091,320,18,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3091,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3091,401,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3091,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3091,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3091,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3091,606,0.039,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3092,203,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3092,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3092,205,5.8,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3092,207,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3092,208,24,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3092,255,92.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3092,269,1.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3092,291,1.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3092,301,65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3092,303,1.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3092,306,128,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3092,307,5,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3092,320,24,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3092,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3092,401,8.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3092,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3092,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3092,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3092,606,0.023,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3093,203,1.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3093,204,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3093,205,5.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3093,207,0.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3093,208,29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3093,255,92.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3093,269,1.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3093,291,1.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3093,301,27,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3093,303,0.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3093,306,116,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3093,307,37,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3093,320,24,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3093,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3093,401,1.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3093,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3093,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3093,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3093,606,0.044,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3096,203,2.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3096,204,1.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3096,205,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3096,207,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3096,208,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3096,255,86.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3096,269,2.35,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3096,291,1.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3096,301,60,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3096,303,0.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3096,306,148,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3096,307,18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3096,320,14,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3096,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3096,401,1.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3096,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3096,601,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3096,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3096,606,1.117,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3098,203,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3098,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3098,205,7.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3098,207,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3098,208,34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3098,255,90.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3098,269,6.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3098,291,1.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3098,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3098,303,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3098,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3098,307,83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3098,320,1,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3098,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3098,401,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3098,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3098,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3098,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3098,606,0.016,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3099,203,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3099,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3099,205,6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3099,207,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3099,208,26,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3099,255,92.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3099,269,3.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3099,291,1.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3099,301,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3099,303,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3099,306,196,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3099,307,69,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3099,320,573,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3099,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3099,401,5.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3099,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3099,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3099,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3099,606,0.018,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3100,203,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3100,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3100,205,7.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3100,207,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3100,208,32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3100,255,91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3100,269,3.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3100,291,1.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3100,301,23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3100,303,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3100,306,202,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3100,307,49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3100,320,591,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3100,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3100,401,5.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3100,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3100,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3100,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3100,606,0.036,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3104,203,0.81,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3104,204,0.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3104,205,5.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3104,207,0.6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3104,208,28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3104,255,92.66,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3104,269,3.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3104,291,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3104,301,24,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3104,303,0.32,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3104,306,185,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3104,307,5,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3104,320,85,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (3104,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3104,401,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3104,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3104,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3104,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3104,606,0.02,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3105,203,0.81,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3105,204,0.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3105,205,5.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3105,207,0.6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3105,208,24,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3105,255,92.66,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3105,269,3.24,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3105,291,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3105,301,24,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3105,303,0.32,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3105,306,185,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3105,307,5,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3105,320,85,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (3105,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3105,401,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3105,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3105,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3105,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3105,606,0.02,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3108,203,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3108,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3108,205,13.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3108,207,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3108,208,57,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3108,255,84.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3108,269,4.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3108,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3108,301,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3108,303,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3108,306,263,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3108,307,22,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3108,320,322,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3108,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3108,401,9.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3108,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3108,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3108,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3108,606,0.021,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3109,203,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3109,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3109,205,14,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3109,207,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3109,208,60,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3109,255,84.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3109,269,4.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3109,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3109,301,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3109,303,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3109,306,243,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3109,307,18,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3109,320,332,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3109,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3109,401,9.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3109,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3109,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3109,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3109,606,0.021,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3112,203,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3112,204,0.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3112,205,11.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3112,207,0.37,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3112,208,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3112,255,86.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3112,269,0.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3112,291,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3112,301,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3112,303,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3112,306,110,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3112,307,57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3112,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3112,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3112,401,10.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3112,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3112,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3112,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3112,606,0.015,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3114,203,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3114,204,0.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3114,205,9.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3114,207,0.84,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3114,208,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3114,255,87.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3114,269,2.93,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3114,291,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3114,301,32,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3114,303,0.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3114,306,352,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3114,307,5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3114,320,140,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3114,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3114,401,4.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3114,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3114,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3114,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3114,606,0.095,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3115,203,0.19,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3115,204,0.36,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3115,205,11.56,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3115,207,0.21,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3115,208,50,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3115,255,87.68,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3115,269,10.48,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3115,291,1.9,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3115,301,4,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3115,303,0.08,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3115,306,86,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3115,307,2,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3115,320,1,'100g',1,1,'2024-12-12','2017-01-01');
INSERT INTO `cndb_nutval` VALUES (3115,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3115,401,64.5,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3115,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3115,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3115,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3115,606,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3116,203,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3116,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3116,205,10.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3116,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3116,208,41,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3116,255,88.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3116,269,9.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3116,291,1.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3116,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3116,303,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3116,306,71,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3116,307,0,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3116,320,1,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3116,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3116,401,38.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3116,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3116,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3116,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3116,606,0.032,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3117,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3117,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3117,205,10.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3117,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3117,208,37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3117,255,89.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3117,269,8.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3117,291,1.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3117,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3117,303,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3117,306,77,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3117,307,1,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3117,320,0,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3117,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3117,401,37.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3117,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3117,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3117,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3117,606,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3118,203,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3118,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3118,205,16.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3118,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3118,208,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3118,255,83.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3118,269,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3118,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3118,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3118,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3118,306,121,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3118,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3118,320,36,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3118,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3118,401,21.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3118,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3118,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3118,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3118,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3119,203,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3119,204,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3119,205,14.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3119,207,0.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3119,208,57,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3119,255,83.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3119,269,1.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3119,291,2.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3119,301,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3119,303,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3119,306,90,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3119,307,43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3119,320,5,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3119,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3119,401,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3119,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3119,601,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3119,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3119,606,0.076,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3120,203,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3120,204,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3120,205,16.25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3120,207,0.55,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3120,208,65,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3120,255,81.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3120,269,1.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3120,291,2.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3120,301,4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3120,303,0.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3120,306,81,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3120,307,52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3120,320,2,'100g',2,1,'2024-12-12','2004-01-08');
INSERT INTO `cndb_nutval` VALUES (3120,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3120,401,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3120,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3120,601,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3120,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3120,606,0.074,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3121,203,3.27,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3121,204,0.43,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3121,205,8.36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3121,207,0.42,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3121,208,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3121,255,87.52,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3121,269,2.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3121,291,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3121,301,18,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3121,303,0.95,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3121,306,106,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3121,307,5,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3121,320,11,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (3121,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3121,401,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3121,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3121,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3121,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3121,606,0.07,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3122,203,3.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3122,204,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3122,205,10.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3122,207,0.35,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3122,208,64,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3122,255,84.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3122,269,4.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3122,291,3.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3122,301,21,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3122,303,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3122,306,81,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3122,307,48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3122,320,15,'100g',2,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (3122,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3122,401,6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3122,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3122,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3122,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3122,606,0.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3127,203,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3127,204,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3127,205,5.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3127,207,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3127,208,37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3127,255,89.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3127,269,2.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3127,291,1.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3127,301,89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3127,303,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3127,306,191,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3127,307,49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3127,320,227,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3127,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3127,401,8.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3127,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3127,601,5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3127,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3127,606,0.702,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3128,203,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3128,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3128,205,17.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3128,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3128,208,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3128,255,82.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3128,269,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3128,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3128,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3128,303,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3128,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3128,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3128,320,36,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3128,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3128,401,17.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3128,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3128,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3128,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3128,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3129,203,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3129,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3129,205,15.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3129,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3129,208,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3129,255,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3129,269,0.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3129,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3129,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3129,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3129,306,88,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3129,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3129,320,2,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3129,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3129,401,16.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3129,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3129,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3129,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3129,606,0.035,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3130,203,0.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3130,204,0.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3130,205,14.48,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3130,207,0.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3130,208,65,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3130,255,83.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3130,269,11.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3130,291,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3130,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3130,303,0.23,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3130,306,195,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3130,307,4,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3130,320,34,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (3130,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3130,401,46.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3130,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3130,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3130,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3130,606,0.02,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3131,203,0.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3131,204,0.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3131,205,14.48,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3131,207,0.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3131,208,65,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3131,255,83.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3131,269,11.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3131,291,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3131,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3131,303,0.23,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3131,306,195,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3131,307,4,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3131,320,34,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3131,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3131,401,46.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3131,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3131,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3131,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3131,606,0.02,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3132,203,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3132,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3132,205,10.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3132,207,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3132,208,42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3132,255,88.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3132,269,6.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3132,291,2.8,'100g',6,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3132,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3132,303,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3132,306,130,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3132,307,1,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3132,320,1,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3132,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3132,401,24.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3132,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3132,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3132,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3132,606,0.012,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3133,203,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3133,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3133,205,11.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3133,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3133,208,44,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3133,255,87.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3133,269,7.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3133,291,2.8,'100g',6,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3133,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3133,303,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3133,306,115,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3133,307,1,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3133,320,1,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3133,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3133,401,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3133,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3133,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3133,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3133,606,0.006,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3134,203,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3134,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3134,205,19.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3134,207,0.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3134,208,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3134,255,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3134,269,13.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3134,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3134,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3134,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3134,306,85,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3134,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3134,320,7,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3134,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3134,401,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3134,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3134,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3134,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3134,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3135,203,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3135,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3135,205,20.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3135,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3135,208,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3135,255,79.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3135,269,13.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3135,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3135,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3135,303,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3135,306,83,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3135,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3135,320,5,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3135,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3135,401,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3135,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3135,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3135,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3135,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3136,203,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3136,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3136,205,18.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3136,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3136,208,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3136,255,80.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3136,269,10.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3136,291,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3136,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3136,303,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3136,306,177,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3136,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3136,320,23,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3136,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3136,401,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3136,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3136,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3136,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3136,606,0.008,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3137,203,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3137,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3137,205,18.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3137,207,0.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3137,208,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3137,255,80.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3137,269,10.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3137,291,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3137,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3137,303,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3137,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3137,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3137,320,10,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (3137,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3137,401,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3137,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3137,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3137,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3137,606,0.008,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3139,203,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3139,204,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3139,205,23.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3139,207,0.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3139,208,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3139,255,74.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3139,269,14.28,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3139,291,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3139,301,21,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3139,303,0.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3139,306,306,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3139,307,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3139,320,3,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (3139,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3139,401,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3139,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3139,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3139,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3139,606,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3140,203,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3140,204,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3140,205,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3140,207,0.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3140,208,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3140,255,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3140,269,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3140,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3140,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3140,303,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3140,306,66,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3140,307,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3140,320,23,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (3140,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3140,401,15.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3140,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3140,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3140,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3140,606,0.039,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3141,203,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3141,204,0.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3141,205,13.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3141,207,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3141,208,57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3141,255,85.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3141,269,8.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3141,291,1.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3141,301,10,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3141,303,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3141,306,51,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3141,307,6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3141,320,1,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3141,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3141,401,31.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3141,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3141,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3141,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3141,606,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3142,203,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3142,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3142,205,11.64,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3142,207,0.26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3142,208,44,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3142,255,87.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3142,269,9.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3142,291,1.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3142,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3142,303,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3142,306,120,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3142,307,0,'100g',4,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3142,320,17,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (3142,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3142,401,18.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3142,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3142,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3142,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3142,606,0.024,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3143,203,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3143,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3143,205,12.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3143,207,0.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3143,208,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3143,255,86.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3143,269,8.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3143,291,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3143,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3143,303,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3143,306,109,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3143,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3143,320,2,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3143,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3143,401,17.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3143,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3143,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3143,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3143,606,0.028,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3144,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3144,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3144,205,14.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3144,207,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3144,208,51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3144,255,85.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3144,269,10.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3144,291,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3144,301,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3144,303,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3144,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3144,307,1,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3144,320,2,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3144,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3144,401,42.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3144,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3144,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3144,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3144,606,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3145,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3145,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3145,205,14.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3145,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3145,208,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3145,255,85.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3145,269,10.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3145,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3145,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3145,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3145,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3145,307,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3145,320,2,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (3145,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3145,401,42.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3145,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3145,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3145,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3145,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3147,203,0.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3147,204,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3147,205,16.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3147,207,0.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3147,208,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3147,255,83.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3147,269,4.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3147,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3147,301,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3147,303,0.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3147,306,131,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3147,307,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3147,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3147,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3147,401,17.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3147,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3147,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3147,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3147,606,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3150,203,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3150,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3150,205,10.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3150,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3150,208,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3150,255,89.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3150,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3150,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3150,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3150,303,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3150,306,78,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3150,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3150,320,0,'100g',1,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (3150,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3150,401,28.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3150,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3150,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3150,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3150,606,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3151,203,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3151,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3151,205,10.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3151,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3151,208,39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3151,255,89.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3151,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3151,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3151,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3151,303,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3151,306,76,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3151,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3151,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (3151,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3151,401,26.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3151,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3151,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3151,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3151,606,0.011,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3152,203,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3152,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3152,205,15.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3152,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3152,208,58,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3152,255,83.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3152,269,12.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3152,291,2.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3152,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3152,303,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3152,306,80,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3152,307,0,'100g',4,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3152,320,1,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (3152,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3152,401,26.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3152,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3152,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3152,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3152,606,0.033,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3153,203,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3153,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3153,205,15.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3153,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3153,208,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3153,255,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3153,269,12.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3153,291,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3153,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3153,303,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3153,306,72,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3153,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3153,320,2,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (3153,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3153,401,28.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3153,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3153,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3153,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3153,606,0.032,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3154,203,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3154,204,0.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3154,205,15.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3154,207,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3154,208,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3154,255,84,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3154,269,11.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3154,291,1.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3154,301,8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3154,303,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3154,306,149,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3154,307,3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3154,320,103,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3154,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3154,401,6.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3154,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3154,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3154,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3154,606,0.041,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3156,203,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3156,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3156,205,18.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3156,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3156,208,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3156,255,81.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3156,269,8.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3156,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3156,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3156,303,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3156,306,78,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3156,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3156,320,2,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3156,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3156,401,21.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3156,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3156,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3156,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3156,606,0.036,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3157,203,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3157,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3157,205,17.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3157,207,0.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3157,208,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3157,255,81.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3157,269,10.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3157,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3157,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3157,303,0.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3157,306,68,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3157,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3157,320,3,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3157,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3157,401,19.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3157,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3157,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3157,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3157,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3158,203,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3158,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3158,205,10.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3158,207,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3158,208,41,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3158,255,88.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3158,269,7.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3158,291,2.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3158,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3158,303,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3158,306,116,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3158,307,0,'100g',4,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3158,320,1,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3158,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3158,401,27.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3158,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3158,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3158,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3158,606,0.007,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3159,203,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3159,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3159,205,11.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3159,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3159,208,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3159,255,87.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3159,269,7.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3159,291,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3159,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3159,303,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3159,306,118,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3159,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3159,320,2,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3159,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3159,401,16.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3159,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3159,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3159,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3159,606,0.013,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3161,203,0.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3161,204,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3161,205,11.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3161,207,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3161,208,51,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3161,255,87.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3161,269,9.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3161,291,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3161,301,6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3161,303,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3161,306,83,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3161,307,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3161,320,7,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3161,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3161,401,31.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3161,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3161,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3161,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3161,606,0.016,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3163,203,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3163,204,0.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3163,205,19.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3163,207,0.57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3163,208,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3163,255,79,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3163,269,12.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3163,291,1.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3163,301,5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3163,303,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3163,306,233,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3163,307,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3163,320,3,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (3163,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3163,401,13.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3163,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3163,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3163,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3163,606,0.106,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3164,203,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3164,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3164,205,16.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3164,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3164,208,61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3164,255,83.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3164,269,13.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3164,291,1.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3164,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3164,303,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3164,306,69,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3164,307,1,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3164,320,1,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3164,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3164,401,27.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3164,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3164,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3164,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3164,606,0.024,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3165,203,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3165,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3165,205,16.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3165,207,0.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3165,208,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3165,255,82.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3165,269,8.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3165,291,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3165,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3165,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3165,306,65,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3165,307,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3165,320,2,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3165,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3165,401,13.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3165,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3165,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3165,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3165,606,0.024,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3166,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3166,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3166,205,11.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3166,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3166,208,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3166,255,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3166,269,10.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3166,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3166,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3166,303,0.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3166,306,91,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3166,307,8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3166,320,1,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3166,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3166,401,57.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3166,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3166,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3166,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3166,606,0.018,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3167,203,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3167,204,0.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3167,205,12.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3167,207,0.26,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3167,208,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3167,255,87.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3167,269,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3167,291,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3167,301,7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3167,303,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3167,306,123,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3167,307,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3167,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3167,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3167,401,27.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3167,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3167,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3167,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3167,606,0.018,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3168,203,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3168,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3168,205,10.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3168,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3168,208,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3168,255,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3168,269,9.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3168,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3168,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3168,303,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3168,306,97,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3168,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3168,320,3,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3168,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3168,401,58.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3168,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3168,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3168,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3168,606,0.018,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3171,203,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3171,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3171,205,18.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3171,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3171,208,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3171,255,81.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3171,269,10.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3171,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3171,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3171,303,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3171,306,148,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3171,307,8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3171,320,1,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3171,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3171,401,67.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3171,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3171,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3171,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3171,606,0.018,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3172,203,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3172,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3172,205,10.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3172,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3172,208,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3172,255,88.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3172,269,8.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3172,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3172,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3172,303,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3172,306,184,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3172,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3172,320,3,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3172,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3172,401,62.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3172,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3172,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3172,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3172,606,0.035,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3174,203,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3174,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3174,205,11.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3174,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3174,208,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3174,255,87.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3174,269,10.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3174,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3174,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3174,303,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3174,306,134,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3174,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3174,320,1,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3174,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3174,401,32.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3174,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3174,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3174,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3174,606,0.016,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3175,203,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3175,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3175,205,10.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3175,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3175,208,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3175,255,87.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3175,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3175,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3175,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3175,303,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3175,306,199,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3175,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3175,320,11,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (3175,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3175,401,85.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3175,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3175,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3175,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3175,606,0.011,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3177,203,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3177,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3177,205,11.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3177,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3177,208,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3177,255,87.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3177,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3177,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3177,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3177,303,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3177,306,141,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3177,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3177,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (3177,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3177,401,53.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3177,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3177,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3177,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3177,606,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3179,203,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3179,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3179,205,11.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3179,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3179,208,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3179,255,87.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3179,269,8.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3179,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3179,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3179,303,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3179,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3179,307,8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3179,320,2,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3179,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3179,401,63.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3179,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3179,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3179,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3179,606,0.015,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3181,203,13.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3181,204,6.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3181,205,69.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3181,207,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3181,208,376,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3181,255,6.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3181,269,13.2,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3181,291,6.6,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3181,301,643,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3181,303,48.21,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3181,306,467,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3181,307,33,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3181,320,0,'100g',2,1,'2024-12-12','2008-01-08');
INSERT INTO `cndb_nutval` VALUES (3181,328,7.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3181,401,0,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3181,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3181,601,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3181,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3181,606,0.894,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3184,203,6.6,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3184,204,4.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3184,205,83.2,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3184,207,3.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3184,208,402,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3184,255,1.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3184,269,26.66,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3184,291,6.7,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3184,301,600,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3184,303,45,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3184,306,500,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3184,307,66,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3184,320,0,'100g',2,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (3184,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3184,401,58.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3184,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3184,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3184,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3184,606,0.639,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3185,203,6.66,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3185,204,6.66,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3185,205,78.21,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3185,207,1.77,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3185,208,399,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3185,255,6.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3185,269,26.66,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3185,291,6.7,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3185,301,800,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3185,303,30,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3185,306,467,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3185,307,33,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3185,320,0,'100g',2,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (3185,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3185,401,58.3,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3185,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3185,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3185,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3185,606,0.769,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3186,203,10.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3186,204,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3186,205,77.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3186,207,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3186,208,391,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3186,255,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3186,269,6.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3186,291,7.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3186,301,696,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3186,303,47.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3186,306,668,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3186,307,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3186,320,6,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3186,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3186,401,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3186,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3186,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3186,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3186,606,0.846,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3187,203,0.71,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3187,204,0.51,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3187,205,18.38,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3187,207,0.4,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3187,208,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3187,255,80,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3187,269,11.1,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3187,291,1,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3187,301,91,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3187,303,6.81,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3187,306,111,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3187,307,5,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3187,320,0,'100g',2,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (3187,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3187,401,15.9,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3187,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3187,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3187,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3187,606,0.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3188,203,0.71,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3188,204,0.51,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3188,205,18.79,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3188,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3188,208,84,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3188,255,79.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3188,269,11.1,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3188,291,1,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3188,301,91,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3188,303,6.81,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3188,306,111,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3188,307,5,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3188,320,0,'100g',2,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (3188,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3188,401,15.9,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3188,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3188,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3188,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3188,606,0.072,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3189,203,10.99,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3189,204,6.36,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3189,205,73.48,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3189,207,4.6,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3189,208,394,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (3189,255,4.56,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3189,269,11.67,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3189,291,7.3,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3189,301,1160,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3189,303,64.1,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3189,306,549,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3189,307,21,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3189,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (3189,328,12.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3189,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3189,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3189,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3189,605,0.002,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (3189,606,0.841,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3190,203,6.67,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3190,204,6.67,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3190,205,78.07,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3190,207,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3190,208,399,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3190,255,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3190,269,26.66,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3190,291,5.2,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3190,301,800,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3190,303,45,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3190,306,600,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3190,307,33,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3190,320,0,'100g',2,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (3190,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3190,401,58.3,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3190,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3190,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3190,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3190,606,1.267,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3191,203,0.89,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3191,204,0.89,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3191,205,15.62,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3191,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3191,208,75,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3191,255,82.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3191,269,8.85,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3191,291,0.9,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3191,301,6,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3191,303,7.5,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3191,306,97,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3191,307,4,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3191,320,0,'100g',2,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (3191,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3191,401,13.9,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3191,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3191,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3191,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3191,606,0.125,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3192,203,0.89,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3192,204,0.89,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3192,205,16.03,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3192,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3192,208,76,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3192,255,81.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3192,269,8.85,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3192,291,0.9,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3192,301,6,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3192,303,7.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3192,306,97,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3192,307,4,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3192,320,0,'100g',2,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (3192,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3192,401,13.9,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3192,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3192,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3192,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3192,606,0.126,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3194,203,6.65,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3194,204,2.19,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3194,205,83.14,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3194,207,2.89,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3194,208,390,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (3194,255,5.13,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3194,269,4.85,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3194,291,1.3,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3194,301,860,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (3194,303,53.01,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3194,306,281,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3194,307,32,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3194,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3194,328,8.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3194,401,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3194,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3194,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3194,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (3194,606,0.234,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3195,203,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3195,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3195,205,17.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3195,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3195,208,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3195,255,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3195,269,2.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3195,291,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3195,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3195,303,6.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3195,306,28,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3195,307,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3195,320,1,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (3195,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3195,401,31.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3195,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3195,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3195,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3195,606,0.114,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3197,203,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3197,204,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3197,205,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3197,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3197,208,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3197,255,88.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3197,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3197,291,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3197,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3197,303,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3197,306,39,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3197,307,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3197,320,40,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (3197,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3197,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3197,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3197,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3197,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3197,606,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3198,203,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3198,204,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3198,205,7.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3198,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3198,208,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3198,255,88.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3198,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3198,291,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3198,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3198,303,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3198,306,35,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3198,307,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3198,320,41,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (3198,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3198,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3198,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3198,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3198,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3198,606,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3199,203,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3199,204,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3199,205,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3199,207,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3199,208,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3199,255,87.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3199,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3199,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3199,301,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3199,303,0.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3199,306,44,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3199,307,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3199,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (3199,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3199,401,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3199,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3199,601,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3199,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3199,606,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3201,203,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3201,204,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3201,205,6.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3201,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3201,208,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3201,255,85.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3201,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3201,291,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3201,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3201,303,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3201,306,35,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3201,307,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3201,320,28,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (3201,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3201,401,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3201,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3201,601,94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3201,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3201,606,1.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3205,203,10.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3205,204,7.05,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3205,205,74.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3205,207,2.95,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3205,208,402,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3205,255,5.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3205,269,11.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3205,291,7.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3205,301,286,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3205,303,14.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3205,306,346,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3205,307,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3205,320,4,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3205,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3205,401,2.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3205,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3205,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3205,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3205,606,1.572,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3206,203,6.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3206,204,12.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3206,205,73.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3206,207,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3206,208,435,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3206,255,5.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3206,269,24.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3206,291,3.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3206,301,83,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3206,303,2.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3206,306,425,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3206,307,9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3206,320,117,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3206,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3206,401,1.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3206,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3206,601,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3206,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3206,606,2.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3209,203,8.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3209,204,19.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3209,205,66.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3209,207,3.15,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3209,208,477,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3209,255,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3209,269,13,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3209,291,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3209,301,41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3209,303,4.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3209,306,245,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3209,307,633,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3209,320,179,'100g',2,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (3209,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3209,401,50.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3209,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3209,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3209,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3209,606,1.966,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3211,203,25.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3211,204,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3211,205,57.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3211,207,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3211,208,374,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3211,255,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3211,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3211,291,7.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3211,301,751,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3211,303,47.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3211,306,1330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3211,307,104,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3211,320,3,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (3211,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3211,401,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3211,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3211,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3211,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3211,606,0.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3212,203,8.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3212,204,4.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3212,205,79.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3212,207,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3212,208,404,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3212,255,4.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3212,269,16.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3212,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3212,301,691,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3212,303,47.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3212,306,769,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3212,307,0,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3212,320,1,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3212,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3212,401,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3212,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3212,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3212,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3212,606,0.978,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3213,203,11.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3213,204,13.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3213,205,67.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3213,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3213,208,433,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3213,255,5.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3213,269,24.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3213,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3213,301,101,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3213,303,4.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3213,306,501,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3213,307,300,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3213,320,6,'100g',2,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (3213,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3213,401,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3213,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3213,601,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3213,605,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3213,606,2.352,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3214,203,7.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3214,204,10,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3214,205,75.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3214,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3214,208,424,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3214,255,5.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3214,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3214,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3214,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3214,303,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3214,306,156,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3214,307,319,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3214,320,0,'100g',2,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (3214,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3214,401,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3214,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3214,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3214,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3214,606,1.048,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3215,203,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3215,204,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3215,205,82.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3215,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3215,208,397,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3215,255,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3215,269,3.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3215,291,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3215,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3215,303,3.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3215,306,137,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3215,307,269,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3215,320,0,'100g',2,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (3215,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3215,401,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3215,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3215,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3215,605,0.002,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3215,606,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3220,203,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3220,204,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3220,205,19.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3220,207,0.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3220,208,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3220,255,79.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3220,269,17.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3220,291,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3220,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3220,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3220,306,33,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3220,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3220,320,2,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (3220,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3220,401,21.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3220,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3220,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3220,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3220,606,0.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3221,203,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3221,204,0.16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3221,205,19.18,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3221,207,0.14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3221,208,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3221,255,80.32,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3221,269,17.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3221,291,1.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3221,301,3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3221,303,0.11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3221,306,67,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3221,307,3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3221,320,1,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3221,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3221,401,18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3221,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3221,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3221,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3221,606,0.025,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3222,203,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3222,204,0.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3222,205,19.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3222,207,0.19,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3222,208,78,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3222,255,79.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3222,269,10.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3222,291,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3222,301,5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3222,303,0.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3222,306,45,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3222,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3222,320,2,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3222,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3222,401,9.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3222,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3222,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3222,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3222,606,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3224,203,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3224,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3224,205,17.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3224,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3224,208,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3224,255,81.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3224,269,9.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3224,291,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3224,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3224,303,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3224,306,34,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3224,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3224,320,18,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3224,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3224,401,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3224,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3224,601,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3224,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3224,606,0.087,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3225,203,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3225,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3225,205,18.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3225,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3225,208,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3225,255,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3225,269,16.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3225,291,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3225,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3225,303,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3225,306,33,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3225,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3225,320,18,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3225,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3225,401,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3225,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3225,601,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3225,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3225,606,0.058,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3226,203,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3226,204,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3226,205,17.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3226,207,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3226,208,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3226,255,79.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3226,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3226,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3226,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3226,303,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3226,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3226,307,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3226,320,6,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (3226,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3226,401,9.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3226,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3226,601,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3226,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3226,606,0.545,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3227,203,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3227,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3227,205,17.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3227,207,0.24,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3227,208,65,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3227,255,81.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3227,269,10.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3227,291,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3227,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3227,303,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3227,306,54,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3227,307,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3227,320,7,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3227,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3227,401,20.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3227,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3227,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3227,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3227,606,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3228,203,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3228,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3228,205,18.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3228,207,0.24,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3228,208,67,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3228,255,81.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3228,269,11.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3228,291,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3228,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3228,303,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3228,306,56,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3228,307,0,'100g',4,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3228,320,7,'100g',2,1,'2024-12-12','2004-01-08');
INSERT INTO `cndb_nutval` VALUES (3228,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3228,401,20.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3228,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3228,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3228,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3228,606,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3233,203,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3233,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3233,205,20.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3233,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3233,208,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3233,255,77.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3233,269,10.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3233,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3233,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3233,303,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3233,306,81,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3233,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3233,320,11,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3233,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3233,401,27.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3233,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3233,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3233,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3233,606,0.099,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3235,203,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3235,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3235,205,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3235,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3235,208,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3235,255,83.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3235,269,12.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3235,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3235,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3235,303,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3235,306,94,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3235,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3235,320,7,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3235,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3235,401,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3235,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3235,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3235,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3235,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3236,203,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3236,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3236,205,17.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3236,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3236,208,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3236,255,82.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3236,269,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3236,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3236,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3236,303,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3236,306,95,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3236,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3236,320,7,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3236,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3236,401,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3236,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3236,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3236,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3236,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3245,203,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3245,204,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3245,205,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3245,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3245,208,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3245,255,79.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3245,269,11.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3245,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3245,301,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3245,303,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3245,306,66,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3245,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3245,320,18,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3245,328,0.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3245,401,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3245,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3245,601,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3245,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3245,606,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3246,203,1.76,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3246,204,0.98,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3246,205,17.58,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3246,207,0.37,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3246,208,86,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3246,255,79.31,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3246,269,12.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3246,291,0.2,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3246,301,54,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3246,303,0.22,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3246,306,68,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3246,307,26,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3246,320,13,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (3246,328,0.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3246,401,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3246,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3246,601,38,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3246,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3246,606,0.325,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3265,203,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3265,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3265,205,11.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3265,207,0.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3265,208,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3265,255,88.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3265,269,10.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3265,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3265,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3265,303,0.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3265,306,90,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3265,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3265,320,0,'100g',2,1,'2024-12-12','2004-01-08');
INSERT INTO `cndb_nutval` VALUES (3265,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3265,401,31.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3265,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3265,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3265,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3265,606,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3267,203,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3267,204,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3267,205,12.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3267,207,0.52,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3267,208,52,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3267,255,86.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3267,269,10.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3267,291,0.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3267,301,64,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3267,303,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3267,306,86,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3267,307,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3267,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3267,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3267,401,21.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3267,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3267,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3267,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3267,606,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3269,203,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3269,204,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3269,205,11.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3269,207,0.48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3269,208,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3269,255,88.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3269,269,9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3269,291,0.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3269,301,127,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3269,303,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3269,306,92,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3269,307,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3269,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3269,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3269,401,21.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3269,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3269,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3269,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3269,606,0.018,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3274,203,2.04,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3274,204,1.12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3274,205,8.66,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3274,207,0.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3274,208,53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3274,255,87.76,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3274,269,1.46,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3274,291,1.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3274,301,27,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3274,303,0.33,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3274,306,83,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3274,307,34,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3274,320,131,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3274,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3274,401,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3274,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3274,601,7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3274,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3274,606,0.302,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3279,203,1.01,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3279,204,0.11,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3279,205,7.88,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3279,207,0.4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3279,208,34,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3279,255,90.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3279,269,3.08,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3279,291,1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3279,301,17,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3279,303,0.31,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3279,306,112,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3279,307,40,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3279,320,462,'100g',2,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (3279,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3279,401,3.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3279,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3279,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3279,605,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3279,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3280,203,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3280,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3280,205,17.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3280,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3280,208,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3280,255,81.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3280,269,7.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3280,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3280,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3280,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3280,306,108,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3280,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3280,320,2,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3280,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3280,401,25.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3280,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3280,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3280,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3280,606,0.076,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3282,203,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3282,204,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3282,205,8.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3282,207,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3282,208,36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3282,255,89.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3282,269,1.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3282,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3282,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3282,303,0.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3282,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3282,307,36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3282,320,210,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3282,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3282,401,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3282,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3282,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3282,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3282,606,0.079,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3283,203,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3283,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3283,205,6.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3283,207,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3283,208,32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3283,255,90,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3283,269,2.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3283,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3283,301,28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3283,303,0.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3283,306,168,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3283,307,31,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3283,320,303,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3283,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3283,401,5.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3283,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3283,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3283,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3283,606,0.035,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3286,203,1,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (3286,204,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3286,205,8.25,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (3286,207,0.45,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3286,208,36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3286,255,89.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3286,269,1.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3286,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3286,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3286,303,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3286,306,127,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3286,307,0,'100g',4,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (3286,320,158,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (3286,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3286,401,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3286,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3286,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3286,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (3286,606,0.089,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3287,203,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3287,204,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3287,205,7.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3287,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3287,208,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3287,255,87.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3287,269,1.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3287,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3287,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3287,303,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3287,306,46,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3287,307,26,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3287,320,33,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3287,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3287,401,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3287,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3287,601,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3287,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3287,606,0.766,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3289,203,2.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3289,204,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3289,205,10.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3289,207,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3289,208,62,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3289,255,85.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3289,269,7.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3289,291,1.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3289,301,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3289,303,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3289,306,120,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3289,307,9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3289,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3289,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3289,401,0.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3289,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3289,601,8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3289,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3289,606,0.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3290,203,3.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3290,204,2.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3290,205,5.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3290,207,0.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3290,208,59,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3290,255,87.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3290,269,2.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3290,291,2.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3290,301,22,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3290,303,0.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3290,306,226,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3290,307,69,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3290,320,723,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (3290,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3290,401,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3290,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3290,601,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3290,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3290,606,0.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3293,203,1.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3293,204,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3293,205,12.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3293,207,0.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3293,208,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3293,255,85.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3293,269,9.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3293,291,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3293,301,3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3293,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3293,306,265,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3293,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3293,320,7,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (3293,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3293,401,12.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3293,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3293,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3293,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3293,606,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3296,203,3.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3296,204,1.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3296,205,7.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3296,207,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3296,208,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3296,255,86.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3296,269,1.12,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (3296,291,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3296,301,11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3296,303,0.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3296,306,107,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3296,307,176,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3296,320,113,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (3296,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3296,401,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3296,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3296,601,7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3296,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3296,606,0.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3297,203,2.16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3297,204,1.38,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3297,205,10.88,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3297,207,0.18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3297,208,65,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3297,255,85.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3297,269,6.06,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3297,291,1.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3297,301,18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3297,303,0.38,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3297,306,95,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3297,307,12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3297,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (3297,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3297,401,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3297,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3297,601,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3297,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3297,606,0.347,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3298,203,3.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3298,204,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3298,205,6.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3298,207,0.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3298,208,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3298,255,86.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3298,269,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3298,291,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3298,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3298,303,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3298,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3298,307,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3298,320,24,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (3298,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3298,401,17.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3298,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3298,601,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3298,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3298,606,0.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3303,203,2.51,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3303,204,2.17,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3303,205,11.04,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3303,207,0.58,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3303,208,74,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3303,255,83.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3303,269,2.65,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3303,291,1.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3303,301,30,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3303,303,0.45,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3303,306,200,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3303,307,22,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3303,320,216,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3303,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3303,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3303,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3303,601,11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3303,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3303,606,0.572,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3681,203,3.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3681,204,3.26,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3681,205,9.94,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3681,207,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3681,208,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3681,255,82.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3681,269,5.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3681,291,0.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3681,301,162,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3681,303,3.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3681,306,151,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3681,307,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3681,320,43,'100g',4,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (3681,328,1.2,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3681,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3681,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3681,601,10,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3681,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3681,606,1.76,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3685,203,4.14,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3685,204,3.38,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3685,205,12.3,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3685,207,0.96,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3685,208,96,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3685,255,79.21,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3685,269,4.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3685,291,0.8,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3685,301,220,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3685,303,10.43,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3685,306,166,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3685,307,42,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3685,320,41,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (3685,328,1.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3685,401,0.3,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3685,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3685,601,9,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3685,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3685,606,1.745,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3686,203,3.82,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3686,204,3.46,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3686,205,10,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3686,207,0.92,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3686,208,86,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3686,255,81.81,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3686,269,5.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3686,291,0.4,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3686,301,153,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3686,303,3.63,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3686,306,178,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3686,307,48,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3686,320,43,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (3686,328,1.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3686,401,0.4,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3686,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3686,601,10,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3686,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3686,606,1.808,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3689,203,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3689,204,4.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3689,205,15.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3689,207,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3689,208,116,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3689,255,74.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3689,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3689,291,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3689,301,220,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3689,303,12.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3689,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3689,307,46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3689,320,22,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (3689,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3689,401,1.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3689,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3689,601,11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3689,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3689,606,2.258,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (3690,203,3.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3690,204,3.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3690,205,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3690,207,0.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3690,208,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3690,255,81.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3690,269,5.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3690,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3690,301,153,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3690,303,3.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3690,306,178,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3690,307,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3690,320,43,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (3690,328,1.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3690,401,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3690,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3690,601,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3690,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3690,606,1.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3694,203,3.45,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3694,204,3.38,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3694,205,10.31,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3694,207,0.89,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3694,208,85,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3694,255,81.96,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3694,269,4.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3694,291,0,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3694,301,168,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3694,303,3.63,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3694,306,151,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3694,307,42,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3694,320,42,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (3694,328,1.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3694,401,0.2,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3694,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3694,601,10,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3694,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3694,606,1.793,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3712,203,3.57,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3712,204,3.32,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3712,205,10.49,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3712,207,0.81,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3712,208,86,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3712,255,81.81,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3712,269,6.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3712,291,0.1,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3712,301,156,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3712,303,3.63,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3712,306,180,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3712,307,47,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3712,320,43,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (3712,328,1.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3712,401,0.2,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3712,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3712,601,10,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3712,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (3712,606,1.798,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (3934,203,1.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3934,204,0.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3934,205,15.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3934,207,0.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3934,208,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3934,255,82.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3934,269,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3934,291,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3934,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3934,303,0.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3934,306,154,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3934,307,14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3934,320,126,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (3934,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3934,401,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3934,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3934,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3934,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3934,606,0.053,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3956,203,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3956,204,3.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3956,205,13.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3956,207,0.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3956,208,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3956,255,79.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3956,269,11.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3956,291,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3956,301,107,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3956,303,0.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3956,306,149,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3956,307,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3956,320,24,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (3956,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3956,401,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3956,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3956,601,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3956,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3956,606,1.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3959,203,1.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3959,204,1.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3959,205,7.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3959,207,0.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3959,208,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3959,255,88.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3959,269,1.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3959,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3959,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3959,303,0.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3959,306,118,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3959,307,176,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3959,320,13,'100g',2,1,'2024-12-12','2012-01-05');
INSERT INTO `cndb_nutval` VALUES (3959,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3959,401,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3959,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3959,601,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3959,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3959,606,0.875,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3964,203,5.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3964,204,5.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3964,205,68.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3964,207,6.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3964,208,344,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3964,255,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3964,269,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3964,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3964,301,1053,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3964,303,13.16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3964,306,180,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3964,307,157,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3964,320,14,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (3964,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3964,401,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3964,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3964,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3964,605,0.019,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (3964,606,0.453,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3965,203,3.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3965,204,3.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3965,205,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3965,207,0.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3965,208,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3965,255,80.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3965,269,11.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3965,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3965,301,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3965,303,4.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3965,306,143,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3965,307,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3965,320,22,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (3965,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3965,401,3.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3965,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3965,601,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3965,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3965,606,1.582,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3994,203,0.71,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3994,204,0.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3994,205,25.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3994,207,0.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3994,208,109,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3994,255,72.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3994,269,19.29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3994,291,1.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3994,301,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3994,303,0.14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3994,306,395,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3994,307,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3994,320,3,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (3994,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3994,401,12.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3994,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3994,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3994,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3994,606,0.121,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3995,203,1.01,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3995,204,0.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3995,205,21.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3995,207,0.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3995,208,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3995,255,76.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3995,269,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3995,291,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3995,301,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3995,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3995,306,283,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3995,307,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3995,320,3,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (3995,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3995,401,18.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3995,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (3995,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3995,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3995,606,0.081,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (3996,203,6.67,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3996,204,6.67,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3996,205,80.06,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3996,207,2.03,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3996,208,407,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3996,255,4.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3996,269,26.67,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3996,291,6.7,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3996,301,800,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3996,303,30,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3996,306,467,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3996,307,33,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3996,320,0,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (3996,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (3996,401,58.3,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (3996,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (3996,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3996,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (3996,606,1.058,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4001,203,0,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4001,204,100,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4001,205,0,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4001,207,0,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4001,208,902,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4001,255,0,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4001,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4001,291,0,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4001,301,0,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4001,303,0,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4001,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4001,307,0,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4001,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4001,328,0.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4001,401,0,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4001,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4001,601,109,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4001,605,NULL,'100g',NULL,1,'1995-06-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4001,606,49.8,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4002,203,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4002,204,100,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4002,205,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4002,207,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4002,208,902,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4002,255,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4002,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4002,291,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4002,301,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4002,303,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4002,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4002,307,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4002,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4002,328,2.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4002,401,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4002,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4002,601,95,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4002,605,NULL,'100g',NULL,1,'1995-06-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4002,606,39.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4015,203,0.69,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4015,204,26.18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4015,205,31.9,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4015,207,2.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4015,208,355,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4015,255,38.53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4015,269,17.68,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4015,291,0.7,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4015,301,13,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4015,303,0.6,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4015,306,173,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4015,307,1133,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4015,320,29,'100g',2,1,'2024-12-12','2007-01-12');
INSERT INTO `cndb_nutval` VALUES (4015,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4015,401,6,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4015,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4015,601,0,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4015,605,0.17,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (4015,606,2.39,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4016,203,3.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4016,204,45.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4016,205,8.6,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4016,207,3.9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4016,208,443,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4016,255,39.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4016,269,8.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4016,291,1,'100g',3,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4016,301,19,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4016,303,0.6,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4016,306,157,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4016,307,1000,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4016,320,2,'100g',2,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (4016,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4016,401,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4016,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4016,601,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4016,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4016,606,6.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4017,203,1.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4017,204,35.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4017,205,14.64,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4017,207,2.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4017,208,379,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4017,255,46.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4017,269,15.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4017,291,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4017,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4017,303,1.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4017,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4017,307,962,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (4017,320,14,'100g',2,1,'2024-12-12','2004-01-07');
INSERT INTO `cndb_nutval` VALUES (4017,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4017,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4017,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4017,601,26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4017,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4017,606,5.092,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4018,203,0.65,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4018,204,21.6,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4018,205,14.78,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4018,207,1.76,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4018,208,250,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4018,255,61.22,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4018,269,10.02,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4018,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4018,301,5,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4018,303,0.12,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4018,306,36,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4018,307,653,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4018,320,5,'100g',1,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (4018,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4018,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4018,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4018,601,19,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4018,605,0.078,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (4018,606,3.396,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4020,203,0.58,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4020,204,11.52,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4020,205,31.22,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4020,207,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4020,208,222,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4020,255,54.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4020,269,16.86,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4020,291,1.5,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4020,301,11,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4020,303,0.73,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4020,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4020,307,838,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4020,320,27,'100g',2,1,'2024-12-12','2007-01-12');
INSERT INTO `cndb_nutval` VALUES (4020,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4020,401,4.8,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4020,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4020,601,0,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4020,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4020,606,0.842,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4021,203,0.39,'100g',1,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4021,204,6.68,'100g',1,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4021,205,9.99,'100g',3,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4021,207,2.83,'100g',1,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4021,208,102,'100g',3,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4021,255,80.11,'100g',1,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4021,269,9.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4021,291,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4021,301,15,'100g',1,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4021,303,0.25,'100g',1,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4021,306,90,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4021,307,891,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (4021,320,1,'100g',2,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (4021,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4021,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4021,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4021,601,0,'100g',3,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4021,605,0.017,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4021,606,0.833,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4022,203,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4022,204,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4022,205,27.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4022,207,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4022,208,141,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4022,255,65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4022,269,21.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4022,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4022,301,19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4022,303,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4022,306,157,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4022,307,868,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4022,320,2,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (4022,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4022,401,6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4022,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4022,601,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4022,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4022,606,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4023,203,0.83,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4023,204,11.32,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4023,205,24.06,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4023,207,3.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4023,208,195,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4023,255,60.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4023,269,17.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4023,291,1.2,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4023,301,27,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4023,303,0.9,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4023,306,202,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4023,307,955,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4023,320,16,'100g',2,1,'2024-12-12','2007-01-12');
INSERT INTO `cndb_nutval` VALUES (4023,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4023,401,1.5,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4023,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4023,601,11,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4023,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4023,606,0.746,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4025,203,0.96,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (4025,204,74.85,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (4025,205,0.57,'100g',3,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (4025,207,1.98,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (4025,208,680,'100g',3,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (4025,255,21.65,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (4025,269,0.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4025,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4025,301,8,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (4025,303,0.21,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (4025,306,20,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4025,307,635,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (4025,320,16,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (4025,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4025,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4025,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4025,601,42,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (4025,605,0.187,'100g',3,1,'2006-01-24','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4025,606,11.703,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4026,203,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4026,204,79.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4026,205,2.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4026,207,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4026,208,717,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4026,255,15.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4026,269,0.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4026,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4026,301,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4026,303,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4026,306,34,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4026,307,568,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4026,320,84,'100g',1,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4026,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4026,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4026,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4026,601,59,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4026,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4026,606,8.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4027,203,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4027,204,19.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4027,205,16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4027,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4027,208,232,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4027,255,62.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4027,269,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4027,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4027,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4027,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4027,306,10,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4027,307,497,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4027,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (4027,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4027,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4027,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4027,601,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4027,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4027,606,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4028,203,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4028,204,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4028,205,11.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4028,207,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4028,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4028,255,79.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4028,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4028,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4028,301,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4028,303,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4028,306,97,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4028,307,504,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4028,320,4,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (4028,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4028,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4028,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4028,601,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4028,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4028,606,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4029,203,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4029,204,47.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4029,205,15.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4029,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4029,208,482,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4029,255,34.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4029,269,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4029,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4029,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4029,303,0.01,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4029,306,10,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4029,307,353,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4029,320,0,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (4029,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4029,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4029,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4029,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4029,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4029,606,7.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4030,203,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4030,204,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4030,205,22.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4030,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4030,208,389,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4030,255,40.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4030,269,15.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4030,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4030,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4030,303,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4030,306,35,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4030,307,1000,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4030,320,22,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4030,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4030,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4030,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4030,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4030,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4030,606,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4031,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4031,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4031,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4031,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4031,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4031,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4031,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4031,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4031,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4031,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4031,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4031,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4031,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4031,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4031,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4031,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4031,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4031,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4031,606,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4034,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4034,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4034,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4034,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4034,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4034,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4034,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4034,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4034,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4034,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4034,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4034,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4034,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4034,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4034,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4034,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4034,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4034,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4034,606,14.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4037,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4037,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4037,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4037,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4037,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4037,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4037,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4037,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4037,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4037,303,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4037,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4037,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4037,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4037,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4037,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4037,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4037,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4037,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4037,606,19.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4038,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4038,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4038,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4038,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4038,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4038,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4038,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4038,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4038,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4038,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4038,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4038,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4038,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4038,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4038,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4038,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4038,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4038,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4038,606,18.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4042,203,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4042,204,100,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4042,205,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4042,207,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4042,208,884,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4042,255,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4042,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4042,291,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4042,301,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4042,303,0.03,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4042,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4042,307,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4042,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4042,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4042,401,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4042,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4042,601,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4042,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4042,606,16.9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4044,203,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4044,204,100,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4044,205,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4044,207,0,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4044,208,884,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4044,255,0,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4044,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4044,291,0,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4044,301,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4044,303,0.05,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4044,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4044,307,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4044,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4044,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4044,401,0,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4044,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4044,601,0,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4044,605,0.533,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (4044,606,15.65,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4047,203,0,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4047,204,99.06,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (4047,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4047,207,0.03,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4047,208,892,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (4047,255,0.03,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4047,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4047,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4047,301,1,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4047,303,0.05,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4047,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4047,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4047,320,0,'100g',1,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (4047,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4047,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4047,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4047,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4047,605,0.028,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (4047,606,82.475,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (4053,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4053,204,100,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4053,205,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4053,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4053,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4053,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4053,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4053,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4053,301,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4053,303,0.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4053,306,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4053,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4053,320,0,'100g',3,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (4053,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4053,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4053,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4053,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4053,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4053,606,13.808,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4055,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4055,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4055,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4055,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4055,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4055,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4055,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4055,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4055,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4055,303,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4055,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4055,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4055,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4055,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4055,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4055,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4055,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4055,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4055,606,49.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4058,203,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4058,204,100,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4058,205,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4058,207,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4058,208,884,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4058,255,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4058,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4058,291,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4058,301,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4058,303,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4058,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4058,307,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4058,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4058,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4058,401,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4058,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4058,601,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4058,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4058,606,14.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4060,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4060,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4060,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4060,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4060,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4060,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4060,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4060,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4060,301,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4060,303,0.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4060,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4060,307,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4060,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4060,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4060,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4060,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4060,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4060,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4060,606,10.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4073,203,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4073,204,80.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4073,205,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4073,207,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4073,208,719,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4073,255,15.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4073,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4073,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4073,301,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4073,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4073,306,42,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4073,307,943,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4073,320,819,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4073,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4073,401,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4073,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4073,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4073,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4073,606,16.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4114,203,0.41,'100g',1,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4114,204,21.12,'100g',1,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4114,205,12.12,'100g',3,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4114,207,2.95,'100g',1,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4114,208,240,'100g',3,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4114,255,63.4,'100g',1,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4114,269,10.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4114,291,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4114,301,13,'100g',1,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4114,303,0.26,'100g',1,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4114,306,84,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4114,307,993,'100g',1,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4114,320,2,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (4114,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4114,401,0.4,'100g',3,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4114,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4114,601,0,'100g',3,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (4114,605,0.067,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4114,606,2.948,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4120,203,0.87,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4120,204,39.07,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4120,205,18.79,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4120,207,1.92,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4120,208,419,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4120,255,39.34,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4120,269,17.43,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4120,291,2.4,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4120,301,27,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4120,303,0.32,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4120,306,108,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4120,307,661,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4120,320,23,'100g',2,1,'2024-12-12','2007-01-12');
INSERT INTO `cndb_nutval` VALUES (4120,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4120,401,0,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4120,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4120,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4120,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4120,606,6.093,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4128,203,0.23,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4128,204,37.98,'100g',7,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4128,205,1.52,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4128,207,1.6,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4128,208,349,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4128,255,58.67,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4128,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4128,291,0,'100g',4,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4128,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4128,303,0.04,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4128,306,51,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4128,307,584,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4128,320,1348,'100g',2,1,'2024-12-12','2017-01-04');
INSERT INTO `cndb_nutval` VALUES (4128,328,17.5,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4128,401,0,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4128,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4128,601,0,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4128,605,0.079,'100g',3,1,'2006-02-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4128,606,8.656,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4133,203,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4133,204,70.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4133,205,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4133,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4133,208,631,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4133,255,24.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4133,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4133,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4133,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4133,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4133,306,24,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4133,307,658,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4133,320,26,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (4133,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4133,401,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4133,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4133,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4133,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4133,606,12.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4135,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4135,204,50.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4135,205,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4135,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4135,208,449,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4135,255,47.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4135,269,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4135,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4135,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4135,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4135,306,8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4135,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4135,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (4135,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4135,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4135,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4135,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4135,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4135,606,9.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4141,203,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4141,204,44.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4141,205,15.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4141,207,2.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4141,208,459,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4141,255,36.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4141,269,15.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4141,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4141,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4141,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4141,306,67,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4141,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4141,320,23,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (4141,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4141,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4141,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4141,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4141,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4141,606,5.648,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4142,203,0.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4142,204,13.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4142,205,29.28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4142,207,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4142,208,233,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4142,255,54.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4142,269,28.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4142,291,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4142,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4142,303,0.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4142,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4142,307,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4142,320,27,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (4142,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4142,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4142,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4142,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4142,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4142,606,1.099,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4143,203,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4143,204,28.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4143,205,10.43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4143,207,4.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4143,208,292,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4143,255,56.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4143,269,8.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4143,291,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4143,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4143,303,0.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4143,306,48,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4143,307,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4143,320,2,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (4143,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4143,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4143,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4143,601,67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4143,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4143,606,4.474,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4144,203,0.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4144,204,6.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4144,205,4.57,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4144,207,3.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4144,208,76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4144,255,84.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4144,269,4.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4144,291,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4144,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4144,303,0.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4144,306,85,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4144,307,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4144,320,1,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (4144,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4144,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4144,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4144,601,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4144,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4144,606,0.451,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4145,203,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4145,204,79.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4145,205,2.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4145,207,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4145,208,717,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4145,255,16.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4145,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4145,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4145,301,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4145,303,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4145,306,34,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4145,307,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4145,320,84,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (4145,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4145,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4145,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4145,601,59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4145,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4145,606,11.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4146,203,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4146,204,70.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4146,205,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4146,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4146,208,631,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4146,255,24.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4146,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4146,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4146,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4146,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4146,306,24,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4146,307,658,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4146,320,0,'100g',3,1,'2024-12-12','2002-01-07');
INSERT INTO `cndb_nutval` VALUES (4146,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4146,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4146,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4146,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4146,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4146,606,18.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4367,203,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4367,204,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4367,205,32.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4367,207,2.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4367,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4367,255,65.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4367,269,16.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4367,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4367,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4367,303,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4367,306,84,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4367,307,853,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4367,320,4,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (4367,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4367,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4367,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4367,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4367,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4367,606,0.037,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4501,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4501,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4501,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4501,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4501,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4501,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4501,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4501,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4501,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4501,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4501,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4501,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4501,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4501,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4501,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4501,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4501,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4501,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4501,606,59.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4502,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4502,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4502,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4502,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4502,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4502,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4502,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4502,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4502,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4502,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4502,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4502,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4502,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4502,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4502,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4502,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4502,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4502,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4502,606,25.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4506,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4506,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4506,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4506,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4506,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4506,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4506,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4506,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4506,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4506,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4506,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4506,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4506,320,0,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (4506,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4506,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4506,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4506,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4506,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4506,606,10.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4510,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4510,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4510,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4510,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4510,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4510,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4510,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4510,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4510,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4510,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4510,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4510,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4510,320,0,'100g',2,1,'2024-12-12','2002-01-12');
INSERT INTO `cndb_nutval` VALUES (4510,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4510,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4510,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4510,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4510,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4510,606,6.203,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4511,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4511,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4511,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4511,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4511,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4511,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4511,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4511,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4511,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4511,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4511,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4511,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4511,320,0,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (4511,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4511,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4511,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4511,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4511,605,0.096,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (4511,606,7.541,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4513,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4513,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4513,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4513,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4513,208,862,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4513,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4513,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4513,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4513,301,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4513,303,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4513,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4513,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4513,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4513,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4513,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4513,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4513,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4513,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4513,606,81.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4514,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4514,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4514,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4514,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4514,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4514,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4514,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4514,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4514,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4514,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4514,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4514,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4514,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4514,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4514,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4514,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4514,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4514,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4514,606,13.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4515,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4515,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4515,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4515,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4515,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4515,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4515,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4515,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4515,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4515,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4515,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4515,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4515,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4515,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4515,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4515,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4515,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4515,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4515,606,19.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4516,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4516,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4516,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4516,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4516,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4516,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4516,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4516,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4516,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4516,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4516,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4516,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4516,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4516,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4516,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4516,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4516,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4516,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4516,606,21.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4517,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4517,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4517,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4517,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4517,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4517,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4517,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4517,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4517,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4517,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4517,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4517,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4517,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4517,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4517,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4517,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4517,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4517,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4517,606,9.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4518,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4518,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4518,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4518,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4518,208,900,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (4518,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4518,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4518,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4518,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4518,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4518,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4518,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4518,320,0,'100g',1,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (4518,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4518,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4518,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4518,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4518,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (4518,606,12.948,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4528,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4528,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4528,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4528,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4528,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4528,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4528,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4528,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4528,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4528,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4528,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4528,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4528,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4528,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4528,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4528,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4528,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4528,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4528,606,9.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4529,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4529,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4529,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4529,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4529,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4529,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4529,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4529,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4529,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4529,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4529,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4529,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4529,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4529,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4529,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4529,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4529,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4529,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4529,606,8.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4530,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4530,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4530,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4530,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4530,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4530,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4530,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4530,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4530,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4530,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4530,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4530,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4530,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4530,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4530,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4530,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4530,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4530,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4530,606,6.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4531,203,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4531,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4531,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4531,207,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4531,208,763,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4531,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4531,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4531,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4531,301,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4531,303,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4531,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4531,307,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4531,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4531,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4531,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4531,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4531,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4531,605,NULL,'100g',NULL,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (4531,606,15.005,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4532,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4532,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4532,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4532,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4532,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4532,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4532,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4532,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4532,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4532,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4532,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4532,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4532,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4532,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4532,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4532,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4532,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4532,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4532,606,7.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4534,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4534,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4534,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4534,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4534,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4534,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4534,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4534,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4534,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4534,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4534,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4534,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4534,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4534,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4534,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4534,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4534,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4534,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4534,606,81.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4536,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4536,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4536,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4536,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4536,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4536,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4536,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4536,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4536,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4536,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4536,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4536,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4536,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4536,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4536,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4536,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4536,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4536,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4536,606,46.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4539,203,1.37,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4539,204,51.1,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4539,205,4.77,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4539,207,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4539,208,484,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4539,255,39.71,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4539,269,3.48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4539,291,0.4,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4539,301,37,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4539,303,0.09,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4539,306,88,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4539,307,642,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (4539,320,14,'100g',2,1,'2024-12-12','2013-01-06');
INSERT INTO `cndb_nutval` VALUES (4539,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4539,401,0.7,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4539,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4539,601,31,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4539,605,1.34,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (4539,606,8.275,'100g',6,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4541,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4541,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4541,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4541,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4541,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4541,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4541,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4541,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4541,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4541,303,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4541,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4541,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4541,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4541,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4541,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4541,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4541,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4541,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4541,606,53.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4542,203,0,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4542,204,99.8,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4542,205,0,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4542,207,0,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4542,208,900,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4542,255,0.2,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4542,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4542,291,0,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4542,301,0,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4542,303,0,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4542,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4542,307,0,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4542,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4542,328,4.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4542,401,0,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4542,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4542,601,85,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4542,605,NULL,'100g',NULL,1,'1994-07-01','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4542,606,29.8,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4543,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4543,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4543,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4543,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4543,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4543,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4543,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4543,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4543,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4543,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4543,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4543,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4543,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4543,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4543,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4543,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4543,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4543,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4543,606,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4544,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4544,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4544,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4544,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4544,208,900,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4544,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4544,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4544,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4544,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4544,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4544,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4544,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4544,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (4544,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4544,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4544,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4544,601,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4544,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4544,606,40.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4545,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4545,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4545,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4545,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4545,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4545,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4545,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4545,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4545,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4545,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4545,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4545,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4545,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4545,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4545,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4545,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4545,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4545,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4545,606,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4546,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4546,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4546,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4546,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4546,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4546,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4546,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4546,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4546,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4546,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4546,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4546,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4546,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4546,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4546,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4546,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4546,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4546,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4546,606,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4548,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4548,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4548,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4548,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4548,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4548,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4548,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4548,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4548,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4548,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4548,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4548,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4548,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4548,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4548,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4548,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4548,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4548,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4548,606,27.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4549,203,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4549,204,100,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4549,205,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4549,207,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4549,208,900,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4549,255,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4549,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4549,291,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4549,301,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4549,303,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4549,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4549,307,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4549,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4549,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4549,401,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4549,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4549,601,56,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4549,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4549,606,35.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4550,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4550,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4550,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4550,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4550,208,900,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4550,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4550,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4550,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4550,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4550,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4550,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4550,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4550,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4550,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4550,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4550,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4550,601,100,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4550,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4550,606,44.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4551,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4551,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4551,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4551,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4551,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4551,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4551,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4551,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4551,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4551,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4551,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4551,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4551,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4551,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4551,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4551,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4551,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4551,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4551,606,91.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4554,203,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4554,204,100,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4554,205,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4554,207,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4554,208,884,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4554,255,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4554,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4554,291,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4554,301,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4554,303,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4554,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4554,307,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4554,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4554,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4554,401,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4554,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4554,601,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4554,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4554,606,25.6,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4556,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4556,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4556,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4556,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4556,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4556,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4556,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4556,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4556,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4556,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4556,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4556,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4556,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4556,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4556,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4556,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4556,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4556,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4556,606,47.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4559,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4559,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4559,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4559,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4559,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4559,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4559,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4559,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4559,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4559,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4559,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4559,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4559,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4559,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4559,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4559,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4559,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4559,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4559,606,25.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4560,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4560,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4560,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4560,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4560,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4560,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4560,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4560,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4560,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4560,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4560,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4560,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4560,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4560,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4560,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4560,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4560,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4560,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4560,606,21.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4570,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4570,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4570,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4570,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4570,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4570,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4570,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4570,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4570,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4570,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4570,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4570,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4570,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4570,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4570,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4570,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4570,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4570,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4570,606,65.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4572,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4572,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4572,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4572,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4572,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4572,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4572,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4572,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4572,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4572,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4572,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4572,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4572,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4572,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4572,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4572,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4572,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4572,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4572,606,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4573,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4573,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4573,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4573,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4573,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4573,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4573,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4573,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4573,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4573,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4573,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4573,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4573,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4573,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4573,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4573,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4573,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4573,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4573,606,85.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4575,203,0,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4575,204,99.8,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4575,205,0,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4575,207,0,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4575,208,900,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4575,255,0.2,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4575,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4575,291,0,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4575,301,0,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4575,303,0,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4575,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4575,307,0,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4575,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4575,328,4.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4575,401,0,'100g',3,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4575,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4575,601,102,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4575,605,NULL,'100g',NULL,1,'1994-07-01','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4575,606,29.4,'100g',1,1,'1994-05-19','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4576,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4576,204,99.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4576,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4576,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4576,208,900,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4576,255,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4576,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4576,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4576,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4576,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4576,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4576,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4576,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4576,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4576,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4576,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4576,601,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4576,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4576,606,27.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4581,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4581,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4581,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4581,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4581,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4581,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4581,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4581,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4581,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4581,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4581,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4581,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4581,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4581,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4581,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4581,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4581,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4581,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4581,606,11.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4582,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4582,204,100,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4582,205,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4582,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4582,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4582,255,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4582,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4582,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4582,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4582,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4582,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4582,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4582,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (4582,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4582,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4582,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4582,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4582,605,0.395,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4582,606,7.365,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4583,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4583,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4583,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4583,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4583,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4583,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4583,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4583,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4583,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4583,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4583,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4583,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4583,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4583,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4583,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4583,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4583,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4583,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4583,606,11.582,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4584,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4584,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4584,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4584,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4584,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4584,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4584,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4584,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4584,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4584,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4584,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4584,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4584,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4584,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4584,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4584,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4584,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4584,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4584,606,9.859,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4585,203,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4585,204,80.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4585,205,0.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4585,207,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4585,208,727,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4585,255,17.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4585,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4585,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4585,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4585,303,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4585,306,22,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4585,307,719,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4585,320,819,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (4585,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4585,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4585,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4585,601,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4585,605,14.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4585,606,14.198,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4586,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4586,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4586,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4586,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4586,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4586,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4586,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4586,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4586,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4586,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4586,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4586,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4586,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4586,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4586,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4586,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4586,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4586,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4586,606,20.001,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4587,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4587,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4587,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4587,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4587,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4587,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4587,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4587,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4587,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4587,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4587,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4587,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4587,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4587,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4587,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4587,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4587,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4587,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4587,606,28.843,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4588,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4588,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4588,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4588,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4588,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4588,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4588,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4588,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4588,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4588,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4588,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4588,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4588,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4588,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4588,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4588,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4588,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4588,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4588,606,19.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4589,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4589,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4589,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4589,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4589,208,902,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4589,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4589,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4589,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4589,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4589,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4589,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4589,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4589,320,30000,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4589,328,250,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4589,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4589,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4589,601,570,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4589,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4589,606,22.608,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4590,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4590,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4590,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4590,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4590,208,902,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4590,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4590,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4590,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4590,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4590,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4590,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4590,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4590,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4590,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4590,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4590,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4590,601,766,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4590,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4590,606,21.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4591,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4591,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4591,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4591,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4591,208,902,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4591,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4591,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4591,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4591,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4591,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4591,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4591,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4591,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4591,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4591,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4591,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4591,601,521,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4591,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4591,606,30.427,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4592,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4592,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4592,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4592,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4592,208,902,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4592,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4592,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4592,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4592,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4592,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4592,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4592,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4592,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4592,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4592,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4592,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4592,601,500,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4592,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4592,606,95.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4593,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4593,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4593,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4593,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4593,208,902,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4593,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4593,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4593,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4593,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4593,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4593,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4593,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4593,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4593,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4593,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4593,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4593,601,485,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4593,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4593,606,19.872,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4594,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4594,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4594,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4594,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4594,208,902,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4594,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4594,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4594,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4594,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4594,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4594,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4594,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4594,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4594,328,8.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4594,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4594,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4594,601,710,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4594,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4594,606,29.892,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4595,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4595,204,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4595,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4595,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4595,208,884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4595,255,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4595,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4595,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4595,301,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4595,303,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4595,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4595,307,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4595,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (4595,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4595,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4595,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4595,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4595,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (4595,606,30.423,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4600,203,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4600,204,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4600,205,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4600,207,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4600,208,362,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4600,255,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4600,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4600,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4600,301,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4600,303,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4600,306,36,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4600,307,786,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4600,320,819,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (4600,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4600,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4600,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4600,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4600,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4600,606,7.238,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4601,203,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4601,204,55.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4601,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4601,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4601,208,499,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (4601,255,42.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4601,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4601,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4601,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4601,303,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4601,306,71,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4601,307,450,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4601,320,465,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4601,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4601,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4601,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4601,601,106,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4601,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4601,606,34.321,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4602,203,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4602,204,55.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4602,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4602,207,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4602,208,499,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4602,255,43.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4602,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4602,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4602,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4602,303,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4602,306,71,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4602,307,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4602,320,465,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4602,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4602,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4602,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4602,601,106,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4602,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4602,606,34.321,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4609,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4609,204,99.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4609,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4609,207,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4609,208,897,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4609,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4609,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4609,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4609,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4609,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4609,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4609,307,150,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4609,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4609,328,2.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4609,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4609,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4609,601,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4609,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4609,606,39.004,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4610,203,0.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4610,204,80.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4610,205,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4610,207,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4610,208,717,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4610,255,16.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4610,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4610,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4610,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4610,303,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4610,306,18,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4610,307,751,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4610,320,819,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4610,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4610,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4610,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4610,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4610,605,14.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4610,606,15.189,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4611,203,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4611,204,80.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4611,205,0.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4611,207,1.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4611,208,713,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4611,255,17.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4611,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4611,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4611,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4611,303,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4611,306,17,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4611,307,657,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4611,320,819,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4611,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4611,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4611,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4611,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4611,605,5.827,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4611,606,14.224,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4612,203,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4612,204,60.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4612,205,0.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4612,207,1.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4612,208,537,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4612,255,36.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4612,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4612,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4612,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4612,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4612,306,30,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4612,307,785,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4612,320,819,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (4612,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4612,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4612,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4612,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4612,605,12.731,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4612,606,10.884,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4613,203,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4613,204,59.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4613,205,0.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4613,207,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4613,208,533,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4613,255,37.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4613,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4613,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4613,301,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4613,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4613,306,30,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4613,307,615,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4613,320,819,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (4613,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4613,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4613,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4613,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4613,605,3.664,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4613,606,12.086,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4614,203,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4614,204,59.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4614,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4614,207,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4614,208,526,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4614,255,38.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4614,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4614,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4614,301,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4614,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4614,306,30,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4614,307,700,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4614,320,819,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (4614,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4614,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4614,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4614,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4614,605,7.374,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4614,606,10.042,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4615,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4615,204,99.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4615,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4615,207,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4615,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4615,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4615,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4615,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4615,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4615,303,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4615,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4615,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4615,320,0,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (4615,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4615,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4615,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4615,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4615,605,13.164,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4615,606,24.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4617,203,0.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4617,204,80.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4617,205,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4617,207,1.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4617,208,717,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4617,255,16.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4617,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4617,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4617,301,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4617,303,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4617,306,18,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4617,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4617,320,819,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4617,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4617,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4617,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4617,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4617,605,14.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4617,606,15.189,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4618,203,0.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4618,204,80.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4618,205,0.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4618,207,1.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4618,208,713,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4618,255,17.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4618,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4618,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4618,301,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4618,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4618,306,17,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4618,307,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4618,320,819,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (4618,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4618,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4618,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4618,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4618,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4618,606,14.224,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4620,203,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4620,204,59.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4620,205,0.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4620,207,1.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4620,208,533,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4620,255,37.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4620,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4620,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4620,301,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4620,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4620,306,30,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4620,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4620,320,819,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (4620,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4620,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4620,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4620,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4620,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4620,606,12.086,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4624,203,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4624,204,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4624,205,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4624,207,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4624,208,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4624,255,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4624,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4624,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4624,301,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4624,303,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4624,306,50,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4624,307,833,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4624,320,819,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (4624,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4624,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4624,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4624,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4624,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4624,606,0.416,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4626,203,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4626,204,70,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4626,205,0.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4626,207,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4626,208,630,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4626,255,28,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4626,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4626,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4626,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4626,303,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4626,306,25,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4626,307,590,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4626,320,819,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4626,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4626,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4626,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4626,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4626,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4626,606,13.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4627,203,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4627,204,35,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4627,205,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4627,207,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4627,208,330,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4627,255,59,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4627,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4627,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4627,301,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4627,303,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4627,306,64,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4627,307,630,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4627,320,819,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (4627,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4627,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4627,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4627,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4627,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4627,606,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4628,203,0.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4628,204,80.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4628,205,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4628,207,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4628,208,717,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4628,255,16.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4628,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4628,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4628,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4628,303,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4628,306,18,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4628,307,654,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4628,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (4628,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4628,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4628,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4628,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4628,605,14.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4628,606,15.189,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4629,203,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4629,204,70.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4629,205,1.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4629,207,1.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4629,208,628,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4629,255,26.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4629,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4629,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4629,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4629,303,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4629,306,46,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4629,307,700,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4629,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (4629,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4629,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4629,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4629,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4629,605,14.786,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4629,606,13.631,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4630,203,0.27,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4630,204,44.46,'100g',7,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4630,205,0,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4630,207,1.82,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4630,208,401,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4630,255,54.38,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4630,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4630,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4630,301,2,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4630,303,0.06,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4630,306,17,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4630,307,716,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4630,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (4630,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4630,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4630,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4630,601,NULL,'100g',NULL,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4630,605,0.562,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4630,606,11.055,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (4631,203,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4631,204,3.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4631,205,4.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4631,207,1.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4631,208,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4631,255,90.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4631,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4631,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4631,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4631,303,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4631,306,36,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4631,307,580,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4631,320,993,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (4631,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4631,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4631,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4631,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4631,605,0.168,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4631,606,2.128,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4633,203,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4633,204,19.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4633,205,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4633,207,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4633,208,175,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4633,255,78.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4633,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4633,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4633,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4633,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4633,306,25,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4633,307,733,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4633,320,819,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (4633,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4633,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4633,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4633,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4633,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4633,606,2.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4634,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4634,204,19.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4634,205,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4634,207,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4634,208,175,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4634,255,78.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4634,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4634,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4634,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4634,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4634,306,25,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4634,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4634,320,819,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (4634,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4634,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4634,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4634,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4634,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4634,606,2.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4635,203,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4635,204,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4635,205,29.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4635,207,2.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4635,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4635,255,66.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4635,269,16.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4635,291,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4635,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4635,303,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4635,306,122,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4635,307,788,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4635,320,1,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (4635,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4635,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4635,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4635,601,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4635,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4635,606,0.198,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4636,203,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4636,204,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4636,205,8.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4636,207,3.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4636,208,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4636,255,85.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4636,269,8.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4636,291,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4636,301,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4636,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4636,306,102,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4636,307,1129,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4636,320,4,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (4636,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4636,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4636,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4636,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4636,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4636,606,0.295,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4638,203,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4638,204,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4638,205,26.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4638,207,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4638,208,119,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4638,255,68.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4638,269,5.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4638,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4638,301,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4638,303,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4638,306,111,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4638,307,897,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4638,320,1,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (4638,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4638,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4638,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4638,601,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4638,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4638,606,0.447,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4639,203,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4639,204,44.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4639,205,5.9,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (4639,207,2.55,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (4639,208,430,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (4639,255,45.68,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (4639,269,4.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4639,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4639,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4639,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4639,306,64,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4639,307,901,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4639,320,15,'100g',1,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4639,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4639,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4639,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4639,601,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4639,605,0.182,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4639,606,6.964,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4640,203,1.25,'100g',7,1,'2004-07-15','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4640,204,12.42,'100g',7,1,'2004-07-15','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4640,205,21.33,'100g',3,1,'2004-07-15','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4640,207,2.96,'100g',1,1,'2004-07-15','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4640,208,196,'100g',3,1,'2004-07-15','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4640,255,62.04,'100g',1,1,'2004-07-15','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4640,269,3.77,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4640,291,1.1,'100g',7,1,'2004-07-15','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4640,301,40,'100g',7,1,'2004-07-15','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4640,303,0.69,'100g',7,1,'2004-07-15','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4640,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4640,307,1120,'100g',3,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4640,320,18,'100g',2,1,'2024-12-12','2007-01-12');
INSERT INTO `cndb_nutval` VALUES (4640,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4640,401,0.6,'100g',7,1,'2004-07-15','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4640,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4640,601,16,'100g',7,1,'2004-07-15','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4640,605,0.059,'100g',3,1,'2006-01-24','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4640,606,1.25,'100g',3,1,'2004-07-15','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (4641,203,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4641,204,22.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4641,205,9.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4641,207,2.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4641,208,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4641,255,66.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4641,269,3.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4641,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4641,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4641,303,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4641,306,31,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4641,307,827,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4641,320,8,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (4641,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4641,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4641,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4641,601,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4641,605,0.056,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4641,606,3.446,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4642,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4642,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4642,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4642,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4642,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4642,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4642,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4642,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4642,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4642,303,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4642,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4642,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4642,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4642,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4642,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4642,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4642,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4642,605,0.219,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4642,606,9.009,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4643,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4643,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4643,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4643,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4643,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4643,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4643,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4643,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4643,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4643,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4643,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4643,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4643,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4643,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4643,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4643,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4643,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4643,605,1.618,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4643,606,7.615,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4644,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4644,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4644,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4644,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4644,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4644,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4644,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4644,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4644,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4644,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4644,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4644,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4644,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (4644,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4644,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4644,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4644,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4644,605,1.771,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4644,606,7.758,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4645,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4645,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4645,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4645,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4645,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4645,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4645,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4645,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4645,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4645,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4645,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4645,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4645,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (4645,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4645,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4645,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4645,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4645,605,27.017,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4645,606,10.117,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4646,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4646,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4646,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4646,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4646,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4646,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4646,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4646,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4646,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4646,303,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4646,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4646,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4646,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4646,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4646,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4646,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4646,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4646,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4646,606,86.002,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4648,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4648,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4648,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4648,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4648,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4648,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4648,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4648,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4648,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4648,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4648,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4648,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4648,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4648,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4648,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4648,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4648,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4648,605,13.555,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4648,606,17.683,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4649,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4649,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4649,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4649,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4649,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4649,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4649,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4649,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4649,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4649,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4649,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4649,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4649,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4649,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4649,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4649,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4649,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4649,605,12.574,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4649,606,18.358,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4650,203,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4650,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4650,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4650,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4650,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4650,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4650,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4650,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4650,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4650,303,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4650,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4650,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4650,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4650,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4650,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4650,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4650,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4650,605,0.124,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4650,606,15.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4651,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4651,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4651,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4651,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4651,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4651,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4651,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4651,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4651,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4651,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4651,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4651,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4651,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4651,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4651,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4651,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4651,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4651,605,12.927,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4651,606,18.101,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4652,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4652,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4652,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4652,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4652,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4652,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4652,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4652,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4652,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4652,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4652,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4652,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4652,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4652,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4652,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4652,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4652,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4652,605,34.162,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4652,606,24.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4653,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4653,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4653,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4653,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4653,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4653,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4653,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4653,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4653,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4653,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4653,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4653,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4653,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4653,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4653,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4653,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4653,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4653,605,10.755,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4653,606,15.341,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4654,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4654,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4654,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4654,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4654,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4654,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4654,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4654,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4654,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4654,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4654,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4654,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4654,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4654,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4654,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4654,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4654,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4654,605,30.809,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4654,606,25.883,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4655,203,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4655,204,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4655,205,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4655,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4655,208,628,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4655,255,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4655,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4655,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4655,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4655,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4655,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4655,307,864,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4655,320,0,'100g',2,1,'2024-12-12','2004-01-05');
INSERT INTO `cndb_nutval` VALUES (4655,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4655,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4655,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4655,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4655,605,19.068,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4655,606,22.869,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4656,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4656,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4656,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4656,207,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4656,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4656,255,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4656,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4656,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4656,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4656,303,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4656,306,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4656,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4656,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4656,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4656,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4656,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4656,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4656,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4656,606,87.558,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4657,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4657,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4657,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4657,207,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4657,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4657,255,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4657,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4657,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4657,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4657,303,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4657,306,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4657,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4657,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4657,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4657,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4657,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4657,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4657,605,0.257,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4657,606,93.701,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4658,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4658,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4658,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4658,207,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4658,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4658,255,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4658,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4658,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4658,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4658,303,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4658,306,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4658,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4658,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4658,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4658,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4658,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4658,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4658,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4658,606,92.614,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4659,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4659,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4659,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4659,207,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4659,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4659,255,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4659,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4659,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4659,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4659,303,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4659,306,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4659,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4659,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4659,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4659,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4659,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4659,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4659,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4659,606,86.503,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4660,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4660,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4660,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4660,207,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4660,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4660,255,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4660,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4660,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4660,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4660,303,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4660,306,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4660,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4660,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4660,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4660,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4660,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4660,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4660,605,3.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4660,606,88.965,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4661,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4661,204,99.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4661,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4661,207,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4661,208,880,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4661,255,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4661,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4661,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4661,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4661,303,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4661,306,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4661,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4661,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4661,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4661,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4661,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4661,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4661,605,0.267,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4661,606,93.536,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4662,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4662,204,99.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4662,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4662,207,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4662,208,880,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4662,255,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4662,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4662,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4662,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4662,303,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4662,306,4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4662,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4662,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4662,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4662,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4662,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4662,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4662,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4662,606,71.444,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4663,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4663,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4663,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4663,207,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4663,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4663,255,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4663,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4663,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4663,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4663,303,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4663,306,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4663,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4663,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4663,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4663,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4663,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4663,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4663,605,4.658,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4663,606,88.209,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4664,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4664,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4664,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4664,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4664,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4664,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4664,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4664,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4664,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4664,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4664,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4664,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4664,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (4664,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4664,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4664,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4664,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4664,605,31.228,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4664,606,28.421,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4665,203,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4665,204,80.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4665,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4665,207,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4665,208,714,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4665,255,15.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4665,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4665,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4665,301,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4665,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4665,306,94,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4665,307,879,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4665,320,1032,'100g',2,1,'2024-12-12','2004-01-05');
INSERT INTO `cndb_nutval` VALUES (4665,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4665,401,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4665,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4665,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4665,605,24.747,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4665,606,20.442,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4666,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4666,204,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4666,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4666,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4666,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4666,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4666,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4666,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4666,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4666,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4666,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4666,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4666,320,0,'100g',2,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (4666,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4666,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4666,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4666,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4666,605,13.784,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4666,606,17.416,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4667,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4667,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4667,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4667,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4667,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4667,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4667,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4667,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4667,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4667,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4667,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4667,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4667,320,0,'100g',2,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (4667,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4667,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4667,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4667,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4667,605,42.851,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4667,606,18.788,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4668,203,0.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4668,204,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4668,205,0.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4668,207,1.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4668,208,714,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4668,255,17.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4668,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4668,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4668,301,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4668,303,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4668,306,18,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4668,307,886,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4668,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (4668,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4668,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4668,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4668,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4668,605,20.578,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4668,606,16.321,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4669,203,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4669,204,100,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4669,205,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4669,207,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4669,208,884,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4669,255,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4669,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4669,291,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4669,301,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4669,303,0.02,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4669,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4669,307,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4669,320,0,'100g',2,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (4669,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4669,401,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4669,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4669,601,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4669,605,0.678,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4669,606,15.251,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (4678,203,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4678,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4678,205,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4678,207,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4678,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4678,255,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4678,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4678,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4678,301,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4678,303,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4678,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4678,307,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4678,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (4678,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4678,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4678,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4678,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4678,605,0.767,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4678,606,6.511,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4683,203,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4683,204,68.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4683,205,0.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4683,207,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4683,208,606,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4683,255,29.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4683,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4683,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4683,301,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4683,303,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4683,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4683,307,536,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4683,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (4683,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4683,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4683,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4683,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4683,605,3.265,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4683,606,16.688,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4686,203,0.98,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (4686,204,10,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (4686,205,28.26,'100g',3,1,'2007-12-03','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4686,207,2.56,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (4686,208,207,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (4686,255,57.19,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (4686,269,18.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4686,291,0.8,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (4686,301,67,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (4686,303,0.41,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (4686,306,55,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4686,307,701,'100g',3,1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (4686,320,1,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (4686,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4686,401,0.4,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (4686,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4686,601,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (4686,605,0.003,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (4686,606,0.833,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (4688,203,0.16,'100g',6,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (4688,204,10.75,'100g',6,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (4688,205,16.6,'100g',6,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (4688,207,1.5,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (4688,208,165,'100g',6,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (4688,255,71,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (4688,269,14.29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4688,291,0.3,'100g',6,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (4688,301,6,'100g',6,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (4688,303,0.18,'100g',6,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (4688,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4688,307,1102,'100g',6,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (4688,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (4688,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4688,401,0.7,'100g',6,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (4688,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4688,601,0,'100g',6,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (4688,605,0.139,'100g',6,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (4688,606,1.643,'100g',6,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (4690,203,0.51,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4690,204,37.77,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4690,205,0.66,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4690,207,1.52,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4690,208,339,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4690,255,59.55,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4690,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4690,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4690,301,6,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4690,303,0.02,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4690,306,34,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4690,307,589,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4690,320,1297,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4690,328,10.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4690,401,0.1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4690,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4690,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4690,605,1.687,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4690,606,8.637,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4691,203,0.16,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4691,204,80.71,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4691,205,0.7,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4691,207,1.92,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4691,208,717,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4691,255,16.52,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4691,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4691,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4691,301,3,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4691,303,0.06,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4691,306,18,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4691,307,751,'100g',3,1,'2010-01-04','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4691,320,819,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4691,328,10.7,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4691,401,0.2,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4691,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4691,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4691,605,14.89,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4691,606,15.189,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4692,203,0.22,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4692,204,80.17,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4692,205,0.75,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4692,207,1.78,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4692,208,713,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4692,255,17.07,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4692,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4692,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4692,301,3,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4692,303,0,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4692,306,17,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4692,307,657,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4692,320,819,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4692,328,10.7,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4692,401,0.1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4692,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4692,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4692,605,5.827,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4692,606,14.224,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4693,203,0.12,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4693,204,60.39,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4693,205,0.69,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4693,207,1.84,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4693,208,537,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4693,255,36.95,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4693,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4693,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4693,301,21,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4693,303,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4693,306,30,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4693,307,785,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4693,320,819,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4693,328,10.7,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4693,401,0.1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4693,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4693,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4693,605,12.731,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4693,606,10.884,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4694,203,0.17,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4694,204,59.81,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4694,205,0.86,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4694,207,1.59,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4694,208,533,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4694,255,37.58,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4694,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4694,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4694,301,21,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4694,303,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4694,306,30,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4694,307,785,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4694,320,819,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4694,328,10.7,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4694,401,0.1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4694,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4694,601,1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4694,605,3.664,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4694,606,12.086,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4695,203,0.6,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4695,204,59.17,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4695,205,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4695,207,1.7,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4695,208,535,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4695,255,38.68,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4695,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4695,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4695,301,21,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4695,303,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4695,306,30,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4695,307,785,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4695,320,819,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4695,328,10.7,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4695,401,0.1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4695,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4695,601,1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4695,605,7.374,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4695,606,10.042,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4696,203,0.16,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4696,204,80.71,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4696,205,0.7,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4696,207,1.92,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4696,208,717,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4696,255,16.52,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4696,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4696,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4696,301,3,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4696,303,0.06,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4696,306,18,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4696,307,2,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4696,320,819,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4696,328,10.7,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4696,401,0.2,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4696,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4696,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4696,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4696,606,15.189,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4697,203,0.17,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4697,204,59.81,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4697,205,0.86,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4697,207,1.59,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4697,208,542,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4697,255,37.58,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4697,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4697,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4697,301,21,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4697,303,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4697,306,30,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4697,307,2,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4697,320,819,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (4697,328,10.7,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4697,401,0.1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4697,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4697,601,1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4697,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4697,606,12.086,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (4698,203,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4698,204,100,'100g',6,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4698,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4698,207,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4698,208,900,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4698,255,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4698,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4698,291,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4698,301,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4698,303,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4698,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4698,307,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4698,320,0,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (4698,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4698,401,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4698,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4698,601,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4698,605,0.957,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4698,606,6.787,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4699,203,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4699,204,100,'100g',6,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4699,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4699,207,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4699,208,900,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4699,255,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4699,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4699,291,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4699,301,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4699,303,0.05,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4699,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4699,307,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4699,320,0,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (4699,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4699,401,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4699,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4699,601,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4699,605,0.67,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4699,606,15.084,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4700,203,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4700,204,100,'100g',6,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4700,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4700,207,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4700,208,884,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4700,255,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4700,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4700,291,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4700,301,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4700,303,0.05,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4700,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4700,307,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4700,320,0,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (4700,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4700,401,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4700,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4700,601,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4700,605,0.306,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4700,606,14.853,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4701,203,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4701,204,100,'100g',6,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4701,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4701,207,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4701,208,884,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4701,255,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4701,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4701,291,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4701,301,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4701,303,0.05,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4701,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4701,307,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4701,320,0,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (4701,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4701,401,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4701,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4701,601,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4701,605,1.148,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4701,606,93.966,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (4702,203,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4702,204,100,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4702,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4702,207,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4702,208,884,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4702,255,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4702,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4702,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4702,301,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4702,303,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4702,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4702,307,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4702,320,0,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (4702,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4702,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4702,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4702,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4702,605,0.67,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4702,606,93.608,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4703,203,0.87,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4703,204,40.83,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4703,205,23.33,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4703,207,2.32,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4703,208,464,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4703,255,32.64,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4703,269,15.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4703,291,0.4,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4703,301,12,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4703,303,0.29,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4703,306,20,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4703,307,512,'100g',3,1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (4703,320,12,'100g',2,1,'2024-12-12','2011-01-01');
INSERT INTO `cndb_nutval` VALUES (4703,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4703,401,0.2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4703,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4703,601,29,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4703,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4703,606,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4704,203,0.92,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4704,204,33.33,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4704,205,23.73,'100g',3,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (4704,207,2.36,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4704,208,399,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4704,255,38.85,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4704,269,23.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4704,291,0.3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4704,301,59,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4704,303,0.25,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4704,306,61,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4704,307,933,'100g',3,1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (4704,320,51,'100g',2,1,'2024-12-12','2011-01-01');
INSERT INTO `cndb_nutval` VALUES (4704,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4704,401,0.3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4704,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4704,601,15,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4704,605,0.144,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4704,606,6.061,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4705,203,1.47,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4705,204,0.23,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4705,205,30.73,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4705,207,3.48,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4705,208,131,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4705,255,64.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4705,269,8.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4705,291,0.2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4705,301,33,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4705,303,0.29,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4705,306,48,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4705,307,1265,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4705,320,1,'100g',2,1,'2024-12-12','2010-01-12');
INSERT INTO `cndb_nutval` VALUES (4705,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4705,401,0.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4705,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4705,601,1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4705,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4705,606,0.096,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4706,203,1.07,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4706,204,1.47,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4706,205,38.43,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4706,207,2.86,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4706,208,169,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4706,255,56.17,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4706,269,17.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4706,291,1.2,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4706,301,24,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4706,303,0.36,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4706,306,69,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4706,307,1004,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4706,320,5,'100g',2,1,'2024-12-12','2010-01-12');
INSERT INTO `cndb_nutval` VALUES (4706,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4706,401,2.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4706,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (4706,601,1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4706,605,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4706,606,0.349,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4707,203,0.37,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4707,204,99.01,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4707,205,0.39,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4707,207,0.07,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4707,208,878,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4707,255,0.16,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4707,269,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4707,291,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4707,301,9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4707,303,0.34,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4707,306,31,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4707,307,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4707,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (4707,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4707,401,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4707,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4707,601,0,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4707,605,0.184,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4707,606,9.047,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (4708,203,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4708,204,40,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4708,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4708,207,2.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4708,208,361,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4708,255,57.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4708,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4708,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4708,301,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4708,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4708,306,31,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4708,307,800,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4708,320,8,'100g',1,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (4708,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4708,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4708,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4708,601,33,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4708,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4708,606,5.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (4709,203,0.65,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4709,204,10,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4709,205,16.4,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4709,207,1.76,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4709,208,158,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4709,255,71.2,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4709,269,6.67,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4709,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4709,301,5,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4709,303,0.12,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4709,306,36,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4709,307,833,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4709,320,2,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (4709,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (4709,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4709,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (4709,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (4709,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (4709,606,1.484,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5000,203,28.04,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5000,204,3.57,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5000,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5000,207,1.4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5000,208,144,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5000,255,67.78,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5000,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5000,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5000,301,13,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5000,303,0.46,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5000,306,284,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5000,307,328,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5000,320,5,'100g',2,1,'2024-12-12','2013-01-06');
INSERT INTO `cndb_nutval` VALUES (5000,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5000,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5000,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5000,601,86,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5000,605,NULL,'100g',NULL,1,'2013-02-22','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (5000,606,0.863,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5001,203,18.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5001,204,14.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5001,205,0.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5001,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5001,208,213,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5001,255,66.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5001,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5001,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5001,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5001,303,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5001,306,189,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5001,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5001,320,232,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5001,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5001,401,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5001,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5001,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5001,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5001,606,4.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5002,203,22.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5002,204,17.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5002,205,9.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5002,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5002,208,291,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5002,255,49.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5002,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5002,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5002,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5002,303,1.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5002,306,190,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5002,307,284,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5002,320,181,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5002,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5002,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5002,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5002,601,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5002,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5002,606,4.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5003,203,28.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5003,204,15.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5003,205,3.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5003,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5003,208,272,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5003,255,51.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5003,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5003,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5003,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5003,303,1.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5003,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5003,307,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5003,320,248,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5003,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5003,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5003,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5003,601,112,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5003,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5003,606,4.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5004,203,26.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5004,204,13.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5004,205,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5004,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5004,208,234,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5004,255,60.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5004,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5004,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5004,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5004,303,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5004,306,212,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5004,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5004,320,191,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5004,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5004,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5004,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5004,601,107,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5004,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5004,606,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5005,203,24.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5005,204,12.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5005,205,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5005,207,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5005,208,216,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5005,255,64.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5005,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5005,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5005,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5005,303,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5005,306,163,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5005,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5005,320,174,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5005,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5005,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5005,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5005,601,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5005,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5005,606,3.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5006,203,18.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5006,204,15.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5006,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5006,207,0.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5006,208,215,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5006,255,65.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5006,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5006,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5006,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5006,303,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5006,306,189,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5006,307,70,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5006,320,41,'100g',2,1,'2024-12-12','2009-01-08');
INSERT INTO `cndb_nutval` VALUES (5006,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5006,401,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5006,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5006,601,75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5006,605,0.097,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5006,606,4.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5007,203,22.54,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5007,204,17.35,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5007,205,9.42,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5007,207,1.3,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5007,208,289,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5007,255,49.39,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5007,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5007,291,0.3,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5007,301,21,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5007,303,1.37,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5007,306,185,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5007,307,292,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5007,320,28,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (5007,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5007,401,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5007,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5007,601,87,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5007,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5007,606,4.61,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5008,203,28.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5008,204,14.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5008,205,3.15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5008,207,0.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5008,208,269,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5008,255,52.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5008,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5008,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5008,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5008,303,1.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5008,306,234,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5008,307,84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5008,320,27,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (5008,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5008,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5008,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5008,601,90,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5008,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5008,606,4.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5009,203,27.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5009,204,13.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5009,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5009,207,0.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5009,208,239,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5009,255,59.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5009,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5009,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5009,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5009,303,1.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5009,306,223,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5009,307,82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5009,320,48,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5009,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5009,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5009,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5009,601,88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5009,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5009,606,3.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5010,203,24.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5010,204,12.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5010,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5010,207,0.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5010,208,219,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5010,255,63.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5010,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5010,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5010,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5010,303,1.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5010,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5010,307,67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5010,320,44,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5010,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5010,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5010,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5010,601,78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5010,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5010,606,3.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5011,203,21.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5011,204,3.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5011,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5011,207,0.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5011,208,119,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5011,255,75.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5011,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5011,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5011,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5011,303,0.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5011,306,229,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5011,307,77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5011,320,16,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5011,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5011,401,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5011,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5011,601,70,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5011,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5011,606,0.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5012,203,30.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5012,204,9.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5012,205,1.69,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5012,207,1.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5012,208,219,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5012,255,57.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5012,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5012,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5012,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5012,303,1.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5012,306,257,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5012,307,91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5012,320,18,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5012,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5012,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5012,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5012,601,94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5012,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5012,606,2.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5013,203,28.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5013,204,7.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5013,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5013,207,1.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5013,208,190,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5013,255,63.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5013,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5013,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5013,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5013,303,1.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5013,306,243,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5013,307,86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5013,320,16,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5013,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5013,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5013,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5013,601,89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5013,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5013,606,2.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5014,203,27.29,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5014,204,6.71,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5014,205,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5014,207,0.85,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5014,208,177,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5014,255,66.81,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5014,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5014,291,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5014,301,14,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5014,303,1.17,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5014,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5014,307,70,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5014,320,15,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5014,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5014,401,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5014,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5014,601,83,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5014,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5014,606,1.84,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5015,203,13.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5015,204,32.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5015,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5015,207,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5015,208,349,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5015,255,54.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5015,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5015,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5015,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5015,303,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5015,306,103,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5015,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5015,320,76,'100g',2,1,'2024-12-12','2009-01-08');
INSERT INTO `cndb_nutval` VALUES (5015,328,0.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5015,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5015,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5015,601,109,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5015,605,0.349,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5015,606,9.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5016,203,10.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5016,204,28.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5016,205,23.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5016,207,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5016,208,394,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5016,255,36.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5016,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5016,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5016,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5016,303,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5016,306,75,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5016,307,581,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5016,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (5016,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5016,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5016,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5016,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5016,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5016,606,7.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5017,203,19.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5017,204,42.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5017,205,9.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5017,207,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5017,208,502,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5017,255,28.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5017,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5017,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5017,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5017,303,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5017,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5017,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5017,320,70,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5017,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5017,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5017,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5017,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5017,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5017,606,11.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5018,203,20.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5018,204,40.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5018,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5018,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5018,208,454,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5018,255,40.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5018,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5018,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5018,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5018,303,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5018,306,136,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5018,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5018,320,78,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5018,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5018,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5018,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5018,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5018,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5018,606,11.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5019,203,15.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5019,204,33.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5019,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5019,207,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5019,208,363,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5019,255,53.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5019,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5019,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5019,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5019,303,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5019,306,117,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5019,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5019,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (5019,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5019,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5019,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5019,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5019,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5019,606,9.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5020,203,17.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5020,204,4.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5020,205,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5020,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5020,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5020,255,74.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5020,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5020,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5020,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5020,303,5.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5020,306,228,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5020,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5020,320,2657,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5020,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5020,401,16.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5020,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5020,601,262,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5020,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5020,606,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5021,203,32.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5021,204,13.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5021,205,4.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5021,207,1.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5021,208,277,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5021,255,47.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5021,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5021,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5021,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5021,303,10.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5021,306,330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5021,307,113,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5021,320,3582,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5021,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5021,401,8.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5021,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5021,601,446,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5021,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5021,606,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5022,203,27.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5022,204,4.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5022,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5022,207,1.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5022,208,157,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5022,255,67.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5022,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5022,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5022,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5022,303,7.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5022,306,224,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5022,307,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5022,320,1753,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (5022,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5022,401,12.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5022,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5022,601,442,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5022,605,0.103,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5022,606,1.322,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5023,203,17.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5023,204,2.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5023,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5023,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5023,208,94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5023,255,79.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5023,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5023,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5023,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5023,303,2.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5023,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5023,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5023,320,19,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (5023,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5023,401,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5023,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5023,601,240,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5023,605,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5023,606,0.529,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5024,203,30.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5024,204,2.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5024,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5024,207,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5024,208,154,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5024,255,67.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5024,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5024,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5024,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5024,303,3.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5024,306,179,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5024,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5024,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (5024,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5024,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5024,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5024,601,370,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5024,605,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5024,606,0.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5025,203,15.55,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5025,204,9.33,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5025,205,0.71,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5025,207,0.85,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5025,208,153,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5025,255,73.56,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5025,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5025,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5025,301,12,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5025,303,5.96,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5025,306,176,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5025,307,74,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5025,320,9,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5025,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5025,401,3.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5025,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5025,601,136,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5025,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5025,606,2.66,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5026,203,26.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5026,204,7.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5026,205,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5026,207,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5026,208,185,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5026,255,64.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5026,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5026,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5026,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5026,303,9.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5026,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5026,307,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5026,320,8,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5026,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5026,401,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5026,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5026,601,242,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5026,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5026,606,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5027,203,16.92,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5027,204,4.83,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5027,205,0.73,'100g',3,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5027,207,1.06,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5027,208,119,'100g',3,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5027,255,76.46,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5027,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5027,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5027,301,8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5027,303,8.99,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5027,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5027,307,71,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5027,320,3296,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (5027,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5027,401,17.9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5027,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5027,601,345,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5027,605,0.065,'100g',1,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5027,606,1.563,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5028,203,24.46,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5028,204,6.51,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5028,205,0.87,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5028,207,1.36,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5028,208,167,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5028,255,66.81,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5028,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5028,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5028,301,11,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5028,303,11.63,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5028,306,263,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5028,307,76,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5028,320,3981,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (5028,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5028,401,27.9,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5028,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5028,601,563,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5028,605,0.09,'100g',1,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5028,606,2.06,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5029,203,20.27,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5029,204,11.07,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5029,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5029,207,0.86,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5029,208,186,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5029,255,68.6,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5029,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5029,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5029,301,11,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5029,303,0.79,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5029,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5029,307,65,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5029,320,29,'100g',2,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (5029,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5029,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5029,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5029,601,67,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5029,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5029,606,3.16,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5030,203,23.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5030,204,15.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5030,205,9.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5030,207,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5030,208,277,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5030,255,50.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5030,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5030,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5030,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5030,303,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5030,306,185,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5030,307,287,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5030,320,24,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5030,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5030,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5030,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5030,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5030,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5030,606,4.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5031,203,30.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5031,204,12.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5031,205,1.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5031,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5031,208,246,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5031,255,54.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5031,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5031,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5031,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5031,303,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5031,306,239,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5031,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5031,320,20,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5031,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5031,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5031,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5031,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5031,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5031,606,3.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5032,203,29.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5032,204,10.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5032,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5032,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5032,208,222,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5032,255,60.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5032,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5032,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5032,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5032,303,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5032,306,227,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5032,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5032,320,33,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5032,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5032,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5032,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5032,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5032,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5032,606,3.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5033,203,26.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5033,204,9.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5033,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5033,207,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5033,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5033,255,65.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5033,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5033,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5033,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5033,303,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5033,306,167,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5033,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5033,320,29,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5033,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5033,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5033,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5033,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5033,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5033,606,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5034,203,16.69,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5034,204,18.34,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5034,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5034,207,0.76,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5034,208,237,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5034,255,65.42,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5034,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5034,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5034,301,11,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5034,303,0.98,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5034,306,178,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5034,307,73,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5034,320,49,'100g',2,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (5034,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5034,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5034,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5034,601,81,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5034,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5034,606,5.26,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5035,203,21.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5035,204,18.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5035,205,9.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5035,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5035,208,298,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5035,255,48.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5035,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5035,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5035,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5035,303,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5035,306,185,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5035,307,295,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5035,320,31,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5035,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5035,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5035,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5035,601,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5035,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5035,606,4.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5036,203,27.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5036,204,16.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5036,205,4.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5036,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5036,208,285,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5036,255,50.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5036,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5036,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5036,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5036,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5036,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5036,307,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5036,320,31,'100g',1,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (5036,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5036,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5036,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5036,601,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5036,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5036,606,4.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5037,203,25.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5037,204,15.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5037,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5037,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5037,208,253,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5037,255,58.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5037,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5037,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5037,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5037,303,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5037,306,220,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5037,307,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5037,320,60,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5037,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5037,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5037,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5037,601,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5037,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5037,606,4.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5038,203,23.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5038,204,14.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5038,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5038,207,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5038,208,233,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5038,255,62.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5038,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5038,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5038,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5038,303,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5038,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5038,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5038,320,56,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5038,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5038,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5038,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5038,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5038,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5038,606,4.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5039,203,23.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5039,204,1.65,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5039,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5039,207,0.98,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5039,208,114,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5039,255,74.86,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5039,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5039,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5039,301,12,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5039,303,0.73,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5039,306,239,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5039,307,68,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5039,320,8,'100g',2,1,'2024-12-12','2003-01-06');
INSERT INTO `cndb_nutval` VALUES (5039,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5039,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5039,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5039,601,58,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5039,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5039,606,0.44,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5040,203,32.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5040,204,5.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5040,205,0.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5040,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5040,208,192,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5040,255,60.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5040,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5040,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5040,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5040,303,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5040,306,263,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5040,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5040,320,9,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5040,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5040,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5040,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5040,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5040,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5040,606,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5041,203,30.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5041,204,4.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5041,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5041,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5041,208,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5041,255,64.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5041,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5041,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5041,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5041,303,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5041,306,247,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5041,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5041,320,9,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5041,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5041,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5041,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5041,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5041,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5041,606,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5042,203,28.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5042,204,3.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5042,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5042,207,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5042,208,159,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5042,255,68.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5042,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5042,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5042,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5042,303,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5042,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5042,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5042,320,8,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5042,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5042,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5042,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5042,601,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5042,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5042,606,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5043,203,20.08,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5043,204,4.31,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5043,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5043,207,0.94,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5043,208,125,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5043,255,75.99,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5043,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5043,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5043,301,12,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5043,303,1.03,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5043,306,222,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5043,307,85,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5043,320,22,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (5043,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5043,401,3.1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5043,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5043,601,80,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5043,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5043,606,1.1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5044,203,28.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5044,204,11.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5044,205,2.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5044,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5044,208,239,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5044,255,55.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5044,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5044,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5044,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5044,303,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5044,306,253,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5044,307,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5044,320,24,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5044,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5044,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5044,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5044,601,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5044,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5044,606,3.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5045,203,27.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5045,204,9.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5045,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5045,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5045,208,205,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5045,255,63.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5045,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5045,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5045,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5045,303,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5045,306,240,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5045,307,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5045,320,22,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5045,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5045,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5045,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5045,601,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5045,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5045,606,2.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5046,203,25.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5046,204,8.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5046,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5046,207,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5046,208,192,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5046,255,65.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5046,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5046,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5046,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5046,303,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5046,306,181,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5046,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5046,320,21,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5046,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5046,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5046,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5046,601,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5046,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5046,606,2.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5047,203,3.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5047,204,67.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5047,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5047,207,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5047,208,629,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5047,255,28.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5047,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5047,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5047,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5047,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5047,306,64,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5047,307,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5047,320,125,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (5047,328,3.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5047,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5047,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5047,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5047,605,0.748,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5047,606,20.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5048,203,14.05,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5048,204,28.74,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5048,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5048,207,0.64,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5048,208,319,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5048,255,58.1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5048,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5048,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5048,301,13,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5048,303,0.94,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5048,306,144,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5048,307,64,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5048,320,75,'100g',2,1,'2024-12-12','2003-01-06');
INSERT INTO `cndb_nutval` VALUES (5048,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5048,401,1.6,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5048,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5048,601,79,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5048,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5048,606,8.34,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5049,203,21.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5049,204,21.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5049,205,10.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5049,207,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5049,208,331,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5049,255,44.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5049,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5049,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5049,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5049,303,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5049,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5049,307,317,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5049,320,36,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5049,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5049,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5049,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5049,601,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5049,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5049,606,5.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5050,203,27.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5050,204,20.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5050,205,6.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5050,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5050,208,331,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5050,255,43.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5050,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5050,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5050,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5050,303,1.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5050,306,226,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5050,307,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5050,320,37,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5050,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5050,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5050,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5050,601,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5050,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5050,606,5.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5051,203,25.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5051,204,20.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5051,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5051,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5051,208,300,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5051,255,53.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5051,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5051,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5051,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5051,303,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5051,306,210,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5051,307,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5051,320,105,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5051,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5051,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5051,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5051,601,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5051,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5051,606,5.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5052,203,22.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5052,204,18.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5052,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5052,207,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5052,208,258,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5052,255,60.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5052,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5052,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5052,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5052,303,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5052,306,145,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5052,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5052,320,88,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5052,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5052,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5052,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5052,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5052,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5052,606,5.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5053,203,19.56,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5053,204,5.92,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5053,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5053,207,0.92,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5053,208,137,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5053,255,75.31,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5053,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5053,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5053,301,17,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5053,303,1.04,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5053,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5053,307,82,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5053,320,30,'100g',2,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (5053,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5053,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5053,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5053,601,81,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5053,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5053,606,1.52,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5054,203,29.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5054,204,15.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5054,205,5.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5054,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5054,208,288,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5054,255,47.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5054,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5054,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5054,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5054,303,1.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5054,306,251,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5054,307,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5054,320,29,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5054,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5054,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5054,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5054,601,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5054,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5054,606,4.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5055,203,28.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5055,204,13.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5055,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5055,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5055,208,239,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5055,255,58.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5055,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5055,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5055,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5055,303,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5055,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5055,307,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5055,320,0,'100g',1,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (5055,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5055,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5055,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5055,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5055,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5055,606,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5056,203,25.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5056,204,11.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5056,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5056,207,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5056,208,209,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5056,255,64.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5056,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5056,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5056,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5056,303,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5056,306,158,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5056,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5056,320,27,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5056,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5056,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5056,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5056,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5056,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5056,606,3.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5057,203,20.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5057,204,9.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5057,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5057,207,1.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5057,208,172,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5057,255,69.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5057,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5057,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5057,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5057,303,0.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5057,306,220,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5057,307,63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5057,320,24,'100g',2,1,'2024-12-12','2009-01-08');
INSERT INTO `cndb_nutval` VALUES (5057,328,0.4,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5057,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5057,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5057,601,64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5057,605,0.105,'100g',3,1,'2006-01-24','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5057,606,2.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5058,203,24.84,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5058,204,13.2,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5058,205,8.99,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5058,207,1.33,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5058,208,260,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5058,255,51.64,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5058,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5058,291,0.3,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5058,301,20,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5058,303,1.25,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5058,306,201,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5058,307,275,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5058,320,20,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5058,328,0.1,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (5058,401,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5058,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5058,601,85,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5058,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5058,606,3.52,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5059,203,31.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5059,204,8.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5059,205,1.64,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5059,207,1.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5059,208,222,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5059,255,56.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5059,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5059,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5059,301,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5059,303,1.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5059,306,259,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5059,307,76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5059,320,15,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5059,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5059,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5059,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5059,601,89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5059,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5059,606,2.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5060,203,29.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5060,204,7.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5060,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5060,207,0.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5060,208,197,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5060,255,62.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5060,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5060,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5060,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5060,303,1.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5060,306,245,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5060,307,71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5060,320,28,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5060,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5060,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5060,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5060,601,84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5060,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5060,606,2.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5061,203,27.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5061,204,7.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5061,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5061,207,0.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5061,208,184,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5061,255,66.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5061,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5061,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5061,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5061,303,0.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5061,306,178,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5061,307,62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5061,320,25,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5061,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5061,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5061,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5061,601,75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5061,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5061,606,2.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5062,203,22.5,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5062,204,2.62,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5062,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5062,207,1.13,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5062,208,120,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5062,255,73.9,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5062,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5062,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5062,301,5,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5062,303,0.37,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5062,306,334,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5062,307,45,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5062,320,9,'100g',1,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (5062,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5062,401,0,'100g',4,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5062,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5062,601,73,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5062,605,0.007,'100g',3,1,'2006-01-24','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5062,606,0.563,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5063,203,33.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5063,204,4.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5063,205,0.51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5063,207,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5063,208,187,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5063,255,60.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5063,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5063,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5063,301,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5063,303,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5063,306,276,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5063,307,79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5063,320,7,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5063,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5063,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5063,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5063,601,91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5063,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5063,606,1.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5064,203,31.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5064,204,3.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5064,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5064,207,1.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5064,208,165,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5064,255,65.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5064,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5064,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5064,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5064,303,1.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5064,306,256,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5064,307,74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5064,320,6,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5064,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5064,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5064,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5064,601,85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5064,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5064,606,1.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5065,203,28.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5065,204,3.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5065,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5065,207,0.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5065,208,151,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5065,255,68.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5065,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5065,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5065,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5065,303,0.88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5065,306,187,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5065,307,63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5065,320,6,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5065,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5065,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5065,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5065,601,77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5065,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5065,606,0.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5066,203,18.08,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5066,204,9.2,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5066,205,0.11,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5066,207,0.86,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5066,208,161,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5066,255,72.46,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5066,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5066,291,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5066,301,8,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5066,303,0.71,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5066,306,211,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5066,307,106,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5066,320,14,'100g',1,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (5066,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5066,401,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5066,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5066,601,92,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5066,605,0.047,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5066,606,2.459,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5067,203,21.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5067,204,15.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5067,205,8.28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5067,207,1.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5067,208,268,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5067,255,52.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5067,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5067,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5067,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5067,303,1.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5067,306,186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5067,307,269,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5067,320,26,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5067,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5067,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5067,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5067,601,86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5067,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5067,606,4.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5068,203,26.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5068,204,13.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5068,205,1.63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5068,207,0.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5068,208,245,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5068,255,56.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5068,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5068,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5068,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5068,303,1.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5068,306,229,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5068,307,89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5068,320,25,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5068,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5068,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5068,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5068,601,90,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5068,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5068,606,3.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5069,203,23.35,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5069,204,10.15,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5069,205,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5069,207,1.02,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5069,208,191,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5069,255,66.39,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5069,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5069,291,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5069,301,11,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5069,303,1.11,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5069,306,247,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5069,307,123,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5069,320,12,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (5069,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5069,401,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5069,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5069,601,130,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5069,605,0.055,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5069,606,2.74,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5070,203,25.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5070,204,10.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5070,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5070,207,0.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5070,208,204,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5070,255,65.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5070,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5070,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5070,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5070,303,1.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5070,306,184,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5070,307,76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5070,320,27,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5070,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5070,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5070,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5070,601,83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5070,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5070,606,2.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5071,203,19.41,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5071,204,3.71,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5071,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5071,207,0.92,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5071,208,116,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5071,255,76.78,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5071,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5071,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5071,301,9,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5071,303,0.76,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5071,306,225,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5071,307,114,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5071,320,7,'100g',1,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (5071,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5071,401,0,'100g',4,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5071,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5071,601,89,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5071,605,0.018,'100g',3,1,'2006-01-24','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5071,606,0.949,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5072,203,28.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5072,204,8.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5072,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5072,207,1.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5072,208,195,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5072,255,62.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5072,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5072,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5072,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5072,303,1.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5072,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5072,307,96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5072,320,18,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5072,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5072,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5072,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5072,601,94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5072,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5072,606,2.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5073,203,24.24,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5073,204,5.7,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5073,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5073,207,1.06,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5073,208,155,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5073,255,69.93,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5073,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5073,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5073,301,11,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5073,303,1.14,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5073,306,256,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5073,307,128,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5073,320,6,'100g',1,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (5073,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5073,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5073,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5073,601,130,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5073,605,0.03,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5073,606,1.505,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5074,203,27.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5074,204,5.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5074,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5074,207,0.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5074,208,169,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5074,255,67.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5074,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5074,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5074,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5074,303,1.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5074,306,199,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5074,307,80,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5074,320,17,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5074,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5074,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5074,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5074,601,88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5074,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5074,606,1.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5075,203,16.37,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5075,204,15.95,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5075,205,0.17,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5075,207,0.81,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5075,208,214,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5075,255,67.3,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5075,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5075,291,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5075,301,9,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5075,303,0.69,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5075,306,203,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5075,307,84,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5075,320,28,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (5075,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5075,401,0.2,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5075,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5075,601,93,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5075,605,0.06,'100g',3,1,'2006-01-24','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5075,606,4.366,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5076,203,21.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5076,204,16.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5076,205,8.72,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5076,207,1.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5076,208,273,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5076,255,52.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5076,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5076,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5076,301,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5076,303,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5076,306,189,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5076,307,279,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5076,320,27,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5076,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5076,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5076,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5076,601,90,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5076,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5076,606,4.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5077,203,26.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5077,204,14.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5077,205,2.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5077,207,0.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5077,208,254,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5077,255,55.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5077,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5077,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5077,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5077,303,1.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5077,306,233,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5077,307,88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5077,320,28,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5077,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5077,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5077,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5077,601,94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5077,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5077,606,3.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5078,203,24.03,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5078,204,8.99,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5078,205,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5078,207,1.02,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5078,208,184,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5078,255,66.74,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5078,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5078,291,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5078,301,12,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5078,303,1.09,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5078,306,264,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5078,307,98,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5078,320,20,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (5078,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5078,401,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5078,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5078,601,127,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5078,605,0.032,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5078,606,2.446,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5079,203,24.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5079,204,12.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5079,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5079,207,0.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5079,208,220,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5079,255,64.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5079,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5079,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5079,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5079,303,1.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5079,306,176,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5079,307,73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5079,320,37,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5079,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5079,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5079,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5079,601,84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5079,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5079,606,3.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5080,203,19.16,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5080,204,4.22,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5080,205,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5080,207,0.95,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5080,208,120,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5080,255,76.41,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5080,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5080,291,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5080,301,10,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5080,303,0.78,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5080,306,238,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5080,307,96,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5080,320,10,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (5080,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5080,401,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5080,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5080,601,91,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5080,605,0.015,'100g',3,1,'2006-01-24','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5080,606,1.05,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5081,203,28.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5081,204,9.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5081,205,0.65,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5081,207,1.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5081,208,208,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5081,255,60.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5081,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5081,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5081,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5081,303,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5081,306,254,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5081,307,96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5081,320,20,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5081,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5081,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5081,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5081,601,99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5081,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5081,606,2.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5082,203,24.22,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5082,204,7.8,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5082,205,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5082,207,1.04,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5082,208,174,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5082,255,67.69,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5082,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5082,291,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5082,301,12,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5082,303,1.08,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5082,306,269,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5082,307,99,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5082,320,7,'100g',1,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (5082,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5082,401,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5082,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5082,601,128,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5082,605,0.033,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5082,606,2.108,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5083,203,26.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5083,204,8.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5083,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5083,207,0.88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5083,208,185,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5083,255,66.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5083,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5083,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5083,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5083,303,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5083,306,190,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5083,307,78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5083,320,18,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5083,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5083,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5083,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5083,601,89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5083,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5083,606,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5084,203,14.07,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5084,204,26.24,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5084,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5084,207,0.55,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5084,208,297,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5084,255,59.99,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5084,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5084,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5084,301,18,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5084,303,1.9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5084,306,137,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5084,307,64,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5084,320,65,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5084,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5084,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5084,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5084,601,99,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5084,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5084,606,7.27,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5085,203,19.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5085,204,23.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5085,205,8.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5085,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5085,208,330,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5085,255,46.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5085,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5085,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5085,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5085,303,2.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5085,306,151,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5085,307,276,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5085,320,51,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5085,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5085,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5085,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5085,601,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5085,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5085,606,6.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5086,203,24.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5086,204,23.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5086,205,4.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5086,207,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5086,208,332,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5086,255,47.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5086,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5086,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5086,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5086,303,2.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5086,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5086,307,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5086,320,57,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5086,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5086,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5086,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5086,601,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5086,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5086,606,6.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5087,203,19.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5087,204,18.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5087,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5087,207,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5087,208,247,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5087,255,61.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5087,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5087,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5087,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5087,303,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5087,306,108,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5087,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5087,320,48,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5087,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5087,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5087,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5087,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5087,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5087,606,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5088,203,17.55,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5088,204,8.78,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5088,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5088,207,0.69,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5088,208,154,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5088,255,71.17,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5088,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5088,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5088,301,27,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5088,303,2.06,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5088,306,175,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5088,307,81,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5088,320,44,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5088,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5088,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5088,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5088,601,83,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5088,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5088,606,2.25,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5089,203,26.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5089,204,11.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5089,205,1.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5089,207,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5089,208,229,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5089,255,58.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5089,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5089,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5089,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5089,303,2.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5089,306,213,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5089,307,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5089,320,49,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5089,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5089,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5089,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5089,601,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5089,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5089,606,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5090,203,24.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5090,204,8.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5090,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5090,207,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5090,208,179,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5090,255,67.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5090,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5090,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5090,301,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5090,303,2.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5090,306,140,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5090,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5090,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (5090,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5090,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5090,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5090,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5090,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5090,606,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5091,203,16.52,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5091,204,16.61,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5091,205,0.25,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5091,207,0.81,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5091,208,221,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5091,255,66.47,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5091,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5091,291,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5091,301,7,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5091,303,0.68,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5091,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5091,307,81,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5091,320,23,'100g',1,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (5091,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5091,401,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5091,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5091,601,98,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5091,605,0.085,'100g',3,1,'2006-01-24','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5091,606,4.524,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5092,203,21.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5092,204,16.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5092,205,9.08,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5092,207,1.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5092,208,277,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5092,255,51.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5092,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5092,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5092,301,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5092,303,1.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5092,306,192,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5092,307,288,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5092,320,29,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5092,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5092,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5092,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5092,601,93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5092,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5092,606,4.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5093,203,26.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5093,204,14.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5093,205,3.18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5093,207,0.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5093,208,262,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5093,255,54.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5093,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5093,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5093,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5093,303,1.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5093,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5093,307,88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5093,320,29,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5093,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5093,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5093,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5093,601,97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5093,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5093,606,4.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5094,203,23.26,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5094,204,14.71,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5094,205,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5094,207,0.98,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5094,208,232,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5094,255,61.96,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5094,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5094,291,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5094,301,9,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5094,303,1.08,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5094,306,253,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5094,307,102,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5094,320,16,'100g',1,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (5094,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5094,401,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5094,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5094,601,133,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5094,605,0.081,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5094,606,4.111,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5095,203,23.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5095,204,14.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5095,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5095,207,0.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5095,208,232,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5095,255,63.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5095,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5095,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5095,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5095,303,1.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5095,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5095,307,71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5095,320,45,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5095,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5095,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5095,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5095,601,84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5095,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5095,606,4.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5096,203,19.66,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5096,204,4.12,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5096,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5096,207,0.95,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5096,208,121,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5096,255,76.22,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5096,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5096,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5096,301,7,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5096,303,0.81,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5096,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5096,307,95,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5096,320,7,'100g',1,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (5096,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5096,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5096,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5096,601,94,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5096,605,0.02,'100g',3,1,'2006-01-24','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5096,606,1.097,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5097,203,28.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5097,204,10.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5097,205,1.18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5097,207,1.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5097,208,218,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5097,255,59.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5097,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5097,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5097,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5097,303,1.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5097,306,259,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5097,307,95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5097,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (5097,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5097,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5097,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5097,601,102,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5097,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5097,606,2.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5098,203,24.76,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5098,204,8.15,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5098,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5098,207,1.04,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5098,208,179,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5098,255,67,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5098,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5098,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5098,301,9,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5098,303,1.13,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5098,306,269,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5098,307,106,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5098,320,8,'100g',1,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (5098,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5098,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5098,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5098,601,133,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5098,605,0.044,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5098,606,2.311,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5099,203,25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5099,204,9.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5099,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5099,207,0.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5099,208,195,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5099,255,65.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5099,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5099,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5099,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5099,303,1.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5099,306,183,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5099,307,75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5099,320,19,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5099,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5099,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5099,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5099,601,90,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5099,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5099,606,2.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5100,203,17.52,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5100,204,12.85,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5100,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5100,207,0.74,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5100,208,191,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5100,255,69.19,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5100,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5100,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5100,301,11,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5100,303,0.46,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5100,306,187,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5100,307,84,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5100,320,9,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (5100,328,0.1,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (5100,401,0,'100g',4,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5100,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5100,601,111,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5100,605,0.061,'100g',3,1,'2006-01-24','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5100,606,3.535,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5101,203,19.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5101,204,21.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5101,205,10.94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5101,207,1.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5101,208,324,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5101,255,46.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5101,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5101,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5101,301,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5101,303,1.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5101,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5101,307,320,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5101,320,34,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5101,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5101,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5101,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5101,601,79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5101,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5101,606,5.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5102,203,26.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5102,204,22.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5102,205,2.39,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5102,207,0.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5102,208,321,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5102,255,48.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5102,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5102,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5102,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5102,303,1.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5102,306,177,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5102,307,77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5102,320,38,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5102,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5102,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5102,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5102,601,81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5102,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5102,606,6.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5103,203,23.79,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5103,204,16.87,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5103,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5103,207,0.88,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5103,208,254,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5103,255,59.4,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5103,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5103,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5103,301,18,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5103,303,0.84,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5103,306,212,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5103,307,98,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5103,320,12,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (5103,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5103,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5103,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5103,601,141,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5103,605,0.084,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5103,606,4.976,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5104,203,22.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5104,204,16.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5104,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5104,207,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5104,208,249,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5104,255,62.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5104,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5104,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5104,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5104,303,1.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5104,306,139,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5104,307,67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5104,320,40,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5104,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5104,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5104,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5104,601,70,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5104,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5104,606,4.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5105,203,21.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5105,204,3.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5105,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5105,207,0.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5105,208,126,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5105,255,74.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5105,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5105,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5105,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5105,303,0.88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5105,306,194,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5105,307,81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5105,320,18,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5105,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5105,401,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5105,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5105,601,57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5105,605,0.07,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5105,606,0.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5106,203,30.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5106,204,9.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5106,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5106,207,0.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5106,208,211,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5106,255,59.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5106,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5106,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5106,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5106,303,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5106,306,208,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5106,307,91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5106,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (5106,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5106,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5106,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5106,601,84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5106,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5106,606,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5107,203,30.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5107,204,8.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5107,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5107,207,0.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5107,208,203,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5107,255,62.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5107,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5107,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5107,301,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5107,303,1.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5107,306,210,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5107,307,92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5107,320,18,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5107,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5107,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5107,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5107,601,85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5107,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5107,606,2.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5108,203,27.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5108,204,7.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5108,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5108,207,0.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5108,208,181,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5108,255,67.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5108,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5108,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5108,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5108,303,1.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5108,306,153,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5108,307,73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5108,320,16,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5108,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5108,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5108,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5108,601,74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5108,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5108,606,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5109,203,17.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5109,204,15.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5109,205,0.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5109,207,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5109,208,213,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5109,255,65.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5109,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5109,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5109,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5109,303,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5109,306,196,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5109,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5109,320,253,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5109,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5109,401,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5109,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5109,601,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5109,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5109,606,4.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5110,203,23.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5110,204,13.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5110,205,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5110,207,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5110,208,220,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5110,255,62.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5110,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5110,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5110,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5110,303,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5110,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5110,307,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5110,320,179,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5110,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5110,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5110,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5110,601,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5110,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5110,606,3.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5111,203,24.31,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5111,204,4.02,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5111,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5111,207,1.41,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5111,208,133,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5111,255,70.78,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5111,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5111,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5111,301,4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5111,303,5.91,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5111,306,336,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5111,307,50,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5111,320,11,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (5111,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5111,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5111,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5111,601,80,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5111,605,0.008,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5111,606,0.609,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5112,203,23.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5112,204,13.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5112,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5112,207,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5112,208,223,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5112,255,62.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5112,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5112,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5112,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5112,303,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5112,306,211,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5112,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5112,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (5112,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5112,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5112,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5112,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5112,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5112,606,3.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5113,203,20.33,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5113,204,2.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5113,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5113,207,1.07,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5113,208,111,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5113,255,74.94,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5113,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5113,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5113,301,10,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5113,303,1.03,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5113,306,238,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5113,307,75,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5113,320,13,'100g',2,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (5113,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5113,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5113,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5113,601,65,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5113,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5113,606,0.67,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5114,203,25.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5114,204,6.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5114,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5114,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5114,208,167,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5114,255,67.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5114,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5114,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5114,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5114,303,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5114,306,229,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5114,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5114,320,12,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5114,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5114,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5114,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5114,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5114,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5114,606,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5115,203,18.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5115,204,5.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5115,205,1.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5115,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5115,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5115,255,74.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5115,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5115,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5115,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5115,303,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5115,306,227,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5115,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5115,320,2880,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5115,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5115,401,13.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5115,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5115,601,236,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5115,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5115,606,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5116,203,26.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5116,204,5.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5116,205,0.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5116,207,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5116,208,165,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5116,255,66.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5116,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5116,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5116,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5116,303,6.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5116,306,160,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5116,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5116,320,2443,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5116,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5116,401,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5116,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5116,601,357,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5116,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5116,606,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5117,203,22.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5117,204,1.63,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5117,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5117,207,1.1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5117,208,109,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5117,255,74.3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5117,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5117,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5117,301,11,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5117,303,0.89,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5117,306,252,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5117,307,51,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5117,320,8,'100g',1,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (5117,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5117,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5117,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5117,601,57,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5117,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5117,606,0.37,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5118,203,27.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5118,204,4.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5118,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5118,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5118,208,153,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5118,255,67.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5118,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5118,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5118,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5118,303,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5118,306,236,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5118,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5118,320,8,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5118,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5118,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5118,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5118,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5118,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5118,606,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5119,203,18.74,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5119,204,3.61,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5119,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5119,207,1.04,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5119,208,113,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5119,255,75.48,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5119,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5119,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5119,301,9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5119,303,1.15,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5119,306,227,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5119,307,95,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5119,320,18,'100g',2,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (5119,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5119,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5119,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5119,601,72,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5119,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5119,606,0.93,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5120,203,23.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5120,204,8.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5120,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5120,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5120,208,178,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5120,255,67.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5120,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5120,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5120,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5120,303,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5120,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5120,307,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5120,320,16,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5120,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5120,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5120,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5120,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5120,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5120,606,2.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5121,203,17.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5121,204,19.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5121,205,0.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5121,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5121,208,251,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5121,255,62.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5121,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5121,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5121,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5121,303,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5121,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5121,307,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5121,320,331,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5121,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5121,401,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5121,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5121,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5121,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5121,606,5.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5122,203,24.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5122,204,11.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5122,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5122,207,0.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5122,208,214,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5122,255,64.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5122,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5122,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5122,301,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5122,303,1.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5122,306,171,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5122,307,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5122,320,182,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5122,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5122,401,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5122,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5122,601,107,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5122,605,0.008,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5122,606,3.324,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5123,203,17.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5123,204,20.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5123,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5123,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5123,208,258,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5123,255,61.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5123,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5123,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5123,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5123,303,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5123,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5123,307,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5123,320,52,'100g',2,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (5123,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5123,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5123,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5123,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5123,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5123,606,5.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5124,203,26.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5124,204,18.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5124,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5124,207,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5124,208,285,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5124,255,53.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5124,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5124,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5124,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5124,303,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5124,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5124,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5124,320,39,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5124,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5124,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5124,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5124,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5124,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5124,606,5.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5125,203,21.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5125,204,6.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5125,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5125,207,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5125,208,148,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5125,255,72.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5125,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5125,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5125,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5125,303,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5125,306,251,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5125,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5125,320,32,'100g',1,1,'2024-12-12','2004-01-08');
INSERT INTO `cndb_nutval` VALUES (5125,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5125,401,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5125,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5125,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5125,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5125,606,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5126,203,30.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5126,204,11.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5126,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5126,207,1.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5126,208,237,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5126,255,56.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5126,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5126,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5126,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5126,303,1.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5126,306,202,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5126,307,78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5126,320,34,'100g',2,1,'2024-12-12','2002-01-12');
INSERT INTO `cndb_nutval` VALUES (5126,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5126,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5126,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5126,601,83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5126,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5126,606,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5127,203,17.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5127,204,9.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5127,205,2.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5127,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5127,208,168,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5127,255,69.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5127,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5127,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5127,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5127,303,5.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5127,306,226,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5127,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5127,320,3152,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5127,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5127,401,11.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5127,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5127,601,240,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5127,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5127,606,2.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5128,203,25.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5128,204,9.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5128,205,0.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5128,207,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5128,208,194,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5128,255,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5128,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5128,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5128,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5128,303,6.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5128,306,154,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5128,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5128,320,2864,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5128,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5128,401,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5128,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5128,601,355,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5128,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5128,606,2.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5129,203,23.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5129,204,4.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5129,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5129,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5129,208,137,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5129,255,73.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5129,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5129,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5129,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5129,303,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5129,306,261,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5129,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5129,320,21,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (5129,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5129,401,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5129,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5129,601,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5129,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5129,606,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5130,203,33.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5130,204,7.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5130,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5130,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5130,208,213,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5130,255,57.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5130,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5130,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5130,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5130,303,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5130,306,199,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5130,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5130,320,22,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5130,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5130,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5130,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5130,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5130,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5130,606,1.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5131,203,19.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5131,204,8.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5131,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5131,207,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5131,208,157,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5131,255,71.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5131,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5131,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5131,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5131,303,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5131,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5131,307,101,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5131,320,41,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (5131,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5131,401,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5131,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5131,601,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5131,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5131,606,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5132,203,28.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5132,204,15.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5132,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5132,207,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5132,208,258,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5132,255,55.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5132,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5132,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5132,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5132,303,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5132,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5132,307,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5132,320,44,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5132,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5132,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5132,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5132,601,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5132,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5132,606,4.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5133,203,18.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5133,204,16.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5133,205,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5133,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5133,208,232,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5133,255,63.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5133,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5133,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5133,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5133,303,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5133,306,213,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5133,307,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5133,320,272,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5133,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5133,401,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5133,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5133,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5133,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5133,606,4.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5134,203,28.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5134,204,11.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5134,205,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5134,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5134,208,226,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5134,255,59.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5134,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5134,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5134,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5134,303,1.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5134,306,243,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5134,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5134,320,220,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5134,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5134,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5134,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5134,601,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5134,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5134,606,3.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5135,203,18.77,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5135,204,17.07,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5135,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5135,207,0.96,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5135,208,234,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5135,255,63.24,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5135,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5135,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5135,301,11,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5135,303,1.09,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5135,306,217,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5135,307,45,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5135,320,37,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (5135,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5135,401,1.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5135,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5135,601,75,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5135,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5135,606,4.95,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5136,203,28.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5136,204,11.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5136,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5136,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5136,208,229,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5136,255,58.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5136,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5136,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5136,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5136,303,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5136,306,255,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5136,307,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5136,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (5136,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5136,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5136,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5136,601,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5136,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5136,606,3.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5137,203,18.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5137,204,5.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5137,205,1.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5137,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5137,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5137,255,74.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5137,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5137,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5137,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5137,303,6.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5137,306,226,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5137,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5137,320,4374,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5137,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5137,401,18.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5137,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5137,601,292,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5137,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5137,606,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5138,203,26.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5138,204,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5138,205,0.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5138,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5138,208,164,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5138,255,66.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5138,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5138,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5138,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5138,303,6.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5138,306,153,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5138,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5138,320,3984,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5138,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5138,401,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5138,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5138,601,434,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5138,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5138,606,1.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5139,203,11.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5139,204,39.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5139,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5139,207,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5139,208,404,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5139,255,48.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5139,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5139,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5139,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5139,303,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5139,306,209,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5139,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5139,320,50,'100g',2,1,'2024-12-12','2009-01-08');
INSERT INTO `cndb_nutval` VALUES (5139,328,0.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5139,401,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5139,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5139,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5139,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5139,606,13.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5140,203,18.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5140,204,28.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5140,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5140,207,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5140,208,337,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5140,255,51.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5140,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5140,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5140,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5140,303,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5140,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5140,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5140,320,63,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5140,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5140,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5140,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5140,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5140,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5140,606,9.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5141,203,18.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5141,204,5.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5141,205,0.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5141,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5141,208,135,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5141,255,73.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5141,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5141,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5141,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5141,303,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5141,306,271,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5141,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5141,320,24,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5141,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5141,401,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5141,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5141,601,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5141,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5141,606,2.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5142,203,23.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5142,204,11.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5142,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5142,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5142,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5142,255,64.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5142,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5142,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5142,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5142,303,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5142,306,252,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5142,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5142,320,23,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5142,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5142,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5142,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5142,601,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5142,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5142,606,3.951,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5143,203,18.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5143,204,4.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5143,205,3.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5143,207,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5143,208,136,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5143,255,71.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5143,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5143,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5143,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5143,303,30.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5143,306,230,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5143,307,140,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5143,320,11984,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5143,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5143,401,4.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5143,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5143,601,515,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5143,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5143,606,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5144,203,17.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5144,204,15.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5144,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5144,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5144,208,211,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5144,255,66.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5144,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5144,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5144,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5144,303,4.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5144,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5144,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5144,320,26,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5144,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5144,401,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5144,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5144,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5144,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5144,606,5.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5145,203,19.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5145,204,4.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5145,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5145,207,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5145,208,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5145,255,75.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5145,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5145,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5145,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5145,303,4.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5145,306,268,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5145,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5145,320,16,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5145,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5145,401,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5145,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5145,601,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5145,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5145,606,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5146,203,15.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5146,204,33.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5146,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5146,207,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5146,208,371,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5146,255,49.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5146,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5146,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5146,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5146,303,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5146,306,308,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5146,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5146,320,17,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5146,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5146,401,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5146,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5146,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5146,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5146,606,9.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5147,203,25.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5147,204,21.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5147,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5147,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5147,208,305,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5147,255,51.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5147,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5147,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5147,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5147,303,2.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5147,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5147,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5147,320,21,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5147,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5147,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5147,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5147,601,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5147,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5147,606,6.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5148,203,22.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5148,204,7.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5148,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5148,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5148,208,161,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5148,255,68.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5148,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5148,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5148,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5148,303,2.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5148,306,420,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5148,307,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5148,320,12,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5148,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5148,401,7.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5148,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5148,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5148,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5148,606,2.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5149,203,28.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5149,204,12.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5149,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5149,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5149,208,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5149,255,57.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5149,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5149,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5149,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5149,303,2.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5149,306,388,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5149,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5149,320,12,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5149,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5149,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5149,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5149,601,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5149,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5149,606,4.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5150,203,16.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5150,204,4.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5150,205,6.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5150,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5150,208,133,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5150,255,71.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5150,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5150,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5150,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5150,303,30.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5150,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5150,307,140,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5150,320,9309,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5150,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5150,401,4.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5150,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5150,601,515,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5150,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5150,606,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5151,203,23.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5151,204,6.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5151,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5151,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5151,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5151,255,68.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5151,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5151,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5151,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5151,303,0.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5151,306,193,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5151,307,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5151,320,28,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5151,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5151,401,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5151,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5151,601,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5151,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5151,606,1.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5152,203,20.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5152,204,2.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5152,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5152,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5152,208,110,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5152,255,74.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5152,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5152,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5152,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5152,303,0.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5152,306,220,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5152,307,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5152,320,12,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5152,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5152,401,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5152,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5152,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5152,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5152,606,0.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5153,203,22.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5153,204,9.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5153,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5153,207,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5153,208,181,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5153,255,67.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5153,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5153,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5153,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5153,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5153,306,243,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5153,307,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5153,320,53,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5153,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5153,401,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5153,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5153,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5153,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5153,606,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5154,203,23.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5154,204,3.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5154,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5154,207,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5154,208,133,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5154,255,72.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5154,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5154,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5154,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5154,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5154,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5154,307,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5154,320,50,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5154,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5154,401,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5154,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5154,601,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5154,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5154,606,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5155,203,24.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5155,204,3.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5155,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5155,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5155,208,133,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5155,255,72.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5155,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5155,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5155,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5155,303,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5155,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5155,307,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5155,320,44,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5155,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5155,401,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5155,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5155,601,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5155,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5155,606,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5156,203,22.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5156,204,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5156,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5156,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5156,208,134,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5156,255,73.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5156,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5156,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5156,301,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5156,303,1.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5156,306,296,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5156,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5156,320,59,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5156,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5156,401,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5156,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5156,601,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5156,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5156,606,1.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5157,203,19.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5157,204,12.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5157,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5157,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5157,208,192,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5157,255,69.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5157,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5157,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5157,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5157,303,3.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5157,306,216,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5157,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5157,320,73,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5157,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5157,401,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5157,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5157,601,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5157,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5157,606,3.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5158,203,21.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5158,204,4.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5158,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5158,207,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5158,208,134,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5158,255,70.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5158,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5158,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5158,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5158,303,4.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5158,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5158,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5158,320,17,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5158,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5158,401,7.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5158,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5158,601,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5158,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5158,606,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5159,203,22.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5159,204,2.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5159,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5159,207,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5159,208,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5159,255,71.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5159,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5159,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5159,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5159,303,2.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5159,306,260,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5159,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5159,320,11,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5159,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5159,401,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5159,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5159,601,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5159,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5159,606,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5160,203,18.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5160,204,23.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5160,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5160,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5160,208,294,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5160,255,56.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5160,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5160,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5160,301,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5160,303,3.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5160,306,199,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5160,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5160,320,73,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5160,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5160,401,5.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5160,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5160,601,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5160,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5160,606,8.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5161,203,17.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5161,204,7.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5161,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5161,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5161,208,142,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5161,255,72.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5161,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5161,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5161,301,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5161,303,4.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5161,306,237,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5161,307,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5161,320,28,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5161,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5161,401,7.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5161,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5161,601,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5161,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5161,606,1.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5162,203,21.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5162,204,4.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5162,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5162,207,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5162,208,134,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5162,255,72.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5162,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5162,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5162,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5162,303,2.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5162,306,260,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5162,307,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5162,320,17,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5162,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5162,401,5.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5162,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5162,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5162,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5162,606,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5165,203,21.64,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5165,204,5.64,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5165,205,0.14,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (5165,207,0.98,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5165,208,144,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (5165,255,72.69,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5165,269,0.07,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5165,291,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5165,301,11,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5165,303,0.86,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5165,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5165,307,112,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5165,320,17,'100g',2,1,'2024-12-12','2016-01-12');
INSERT INTO `cndb_nutval` VALUES (5165,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5165,401,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5165,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5165,601,72,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5165,605,0.062,'100g',3,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5165,606,1.461,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5166,203,28.55,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5166,204,7.39,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5166,205,0.06,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5166,207,1.18,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5166,208,189,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5166,255,63.52,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5166,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5166,291,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5166,301,14,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5166,303,1.09,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5166,306,239,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5166,307,103,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5166,320,12,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5166,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5166,401,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5166,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5166,601,109,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5166,605,0.101,'100g',3,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5166,606,2.155,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5167,203,22.64,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5167,204,1.93,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5167,205,0.14,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5167,207,1.04,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5167,208,115,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (5167,255,75.37,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5167,269,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5167,291,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5167,301,11,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5167,303,0.86,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5167,306,235,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5167,307,118,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5167,320,9,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5167,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5167,401,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5167,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5167,601,67,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5167,605,0.007,'100g',3,1,'2006-02-23','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5167,606,0.459,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5168,203,29.06,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5168,204,3.84,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5168,205,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5168,207,1.17,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5168,208,159,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5168,255,66.7,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5168,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5168,291,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5168,301,13,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5168,303,1.03,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5168,306,239,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5168,307,101,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5168,320,4,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5168,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5168,401,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5168,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5168,601,101,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5168,605,0.049,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5168,606,1.132,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5169,203,12.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5169,204,38.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5169,205,0.16,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5169,207,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5169,208,407,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5169,255,48.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5169,269,0.1,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5169,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5169,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5169,303,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5169,306,124,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5169,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5169,320,85,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5169,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5169,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5169,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5169,601,122,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5169,605,0.557,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5169,606,10.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5170,203,23.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5170,204,39.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5170,205,0.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5170,207,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5170,208,459,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5170,255,34.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5170,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5170,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5170,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5170,303,1.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5170,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5170,307,116,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5170,320,79,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5170,328,1.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5170,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5170,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5170,601,177,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5170,605,0.568,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5170,606,11.356,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5171,203,18.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5171,204,5.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5171,205,0.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5171,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5171,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5171,255,76.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5171,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5171,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5171,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5171,303,5.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5171,306,198,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5171,307,136,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5171,320,3939,'100g',2,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5171,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5171,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5171,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5171,601,333,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5171,605,0.046,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5171,606,1.452,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5172,203,26.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5172,204,6.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5172,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5172,207,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5172,208,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5172,255,66.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5172,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5172,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5172,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5172,303,3.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5172,306,177,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5172,307,117,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5172,320,4619,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5172,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5172,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5172,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5172,601,521,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5172,605,0.045,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5172,606,1.725,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5173,203,18.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5173,204,3.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5173,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5173,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5173,208,111,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5173,255,77.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5173,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5173,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5173,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5173,303,2.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5173,306,185,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5173,307,147,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5173,320,46,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5173,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5173,401,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5173,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5173,601,271,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5173,605,0.031,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5173,606,0.929,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5174,203,26.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5174,204,4.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5174,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5174,207,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5174,208,155,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5174,255,69.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5174,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5174,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5174,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5174,303,3.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5174,306,193,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5174,307,127,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5174,320,11,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5174,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5174,401,6.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5174,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5174,601,452,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5174,605,0.026,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5174,606,1.059,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5175,203,16.7,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5175,204,7.44,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5175,205,0.4,'100g',3,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5175,207,0.99,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5175,208,140,'100g',3,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5175,255,74.47,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5175,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5175,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5175,301,18,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5175,303,3.7,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5175,306,179,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5175,307,129,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5175,320,82,'100g',1,1,'2024-12-12','2012-01-09');
INSERT INTO `cndb_nutval` VALUES (5175,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5175,401,3,'100g',1,1,'1996-09-30','2012-09-01');
INSERT INTO `cndb_nutval` VALUES (5175,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5175,601,225,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5175,605,0.084,'100g',3,1,'2006-01-24','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5175,606,1.923,'100g',3,1,'1996-09-30','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5176,203,24.88,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5176,204,7.52,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5176,205,0,'100g',3,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5176,207,1.21,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5176,208,174,'100g',3,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5176,255,67.15,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5176,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5176,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5176,301,21,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5176,303,6.96,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5176,306,203,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5176,307,140,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5176,320,16,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5176,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5176,401,0,'100g',4,1,'1996-09-30','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5176,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5176,601,359,'100g',1,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5176,605,0.061,'100g',3,1,'2006-01-24','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5176,606,1.898,'100g',3,1,'1996-09-30','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5177,203,18.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5177,204,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5177,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5177,207,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5177,208,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5177,255,75.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5177,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5177,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5177,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5177,303,8.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5177,306,214,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5177,307,131,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5177,320,8058,'100g',1,1,'2024-12-12','2012-01-09');
INSERT INTO `cndb_nutval` VALUES (5177,328,1.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5177,401,24.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5177,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5177,601,415,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5177,605,0.044,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5177,606,1.664,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5178,203,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5178,204,8.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5178,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5178,207,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5178,208,189,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5178,255,63.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5178,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5178,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5178,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5178,303,1.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5178,306,153,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5178,307,98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5178,320,10751,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5178,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5178,401,22.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5178,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5178,601,648,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5178,605,0.058,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5178,606,2.304,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5179,203,16.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5179,204,6.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5179,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5179,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5179,208,125,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5179,255,75.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5179,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5179,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5179,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5179,303,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5179,306,133,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5179,307,233,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5179,320,13,'100g',2,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5179,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5179,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5179,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5179,601,115,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5179,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5179,606,1.647,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5180,203,22.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5180,204,7.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5180,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5180,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5180,208,162,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5180,255,69.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5180,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5180,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5180,301,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5180,303,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5180,306,114,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5180,307,246,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5180,320,0,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5180,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5180,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5180,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5180,601,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5180,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5180,606,2.216,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5181,203,21.96,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5181,204,7.43,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5181,205,0.15,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5181,207,0.96,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5181,208,161,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5181,255,70.68,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5181,269,0.06,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5181,291,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5181,301,11,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5181,303,0.75,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5181,306,223,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5181,307,105,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5181,320,19,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5181,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5181,401,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5181,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5181,601,67,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5181,605,0.1,'100g',3,1,'2006-02-23','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5181,606,1.899,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5182,203,29.55,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5182,204,5.57,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5182,205,0.05,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5182,207,1.22,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5182,208,177,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5182,255,64.79,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5182,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5182,291,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5182,301,11,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5182,303,0.8,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5182,306,248,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5182,307,101,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5182,320,10,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5182,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5182,401,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5182,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5182,601,89,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5182,605,0.075,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5182,606,1.603,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5183,203,19.81,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5183,204,8.97,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5183,205,0.15,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5183,207,0.94,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5183,208,166,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (5183,255,71.1,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5183,269,0.1,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5183,291,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5183,301,11,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5183,303,1,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5183,306,208,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5183,307,113,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5183,320,26,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5183,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5183,401,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5183,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5183,601,87,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5183,605,0.099,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5183,606,2.413,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5184,203,27.27,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5184,204,9.95,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5184,205,0.07,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5184,207,1.14,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5184,208,206,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5184,255,61.66,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5184,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5184,291,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5184,301,17,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5184,303,1.45,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5184,306,228,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5184,307,105,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5184,320,14,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5184,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5184,401,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5184,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5184,601,134,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5184,605,0.137,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5184,606,2.93,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5185,203,23.66,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5185,204,1.48,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5185,205,0.14,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5185,207,1.04,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5185,208,114,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5185,255,74.89,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5185,269,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5185,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5185,301,11,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5185,303,0.73,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5185,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5185,307,113,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5185,320,6,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5185,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5185,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5185,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5185,601,57,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5185,605,0.013,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5185,606,0.289,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5186,203,30.13,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5186,204,2.08,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5186,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5186,207,1.22,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5186,208,147,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5186,255,67.88,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5186,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5186,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5186,301,9,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5186,303,0.71,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5186,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5186,307,99,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5186,320,3,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5186,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5186,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5186,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5186,601,80,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5186,605,0.024,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5186,606,0.593,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5187,203,21.28,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5187,204,2.5,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5187,205,0.15,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5187,207,1.03,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5187,208,108,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5187,255,76.01,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5187,269,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5187,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5187,301,11,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5187,303,1.04,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5187,306,226,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5187,307,124,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5187,320,13,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5187,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5187,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5187,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5187,601,79,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5187,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5187,606,0.683,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5188,203,27.71,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5188,204,6.04,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5188,205,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5188,207,1.12,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5188,208,173,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5188,255,65.23,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5188,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5188,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5188,301,17,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5188,303,1.43,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5188,306,227,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5188,307,104,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5188,320,5,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5188,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5188,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5188,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5188,601,128,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5188,605,0.08,'100g',3,1,'2006-02-23','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5188,606,1.807,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5190,203,26.59,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5190,204,14.38,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5190,205,0.16,'100g',3,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5190,207,0.93,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5190,208,244,'100g',3,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5190,255,57.94,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5190,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5190,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5190,301,33,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5190,303,2.19,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5190,306,260,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5190,307,73,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5190,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5190,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5190,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5190,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5190,601,91,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5190,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5190,606,4.18,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5191,203,21.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5191,204,7.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5191,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5191,207,0.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5191,208,157,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5191,255,70.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5191,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5191,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5191,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5191,303,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5191,306,275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5191,307,59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5191,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5191,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5191,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5191,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5191,601,65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5191,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5191,606,1.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5192,203,28.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5192,204,7.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5192,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5192,207,1.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5192,208,189,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5192,255,63.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5192,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5192,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5192,301,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5192,303,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5192,306,288,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5192,307,63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5192,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5192,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5192,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5192,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5192,601,74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5192,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5192,606,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5193,203,19.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5193,204,6.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5193,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5193,207,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5193,208,144,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5193,255,72.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5193,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5193,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5193,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5193,303,1.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5193,306,273,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5193,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5193,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5193,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5193,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5193,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5193,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5193,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5193,606,2.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5194,203,27.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5194,204,9.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5194,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5194,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5194,208,208,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5194,255,61.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5194,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5194,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5194,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5194,303,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5194,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5194,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5194,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5194,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5194,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5194,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5194,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5194,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5194,606,3.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5195,203,20.22,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5195,204,12.32,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5195,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5195,207,0.81,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5195,208,197,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5195,255,66.49,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5195,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5195,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5195,301,14,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5195,303,1.26,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5195,306,240,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5195,307,55,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5195,320,3,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5195,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5195,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5195,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5195,601,70,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5195,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5195,606,3.28,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5196,203,27.38,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5196,204,12.43,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5196,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5196,207,0.97,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5196,208,229,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5196,255,59.49,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5196,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5196,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5196,301,24,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5196,303,1.46,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5196,306,266,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5196,307,61,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5196,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5196,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5196,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5196,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5196,601,81,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5196,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5196,606,3.39,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5200,203,28.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5200,204,5.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5200,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5200,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5200,208,172,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5200,255,65.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5200,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5200,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5200,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5200,303,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5200,306,250,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5200,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5200,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5200,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5200,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5200,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5200,601,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5200,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5200,606,1.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5216,203,27.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5216,204,6.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5216,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5216,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5216,208,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5216,255,65.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5216,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5216,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5216,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5216,303,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5216,306,227,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5216,307,104,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5216,320,5,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5216,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5216,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5216,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5216,601,128,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5216,605,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5216,606,1.807,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5219,203,23.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5219,204,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5219,205,0.14,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5219,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5219,208,114,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5219,255,74.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5219,269,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5219,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5219,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5219,303,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5219,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5219,307,113,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5219,320,6,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5219,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5219,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5219,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5219,601,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5219,605,0.013,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5219,606,0.289,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5220,203,30.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5220,204,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5220,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5220,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5220,208,147,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5220,255,67.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5220,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5220,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5220,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5220,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5220,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5220,307,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5220,320,3,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5220,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5220,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5220,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5220,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5220,605,0.024,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5220,606,0.593,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5227,203,23.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5227,204,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5227,205,0.14,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5227,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5227,208,115,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (5227,255,74.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5227,269,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5227,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5227,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5227,303,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5227,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5227,307,113,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5227,320,6,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5227,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5227,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5227,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5227,601,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5227,605,0.013,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5227,606,0.289,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5228,203,30.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5228,204,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5228,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5228,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5228,208,147,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5228,255,67.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5228,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5228,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5228,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5228,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5228,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5228,307,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5228,320,3,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5228,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5228,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5228,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5228,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5228,605,0.024,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5228,606,0.593,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5236,203,19.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5236,204,44.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5236,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5236,207,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5236,208,482,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5236,255,35.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5236,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5236,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5236,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5236,303,1.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5236,306,155,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5236,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5236,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5236,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5236,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5236,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5236,601,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5236,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5236,606,11.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5277,203,21.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5277,204,7.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5277,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5277,207,1.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5277,208,165,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5277,255,68.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5277,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5277,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5277,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5277,303,1.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5277,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5277,307,503,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5277,320,34,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5277,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5277,401,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5277,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5277,601,62,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5277,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5277,606,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5282,203,11.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5282,204,43.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5282,205,4.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5282,207,3.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5282,208,462,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5282,255,37.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5282,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5282,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5282,301,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5282,303,5.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5282,306,138,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5282,307,697,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5282,320,1001,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5282,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5282,401,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5282,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5282,601,150,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5282,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5282,606,14.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5284,203,23.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5284,204,6.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5284,205,1.47,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5284,207,1.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5284,208,169,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5284,255,66.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5284,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5284,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5284,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5284,303,1.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5284,306,224,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5284,307,518,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (5284,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5284,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5284,401,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5284,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5284,601,66,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5284,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (5284,606,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5285,203,18.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5285,204,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5285,205,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5285,207,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5285,208,138,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5285,255,71.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5285,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5285,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5285,301,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5285,303,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5285,306,310,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5285,307,850,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5285,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5285,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5285,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5285,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5285,601,55,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5285,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5285,606,1.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5286,203,5.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5286,204,2.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5286,205,4.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5286,207,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5286,208,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5286,255,85.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5286,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5286,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5286,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5286,303,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5286,306,61,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5286,307,554,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5286,320,13,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5286,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5286,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5286,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5286,601,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5286,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5286,606,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5293,203,22.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5293,204,3.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5293,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5293,207,2.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5293,208,126,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5293,255,70.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5293,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5293,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5293,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5293,303,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5293,306,248,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5293,307,397,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5293,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5293,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5293,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5293,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5293,601,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5293,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5293,606,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5294,203,18.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5294,204,8.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5294,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5294,207,2.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5294,208,157,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5294,255,70.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5294,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5294,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5294,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5294,303,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5294,306,241,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5294,307,437,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5294,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5294,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5294,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5294,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5294,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5294,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5294,606,2.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5295,203,17.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5295,204,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5295,205,6.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5295,207,3.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5295,208,120,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5295,255,70.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5295,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5295,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5295,301,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5295,303,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5295,306,360,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5295,307,678,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5295,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5295,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5295,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5295,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5295,601,53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5295,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5295,606,0.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5300,203,14.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5300,204,16.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5300,205,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5300,207,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5300,208,279,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5300,255,49.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5300,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5300,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5300,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5300,303,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5300,306,260,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5300,307,838,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5300,320,12,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5300,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5300,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5300,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5300,601,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5300,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5300,606,4.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5301,203,11.39,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5301,204,24.73,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5301,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5301,207,0.96,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5301,208,272,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5301,255,62.66,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5301,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5301,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5301,301,138,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5301,303,1.57,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5301,306,104,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5301,307,40,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5301,320,74,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5301,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5301,401,1.5,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5301,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5301,601,130,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5301,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5301,606,7.45,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5302,203,13.79,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5302,204,15.48,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5302,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5302,207,1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5302,208,199,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5302,255,69.29,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5302,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5302,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5302,301,123,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5302,303,1.73,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5302,306,128,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5302,307,51,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5302,320,32,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5302,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5302,401,3,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5302,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5302,601,104,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5302,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5302,606,4.71,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5303,203,14.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5303,204,19.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5303,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5303,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5303,208,243,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5303,255,62.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5303,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5303,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5303,301,187,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5303,303,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5303,306,104,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5303,307,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5303,320,45,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5303,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5303,401,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5303,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5303,601,143,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5303,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5303,606,4.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5304,203,13.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5304,204,15.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5304,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5304,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5304,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5304,255,69.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5304,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5304,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5304,301,145,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5304,303,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5304,306,173,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5304,307,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5304,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (5304,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5304,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5304,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5304,601,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5304,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5304,606,5.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5305,203,19.66,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5305,204,7.66,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5305,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5305,207,1,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5305,208,148,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5305,255,72.36,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5305,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5305,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5305,301,19,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5305,303,1.09,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5305,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5305,307,58,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5305,320,20,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5305,328,0.4,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5305,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (5305,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5305,601,69,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5305,605,0.103,'100g',3,1,'2006-01-24','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5305,606,2.024,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5306,203,27.37,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5306,204,10.4,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5306,205,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5306,207,1.26,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5306,208,203,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5306,255,62.07,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5306,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5306,291,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5306,301,28,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5306,303,1.52,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5306,306,294,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5306,307,78,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5306,320,24,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5306,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5306,401,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5306,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5306,601,93,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5306,605,0.134,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5306,606,2.669,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5307,203,17.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5307,204,14.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5307,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5307,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5307,208,200,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5307,255,68.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5307,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5307,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5307,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5307,303,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5307,306,236,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5307,307,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5307,320,32,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (5307,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5307,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5307,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5307,601,101,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5307,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5307,606,3.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5308,203,22.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5308,204,18.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5308,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5308,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5308,208,259,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5308,255,58.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5308,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5308,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5308,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5308,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5308,306,245,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5308,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5308,320,32,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5308,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5308,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5308,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5308,601,131,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5308,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5308,606,5.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5309,203,20.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5309,204,3.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5309,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5309,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5309,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5309,255,75.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5309,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5309,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5309,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5309,303,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5309,306,269,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5309,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5309,320,22,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (5309,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5309,401,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5309,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5309,601,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5309,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5309,606,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5310,203,23.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5310,204,3.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5310,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5310,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5310,208,134,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5310,255,71.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5310,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5310,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5310,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5310,303,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5310,306,250,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5310,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5310,320,20,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5310,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5310,401,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5310,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5310,601,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5310,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5310,606,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5311,203,25.3,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5311,204,8.1,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5311,205,0.9,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5311,207,0.8,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5311,208,185,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5311,255,64.9,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5311,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5311,291,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5311,301,14,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5311,303,1.3,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5311,306,153,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5311,307,482,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (5311,320,53,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5311,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5311,401,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5311,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5311,601,50,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5311,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5311,606,2.25,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (5312,203,19.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5312,204,12.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5312,205,3.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5312,207,2.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5312,208,211,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5312,255,61.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5312,269,2.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5312,291,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5312,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5312,303,2.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5312,306,190,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5312,307,615,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5312,320,17,'100g',1,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (5312,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5312,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5312,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5312,601,126,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5312,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5312,606,3.321,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5313,203,25.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5313,204,13.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5313,205,3.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5313,207,3.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5313,208,248,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5313,255,53.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5313,269,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5313,291,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5313,301,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5313,303,2.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5313,306,254,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5313,307,837,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5313,320,20,'100g',1,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (5313,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5313,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5313,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5313,601,156,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5313,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5313,606,3.655,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5314,203,20.32,'100g',1,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5314,204,3,'100g',1,1,'2010-01-04','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5314,205,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5314,207,1.36,'100g',1,1,'2010-01-04','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5314,208,108,'100g',3,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5314,255,75.59,'100g',1,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5314,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5314,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5314,301,5,'100g',1,1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5314,303,0.34,'100g',1,1,'2010-01-04','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5314,306,332,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5314,307,173,'100g',1,1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5314,320,11,'100g',1,1,'2024-12-12','2013-01-06');
INSERT INTO `cndb_nutval` VALUES (5314,328,0,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (5314,401,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5314,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5314,601,64,'100g',1,1,'2010-01-04','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5314,605,0.006,'100g',3,1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5314,606,0.545,'100g',3,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5315,203,24.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5315,204,10.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5315,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5315,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5315,208,202,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5315,255,63.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5315,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5315,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5315,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5315,303,3.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5315,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5315,307,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5315,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (5315,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5315,401,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5315,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5315,601,136,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5315,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5315,606,2.922,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5316,203,27.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5316,204,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5316,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5316,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5316,208,140,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5316,255,68.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5316,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5316,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5316,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5316,303,4.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5316,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5316,307,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5316,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (5316,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5316,401,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5316,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5316,601,143,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5316,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5316,606,0.578,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5317,203,26.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5317,204,11.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5317,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5317,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5317,208,217,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5317,255,60.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5317,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5317,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5317,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5317,303,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5317,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5317,307,110,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5317,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (5317,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5317,401,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5317,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5317,601,114,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5317,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5317,606,2.975,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5318,203,29.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5318,204,5.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5318,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5318,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5318,208,178,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5318,255,64.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5318,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5318,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5318,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5318,303,2.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5318,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5318,307,108,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5318,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (5318,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5318,401,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5318,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5318,601,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5318,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5318,606,1.339,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5319,203,27.71,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5319,204,6.76,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5319,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5319,207,1.8,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5319,208,172,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5319,255,64.11,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5319,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5319,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5319,301,20,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5319,303,1.05,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5319,306,291,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5319,307,403,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5319,320,10,'100g',2,1,'2024-12-12','2013-01-07');
INSERT INTO `cndb_nutval` VALUES (5319,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5319,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5319,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5319,601,155,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5319,605,NULL,'100g',NULL,1,'2013-02-22','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (5319,606,1.573,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5320,203,22.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5320,204,14.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5320,205,3.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5320,207,2.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5320,208,242,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5320,255,57.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5320,269,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5320,291,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5320,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5320,303,1.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5320,306,218,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5320,307,559,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5320,320,21,'100g',1,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (5320,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5320,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5320,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5320,601,136,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5320,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5320,606,3.966,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5323,203,14.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5323,204,20.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5323,205,13.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5323,207,1.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5323,208,292,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5323,255,50.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5323,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5323,291,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5323,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5323,303,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5323,306,248,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5323,307,518,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5323,320,11,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (5323,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5323,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5323,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5323,601,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5323,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5323,606,4.013,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5324,203,14.85,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5324,204,19.58,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5324,205,12.84,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5324,207,1.92,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5324,208,287,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5324,255,50.82,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5324,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5324,291,0.3,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5324,301,19,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5324,303,0.95,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5324,306,261,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5324,307,532,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5324,320,0,'100g',2,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (5324,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5324,401,0,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5324,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5324,601,43,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5324,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5324,606,3.662,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5326,203,16.35,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5326,204,12.89,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5326,205,17.56,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5326,207,1.87,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5326,208,252,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5326,255,51.34,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5326,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5326,291,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5326,301,14,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5326,303,1,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5326,306,225,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5326,307,446,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5326,320,0,'100g',2,1,'2024-12-12','2012-01-12');
INSERT INTO `cndb_nutval` VALUES (5326,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5326,401,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5326,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5326,601,45,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5326,605,NULL,'100g',NULL,1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (5326,606,3.2,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5327,203,14.73,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5327,204,15.75,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5327,205,15.01,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5327,207,1.77,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5327,208,263,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5327,255,52.74,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5327,269,0.37,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5327,291,1.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5327,301,19,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5327,303,1.11,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5327,306,214,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5327,307,536,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5327,320,0,'100g',2,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (5327,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5327,401,0.8,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5327,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5327,601,41,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5327,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (5327,606,3.26,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5332,203,17.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5332,204,8.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5332,205,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5332,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5332,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5332,255,73.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5332,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5332,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5332,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5332,303,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5332,306,522,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5332,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5332,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (5332,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5332,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5332,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5332,601,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5332,605,0.065,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5332,606,2.301,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5333,203,23.28,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5333,204,10.92,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5333,205,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5333,207,1.57,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5333,208,189,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5333,255,64.92,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5333,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5333,291,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5333,301,8,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5333,303,0.93,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5333,306,677,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5333,307,75,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5333,320,0,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (5333,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5333,401,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5333,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5333,601,107,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5333,605,0.087,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5333,606,3.11,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (5334,203,24.09,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5334,204,10.74,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5334,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5334,207,1.4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5334,208,193,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5334,255,64.35,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5334,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5334,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5334,301,13,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5334,303,0.97,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5334,306,262,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5334,307,335,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5334,320,13,'100g',2,1,'2024-12-12','2012-01-05');
INSERT INTO `cndb_nutval` VALUES (5334,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5334,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5334,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5334,601,128,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5334,605,NULL,'100g',NULL,1,'2013-02-22','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (5334,606,2.777,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5335,203,19.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5335,204,14.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5335,205,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5335,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5335,208,215,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5335,255,65.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5335,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5335,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5335,301,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5335,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5335,306,31,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5335,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5335,320,30,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (5335,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5335,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5335,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5335,601,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5335,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5335,606,3.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5339,203,28.34,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5339,204,7.79,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5339,205,0.54,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5339,207,0.98,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5339,208,186,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (5339,255,62.87,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5339,269,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5339,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5339,301,32,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5339,303,0.97,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5339,306,322,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5339,307,725,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5339,320,11,'100g',1,1,'2024-12-12','2012-01-05');
INSERT INTO `cndb_nutval` VALUES (5339,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5339,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5339,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5339,601,134,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5339,605,NULL,'100g',NULL,1,'2013-02-22','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (5339,606,2.134,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5341,203,25.34,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5341,204,11.54,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5341,205,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5341,207,2.61,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5341,208,205,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5341,255,61.24,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5341,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5341,291,0,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5341,301,38,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5341,303,0.97,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5341,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5341,307,661,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5341,320,17,'100g',1,1,'2024-12-12','2007-01-06');
INSERT INTO `cndb_nutval` VALUES (5341,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5341,401,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5341,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5341,601,123,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5341,605,0.146,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5341,606,3.007,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5342,203,28,'100g',1,1,'2009-01-25','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5342,204,2.79,'100g',1,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5342,205,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5342,207,1.67,'100g',1,1,'2009-01-25','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5342,208,137,'100g',3,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5342,255,68.23,'100g',1,1,'2009-01-25','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5342,269,0,'100g',4,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5342,291,0,'100g',4,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5342,301,13,'100g',1,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5342,303,0.45,'100g',1,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5342,306,303,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5342,307,313,'100g',1,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5342,320,5,'100g',1,1,'2024-12-12','2007-01-06');
INSERT INTO `cndb_nutval` VALUES (5342,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5342,401,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5342,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5342,601,86,'100g',1,1,'2009-01-25','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5342,605,0.009,'100g',3,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5342,606,0.775,'100g',3,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5343,203,28.74,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5343,204,6.81,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5343,205,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5343,207,1.91,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5343,208,176,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5343,255,63.05,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5343,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5343,291,0,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5343,301,21,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5343,303,1.09,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5343,306,301,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5343,307,417,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5343,320,10,'100g',1,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (5343,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5343,401,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5343,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5343,601,160,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5343,605,0.077,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5343,606,1.594,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5344,203,17.66,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5344,204,37.24,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5344,205,0.11,'100g',3,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5344,207,1.7,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5344,208,406,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5344,255,43.76,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5344,269,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5344,291,0,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5344,301,25,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5344,303,0.98,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5344,306,245,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5344,307,381,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5344,320,56,'100g',1,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (5344,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5344,401,0,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5344,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5344,601,141,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5344,605,0.456,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5344,606,9.994,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5345,203,24.06,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5345,204,11.09,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5345,205,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5345,207,1.56,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5345,208,196,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5345,255,63.89,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5345,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5345,291,0,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5345,301,13,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5345,303,0.97,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5345,306,264,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5345,307,337,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5345,320,13,'100g',1,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (5345,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5345,401,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5345,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5345,601,130,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5345,605,0.131,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5345,606,2.866,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5346,203,27.69,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5346,204,9.53,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5346,205,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5346,207,2.65,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5346,208,197,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5346,255,61.13,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5346,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5346,291,0,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5346,301,32,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5346,303,0.97,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5346,306,322,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5346,307,725,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5346,320,11,'100g',1,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (5346,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5346,401,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5346,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5346,601,140,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5346,605,0.104,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5346,606,2.223,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5347,203,23.23,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5347,204,18.59,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5347,205,0.03,'100g',3,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5347,207,2.36,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5347,208,260,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5347,255,56.44,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5347,269,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5347,291,0,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5347,301,35,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5347,303,0.97,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5347,306,291,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5347,307,584,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5347,320,28,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (5347,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5347,401,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5347,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5347,601,128,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5347,605,0.231,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5347,606,4.924,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5348,203,27.48,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5348,204,8.18,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5348,205,0.02,'100g',3,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5348,207,1.72,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5348,208,184,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5348,255,63.49,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5348,269,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5348,291,0,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5348,301,15,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5348,303,0.55,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5348,306,289,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5348,307,347,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5348,320,12,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (5348,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5348,401,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5348,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5348,601,96,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5348,605,0.099,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5348,606,2.114,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5349,203,26.86,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5349,204,11.98,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5349,205,0.02,'100g',3,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5349,207,1.87,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5349,208,215,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5349,255,59.78,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5349,269,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5349,291,0,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5349,301,21,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5349,303,1.07,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5349,306,291,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5349,307,411,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5349,320,18,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (5349,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5349,401,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5349,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5349,601,156,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5349,605,0.141,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5349,606,3.02,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5351,203,22.93,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5351,204,15.7,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5351,205,0.02,'100g',3,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5351,207,1.58,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5351,208,233,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5351,255,60.34,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5351,269,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5351,291,0,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5351,301,15,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5351,303,0.97,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5351,306,260,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5351,307,345,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5351,320,21,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (5351,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5351,401,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5351,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5351,601,132,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5351,605,0.188,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5351,606,4.123,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5352,203,24.34,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5352,204,18.77,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5352,205,0.04,'100g',3,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5352,207,2.33,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5352,208,266,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5352,255,55.34,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5352,269,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5352,291,0,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5352,301,29,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5352,303,0.97,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5352,306,296,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5352,307,610,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5352,320,26,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (5352,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5352,401,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5352,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5352,601,140,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5352,605,0.221,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5352,606,4.814,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (5356,203,15.19,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5356,204,35.15,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5356,205,0.7,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5356,207,1.52,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5356,208,378,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5356,255,47.81,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5356,269,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5356,291,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5356,301,34,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5356,303,0.86,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5356,306,223,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5356,307,335,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5356,320,51,'100g',1,1,'2024-12-12','2012-01-05');
INSERT INTO `cndb_nutval` VALUES (5356,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5356,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5356,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5356,601,120,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5356,605,0.438,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5356,606,9.333,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5357,203,20.29,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5357,204,18.86,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5357,205,0.4,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5357,207,1.43,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5357,208,251,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5357,255,59.41,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5357,269,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5357,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5357,301,33,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5357,303,0.83,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5357,306,254,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5357,307,509,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5357,320,24,'100g',1,1,'2024-12-12','2012-01-09');
INSERT INTO `cndb_nutval` VALUES (5357,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5357,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5357,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5357,601,118,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5357,605,0.103,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5357,606,4.953,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5358,203,26.37,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5358,204,7.67,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5358,205,0.09,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5358,207,1.42,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5358,208,175,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5358,255,65.19,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5358,269,0.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5358,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5358,301,16,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5358,303,0.51,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5358,306,276,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5358,307,329,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5358,320,11,'100g',2,1,'2024-12-12','2012-01-05');
INSERT INTO `cndb_nutval` VALUES (5358,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5358,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5358,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5358,601,90,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5358,605,0.057,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5358,606,1.958,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5359,203,25.65,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5359,204,11.46,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5359,205,0.12,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5359,207,1.75,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5359,208,206,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5359,255,61.42,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5359,269,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5359,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5359,301,22,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5359,303,1.02,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5359,306,279,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5359,307,392,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5359,320,17,'100g',2,1,'2024-12-12','2012-01-05');
INSERT INTO `cndb_nutval` VALUES (5359,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5359,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5359,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5359,601,149,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5359,605,0.072,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5359,606,2.855,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5361,203,22.51,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5361,204,15.08,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5361,205,0.12,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5361,207,1.42,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5361,208,226,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5361,255,61.41,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5361,269,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5361,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5361,301,16,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5361,303,0.95,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5361,306,255,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5361,307,335,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5361,320,20,'100g',2,1,'2024-12-12','2012-01-05');
INSERT INTO `cndb_nutval` VALUES (5361,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5361,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5361,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5361,601,127,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5361,605,0.078,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5361,606,3.927,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5362,203,23.42,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5362,204,18.04,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5362,205,0.6,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5362,207,1.18,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5362,208,257,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5362,255,57.23,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5362,269,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5362,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5362,301,33,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5362,303,0.93,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5362,306,285,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5362,307,579,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5362,320,26,'100g',2,1,'2024-12-12','2012-01-05');
INSERT INTO `cndb_nutval` VALUES (5362,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5362,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5362,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5362,601,129,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5362,605,0.164,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5362,606,4.627,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5363,203,25.94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (5363,204,0.88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (5363,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (5363,207,1.07,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (5363,208,112,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (5363,255,72.93,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (5363,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (5363,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (5363,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (5363,303,0.58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (5363,306,311,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5363,307,50,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (5363,320,5,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (5363,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5363,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (5363,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5363,601,40,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (5363,605,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (5363,606,0.13,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (5621,203,22.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5621,204,4.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5621,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5621,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5621,208,134,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5621,255,72.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5621,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5621,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5621,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5621,303,4.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5621,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5621,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5621,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (5621,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5621,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5621,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5621,601,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5621,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5621,606,1.022,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5622,203,28.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5622,204,4.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5622,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5622,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5622,208,163,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5622,255,65.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5622,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5622,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5622,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5622,303,5.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5622,306,375,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5622,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5622,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (5622,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5622,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5622,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5622,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5622,605,0.153,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5622,606,1.242,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5623,203,22.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5623,204,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5623,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5623,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5623,208,103,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5623,255,74.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5623,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5623,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5623,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5623,303,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5623,306,300,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5623,307,120,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5623,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5623,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5623,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5623,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5623,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5623,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5623,606,0.201,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5624,203,31.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5624,204,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5624,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5624,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5624,208,154,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5624,255,66.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5624,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5624,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5624,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5624,303,4.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5624,306,397,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5624,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5624,320,0,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (5624,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5624,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5624,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5624,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5624,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5624,606,0.583,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5625,203,22.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5625,204,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5625,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5625,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5625,208,102,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5625,255,75.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5625,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5625,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5625,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5625,303,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5625,306,240,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5625,307,150,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5625,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5625,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5625,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5625,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5625,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5625,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5625,606,0.187,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5626,203,22.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5626,204,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5626,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5626,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5626,208,112,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5626,255,73.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5626,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5626,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5626,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5626,303,4.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5626,306,330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5626,307,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5626,320,4,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (5626,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5626,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5626,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5626,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5626,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5626,606,0.448,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5627,203,33.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5627,204,2.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5627,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5627,207,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5627,208,168,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5627,255,61.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5627,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5627,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5627,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5627,303,6.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5627,306,324,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5627,307,110,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5627,320,3,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5627,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5627,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5627,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5627,601,129,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5627,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5627,606,0.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5628,203,22.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5628,204,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5628,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5628,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5628,208,108,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5628,255,74.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5628,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5628,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5628,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5628,303,5.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5628,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5628,307,102,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5628,320,5,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5628,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5628,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5628,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5628,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5628,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5628,606,0.386,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5629,203,32.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5629,204,2.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5629,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5629,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5629,208,156,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5629,255,64.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5629,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5629,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5629,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5629,303,7.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5629,306,312,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5629,307,118,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5629,320,3,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5629,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5629,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5629,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5629,601,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5629,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5629,606,0.654,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5630,203,23.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5630,204,0.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5630,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5630,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5630,208,103,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5630,255,74.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5630,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5630,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5630,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5630,303,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5630,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5630,307,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5630,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5630,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5630,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5630,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5630,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5630,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5630,606,0.122,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5631,203,22.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5631,204,4.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5631,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5631,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5631,208,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5631,255,72.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5631,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5631,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5631,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5631,303,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5631,306,250,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5631,307,150,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5631,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5631,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5631,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5631,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5631,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5631,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5631,606,1.231,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5632,203,29.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5632,204,3.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5632,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5632,207,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5632,208,152,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5632,255,67.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5632,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5632,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5632,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5632,303,5.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5632,306,374,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5632,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5632,320,0,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (5632,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5632,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5632,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5632,601,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5632,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5632,606,0.794,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5641,203,20.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5641,204,8.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5641,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5641,207,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5641,208,165,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5641,255,71.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5641,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5641,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5641,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5641,303,2.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5641,306,291,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5641,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5641,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (5641,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5641,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5641,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5641,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5641,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5641,606,2.177,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5642,203,26.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5642,204,7.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5642,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5642,207,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5642,208,175,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5642,255,67.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5642,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5642,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5642,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5642,303,3.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5642,306,323,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5642,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5642,320,0,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5642,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5642,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5642,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5642,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5642,605,0.233,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5642,606,1.793,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5643,203,21.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5643,204,2.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5643,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5643,207,0.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5643,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5643,255,75.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5643,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5643,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5643,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5643,303,4.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5643,306,308,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5643,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5643,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5643,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5643,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5643,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5643,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5643,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5643,606,0.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5644,203,22.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5644,204,1.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5644,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5644,207,0.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5644,208,111,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5644,255,75.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5644,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5644,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5644,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5644,303,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5644,306,320,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5644,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5644,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5644,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5644,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5644,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5644,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5644,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5644,606,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5645,203,29.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5645,204,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5645,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5645,207,0.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5645,208,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5645,255,69.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5645,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5645,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5645,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5645,303,3.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5645,306,352,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5645,307,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5645,320,0,'100g',2,1,'2024-12-12','2002-01-02');
INSERT INTO `cndb_nutval` VALUES (5645,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5645,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5645,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5645,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5645,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5645,606,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5646,203,23.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5646,204,2.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5646,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5646,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5646,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5646,255,74.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5646,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5646,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5646,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5646,303,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5646,306,330,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5646,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5646,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5646,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5646,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5646,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5646,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5646,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5646,606,0.923,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5647,203,29.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5647,204,4.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5647,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5647,207,0.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5647,208,164,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5647,255,66.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5647,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5647,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5647,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5647,303,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5647,306,366,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5647,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5647,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5647,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5647,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5647,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5647,601,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5647,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5647,606,1.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5648,203,22.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5648,204,1.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5648,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5648,207,0.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5648,208,115,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5648,255,75.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5648,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5648,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5648,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5648,303,2.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5648,306,322,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5648,307,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5648,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5648,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5648,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5648,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5648,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5648,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5648,606,0.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5649,203,23.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5649,204,2.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5649,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5649,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5649,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5649,255,74.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5649,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5649,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5649,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5649,303,3.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5649,306,333,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5649,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5649,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5649,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5649,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5649,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5649,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5649,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5649,606,0.771,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5650,203,28.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5650,204,3.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5650,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5650,207,0.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5650,208,156,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5650,255,66.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5650,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5650,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5650,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5650,303,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5650,306,367,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5650,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5650,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5650,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5650,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5650,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5650,601,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5650,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5650,606,1.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5651,203,21.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5651,204,3.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5651,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5651,207,0.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5651,208,125,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5651,255,75.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5651,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5651,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5651,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5651,303,3.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5651,306,297,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5651,307,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5651,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5651,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5651,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5651,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5651,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5651,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5651,606,1.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5652,203,28.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5652,204,3.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5652,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5652,207,0.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5652,208,159,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5652,255,67.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5652,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5652,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5652,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5652,303,4.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5652,306,409,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5652,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5652,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5652,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5652,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5652,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5652,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5652,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5652,606,1.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5653,203,21.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5653,204,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5653,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5653,207,0.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5653,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5653,255,75.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5653,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5653,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5653,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5653,303,3.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5653,306,315,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5653,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5653,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5653,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5653,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5653,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5653,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5653,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5653,606,0.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5654,203,22.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5654,204,3.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5654,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5654,207,0.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5654,208,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5654,255,74.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5654,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5654,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5654,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5654,303,4.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5654,306,320,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5654,307,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5654,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5654,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5654,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5654,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5654,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5654,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5654,606,1.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5655,203,21.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5655,204,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5655,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5655,207,0.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5655,208,114,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5655,255,76.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5655,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5655,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5655,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5655,303,2.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5655,306,310,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5655,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5655,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5655,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5655,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5655,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5655,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5655,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5655,606,0.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5656,203,28.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5656,204,2.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5656,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5656,207,0.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5656,208,145,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5656,255,68.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5656,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5656,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5656,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5656,303,2.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5656,306,362,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5656,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5656,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5656,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5656,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5656,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5656,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5656,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5656,606,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5657,203,21.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5657,204,2.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5657,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5657,207,0.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5657,208,119,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5657,255,75.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5657,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5657,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5657,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5657,303,3.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5657,306,312,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5657,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5657,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (5657,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5657,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5657,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5657,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5657,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5657,606,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5658,203,28.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5658,204,3.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5658,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5658,207,0.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5658,208,155,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5658,255,67.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5658,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5658,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5658,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5658,303,3.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5658,306,353,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5658,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5658,320,0,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (5658,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5658,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5658,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5658,601,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5658,605,0.128,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5658,606,1.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5661,203,25.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5661,204,6.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5661,205,1.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5661,207,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5661,208,172,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5661,255,65.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5661,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5661,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5661,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5661,303,12.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5661,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5661,307,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5661,320,4296,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (5661,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5661,401,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5661,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5661,601,564,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5661,605,0.098,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5661,606,2.033,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5662,203,23.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5662,204,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5662,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5662,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5662,208,112,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5662,255,74.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5662,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5662,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5662,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5662,303,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5662,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5662,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5662,320,7,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5662,328,0.4,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5662,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5662,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5662,601,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5662,605,0.017,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5662,606,0.487,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5663,203,31.69,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5663,204,2.71,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5663,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5663,207,1.42,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5663,208,151,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5663,255,65.76,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5663,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5663,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5663,301,6,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5663,303,1.02,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5663,306,357,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5663,307,61,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5663,320,9,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5663,328,0.2,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5663,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5663,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5663,601,71,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5663,605,0.024,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5663,606,0.717,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5664,203,28.99,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5664,204,2.48,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5664,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5664,207,1.29,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5664,208,138,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5664,255,68.4,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5664,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5664,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5664,301,6,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5664,303,0.78,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5664,306,339,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5664,307,59,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5664,320,8,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5664,328,0.2,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5664,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5664,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5664,601,65,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5664,605,0.023,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5664,606,0.673,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5665,203,18.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5665,204,8.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5665,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5665,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5665,208,150,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5665,255,72.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5665,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5665,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5665,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5665,303,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5665,306,213,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5665,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5665,320,22,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5665,328,0.4,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5665,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5665,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5665,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5665,605,0.112,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5665,606,2.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5666,203,27.1,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5666,204,11.6,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5666,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5666,207,1.27,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5666,208,213,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5666,255,61.05,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5666,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5666,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5666,301,31,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5666,303,1.56,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5666,306,304,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5666,307,90,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5666,320,30,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5666,328,0.2,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5666,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5666,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5666,601,104,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5666,605,0.144,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5666,606,2.966,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5667,203,25.86,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5667,204,11.45,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5667,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5667,207,1.07,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5667,208,207,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5667,255,62.42,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5667,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5667,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5667,301,29,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5667,303,1.73,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5667,306,247,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5667,307,91,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5667,320,31,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5667,328,0.2,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5667,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5667,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5667,601,106,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5667,605,0.143,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5667,606,2.958,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5668,203,16.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5668,204,12.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5668,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5668,207,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5668,208,180,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5668,255,69.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5668,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5668,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5668,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5668,303,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5668,306,202,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5668,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5668,320,30,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5668,328,0.4,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5668,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5668,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5668,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5668,605,0.181,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5668,606,3.414,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5669,203,25.11,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5669,204,17.45,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5669,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5669,207,1.32,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5669,208,258,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5669,255,56.66,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5669,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5669,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5669,301,49,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5669,303,1.98,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5669,306,276,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5669,307,85,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5669,320,35,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5669,328,0.2,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5669,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5669,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5669,601,106,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5669,605,0.243,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5669,606,4.572,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5670,203,25.88,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5670,204,16.2,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5670,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5670,207,1.2,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5670,208,249,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5670,255,58.25,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5670,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5670,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5670,301,48,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5670,303,2.04,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5670,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5670,307,81,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5670,320,29,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (5670,328,0.2,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5670,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5670,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5670,601,105,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5670,605,0.224,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5670,606,4.127,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (5671,203,23.93,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5671,204,5.95,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5671,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5671,207,0.98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5671,208,149,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5671,255,69.94,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5671,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5671,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5671,301,12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5671,303,0.94,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5671,306,239,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5671,307,117,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5671,320,7,'100g',1,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (5671,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5671,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5671,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5671,601,132,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5671,605,0.03,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5671,606,1.601,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5672,203,24.55,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5672,204,8.63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5672,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5672,207,0.99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5672,208,176,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5672,255,66.87,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5672,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5672,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5672,301,12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5672,303,1.27,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5672,306,266,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5672,307,77,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5672,320,8,'100g',1,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (5672,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5672,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5672,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5672,601,141,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5672,605,0.046,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5672,606,2.346,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5673,203,14.61,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5673,204,42.76,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5673,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5673,207,0.63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5673,208,443,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5673,255,42.09,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5673,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5673,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5673,301,9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5673,303,1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5673,306,161,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5673,307,75,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5673,320,48,'100g',1,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (5673,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5673,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5673,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5673,601,130,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5673,605,0.225,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5673,606,11.914,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5674,203,9.58,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5674,204,44.23,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5674,205,0.79,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5674,207,0.49,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5674,208,440,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5674,255,44.91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5674,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5674,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5674,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5674,303,0.37,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5674,306,119,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5674,307,51,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5674,320,59,'100g',1,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (5674,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5674,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5674,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5674,601,105,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5674,605,0.229,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5674,606,12.102,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5675,203,16.57,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5675,204,43.99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5675,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5675,207,0.72,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5675,208,462,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5675,255,39.45,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5675,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5675,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5675,301,10,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5675,303,0.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5675,306,181,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5675,307,85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5675,320,54,'100g',1,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (5675,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5675,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5675,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5675,601,132,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5675,605,0.246,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5675,606,12.146,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5676,203,22.72,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5676,204,10.73,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5676,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5676,207,0.93,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5676,208,187,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5676,255,66.33,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5676,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5676,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5676,301,12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5676,303,0.94,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5676,306,229,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5676,307,111,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5676,320,12,'100g',2,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (5676,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5676,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5676,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5676,601,132,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5676,605,0.055,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5676,606,2.939,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5677,203,22.57,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5677,204,15.43,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5677,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5677,207,0.91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5677,208,229,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5677,255,61.93,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5677,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5677,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5677,301,11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5677,303,1.21,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5677,306,245,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5677,307,76,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5677,320,16,'100g',2,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (5677,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5677,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5677,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5677,601,139,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5677,605,0.082,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5677,606,4.253,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (5678,203,19.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5678,204,3.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5678,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5678,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5678,208,106,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5678,255,77.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5678,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5678,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5678,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5678,303,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5678,306,192,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5678,307,152,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5678,320,8,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (5678,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5678,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5678,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5678,601,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5678,605,0.021,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5678,606,0.954,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5679,203,25.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5679,204,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5679,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5679,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5679,208,146,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5679,255,69.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5679,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5679,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5679,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5679,303,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5679,306,250,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5679,307,190,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5679,320,6,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (5679,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5679,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5679,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5679,601,124,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5679,605,0.028,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5679,606,1.438,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5680,203,22.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5680,204,6.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5680,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5680,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5680,208,149,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5680,255,70.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5680,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5680,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5680,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5680,303,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5680,306,229,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5680,307,169,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5680,320,7,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (5680,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5680,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5680,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5680,601,135,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5680,605,0.035,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5680,606,1.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5681,203,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5681,204,7.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5681,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5681,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5681,208,164,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5681,255,68.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5681,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5681,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5681,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5681,303,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5681,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5681,307,197,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5681,320,8,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (5681,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5681,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5681,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5681,601,126,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5681,605,0.035,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5681,606,2.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5682,203,19.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5682,204,3.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5682,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5682,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5682,208,110,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5682,255,77.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5682,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5682,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5682,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5682,303,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5682,306,234,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5682,307,156,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5682,320,6,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (5682,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5682,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5682,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5682,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5682,605,0.017,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5682,606,0.899,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5683,203,24.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5683,204,7.73,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5683,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5683,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5683,208,164,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5683,255,67.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5683,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5683,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5683,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5683,303,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5683,306,268,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5683,307,177,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5683,320,8,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (5683,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5683,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5683,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5683,601,122,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5683,605,0.046,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5683,606,2.405,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5684,203,12.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5684,204,38.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5684,205,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5684,207,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5684,208,403,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5684,255,46.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5684,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5684,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5684,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5684,303,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5684,306,146,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5684,307,139,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5684,320,44,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (5684,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5684,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5684,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5684,601,124,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5684,605,0.245,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5684,606,10.605,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5685,203,11.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5685,204,37.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5685,205,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5685,207,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5685,208,386,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5685,255,50.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5685,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5685,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5685,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5685,303,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5685,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5685,307,139,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5685,320,56,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (5685,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5685,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5685,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5685,601,113,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5685,605,0.231,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5685,606,10.565,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5686,203,20.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5686,204,37.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5686,205,0.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5686,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5686,208,421,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5686,255,40.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5686,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5686,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5686,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5686,303,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5686,306,198,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5686,307,162,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5686,320,53,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (5686,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5686,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5686,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5686,601,154,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5686,605,0.27,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5686,606,11,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5687,203,21.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5687,204,10.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5687,205,0.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5687,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5687,208,183,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5687,255,67.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5687,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5687,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5687,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5687,303,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5687,306,218,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5687,307,165,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5687,320,12,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (5687,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5687,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5687,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5687,601,133,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5687,605,0.063,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5687,606,2.923,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5688,203,18.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5688,204,8.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5688,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5688,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5688,208,146,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5688,255,73.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5688,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5688,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5688,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5688,303,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5688,306,179,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5688,307,150,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5688,320,15,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (5688,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5688,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5688,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5688,601,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5688,605,0.051,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5688,606,2.334,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5689,203,24.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5689,204,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5689,205,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5689,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5689,208,180,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5689,255,65.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5689,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5689,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5689,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5689,303,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5689,306,244,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5689,307,186,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5689,320,12,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (5689,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5689,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5689,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5689,601,128,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5689,605,0.059,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5689,606,2.656,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5690,203,20.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5690,204,14.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5690,205,0.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5690,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5690,208,215,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5690,255,63.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5690,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5690,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5690,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5690,303,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5690,306,259,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5690,307,185,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5690,320,15,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (5690,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5690,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5690,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5690,601,125,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5690,605,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5690,606,3.881,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5691,203,16.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5691,204,14.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5691,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5691,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5691,208,197,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5691,255,68.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5691,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5691,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5691,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5691,303,0.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5691,306,191,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5691,307,151,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5691,320,22,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (5691,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5691,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5691,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5691,601,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5691,605,0.085,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5691,606,3.975,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5692,203,23.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5692,204,13.81,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5692,205,0.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5692,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5692,208,214,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5692,255,62.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5692,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5692,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5692,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5692,303,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5692,306,254,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5692,307,174,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5692,320,17,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (5692,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5692,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5692,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5692,601,128,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5692,605,0.091,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5692,606,4.145,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5693,203,21.85,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5693,204,13.87,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5693,205,0.31,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5693,207,1.4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5693,208,212,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5693,255,62.96,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5693,269,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5693,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5693,301,33,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5693,303,0.82,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5693,306,263,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5693,307,563,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5693,320,15,'100g',1,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (5693,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5693,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5693,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5693,601,117,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5693,605,NULL,'100g',NULL,1,'2013-02-22','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (5693,606,3.613,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5694,203,19.27,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5694,204,4.12,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5694,205,0.1,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5694,207,1.19,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5694,208,115,'100g',3,1,'2013-02-22','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5694,255,75.86,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5694,269,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5694,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5694,301,15,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5694,303,0.9,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5694,306,226,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5694,307,167,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5694,320,13,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5694,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5694,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5694,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5694,601,79,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5694,605,0.052,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5694,606,1.124,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5695,203,26.1,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5695,204,6,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5695,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5695,207,1.24,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5695,208,158,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5695,255,66.85,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5695,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5695,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5695,301,16,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5695,303,1.07,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5695,306,227,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5695,307,201,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5695,320,5,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5695,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5695,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5695,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5695,601,105,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5695,605,0.08,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5695,606,1.807,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5696,203,21.54,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5696,204,1.66,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5696,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5696,207,1.42,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5696,208,101,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5696,255,76.42,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5696,269,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5696,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5696,301,14,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5696,303,0.54,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5696,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5696,307,206,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5696,320,6,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5696,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5696,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5696,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5696,601,54,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5696,605,0.024,'100g',3,1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5696,606,0.536,'100g',3,1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5697,203,26.97,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5697,204,2.08,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5697,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5697,207,1.44,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5697,208,127,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5697,255,70.18,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5697,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5697,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5697,301,13,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5697,303,0.55,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5697,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5697,307,238,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5697,320,3,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5697,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5697,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5697,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5697,601,69,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5697,605,0.024,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5697,606,0.593,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5698,203,12.29,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5698,204,36.8,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5698,205,0.21,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5698,207,0.69,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5698,208,381,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5698,255,50,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5698,269,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5698,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5698,301,13,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5698,303,0.57,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5698,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5698,307,138,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5698,320,85,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5698,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5698,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5698,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5698,601,94,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5698,605,0.557,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5698,606,10.43,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5699,203,22.15,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5699,204,40.31,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5699,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5699,207,1.37,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5699,208,451,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5699,255,36.92,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5699,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5699,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5699,301,25,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5699,303,1.08,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5699,306,263,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5699,307,234,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5699,320,79,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5699,328,1.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5699,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5699,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5699,601,144,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5699,605,0.568,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5699,606,11.356,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5700,203,17.84,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5700,204,10.83,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5700,205,0.15,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5700,207,1.08,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5700,208,169,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5700,255,70.55,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5700,269,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5700,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5700,301,14,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5700,303,0.83,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5700,306,202,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5700,307,161,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5700,320,28,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5700,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5700,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5700,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5700,601,82,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5700,605,0.183,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (5700,606,2.6,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5701,203,25.55,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5701,204,10.81,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5701,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5701,207,1.26,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5701,208,199,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5701,255,62.66,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5701,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5701,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5701,301,17,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5701,303,1.08,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5701,306,232,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5701,307,206,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5701,320,16,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5701,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5701,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5701,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5701,601,110,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5701,605,0.148,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5701,606,3.145,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5702,203,20.02,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5702,204,7.42,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5702,205,0.14,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5702,207,1.31,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5702,208,147,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5702,255,72.09,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5702,269,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5702,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5702,301,14,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5702,303,0.54,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5702,306,220,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5702,307,195,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5702,320,19,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (5702,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5702,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5702,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5702,601,60,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5702,605,0.132,'100g',3,1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5702,606,1.35,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5703,203,26.52,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5703,204,5.64,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5703,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5703,207,1.43,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5703,208,157,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5703,255,67.09,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5703,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5703,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5703,301,14,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5703,303,0.6,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5703,306,250,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5703,307,237,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5703,320,10,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5703,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5703,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5703,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5703,601,76,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5703,605,0.075,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5703,606,1.593,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5704,203,20.87,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5704,204,2.39,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5704,205,0.14,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5704,207,1.35,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5704,208,106,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (5704,255,76.25,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5704,269,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5704,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5704,301,14,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5704,303,0.64,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5704,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5704,307,194,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5704,320,8,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5704,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5704,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5704,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5704,601,61,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5704,605,0.025,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5704,606,0.535,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5705,203,26.61,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5705,204,3.7,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5705,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5705,207,1.36,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5705,208,140,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5705,255,68.81,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5705,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5705,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5705,301,14,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5705,303,0.77,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5705,306,239,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5705,307,223,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5705,320,4,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5705,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5705,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5705,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5705,601,84,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5705,605,0.047,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5705,606,1.093,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5706,203,19.03,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5706,204,9.1,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5706,205,0.15,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5706,207,1.21,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5706,208,159,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (5706,255,71.26,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5706,269,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5706,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5706,301,14,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5706,303,0.67,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5706,306,211,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5706,307,180,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5706,320,23,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5706,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5706,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5706,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5706,601,70,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5706,605,0.163,'100g',3,1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5706,606,1.7,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5707,203,26.09,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5707,204,8.01,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5707,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5707,207,1.36,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5707,208,176,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5707,255,65.05,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5707,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5707,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5707,301,15,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5707,303,0.81,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5707,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5707,307,224,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5707,320,13,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (5707,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5707,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5707,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5707,601,91,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (5707,605,0.108,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5707,606,2.301,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5708,203,21.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5708,204,2.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5708,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5708,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5708,208,111,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5708,255,75.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5708,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5708,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5708,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5708,303,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5708,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5708,307,124,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5708,320,5,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5708,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5708,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5708,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5708,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5708,605,0.128,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (5708,606,0.6,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5709,203,27.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5709,204,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5709,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5709,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5709,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5709,255,69.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5709,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5709,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5709,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5709,303,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5709,306,264,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5709,307,184,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5709,320,3,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5709,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5709,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5709,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5709,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5709,605,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5709,606,0.428,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5710,203,23.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5710,204,2.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5710,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5710,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5710,208,114,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5710,255,74.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5710,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5710,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5710,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5710,303,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5710,306,267,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5710,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5710,320,5,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5710,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5710,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5710,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5710,601,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5710,605,0.013,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5710,606,0.344,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5711,203,29.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5711,204,1.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5711,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5711,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5711,208,136,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5711,255,67.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5711,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5711,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5711,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5711,303,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5711,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5711,307,114,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5711,320,3,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5711,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5711,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5711,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5711,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5711,605,0.024,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5711,606,0.66,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5712,203,22.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5712,204,2.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5712,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5712,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5712,208,112,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5712,255,75.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5712,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5712,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5712,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5712,303,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5712,306,222,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5712,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5712,320,5,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5712,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5712,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5712,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5712,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5712,605,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5712,606,0.458,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5713,203,30.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5713,204,5.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5713,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5713,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5713,208,170,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5713,255,64.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5713,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5713,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5713,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5713,303,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5713,306,207,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5713,307,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5713,320,8,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5713,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5713,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5713,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5713,601,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5713,605,0.057,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5713,606,1.357,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5714,203,14.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5714,204,35.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5714,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5714,207,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5714,208,380,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5714,255,50.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5714,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5714,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5714,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5714,303,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5714,306,93,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5714,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5714,320,79,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5714,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5714,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5714,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5714,601,111,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5714,605,0.469,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5714,606,10.216,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5715,203,24.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5715,204,35.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5715,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5715,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5715,208,414,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5715,255,39.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5715,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5715,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5715,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5715,303,1.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5715,306,225,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5715,307,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5715,320,59,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5715,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5715,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5715,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5715,601,139,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5715,605,0.459,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5715,606,10.184,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5716,203,20.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5716,204,3.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5716,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5716,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5716,208,118,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5716,255,75.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5716,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5716,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5716,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5716,303,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5716,306,220,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5716,307,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5716,320,20,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5716,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5716,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5716,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5716,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5716,605,0.039,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5716,606,1.073,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5717,203,20.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5717,204,3.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5717,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5717,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5717,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5717,255,75.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5717,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5717,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5717,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5717,303,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5717,306,269,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5717,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5717,320,19,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5717,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5717,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5717,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5717,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5717,605,0.031,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5717,606,0.782,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5718,203,26.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5718,204,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5718,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5718,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5718,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5718,255,70.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5718,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5718,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5718,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5718,303,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5718,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5718,307,238,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5718,320,3,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5718,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5718,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5718,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5718,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5718,605,0.024,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5718,606,0.593,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5719,203,19.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5719,204,4.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5719,205,0.15,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5719,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5719,208,115,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5719,255,75.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5719,269,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5719,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5719,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5719,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5719,306,226,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5719,307,167,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5719,320,13,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5719,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5719,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5719,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5719,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5719,605,0.052,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5719,606,1.124,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5720,203,26.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5720,204,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5720,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5720,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5720,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5720,255,70.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5720,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5720,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5720,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5720,303,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5720,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5720,307,238,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5720,320,3,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5720,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5720,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5720,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5720,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5720,605,0.024,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5720,606,0.593,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5721,203,21.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5721,204,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5721,205,0.14,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5721,207,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5721,208,102,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5721,255,76.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5721,269,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5721,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5721,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5721,303,0.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5721,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5721,307,206,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5721,320,6,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5721,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5721,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5721,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5721,601,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5721,605,0.024,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5721,606,0.536,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5722,203,25.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5722,204,6.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5722,205,0.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5722,207,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5722,208,159,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5722,255,66.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5722,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5722,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5722,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5722,303,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5722,306,296,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5722,307,104,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5722,320,6,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5722,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5722,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5722,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5722,601,116,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5722,605,0.089,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5722,606,2.02,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5723,203,28.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5723,204,6.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5723,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5723,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5723,208,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5723,255,65.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5723,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5723,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5723,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5723,303,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5723,306,257,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5723,307,112,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5723,320,6,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5723,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5723,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5723,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5723,601,118,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5723,605,0.084,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5723,606,1.707,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5724,203,19.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5724,204,4.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5724,205,0.15,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5724,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5724,208,115,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5724,255,75.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5724,269,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5724,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5724,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5724,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5724,306,226,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5724,307,167,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5724,320,13,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5724,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5724,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5724,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5724,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5724,605,0.052,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5724,606,1.124,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5725,203,26.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5725,204,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5725,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5725,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5725,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5725,255,66.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5725,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5725,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5725,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5725,303,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5725,306,227,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5725,307,201,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5725,320,5,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5725,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5725,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5725,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5725,601,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5725,605,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5725,606,1.807,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5726,203,19.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5726,204,4.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5726,205,0.15,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5726,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5726,208,115,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5726,255,75.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5726,269,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5726,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5726,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5726,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5726,306,226,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5726,307,167,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5726,320,13,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5726,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5726,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5726,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5726,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5726,605,0.052,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5726,606,1.124,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5727,203,20.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5727,204,6.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5727,205,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5727,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5727,208,144,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5727,255,72.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5727,269,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5727,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5727,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5727,303,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5727,306,221,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5727,307,126,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5727,320,15,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5727,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5727,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5727,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5727,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5727,605,0.129,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5727,606,1.24,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5728,203,26.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5728,204,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5728,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5728,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5728,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5728,255,66.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5728,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5728,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5728,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5728,303,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5728,306,227,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5728,307,201,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5728,320,5,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5728,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5728,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5728,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5728,601,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5728,605,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5728,606,1.807,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5729,203,21.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5729,204,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5729,205,0.14,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5729,207,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5729,208,102,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5729,255,76.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5729,269,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5729,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5729,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5729,303,0.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5729,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5729,307,206,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5729,320,6,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5729,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5729,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5729,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5729,601,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5729,605,0.024,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5729,606,0.536,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5730,203,26.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5730,204,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5730,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5730,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5730,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5730,255,70.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5730,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5730,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5730,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5730,303,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5730,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5730,307,238,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5730,320,3,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5730,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5730,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5730,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5730,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5730,605,0.024,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5730,606,0.593,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5732,203,21.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5732,204,7.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5732,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5732,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5732,208,155,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5732,255,70.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5732,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5732,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5732,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5732,303,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5732,306,247,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5732,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5732,320,16,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5732,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5732,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5732,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5732,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5732,605,0.089,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5732,606,1.756,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5733,203,29.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5733,204,5.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5733,205,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5733,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5733,208,164,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5733,255,64.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5733,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5733,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5733,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5733,303,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5733,306,292,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5733,307,114,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5733,320,10,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (5733,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5733,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5733,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5733,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5733,605,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5733,606,1.657,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5734,203,19.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5734,204,13.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5734,205,0.05,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5734,207,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5734,208,202,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5734,255,66.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5734,269,0.03,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5734,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5734,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5734,303,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5734,306,192,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5734,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5734,320,30,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5734,328,0.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5734,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5734,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5734,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5734,605,0.187,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5734,606,3.549,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5735,203,28.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5735,204,13.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5735,205,0.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5735,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5735,208,235,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5735,255,57.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5735,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5735,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5735,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5735,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5735,306,215,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5735,307,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5735,320,24,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5735,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5735,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5735,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5735,601,115,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5735,605,0.175,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5735,606,3.656,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5736,203,19.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5736,204,6.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5736,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5736,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5736,208,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5736,255,73.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5736,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5736,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5736,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5736,303,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5736,306,208,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5736,307,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5736,320,26,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (5736,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5736,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5736,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5736,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5736,605,0.078,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5736,606,1.896,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5737,203,28.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5737,204,9.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5737,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5737,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5737,208,197,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5737,255,62.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5737,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5737,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5737,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5737,303,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5737,306,254,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5737,307,112,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5737,320,11,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (5737,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5737,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5737,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5737,601,120,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5737,605,0.091,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5737,606,2.307,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5738,203,23.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5738,204,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5738,205,0.14,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5738,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5738,208,109,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (5738,255,74.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5738,269,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5738,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5738,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5738,303,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5738,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5738,307,113,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5738,320,6,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5738,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5738,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5738,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5738,601,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5738,605,0.013,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5738,606,0.289,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5739,203,30.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5739,204,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5739,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5739,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5739,208,139,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5739,255,67.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5739,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5739,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5739,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5739,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5739,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5739,307,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5739,320,3,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5739,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5739,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5739,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5739,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5739,605,0.024,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5739,606,0.593,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5740,203,21.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5740,204,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5740,205,0.15,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5740,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5740,208,108,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5740,255,76.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5740,269,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5740,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5740,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5740,303,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5740,306,226,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5740,307,124,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5740,320,13,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5740,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5740,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5740,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5740,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5740,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5740,606,0.683,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5741,203,27.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5741,204,6.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5741,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5741,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5741,208,165,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5741,255,65.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5741,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5741,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5741,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5741,303,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5741,306,227,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5741,307,104,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5741,320,5,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5741,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5741,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5741,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5741,601,128,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5741,605,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5741,606,1.807,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5742,203,19.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5742,204,9.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5742,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5742,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5742,208,161,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5742,255,71.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5742,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5742,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5742,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5742,303,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5742,306,239,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5742,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5742,320,29,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5742,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5742,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5742,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5742,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5742,605,0.106,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5742,606,2.386,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5743,203,23.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5743,204,9.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5743,205,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5743,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5743,208,183,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5743,255,65.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5743,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5743,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5743,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5743,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5743,306,273,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5743,307,101,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5743,320,14,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5743,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5743,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5743,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5743,601,116,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5743,605,0.138,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5743,606,2.96,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5744,203,16.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5744,204,15.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5744,205,0.15,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5744,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5744,208,206,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5744,255,66.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5744,269,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5744,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5744,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5744,303,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5744,306,185,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5744,307,157,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5744,320,38,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5744,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5744,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5744,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5744,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5744,605,0.287,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5744,606,2.73,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5745,203,25.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5745,204,11.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5745,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5745,207,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5745,208,205,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5745,255,62.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5745,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5745,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5745,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5745,303,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5745,306,252,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5745,307,237,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5745,320,22,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (5745,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5745,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5745,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5745,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5745,605,0.156,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5745,606,3.205,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5746,203,32.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5746,204,3.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5746,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5746,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5746,208,157,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5746,255,65.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5746,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5746,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5746,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5746,303,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5746,306,343,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5746,307,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5746,320,10,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (5746,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5746,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5746,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5746,601,116,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5746,605,0.013,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5746,606,1.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5747,203,30.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5747,204,3.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5747,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5747,207,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5747,208,151,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5747,255,66.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5747,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5747,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5747,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5747,303,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5747,306,391,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5747,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5747,320,10,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (5747,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5747,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5747,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (5747,601,104,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5747,605,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5747,606,0.992,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5748,203,28.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5748,204,3.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5748,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5748,207,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5748,208,145,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5748,255,68.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5748,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5748,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5748,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5748,303,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5748,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5748,307,172,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5748,320,9,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (5748,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5748,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5748,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5748,601,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5748,605,0.014,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (5748,606,1.193,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (5749,203,29.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5749,204,3.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5749,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5749,207,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5749,208,148,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5749,255,66.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5749,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5749,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5749,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5749,303,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5749,306,420,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5749,307,215,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5749,320,10,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (5749,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (5749,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5749,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (5749,601,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (5749,605,0.013,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (5749,606,1.012,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6001,203,1.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6001,204,3.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6001,205,8.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6001,207,2.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6001,208,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6001,255,84.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6001,269,0.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6001,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6001,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6001,303,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6001,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6001,307,669,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6001,320,26,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6001,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6001,401,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6001,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6001,601,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6001,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6001,606,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6002,203,4.83,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6002,204,1.32,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6002,205,15.42,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6002,207,3.1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6002,208,91,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6002,255,75.33,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6002,269,2.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6002,291,6.8,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6002,301,35,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6002,303,1.5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6002,306,250,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6002,307,970,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6002,320,22,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6002,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6002,401,0.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6002,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6002,601,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6002,605,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6002,606,0.34,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6004,203,5.88,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6004,204,4.42,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6004,205,16.97,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6004,207,2.57,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6004,208,129,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6004,255,70.17,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6004,269,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6004,291,5.9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6004,301,60,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6004,303,1.53,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6004,306,375,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6004,307,672,'100g',6,1,'1996-09-30','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (6004,320,34,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6004,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6004,401,1.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6004,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6004,601,2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6004,605,NULL,'100g',NULL,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6004,606,1.14,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6006,203,7.6,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6006,204,5.31,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6006,205,16.75,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6006,207,2.64,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6006,208,142,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6006,255,67.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6006,269,NULL,'100g',NULL,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6006,291,4.6,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6006,301,66,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6006,303,1.78,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6006,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6006,307,831,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6006,320,33,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6006,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6006,401,0.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6006,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6006,601,9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6006,605,NULL,'100g',NULL,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6006,606,1.61,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6007,203,5.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6007,204,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6007,205,11.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6007,207,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6007,208,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6007,255,78.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6007,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6007,291,4.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6007,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6007,303,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6007,306,175,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6007,307,400,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6007,320,81,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6007,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6007,401,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6007,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6007,601,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6007,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6007,606,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6008,203,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6008,204,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6008,205,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6008,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6008,208,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6008,255,97.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6008,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6008,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6008,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6008,303,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6008,306,54,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6008,307,372,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6008,320,0,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6008,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6008,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6008,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6008,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6008,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6008,606,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6009,203,3.85,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6009,204,2.46,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6009,205,7.16,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6009,207,2.12,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6009,208,67,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6009,255,84.42,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6009,269,2.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6009,291,0.6,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6009,301,12,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6009,303,0.88,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6009,306,79,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6009,307,653,'100g',6,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (6009,320,11,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6009,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6009,401,0.3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6009,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6009,601,4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6009,605,NULL,'100g',NULL,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6009,606,0.91,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6010,203,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6010,204,4.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6010,205,7.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6010,207,2.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6010,208,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6010,255,84.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6010,269,1.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6010,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6010,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6010,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6010,306,98,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6010,307,516,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6010,320,22,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6010,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6010,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6010,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6010,601,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6010,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6010,606,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6011,203,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6011,204,3.92,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6011,205,11.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6011,207,2.29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6011,208,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6011,255,81.69,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6011,269,3.73,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6011,291,2.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6011,301,36,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6011,303,0.15,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6011,306,37,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6011,307,692,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6011,320,69,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (6011,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6011,401,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6011,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6011,601,3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6011,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6011,606,2.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6013,203,4.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6013,204,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6013,205,0.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6013,207,1.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6013,208,31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6013,255,91.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6013,269,0.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6013,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6013,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6013,303,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6013,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6013,307,621,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6013,320,0,'100g',2,1,'2024-12-12','2003-01-06');
INSERT INTO `cndb_nutval` VALUES (6013,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6013,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6013,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6013,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6013,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6013,606,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6015,203,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6015,204,2.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6015,205,6.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6015,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6015,208,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6015,255,84.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6015,269,0.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6015,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6015,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6015,303,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6015,306,70,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6015,307,354,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6015,320,27,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6015,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6015,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6015,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6015,601,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6015,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6015,606,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6016,203,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6016,204,5.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6016,205,7.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6016,207,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6016,208,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6016,255,82.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6016,269,0.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6016,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6016,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6016,303,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6016,306,49,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6016,307,702,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6016,320,43,'100g',2,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (6016,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6016,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6016,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6016,601,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6016,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6016,606,1.697,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6017,203,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6017,204,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6017,205,6.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6017,207,2.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6017,208,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6017,255,88.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6017,269,1.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6017,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6017,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6017,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6017,306,60,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6017,307,693,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6017,320,5,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6017,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6017,401,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6017,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6017,601,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6017,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6017,606,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6018,203,3.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6018,204,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6018,205,4.46,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6018,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6018,208,41,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6018,255,89.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6018,269,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6018,291,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6018,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6018,303,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6018,306,117,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6018,307,306,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6018,320,62,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6018,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6018,401,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6018,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6018,601,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6018,605,0.001,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6018,606,0.627,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6019,203,2.37,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6019,204,1.55,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6019,205,6.07,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6019,207,1.81,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6019,208,48,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6019,255,88.2,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6019,269,0,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6019,291,0.9,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6019,301,6,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6019,303,0.67,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6019,306,48,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6019,307,681,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6019,320,22,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6019,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6019,401,0,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6019,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6019,601,8,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6019,605,0.007,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6019,606,0.389,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6022,203,5.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6022,204,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6022,205,5.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6022,207,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6022,208,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6022,255,86.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6022,269,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6022,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6022,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6022,303,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6022,306,45,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6022,307,370,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6022,320,122,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6022,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6022,401,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6022,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6022,601,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6022,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6022,606,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6023,203,1.84,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6023,204,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6023,205,11.57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6023,207,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6023,208,68,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6023,255,83.15,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6023,269,0.23,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6023,291,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6023,301,41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6023,303,0.25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6023,306,34,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6023,307,645,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6023,320,25,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (6023,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6023,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6023,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6023,601,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6023,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6023,606,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6024,203,1.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6024,204,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6024,205,4.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6024,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6024,208,33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6024,255,91.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6024,269,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6024,291,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6024,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6024,303,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6024,306,133,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6024,307,229,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6024,320,52,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (6024,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6024,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6024,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6024,601,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6024,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6024,606,0.121,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6025,203,2.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6025,204,2.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6025,205,7.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6025,207,2.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6025,208,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6025,255,85.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6025,269,1.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6025,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6025,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6025,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6025,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6025,307,706,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6025,320,109,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6025,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6025,401,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6025,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6025,601,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6025,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6025,606,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6026,203,5.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6026,204,2.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6026,205,18.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6026,207,2.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6026,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6026,255,70.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6026,269,5.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6026,291,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6026,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6026,303,1.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6026,306,400,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6026,307,788,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6026,320,57,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6026,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6026,401,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6026,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6026,601,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6026,605,0.069,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6026,606,1.242,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6027,203,3.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6027,204,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6027,205,7.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6027,207,1.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6027,208,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6027,255,86.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6027,269,1.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6027,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6027,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6027,303,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6027,306,160,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6027,307,417,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6027,320,70,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (6027,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6027,401,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6027,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6027,601,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6027,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6027,606,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6028,203,1.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6028,204,1.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6028,205,9.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6028,207,2.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6028,208,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6028,255,84.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6028,269,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6028,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6028,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6028,303,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6028,306,150,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6028,307,698,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6028,320,41,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6028,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6028,401,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6028,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6028,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6028,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6028,606,0.305,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6030,203,3.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6030,204,2.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6030,205,10.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6030,207,2.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6030,208,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6030,255,81.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6030,269,0.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6030,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6030,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6030,303,2.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6030,306,221,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6030,307,516,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6030,320,17,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6030,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6030,401,4.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6030,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6030,601,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6030,605,0.013,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6030,606,0.959,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6032,203,2.52,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6032,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6032,205,0.32,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6032,207,2.4,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6032,208,11,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6032,255,94.76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6032,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6032,291,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6032,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6032,303,0.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6032,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6032,307,694,'100g',6,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (6032,320,0,'100g',2,1,'2024-12-12','2006-01-09');
INSERT INTO `cndb_nutval` VALUES (6032,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6032,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6032,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6032,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6032,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6032,606,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6037,203,3.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6037,204,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6037,205,8.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6037,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6037,208,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6037,255,85.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6037,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6037,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6037,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6037,303,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6037,306,144,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6037,307,532,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6037,320,7,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6037,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6037,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6037,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6037,601,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6037,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6037,606,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6039,203,2.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6039,204,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6039,205,8.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6039,207,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6039,208,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6039,255,86.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6039,269,2.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6039,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6039,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6039,303,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6039,306,255,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6039,307,288,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6039,320,89,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6039,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6039,401,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6039,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6039,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6039,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6039,606,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6040,203,3.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6040,204,2.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6040,205,9.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6040,207,2.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6040,208,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6040,255,82.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6040,269,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6040,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6040,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6040,303,0.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6040,306,255,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6040,307,516,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6040,320,85,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (6040,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6040,401,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6040,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6040,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6040,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6040,606,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6042,203,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6042,204,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6042,205,9.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6042,207,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6042,208,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6042,255,84.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6042,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6042,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6042,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6042,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6042,306,76,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6042,307,573,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6042,320,8,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6042,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6042,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6042,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6042,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6042,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6042,606,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6043,203,1.35,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6043,204,5.3,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6043,205,6.8,'100g',3,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6043,207,1.85,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6043,208,79,'100g',3,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6043,255,84.7,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6043,269,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6043,291,0.7,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6043,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6043,303,0.18,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6043,306,64,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6043,307,691,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6043,320,2,'100g',1,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (6043,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6043,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6043,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6043,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6043,605,0.023,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6043,606,0.964,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6044,203,2.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6044,204,3.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6044,205,7.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6044,207,2.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6044,208,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6044,255,84.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6044,269,2.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6044,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6044,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6044,303,0.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6044,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6044,307,773,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6044,320,17,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6044,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6044,401,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6044,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6044,601,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6044,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6044,606,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6045,203,3.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6045,204,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6045,205,6.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6045,207,2.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6045,208,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6045,255,86.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6045,269,2.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6045,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6045,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6045,303,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6045,306,56,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6045,307,516,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6045,320,3,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6045,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6045,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6045,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6045,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6045,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6045,606,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6046,203,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6046,204,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6046,205,10.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6046,207,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6046,208,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6046,255,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6046,269,3.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6046,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6046,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6046,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6046,306,98,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6046,307,637,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6046,320,28,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6046,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6046,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6046,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6046,601,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6046,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6046,606,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6048,203,1.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6048,204,3.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6048,205,3.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6048,207,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6048,208,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6048,255,89.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6048,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6048,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6048,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6048,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6048,306,40,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6048,307,722,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6048,320,3,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6048,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6048,401,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6048,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6048,601,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6048,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6048,606,2.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6049,203,6.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6049,204,2.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6049,205,20.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6049,207,2.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6049,208,125,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6049,255,68.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6049,269,6.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6049,291,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6049,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6049,303,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6049,306,145,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6049,307,680,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6049,320,7,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6049,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6049,401,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6049,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6049,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6049,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6049,606,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6050,203,4.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6050,204,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6050,205,11.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6050,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6050,208,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6050,255,80.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6050,269,1.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6050,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6050,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6050,303,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6050,306,127,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6050,307,301,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6050,320,102,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6050,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6050,401,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6050,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6050,601,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6050,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6050,606,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6051,203,7.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6051,204,3.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6051,205,20.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6051,207,2.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6051,208,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6051,255,65.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6051,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6051,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6051,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6051,303,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6051,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6051,307,630,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6051,320,17,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6051,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6051,401,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6051,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6051,601,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6051,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6051,606,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6053,203,1.51,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6053,204,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6053,205,12.79,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6053,207,1.82,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6053,208,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6053,255,82,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6053,269,1.44,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6053,291,1.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6053,301,17,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6053,303,0.34,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6053,306,165,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6053,307,604,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6053,320,19,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6053,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6053,401,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6053,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6053,601,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6053,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6053,606,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6056,203,2.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6056,204,4.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6056,205,6.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6056,207,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6056,208,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6056,255,84.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6056,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6056,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6056,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6056,303,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6056,306,47,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6056,307,685,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6056,320,32,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6056,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6056,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6056,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6056,601,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6056,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6056,606,2.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6061,203,3.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6061,204,3.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6061,205,16.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6061,207,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6061,208,112,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6061,255,74.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6061,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6061,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6061,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6061,303,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6061,306,176,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6061,307,731,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6061,320,21,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6061,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6061,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6061,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6061,601,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6061,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6061,606,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6063,203,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6063,204,2.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6063,205,17.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6063,207,2.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6063,208,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6063,255,77.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6063,269,5.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6063,291,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6063,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6063,303,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6063,306,257,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6063,307,635,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6063,320,23,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6063,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6063,401,11.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6063,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6063,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6063,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6063,606,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6064,203,4.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6064,204,1.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6064,205,5.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6064,207,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6064,208,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6064,255,86.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6064,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6064,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6064,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6064,303,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6064,306,153,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6064,307,391,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6064,320,152,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6064,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6064,401,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6064,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6064,601,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6064,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6064,606,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6067,203,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6067,204,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6067,205,7.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6067,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6067,208,39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6067,255,89.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6067,269,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6067,291,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6067,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6067,303,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6067,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6067,307,267,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6067,320,52,'100g',1,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (6067,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6067,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6067,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6067,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6067,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6067,606,0.045,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6068,203,1.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6068,204,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6068,205,9.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6068,207,2.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6068,208,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6068,255,84.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6068,269,3.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6068,291,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6068,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6068,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6068,306,171,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6068,307,516,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6068,320,142,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (6068,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6068,401,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6068,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6068,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6068,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6068,606,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6070,203,3.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6070,204,1.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6070,205,10.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6070,207,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6070,208,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6070,255,83.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6070,269,0.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6070,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6070,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6070,303,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6070,306,140,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6070,307,338,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6070,320,54,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6070,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6070,401,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6070,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6070,601,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6070,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6070,606,0.554,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6071,203,4.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6071,204,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6071,205,8.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6071,207,2.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6071,208,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6071,255,83.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6071,269,0.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6071,291,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6071,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6071,303,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6071,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6071,307,706,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6071,320,155,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (6071,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6071,401,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6071,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6071,601,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6071,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6071,606,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6072,203,2.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6072,204,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6072,205,10.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6072,207,2.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6072,208,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6072,255,83.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6072,269,1.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6072,291,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6072,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6072,303,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6072,306,157,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6072,307,515,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6072,320,85,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6072,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6072,401,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6072,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6072,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6072,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6072,606,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6075,203,15.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6075,204,8.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6075,205,17.4,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (6075,207,54.5,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (6075,208,213,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (6075,255,3.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6075,269,16.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6075,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6075,301,60,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6075,303,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6075,306,446,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6075,307,26000,'100g',6,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (6075,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6075,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6075,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6075,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6075,601,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6075,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (6075,606,4.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6076,203,17.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6076,204,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6076,205,16.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6076,207,59.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6076,208,170,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6076,255,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6076,269,14.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6076,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6076,301,60,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6076,303,2.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6076,306,403,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6076,307,24000,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6076,320,0,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6076,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6076,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6076,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6076,601,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6076,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (6076,606,1.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6080,203,16.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6080,204,13.88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6080,205,18.01,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6080,207,49.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6080,208,267,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6080,255,2.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6080,269,17.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6080,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6080,301,187,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6080,303,1.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6080,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6080,307,23875,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6080,320,0,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (6080,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6080,401,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6080,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6080,601,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6080,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6080,606,3.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6081,203,14.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6081,204,4.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6081,205,23.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6081,207,54.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6081,208,198,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6081,255,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6081,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6081,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6081,301,190,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6081,303,1.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6081,306,374,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6081,307,24000,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6081,320,0,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6081,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6081,401,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6081,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6081,601,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6081,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6081,606,1.2,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (6094,203,7.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6094,204,0.34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6094,205,65.07,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6094,207,23.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6094,208,293,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6094,255,3.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6094,269,4.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6094,291,6.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6094,301,143,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6094,303,1.25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6094,306,721,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6094,307,8031,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6094,320,1,'100g',2,1,'2024-12-12','2006-01-10');
INSERT INTO `cndb_nutval` VALUES (6094,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6094,401,3.4,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6094,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6094,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6094,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6094,606,0.089,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6101,203,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6101,204,24.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6101,205,52.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6101,207,12.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6101,208,446,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6101,255,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6101,269,17.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6101,291,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6101,301,134,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6101,303,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6101,306,408,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6101,307,3857,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (6101,320,600,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6101,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6101,401,16.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6101,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6101,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6101,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6101,606,6.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6112,203,5.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6112,204,0.02,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6112,205,15.56,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6112,207,10.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6112,208,89,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6112,255,67.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6112,269,14.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6112,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6112,301,25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6112,303,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6112,306,225,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6112,307,3833,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6112,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6112,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6112,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6112,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6112,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6112,605,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6112,606,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6114,203,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6114,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6114,205,2.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6114,207,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6114,208,16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6114,255,94.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6114,269,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (6114,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6114,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6114,303,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6114,306,81,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6114,307,478,'100g',6,1,'1994-01-31','2012-09-01');
INSERT INTO `cndb_nutval` VALUES (6114,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6114,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6114,401,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6114,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6114,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6114,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (6114,606,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6115,203,9.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6115,204,9.63,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6115,205,47.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6115,207,30.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6115,208,313,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6115,255,2.74,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6115,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6115,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6115,301,140,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6115,303,9.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6115,306,279,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6115,307,11588,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6115,320,0,'100g',1,1,'2024-12-12','2006-01-08');
INSERT INTO `cndb_nutval` VALUES (6115,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6115,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6115,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6115,601,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6115,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6115,606,2.026,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6116,203,3.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6116,204,2.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6116,205,4.81,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6116,207,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6116,208,53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6116,255,87.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6116,269,0.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6116,291,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6116,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6116,303,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6116,306,81,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6116,307,633,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (6116,320,1,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6116,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6116,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6116,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6116,601,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6116,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6116,606,1.153,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6118,203,10.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6118,204,9.61,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6118,205,59.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6118,207,15.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6118,208,367,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6118,255,5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6118,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6118,291,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6118,301,132,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6118,303,1.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6118,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6118,307,4843,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6118,320,8,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6118,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6118,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6118,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6118,601,3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6118,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6118,606,3.319,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6119,203,0.71,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6119,204,2.62,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6119,205,5.29,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6119,207,1.08,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6119,208,48,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6119,255,90.3,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6119,269,0.3,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6119,291,0.1,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6119,301,10,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6119,303,0.09,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6119,306,42,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6119,307,389,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6119,320,1,'100g',2,1,'2024-12-12','2003-01-06');
INSERT INTO `cndb_nutval` VALUES (6119,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6119,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6119,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6119,601,5,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6119,605,0.011,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6119,606,0.639,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6120,203,11.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6120,204,9.73,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6120,205,62.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6120,207,13.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6120,208,381,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6120,255,3.85,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6120,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6120,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6120,301,146,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6120,303,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6120,306,404,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6120,307,4152,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6120,320,38,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6120,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6120,401,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6120,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6120,601,19,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6120,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6120,606,2.92,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6121,203,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6121,204,2.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6121,205,5.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6121,207,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6121,208,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6121,255,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6121,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6121,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6121,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6121,303,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6121,306,106,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6121,307,570,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6121,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6121,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6121,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6121,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6121,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6121,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6121,606,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6122,203,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6122,204,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6122,205,64.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6122,207,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6122,208,328,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6122,255,3.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6122,269,3.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6122,291,4.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6122,301,230,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6122,303,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6122,306,262,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6122,307,6580,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6122,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (6122,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6122,401,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6122,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6122,601,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6122,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6122,606,2.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6123,203,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6123,204,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6123,205,67.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6123,207,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6123,208,322,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6123,255,4.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6123,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6123,291,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6123,301,280,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6123,303,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6123,306,262,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6123,307,4186,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6123,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6123,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6123,401,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6123,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6123,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6123,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6123,606,1.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6124,203,8.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6124,204,8.63,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6124,205,63.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6124,207,14.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6124,208,367,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6124,255,4.43,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6124,269,24.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6124,291,2.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6124,301,139,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6124,303,3.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6124,306,235,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6124,307,5356,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6124,320,34,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (6124,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6124,401,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6124,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6124,601,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6124,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6124,606,4.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6125,203,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6125,204,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6125,205,5.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6125,207,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6125,208,51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6125,255,88.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6125,269,0.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6125,291,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6125,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6125,303,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6125,306,109,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6125,307,577,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6125,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6125,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6125,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6125,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6125,601,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6125,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6125,606,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6126,203,10.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6126,204,7.19,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6126,205,65.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6126,207,12.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6126,208,367,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6126,255,4.67,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6126,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6126,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6126,301,146,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6126,303,3.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6126,306,428,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6126,307,4392,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6126,320,8,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6126,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6126,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6126,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6126,601,14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6126,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6126,606,1.975,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6127,203,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6127,204,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6127,205,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6127,207,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6127,208,344,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6127,255,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6127,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6127,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6127,301,150,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6127,303,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6127,306,262,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6127,307,5730,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6127,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6127,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6127,401,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6127,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6127,601,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6127,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6127,606,2.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6128,203,15.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6128,204,6.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6128,205,62.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6128,207,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6128,208,377,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6128,255,4.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6128,269,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6128,291,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6128,301,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6128,303,2.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6128,306,306,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6128,307,3161,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (6128,320,8,'100g',2,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (6128,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6128,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6128,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6128,601,74,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6128,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6128,606,1.969,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6147,203,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6147,204,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6147,205,5.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6147,207,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6147,208,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6147,255,85.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6147,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6147,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6147,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6147,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6147,306,126,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6147,307,709,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6147,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6147,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6147,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6147,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6147,601,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6147,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6147,606,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6149,203,1.61,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6149,204,4.84,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6149,205,11.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6149,207,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6149,208,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6149,255,80.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6149,269,0.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6149,291,3.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6149,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6149,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6149,306,56,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6149,307,669,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6149,320,9,'100g',2,1,'2024-12-12','2008-01-06');
INSERT INTO `cndb_nutval` VALUES (6149,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6149,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6149,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6149,601,8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6149,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6149,606,1.246,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6150,203,0.82,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6150,204,0.63,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6150,205,40.77,'100g',3,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6150,207,3.07,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6150,208,172,'100g',3,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6150,255,54.71,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6150,269,33.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6150,291,0.9,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6150,301,33,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6150,303,0.64,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6150,306,232,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6150,307,1027,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6150,320,11,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (6150,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6150,401,0.6,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6150,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6150,601,0,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6150,605,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6150,606,0.045,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6151,203,0.89,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6151,204,1.04,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6151,205,42.81,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6151,207,1.56,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6151,208,184,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6151,255,53.71,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6151,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (6151,291,0.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6151,301,12,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6151,303,1.43,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6151,306,259,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6151,307,538,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6151,320,2,'100g',1,1,'2024-12-12','2003-01-06');
INSERT INTO `cndb_nutval` VALUES (6151,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6151,401,0.5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6151,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6151,601,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6151,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (6151,606,0.153,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6152,203,2.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6152,204,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6152,205,8.66,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6152,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6152,208,54,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6152,255,86.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6152,269,3.78,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6152,291,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6152,301,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6152,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6152,306,354,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6152,307,348,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6152,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (6152,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6152,401,11.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6152,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6152,601,0,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6152,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6152,606,0.46,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6158,203,1.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6158,204,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6158,205,18.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6158,207,2.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6158,208,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6158,255,75.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6158,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6158,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6158,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6158,303,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6158,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6158,307,698,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6158,320,32,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6158,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6158,401,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6158,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6158,601,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6158,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6158,606,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6159,203,1.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6159,204,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6159,205,15.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6159,207,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6159,208,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6159,255,80.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6159,269,8.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6159,291,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6159,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6159,303,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6159,306,562,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6159,307,377,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6159,320,20,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (6159,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6159,401,12.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6159,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6159,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6159,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6159,606,0.115,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6164,203,1.52,'100g',1,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6164,204,0.17,'100g',1,1,'1994-11-14','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (6164,205,6.64,'100g',3,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6164,207,2.39,'100g',1,1,'1994-11-14','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (6164,208,29,'100g',3,1,'1994-11-14','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (6164,255,89.28,'100g',1,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6164,269,4.01,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6164,291,1.9,'100g',1,1,'1994-11-14','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6164,301,30,'100g',1,1,'1994-11-14','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (6164,303,0.42,'100g',1,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6164,306,275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6164,307,711,'100g',1,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6164,320,23,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (6164,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6164,401,1.9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6164,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6164,601,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6164,605,NULL,'100g',NULL,1,'1994-09-20','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6164,606,0.021,'100g',3,1,'1994-11-14','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6166,203,3.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6166,204,10.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6166,205,9.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6166,207,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6166,208,147,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6166,255,74.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6166,269,4.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6166,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6166,301,118,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6166,303,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6166,306,156,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6166,307,354,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6166,320,104,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (6166,328,1.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6166,401,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6166,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6166,601,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6166,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6166,606,2.854,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6167,203,3.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6167,204,13.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6167,205,11.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6167,207,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6167,208,186,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6167,255,69.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6167,269,3.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6167,291,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6167,301,111,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6167,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6167,306,149,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6167,307,373,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6167,320,130,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (6167,328,1.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6167,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6167,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6167,601,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6167,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6167,606,3.416,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6168,203,0.51,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6168,204,0.37,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6168,205,1.75,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6168,207,7.39,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6168,208,11,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6168,255,89.98,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6168,269,1.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6168,291,0.3,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6168,301,8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6168,303,0.48,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6168,306,144,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6168,307,2643,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6168,320,8,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6168,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6168,401,74.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6168,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6168,601,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6168,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (6168,606,0.052,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6170,203,1.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6170,204,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6170,205,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6170,207,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6170,208,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6170,255,95.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6170,269,0.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6170,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6170,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6170,303,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6170,306,185,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6170,307,198,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6170,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6170,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6170,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6170,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6170,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6170,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6170,606,0.035,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6172,203,2.52,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6172,204,1.2,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6172,205,3.53,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6172,207,0.63,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6172,208,36,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6172,255,92.15,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6172,269,1.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6172,291,0,'100g',4,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6172,301,3,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6172,303,0.21,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6172,306,105,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6172,307,143,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6172,320,1,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6172,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6172,401,0.2,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6172,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6172,601,3,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6172,605,NULL,'100g',NULL,1,'1995-06-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (6172,606,0.321,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6174,203,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6174,204,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6174,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6174,207,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6174,208,16,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6174,255,96.6,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6174,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6174,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6174,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6174,303,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6174,306,144,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6174,307,156,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6174,320,2,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6174,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6174,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6174,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6174,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6174,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6174,606,0.203,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6175,203,3.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6175,204,3.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6175,205,44.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6175,207,4.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6175,208,220,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6175,255,44.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6175,269,27.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6175,291,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6175,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6175,303,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6175,306,119,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6175,307,1615,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6175,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6175,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6175,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6175,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6175,601,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6175,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6175,606,0.568,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6176,203,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6176,204,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6176,205,10.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6176,207,7.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6176,208,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6176,255,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6176,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6176,291,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6176,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6176,303,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6176,306,54,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6176,307,2733,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6176,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6176,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6176,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6176,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6176,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6176,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6176,606,0.043,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6177,203,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6177,204,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6177,205,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6177,207,1.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6177,208,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6177,255,87.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6177,269,2.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6177,291,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6177,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6177,303,0.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6177,306,186,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6177,307,215,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6177,320,33,'100g',2,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (6177,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6177,401,5.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6177,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6177,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6177,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6177,606,0.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6179,203,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6179,204,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6179,205,3.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6179,207,20.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6179,208,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6179,255,71.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6179,269,3.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6179,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6179,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6179,303,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6179,306,288,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6179,307,7851,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6179,320,4,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6179,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6179,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6179,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6179,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6179,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6179,606,0.003,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6180,203,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6180,204,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6180,205,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6180,207,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6180,208,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6180,255,90.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6180,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6180,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6180,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6180,303,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6180,306,53,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6180,307,501,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6180,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6180,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6180,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6180,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6180,601,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6180,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6180,606,0.501,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6182,203,1.21,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6182,204,1.69,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6182,205,8.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6182,207,1.69,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6182,208,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6182,255,87.26,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6182,269,2.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6182,291,0.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6182,301,13,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6182,303,0.48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6182,306,374,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6182,307,383,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6182,320,2,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6182,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6182,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6182,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6182,601,3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6182,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6182,606,0.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6183,203,1.36,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6183,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6183,205,0.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6183,207,0.89,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6183,208,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6183,255,97.32,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6183,269,0.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6183,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6183,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6183,303,0.26,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6183,306,85,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6183,307,231,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6183,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6183,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6183,401,0.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6183,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6183,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6183,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6183,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6188,203,1.14,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6188,204,0.07,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6188,205,0.2,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6188,207,0.58,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6188,208,6,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6188,255,98.01,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6188,269,0.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6188,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6188,301,3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6188,303,0.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6188,306,20,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6188,307,225,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6188,320,0,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (6188,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6188,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6188,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6188,601,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6188,605,0.003,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6188,606,0.042,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6189,203,5.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6189,204,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6189,205,15.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6189,207,8.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6189,208,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6189,255,69.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6189,269,14.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6189,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6189,301,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6189,303,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6189,306,225,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6189,307,1778,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6189,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6189,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6189,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6189,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6189,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6189,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6189,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6190,203,4.19,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6190,204,1.03,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6190,205,13.66,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6190,207,1.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6190,208,81,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6190,255,79.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6190,269,3.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6190,291,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6190,301,38,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6190,303,1.02,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6190,306,158,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6190,307,187,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6190,320,35,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6190,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6190,401,1.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6190,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6190,601,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6190,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6190,606,0.252,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6192,203,3.85,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6192,204,0.92,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6192,205,11.83,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6192,207,1,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6192,208,71,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6192,255,82.4,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6192,269,5.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6192,291,1.9,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6192,301,17,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6192,303,0.77,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6192,306,183,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6192,307,166,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6192,320,28,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (6192,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6192,401,0,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6192,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6192,601,2,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6192,605,NULL,'100g',NULL,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6192,606,0.3,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6193,203,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6193,204,0.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6193,205,11.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6193,207,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6193,208,68,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6193,255,82.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6193,269,1.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6193,291,1.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6193,301,16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6193,303,0.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6193,306,204,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6193,307,196,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6193,320,21,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (6193,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6193,401,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6193,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6193,601,3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6193,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6193,606,0.294,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6194,203,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6194,204,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6194,205,0.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6194,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6194,208,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6194,255,97.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6194,269,0.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6194,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6194,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6194,303,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6194,306,18,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6194,307,371,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6194,320,0,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (6194,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6194,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6194,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6194,601,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6194,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6194,606,0.013,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6201,203,2.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6201,204,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6201,205,6.61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6201,207,1.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6201,208,65,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6201,255,86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6201,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6201,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6201,301,70,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6201,303,0.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6201,306,145,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6201,307,420,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6201,320,25,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6201,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6201,401,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6201,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6201,601,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6201,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6201,606,1.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6208,203,1.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6208,204,4.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6208,205,5.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6208,207,1.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6208,208,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6208,255,87.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6208,269,0.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6208,291,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6208,301,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6208,303,0.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6208,306,73,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6208,307,416,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6208,320,19,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6208,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6208,401,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6208,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6208,601,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6208,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6208,606,1.636,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6210,203,2.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6210,204,3.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6210,205,5.86,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6210,207,1.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6210,208,66,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6210,255,86.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6210,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6210,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6210,301,75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6210,303,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6210,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6210,307,272,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6210,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (6210,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6210,401,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6210,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6210,601,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6210,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6210,606,1.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6211,203,3.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6211,204,5.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6211,205,6.47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6211,207,1.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6211,208,92,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6211,255,82.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6211,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6211,291,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6211,301,115,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6211,303,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6211,306,136,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6211,307,406,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6211,320,143,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6211,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6211,401,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6211,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6211,601,19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6211,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6211,606,3.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6216,203,3.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6216,204,4.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6216,205,6.04,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6216,207,1.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6216,208,77,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6216,255,84.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6216,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6216,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6216,301,73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6216,303,0.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6216,306,110,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6216,307,362,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6216,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (6216,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6216,401,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6216,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6216,601,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6216,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6216,606,1.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6217,203,2.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6217,204,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6217,205,12.11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6217,207,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6217,208,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6217,255,82.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6217,269,4.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6217,291,2.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6217,301,20,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6217,303,0.66,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6217,306,433,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6217,307,385,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6217,320,86,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6217,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6217,401,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6217,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6217,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6217,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6217,606,0.147,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6230,203,3.24,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6230,204,2.02,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (6230,205,7.46,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (6230,207,1.79,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (6230,208,61,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (6230,255,85.49,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (6230,269,2.81,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6230,291,0.3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6230,301,70,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (6230,303,1.21,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6230,306,179,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6230,307,273,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6230,320,37,'100g',4,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (6230,328,0.6,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6230,401,2.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6230,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6230,601,7,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6230,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (6230,606,1.094,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (6243,203,2.36,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6243,204,3.58,'100g',7,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6243,205,5.76,'100g',7,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6243,207,1.26,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6243,208,65,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6243,255,87.04,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6243,269,2.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6243,291,0.3,'100g',7,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6243,301,68,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6243,303,0.1,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6243,306,103,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6243,307,357,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6243,320,30,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (6243,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6243,401,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6243,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6243,601,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6243,605,0.055,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6243,606,1.116,'100g',7,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6246,203,2.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6246,204,3.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6246,205,7.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6246,207,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6246,208,75,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6246,255,84.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6246,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6246,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6246,301,72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6246,303,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6246,306,125,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6246,307,405,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6246,320,21,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6246,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6246,401,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6246,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6246,601,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6246,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6246,606,1.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6248,203,2.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6248,204,3.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6248,205,3.99,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6248,207,1.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6248,208,55,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6248,255,88.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6248,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6248,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6248,301,68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6248,303,0.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6248,306,96,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6248,307,425,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6248,320,23,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6248,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6248,401,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6248,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6248,601,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6248,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6248,606,2.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6249,203,4.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6249,204,2.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6249,205,12.69,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6249,207,1.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6249,208,94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6249,255,77.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6249,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6249,291,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6249,301,68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6249,303,0.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6249,306,148,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6249,307,352,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6249,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (6249,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6249,401,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6249,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6249,601,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6249,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6249,606,1.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6253,203,2.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6253,204,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6253,205,6.92,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6253,207,1.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6253,208,60,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6253,255,86.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6253,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6253,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6253,301,67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6253,303,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6253,306,130,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6253,307,230,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6253,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (6253,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6253,401,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6253,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6253,601,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6253,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6253,606,1.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6256,203,2.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6256,204,3.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6256,205,5.64,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6256,207,1.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6256,208,61,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6256,255,87.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6256,269,2.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6256,291,0.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6256,301,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6256,303,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6256,306,95,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6256,307,354,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6256,320,43,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (6256,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6256,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6256,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6256,601,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6256,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6256,606,1.93,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6264,203,3.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6264,204,2.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6264,205,8.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6264,207,1.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6264,208,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6264,255,84.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6264,269,5.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6264,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6264,301,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6264,303,0.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6264,306,167,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6264,307,184,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6264,320,84,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (6264,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6264,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6264,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6264,601,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6264,605,0.098,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6264,606,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6285,203,1.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6285,204,0.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6285,205,16.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6285,207,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6285,208,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6285,255,78.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6285,269,10.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6285,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6285,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6285,303,0.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6285,306,193,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6285,307,347,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6285,320,6,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (6285,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6285,401,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6285,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6285,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6285,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6285,606,0.144,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6358,203,2.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6358,204,2.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6358,205,11.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6358,207,1.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6358,208,79,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6358,255,81.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6358,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6358,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6358,301,74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6358,303,0.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6358,306,241,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6358,307,442,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6358,320,25,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6358,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6358,401,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6358,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6358,601,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6358,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6358,606,1.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6359,203,2.42,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6359,204,1.24,'100g',7,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6359,205,9.82,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6359,207,1.38,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6359,208,55,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6359,255,85.15,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6359,269,6.59,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6359,291,0.5,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6359,301,68,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6359,303,0.3,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6359,306,343,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6359,307,206,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6359,320,38,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (6359,328,0.6,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6359,401,6.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6359,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6359,601,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6359,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6359,606,0.707,'100g',7,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6401,203,0.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6401,204,1.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6401,205,4.38,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6401,207,1.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6401,208,35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6401,255,91.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6401,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6401,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6401,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6401,303,0.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6401,306,71,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6401,307,402,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6401,320,15,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6401,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6401,401,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6401,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6401,601,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6401,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6401,606,0.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6402,203,2.42,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6402,204,0.66,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6402,205,7.71,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6402,207,1.6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6402,208,46,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6402,255,87.62,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6402,269,1.24,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6402,291,3.4,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6402,301,19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6402,303,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6402,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6402,307,487,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6402,320,11,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6402,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6402,401,0.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6402,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6402,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6402,605,0,'100g',7,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6402,606,0.17,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6404,203,2.88,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6404,204,2.16,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6404,205,8.31,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6404,207,1.31,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6404,208,63,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6404,255,85.35,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6404,269,1.47,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6404,291,2.9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6404,301,31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6404,303,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6404,306,147,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6404,307,349,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6404,320,17,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6404,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6404,401,0.6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6404,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6404,601,1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6404,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6404,606,0.558,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6406,203,3.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6406,204,2.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6406,205,8.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6406,207,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6406,208,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6406,255,83.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6406,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6406,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6406,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6406,303,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6406,306,191,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6406,307,437,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6406,320,17,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6406,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6406,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6406,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6406,601,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6406,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6406,606,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6409,203,1.93,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6409,204,1.23,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6409,205,3.58,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6409,207,1.1,'100g',3,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (6409,208,34,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6409,255,92.16,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6409,269,1.03,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6409,291,0.3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6409,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6409,303,0.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6409,306,40,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6409,307,325,'100g',6,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (6409,320,5,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6409,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6409,401,0.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6409,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6409,601,2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6409,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6409,606,0.455,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6410,203,0.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6410,204,2.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6410,205,3.62,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6410,207,1.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6410,208,37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6410,255,92.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6410,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6410,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6410,301,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6410,303,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6410,306,50,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6410,307,254,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6410,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (6410,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6410,401,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6410,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6410,601,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6410,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6410,606,0.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6411,203,2.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6411,204,4.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6411,205,4.26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6411,207,1.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6411,208,63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6411,255,88.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6411,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6411,291,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6411,301,57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6411,303,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6411,306,62,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6411,307,388,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6411,320,120,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6411,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6411,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6411,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6411,601,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6411,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6411,606,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6413,203,2.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6413,204,0.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6413,205,0.38,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6413,207,1.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6413,208,16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6413,255,95.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6413,269,0.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6413,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6413,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6413,303,0.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6413,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6413,307,306,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6413,320,0,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6413,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6413,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6413,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6413,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6413,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6413,606,0.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6416,203,1.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6416,204,3.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6416,205,3.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6416,207,1.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6416,208,48,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6416,255,90.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6416,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6416,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6416,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6416,303,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6416,306,36,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6416,307,347,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6416,320,67,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6416,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6416,401,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6416,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6416,601,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6416,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6416,606,0.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6417,203,1.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6417,204,0.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6417,205,3.43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6417,207,1.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6417,208,23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6417,255,93.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6417,269,1.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6417,291,0.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6417,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6417,303,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6417,306,31,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6417,307,391,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6417,320,3,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6417,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6417,401,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6417,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6417,601,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6417,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6417,606,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6419,203,1.16,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6419,204,0.76,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6419,205,2.97,'100g',7,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6419,207,0.94,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6419,208,24,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6419,255,94.17,'100g',7,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6419,269,0,'100g',7,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6419,291,0.5,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6419,301,5,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6419,303,0.33,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6419,306,24,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6419,307,335,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6419,320,11,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (6419,328,0,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6419,401,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6419,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6419,601,4,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6419,605,0.003,'100g',7,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6419,606,0.191,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6423,203,1.45,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6423,204,0.78,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6423,205,2.92,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6423,207,0.99,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6423,208,24,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6423,255,93.87,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6423,269,0.08,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6423,291,0.3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6423,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6423,303,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6423,306,41,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6423,307,238,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6423,320,9,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (6423,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6423,401,0.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6423,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6423,601,3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6423,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6423,606,0.185,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6426,203,2.49,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6426,204,1.24,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6426,205,9.23,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6426,207,1.37,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6426,208,57,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6426,255,85.68,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6426,269,2.49,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6426,291,1.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6426,301,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6426,303,0.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6426,306,196,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6426,307,388,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6426,320,28,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6426,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6426,401,1.5,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6426,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6426,601,5,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6426,605,0.034,'100g',7,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6426,606,0.608,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6428,203,0.85,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6428,204,0.86,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6428,205,4.77,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6428,207,1.26,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6428,208,30,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6428,255,92.26,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6428,269,1.32,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6428,291,0.6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6428,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6428,303,0.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6428,306,74,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6428,307,226,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6428,320,20,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6428,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6428,401,1.6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6428,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6428,601,1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6428,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (6428,606,0.149,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6430,203,1.55,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6430,204,1.01,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6430,205,5.05,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6430,207,1.5,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6430,208,35,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6430,255,90.89,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6430,269,0.19,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6430,291,0.3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6430,301,9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6430,303,1.22,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6430,306,108,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6430,307,254,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6430,320,8,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6430,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6430,401,2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6430,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6430,601,3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6430,605,0.006,'100g',7,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6430,606,0.468,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6432,203,2.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6432,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6432,205,0.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6432,207,0.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6432,208,12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6432,255,96.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6432,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6432,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6432,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6432,303,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6432,306,64,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6432,307,264,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6432,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6432,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6432,401,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6432,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6432,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6432,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6432,606,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6440,203,1.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6440,204,1.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6440,205,4.66,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6440,207,1.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6440,208,34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6440,255,91.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6440,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6440,291,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6440,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6440,303,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6440,306,130,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6440,307,254,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6440,320,49,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6440,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6440,401,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6440,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6440,601,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6440,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6440,606,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6442,203,0.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6442,204,0.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6442,205,4.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6442,207,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6442,208,30,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6442,255,92.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6442,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6442,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6442,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6442,303,0.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6442,306,38,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6442,307,365,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6442,320,4,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6442,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6442,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6442,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6442,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6442,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6442,606,0.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6443,203,0.66,'100g',7,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6443,204,2.59,'100g',7,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6443,205,3.33,'100g',7,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6443,207,0.96,'100g',7,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6443,208,39,'100g',7,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6443,255,92.46,'100g',7,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6443,269,0.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6443,291,0.3,'100g',7,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6443,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6443,303,0.09,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6443,306,31,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6443,307,340,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (6443,320,1,'100g',4,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (6443,328,0.1,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6443,401,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6443,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6443,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6443,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6443,606,0.472,'100g',7,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6444,203,1.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6444,204,1.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6444,205,3.81,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6444,207,1.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6444,208,35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6444,255,92.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6444,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6444,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6444,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6444,303,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6444,306,65,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6444,307,397,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6444,320,26,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6444,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6444,401,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6444,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6444,601,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6444,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6444,606,0.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6446,203,1.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6446,204,2.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6446,205,5.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6446,207,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6446,208,44,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6446,255,90.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6446,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6446,291,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6446,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6446,303,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6446,306,49,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6446,307,380,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6446,320,6,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6446,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6446,401,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6446,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6446,601,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6446,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6446,606,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6448,203,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6448,204,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6448,205,1.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6448,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6448,208,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6448,255,94.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6448,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6448,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6448,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6448,303,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6448,306,20,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6448,307,407,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6448,320,8,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6448,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6448,401,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6448,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6448,601,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6448,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6448,606,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6449,203,3.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6449,204,1.09,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6449,205,9.88,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6449,207,1.28,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6449,208,61,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6449,255,84.55,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6449,269,3.19,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6449,291,1.9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6449,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6449,303,0.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6449,306,71,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6449,307,336,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6449,320,3,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6449,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6449,401,0.6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6449,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6449,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6449,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6449,606,0.524,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6451,203,4.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6451,204,1.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6451,205,11.05,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6451,207,1.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6451,208,75,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6451,255,81.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6451,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6451,291,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6451,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6451,303,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6451,306,158,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6451,307,398,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6451,320,9,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6451,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6451,401,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6451,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6451,601,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6451,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6451,606,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6453,203,0.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6453,204,0.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6453,205,4.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6453,207,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6453,208,30,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6453,255,92.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6453,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6453,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6453,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6453,303,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6453,306,56,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6453,307,238,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6453,320,29,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6453,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6453,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6453,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6453,601,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6453,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6453,606,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6456,203,1.11,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6456,204,2.07,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6456,205,3.27,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6456,207,1.18,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6456,208,36,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6456,255,92.38,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6456,269,0.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6456,291,0.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6456,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6456,303,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6456,306,24,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6456,307,391,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6456,320,16,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6456,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6456,401,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6456,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6456,601,7,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6456,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6456,606,1.29,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6461,203,1.78,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6461,204,1.71,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6461,205,8.44,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6461,207,1.09,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6461,208,56,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6461,255,86.99,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6461,269,0.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6461,291,0.6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6461,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6461,303,0.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6461,306,88,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6461,307,367,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6461,320,12,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6461,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6461,401,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6461,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6461,601,2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6461,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6461,606,0.635,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6463,203,0.82,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6463,204,1.06,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6463,205,8.54,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6463,207,1.07,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6463,208,47,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6463,255,88.52,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6463,269,2.95,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6463,291,0.7,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6463,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6463,303,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6463,306,129,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6463,307,319,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6463,320,12,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6463,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6463,401,5.8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6463,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6463,601,1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6463,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6463,606,0.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6465,203,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6465,204,0.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6465,205,3.54,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6465,207,1.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6465,208,28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6465,255,92.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6465,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6465,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6465,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6465,303,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6465,306,31,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6465,307,334,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6465,320,6,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6465,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6465,401,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6465,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6465,601,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6465,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6465,606,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6466,203,1.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6466,204,1.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6466,205,3.58,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6466,207,0.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6466,208,30,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6466,255,92.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6466,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6466,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6466,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6466,303,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6466,306,73,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6466,307,376,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6466,320,51,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6466,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6466,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6466,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6466,601,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6466,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6466,606,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6468,203,0.86,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6468,204,0.79,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6468,205,4.89,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6468,207,1.06,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6468,208,28,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6468,255,92.41,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6468,269,1.57,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6468,291,0.3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6468,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6468,303,0.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6468,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6468,307,338,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6468,320,71,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6468,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6468,401,0.6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6468,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6468,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6468,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6468,606,0.12,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6471,203,2.23,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6471,204,0.76,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6471,205,4.06,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6471,207,1.18,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6471,208,31,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6471,255,91.8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6471,269,0.45,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6471,291,0.8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6471,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6471,303,0.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6471,306,69,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6471,307,349,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6471,320,78,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6471,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6471,401,1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6471,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6471,601,2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6471,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6471,606,0.34,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6472,203,1.21,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6472,204,0.78,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6472,205,5.35,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6472,207,1.08,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6472,208,33,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6472,255,91.59,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6472,269,0.82,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6472,291,0.7,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6472,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6472,303,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6472,306,79,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6472,307,253,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6472,320,43,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6472,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6472,401,1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6472,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6472,601,1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6472,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6472,606,0.18,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6475,203,0.21,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6475,204,0.08,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6475,205,0.25,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6475,207,0.77,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6475,208,3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6475,255,98.69,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6475,269,0.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6475,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6475,301,4,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6475,303,0.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6475,306,6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6475,307,382,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (6475,320,0,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6475,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6475,401,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6475,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6475,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6475,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (6475,606,0.04,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6476,203,0.21,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6476,204,0.08,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6476,205,0.25,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6476,207,0.77,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6476,208,3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6476,255,98.69,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6476,269,0.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6476,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6476,301,4,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6476,303,0.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6476,306,6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6476,307,260,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6476,320,0,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6476,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6476,401,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6476,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6476,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6476,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (6476,606,0.04,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6480,203,0.28,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6480,204,0.23,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6480,205,0.3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6480,207,0.92,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6480,208,4,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6480,255,98.28,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6480,269,0.29,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6480,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6480,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6480,303,0.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6480,306,6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6480,307,401,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6480,320,0,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6480,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6480,401,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6480,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6480,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6480,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6480,606,0.057,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6481,203,0.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6481,204,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6481,205,0.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6481,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6481,208,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6481,255,97.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6481,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6481,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6481,301,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6481,303,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6481,306,10,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6481,307,326,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6481,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6481,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6481,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6481,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6481,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6481,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6481,606,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6483,203,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6483,204,2.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6483,205,5.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6483,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6483,208,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6483,255,90.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6483,269,1.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6483,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6483,301,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6483,303,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6483,306,82,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6483,307,454,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6483,320,8,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6483,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6483,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6483,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6483,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6483,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6483,606,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6494,203,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6494,204,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6494,205,2.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6494,207,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6494,208,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6494,255,95.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6494,269,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6494,291,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6494,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6494,303,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6494,306,31,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6494,307,346,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6494,320,0,'100g',2,1,'2024-12-12','2006-01-10');
INSERT INTO `cndb_nutval` VALUES (6494,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6494,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6494,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6494,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6494,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6494,606,0.004,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6498,203,0.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6498,204,0.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6498,205,7.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6498,207,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6498,208,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6498,255,89.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6498,269,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6498,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6498,301,29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6498,303,0.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6498,306,111,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6498,307,356,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6498,320,20,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6498,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6498,401,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6498,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6498,601,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6498,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6498,606,0.286,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6528,203,0.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6528,204,0.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6528,205,3.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6528,207,0.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6528,208,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6528,255,94.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6528,269,0.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6528,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6528,301,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6528,303,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6528,306,13,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6528,307,229,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6528,320,1,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6528,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6528,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6528,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6528,601,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6528,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6528,606,0.122,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6547,203,2.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6547,204,1.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6547,205,2.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6547,207,1.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6547,208,30,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6547,255,92.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6547,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6547,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6547,301,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6547,303,0.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6547,306,63,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6547,307,386,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6547,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6547,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6547,401,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6547,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6547,601,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6547,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6547,606,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6549,203,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6549,204,3.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6549,205,3.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6549,207,0.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6549,208,54,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6549,255,90,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6549,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6549,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6549,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6549,303,0.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6549,306,63,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6549,307,327,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (6549,320,23,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6549,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6549,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6549,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6549,601,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6549,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6549,606,0.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6558,203,0.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6558,204,1.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6558,205,9.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6558,207,1.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6558,208,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6558,255,87.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6558,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6558,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6558,301,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6558,303,0.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6558,306,169,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6558,307,424,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6558,320,18,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6558,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6558,401,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6558,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6558,601,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6558,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6558,606,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6559,203,0.71,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6559,204,0.21,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6559,205,7.45,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6559,207,1.08,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6559,208,32,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6559,255,90.55,'100g',7,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6559,269,4.03,'100g',7,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6559,291,0.5,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6559,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6559,303,0.29,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6559,306,275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6559,307,186,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6559,320,10,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (6559,328,0,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6559,401,6.3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6559,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6559,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6559,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (6559,606,0.056,'100g',7,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6583,203,10.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6583,204,17.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6583,205,60.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6583,207,5.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6583,208,440,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6583,255,6.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6583,269,1.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6583,291,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6583,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6583,303,4.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6583,306,181,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6583,307,1855,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6583,320,1,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (6583,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6583,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6583,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6583,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6583,605,0.065,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6583,606,8.117,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6584,203,2.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6584,204,5.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6584,205,7.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6584,207,2.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6584,208,87,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6584,255,82.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6584,269,2.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6584,291,1.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6584,301,41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6584,303,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6584,306,207,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6584,307,661,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6584,320,66,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6584,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6584,401,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6584,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6584,601,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6584,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6584,606,1.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6618,203,2.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6618,204,6.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6618,205,28.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6618,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6618,208,179,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6618,255,62.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6618,269,18.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6618,291,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6618,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6618,303,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6618,306,99,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6618,307,319,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6618,320,0,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (6618,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6618,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6618,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6618,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6618,605,0.002,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6618,606,3.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6626,203,9.83,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6626,204,37.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6626,205,10.09,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6626,207,3.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6626,208,418,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6626,255,38.98,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6626,269,6.33,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6626,291,1.8,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6626,301,306,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6626,303,0.57,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6626,306,560,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6626,307,603,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6626,320,77,'100g',1,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (6626,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6626,401,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6626,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6626,601,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (6626,605,0.398,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6626,606,7.07,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6627,203,5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6627,204,42.42,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6627,205,6.14,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6627,207,3.35,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6627,208,426,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6627,255,43.08,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6627,269,1.92,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6627,291,1.7,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6627,301,173,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6627,303,0.88,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6627,306,205,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6627,307,998,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6627,320,90,'100g',1,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (6627,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6627,401,0.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6627,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6627,601,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (6627,605,0.194,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6627,606,7.362,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6700,203,0.24,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6700,204,0.07,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6700,205,0.93,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6700,207,0.71,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6700,208,5,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6700,255,98.05,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6700,269,0.55,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6700,291,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6700,301,3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6700,303,0.06,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6700,306,19,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6700,307,296,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6700,320,12,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (6700,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6700,401,0.4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6700,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6700,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6700,605,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6700,606,0.028,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6720,203,7.68,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6720,204,18.33,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6720,205,60.52,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6720,207,9.67,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6720,208,438,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6720,255,3.78,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6720,269,10.26,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6720,291,1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6720,301,204,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6720,303,0.5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6720,306,428,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6720,307,3202,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6720,320,56,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6720,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6720,401,0.9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6720,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6720,601,23,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6720,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (6720,606,8.44,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6725,203,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6725,204,6.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6725,205,7.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6725,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6725,208,99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6725,255,82.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6725,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6725,291,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6725,301,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6725,303,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6725,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6725,307,299,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6725,320,58,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (6725,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6725,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6725,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6725,601,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6725,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6725,606,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6731,203,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6731,204,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6731,205,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6731,207,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6731,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6731,255,70.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6731,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6731,291,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6731,301,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6731,303,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6731,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6731,307,672,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6731,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (6731,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6731,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6731,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6731,601,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6731,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6731,606,0.601,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6742,203,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6742,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6742,205,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6742,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6742,208,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6742,255,88.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6742,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6742,291,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6742,301,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6742,303,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6742,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6742,307,376,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6742,320,33,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (6742,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6742,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6742,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6742,601,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6742,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6742,606,0.221,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6749,203,3.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6749,204,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6749,205,6.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6749,207,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6749,208,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6749,255,88.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6749,269,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6749,291,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6749,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6749,303,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6749,306,174,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6749,307,326,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6749,320,115,'100g',1,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (6749,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6749,401,3.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6749,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6749,601,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6749,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6749,606,0.407,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6930,203,6.71,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6930,204,13.29,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6930,205,6.83,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6930,207,2.67,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6930,208,174,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6930,255,70.5,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6930,269,0.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6930,291,0.5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6930,301,184,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6930,303,0.21,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6930,306,30,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6930,307,828,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6930,320,80,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (6930,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6930,401,0.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6930,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6930,601,29,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6930,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (6930,606,6.01,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6931,203,1.39,'100g',1,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6931,204,1.61,'100g',1,1,'1996-09-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6931,205,7.43,'100g',3,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6931,207,1.7,'100g',1,1,'1996-09-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6931,208,50,'100g',3,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6931,255,87.87,'100g',1,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6931,269,4.91,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6931,291,1.8,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (6931,301,26,'100g',1,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6931,303,0.73,'100g',1,1,'1996-09-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6931,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6931,307,437,'100g',1,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (6931,320,31,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (6931,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6931,401,2,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6931,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6931,601,2,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (6931,605,0.007,'100g',3,1,'2006-02-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6931,606,0.218,'100g',3,1,'1996-09-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6955,203,1.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6955,204,1.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6955,205,9.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6955,207,1.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6955,208,58,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6955,255,85.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6955,269,0.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6955,291,0.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6955,301,11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6955,303,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6955,306,272,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6955,307,357,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6955,320,25,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (6955,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6955,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6955,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6955,601,6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6955,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6955,606,0.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6956,203,1.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6956,204,0.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6956,205,13.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6956,207,1.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6956,208,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6956,255,82.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6956,269,8.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6956,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6956,301,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6956,303,1.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6956,306,229,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6956,307,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6956,320,20,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6956,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6956,401,12.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6956,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6956,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6956,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6956,606,0.155,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6957,203,8.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6957,204,11.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6957,205,59.78,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6957,207,14.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6957,208,380,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6957,255,5.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6957,269,9.23,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6957,291,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6957,301,116,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6957,303,7.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6957,306,367,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6957,307,5053,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6957,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6957,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6957,401,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6957,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6957,601,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6957,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6957,606,5.866,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6958,203,9.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6958,204,9.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6958,205,61.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6958,207,14.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6958,208,369,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6958,255,4.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6958,269,23.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6958,291,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6958,301,141,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6958,303,6.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6958,306,450,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6958,307,5203,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6958,320,2,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6958,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6958,401,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6958,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6958,601,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6958,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6958,606,4.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6959,203,11.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6959,204,14.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6959,205,57.56,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6959,207,10.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6959,208,409,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6959,255,5.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6959,269,7.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6959,291,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6959,301,115,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6959,303,9.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6959,306,306,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6959,307,4090,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6959,320,18,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6959,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6959,401,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6959,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6959,601,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6959,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6959,606,4.931,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6960,203,15.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6960,204,36.35,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6960,205,36.52,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6960,207,9.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6960,208,535,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6960,255,2.05,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6960,269,5.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6960,291,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6960,301,467,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6960,303,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6960,306,254,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6960,307,2590,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6960,320,54,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (6960,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6960,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6960,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6960,601,56,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6960,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6960,606,13.18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6961,203,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6961,204,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6961,205,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6961,207,0.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6961,208,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6961,255,94.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6961,269,2.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6961,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6961,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6961,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6961,306,564,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6961,307,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6961,320,23,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (6961,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6961,401,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6961,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6961,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6961,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6961,606,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6962,203,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6962,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6962,205,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6962,207,0.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6962,208,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6962,255,93.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6962,269,2.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6962,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6962,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6962,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6962,306,564,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6962,307,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6962,320,29,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (6962,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6962,401,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6962,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6962,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6962,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6962,606,0.013,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6963,203,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6963,204,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6963,205,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6963,207,0.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6963,208,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6963,255,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6963,269,0.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6963,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6963,301,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6963,303,0.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6963,306,86,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6963,307,200,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (6963,320,1,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (6963,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6963,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6963,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6963,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6963,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6963,606,0.133,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6964,203,0.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6964,204,0.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6964,205,6.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6964,207,0.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6964,208,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6964,255,91.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6964,269,3.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6964,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6964,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6964,303,0.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6964,306,112,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6964,307,33,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6964,320,10,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6964,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6964,401,6.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6964,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6964,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6964,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6964,606,0.076,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6965,203,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6965,204,1.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6965,205,9.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6965,207,1.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6965,208,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6965,255,84.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6965,269,3.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6965,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6965,301,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6965,303,0.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6965,306,71,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6965,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6965,320,3,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6965,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6965,401,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6965,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6965,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6965,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6965,606,0.524,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6966,203,1.27,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6966,204,0.95,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6966,205,2.95,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6966,207,1.01,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6966,208,25,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6966,255,93.82,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6966,269,0.27,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6966,291,0.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6966,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6966,303,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6966,306,22,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6966,307,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6966,320,11,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6966,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6966,401,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6966,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6966,601,5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6966,605,0.003,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6966,606,0.262,'100g',7,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6967,203,1.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6967,204,0.45,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6967,205,6.06,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6967,207,1.05,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6967,208,33,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6967,255,91.35,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6967,269,2.15,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6967,291,1.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6967,301,12,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6967,303,0.33,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6967,306,217,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6967,307,194,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6967,320,43,'100g',4,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (6967,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6967,401,0.4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6967,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6967,601,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6967,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6967,606,0.074,'100g',7,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6968,203,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6968,204,3.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6968,205,4.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6968,207,0.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6968,208,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6968,255,90.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6968,269,1.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6968,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6968,301,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6968,303,0.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6968,306,41,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6968,307,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6968,320,7,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (6968,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6968,401,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6968,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6968,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6968,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6968,606,1.005,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6969,203,9.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6969,204,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6969,205,76.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6969,207,5.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6969,208,343,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6969,255,5.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6969,269,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6969,291,7.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6969,301,172,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6969,303,2.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6969,306,1248,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6969,307,2400,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6969,320,3,'100g',2,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (6969,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6969,401,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6969,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6969,601,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6969,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6969,606,0.613,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6970,203,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6970,204,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6970,205,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6970,207,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6970,208,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6970,255,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6970,269,0.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6970,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6970,301,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6970,303,0.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6970,306,86,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6970,307,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6970,320,0,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (6970,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6970,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6970,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6970,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6970,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6970,606,0.179,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6971,203,0,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (6971,204,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (6971,205,19.17,'100g',3,1,'2007-12-03','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (6971,207,2.29,'100g',3,1,'2007-12-03','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (6971,208,77,'100g',3,1,'2007-12-03','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (6971,255,78.54,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (6971,269,10.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6971,291,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (6971,301,107,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (6971,303,5.3,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (6971,306,800,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6971,307,1300,'100g',6,1,'2007-12-03','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (6971,320,5,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (6971,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6971,401,13,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (6971,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6971,601,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (6971,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (6971,606,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (6972,203,2.5,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6972,204,0.3,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6972,205,19.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6972,207,9.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6972,208,92,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6972,255,68,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6972,269,13.33,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6972,291,2.4,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6972,301,20,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6972,303,0.8,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6972,306,370,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6972,307,1338,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6972,320,34,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (6972,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6972,401,16,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6972,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6972,601,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (6972,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6972,606,0.045,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6974,203,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6974,204,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6974,205,8.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6974,207,0.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6974,208,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6974,255,83.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6974,269,1.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6974,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6974,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6974,303,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6974,306,153,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6974,307,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6974,320,138,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (6974,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6974,401,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6974,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6974,601,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6974,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6974,606,0.597,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6976,203,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6976,204,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6976,205,8.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6976,207,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6976,208,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6976,255,87.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6976,269,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6976,291,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6976,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6976,303,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6976,306,319,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6976,307,30,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6976,320,33,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (6976,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6976,401,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6976,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6976,601,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6976,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6976,606,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6977,203,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6977,204,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6977,205,6.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6977,207,0.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6977,208,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6977,255,87.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6977,269,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6977,291,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6977,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6977,303,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6977,306,81,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6977,307,18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6977,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (6977,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6977,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6977,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6977,601,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6977,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6977,606,1.003,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6978,203,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6978,204,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6978,205,9.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6978,207,0.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6978,208,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6978,255,83.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6978,269,0.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6978,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6978,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6978,303,0.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6978,306,140,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6978,307,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6978,320,98,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (6978,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6978,401,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6978,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6978,601,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6978,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6978,606,1.621,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6980,203,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6980,204,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6980,205,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6980,207,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6980,208,98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6980,255,79.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6980,269,1.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6980,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6980,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6980,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6980,306,140,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6980,307,435,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6980,320,84,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (6980,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6980,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6980,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6980,601,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6980,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6980,606,2.324,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6981,203,16.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6981,204,13.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6981,205,64.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6981,207,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6981,208,438,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6981,255,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6981,269,14.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6981,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6981,301,187,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6981,303,1.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6981,306,309,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6981,307,1067,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6981,320,25,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (6981,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6981,401,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6981,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (6981,601,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6981,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6981,606,3.433,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6982,203,10.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6982,204,17.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6982,205,60.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6982,207,5.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6982,208,441,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6982,255,6.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6982,269,1.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6982,291,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6982,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6982,303,3.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6982,306,177,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6982,307,1727,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6982,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (6982,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6982,401,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6982,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6982,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6982,605,0.069,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (6982,606,8.158,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6983,203,10.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6983,204,17.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6983,205,60.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6983,207,5.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6983,208,439,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6983,255,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6983,269,1.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6983,291,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6983,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6983,303,4.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6983,306,183,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6983,307,1923,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6983,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (6983,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (6983,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6983,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (6983,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (6983,605,0.063,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (6983,606,8.095,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7001,203,15.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7001,204,8.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7001,205,6.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7001,207,4.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7001,208,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7001,255,64.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7001,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7001,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7001,301,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7001,303,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7001,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7001,307,1334,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7001,320,3,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (7001,328,0.9,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7001,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7001,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7001,601,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7001,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7001,606,3.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7002,203,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7002,204,22.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7002,205,3.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7002,207,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7002,208,277,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7002,255,56.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7002,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7002,291,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7002,301,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7002,303,1.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7002,306,244,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7002,307,881,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7002,320,3,'100g',2,1,'2024-12-12','2004-01-07');
INSERT INTO `cndb_nutval` VALUES (7002,328,0.9,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7002,401,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7002,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7002,601,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7002,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7002,606,8.438,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7003,203,14.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7003,204,18.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7003,205,2.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7003,207,3.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7003,208,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7003,255,61.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7003,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7003,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7003,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7003,303,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7003,306,253,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7003,307,1240,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7003,320,0,'100g',1,1,'2024-12-12','2006-01-02');
INSERT INTO `cndb_nutval` VALUES (7003,328,0.9,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7003,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7003,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7003,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7003,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7003,606,6.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7004,203,15.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7004,204,17.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7004,205,2.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7004,207,3.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7004,208,230,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7004,255,60.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7004,269,2.35,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7004,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7004,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7004,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7004,306,283,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7004,307,1297,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7004,320,0,'100g',2,1,'2024-12-12','2002-01-08');
INSERT INTO `cndb_nutval` VALUES (7004,328,0.3,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7004,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7004,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7004,601,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7004,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7004,606,6.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7005,203,14.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7005,204,34.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7005,205,1.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7005,207,2.31,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7005,208,379,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7005,255,47.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7005,269,1.29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7005,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7005,301,6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7005,303,6.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7005,306,38,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7005,307,680,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7005,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (7005,328,1.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7005,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7005,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7005,601,120,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7005,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7005,606,13.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7006,203,14.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7006,204,25.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7006,205,2.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7006,207,2.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7006,208,301,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7006,255,54.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7006,269,1.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7006,291,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7006,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7006,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7006,306,270,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7006,307,756,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7006,320,15,'100g',2,1,'2024-12-12','2013-01-07');
INSERT INTO `cndb_nutval` VALUES (7006,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7006,401,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7006,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7006,601,93,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7006,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7006,606,10.256,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7007,203,10.91,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (7007,204,26.13,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (7007,205,4.29,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (7007,207,3.37,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (7007,208,299,'100g',3,1,'1994-01-31','2012-09-01');
INSERT INTO `cndb_nutval` VALUES (7007,255,55.31,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (7007,269,2.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7007,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7007,301,21,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (7007,303,1.29,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (7007,306,351,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7007,307,1013,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (7007,320,19,'100g',1,1,'2024-12-12','2012-01-09');
INSERT INTO `cndb_nutval` VALUES (7007,328,0.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7007,401,15.2,'100g',1,1,'1994-01-31','2012-09-01');
INSERT INTO `cndb_nutval` VALUES (7007,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7007,601,57,'100g',1,1,'1994-01-31','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (7007,605,1.37,'100g',3,1,'2006-01-24','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (7007,606,10.487,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7008,203,15.2,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7008,204,24.59,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7008,205,5.49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7008,207,2.85,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7008,208,308,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7008,255,51.87,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7008,269,4.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7008,291,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7008,301,85,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7008,303,1.21,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7008,306,315,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7008,307,960,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (7008,320,25,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (7008,328,0.8,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7008,401,0.8,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7008,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7008,601,60,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7008,605,0,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7008,606,9.301,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7010,203,15.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7010,204,19.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7010,205,0.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7010,207,3.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7010,208,247,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7010,255,60.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7010,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7010,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7010,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7010,303,0.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7010,306,281,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7010,307,907,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (7010,320,0,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (7010,328,1.4,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7010,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7010,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7010,601,59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7010,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (7010,606,6.839,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7011,203,11.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7011,204,16.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7011,205,4.68,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7011,207,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7011,208,209,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7011,255,64.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7011,269,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7011,291,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7011,301,123,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7011,303,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7011,306,135,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7011,307,1071,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (7011,320,9,'100g',2,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (7011,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7011,401,13.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7011,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7011,601,75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7011,605,0.123,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7011,606,4.355,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7013,203,13.72,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7013,204,29.18,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7013,205,2.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7013,207,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7013,208,333,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7013,255,51.45,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7013,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7013,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7013,301,28,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7013,303,0.53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7013,306,348,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7013,307,846,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7013,320,2,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (7013,328,1.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7013,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7013,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7013,601,74,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7013,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7013,606,9.998,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7014,203,14.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7014,204,28.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7014,205,3.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7014,207,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7014,208,327,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7014,255,50.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7014,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7014,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7014,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7014,303,11.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7014,306,199,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7014,307,977,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7014,320,4220,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (7014,328,1.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7014,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7014,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7014,601,180,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7014,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7014,606,9.307,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7015,203,14.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7015,204,27.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7015,205,2.98,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7015,207,3.67,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7015,208,323,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7015,255,51.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7015,269,2.98,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7015,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7015,301,48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7015,303,1.03,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7015,306,281,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7015,307,1112,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7015,320,0,'100g',2,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (7015,328,0.3,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7015,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7015,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7015,601,63,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7015,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7015,606,9.93,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7016,203,14.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7016,204,29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7016,205,1.51,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7016,207,3.03,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7016,208,328,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7016,255,52.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7016,269,1.51,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7016,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7016,301,58,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7016,303,1.08,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7016,306,206,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7016,307,1082,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7016,320,6,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (7016,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7016,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7016,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7016,601,68,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7016,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7016,606,10.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7018,203,18.01,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7018,204,17.56,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7018,205,4.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7018,207,2.97,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7018,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7018,255,57.41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7018,269,0.47,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7018,291,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7018,301,16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7018,303,0.87,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7018,306,106,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7018,307,722,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7018,320,30,'100g',2,1,'2024-12-12','2002-01-08');
INSERT INTO `cndb_nutval` VALUES (7018,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7018,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7018,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7018,601,56,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7018,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7018,606,3.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7019,203,13.63,'100g',1,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7019,204,25.1,'100g',1,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7019,205,3.78,'100g',3,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7019,207,2.72,'100g',1,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7019,208,296,'100g',3,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7019,255,54.77,'100g',1,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7019,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7019,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7019,301,19,'100g',1,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7019,303,1.41,'100g',1,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7019,306,308,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7019,307,788,'100g',1,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7019,320,0,'100g',1,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (7019,328,1.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7019,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7019,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7019,601,63,'100g',1,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7019,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (7019,606,8.595,'100g',3,1,'1996-09-30','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7020,203,22.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7020,204,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7020,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7020,207,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7020,208,153,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7020,255,69.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7020,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7020,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7020,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7020,303,2.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7020,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7020,307,953,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7020,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (7020,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7020,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7020,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7020,601,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7020,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7020,606,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7021,203,12,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7021,204,22.91,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7021,205,3.93,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7021,207,3.07,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7021,208,273,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7021,255,58.1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7021,269,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7021,291,0.3,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7021,301,7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7021,303,0.16,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7021,306,210,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7021,307,786,'100g',6,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7021,320,33,'100g',2,1,'2024-12-12','2008-01-06');
INSERT INTO `cndb_nutval` VALUES (7021,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7021,401,1.4,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7021,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7021,601,60,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7021,605,0,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7021,606,8.806,'100g',3,1,'1996-09-30','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7022,203,11.69,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7022,204,28.1,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7022,205,2.97,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7022,207,2.76,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7022,208,315,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7022,255,54.47,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7022,269,1.17,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7022,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7022,301,14,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7022,303,1.12,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7022,306,364,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7022,307,865,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7022,320,3,'100g',1,1,'2024-12-12','2016-01-03');
INSERT INTO `cndb_nutval` VALUES (7022,328,0.9,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7022,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7022,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7022,601,58,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7022,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (7022,606,11.46,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7024,203,15.51,'100g',1,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7024,204,16.19,'100g',1,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7024,205,2.74,'100g',3,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7024,207,3.06,'100g',1,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7024,208,223,'100g',3,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7024,255,62.5,'100g',1,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7024,269,2.98,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7024,291,0,'100g',4,1,'1994-11-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7024,301,74,'100g',1,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7024,303,1.17,'100g',1,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7024,306,202,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7024,307,1027,'100g',3,1,'1994-11-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7024,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (7024,328,0.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7024,401,0,'100g',4,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7024,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7024,601,96,'100g',1,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7024,605,0.149,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7024,606,3.856,'100g',3,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7025,203,12.23,'100g',1,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7025,204,17.29,'100g',1,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7025,205,3.81,'100g',3,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7025,207,3.68,'100g',1,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7025,208,223,'100g',3,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7025,255,62.99,'100g',1,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7025,269,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7025,291,0,'100g',1,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7025,301,148,'100g',1,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7025,303,1.47,'100g',1,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7025,306,392,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7025,307,911,'100g',6,1,'1994-11-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (7025,320,0,'100g',1,1,'2024-12-12','2002-01-08');
INSERT INTO `cndb_nutval` VALUES (7025,328,0.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7025,401,0,'100g',4,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7025,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7025,601,77,'100g',1,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7025,605,0.789,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7025,606,4.028,'100g',3,1,'1994-11-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7026,203,16.06,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7026,204,18.83,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7026,205,0.26,'100g',3,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (7026,207,4.08,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7026,208,239,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7026,255,60.77,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7026,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7026,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7026,301,7,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7026,303,0.95,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7026,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7026,307,1280,'100g',6,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (7026,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (7026,328,0.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7026,401,2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7026,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7026,601,49,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7026,605,NULL,'100g',NULL,1,'1996-09-30','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (7026,606,6.291,'100g',3,1,'1996-09-30','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7027,203,16.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7027,204,16.7,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7027,205,0,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7027,207,3.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7027,208,221,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7027,255,65.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7027,269,5,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7027,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7027,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7027,303,0.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7027,306,319,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7027,307,1194,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7027,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (7027,328,0.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7027,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7027,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7027,601,59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7027,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (7027,606,6.1,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7028,203,16.85,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7028,204,4.04,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7028,205,0.7,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7028,207,3.57,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7028,208,107,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7028,255,74.84,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7028,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7028,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7028,301,5,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (7028,303,0.59,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7028,306,463,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7028,307,945,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7028,320,0,'100g',1,1,'2024-12-12','2004-01-05');
INSERT INTO `cndb_nutval` VALUES (7028,328,0.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7028,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7028,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7028,601,41,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (7028,605,0.014,'100g',3,1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7028,606,1.227,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7029,203,16.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7029,204,8.8,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7029,205,3.63,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7029,207,3.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7029,208,164,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7029,255,67.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7029,269,1,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7029,291,1.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7029,301,24,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7029,303,1.02,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7029,306,287,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7029,307,814,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7029,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (7029,328,0.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7029,401,4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7029,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7029,601,57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7029,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (7029,606,0.5,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7030,203,16.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7030,204,20.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7030,205,1.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7030,207,3.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7030,208,263,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7030,255,57.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7030,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7030,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7030,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7030,303,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7030,306,311,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7030,307,1245,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7030,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (7030,328,0.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7030,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7030,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7030,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7030,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7030,606,7.181,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7031,203,8.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7031,204,15.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7031,205,10.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7031,207,2.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7031,208,216,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7031,255,62.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7031,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7031,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7031,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7031,303,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7031,306,150,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7031,307,1075,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7031,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (7031,328,0.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7031,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7031,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7031,601,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7031,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7031,606,5.049,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7032,203,13.6,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7032,204,18.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7032,205,4,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7032,207,3.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7032,208,241,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7032,255,60.3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7032,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7032,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7032,301,58,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7032,303,0.91,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7032,306,294,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7032,307,1000,'100g',6,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (7032,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (7032,328,1.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7032,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7032,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7032,601,58,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7032,605,NULL,'100g',NULL,1,'1996-09-30','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (7032,606,6.966,'100g',3,1,'1996-09-30','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7033,203,16.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7033,204,18.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7033,205,2.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7033,207,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7033,208,245,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7033,255,59.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7033,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7033,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7033,301,217,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7033,303,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7033,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7033,307,1197,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7033,320,91,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (7033,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7033,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7033,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7033,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7033,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7033,606,8.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7034,203,13.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7034,204,10.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7034,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7034,207,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7034,208,157,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7034,255,73.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7034,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7034,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7034,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7034,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7034,306,31,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7034,307,941,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7034,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (7034,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7034,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7034,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7034,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7034,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7034,606,3.402,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7036,203,13.9,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7036,204,24.26,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7036,205,2.97,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7036,207,2.42,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7036,208,290,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7036,255,56.44,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7036,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (7036,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7036,301,12,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7036,303,1.77,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7036,306,211,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7036,307,563,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7036,320,0,'100g',1,1,'2024-12-12','2016-01-10');
INSERT INTO `cndb_nutval` VALUES (7036,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7036,401,0,'100g',4,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7036,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7036,601,69,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7036,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (7036,606,8.615,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7038,203,11.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7038,204,27.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7038,205,3.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7038,207,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7038,208,307,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7038,255,55.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7038,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7038,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7038,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7038,303,0.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7038,306,199,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7038,307,930,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7038,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (7038,328,1.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7038,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7038,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7038,601,60,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7038,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (7038,606,10.21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7039,203,19.03,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7039,204,10.44,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7039,205,0.44,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7039,207,4.32,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7039,208,172,'100g',3,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (7039,255,65.77,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7039,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7039,291,0,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7039,301,20,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7039,303,2.15,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7039,306,330,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7039,307,1374,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7039,320,12,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (7039,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7039,401,0.9,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7039,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7039,601,55,'100g',6,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7039,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (7039,606,2.794,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7040,203,15.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7040,204,25.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7040,205,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7040,207,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7040,208,304,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7040,255,53.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7040,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7040,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7040,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7040,303,10.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7040,306,226,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7040,307,1225,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7040,320,5252,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (7040,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7040,401,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7040,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7040,601,174,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7040,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7040,606,8.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7041,203,14.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7041,204,28.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7041,205,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7041,207,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7041,208,326,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7041,255,52.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7041,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7041,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7041,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7041,303,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7041,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7041,307,860,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7041,320,8308,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (7041,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7041,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7041,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7041,601,158,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7041,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7041,606,10.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7043,203,18.62,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7043,204,3.69,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7043,205,0.64,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7043,207,3.33,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7043,208,115,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7043,255,73.72,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7043,269,0.29,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7043,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7043,301,5,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7043,303,2.05,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7043,306,647,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7043,307,853,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7043,320,3,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (7043,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7043,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7043,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7043,601,51,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7043,605,0.148,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7043,606,1.318,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7045,203,12.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7045,204,30.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7045,205,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7045,207,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7045,208,334,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7045,255,51.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7045,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7045,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7045,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7045,303,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7045,306,215,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7045,307,1289,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7045,320,0,'100g',1,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (7045,328,0.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7045,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7045,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7045,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7045,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7045,606,10.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7046,203,21.81,'100g',3,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7046,204,0.83,'100g',3,1,'2010-01-04','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7046,205,3.51,'100g',3,1,'2010-01-04','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7046,207,2.87,'100g',3,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7046,208,109,'100g',3,1,'2010-01-04','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7046,255,71.1,'100g',3,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7046,269,3.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7046,291,0.5,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (7046,301,8,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (7046,303,0.63,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (7046,306,211,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7046,307,772,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (7046,320,10,'100g',1,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (7046,328,0.1,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7046,401,5.7,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (7046,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7046,601,44,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (7046,605,0,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (7046,606,0.197,'100g',3,1,'2010-01-04','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7050,203,16.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7050,204,25.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7050,205,3.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7050,207,2.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7050,208,311,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7050,255,52.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7050,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7050,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7050,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7050,303,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7050,306,163,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7050,307,1246,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7050,320,0,'100g',1,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (7050,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7050,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7050,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7050,601,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7050,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7050,606,9.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7051,203,11.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7051,204,16.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7051,205,9.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7051,207,4.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7051,208,235,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7051,255,58.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7051,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7051,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7051,301,109,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7051,303,0.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7051,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7051,307,964,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (7051,320,60,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (7051,328,1.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7051,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7051,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7051,601,38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7051,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (7051,606,5.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7052,203,16.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7052,204,6.21,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (7052,205,3.34,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (7052,207,3.98,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7052,208,139,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7052,255,71.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7052,269,3.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7052,291,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7052,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7052,303,4.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7052,306,345,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7052,307,1123,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (7052,320,4,'100g',2,1,'2024-12-12','2008-01-01');
INSERT INTO `cndb_nutval` VALUES (7052,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7052,401,8.1,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (7052,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7052,601,68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7052,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (7052,606,1.395,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7053,203,13.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7053,204,13.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7053,205,6.55,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7053,207,1.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7053,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7053,255,65.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7053,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7053,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7053,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7053,303,9.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7053,306,95,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7053,307,386,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7053,320,217,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (7053,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7053,401,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7053,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7053,601,391,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7053,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7053,606,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7054,203,11.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7054,204,43.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7054,205,4.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7054,207,3.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7054,208,462,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7054,255,37.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7054,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7054,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7054,301,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7054,303,5.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7054,306,138,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7054,307,697,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7054,320,1001,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (7054,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7054,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7054,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7054,601,150,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7054,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7054,606,14.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7055,203,14.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7055,204,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7055,205,1.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7055,207,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7055,208,319,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7055,255,53.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7055,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7055,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7055,301,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7055,303,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7055,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7055,307,697,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7055,320,991,'100g',1,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (7055,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7055,401,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7055,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7055,601,255,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7055,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7055,606,9.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7056,203,17.3,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7056,204,6.37,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7056,205,4.53,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (7056,207,4.4,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7056,208,149,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7056,255,67.4,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7056,269,4.61,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7056,291,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7056,301,54,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7056,303,1.07,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7056,306,394,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7056,307,732,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (7056,320,0,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (7056,328,0.8,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7056,401,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7056,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7056,601,46,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7056,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (7056,606,2.28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7057,203,19.25,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7057,204,46.28,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7057,205,1.18,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7057,207,4.74,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7057,208,504,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (7057,255,28.55,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (7057,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7057,291,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7057,301,19,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7057,303,1.33,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7057,306,274,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7057,307,1582,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7057,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (7057,328,1.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7057,401,0,'100g',4,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7057,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7057,601,97,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7057,605,1.527,'100g',3,1,'2006-02-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7057,606,17.708,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7058,203,11.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7058,204,15.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7058,205,8.46,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7058,207,4.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7058,208,225,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7058,255,60.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7058,269,8.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7058,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7058,301,109,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7058,303,1.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7058,306,371,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7058,307,1040,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (7058,320,78,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (7058,328,0.8,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7058,401,7.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7058,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7058,601,58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7058,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (7058,606,5.287,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7059,203,14.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7059,204,28.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7059,205,1.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7059,207,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7059,208,326,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7059,255,53.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7059,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7059,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7059,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7059,303,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7059,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7059,307,876,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7059,320,0,'100g',2,1,'2024-12-12','2002-01-07');
INSERT INTO `cndb_nutval` VALUES (7059,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7059,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7059,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7059,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7059,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7059,606,10.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7060,203,18.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7060,204,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7060,205,4.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7060,207,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7060,208,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7060,255,68.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7060,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7060,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7060,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7060,303,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7060,306,377,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7060,307,1225,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7060,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (7060,328,0.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7060,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7060,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7060,601,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7060,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7060,606,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7061,203,12.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7061,204,22.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7061,205,7.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7061,207,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7061,208,282,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7061,255,54.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7061,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7061,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7061,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7061,303,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7061,306,225,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7061,307,1127,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7061,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (7061,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7061,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7061,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7061,601,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7061,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7061,606,7.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7062,203,14.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7062,204,16.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7062,205,4.76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7062,207,3.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7062,208,232,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7062,255,60.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7062,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (7062,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7062,301,47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7062,303,1.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7062,306,267,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7062,307,1164,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7062,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (7062,328,1.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7062,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7062,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7062,601,38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7062,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (7062,606,6.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7063,203,15.39,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (7063,204,24.8,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (7063,205,0.93,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7063,207,2.54,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (7063,208,288,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (7063,255,56.59,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (7063,269,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7063,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7063,301,8,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (7063,303,1.02,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7063,306,307,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7063,307,739,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (7063,320,27,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (7063,328,1.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7063,401,0,'100g',4,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (7063,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7063,601,70,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7063,605,0.101,'100g',3,1,'2006-01-24','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7063,606,7.57,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (7064,203,18.53,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7064,204,27.25,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7064,205,1.42,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (7064,207,2.9,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7064,208,325,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7064,255,49.89,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7064,269,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7064,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7064,301,9,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (7064,303,1.2,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (7064,306,342,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7064,307,814,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7064,320,28,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (7064,328,1.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7064,401,0,'100g',4,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (7064,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7064,601,86,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7064,605,0.12,'100g',3,1,'2006-01-24','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (7064,606,8.826,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7065,203,13.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7065,204,36.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7065,205,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7065,207,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7065,208,396,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7065,255,44.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7065,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7065,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7065,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7065,303,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7065,306,189,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7065,307,929,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7065,320,0,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (7065,328,0.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7065,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7065,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7065,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7065,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7065,606,12.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7066,203,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7066,204,10.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7066,205,10.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7066,207,2.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7066,208,204,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7066,255,59.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7066,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7066,291,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7066,301,31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7066,303,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7066,306,207,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7066,307,721,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7066,320,2,'100g',2,1,'2024-12-12','2002-01-08');
INSERT INTO `cndb_nutval` VALUES (7066,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7066,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7066,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7066,601,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7066,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7066,606,2.871,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7067,203,11.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7067,204,13.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7067,205,7.41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7067,207,1.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7067,208,200,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7067,255,66.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7067,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7067,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7067,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7067,303,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7067,306,183,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7067,307,653,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7067,320,42,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (7067,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7067,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7067,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7067,601,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7067,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7067,606,3.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7068,203,12.6,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7068,204,22.2,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7068,205,1.9,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7068,207,3.3,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7068,208,261,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7068,255,60,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7068,269,1.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7068,291,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7068,301,6,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7068,303,2.2,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7068,306,188,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7068,307,1140,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7068,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (7068,328,1.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7068,401,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7068,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7068,601,71,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7068,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (7068,606,9.865,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7069,203,21.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7069,204,25.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7069,205,2.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7069,207,4.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7069,208,336,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7069,255,45.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7069,269,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7069,291,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7069,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7069,303,1.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7069,306,316,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7069,307,1740,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (7069,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (7069,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7069,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7069,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7069,601,89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7069,605,0.586,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7069,606,9.316,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7070,203,19.2,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7070,204,9.21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7070,205,1.55,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (7070,207,1.68,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7070,208,172,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (7070,255,68.8,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7070,269,1.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7070,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7070,301,40,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7070,303,1.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7070,306,216,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7070,307,1107,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (7070,320,2,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (7070,328,0.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7070,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7070,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7070,601,76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7070,605,0,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7070,606,2.783,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7071,203,22.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7071,204,33.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7071,205,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7071,207,5.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7071,208,407,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7071,255,36.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7071,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7071,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7071,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7071,303,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7071,306,378,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7071,307,2260,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7071,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (7071,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7071,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7071,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7071,601,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7071,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7071,606,11.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7072,203,21.07,'100g',1,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7072,204,31.65,'100g',1,1,'1996-09-30','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7072,205,0.72,'100g',3,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7072,207,5.37,'100g',1,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7072,208,378,'100g',3,1,'1996-09-30','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7072,255,41.19,'100g',1,1,'1996-09-30','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7072,269,0.26,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7072,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7072,301,24,'100g',1,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7072,303,1.36,'100g',1,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7072,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7072,307,1756,'100g',1,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7072,320,11,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (7072,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7072,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7072,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7072,601,108,'100g',1,1,'1996-09-30','2012-04-01');
INSERT INTO `cndb_nutval` VALUES (7072,605,0.48,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7072,606,11.418,'100g',3,1,'1996-09-30','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7073,203,7.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7073,204,17.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7073,205,11.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7073,207,2.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7073,208,235,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7073,255,60.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7073,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7073,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7073,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7073,303,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7073,306,110,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7073,307,1013,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7073,320,26,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (7073,328,0.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7073,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7073,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7073,601,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7073,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7073,606,5.977,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7074,203,11.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7074,204,28.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7074,205,0.94,'100g',3,1,'1994-01-31','2012-09-01');
INSERT INTO `cndb_nutval` VALUES (7074,207,3.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7074,208,309,'100g',3,1,'1994-01-31','2012-09-01');
INSERT INTO `cndb_nutval` VALUES (7074,255,56.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7074,269,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7074,291,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7074,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7074,303,0.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7074,306,483,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7074,307,827,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7074,320,0,'100g',2,1,'2024-12-12','2012-01-09');
INSERT INTO `cndb_nutval` VALUES (7074,328,1.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7074,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7074,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7074,601,61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7074,605,0.231,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7074,606,9.313,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7075,203,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7075,204,28.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7075,205,2.42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7075,207,2.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7075,208,320,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7075,255,53.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7075,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7075,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7075,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7075,303,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7075,306,179,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7075,307,911,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7075,320,13,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (7075,328,1.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7075,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7075,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7075,601,58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7075,605,0,'100g',1,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7075,606,9.769,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7077,203,13.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7077,204,27.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7077,205,1.92,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7077,207,3.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7077,208,313,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7077,255,53.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7077,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (7077,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7077,301,41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7077,303,1.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7077,306,286,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7077,307,1173,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7077,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (7077,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7077,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7077,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7077,601,65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7077,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (7077,606,9.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7078,203,17.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7078,204,30.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7078,205,3.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7078,207,3.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7078,208,362,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7078,255,45.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7078,269,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7078,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7078,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7078,303,2.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7078,306,260,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7078,307,1300,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7078,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (7078,328,1.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7078,401,16.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7078,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7078,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7078,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7078,606,11.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7081,203,14.81,'100g',1,1,'1995-06-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7081,204,3.77,'100g',1,1,'1995-06-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7081,205,2.2,'100g',3,1,'1995-06-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7081,207,3.24,'100g',1,1,'1995-06-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7081,208,106,'100g',3,1,'1995-06-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7081,255,75.98,'100g',1,1,'1995-06-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7081,269,0.91,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7081,291,0,'100g',4,1,'1995-06-13','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7081,301,14,'100g',1,1,'1995-06-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7081,303,0.42,'100g',1,1,'1995-06-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7081,306,371,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7081,307,898,'100g',1,1,'1995-06-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7081,320,0,'100g',1,1,'2024-12-12','2002-01-08');
INSERT INTO `cndb_nutval` VALUES (7081,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7081,401,0,'100g',4,1,'1995-06-13','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (7081,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7081,601,49,'100g',3,1,'1995-06-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7081,605,0.029,'100g',3,1,'2006-02-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7081,606,0.906,'100g',3,1,'1995-06-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7083,203,10.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7083,204,19.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7083,205,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7083,207,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7083,208,230,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7083,255,64.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7083,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7083,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7083,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7083,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7083,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7083,307,879,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7083,320,0,'100g',1,1,'2024-12-12','2004-01-05');
INSERT INTO `cndb_nutval` VALUES (7083,328,0.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7083,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7083,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7083,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7083,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7083,606,7.125,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7088,203,18.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7088,204,10.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7088,205,2.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7088,207,3.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7088,208,182,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7088,255,64.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7088,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7088,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7088,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7088,303,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7088,306,291,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7088,307,1322,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7088,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (7088,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7088,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7088,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7088,601,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7088,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7088,606,4.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7089,203,18.4,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7089,204,26.4,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7089,205,1.86,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7089,207,2.76,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7089,208,324,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7089,255,50.58,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7089,269,1.42,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7089,291,0,'100g',4,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7089,301,13,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7089,303,1.25,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7089,306,339,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7089,307,801,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7089,320,10,'100g',1,1,'2024-12-12','2004-01-07');
INSERT INTO `cndb_nutval` VALUES (7089,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7089,401,0,'100g',4,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7089,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7089,601,81,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7089,605,NULL,'100g',NULL,1,'1994-01-31','2013-06-15');
INSERT INTO `cndb_nutval` VALUES (7089,606,9.028,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7090,203,15.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7090,204,20.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7090,205,1.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7090,207,3.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7090,208,260,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7090,255,58.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7090,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7090,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7090,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7090,303,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7090,306,245,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7090,307,1182,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7090,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (7090,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7090,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7090,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7090,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7090,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7090,606,7.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7254,203,15.94,'100g',1,1,'1998-04-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7254,204,16.93,'100g',1,1,'1998-04-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7254,205,1.89,'100g',3,1,'1998-04-03','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7254,207,3.41,'100g',1,1,'1998-04-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7254,208,226,'100g',3,1,'1998-04-03','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7254,255,61.83,'100g',1,1,'1998-04-03','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7254,269,NULL,'100g',NULL,1,'2016-03-11','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7254,291,NULL,'100g',NULL,1,'2016-03-11','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7254,301,80,'100g',1,1,'1998-04-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7254,303,1.4,'100g',1,1,'1998-04-03','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7254,306,349,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7254,307,1069,'100g',1,1,'1998-04-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7254,320,10,'100g',1,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (7254,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7254,401,NULL,'100g',NULL,1,'2016-03-11','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7254,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7254,601,86,'100g',1,1,'1998-04-03','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7254,605,NULL,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (7254,606,4.52,'100g',3,1,'1998-04-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7900,203,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7900,204,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7900,205,11.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7900,207,1.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7900,208,101,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7900,255,76.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7900,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7900,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7900,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7900,303,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7900,306,243,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7900,307,796,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7900,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (7900,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7900,401,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7900,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7900,601,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7900,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7900,606,0.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7905,203,12.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7905,204,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7905,205,11.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7905,207,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7905,208,109,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7905,255,71.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7905,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7905,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7905,301,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7905,303,1.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7905,306,220,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7905,307,880,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7905,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (7905,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7905,401,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7905,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7905,601,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7905,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7905,606,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7906,203,12.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7906,204,25.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7906,205,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7906,207,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7906,208,293,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7906,255,55.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7906,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7906,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7906,301,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7906,303,0.64,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7906,306,564,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7906,307,1036,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7906,320,0,'100g',1,1,'2024-12-12','2004-01-05');
INSERT INTO `cndb_nutval` VALUES (7906,328,0.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7906,401,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7906,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7906,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7906,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7906,606,8.873,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7908,203,13.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7908,204,26.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7908,205,4.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7908,207,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7908,208,315,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7908,255,51.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7908,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7908,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7908,301,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7908,303,0.64,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7908,306,409,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7908,307,1411,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7908,320,0,'100g',1,1,'2024-12-12','2004-01-05');
INSERT INTO `cndb_nutval` VALUES (7908,328,0.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7908,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7908,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7908,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7908,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7908,606,9.987,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7909,203,15.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7909,204,13.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7909,205,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7909,207,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7909,208,196,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7909,255,65.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7909,269,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7909,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7909,301,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7909,303,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7909,306,461,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7909,307,1032,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7909,320,0,'100g',1,1,'2024-12-12','2004-01-05');
INSERT INTO `cndb_nutval` VALUES (7909,328,0.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7909,401,38.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7909,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7909,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7909,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7909,606,4.514,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7910,203,13.99,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7910,204,31.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7910,205,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7910,207,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7910,208,341,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7910,255,53.51,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7910,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7910,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7910,301,11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7910,303,0.74,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7910,306,231,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7910,307,60,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7910,320,0,'100g',2,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7910,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7910,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7910,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7910,601,79,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7910,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7910,606,14.94,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7911,203,12.38,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7911,204,25.45,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7911,205,5.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7911,207,2.75,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7911,208,305,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7911,255,53.53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7911,269,1.65,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7911,291,2.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7911,301,22,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7911,303,8.85,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7911,306,170,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7911,307,700,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7911,320,4091,'100g',1,1,'2024-12-12','2004-01-07');
INSERT INTO `cndb_nutval` VALUES (7911,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7911,401,3.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7911,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7911,601,118,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7911,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7911,606,9.925,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7912,203,15.27,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7912,204,16.28,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7912,205,3.73,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7912,207,3.02,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7912,208,223,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7912,255,61.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7912,269,0.71,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7912,291,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7912,301,23,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7912,303,2.06,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7912,306,259,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7912,307,724,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7912,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (7912,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7912,401,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7912,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7912,601,70,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7912,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7912,606,6.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7913,203,15.01,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7913,204,30.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7913,205,15.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7913,207,5.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7913,208,396,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7913,255,33.74,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7913,269,6.21,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7913,291,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7913,301,94,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7913,303,1.55,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7913,306,1372,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7913,307,623,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7913,320,4,'100g',2,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (7913,328,0.8,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7913,401,0.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7913,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7913,601,90,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7913,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7913,606,10.58,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7914,203,16.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7914,204,8.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7914,205,2.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7914,207,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7914,208,149,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7914,255,71.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7914,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7914,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7914,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7914,303,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7914,306,194,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7914,307,570,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7914,320,0,'100g',2,1,'2024-12-12','2005-01-07');
INSERT INTO `cndb_nutval` VALUES (7914,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7914,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7914,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7914,601,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7914,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7914,606,3.257,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7915,203,17.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7915,204,19.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7915,205,3.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7915,207,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7915,208,259,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7915,255,55.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7915,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7915,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7915,301,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7915,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7915,306,237,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7915,307,1540,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7915,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7915,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7915,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7915,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7915,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7915,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7915,606,8.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7916,203,12.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7916,204,26.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7916,205,1.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7916,207,2.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7916,208,301,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7916,255,56.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7916,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7916,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7916,301,7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7916,303,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7916,306,189,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7916,307,848,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7916,320,0,'100g',2,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7916,328,1.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7916,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7916,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7916,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7916,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7916,606,9.207,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7917,203,12.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7917,204,25.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7917,205,2.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7917,207,3.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7917,208,296,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7917,255,56.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7917,269,0.11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7917,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7917,301,57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7917,303,0.73,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7917,306,206,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7917,307,848,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7917,320,0,'100g',2,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7917,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7917,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7917,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7917,601,63,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7917,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7917,606,9.482,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7918,203,19.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7918,204,37.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7918,205,1.82,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7918,207,4.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7918,208,426,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7918,255,36.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7918,269,0.12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7918,291,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7918,301,81,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7918,303,2.26,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7918,306,206,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7918,307,1483,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7918,320,225,'100g',2,1,'2024-12-12','2002-01-08');
INSERT INTO `cndb_nutval` VALUES (7918,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7918,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7918,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7918,601,89,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7918,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7918,606,10.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7919,203,15.91,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7919,204,10.39,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7919,205,3.18,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7919,207,2.65,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7919,208,174,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7919,255,67.86,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7919,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7919,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7919,301,55,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7919,303,1.34,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7919,306,258,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7919,307,714,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7919,320,0,'100g',1,1,'2024-12-12','2016-01-10');
INSERT INTO `cndb_nutval` VALUES (7919,328,0.4,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7919,401,0,'100g',4,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7919,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7919,601,76,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7919,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7919,606,2.821,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7921,203,29.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7921,204,44.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7921,205,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7921,207,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7921,208,517,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7921,255,21.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7921,269,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7921,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7921,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7921,303,1.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7921,306,385,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7921,307,1420,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7921,320,0,'100g',3,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7921,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7921,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7921,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7921,601,102,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7921,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7921,606,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7922,203,12.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7922,204,26.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7922,205,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7922,207,2.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7922,208,297,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7922,255,56.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7922,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7922,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7922,301,7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7922,303,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7922,306,283,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7922,307,848,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7922,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7922,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7922,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7922,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7922,601,78,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7922,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7922,606,6.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7925,203,19.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7925,204,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7925,205,1.54,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7925,207,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7925,208,95,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7925,255,74.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7925,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7925,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7925,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7925,303,2.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7925,306,228,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7925,307,1010,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7925,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7925,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7925,401,34.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7925,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7925,601,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7925,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7925,606,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7926,203,21.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7926,204,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7926,205,1.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7926,207,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7926,208,425,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7926,255,34.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7926,269,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7926,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7926,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7926,303,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7926,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7926,307,1890,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7926,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7926,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7926,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7926,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7926,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7926,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7926,606,13.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7927,203,15.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7927,204,8.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7927,205,4.65,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7927,207,3.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7927,208,158,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7927,255,68.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7927,269,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7927,291,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7927,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7927,303,9.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7927,306,197,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7927,307,928,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7927,320,43,'100g',1,1,'2024-12-12','2002-01-07');
INSERT INTO `cndb_nutval` VALUES (7927,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7927,401,30.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7927,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7927,601,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7927,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7927,606,3.401,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7928,203,13.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7928,204,14.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7928,205,8.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7928,207,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7928,208,216,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7928,255,60.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7928,269,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7928,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7928,301,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7928,303,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7928,306,246,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7928,307,1034,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7928,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7928,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7928,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7928,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7928,601,120,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7928,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7928,606,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7929,203,15.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7929,204,8.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7929,205,4.65,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7929,207,3.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7929,208,158,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7929,255,68.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7929,269,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7929,291,0.3,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7929,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7929,303,9.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7929,306,197,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7929,307,916,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7929,320,43,'100g',1,1,'2024-12-12','2002-01-08');
INSERT INTO `cndb_nutval` VALUES (7929,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7929,401,30.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7929,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7929,601,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7929,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7929,606,3.401,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7930,203,14.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7930,204,22.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7930,205,1.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7930,207,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7930,208,268,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7930,255,58.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7930,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7930,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7930,301,19,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7930,303,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7930,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7930,307,936,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7930,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7930,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7930,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7930,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7930,601,64,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7930,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7930,606,7.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7931,203,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7931,204,22.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7931,205,4.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7931,207,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7931,208,276,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7931,255,56.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7931,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7931,291,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7931,301,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7931,303,1.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7931,306,244,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7931,307,732,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7931,320,3,'100g',2,1,'2024-12-12','2002-01-07');
INSERT INTO `cndb_nutval` VALUES (7931,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7931,401,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7931,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7931,601,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7931,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7931,606,8.438,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7932,203,16.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7932,204,0.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7932,205,2.25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7932,207,3.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7932,208,80,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7932,255,76.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7932,269,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7932,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7932,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7932,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7932,306,316,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7932,307,1040,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7932,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7932,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7932,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7932,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7932,601,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7932,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7932,606,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7933,203,16.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7933,204,0.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7933,205,2.17,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7933,207,3.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7933,208,79,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7933,255,76.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7933,269,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7933,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7933,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7933,303,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7933,306,67,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7933,307,1087,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7933,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7933,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7933,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7933,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7933,601,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7933,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7933,606,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7934,203,13.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7934,204,17.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7934,205,3.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7934,207,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7934,208,226,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7934,255,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7934,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7934,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7934,301,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7934,303,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7934,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7934,307,1200,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7934,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7934,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7934,401,14.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7934,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7934,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7934,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7934,606,6.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7935,203,14.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7935,204,7.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7935,205,1.79,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7935,207,2.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7935,208,134,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7935,255,72.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7935,269,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7935,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7935,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7935,303,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7935,306,324,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7935,307,883,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7935,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7935,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7935,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7935,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7935,601,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7935,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7935,606,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7936,203,13.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7936,204,16.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7936,205,3.45,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7936,207,2.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7936,208,211,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7936,255,64.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7936,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7936,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7936,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7936,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7936,306,138,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7936,307,716,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7936,320,1,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (7936,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7936,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7936,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7936,601,79,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7936,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7936,606,5.46,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7937,203,11.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7937,204,29.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7937,205,6.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7937,207,7.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7937,208,336,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7937,255,45.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7937,269,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7937,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7937,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7937,303,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7937,306,222,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7937,307,1055,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7937,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7937,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7937,401,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7937,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7937,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7937,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7937,606,11.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7938,203,17.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7938,204,2.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7938,205,7.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7938,207,2.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7938,208,122,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7938,255,69.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7938,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7938,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7938,301,6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7938,303,0.39,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7938,306,165,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7938,307,900,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7938,320,0,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (7938,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7938,401,0.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7938,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7938,601,22,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7938,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7938,606,0.87,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7939,203,12.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7939,204,23.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7939,205,0.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7939,207,3.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7939,208,269,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7939,255,59.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7939,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7939,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7939,301,267,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7939,303,3.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7939,306,264,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7939,307,816,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7939,320,79,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (7939,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7939,401,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7939,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7939,601,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7939,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7939,606,8.719,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7940,203,11.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7940,204,14.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7940,205,11.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7940,207,4.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7940,208,228,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7940,255,57.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7940,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7940,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7940,301,122,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7940,303,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7940,306,313,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7940,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7940,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7940,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7940,401,16.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7940,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7940,601,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7940,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7940,606,5.614,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7941,203,21.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7941,204,26.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7941,205,6.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7941,207,4.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7941,208,350,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7941,255,40.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7941,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7941,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7941,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7941,303,1.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7941,306,378,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7941,307,936,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7941,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7941,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7941,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7941,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7941,601,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7941,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7941,606,9.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7942,203,11.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7942,204,28.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7942,205,6.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7942,207,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7942,208,327,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7942,255,51.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7942,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7942,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7942,301,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7942,303,3.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7942,306,138,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7942,307,807,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7942,320,4505,'100g',1,1,'2024-12-12','2002-01-07');
INSERT INTO `cndb_nutval` VALUES (7942,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7942,401,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7942,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7942,601,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7942,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7942,606,10.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7943,203,20.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7943,204,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7943,205,1.31,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7943,207,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7943,208,95,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7943,255,73.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7943,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7943,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7943,301,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7943,303,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7943,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7943,307,1160,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7943,320,0,'100g',3,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (7943,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7943,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7943,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7943,601,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7943,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7943,606,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7944,203,13.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7944,204,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7944,205,7.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7944,207,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7944,208,112,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7944,255,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7944,269,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7944,291,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7944,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7944,303,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7944,306,349,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7944,307,1200,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7944,320,2,'100g',2,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (7944,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7944,401,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7944,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7944,601,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7944,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7944,606,0.118,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7945,203,11.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7945,204,29.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7945,205,2.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7945,207,2.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7945,208,322,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7945,255,53.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7945,269,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7945,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7945,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7945,303,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7945,306,252,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7945,307,852,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7945,320,0,'100g',2,1,'2024-12-12','2002-01-08');
INSERT INTO `cndb_nutval` VALUES (7945,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7945,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7945,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7945,601,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7945,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7945,606,11.593,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7949,203,9.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7949,204,24.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7949,205,4.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7949,207,3.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7949,208,278,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7949,255,57.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7949,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7949,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7949,301,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7949,303,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7949,306,141,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7949,307,1013,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7949,320,0,'100g',2,1,'2024-12-12','2002-01-07');
INSERT INTO `cndb_nutval` VALUES (7949,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7949,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7949,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7949,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7949,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7949,606,7.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7950,203,10.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7950,204,25.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7950,205,4.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7950,207,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7950,208,290,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7950,255,56.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7950,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7950,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7950,301,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7950,303,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7950,306,152,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7950,307,1090,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7950,320,0,'100g',2,1,'2024-12-12','2002-01-07');
INSERT INTO `cndb_nutval` VALUES (7950,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7950,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7950,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7950,601,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7950,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7950,606,7.666,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7951,203,8.06,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7951,204,13.87,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7951,205,14.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7951,207,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7951,208,213,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7951,255,62.47,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7951,269,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7951,291,0.3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7951,301,7,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7951,303,1.89,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7951,306,158,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7951,307,482,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7951,320,626,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (7951,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7951,401,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7951,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7951,601,49,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7951,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7951,606,4.732,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7952,203,9.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7952,204,26.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7952,205,5.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7952,207,3.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7952,208,298,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7952,255,55.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7952,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7952,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7952,301,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7952,303,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7952,306,152,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7952,307,922,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7952,320,13,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (7952,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7952,401,19.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7952,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7952,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7952,605,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7952,606,7.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7953,203,15.12,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7953,204,41.66,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7953,205,0.62,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7953,207,3.09,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7953,208,438,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (7953,255,39.64,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7953,269,0.62,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7953,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7953,301,17,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7953,303,0.95,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7953,306,225,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7953,307,990,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7953,320,22,'100g',1,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (7953,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7953,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7953,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7953,601,79,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7953,605,0.209,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7953,606,13.557,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7954,203,12.9,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7954,204,28.22,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7954,205,4.61,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7954,207,3.07,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7954,208,327,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7954,255,51.21,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7954,269,1,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7954,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7954,301,29,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7954,303,1.45,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7954,306,285,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7954,307,904,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7954,320,23,'100g',1,1,'2024-12-12','2016-01-11');
INSERT INTO `cndb_nutval` VALUES (7954,328,0.1,'100g',3,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7954,401,0,'100g',4,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7954,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7954,601,60,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7954,605,1.179,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7954,606,11.298,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (7955,203,18.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7955,204,8.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7955,205,0.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7955,207,2.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7955,208,155,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7955,255,70.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7955,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7955,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7955,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7955,303,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7955,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7955,307,593,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7955,320,13,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (7955,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7955,401,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7955,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7955,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7955,605,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7955,606,1.963,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7956,203,18.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7956,204,27.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7956,205,0.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7956,207,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7956,208,332,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7956,255,51.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7956,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7956,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7956,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7956,303,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7956,306,258,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7956,307,813,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7956,320,13,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (7956,328,0.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7956,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7956,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7956,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7956,605,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7956,606,10.905,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7957,203,12.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7957,204,30.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7957,205,3.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7957,207,3.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7957,208,342,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7957,255,50.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7957,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7957,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7957,301,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7957,303,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7957,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7957,307,876,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7957,320,21,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (7957,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7957,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7957,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7957,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7957,605,0.328,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7957,606,9.881,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7958,203,23.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7958,204,10.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7958,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7958,207,2,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7958,208,196,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7958,255,65.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7958,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7958,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7958,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7958,303,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7958,306,298,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7958,307,665,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7958,320,13,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (7958,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7958,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7958,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7958,601,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7958,605,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7958,606,2.266,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7959,203,11.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7959,204,22.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7959,205,5.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7959,207,3.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7959,208,272,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7959,255,56.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7959,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7959,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7959,301,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7959,303,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7959,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7959,307,1120,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7959,320,13,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (7959,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7959,401,15.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7959,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7959,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7959,605,0.237,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7959,606,6.997,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7960,203,10.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7960,204,30.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7960,205,4.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7960,207,4.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7960,208,336,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7960,255,50.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7960,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7960,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7960,301,196,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7960,303,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7960,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7960,307,1240,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7960,320,13,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (7960,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7960,401,13.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7960,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7960,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7960,605,0.283,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7960,606,9.863,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7961,203,17.4,'100g',1,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7961,204,1.86,'100g',1,1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (7961,205,2.92,'100g',3,1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (7961,207,3.34,'100g',1,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7961,208,98,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7961,255,74.47,'100g',1,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7961,269,0.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7961,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7961,301,11,'100g',1,1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (7961,303,0.39,'100g',1,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7961,306,360,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7961,307,1032,'100g',1,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7961,320,2,'100g',1,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (7961,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7961,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7961,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7961,601,51,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (7961,605,0.007,'100g',3,1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (7961,606,0.564,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7962,203,9.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7962,204,24.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7962,205,5.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7962,207,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7962,208,277,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7962,255,57.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7962,269,2.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7962,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7962,301,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7962,303,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7962,306,359,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7962,307,976,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7962,320,31,'100g',1,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (7962,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7962,401,22.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7962,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7962,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7962,605,0.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7962,606,7.583,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7963,203,10.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7963,204,26.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7963,205,4.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7963,207,3.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7963,208,298,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7963,255,55.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7963,269,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7963,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7963,301,107,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7963,303,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7963,306,323,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7963,307,914,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7963,320,31,'100g',1,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (7963,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7963,401,19.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7963,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7963,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7963,605,0.237,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7963,606,8.216,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7964,203,10.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7964,204,26.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7964,205,5.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7964,207,3.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7964,208,302,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7964,255,53.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7964,269,2.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7964,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7964,301,118,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7964,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7964,306,387,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7964,307,1079,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7964,320,32,'100g',1,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (7964,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7964,401,19.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7964,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7964,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7964,605,0.237,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7964,606,8.218,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7965,203,16.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7965,204,16.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7965,205,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7965,207,2.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7965,208,217,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7965,255,64.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7965,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7965,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7965,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7965,303,1.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7965,306,275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7965,307,581,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7965,320,27,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (7965,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7965,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7965,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7965,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7965,605,0.064,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7965,606,4.368,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7966,203,20.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7966,204,20.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7966,205,0.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7966,207,2.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7966,208,267,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7966,255,55.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7966,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7966,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7966,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7966,303,1.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7966,306,328,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7966,307,698,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7966,320,28,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (7966,328,1.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7966,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7966,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7966,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7966,605,0.091,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7966,606,6.034,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7967,203,13.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7967,204,37.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7967,205,0.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7967,207,2.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7967,208,392,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7967,255,45.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7967,269,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7967,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7967,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7967,303,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7967,306,211,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7967,307,810,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7967,320,21,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (7967,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7967,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7967,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7967,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7967,605,0.184,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7967,606,12.129,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7968,203,12.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7968,204,29.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7968,205,5.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7968,207,3.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7968,208,337,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7968,255,49.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7968,269,2.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7968,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7968,301,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7968,303,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7968,306,306,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7968,307,1062,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7968,320,9,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (7968,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7968,401,14.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7968,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7968,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7968,605,0.275,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7968,606,9.894,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7969,203,12.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7969,204,29.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7969,205,4.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7969,207,3.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7969,208,333,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7969,255,49.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7969,269,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7969,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7969,301,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7969,303,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7969,306,304,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7969,307,1046,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7969,320,10,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (7969,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7969,401,16.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7969,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7969,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7969,605,0.297,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7969,606,9.487,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7970,203,10.84,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7970,204,29.63,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7970,205,3.72,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7970,207,3,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7970,208,325,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7970,255,52.82,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7970,269,2.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7970,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7970,301,24,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7970,303,0.75,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7970,306,217,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7970,307,928,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7970,320,8,'100g',1,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (7970,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7970,401,19.1,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7970,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7970,601,61,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7970,605,0.228,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7970,606,9.684,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7971,203,10.34,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7971,204,23.77,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7971,205,6.31,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7971,207,3.65,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7971,208,281,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7971,255,55.93,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7971,269,1.97,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7971,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7971,301,125,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7971,303,1.24,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7971,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7971,307,1379,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7971,320,0,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (7971,328,0.8,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7971,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (7971,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7971,601,92,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7971,605,0.183,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (7971,606,7.389,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (7972,203,14.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7972,204,22.21,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7972,205,8.06,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7972,207,2.64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7972,208,286,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7972,255,53.67,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7972,269,3.47,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7972,291,2.3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7972,301,80,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7972,303,1.77,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7972,306,296,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7972,307,666,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7972,320,22,'100g',1,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (7972,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7972,401,0,'100g',NULL,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (7972,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (7972,601,66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7972,605,0.577,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7972,606,7.627,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7973,203,29.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7973,204,25.87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7973,205,4.24,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7973,207,6.8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7973,208,368,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7973,255,34.46,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7973,269,4.24,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7973,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7973,301,163,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7973,303,2.63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7973,306,666,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7973,307,2021,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7973,320,19,'100g',1,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (7973,328,1.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7973,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7973,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7973,601,153,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7973,605,0.287,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7973,606,6.933,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (7974,203,13.33,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7974,204,20,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7974,205,4.8,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7974,207,2.93,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7974,208,253,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7974,255,58.93,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7974,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7974,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7974,301,10,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7974,303,0.72,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7974,306,156,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7974,307,900,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7974,320,8,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (7974,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7974,401,24,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7974,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7974,601,100,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7974,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7974,606,6.667,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7976,203,21.43,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7976,204,4.46,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7976,205,14.25,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7976,207,3.85,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7976,208,183,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7976,255,56.01,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7976,269,0.81,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7976,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7976,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7976,303,1.29,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7976,306,1062,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7976,307,446,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7976,320,0,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (7976,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7976,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7976,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7976,601,36,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7976,605,0.018,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7976,606,0.893,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7977,203,18.52,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7977,204,2.71,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7977,205,10.7,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7977,207,3.48,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7977,208,141,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7977,255,64.59,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7977,269,10.68,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7977,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7977,301,5,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7977,303,0.76,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7977,306,330,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7977,307,1062,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7977,320,12,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (7977,328,0.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7977,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7977,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7977,601,50,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7977,605,0.019,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7977,606,1.786,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7978,203,9.41,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7978,204,22.35,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7978,205,8.13,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7978,207,1.24,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7978,208,271,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7978,255,58.87,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7978,269,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7978,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7978,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7978,303,0.85,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7978,306,160,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7978,307,294,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7978,320,9,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (7978,328,0.8,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7978,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7978,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7978,601,59,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7978,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7978,606,8.235,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7979,203,10.71,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7979,204,26.79,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7979,205,0.11,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7979,207,2.47,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7979,208,284,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7979,255,60.08,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7979,269,0.02,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7979,291,0.1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7979,301,24,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7979,303,1.6,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7979,306,240,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7979,307,679,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7979,320,6,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (7979,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (7979,401,0.8,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7979,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (7979,601,70,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7979,605,0.718,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (7979,606,10.714,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (8037,203,13.67,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (8037,204,24.31,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (8037,205,53.88,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (8037,207,2.31,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (8037,208,489,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (8037,255,5.84,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (8037,269,19.8,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (8037,291,8.9,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (8037,301,76,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (8037,303,3.95,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (8037,306,539,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8037,307,26,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (8037,320,1,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (8037,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8037,401,1.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8037,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (8037,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8037,605,0.023,'100g',3,1,'2006-02-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (8037,606,3.957,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (8084,203,29.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8084,204,10.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8084,205,49.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8084,207,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8084,208,382,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8084,255,5.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8084,269,7.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8084,291,15.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8084,301,45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8084,303,9.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8084,306,947,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8084,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8084,320,5,'100g',1,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (8084,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8084,401,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8084,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8084,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8084,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (8084,606,1.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8090,203,7.65,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8090,204,1.75,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8090,205,79.09,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8090,207,0.6,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8090,208,370,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8090,255,10.92,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8090,269,0.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8090,291,4.6,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8090,301,4,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8090,303,3.05,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8090,306,141,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8090,307,1,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8090,320,0,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (8090,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8090,401,0,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8090,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8090,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (8090,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8090,606,0.34,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8091,203,1.71,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8091,204,0.46,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8091,205,14.76,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8091,207,0.15,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8091,208,71,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8091,255,82.93,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8091,269,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8091,291,0.8,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8091,301,1,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8091,303,0.57,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8091,306,27,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8091,307,2,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (8091,320,0,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (8091,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8091,401,0,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8091,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8091,601,0,'100g',4,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8091,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8091,606,0.066,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8120,203,13.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8120,204,6.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8120,205,67.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8120,207,1.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8120,208,379,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8120,255,10.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8120,269,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8120,291,10.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8120,301,52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8120,303,4.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8120,306,362,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8120,307,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8120,320,0,'100g',1,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (8120,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8120,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8120,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8120,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8120,605,NULL,'100g',NULL,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (8120,606,1.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8121,203,2.54,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (8121,204,1.52,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (8121,205,12,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (8121,207,0.34,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (8121,208,71,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (8121,255,83.61,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (8121,269,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8121,291,1.7,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (8121,301,9,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (8121,303,0.9,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (8121,306,70,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8121,307,4,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (8121,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (8121,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8121,401,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (8121,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8121,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (8121,605,0.001,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (8121,606,0.31,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (8122,203,11.92,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8122,204,6.9,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8122,205,69.52,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8122,207,2.75,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8122,208,362,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8122,255,8.92,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8122,269,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8122,291,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8122,301,351,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8122,303,24.72,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8122,306,366,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8122,307,220,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8122,320,772,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (8122,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8122,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8122,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8122,601,0,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8122,605,0.016,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (8122,606,1.346,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (8123,203,2.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8123,204,1.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8123,205,11.67,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8123,207,0.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8123,208,68,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8123,255,84.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8123,269,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8123,291,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8123,301,80,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8123,303,5.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8123,306,61,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8123,307,49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8123,320,130,'100g',2,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (8123,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8123,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8123,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8123,601,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8123,605,0.003,'100g',3,1,'2006-02-23','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8123,606,0.226,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (8128,203,9.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8128,204,4.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8128,205,76.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8128,207,2.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8128,208,369,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8128,255,6.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8128,269,25.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8128,291,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8128,301,234,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8128,303,8.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8128,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8128,307,434,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8128,320,440,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (8128,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8128,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8128,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (8128,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8128,605,0.003,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8128,606,0.768,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (8129,203,2.37,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8129,204,1.21,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8129,205,18.95,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8129,207,0.73,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8129,208,96,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8129,255,76.74,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8129,269,6.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8129,291,2,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8129,301,61,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8129,303,2.11,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8129,306,71,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8129,307,111,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8129,320,110,'100g',2,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (8129,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8129,401,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (8129,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (8129,601,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (8129,605,0.001,'100g',3,1,'2006-02-23','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8129,606,0.191,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (8133,203,1.98,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8133,204,0.95,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8133,205,17.91,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8133,207,0.72,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8133,208,88,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8133,255,78.44,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8133,269,8.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8133,291,1.3,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8133,301,56,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8133,303,2.21,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8133,306,85,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8133,307,111,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8133,320,138,'100g',2,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (8133,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8133,401,0.1,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8133,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (8133,601,0,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (8133,605,0.008,'100g',3,1,'2006-02-23','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8133,606,0.15,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (8144,203,11.2,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8144,204,2,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8144,205,75.2,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8144,207,1.6,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8144,208,342,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8144,255,9.9,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8144,269,0.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8144,291,9.5,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8144,301,40,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8144,303,3.39,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8144,306,389,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8144,307,2,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8144,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (8144,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8144,401,0,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8144,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8144,601,0,'100g',4,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8144,605,NULL,'100g',NULL,1,'1995-06-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (8144,606,0.3,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8145,203,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8145,204,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8145,205,13.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8145,207,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8145,208,62,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8145,255,83.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8145,269,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8145,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8145,301,7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8145,303,0.62,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8145,306,71,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8145,307,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8145,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (8145,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8145,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8145,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8145,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8145,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (8145,606,0.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8156,203,6.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8156,204,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8156,205,89.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8156,207,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8156,208,402,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8156,255,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8156,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (8156,291,1.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8156,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8156,303,31.7,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8156,306,113,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8156,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8156,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (8156,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8156,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8156,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (8156,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8156,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (8156,606,0.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8157,203,14.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8157,204,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8157,205,79.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8157,207,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8157,208,364,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8157,255,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8157,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (8157,291,4.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8157,301,28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8157,303,31.7,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8157,306,348,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8157,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8157,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (8157,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8157,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8157,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (8157,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8157,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (8157,606,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8160,203,8.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8160,204,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8160,205,79.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8160,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8160,208,371,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8160,255,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8160,269,0.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8160,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8160,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8160,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8160,306,137,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8160,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8160,320,11,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (8160,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8160,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8160,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8160,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8160,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8160,606,0.155,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (8161,203,1.71,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8161,204,0.46,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8161,205,14.76,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8161,207,0.15,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8161,208,71,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8161,255,82.93,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8161,269,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8161,291,0.8,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8161,301,1,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8161,303,0.57,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8161,306,27,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8161,307,223,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8161,320,0,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (8161,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8161,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8161,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8161,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8161,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (8161,606,0.066,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8164,203,1.23,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8164,204,0.39,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8164,205,13.86,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8164,207,0.15,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8164,208,65,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8164,255,84.36,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8164,269,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8164,291,0.7,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8164,301,1,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8164,303,0.57,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8164,306,22,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8164,307,2,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8164,320,0,'100g',1,1,'2024-12-12','2008-01-12');
INSERT INTO `cndb_nutval` VALUES (8164,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8164,401,0,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8164,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8164,601,0,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8164,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (8164,606,0.06,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8165,203,1.23,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8165,204,0.39,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8165,205,13.86,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8165,207,0.15,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8165,208,65,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8165,255,84.36,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8165,269,0.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8165,291,0.7,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8165,301,1,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8165,303,0.57,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8165,306,22,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8165,307,223,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8165,320,0,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (8165,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8165,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8165,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8165,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8165,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (8165,606,0.06,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8172,203,10.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8172,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8172,205,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8172,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8172,208,369,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8172,255,10.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8172,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8172,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8172,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8172,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8172,306,94,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8172,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8172,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (8172,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8172,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8172,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8172,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8172,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8172,606,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8173,203,1.82,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8173,204,0.34,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8173,205,10.92,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8173,207,0.38,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8173,208,53,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8173,255,86.55,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8173,269,0.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8173,291,0.8,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8173,301,97,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8173,303,5.33,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8173,306,23,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8173,307,126,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8173,320,0,'100g',2,1,'2024-12-12','2008-01-11');
INSERT INTO `cndb_nutval` VALUES (8173,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8173,401,0,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8173,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8173,601,0,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8173,605,0.03,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (8173,606,0.066,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (8180,203,2.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8180,204,1.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8180,205,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8180,207,0.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8180,208,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8180,255,83.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8180,269,0.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8180,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8180,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8180,303,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8180,306,70,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8180,307,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8180,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (8180,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8180,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8180,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8180,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8180,605,0.001,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8180,606,0.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8183,203,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8183,204,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8183,205,13.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8183,207,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8183,208,62,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8183,255,83.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8183,269,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8183,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8183,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8183,303,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8183,306,71,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8183,307,233,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8183,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (8183,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8183,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8183,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (8183,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8183,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (8183,606,0.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (8204,203,3.34,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8204,204,3.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8204,205,87.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8204,207,2.25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8204,208,405,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8204,255,3.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8204,269,43.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8204,291,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8204,301,70,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8204,303,15.87,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8204,306,176,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8204,307,534,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8204,320,1324,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (8204,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8204,401,52.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8204,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (8204,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8204,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8204,606,0.961,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (8510,203,6.47,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8510,204,10.98,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8510,205,72.05,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8510,207,1.76,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8510,208,413,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8510,255,8.69,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8510,269,45.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8510,291,0.4,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8510,301,410,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8510,303,5.99,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8510,306,254,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8510,307,319,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8510,320,188,'100g',2,1,'2024-12-12','2005-01-08');
INSERT INTO `cndb_nutval` VALUES (8510,328,1.7,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8510,401,15.4,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8510,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (8510,601,6,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8510,605,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8510,606,9.114,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8546,203,9.09,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8546,204,9.09,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8546,205,72.73,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8546,207,1.6,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8546,208,409,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8546,255,7.5,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8546,269,31.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (8546,291,1.8,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8546,301,31,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8546,303,2.56,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8546,306,143,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8546,307,428,'100g',6,1,'2007-12-03','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (8546,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (8546,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8546,401,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8546,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (8546,601,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8546,605,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8546,606,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (8680,203,9.25,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (8680,204,4.73,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (8680,205,76.67,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (8680,207,2.94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (8680,208,386,'100g',3,1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (8680,255,6.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (8680,269,30.28,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (8680,291,7.2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (8680,301,258,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (8680,303,10.36,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (8680,306,361,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8680,307,505,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (8680,320,692,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (8680,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (8680,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (8680,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (8680,601,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (8680,605,0.002,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (8680,606,0.778,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9001,203,0.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9001,204,0.3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9001,205,7.69,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9001,207,0.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9001,208,32,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9001,255,91.41,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9001,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9001,291,1.1,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9001,301,12,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9001,303,0.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9001,306,146,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9001,307,7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9001,320,38,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9001,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9001,401,1677.6,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9001,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9001,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9001,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9001,606,0.068,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9002,203,0.4,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9002,204,0.3,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9002,205,4.8,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9002,207,0.2,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9002,208,23,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9002,255,94.3,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9002,269,4.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9002,291,0.3,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9002,301,10,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9002,303,0.5,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9002,306,97,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9002,307,3,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9002,320,25,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (9002,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9002,401,1600,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9002,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9002,601,0,'100g',4,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9002,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9002,606,0.068,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9003,203,0.26,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9003,204,0.17,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9003,205,13.81,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9003,207,0.19,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9003,208,52,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9003,255,85.56,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9003,269,10.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9003,291,2.4,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9003,301,6,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9003,303,0.12,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9003,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9003,307,1,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9003,320,3,'100g',1,1,'2024-12-12','2003-01-06');
INSERT INTO `cndb_nutval` VALUES (9003,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9003,401,4.6,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9003,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9003,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9003,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9003,606,0.028,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9004,203,0.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9004,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9004,205,12.76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9004,207,0.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9004,208,48,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9004,255,86.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9004,269,10.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9004,291,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9004,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9004,303,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9004,306,90,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9004,307,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9004,320,2,'100g',1,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (9004,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9004,401,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9004,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9004,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9004,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9004,606,0.021,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9005,203,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9005,204,0.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9005,205,13.64,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9005,207,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9005,208,53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9005,255,85.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9005,269,11.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9005,291,2.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9005,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9005,303,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9005,306,88,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9005,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9005,320,2,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9005,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9005,401,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9005,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9005,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9005,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9005,606,0.058,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9006,203,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9006,204,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9006,205,14.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9006,207,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9006,208,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9006,255,84.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9006,269,11.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9006,291,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9006,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9006,303,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9006,306,93,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9006,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9006,320,2,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9006,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9006,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9006,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9006,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9006,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9006,606,0.068,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9008,203,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9008,204,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9008,205,16.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9008,207,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9008,208,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9008,255,82.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9008,269,14.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9008,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9008,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9008,303,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9008,306,70,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9008,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9008,320,3,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9008,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9008,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9008,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9008,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9008,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9008,606,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9009,203,1.32,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9009,204,0.58,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9009,205,93.53,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9009,207,1.57,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9009,208,346,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9009,255,3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9009,269,81.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9009,291,12.4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9009,301,19,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9009,303,2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9009,306,640,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9009,307,124,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9009,320,4,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9009,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9009,401,2.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9009,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9009,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9009,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9009,606,0.095,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9010,203,0.28,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9010,204,0.12,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9010,205,19.91,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9010,207,0.33,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9010,208,74,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9010,255,79.36,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9010,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9010,291,2.6,'100g',3,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9010,301,4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9010,303,0.43,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9010,306,136,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9010,307,26,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9010,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9010,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9010,401,0.6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9010,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9010,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9010,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9010,606,0.02,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9011,203,0.93,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9011,204,0.32,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9011,205,65.89,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9011,207,1.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9011,208,243,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9011,255,31.76,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9011,269,57.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9011,291,8.7,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9011,301,14,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9011,303,1.4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9011,306,450,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9011,307,87,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9011,320,0,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9011,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9011,401,3.9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9011,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9011,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9011,605,NULL,'100g',NULL,1,'1995-06-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9011,606,0.052,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9012,203,0.22,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9012,204,0.07,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9012,205,15.32,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9012,207,0.26,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9012,208,57,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9012,255,84.13,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9012,269,13.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9012,291,2,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9012,301,3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9012,303,0.33,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9012,306,105,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9012,307,20,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9012,320,1,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9012,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9012,401,1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9012,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9012,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9012,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9012,606,0.012,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9013,203,0.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9013,204,0.07,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9013,205,20.73,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9013,207,0.24,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9013,208,83,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9013,255,78.76,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9013,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9013,291,1.9,'100g',3,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9013,301,3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9013,303,0.31,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9013,306,98,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9013,307,19,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9013,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9013,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9013,401,0.9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9013,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9013,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9013,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9013,606,0.011,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9014,203,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9014,204,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9014,205,12.31,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9014,207,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9014,208,48,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9014,255,86.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9014,269,10.1,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9014,291,1.3,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9014,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9014,303,0.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9014,306,77,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9014,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9014,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (9014,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9014,401,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9014,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9014,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9014,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9014,606,0.053,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9015,203,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9015,204,0.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9015,205,12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9015,207,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9015,208,47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9015,255,87.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9015,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9015,291,1.3,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9015,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9015,303,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9015,306,76,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9015,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9015,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (9015,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9015,401,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9015,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9015,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9015,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9015,606,0.053,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9016,203,0.1,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9016,204,0.13,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9016,205,11.3,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9016,207,0.23,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9016,208,46,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9016,255,88.24,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9016,269,9.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9016,291,0.2,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9016,301,8,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9016,303,0.12,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9016,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9016,307,4,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9016,320,0,'100g',2,1,'2024-12-12','2008-01-05');
INSERT INTO `cndb_nutval` VALUES (9016,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9016,401,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9016,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9016,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9016,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9016,606,0.022,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9017,203,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9017,204,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9017,205,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9017,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9017,208,166,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9017,255,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9017,269,38.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9017,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9017,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9017,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9017,306,448,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9017,307,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9017,320,0,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9017,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9017,401,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9017,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9017,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9017,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9017,606,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9018,203,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9018,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9018,205,11.54,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9018,207,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9018,208,47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9018,255,87.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9018,269,10.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9018,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9018,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9018,303,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9018,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9018,307,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9018,320,0,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9018,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9018,401,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9018,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9018,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9018,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9018,606,0.018,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9019,203,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9019,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9019,205,11.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9019,207,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9019,208,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9019,255,88.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9019,269,9.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9019,291,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9019,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9019,303,0.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9019,306,74,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9019,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9019,320,1,'100g',2,1,'2024-12-12','2016-01-03');
INSERT INTO `cndb_nutval` VALUES (9019,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9019,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9019,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9019,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9019,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9019,606,0.008,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9020,203,0.16,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9020,204,0.17,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9020,205,17.49,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9020,207,0.21,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9020,208,68,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9020,255,81.98,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9020,269,14.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9020,291,1.2,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9020,301,3,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9020,303,0.12,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9020,306,75,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9020,307,2,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9020,320,0,'100g',2,1,'2024-12-12','2016-01-03');
INSERT INTO `cndb_nutval` VALUES (9020,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9020,401,1.7,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9020,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9020,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9020,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9020,606,0.03,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9021,203,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9021,204,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9021,205,11.12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9021,207,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9021,208,48,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9021,255,86.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9021,269,9.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9021,291,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9021,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9021,303,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9021,306,259,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9021,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9021,320,96,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (9021,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9021,401,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9021,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9021,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9021,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9021,606,0.027,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9022,203,0.71,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9022,204,0.16,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9022,205,6.39,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9022,207,0.38,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9022,208,27,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9022,255,92.36,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9022,269,4.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9022,291,1.6,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9022,301,8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9022,303,0.32,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9022,306,192,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9022,307,3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9022,320,98,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9022,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9022,401,3.4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9022,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9022,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9022,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9022,606,0.011,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9023,203,0.69,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9023,204,0.03,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9023,205,5.48,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9023,207,0.38,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9023,208,22,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9023,255,93.43,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9023,269,NULL,'100g',NULL,1,'1995-06-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9023,291,1.1,'100g',3,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9023,301,8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9023,303,0.54,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9023,306,154,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9023,307,11,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9023,320,91,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9023,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9023,401,1.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9023,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9023,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9023,605,0,'100g',NULL,1,'1995-06-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9023,606,0.002,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9024,203,0.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9024,204,0.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9024,205,12.34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9024,207,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9024,208,48,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9024,255,86.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9024,269,10.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9024,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9024,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9024,303,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9024,306,165,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9024,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9024,320,85,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9024,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9024,401,4.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9024,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9024,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9024,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9024,606,0.003,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9025,203,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9025,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9025,205,12.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9025,207,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9025,208,49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9025,255,86.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9025,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9025,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9025,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9025,303,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9025,306,140,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9025,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9025,320,64,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9025,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9025,401,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9025,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9025,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9025,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9025,606,0.007,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9026,203,0.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9026,204,0.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9026,205,16.49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9026,207,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9026,208,63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9026,255,82.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9026,269,14.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9026,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9026,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9026,303,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9026,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9026,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9026,320,66,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9026,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9026,401,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9026,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9026,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9026,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9026,606,0.003,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9027,203,0.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9027,204,0.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9027,205,21.47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9027,207,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9027,208,83,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9027,255,77.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9027,269,19.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9027,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9027,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9027,303,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9027,306,140,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9027,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9027,320,62,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9027,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9027,401,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9027,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9027,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9027,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9027,606,0.005,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9028,203,0.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9028,204,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9028,205,21.45,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9028,207,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9028,208,83,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9028,255,77.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9028,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9028,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9028,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9028,303,0.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9028,306,134,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9028,307,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9028,320,62,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9028,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9028,401,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9028,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9028,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9028,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9028,606,0.006,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9029,203,0.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9029,204,0.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9029,205,24.85,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9029,207,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9029,208,96,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9029,255,74.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9029,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9029,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9029,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9029,303,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9029,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9029,307,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9029,320,74,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9029,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9029,401,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9029,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9029,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9029,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9029,606,0.003,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9030,203,4.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9030,204,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9030,205,82.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9030,207,4.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9030,208,320,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9030,255,7.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9030,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9030,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9030,301,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9030,303,6.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9030,306,1850,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9030,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9030,320,633,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9030,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9030,401,9.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9030,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9030,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9030,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9030,606,0.043,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9031,203,1.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9031,204,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9031,205,32.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9031,207,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9031,208,126,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9031,255,63.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9031,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9031,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9031,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9031,303,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9031,306,728,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9031,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9031,320,220,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9031,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9031,401,7.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9031,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9031,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9031,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9031,606,0.017,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9032,203,3.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9032,204,0.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9032,205,62.64,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9032,207,2.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9032,208,241,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9032,255,30.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9032,269,53.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9032,291,7.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9032,301,55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9032,303,2.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9032,306,1162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9032,307,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9032,320,180,'100g',1,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (9032,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9032,401,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9032,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9032,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9032,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9032,606,0.017,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9033,203,1.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9033,204,0.18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9033,205,22.15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9033,207,0.91,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9033,208,85,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9033,255,75.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9033,269,19.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9033,291,2.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9033,301,19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9033,303,0.94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9033,306,411,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9033,307,4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9033,320,64,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9033,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9033,401,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9033,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9033,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9033,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9033,606,0.006,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9034,203,1.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9034,204,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9034,205,29.26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9034,207,0.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9034,208,113,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9034,255,68.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9034,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9034,291,4.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9034,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9034,303,1.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9034,306,443,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9034,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9034,320,107,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9034,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9034,401,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9034,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9034,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9034,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9034,606,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9035,203,0.7,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9035,204,0.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9035,205,25.1,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9035,207,0.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9035,208,98,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9035,255,73.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9035,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9035,291,2.2,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9035,301,10,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9035,303,0.9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9035,306,229,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9035,307,4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9035,320,84,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9035,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9035,401,9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9035,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9035,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9035,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9035,606,0.007,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9036,203,0.17,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9036,204,0.45,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9036,205,13.63,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9036,207,0.12,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9036,208,56,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9036,255,85.63,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9036,269,12.79,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9036,291,0.1,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9036,301,11,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9036,303,0.1,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9036,306,67,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9036,307,8,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9036,320,16,'100g',1,1,'2024-12-12','2016-01-12');
INSERT INTO `cndb_nutval` VALUES (9036,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9036,401,29.7,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9036,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9036,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9036,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9036,606,0.033,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9037,203,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9037,204,14.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9037,205,8.53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9037,207,1.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9037,208,160,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9037,255,73.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9037,269,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9037,291,6.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9037,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9037,303,0.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9037,306,485,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9037,307,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9037,320,7,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (9037,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9037,401,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9037,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9037,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9037,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9037,606,2.126,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9038,203,1.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9038,204,15.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9038,205,8.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9038,207,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9038,208,167,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9038,255,72.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9038,269,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9038,291,6.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9038,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9038,303,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9038,306,507,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9038,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9038,320,7,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (9038,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9038,401,8.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9038,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9038,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9038,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9038,606,2.126,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9039,203,2.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9039,204,10.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9039,205,7.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9039,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9039,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9039,255,78.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9039,269,2.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9039,291,5.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9039,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9039,303,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9039,306,351,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9039,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9039,320,7,'100g',1,1,'2024-12-12','2003-01-06');
INSERT INTO `cndb_nutval` VALUES (9039,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9039,401,17.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9039,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9039,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9039,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9039,606,1.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9040,203,1.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9040,204,0.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9040,205,22.84,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9040,207,0.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9040,208,89,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9040,255,74.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9040,269,12.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9040,291,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9040,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9040,303,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9040,306,358,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9040,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9040,320,3,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (9040,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9040,401,8.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9040,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9040,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9040,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9040,606,0.112,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9041,203,3.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9041,204,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9041,205,88.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9041,207,3.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9041,208,346,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9041,255,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9041,269,47.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9041,291,9.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9041,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9041,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9041,306,1491,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9041,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9041,320,12,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9041,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9041,401,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9041,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9041,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9041,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9041,606,0.698,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9042,203,1.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9042,204,0.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9042,205,9.61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9042,207,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9042,208,43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9042,255,88.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9042,269,4.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9042,291,5.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9042,301,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9042,303,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9042,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9042,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9042,320,11,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (9042,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9042,401,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9042,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9042,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9042,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9042,606,0.014,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9043,203,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9043,204,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9043,205,7.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9043,207,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9043,208,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9043,255,90.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9043,269,7.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9043,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9043,301,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9043,303,0.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9043,306,135,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9043,307,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9043,320,6,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9043,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9043,401,11.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9043,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9043,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9043,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9043,606,0.018,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9044,203,1.25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9044,204,0.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9044,205,80.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9044,207,0.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9044,208,333,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9044,255,16.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9044,269,67.15,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9044,291,2.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9044,301,38,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9044,303,0.68,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9044,306,376,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9044,307,13,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9044,320,141,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (9044,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9044,401,19.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9044,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9044,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9044,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9044,606,0.146,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9046,203,1.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9046,204,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9046,205,23.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9046,207,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9046,208,92,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9046,255,75.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9046,269,19.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9046,291,3.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9046,301,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9046,303,0.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9046,306,99,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9046,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9046,320,11,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9046,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9046,401,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9046,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9046,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9046,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9046,606,0.005,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9048,203,1.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9048,204,0.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9048,205,15.67,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9048,207,0.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9048,208,64,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9048,255,82.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9048,269,10.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9048,291,5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9048,301,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9048,303,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9048,306,140,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9048,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9048,320,6,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9048,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9048,401,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9048,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9048,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9048,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9048,606,0.015,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9050,203,0.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9050,204,0.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9050,205,14.49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9050,207,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9050,208,57,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9050,255,84.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9050,269,9.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9050,291,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9050,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9050,303,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9050,306,77,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9050,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9050,320,3,'100g',1,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (9050,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9050,401,9.7,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9050,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9050,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9050,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9050,606,0.028,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9052,203,0.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9052,204,0.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9052,205,22.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9052,207,0.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9052,208,88,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9052,255,76.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9052,269,20.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9052,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9052,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9052,303,0.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9052,306,40,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9052,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9052,320,2,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9052,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9052,401,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9052,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9052,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9052,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9052,606,0.027,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9053,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9053,204,0.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9053,205,13.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9053,207,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9053,208,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9053,255,85.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9053,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9053,291,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9053,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9053,303,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9053,306,68,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9053,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9053,320,3,'100g',1,1,'2024-12-12','2008-01-05');
INSERT INTO `cndb_nutval` VALUES (9053,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9053,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9053,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9053,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9053,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9053,606,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9054,203,0.42,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9054,204,0.64,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9054,205,12.17,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9054,207,0.18,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9054,208,51,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9054,255,86.59,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9054,269,8.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9054,291,2.7,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9054,301,8,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9054,303,0.18,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9054,306,54,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9054,307,1,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9054,320,2,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9054,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9054,401,2.5,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9054,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9054,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9054,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9054,606,0.053,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9055,203,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9055,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9055,205,21.95,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9055,207,0.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9055,208,85,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (9055,255,77.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9055,269,19.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9055,291,2.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9055,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9055,303,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9055,306,60,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9055,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9055,320,2,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9055,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9055,401,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9055,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9055,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9055,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9055,606,0.011,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9056,203,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9056,204,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9056,205,22.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9056,207,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9056,208,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9056,255,76.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9056,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9056,291,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9056,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9056,303,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9056,306,90,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9056,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9056,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9056,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9056,401,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9056,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9056,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9056,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9056,606,0.004,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9057,203,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9057,204,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9057,205,12.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9057,207,0.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9057,208,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9057,255,85.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9057,269,6.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9057,291,5.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9057,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9057,303,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9057,306,139,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9057,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9057,320,3,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (9057,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9057,401,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9057,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9057,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9057,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9057,606,0.009,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9059,203,1.07,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9059,204,0.23,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9059,205,27.12,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9059,207,0.93,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9059,208,103,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9059,255,70.65,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9059,269,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9059,291,4.9,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9059,301,17,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9059,303,0.54,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9059,306,490,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9059,307,2,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9059,320,0,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (9059,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9059,401,29,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9059,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9059,601,0,'100g',4,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9059,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9059,606,0.048,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9060,203,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9060,204,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9060,205,6.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9060,207,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9060,208,31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9060,255,91.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9060,269,3.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9060,291,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9060,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9060,303,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9060,306,133,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9060,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9060,320,3,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (9060,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9060,401,34.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9060,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9060,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9060,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9060,606,0.019,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9062,203,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9062,204,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9062,205,17.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9062,207,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9062,208,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9062,255,79.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9062,269,12.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9062,291,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9062,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9062,303,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9062,306,287,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9062,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9062,320,0,'100g',1,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (9062,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9062,401,12.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9062,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9062,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9062,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9062,606,0.233,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9063,203,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9063,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9063,205,12.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9063,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9063,208,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9063,255,86.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9063,269,8.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9063,291,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9063,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9063,303,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9063,306,173,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9063,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9063,320,64,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9063,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9063,401,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9063,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9063,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9063,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9063,606,0.068,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9064,203,0.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9064,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9064,205,8.94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9064,207,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9064,208,36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9064,255,89.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9064,269,7.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9064,291,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9064,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9064,303,1.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9064,306,98,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9064,307,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9064,320,38,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9064,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9064,401,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9064,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9064,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9064,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9064,606,0.023,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9065,203,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9065,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9065,205,19.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9065,207,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9065,208,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9065,255,79.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9065,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9065,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9065,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9065,303,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9065,306,95,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9065,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9065,320,36,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9065,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9065,401,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9065,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9065,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9065,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9065,606,0.022,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9066,203,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9066,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9066,205,23.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9066,207,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9066,208,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9066,255,75.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9066,269,22.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9066,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9066,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9066,303,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9066,306,93,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9066,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9066,320,36,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9066,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9066,401,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9066,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9066,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9066,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9066,606,0.021,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9067,203,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9067,204,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9067,205,29.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9067,207,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9067,208,114,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9067,255,69.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9067,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9067,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9067,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9067,303,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9067,306,91,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9067,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9067,320,35,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9067,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9067,401,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9067,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9067,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9067,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9067,606,0.021,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9068,203,0.92,'100g',1,1,'1994-05-17','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9068,204,0.44,'100g',1,1,'1994-05-17','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9068,205,11.02,'100g',3,1,'1994-05-17','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9068,207,0.42,'100g',1,1,'1994-05-17','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9068,208,46,'100g',3,1,'1994-05-17','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9068,255,87.2,'100g',1,1,'1994-05-17','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9068,269,9.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9068,291,1.6,'100g',1,1,'1994-05-17','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9068,301,13,'100g',1,1,'1994-05-17','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9068,303,0.53,'100g',1,1,'1994-05-17','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9068,306,124,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9068,307,1,'100g',1,1,'1994-05-17','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9068,320,44,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9068,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9068,401,1.7,'100g',1,1,'1994-05-17','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9068,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9068,601,0,'100g',4,1,'1994-05-17','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9068,605,0,'100g',NULL,1,'1994-05-17','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9068,606,0.1,'100g',1,1,'1994-05-17','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9070,203,1.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9070,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9070,205,16.01,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9070,207,0.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9070,208,63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9070,255,82.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9070,269,12.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9070,291,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9070,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9070,303,0.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9070,306,222,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9070,307,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9070,320,3,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (9070,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9070,401,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9070,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9070,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9070,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9070,606,0.038,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9071,203,0.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9071,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9071,205,11.76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9071,207,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9071,208,46,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9071,255,87.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9071,269,10.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9071,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9071,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9071,303,0.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9071,306,131,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9071,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9071,320,8,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9071,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9071,401,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9071,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9071,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9071,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9071,606,0.028,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9072,203,0.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9072,204,0.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9072,205,13.81,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9072,207,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9072,208,54,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9072,255,84.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9072,269,12.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9072,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9072,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9072,303,0.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9072,306,131,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9072,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9072,320,6,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9072,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9072,401,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9072,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9072,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9072,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9072,606,0.004,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9073,203,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9073,204,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9073,205,17.29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9073,207,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9073,208,67,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9073,255,81.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9073,269,15.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9073,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9073,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9073,303,0.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9073,306,148,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9073,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9073,320,8,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9073,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9073,401,3.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9073,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9073,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9073,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9073,606,0.034,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9074,203,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9074,204,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9074,205,21.27,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9074,207,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9074,208,83,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9074,255,77.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9074,269,16.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9074,291,1.4,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9074,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9074,303,0.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9074,306,145,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9074,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9074,320,8,'100g',1,1,'2024-12-12','2008-01-05');
INSERT INTO `cndb_nutval` VALUES (9074,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9074,401,3.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9074,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9074,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9074,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9074,606,0.034,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9075,203,0.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9075,204,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9075,205,26.23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9075,207,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9075,208,102,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9075,255,72.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9075,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9075,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9075,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9075,303,0.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9075,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9075,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9075,320,8,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9075,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9075,401,3.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9075,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9075,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9075,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9075,606,0.033,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9077,203,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9077,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9077,205,19.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9077,207,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9077,208,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9077,255,78.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9077,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9077,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9077,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9077,303,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9077,306,194,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9077,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9077,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9077,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9077,401,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9077,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9077,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9077,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9077,606,0.048,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9078,203,0.46,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9078,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9078,205,11.97,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9078,207,0.12,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9078,208,46,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9078,255,87.32,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9078,269,4.27,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9078,291,3.6,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9078,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9078,303,0.23,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9078,306,80,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9078,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9078,320,3,'100g',1,1,'2024-12-12','2002-01-08');
INSERT INTO `cndb_nutval` VALUES (9078,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9078,401,14,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9078,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9078,601,0,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9078,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9078,606,0.008,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9079,203,0.17,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9079,204,1.09,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9079,205,82.8,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9079,207,0.15,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9079,208,308,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9079,255,15.79,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9079,269,72.56,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9079,291,5.3,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9079,301,9,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9079,303,0.39,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9079,306,49,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9079,307,5,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9079,320,2,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9079,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9079,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9079,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9079,601,0,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9079,605,0.003,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9079,606,0.088,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9081,203,0.9,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9081,204,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9081,205,40.4,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9081,207,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9081,208,159,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9081,255,58.45,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9081,269,31.75,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9081,291,1.1,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9081,301,3,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9081,303,0.41,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9081,306,28,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9081,307,5,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9081,320,2,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9081,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9081,401,1,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9081,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9081,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9081,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9081,606,0.007,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9082,203,0.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9082,204,0.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9082,205,46.2,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9082,207,0.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9082,208,178,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9082,255,53.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9082,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9082,291,0,'100g',3,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9082,301,11,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9082,303,0.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9082,306,38,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9082,307,32,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9082,320,4,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9082,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9082,401,18,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9082,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9082,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9082,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9082,606,0.012,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9083,203,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9083,204,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9083,205,15.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9083,207,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9083,208,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9083,255,81.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9083,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9083,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9083,301,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9083,303,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9083,306,322,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9083,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9083,320,12,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9083,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9083,401,181,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9083,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9083,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9083,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9083,606,0.034,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9084,203,1.4,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9084,204,0.2,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9084,205,13.8,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9084,207,0.66,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9084,208,56,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9084,255,83.95,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9084,269,7.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9084,291,4.3,'100g',3,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9084,301,33,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9084,303,1,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9084,306,275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9084,307,1,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9084,320,2,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9084,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9084,401,41,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9084,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9084,601,0,'100g',4,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9084,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9084,606,0.017,'100g',1,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9085,203,3.43,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9085,204,0.22,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9085,205,76.98,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9085,207,1.77,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9085,208,290,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9085,255,17.6,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9085,269,62.28,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9085,291,4.4,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9085,301,88,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9085,303,1.88,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9085,306,777,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9085,307,43,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9085,320,4,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9085,328,0,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9085,401,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9085,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9085,601,0,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9085,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9085,606,0.085,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9086,203,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9086,204,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9086,205,25.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9086,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9086,208,101,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9086,255,71.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9086,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9086,291,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9086,301,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9086,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9086,306,382,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9086,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9086,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9086,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9086,401,19.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9086,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9086,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9086,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9086,606,0.231,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9087,203,2.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9087,204,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9087,205,75.03,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9087,207,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9087,208,282,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9087,255,20.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9087,269,63.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9087,291,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9087,301,39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9087,303,1.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9087,306,656,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9087,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9087,320,0,'100g',1,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (9087,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9087,401,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9087,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9087,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9087,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9087,606,0.032,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9088,203,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9088,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9088,205,18.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9088,207,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9088,208,73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9088,255,79.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9088,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9088,291,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9088,301,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9088,303,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9088,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9088,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9088,320,30,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9088,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9088,401,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9088,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9088,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9088,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9088,606,0.023,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9089,203,0.75,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9089,204,0.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9089,205,19.18,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9089,207,0.66,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9089,208,74,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9089,255,79.11,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9089,269,16.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9089,291,2.9,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9089,301,35,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9089,303,0.37,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9089,306,232,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9089,307,1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9089,320,7,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9089,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9089,401,2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9089,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9089,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9089,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9089,606,0.06,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9090,203,0.4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9090,204,0.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9090,205,13.99,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9090,207,0.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9090,208,53,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9090,255,85.21,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9090,269,11.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9090,291,2.2,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9090,301,28,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9090,303,0.29,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9090,306,103,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9090,307,1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9090,320,2,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9090,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9090,401,1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9090,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9090,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9090,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9090,606,0.02,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9091,203,0.39,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9091,204,0.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9091,205,17.95,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9091,207,0.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9091,208,69,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9091,255,81.26,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9091,269,16.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9091,291,1.8,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9091,301,27,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9091,303,0.29,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9091,306,102,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9091,307,1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9091,320,2,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9091,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9091,401,1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9091,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9091,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9091,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9091,606,0.02,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9092,203,0.38,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9092,204,0.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9092,205,22.9,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9092,207,0.29,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9092,208,88,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9092,255,76.33,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9092,269,20.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9092,291,2.2,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9092,301,27,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9092,303,0.28,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9092,306,99,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9092,307,1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9092,320,2,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9092,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9092,401,1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9092,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9092,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9092,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9092,606,0.02,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9093,203,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9093,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9093,205,27.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9093,207,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9093,208,107,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9093,255,71.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9093,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9093,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9093,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9093,303,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9093,306,97,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9093,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9093,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9093,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9093,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9093,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9093,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9093,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9093,606,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9094,203,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9094,204,0.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9094,205,63.87,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9094,207,1.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9094,208,249,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9094,255,30.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9094,269,47.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9094,291,9.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9094,301,162,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9094,303,2.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9094,306,680,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9094,307,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9094,320,0,'100g',1,1,'2024-12-12','2002-01-12');
INSERT INTO `cndb_nutval` VALUES (9094,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9094,401,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9094,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9094,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9094,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9094,606,0.144,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9095,203,1.42,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9095,204,0.4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9095,205,27.57,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9095,207,0.8,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9095,208,107,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9095,255,69.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9095,269,23.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9095,291,4.2,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9095,301,70,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9095,303,0.88,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9095,306,294,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9095,307,4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9095,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9095,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9095,401,4.4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9095,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9095,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9095,605,NULL,'100g',NULL,1,'1994-09-21','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9095,606,0.062,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9096,203,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9096,204,0.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9096,205,8.51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9096,207,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9096,208,32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9096,255,90.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9096,269,7.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9096,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9096,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9096,303,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9096,306,94,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9096,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9096,320,13,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9096,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9096,401,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9096,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9096,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9096,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9096,606,0.006,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9097,203,0.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9097,204,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9097,205,11.86,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9097,207,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9097,208,46,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9097,255,87.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9097,269,10.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9097,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9097,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9097,303,0.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9097,306,95,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9097,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9097,320,15,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9097,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9097,401,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9097,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9097,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9097,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9097,606,0.001,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9098,203,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9098,204,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9098,205,11.63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9098,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9098,208,45,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9098,255,87.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9098,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9098,291,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9098,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9098,303,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9098,306,104,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9098,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9098,320,12,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9098,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9098,401,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9098,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9098,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9098,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9098,606,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9099,203,0.4,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9099,204,0.07,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9099,205,14.93,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9099,207,0.23,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9099,208,57,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9099,255,84.37,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9099,269,13.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9099,291,1,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9099,301,6,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9099,303,0.29,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9099,306,89,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9099,307,6,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9099,320,10,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9099,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9099,401,1.9,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9099,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9099,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9099,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9099,606,0.01,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9100,203,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9100,204,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9100,205,18.91,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9100,207,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9100,208,73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9100,255,80.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9100,269,17.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9100,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9100,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9100,303,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9100,306,88,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9100,307,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9100,320,10,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9100,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9100,401,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9100,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9100,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9100,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9100,606,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9101,203,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9101,204,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9101,205,22.89,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9101,207,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9101,208,88,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9101,255,76.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9101,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9101,291,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9101,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9101,303,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9101,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9101,307,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9101,320,10,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9101,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9101,401,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9101,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9101,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9101,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9101,606,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9102,203,0.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9102,204,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9102,205,7.87,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9102,207,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9102,208,30,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9102,255,91.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9102,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9102,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9102,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9102,303,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9102,306,78,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9102,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9102,320,22,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9102,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9102,401,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9102,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9102,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9102,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9102,606,0.009,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9103,203,0.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9103,204,0.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9103,205,13.05,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9103,207,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9103,208,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9103,255,86.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9103,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9103,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9103,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9103,303,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9103,306,116,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9103,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9103,320,30,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9103,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9103,401,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9103,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9103,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9103,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9103,606,0.004,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9104,203,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9104,204,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9104,205,15.14,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9104,207,0.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9104,208,58,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9104,255,84.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9104,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9104,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9104,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9104,303,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9104,306,82,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9104,307,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9104,320,21,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9104,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9104,401,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9104,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9104,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9104,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9104,606,0.009,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9106,203,0.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9106,204,0.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9106,205,22.77,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9106,207,0.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9106,208,88,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9106,255,76.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9106,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9106,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9106,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9106,303,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9106,306,80,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9106,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9106,320,32,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9106,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9106,401,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9106,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9106,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9106,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9106,606,0.009,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9107,203,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9107,204,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9107,205,10.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9107,207,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9107,208,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9107,255,87.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9107,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9107,291,4.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9107,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9107,303,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9107,306,198,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9107,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9107,320,15,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9107,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9107,401,27.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9107,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9107,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9107,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9107,606,0.038,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9109,203,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9109,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9109,205,18.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9109,207,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9109,208,73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9109,255,80.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9109,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9109,291,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9109,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9109,303,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9109,306,77,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9109,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9109,320,7,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9109,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9109,401,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9109,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9109,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9109,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9109,606,0.013,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9110,203,14.26,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9110,204,0.39,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9110,205,77.06,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9110,207,0.78,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9110,208,349,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9110,255,7.5,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9110,269,45.61,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9110,291,13,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9110,301,190,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9110,303,6.8,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9110,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9110,307,298,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9110,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (9110,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9110,401,48.4,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9110,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9110,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9110,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9110,606,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9111,203,0.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9111,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9111,205,8.08,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9111,207,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9111,208,32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9111,255,90.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9111,269,6.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9111,291,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9111,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9111,303,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9111,306,139,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9111,307,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9111,320,46,'100g',2,1,'2024-12-12','2003-01-09');
INSERT INTO `cndb_nutval` VALUES (9111,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9111,401,34.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9111,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9111,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9111,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9111,606,0.014,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9112,203,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9112,204,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9112,205,10.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9112,207,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9112,208,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9112,255,88.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9112,269,6.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9112,291,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9112,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9112,303,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9112,306,135,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9112,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9112,320,58,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (9112,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9112,401,31.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9112,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9112,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9112,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9112,606,0.021,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9113,203,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9113,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9113,205,9.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9113,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9113,208,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9113,255,89.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9113,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9113,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9113,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9113,303,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9113,306,147,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9113,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9113,320,13,'100g',1,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (9113,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9113,401,38.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9113,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9113,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9113,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9113,606,0.014,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9114,203,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9114,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9114,205,7.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9114,207,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9114,208,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9114,255,91.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9114,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9114,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9114,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9114,303,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9114,306,127,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9114,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9114,320,13,'100g',1,1,'2024-12-12','2003-01-09');
INSERT INTO `cndb_nutval` VALUES (9114,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9114,401,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9114,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9114,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9114,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9114,606,0.014,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9116,203,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9116,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9116,205,8.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9116,207,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9116,208,33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9116,255,90.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9116,269,7.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9116,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9116,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9116,303,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9116,306,148,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9116,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9116,320,2,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9116,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9116,401,33.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9116,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9116,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9116,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9116,606,0.014,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9117,203,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9117,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9117,205,9.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9117,207,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9117,208,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9117,255,89.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9117,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9117,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9117,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9117,303,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9117,306,143,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9117,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9117,320,0,'100g',1,1,'2024-12-12','2003-01-09');
INSERT INTO `cndb_nutval` VALUES (9117,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9117,401,33.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9117,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9117,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9117,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9117,606,0.014,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9118,203,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9118,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9118,205,8.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9118,207,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9118,208,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9118,255,90.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9118,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9118,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9118,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9118,303,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9118,306,150,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9118,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9118,320,0,'100g',1,1,'2024-12-12','2003-01-09');
INSERT INTO `cndb_nutval` VALUES (9118,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9118,401,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9118,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9118,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9118,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9118,606,0.014,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9119,203,0.58,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9119,204,0.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9119,205,9.15,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9119,207,0.32,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9119,208,36,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9119,255,89.85,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9119,269,8.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9119,291,0.4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9119,301,15,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9119,303,0.41,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9119,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9119,307,2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9119,320,0,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9119,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9119,401,21.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9119,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9119,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9119,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9119,606,0.014,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9120,203,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9120,204,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9120,205,9.21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9120,207,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9120,208,37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9120,255,89.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9120,269,8.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9120,291,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9120,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9120,303,0.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9120,306,169,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9120,307,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9120,320,0,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9120,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9120,401,33.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9120,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9120,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9120,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9120,606,0.012,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9121,203,0.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9121,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9121,205,15.44,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9121,207,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9121,208,60,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9121,255,83.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9121,269,15.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9121,291,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9121,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9121,303,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9121,306,129,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9121,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9121,320,0,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9121,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9121,401,21.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9121,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9121,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9121,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9121,606,0.014,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9123,203,0.55,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9123,204,0.66,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9123,205,7.54,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9123,207,0.29,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9123,208,37,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9123,255,90.97,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9123,269,7.69,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9123,291,0.6,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9123,301,16,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9123,303,0.08,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9123,306,141,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9123,307,2,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9123,320,2,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (9123,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9123,401,33.7,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9123,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9123,601,1,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9123,605,NULL,'100g',NULL,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9123,606,0.082,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9124,203,0.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9124,204,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9124,205,11.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9124,207,0.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9124,208,46,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9124,255,87.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9124,269,11.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9124,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9124,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9124,303,0.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9124,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9124,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9124,320,0,'100g',2,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (9124,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9124,401,26.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9124,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9124,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9124,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9124,606,0.012,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9125,203,1.97,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9125,204,0.48,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9125,205,34.56,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9125,207,0.99,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9125,208,146,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9125,255,62,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9125,269,34.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9125,291,0.4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9125,301,27,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9125,303,0.49,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9125,306,484,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9125,307,3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9125,320,2,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9125,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9125,401,119.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9125,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9125,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9125,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9125,606,0.064,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9126,203,0.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9126,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9126,205,9.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9126,207,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9126,208,41,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9126,255,89.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9126,269,9.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9126,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9126,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9126,303,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9126,306,136,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9126,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9126,320,0,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9126,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9126,401,33.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9126,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9126,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9126,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9126,606,0.019,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9127,203,0.51,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9127,204,0.68,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9127,205,7.74,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9127,207,0.29,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9127,208,39,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9127,255,90.77,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9127,269,7.96,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9127,291,0.3,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9127,301,146,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9127,303,0.06,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9127,306,132,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9127,307,2,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9127,320,16,'100g',1,1,'2024-12-12','2016-01-10');
INSERT INTO `cndb_nutval` VALUES (9127,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9127,401,22.2,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9127,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9127,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9127,605,NULL,'100g',NULL,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9127,606,0.173,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9128,203,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9128,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9128,205,9.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9128,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9128,208,39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9128,255,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9128,269,9.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9128,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9128,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9128,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9128,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9128,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9128,320,1,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9128,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9128,401,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9128,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9128,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9128,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9128,606,0.014,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9130,203,0.37,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9130,204,0.13,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9130,205,14.77,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9130,207,0.22,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9130,208,60,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9130,255,84.51,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9130,269,14.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9130,291,0.2,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9130,301,11,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9130,303,0.25,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9130,306,104,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9130,307,5,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9130,320,0,'100g',2,1,'2024-12-12','2008-01-06');
INSERT INTO `cndb_nutval` VALUES (9130,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9130,401,25,'100g',6,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9130,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9130,601,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9130,605,0,'100g',NULL,1,'2009-01-25','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9130,606,0.025,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9131,203,0.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9131,204,0.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9131,205,17.15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9131,207,0.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9131,208,67,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9131,255,81.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9131,269,16.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9131,291,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9131,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9131,303,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9131,306,191,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9131,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9131,320,5,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9131,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9131,401,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9131,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9131,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9131,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9131,606,0.114,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9132,203,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9132,204,0.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9132,205,18.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9132,207,0.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9132,208,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9132,255,80.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9132,269,15.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9132,291,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9132,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9132,303,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9132,306,191,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9132,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9132,320,3,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (9132,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9132,401,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9132,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9132,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9132,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9132,606,0.054,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9133,203,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9133,204,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9133,205,10.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9133,207,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9133,208,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9133,255,88.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9133,269,9.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9133,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9133,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9133,303,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9133,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9133,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9133,320,2,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9133,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9133,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9133,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9133,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9133,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9133,606,0.035,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9134,203,0.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9134,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9134,205,19.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9134,207,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9134,208,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9134,255,79.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9134,269,19.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9134,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9134,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9134,303,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9134,306,103,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9134,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9134,320,3,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9134,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9134,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9134,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9134,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9134,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9134,606,0.033,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9135,203,0.37,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9135,204,0.13,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9135,205,14.77,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9135,207,0.22,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9135,208,60,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9135,255,84.51,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9135,269,14.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9135,291,0.2,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9135,301,11,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9135,303,0.25,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9135,306,104,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9135,307,5,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9135,320,0,'100g',2,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (9135,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9135,401,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9135,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9135,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9135,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9135,606,0.025,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9139,203,2.55,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9139,204,0.95,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9139,205,14.32,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9139,207,1.39,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9139,208,68,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9139,255,80.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9139,269,8.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9139,291,5.4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9139,301,18,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9139,303,0.26,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9139,306,417,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9139,307,2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9139,320,31,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (9139,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9139,401,228.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9139,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9139,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9139,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9139,606,0.272,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9140,203,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9140,204,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9140,205,17.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9140,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9140,208,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9140,255,80.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9140,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9140,291,5.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9140,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9140,303,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9140,306,292,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9140,307,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9140,320,5,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9140,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9140,401,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9140,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9140,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9140,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9140,606,0.172,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9143,203,0.32,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9143,204,0.14,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9143,205,9.48,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9143,207,0.5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9143,208,36,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9143,255,89.56,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9143,269,5.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9143,291,3.6,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9143,301,7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9143,303,0.18,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9143,306,225,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9143,307,4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9143,320,14,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9143,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9143,401,146.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9143,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9143,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9143,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9143,606,0.04,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9144,203,1.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9144,204,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9144,205,23.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9144,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9144,208,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9144,255,73.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9144,269,19.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9144,291,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9144,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9144,303,0.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9144,306,448,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9144,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9144,320,5,'100g',1,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (9144,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9144,401,13.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9144,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9144,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9144,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9144,606,0.195,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9148,203,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9148,204,0.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9148,205,14.66,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9148,207,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9148,208,61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9148,255,83.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9148,269,8.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9148,291,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9148,301,34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9148,303,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9148,306,312,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9148,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9148,320,4,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (9148,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9148,401,92.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9148,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9148,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9148,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9148,606,0.029,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9149,203,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9149,204,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9149,205,15.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9149,207,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9149,208,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9149,255,80.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9149,269,9.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9149,291,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9149,301,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9149,303,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9149,306,186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9149,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9149,320,15,'100g',1,1,'2024-12-12','2002-01-08');
INSERT INTO `cndb_nutval` VALUES (9149,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9149,401,43.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9149,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9149,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9149,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9149,606,0.103,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9150,203,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9150,204,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9150,205,9.32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9150,207,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9150,208,29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9150,255,88.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9150,269,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9150,291,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9150,301,26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9150,303,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9150,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9150,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9150,320,1,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9150,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9150,401,53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9150,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9150,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9150,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9150,606,0.039,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9152,203,0.35,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9152,204,0.24,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9152,205,6.9,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9152,207,0.21,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9152,208,22,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9152,255,92.31,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9152,269,2.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9152,291,0.3,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9152,301,6,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9152,303,0.08,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9152,306,103,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9152,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9152,320,0,'100g',1,1,'2024-12-12','2009-01-11');
INSERT INTO `cndb_nutval` VALUES (9152,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9152,401,38.7,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9152,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9152,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9152,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9152,606,0.04,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9153,203,0.45,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9153,204,0.07,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9153,205,5.62,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9153,207,0.22,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9153,208,17,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9153,255,93.64,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9153,269,1.53,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9153,291,0.7,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9153,301,10,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9153,303,0.06,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9153,306,109,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9153,307,24,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9153,320,2,'100g',1,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (9153,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9153,401,14.3,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9153,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9153,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9153,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9153,606,0.027,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9156,203,1.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9156,204,0.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9156,205,16,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9156,207,0.6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9156,208,47,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9156,255,81.6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9156,269,4.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9156,291,10.6,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9156,301,134,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9156,303,0.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9156,306,160,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9156,307,6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9156,320,3,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9156,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9156,401,129,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9156,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9156,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9156,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9156,606,0.039,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9159,203,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9159,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9159,205,10.54,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9159,207,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9159,208,30,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9159,255,88.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9159,269,1.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9159,291,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9159,301,33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9159,303,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9159,306,102,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9159,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9159,320,2,'100g',2,1,'2024-12-12','2004-01-05');
INSERT INTO `cndb_nutval` VALUES (9159,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9159,401,29.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9159,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9159,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9159,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9159,606,0.022,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9160,203,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9160,204,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9160,205,8.42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9160,207,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9160,208,25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9160,255,90.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9160,269,1.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9160,291,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9160,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9160,303,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9160,306,117,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9160,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9160,320,2,'100g',1,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (9160,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9160,401,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9160,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9160,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9160,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9160,606,0.008,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9161,203,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9161,204,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9161,205,6.69,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9161,207,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9161,208,21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9161,255,92.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9161,269,1.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9161,291,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9161,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9161,303,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9161,306,75,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9161,307,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9161,320,1,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9161,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9161,401,6.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9161,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9161,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9161,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9161,606,0.026,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9163,203,2.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9163,204,2.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9163,205,80,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9163,207,0.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9163,208,317,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9163,255,14.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9163,269,67.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9163,291,7.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9163,301,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9163,303,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9163,306,214,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9163,307,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9163,320,7,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (9163,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9163,401,23.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9163,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9163,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9163,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9163,606,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9164,203,0.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9164,204,0.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9164,205,16.53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9164,207,0.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9164,208,66,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9164,255,81.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9164,269,15.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9164,291,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9164,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9164,303,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9164,306,171,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9164,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9164,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9164,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9164,401,71.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9164,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9164,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9164,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9164,606,0.099,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9165,203,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9165,204,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9165,205,70.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9165,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9165,208,277,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9165,255,22.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9165,269,66.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9165,291,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9165,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9165,303,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9165,306,1110,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9165,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9165,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9165,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9165,401,183,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9165,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9165,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9165,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9165,606,0.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9167,203,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9167,204,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9167,205,13.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9167,207,0.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9167,208,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9167,255,84.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9167,269,7.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9167,291,5.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9167,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9167,303,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9167,306,145,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9167,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9167,320,2,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9167,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9167,401,15.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9167,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9167,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9167,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9167,606,0.011,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9174,203,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9174,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9174,205,12.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9174,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9174,208,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9174,255,86.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9174,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9174,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9174,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9174,303,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9174,306,266,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9174,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9174,320,76,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9174,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9174,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9174,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9174,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9174,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9174,606,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9175,203,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9175,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9175,205,12.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9175,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9175,208,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9175,255,86.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9175,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9175,291,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9175,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9175,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9175,306,47,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9175,307,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9175,320,12,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9175,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9175,401,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9175,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9175,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9175,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9175,606,0.136,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9176,203,0.82,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9176,204,0.38,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9176,205,14.98,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9176,207,0.36,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9176,208,60,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9176,255,83.46,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9176,269,13.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9176,291,1.6,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9176,301,11,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9176,303,0.16,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9176,306,168,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9176,307,1,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9176,320,54,'100g',1,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (9176,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9176,401,36.4,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9176,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9176,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9176,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9176,606,0.092,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9178,203,2.45,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9178,204,1.18,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9178,205,78.58,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9178,207,1.19,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9178,208,319,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9178,255,16.6,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9178,269,66.27,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9178,291,2.4,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9178,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9178,303,0.23,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9178,306,279,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9178,307,162,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9178,320,67,'100g',1,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (9178,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9178,401,42.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9178,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9178,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9178,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9178,606,0.287,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9181,203,0.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9181,204,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9181,205,8.16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9181,207,0.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9181,208,34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9181,255,90.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9181,269,7.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9181,291,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9181,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9181,303,0.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9181,306,267,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9181,307,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9181,320,169,'100g',1,1,'2024-12-12','2002-01-12');
INSERT INTO `cndb_nutval` VALUES (9181,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9181,401,36.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9181,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9181,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9181,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9181,606,0.051,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9183,203,1.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9183,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9183,205,6.58,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9183,207,0.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9183,208,28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9183,255,91.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9183,269,5.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9183,291,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9183,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9183,303,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9183,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9183,307,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9183,320,0,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (9183,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9183,401,21.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9183,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9183,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9183,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9183,606,0.025,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9184,203,0.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9184,204,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9184,205,9.09,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9184,207,0.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9184,208,36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9184,255,89.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9184,269,8.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9184,291,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9184,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9184,303,0.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9184,306,228,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9184,307,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9184,320,3,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (9184,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9184,401,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9184,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9184,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9184,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9184,606,0.038,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9185,203,0.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9185,204,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9185,205,7.94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9185,207,0.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9185,208,33,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9185,255,90.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9185,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9185,291,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9185,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9185,303,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9185,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9185,307,31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9185,320,89,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9185,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9185,401,6.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9185,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9185,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9185,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9185,606,0.064,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9190,203,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9190,204,0.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9190,205,9.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9190,207,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9190,208,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9190,255,87.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9190,269,8.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9190,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9190,301,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9190,303,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9190,306,194,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9190,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9190,320,1,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9190,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9190,401,36.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9190,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9190,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9190,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9190,606,0.027,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9191,203,1.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9191,204,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9191,205,10.55,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9191,207,0.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9191,208,44,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9191,255,87.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9191,269,7.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9191,291,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9191,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9191,303,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9191,306,201,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9191,307,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9191,320,17,'100g',1,1,'2024-12-12','2002-01-12');
INSERT INTO `cndb_nutval` VALUES (9191,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9191,401,5.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9191,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9191,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9191,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9191,606,0.025,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9193,203,0.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9193,204,10.9,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9193,205,6.04,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9193,207,2.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9193,208,116,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9193,255,79.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9193,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9193,291,1.6,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9193,301,88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9193,303,6.28,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9193,306,8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9193,307,735,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9193,320,17,'100g',2,1,'2024-12-12','2016-01-08');
INSERT INTO `cndb_nutval` VALUES (9193,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9193,401,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9193,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9193,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9193,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9193,606,2.279,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9194,203,0.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9194,204,6.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9194,205,5.61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9194,207,2.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9194,208,81,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9194,255,84.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9194,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9194,291,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9194,301,94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9194,303,3.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9194,306,9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9194,307,735,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9194,320,17,'100g',2,1,'2024-12-12','2010-01-01');
INSERT INTO `cndb_nutval` VALUES (9194,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9194,401,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9194,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9194,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9194,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9194,606,0.909,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9195,203,1.03,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9195,204,15.32,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9195,205,3.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9195,207,4.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9195,208,145,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9195,255,75.28,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9195,269,0.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9195,291,3.3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9195,301,52,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9195,303,0.49,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9195,306,42,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9195,307,1556,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9195,320,20,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (9195,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9195,401,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9195,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9195,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9195,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9195,606,2.029,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9200,203,0.94,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9200,204,0.12,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9200,205,11.75,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9200,207,0.44,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9200,208,47,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9200,255,86.75,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9200,269,9.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9200,291,2.4,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9200,301,40,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9200,303,0.1,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9200,306,181,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9200,307,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9200,320,11,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (9200,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9200,401,53.2,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9200,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9200,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9200,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9200,606,0.015,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9201,203,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9201,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9201,205,11.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9201,207,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9201,208,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9201,255,86.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9201,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9201,291,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9201,301,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9201,303,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9201,306,179,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9201,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9201,320,12,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9201,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9201,401,48.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9201,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9201,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9201,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9201,606,0.035,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9202,203,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9202,204,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9202,205,12.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9202,207,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9202,208,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9202,255,85.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9202,269,8.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9202,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9202,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9202,303,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9202,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9202,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9202,320,12,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (9202,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9202,401,59.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9202,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9202,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9202,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9202,606,0.017,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9203,203,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9203,204,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9203,205,11.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9203,207,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9203,208,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9203,255,87.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9203,269,9.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9203,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9203,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9203,303,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9203,306,169,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9203,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9203,320,11,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9203,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9203,401,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9203,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9203,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9203,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9203,606,0.025,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9205,203,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9205,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9205,205,15.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9205,207,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9205,208,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9205,255,82.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9205,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9205,291,4.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9205,301,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9205,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9205,306,196,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9205,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9205,320,13,'100g',1,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (9205,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9205,401,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9205,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9205,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9205,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9205,606,0.035,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9206,203,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9206,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9206,205,10.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9206,207,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9206,208,45,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9206,255,88.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9206,269,8.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9206,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9206,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9206,303,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9206,306,200,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9206,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9206,320,10,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (9206,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9206,401,50,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9206,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9206,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9206,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9206,606,0.024,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9207,203,0.68,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9207,204,0.15,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9207,205,11.01,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9207,207,0.43,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9207,208,47,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9207,255,87.72,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9207,269,8.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9207,291,0.3,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9207,301,10,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9207,303,0.1,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9207,306,184,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9207,307,4,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9207,320,9,'100g',2,1,'2024-12-12','2008-01-05');
INSERT INTO `cndb_nutval` VALUES (9207,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9207,401,30.1,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9207,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9207,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9207,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9207,606,0.018,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9209,203,0.68,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9209,204,0.12,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9209,205,11.54,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9209,207,0.43,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9209,208,49,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9209,255,87.22,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9209,269,8.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9209,291,0.3,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9209,301,11,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9209,303,0.13,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9209,306,178,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9209,307,2,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9209,320,2,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (9209,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9209,401,33.6,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9209,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9209,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9209,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9209,606,0.014,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9210,203,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9210,204,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9210,205,11.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9210,207,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9210,208,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9210,255,87.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9210,269,8.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9210,291,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9210,301,140,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9210,303,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9210,306,178,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9210,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9210,320,2,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (9210,328,1,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9210,401,33.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9210,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9210,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9210,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9210,606,0.014,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9211,203,0.68,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9211,204,0.12,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9211,205,11.27,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9211,207,0.71,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9211,208,47,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9211,255,87.22,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9211,269,8.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9211,291,0.3,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9211,301,140,'100g',6,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (9211,303,0.13,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9211,306,178,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9211,307,2,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9211,320,2,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (9211,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9211,401,33.6,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9211,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9211,601,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9211,605,0,'100g',NULL,1,'2010-01-04','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9211,606,0.014,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9212,203,0.6,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9212,204,0.06,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9212,205,8.47,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9212,207,0.81,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9212,208,37,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9212,255,90.07,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9212,269,7.42,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9212,291,0.2,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9212,301,147,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9212,303,0.08,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9212,306,158,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9212,307,4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9212,320,3,'100g',1,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (9212,328,0,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9212,401,36.2,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9212,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9212,601,0,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9212,605,0,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9212,606,0.015,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9213,203,2.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9213,204,0.25,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9213,205,33.86,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9213,207,2.92,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9213,208,147,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9213,255,60.57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9213,269,29.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9213,291,1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9213,301,578,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9213,303,0.33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9213,306,629,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9213,307,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9213,320,13,'100g',1,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (9213,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9213,401,144.8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9213,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9213,601,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9213,605,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9213,606,0.059,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9214,203,2.4,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9214,204,0.25,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9214,205,35.19,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9214,207,1.6,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9214,208,148,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9214,255,60.57,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9214,269,29.68,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9214,291,1,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9214,301,38,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9214,303,0.33,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9214,306,629,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9214,307,7,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9214,320,13,'100g',1,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (9214,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9214,401,144.8,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9214,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9214,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9214,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9214,606,0.059,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9215,203,0.6,'100g',7,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9215,204,0.06,'100g',7,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9215,205,8.8,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9215,207,0.47,'100g',7,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9215,208,37,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9215,255,90.07,'100g',7,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9215,269,7.42,'100g',7,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9215,291,0.2,'100g',7,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9215,301,12,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9215,303,0.08,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9215,306,158,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9215,307,4,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9215,320,3,'100g',1,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (9215,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9215,401,36.2,'100g',7,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9215,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9215,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9215,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9215,606,0.015,'100g',7,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9216,203,1.5,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9216,204,0.2,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9216,205,25,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9216,207,0.8,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9216,208,97,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9216,255,72.5,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9216,269,NULL,'100g',NULL,1,'1995-06-27','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9216,291,10.6,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9216,301,161,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9216,303,0.8,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9216,306,212,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9216,307,3,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9216,320,21,'100g',1,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (9216,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9216,401,136,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9216,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9216,601,0,'100g',4,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9216,605,0,'100g',NULL,1,'1995-06-27','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9216,606,0.024,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9217,203,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9217,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9217,205,10.28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9217,207,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9217,208,43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9217,255,88.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9217,269,10.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9217,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9217,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9217,303,0.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9217,306,158,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9217,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9217,320,6,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9217,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9217,401,29.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9217,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9217,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9217,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9217,606,0.011,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9218,203,0.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9218,204,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9218,205,13.34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9218,207,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9218,208,53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9218,255,85.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9218,269,10.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9218,291,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9218,301,37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9218,303,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9218,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9218,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9218,320,34,'100g',1,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (9218,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9218,401,26.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9218,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9218,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9218,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9218,606,0.039,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9219,203,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9219,204,0.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9219,205,9.57,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9219,207,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9219,208,37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9219,255,89.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9219,269,8.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9219,291,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9219,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9219,303,0.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9219,306,133,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9219,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9219,320,43,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9219,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9219,401,34.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9219,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9219,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9219,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9219,606,0.003,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9220,203,0.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9220,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9220,205,16.19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9220,207,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9220,208,61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9220,255,83.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9220,269,15.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9220,291,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9220,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9220,303,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9220,306,78,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9220,307,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9220,320,42,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9220,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9220,401,19.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9220,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9220,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9220,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9220,606,0.012,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9221,203,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9221,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9221,205,10.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9221,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9221,208,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9221,255,88.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9221,269,9.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9221,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9221,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9221,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9221,306,178,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9221,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9221,320,13,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (9221,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9221,401,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9221,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9221,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9221,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9221,606,0.024,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9226,203,0.47,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9226,204,0.26,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9226,205,10.82,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9226,207,0.39,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9226,208,43,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9226,255,88.06,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9226,269,7.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9226,291,1.7,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9226,301,20,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9226,303,0.25,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9226,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9226,307,8,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9226,320,47,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (9226,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9226,401,60.9,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9226,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9226,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9226,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9226,606,0.081,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9228,203,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9228,204,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9228,205,55.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9228,207,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9228,208,206,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9228,255,43.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9228,269,52.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9228,291,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9228,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9228,303,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9228,306,67,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9228,307,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9228,320,0,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (9228,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9228,401,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9228,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9228,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9228,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9228,606,0.268,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9229,203,0.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9229,204,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9229,205,14.51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9229,207,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9229,208,57,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9229,255,85.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9229,269,13.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9229,291,0.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9229,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9229,303,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9229,306,31,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9229,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9229,320,18,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9229,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9229,401,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9229,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9229,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9229,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9229,606,0.047,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9231,203,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9231,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9231,205,23.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9231,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9231,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9231,255,72.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9231,269,11.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9231,291,10.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9231,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9231,303,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9231,306,348,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9231,307,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9231,320,64,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (9231,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9231,401,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9231,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9231,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9231,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9231,606,0.059,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9232,203,0.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9232,204,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9232,205,13.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9232,207,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9232,208,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9232,255,85.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9232,269,13.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9232,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9232,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9232,303,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9232,306,278,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9232,307,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9232,320,36,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9232,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9232,401,29.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9232,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9232,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9232,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9232,606,0.004,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9233,203,0.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9233,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9233,205,14.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9233,207,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9233,208,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9233,255,84.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9233,269,14.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9233,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9233,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9233,303,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9233,306,278,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9233,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9233,320,47,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (9233,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9233,401,18.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9233,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9233,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9233,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9233,606,0.015,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9236,203,0.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9236,204,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9236,205,9.54,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9236,207,0.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9236,208,39,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9236,255,88.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9236,269,8.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9236,291,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9236,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9236,303,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9236,306,190,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9236,307,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9236,320,16,'100g',1,1,'2024-12-12','2002-01-12');
INSERT INTO `cndb_nutval` VALUES (9236,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9236,401,6.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9236,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9236,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9236,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9236,606,0.019,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9237,203,0.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9237,204,0.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9237,205,6.11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9237,207,0.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9237,208,24,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9237,255,93.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9237,269,4.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9237,291,1.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9237,301,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9237,303,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9237,306,99,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9237,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9237,320,27,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9237,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9237,401,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9237,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9237,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9237,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9237,606,0.006,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9238,203,0.63,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9238,204,0.03,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9238,205,11.57,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9238,207,0.27,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9238,208,44,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9238,255,87.49,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9238,269,10.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9238,291,1.3,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9238,301,6,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9238,303,0.27,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9238,306,128,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9238,307,4,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9238,320,19,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9238,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9238,401,3.6,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9238,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9238,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9238,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9238,606,0.004,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9239,203,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9239,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9239,205,11.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9239,207,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9239,208,42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9239,255,88.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9239,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9239,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9239,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9239,303,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9239,306,74,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9239,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9239,320,14,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9239,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9239,401,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9239,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9239,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9239,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9239,606,0.011,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9240,203,0.45,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9240,204,0.03,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9240,205,14.55,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9240,207,0.25,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9240,208,54,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9240,255,84.72,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9240,269,13.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9240,291,1.3,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9240,301,3,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9240,303,0.36,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9240,306,97,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9240,307,5,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9240,320,18,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9240,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9240,401,2.4,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9240,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9240,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9240,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9240,606,0.003,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9241,203,0.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9241,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9241,205,19.94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9241,207,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9241,208,74,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9241,255,79.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9241,269,18.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9241,291,1.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9241,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9241,303,0.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9241,306,92,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9241,307,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9241,320,17,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9241,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9241,401,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9241,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9241,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9241,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9241,606,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9242,203,0.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9242,204,0.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9242,205,26.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9242,207,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9242,208,96,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9242,255,73.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9242,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9242,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9242,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9242,303,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9242,306,83,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9242,307,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9242,320,7,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9242,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9242,401,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9242,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9242,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9242,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9242,606,0.003,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9243,203,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9243,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9243,205,20.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9243,207,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9243,208,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9243,255,79.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9243,269,18.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9243,291,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9243,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9243,303,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9243,306,85,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9243,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9243,320,16,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9243,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9243,401,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9243,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9243,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9243,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9243,606,0.011,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9244,203,4.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9244,204,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9244,205,83.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9244,207,3.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9244,208,325,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9244,255,7.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9244,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9244,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9244,301,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9244,303,5.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9244,306,1351,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9244,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9244,320,71,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9244,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9244,401,10.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9244,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9244,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9244,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9244,606,0.111,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9245,203,2.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9245,204,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9245,205,34.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9245,207,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9245,208,133,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9245,255,62.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9245,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9245,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9245,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9245,303,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9245,306,554,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9245,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9245,320,20,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9245,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9245,401,6.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9245,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9245,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9245,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9245,606,0.045,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9246,203,3.61,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9246,204,0.76,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9246,205,61.33,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9246,207,2.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9246,208,239,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9246,255,31.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9246,269,41.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9246,291,8.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9246,301,28,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9246,303,4.06,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9246,306,996,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9246,307,7,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9246,320,108,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9246,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9246,401,4.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9246,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9246,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9246,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9246,606,0.082,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9247,203,1.16,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9247,204,0.25,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9247,205,19.69,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9247,207,0.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9247,208,77,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9247,255,78.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9247,269,16.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9247,291,2.7,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9247,301,9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9247,303,1.31,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9247,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9247,307,2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9247,320,10,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9247,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9247,401,3.7,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9247,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9247,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9247,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9247,606,0.026,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9248,203,1.06,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9248,204,0.22,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9248,205,26.6,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9248,207,0.73,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9248,208,103,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9248,255,71.38,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9248,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9248,291,2.4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9248,301,8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9248,303,1.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9248,306,292,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9248,307,2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9248,320,9,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9248,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9248,401,3.4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9248,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9248,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9248,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9248,606,0.024,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9250,203,0.63,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9250,204,0.13,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9250,205,23.98,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9250,207,0.53,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9250,208,94,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9250,255,74.73,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9250,269,22.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9250,291,1.8,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9250,301,3,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9250,303,0.37,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9250,306,130,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9250,307,6,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9250,320,14,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9250,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9250,401,94.2,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9250,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9250,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9250,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9250,606,0.014,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9251,203,0.1,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9251,204,0.57,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9251,205,11.61,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9251,207,0.07,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9251,208,49,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9251,255,87.65,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9251,269,12.08,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9251,291,0.1,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9251,301,6,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9251,303,0.07,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9251,306,30,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9251,307,11,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9251,320,16,'100g',2,1,'2024-12-12','2016-01-12');
INSERT INTO `cndb_nutval` VALUES (9251,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9251,401,0,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9251,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9251,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9251,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9251,606,0.037,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9252,203,0.36,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (9252,204,0.14,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (9252,205,15.23,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (9252,207,0.32,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (9252,208,57,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (9252,255,83.96,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (9252,269,9.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9252,291,3.1,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9252,301,9,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9252,303,0.18,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (9252,306,116,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9252,307,1,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9252,320,1,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (9252,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9252,401,4.3,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (9252,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9252,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9252,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9252,606,0.022,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9253,203,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9253,204,0.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9253,205,7.81,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9253,207,0.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9253,208,29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9253,255,91.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9253,269,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9253,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9253,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9253,303,0.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9253,306,53,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9253,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9253,320,0,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9253,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9253,401,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9253,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9253,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9253,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9253,606,0.002,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9254,203,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9254,204,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9254,205,12.94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9254,207,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9254,208,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9254,255,86.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9254,269,9.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9254,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9254,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9254,303,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9254,306,96,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9254,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9254,320,0,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9254,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9254,401,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9254,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9254,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9254,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9254,606,0.004,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9255,203,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9255,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9255,205,12.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9255,207,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9255,208,47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9255,255,87.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9255,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9255,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9255,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9255,303,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9255,306,45,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9255,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9255,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9255,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9255,401,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9255,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9255,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9255,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9255,606,0.006,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9256,203,0.19,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9256,204,0.03,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9256,205,15.17,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9256,207,0.14,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9256,208,57,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9256,255,84.46,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9256,269,12.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9256,291,1.6,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9256,301,5,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9256,303,0.28,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9256,306,66,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9256,307,5,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9256,320,0,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9256,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9256,401,0.7,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9256,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9256,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9256,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9256,606,0.002,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9257,203,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9257,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9257,205,19.17,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9257,207,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9257,208,74,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9257,255,80.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9257,269,15.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9257,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9257,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9257,303,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9257,306,65,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9257,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9257,320,0,'100g',1,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (9257,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9257,401,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9257,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9257,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9257,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9257,606,0.007,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9258,203,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9258,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9258,205,25.25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9258,207,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9258,208,97,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9258,255,74.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9258,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9258,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9258,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9258,303,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9258,306,64,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9258,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9258,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9258,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9258,401,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9258,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9258,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9258,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9258,606,0.007,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9259,203,1.87,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9259,204,0.63,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9259,205,69.7,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9259,207,1.11,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9259,208,262,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9259,255,26.69,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9259,269,62.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9259,291,7.5,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9259,301,34,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9259,303,2.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9259,306,533,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9259,307,6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9259,320,0,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9259,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9259,401,7,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9259,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9259,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9259,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9259,606,0.035,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9260,203,0.91,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9260,204,0.31,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9260,205,33.81,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9260,207,0.54,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9260,208,127,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9260,255,64.44,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9260,269,27.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9260,291,6.4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9260,301,16,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9260,303,1.02,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9260,306,258,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9260,307,3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9260,320,2,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9260,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9260,401,4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9260,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9260,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9260,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9260,606,0.017,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9261,203,0.86,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9261,204,0.29,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9261,205,37.14,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9261,207,0.51,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9261,208,140,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9261,255,61.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9261,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9261,291,5.8,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9261,301,15,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9261,303,0.97,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9261,306,245,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9261,307,3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9261,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9261,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9261,401,3.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9261,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9261,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9261,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9261,606,0.016,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9262,203,0.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9262,204,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9262,205,15.76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9262,207,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9262,208,60,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9262,255,84.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9262,269,15.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9262,291,0.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9262,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9262,303,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9262,306,13,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9262,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9262,320,0,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9262,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9262,401,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9262,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9262,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9262,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9262,606,0.001,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9263,203,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9263,204,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9263,205,18.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9263,207,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9263,208,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9263,255,80.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9263,269,12.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9263,291,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9263,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9263,303,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9263,306,161,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9263,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9263,320,81,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9263,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9263,401,7.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9263,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9263,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9263,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9263,606,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9266,203,0.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9266,204,0.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9266,205,13.12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9266,207,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9266,208,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9266,255,86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9266,269,9.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9266,291,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9266,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9266,303,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9266,306,109,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9266,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9266,320,3,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9266,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9266,401,47.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9266,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9266,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9266,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9266,606,0.009,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9267,203,0.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9267,204,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9267,205,8.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9267,207,0.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9267,208,32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9267,255,90.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9267,269,7.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9267,291,0.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9267,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9267,303,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9267,306,127,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9267,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9267,320,2,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9267,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9267,401,7.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9267,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9267,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9267,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9267,606,0.006,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9268,203,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9268,204,0.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9268,205,15.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9268,207,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9268,208,60,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9268,255,83.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9268,269,14.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9268,291,0.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9268,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9268,303,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9268,306,122,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9268,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9268,320,2,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9268,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9268,401,9.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9268,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9268,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9268,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9268,606,0.006,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9269,203,0.36,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9269,204,0.12,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9269,205,13.45,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9269,207,0.35,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9269,208,52,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9269,255,85.73,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9269,269,12.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9269,291,0.8,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9269,301,14,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9269,303,0.39,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9269,306,105,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9269,307,1,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9269,320,2,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9269,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9269,401,7.5,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9269,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9269,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9269,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9269,606,0.009,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9270,203,0.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9270,204,0.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9270,205,20.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9270,207,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9270,208,78,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9270,255,78.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9270,269,16.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9270,291,0.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9270,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9270,303,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9270,306,104,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9270,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9270,320,1,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9270,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9270,401,7.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9270,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9270,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9270,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9270,606,0.009,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9271,203,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9271,204,0.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9271,205,21.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9271,207,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9271,208,83,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9271,255,77.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9271,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9271,291,0.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9271,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9271,303,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9271,306,102,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9271,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9271,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9271,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9271,401,7.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9271,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9271,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9271,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9271,606,0.009,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9272,203,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9272,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9272,205,22.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9272,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9272,208,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9272,255,77.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9272,269,21.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9272,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9272,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9272,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9272,306,100,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9272,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9272,320,2,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9272,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9272,401,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9272,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9272,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9272,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9272,606,0.007,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9273,203,0.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9273,204,0.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9273,205,12.87,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9273,207,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9273,208,53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9273,255,86.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9273,269,9.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9273,291,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9273,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9273,303,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9273,306,130,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9273,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9273,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9273,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9273,401,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9273,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9273,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9273,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9273,606,0.008,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9274,203,1.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9274,204,0.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9274,205,44.3,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9274,207,1.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9274,208,179,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9274,255,53.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9274,269,43.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9274,291,0.7,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9274,301,39,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9274,303,0.9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9274,306,472,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9274,307,3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9274,320,3,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9274,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9274,401,42,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9274,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9274,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9274,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9274,606,0.007,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9275,203,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9275,204,0.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9275,205,12.67,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9275,207,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9275,208,51,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9275,255,86.6,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9275,269,12.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9275,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9275,301,13,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9275,303,0.16,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9275,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9275,307,1,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9275,320,1,'100g',2,1,'2024-12-12','2009-01-12');
INSERT INTO `cndb_nutval` VALUES (9275,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9275,401,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9275,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9275,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9275,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9275,606,0.002,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9277,203,1.3,'100g',7,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9277,204,0.35,'100g',7,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9277,205,31.89,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9277,207,1.15,'100g',7,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9277,208,122,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9277,255,65.2,'100g',7,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9277,269,17.51,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9277,291,1.7,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9277,301,3,'100g',7,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9277,303,0.55,'100g',7,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9277,306,487,'100g',7,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9277,307,4,'100g',7,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9277,320,56,'100g',2,1,'2024-12-12','2016-01-11');
INSERT INTO `cndb_nutval` VALUES (9277,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9277,401,18.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9277,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9277,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9277,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9277,606,0,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9278,203,1.52,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9278,204,0.16,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9278,205,41.37,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9278,207,1.09,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9278,208,155,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9278,255,55.87,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9278,269,21.33,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9278,291,2.2,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9278,301,3,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9278,303,0.28,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9278,306,477,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9278,307,2,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9278,320,45,'100g',2,1,'2024-12-12','2016-01-11');
INSERT INTO `cndb_nutval` VALUES (9278,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9278,401,16.4,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9278,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9278,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9278,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9278,606,0,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9279,203,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9279,204,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9279,205,11.42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9279,207,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9279,208,46,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9279,255,87.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9279,269,9.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9279,291,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9279,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9279,303,0.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9279,306,157,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9279,307,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9279,320,17,'100g',1,1,'2024-12-12','2002-01-12');
INSERT INTO `cndb_nutval` VALUES (9279,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9279,401,9.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9279,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9279,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9279,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9279,606,0.017,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9281,203,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9281,204,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9281,205,11.03,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9281,207,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9281,208,41,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9281,255,88.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9281,269,10.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9281,291,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9281,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9281,303,0.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9281,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9281,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9281,320,46,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9281,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9281,401,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9281,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9281,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9281,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9281,606,0.001,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9282,203,0.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9282,204,0.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9282,205,15.15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9282,207,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9282,208,58,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9282,255,84.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9282,269,14.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9282,291,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9282,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9282,303,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9282,306,154,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9282,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9282,320,50,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9282,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9282,401,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9282,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9282,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9282,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9282,606,0.002,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9283,203,0.37,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9283,204,0.1,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9283,205,16.28,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9283,207,0.25,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9283,208,63,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9283,255,83,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9283,269,15.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9283,291,0.9,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9283,301,9,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9283,303,0.86,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9283,306,93,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9283,307,20,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9283,320,12,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9283,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9283,401,0.4,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9283,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9283,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9283,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9283,606,0.008,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9284,203,0.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9284,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9284,205,23.24,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9284,207,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9284,208,89,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9284,255,76.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9284,269,22.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9284,291,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9284,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9284,303,0.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9284,306,91,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9284,307,19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9284,320,13,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9284,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9284,401,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9284,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9284,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9284,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9284,606,0.008,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9285,203,0.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9285,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9285,205,26.31,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9285,207,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9285,208,101,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9285,255,73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9285,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9285,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9285,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9285,303,0.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9285,306,89,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9285,307,19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9285,320,13,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9285,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9285,401,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9285,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9285,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9285,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9285,606,0.008,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9286,203,1.67,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9286,204,1.17,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9286,205,18.7,'100g',3,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9286,207,0.53,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9286,208,83,'100g',3,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9286,255,77.93,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9286,269,13.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9286,291,4,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9286,301,10,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9286,303,0.3,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9286,306,236,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9286,307,3,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9286,320,0,'100g',2,1,'2024-12-12','2008-01-06');
INSERT INTO `cndb_nutval` VALUES (9286,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9286,401,10.2,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9286,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9286,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9286,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9286,606,0.12,'100g',1,1,'1996-09-30','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9287,203,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9287,204,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9287,205,9.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9287,207,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9287,208,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9287,255,87.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9287,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9287,291,3.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9287,301,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9287,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9287,306,220,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9287,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9287,320,2,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (9287,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9287,401,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9287,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9287,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9287,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9287,606,0.067,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9288,203,0.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9288,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9288,205,27.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9288,207,0.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9288,208,105,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9288,255,70.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9288,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9288,291,3.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9288,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9288,303,0.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9288,306,226,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9288,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9288,320,40,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9288,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9288,401,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9288,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9288,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9288,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9288,606,0.016,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9289,203,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9289,204,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9289,205,89.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9289,207,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9289,208,339,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9289,255,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9289,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9289,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9289,301,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9289,303,3.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9289,306,1058,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9289,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9289,320,88,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9289,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9289,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9289,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9289,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9289,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9289,606,0.059,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9290,203,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9290,204,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9290,205,29.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9290,207,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9290,208,113,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9290,255,67.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9290,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9290,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9290,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9290,303,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9290,306,353,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9290,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9290,320,26,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9290,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9290,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9290,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9290,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9290,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9290,606,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9291,203,2.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9291,204,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9291,205,63.88,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9291,207,2.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9291,208,240,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9291,255,30.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9291,269,38.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9291,291,7.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9291,301,43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9291,303,0.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9291,306,732,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9291,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9291,320,39,'100g',1,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (9291,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9291,401,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9291,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9291,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9291,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9291,606,0.088,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9292,203,0.96,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9292,204,0.16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9292,205,28.08,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9292,207,1.16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9292,208,107,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9292,255,69.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9292,269,24.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9292,291,3.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9292,301,19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9292,303,0.41,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9292,306,321,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9292,307,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9292,320,17,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9292,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9292,401,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9292,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9292,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9292,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9292,606,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9293,203,1.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9293,204,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9293,205,32.88,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9293,207,0.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9293,208,124,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9293,255,65.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9293,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9293,291,3.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9293,301,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9293,303,1.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9293,306,312,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9293,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9293,320,14,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9293,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9293,401,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9293,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9293,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9293,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9293,606,0.017,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9294,203,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9294,204,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9294,205,17.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9294,207,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9294,208,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9294,255,81.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9294,269,16.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9294,291,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9294,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9294,303,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9294,306,276,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9294,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9294,320,0,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9294,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9294,401,4.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9294,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9294,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9294,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9294,606,0.003,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9296,203,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9296,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9296,205,15.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9296,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9296,208,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9296,255,83.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9296,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9296,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9296,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9296,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9296,306,197,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9296,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9296,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9296,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9296,401,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9296,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9296,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9296,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9296,606,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9297,203,3.28,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9297,204,0.2,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9297,205,80.02,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9297,207,1.61,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9297,208,301,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9297,255,14.9,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9297,269,65.7,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9297,291,3.3,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9297,301,64,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9297,303,0.98,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9297,306,746,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9297,307,24,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9297,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9297,328,0,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9297,401,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9297,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9297,601,0,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9297,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9297,606,0.065,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9298,203,3.3,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9298,204,0.25,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9298,205,79.32,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9298,207,1.68,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9298,208,299,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9298,255,15.46,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9298,269,65.18,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9298,291,4.5,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9298,301,62,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9298,303,1.79,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9298,306,744,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9298,307,26,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9298,320,0,'100g',1,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (9298,328,0,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9298,401,2.3,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9298,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9298,601,0,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9298,605,0.001,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9298,606,0.094,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9299,203,2.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9299,204,0.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9299,205,78.47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9299,207,1.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9299,208,296,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9299,255,16.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9299,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9299,291,6.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9299,301,28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9299,303,2.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9299,306,825,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9299,307,28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9299,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9299,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9299,401,5.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9299,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9299,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9299,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9299,606,0.178,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9302,203,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9302,204,0.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9302,205,11.94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9302,207,0.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9302,208,52,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9302,255,85.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9302,269,4.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9302,291,6.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9302,301,25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9302,303,0.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9302,306,151,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9302,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9302,320,2,'100g',1,1,'2024-12-12','2002-01-12');
INSERT INTO `cndb_nutval` VALUES (9302,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9302,401,26.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9302,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9302,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9302,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9302,606,0.019,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9304,203,0.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9304,204,0.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9304,205,23.36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9304,207,0.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9304,208,91,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9304,255,75.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9304,269,20.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9304,291,3.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9304,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9304,303,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9304,306,94,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9304,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9304,320,2,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9304,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9304,401,8.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9304,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9304,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9304,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9304,606,0.005,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9306,203,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9306,204,0.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9306,205,26.16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9306,207,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9306,208,103,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9306,255,72.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9306,269,21.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9306,291,4.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9306,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9306,303,0.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9306,306,114,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9306,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9306,320,3,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9306,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9306,401,16.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9306,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9306,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9306,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9306,606,0.005,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9307,203,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9307,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9307,205,4.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9307,207,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9307,208,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9307,255,93.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9307,269,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9307,291,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9307,301,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9307,303,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9307,306,288,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9307,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9307,320,5,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (9307,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9307,401,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9307,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9307,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9307,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9307,606,0.053,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9309,203,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9309,204,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9309,205,5.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9309,207,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9309,208,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9309,255,93.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9309,269,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9309,291,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9309,301,194,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9309,303,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9309,306,108,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9309,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9309,320,5,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9309,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9309,401,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9309,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9309,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9309,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9309,606,0.029,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9310,203,0.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9310,204,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9310,205,31.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9310,207,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9310,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9310,255,67.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9310,269,28.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9310,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9310,301,145,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9310,303,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9310,306,96,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9310,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9310,320,4,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9310,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9310,401,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9310,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9310,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9310,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9310,606,0.014,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9313,203,0.44,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9313,204,1.1,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9313,205,19.96,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9313,207,0.5,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9313,208,83,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9313,255,78,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9313,269,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9313,291,5.3,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9313,301,21,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9313,303,0.8,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9313,306,193,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9313,307,12,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9313,320,3,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9313,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9313,401,14.7,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9313,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9313,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9313,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9313,606,0.194,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9314,203,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9314,204,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9314,205,32.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9314,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9314,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9314,255,64.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9314,269,20.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9314,291,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9314,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9314,303,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9314,306,454,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9314,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9314,320,7,'100g',1,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (9314,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9314,401,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9314,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9314,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9314,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9314,606,0.169,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9315,203,1,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9315,204,0.3,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9315,205,16.84,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9315,207,0.7,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9315,208,66,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9315,255,81.16,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9315,269,13.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9315,291,3.3,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9315,301,14,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9315,303,0.6,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9315,306,278,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9315,307,14,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9315,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9315,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9315,401,20.6,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9315,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9315,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9315,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9315,606,0.051,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9316,203,0.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9316,204,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9316,205,7.68,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9316,207,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9316,208,32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9316,255,90.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9316,269,4.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9316,291,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9316,301,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9316,303,0.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9316,306,153,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9316,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9316,320,1,'100g',1,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (9316,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9316,401,58.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9316,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9316,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9316,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9316,606,0.015,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9317,203,0.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9317,204,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9317,205,23.53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9317,207,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9317,208,92,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9317,255,75.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9317,269,21.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9317,291,1.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9317,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9317,303,0.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9317,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9317,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9317,320,1,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9317,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9317,401,31.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9317,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9317,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9317,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9317,606,0.014,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9318,203,0.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9318,204,0.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9318,205,9.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9318,207,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9318,208,35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9318,255,89.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9318,269,4.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9318,291,2.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9318,301,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9318,303,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9318,306,148,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9318,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9318,320,2,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9318,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9318,401,41.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9318,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9318,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9318,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9318,606,0.006,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9320,203,0.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9320,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9320,205,25.92,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9320,207,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9320,208,96,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9320,255,73.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9320,269,24.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9320,291,1.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9320,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9320,303,0.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9320,306,98,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9320,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9320,320,1,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9320,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9320,401,41.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9320,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9320,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9320,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9320,606,0.007,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9321,203,2.06,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9321,204,0.29,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9321,205,23.64,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9321,207,0.78,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9321,208,94,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9321,255,73.23,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9321,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9321,291,4.4,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9321,301,24,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9321,303,0.6,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9321,306,247,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9321,307,9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9321,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9321,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9321,401,36.3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9321,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9321,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9321,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9321,606,0.048,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9322,203,2.8,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9322,204,0.6,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9322,205,62.5,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9322,207,2.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9322,208,239,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9322,255,31.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9322,269,38.8,'100g',7,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9322,291,5.1,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9322,301,74,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9322,303,2.8,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9322,306,628,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9322,307,28,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9322,320,2,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (9322,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9322,401,3.5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9322,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9322,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9322,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9322,606,0.272,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9325,203,0.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9325,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9325,205,22.36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9325,207,0.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9325,208,86,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9325,255,76.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9325,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9325,291,1.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9325,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9325,303,0.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9325,306,131,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9325,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9325,320,6,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9325,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9325,401,17.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9325,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9325,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9325,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9325,606,0.019,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9326,203,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9326,204,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9326,205,7.55,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9326,207,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9326,208,30,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9326,255,91.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9326,269,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9326,291,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9326,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9326,303,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9326,306,112,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9326,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9326,320,28,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (9326,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9326,401,8.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9326,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9326,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9326,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9326,606,0.016,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9328,203,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9328,204,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9328,205,41.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9328,207,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9328,208,165,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9328,255,57.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9328,269,38.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9328,291,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9328,301,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9328,303,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9328,306,21,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9328,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9328,320,2,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (9328,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9328,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9328,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9328,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9328,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9328,606,0.039,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9334,203,0.71,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9334,204,0.42,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9334,205,15.21,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9334,207,0.38,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9334,208,61,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9334,255,83.28,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9334,269,8.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9334,291,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9334,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9334,303,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9334,306,172,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9334,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9334,320,0,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (9334,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9334,401,32.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9334,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9334,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9334,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9334,606,0.104,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9340,203,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9340,204,0.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9340,205,10.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9340,207,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9340,208,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9340,255,88.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9340,269,7.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9340,291,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9340,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9340,303,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9340,306,121,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9340,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9340,320,0,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9340,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9340,401,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9340,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9340,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9340,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9340,606,0.012,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9351,203,0.47,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9351,204,0.1,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9351,205,18.8,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9351,207,0.24,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9351,208,70,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9351,255,80.4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9351,269,17.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9351,291,1.7,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9351,301,7,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9351,303,0.29,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9351,306,90,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9351,307,6,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9351,320,14,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (9351,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9351,401,1.9,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9351,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9351,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9351,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9351,606,0.014,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9352,203,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9352,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9352,205,22.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9352,207,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9352,208,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9352,255,75.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9352,269,17.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9352,291,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9352,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9352,303,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9352,306,54,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9352,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9352,320,2,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (9352,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9352,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9352,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9352,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9352,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9352,606,0.028,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9354,203,0.51,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9354,204,0.11,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9354,205,15.56,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9354,207,0.31,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9354,208,60,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9354,255,83.51,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9354,269,14.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9354,291,1.3,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9354,301,16,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9354,303,0.28,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9354,306,124,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9354,307,1,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9354,320,3,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9354,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9354,401,9.4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9354,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9354,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9354,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9354,606,0.008,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9357,203,0.64,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9357,204,0.11,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9357,205,21.31,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9357,207,0.38,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9357,208,83,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9357,255,77.56,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9357,269,18.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9357,291,2.7,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9357,301,10,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9357,303,0.3,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9357,306,143,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9357,307,4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9357,320,146,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (9357,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9357,401,3.1,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9357,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9357,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9357,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9357,606,0.007,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9367,203,0.73,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9367,204,0.21,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9367,205,21.07,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9367,207,0.39,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9367,208,83,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9367,255,77.61,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9367,269,16.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9367,291,2.3,'100g',3,1,'1994-11-14','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9367,301,10,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9367,303,0.35,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9367,306,148,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9367,307,3,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9367,320,12,'100g',2,1,'2024-12-12','2008-01-06');
INSERT INTO `cndb_nutval` VALUES (9367,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9367,401,3.6,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9367,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9367,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9367,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9367,606,0.041,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9370,203,0.52,'100g',1,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9370,204,0.18,'100g',1,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9370,205,18.43,'100g',3,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9370,207,0.26,'100g',1,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9370,208,72,'100g',3,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9370,255,80.62,'100g',1,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9370,269,14.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9370,291,1.2,'100g',1,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9370,301,3,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9370,303,0.27,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9370,306,94,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9370,307,6,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9370,320,31,'100g',1,1,'2024-12-12','2009-01-11');
INSERT INTO `cndb_nutval` VALUES (9370,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9370,401,0.7,'100g',1,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9370,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9370,601,0,'100g',4,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (9370,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9370,606,0.013,'100g',3,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9374,203,0.24,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9374,204,0.18,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9374,205,19.08,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9374,207,0.15,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9374,208,74,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9374,255,80.35,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9374,269,16.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9374,291,2.7,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9374,301,6,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9374,303,0.22,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9374,306,66,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9374,307,5,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9374,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9374,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9374,401,1.1,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9374,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9374,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9374,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9374,606,0.01,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9379,203,0.44,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9379,204,0.14,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9379,205,23.12,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9379,207,0.25,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9379,208,89,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9379,255,76.06,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9379,269,21.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9379,291,1.5,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9379,301,10,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9379,303,0.84,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9379,306,93,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9379,307,19,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9379,320,20,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9379,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9379,401,0.4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9379,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9379,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9379,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9379,606,0.011,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9383,203,0.75,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9383,204,0.04,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9383,205,9.41,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9383,207,0.29,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9383,208,38,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9383,255,89.51,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9383,269,8.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9383,291,1.2,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9383,301,12,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9383,303,0.27,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9383,306,136,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9383,307,5,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9383,320,66,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9383,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9383,401,33.9,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9383,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9383,601,0,'100g',4,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9383,605,0,'100g',NULL,1,'1995-06-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9383,606,0.004,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9400,203,0.1,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9400,204,0.13,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9400,205,11.3,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9400,207,0.23,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9400,208,46,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9400,255,88.24,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9400,269,9.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9400,291,0.2,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9400,301,8,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9400,303,0.12,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9400,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9400,307,4,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9400,320,0,'100g',2,1,'2024-12-12','2008-01-05');
INSERT INTO `cndb_nutval` VALUES (9400,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9400,401,38.5,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9400,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9400,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9400,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9400,606,0.022,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (9401,203,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9401,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9401,205,11.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9401,207,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9401,208,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9401,255,88.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9401,269,9.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9401,291,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9401,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9401,303,0.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9401,306,74,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9401,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9401,320,1,'100g',1,1,'2024-12-12','2008-01-08');
INSERT INTO `cndb_nutval` VALUES (9401,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9401,401,21.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9401,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9401,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9401,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9401,606,0.008,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9402,203,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9402,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9402,205,19.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9402,207,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9402,208,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9402,255,79.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9402,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9402,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9402,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9402,303,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9402,306,61,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9402,307,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9402,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9402,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9402,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9402,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9402,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9402,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9402,606,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9404,203,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9404,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9404,205,9.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9404,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9404,208,39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9404,255,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9404,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9404,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9404,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9404,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9404,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9404,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9404,320,22,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9404,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9404,401,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9404,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9404,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9404,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9404,606,0.014,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9407,203,0.21,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9407,204,0.51,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9407,205,11.93,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9407,207,0.08,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9407,208,50,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9407,255,87.28,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9407,269,11.16,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9407,291,0.1,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9407,301,6,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9407,303,0.07,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9407,306,50,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9407,307,8,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9407,320,28,'100g',1,1,'2024-12-12','2016-01-12');
INSERT INTO `cndb_nutval` VALUES (9407,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9407,401,30.2,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9407,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9407,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9407,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9407,606,0.224,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9408,203,0.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9408,204,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9408,205,15.76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9408,207,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9408,208,60,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9408,255,84.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9408,269,15.16,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9408,291,0.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9408,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9408,303,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9408,306,13,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9408,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9408,320,0,'100g',1,1,'2024-12-12','2006-01-02');
INSERT INTO `cndb_nutval` VALUES (9408,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9408,401,27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9408,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9408,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9408,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9408,606,0.001,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9409,203,0.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9409,204,0.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9409,205,12.87,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9409,207,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9409,208,53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9409,255,86.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9409,269,9.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9409,291,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9409,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9409,303,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9409,306,130,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9409,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9409,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9409,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9409,401,43.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9409,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9409,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9409,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9409,606,0.008,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9410,203,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9410,204,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9410,205,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9410,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9410,208,166,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9410,255,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9410,269,38.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9410,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9410,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9410,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9410,306,448,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9410,307,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9410,320,0,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (9410,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9410,401,88.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9410,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9410,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9410,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9410,606,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9411,203,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9411,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9411,205,11.54,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9411,207,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9411,208,47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9411,255,87.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9411,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (9411,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9411,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9411,303,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9411,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9411,307,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9411,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9411,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9411,401,25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9411,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9411,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9411,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9411,606,0.018,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9423,203,2.1,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9423,204,0.2,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9423,205,65.1,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9423,207,2.6,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9423,208,257,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9423,255,30,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9423,269,39,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9423,291,3.3,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9423,301,31,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9423,303,2.8,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9423,306,852,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9423,307,23,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9423,320,100,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9423,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9423,401,4.3,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9423,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9423,601,0,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9423,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9423,606,0.016,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (9426,203,0.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9426,204,0.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9426,205,82.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9426,207,0.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9426,208,322,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9426,255,16.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9426,269,80.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9426,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9426,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9426,303,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9426,306,56,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9426,307,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9426,320,1,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (9426,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9426,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9426,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9426,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9426,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9426,606,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9427,203,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9427,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9427,205,17.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9427,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9427,208,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9427,255,79.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9427,269,8.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9427,291,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9427,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9427,303,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9427,306,304,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9427,307,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9427,320,5,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9427,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9427,401,54.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9427,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9427,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9427,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9427,606,0.014,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9428,203,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9428,204,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9428,205,23.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9428,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9428,208,111,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9428,255,71.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9428,269,14.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9428,291,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9428,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9428,303,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9428,306,131,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9428,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9428,320,19,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (9428,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9428,401,25.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9428,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9428,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9428,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9428,606,0.245,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9434,203,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9434,204,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9434,205,14.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9434,207,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9434,208,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9434,255,84.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9434,269,13.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9434,291,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9434,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9434,303,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9434,306,25,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9434,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9434,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (9434,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9434,401,11.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9434,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9434,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9434,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9434,606,0.029,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9435,203,0.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9435,204,0.06,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9435,205,16.25,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9435,207,0.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9435,208,63,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9435,255,83.51,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9435,269,12.95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9435,291,1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9435,301,8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9435,303,0.38,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9435,306,39,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9435,307,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9435,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (9435,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9435,401,21.1,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9435,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9435,601,0,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9435,605,0,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9435,606,0.02,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9436,203,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9436,204,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9436,205,13.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9436,207,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9436,208,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9436,255,86.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9436,269,12.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9436,291,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9436,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9436,303,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9436,306,24,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9436,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9436,320,35,'100g',1,1,'2024-12-12','2006-01-06');
INSERT INTO `cndb_nutval` VALUES (9436,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9436,401,15.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9436,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9436,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9436,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9436,606,0.014,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9442,203,0.15,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9442,204,0.29,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9442,205,13.13,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9442,207,0.49,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9442,208,54,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9442,255,85.95,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9442,269,12.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9442,291,0.1,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9442,301,11,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9442,303,0.1,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9442,306,214,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9442,307,9,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9442,320,0,'100g',1,1,'2024-12-12','2008-01-06');
INSERT INTO `cndb_nutval` VALUES (9442,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9442,401,0.1,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9442,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9442,601,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9442,605,0,'100g',NULL,1,'2009-01-25','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9442,606,0.077,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (9443,203,0.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9443,204,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9443,205,12.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9443,207,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9443,208,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9443,255,87.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9443,269,10.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9443,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9443,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9443,303,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9443,306,96,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9443,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9443,320,0,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (9443,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9443,401,28.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9443,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9443,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9443,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9443,606,0.023,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9444,203,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9444,204,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9444,205,12.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9444,207,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9444,208,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9444,255,86.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9444,269,9.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9444,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9444,301,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9444,303,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9444,306,89,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9444,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9444,320,0,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (9444,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9444,401,50.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9444,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9444,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9444,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9444,606,0.021,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9446,203,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9446,204,11.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9446,205,49.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9446,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9446,208,309,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9446,255,36.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9446,269,3.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9446,291,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9446,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9446,303,0.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9446,306,482,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9446,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9446,320,60,'100g',1,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (9446,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9446,401,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9446,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9446,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9446,605,0.159,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (9446,606,3.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9447,203,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9447,204,7.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9447,205,40.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9447,207,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9447,208,236,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9447,255,49.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9447,269,21.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9447,291,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9447,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9447,303,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9447,306,507,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9447,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9447,320,66,'100g',1,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (9447,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9447,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9447,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9447,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9447,605,0.111,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9447,606,1.816,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (9452,203,0.41,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (9452,204,0.08,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (9452,205,12.2,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (9452,207,0.35,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (9452,208,51,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (9452,255,87.24,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (9452,269,10.57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (9452,291,0.2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (9452,301,8,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (9452,303,0.18,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (9452,306,150,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9452,307,4,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (9452,320,1,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (9452,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9452,401,40.7,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (9452,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9452,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (9452,605,0,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9452,606,0.011,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (9506,203,0.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9506,204,0.12,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9506,205,11.54,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9506,207,0.43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9506,208,49,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9506,255,87.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9506,269,8.31,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9506,291,0.3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9506,301,146,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9506,303,0.13,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9506,306,178,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9506,307,2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9506,320,114,'100g',2,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (9506,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9506,401,33.6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9506,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9506,601,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9506,605,0,'100g',NULL,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9506,606,0.014,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9512,203,0.37,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9512,204,0.13,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9512,205,14.77,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9512,207,0.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9512,208,62,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9512,255,84.51,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9512,269,14.2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9512,291,0.2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9512,301,42,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9512,303,0.25,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9512,306,104,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9512,307,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9512,320,0,'100g',2,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (9512,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9512,401,25,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9512,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9512,601,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9512,605,0,'100g',NULL,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (9512,606,0.025,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (9517,203,0.12,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9517,204,0.17,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9517,205,11.49,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9517,207,0.31,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9517,208,48,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9517,255,87.92,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9517,269,9.47,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9517,291,0.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9517,301,70,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9517,303,0.13,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9517,306,184,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9517,307,5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9517,320,0,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (9517,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9517,401,30.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9517,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9517,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9517,605,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9517,606,0.029,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9518,203,1.15,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,204,0.81,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,205,12.55,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,207,0.48,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,208,56,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,255,85.01,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,269,6.54,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,291,4.3,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,301,24,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,303,0.76,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,306,184,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,307,4,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,320,4,'100g',1,1,'2024-12-12','2016-01-12');
INSERT INTO `cndb_nutval` VALUES (9518,328,0,'100g',4,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,401,17.6,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9518,601,0,'100g',4,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,605,0,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9518,606,0.064,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9519,203,0.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9519,204,0.07,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9519,205,13.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9519,207,0.09,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9519,208,48,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9519,255,86.23,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9519,269,10.15,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9519,291,1.2,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9519,301,8,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9519,303,0.54,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9519,306,33,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9519,307,6,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9519,320,2,'100g',2,1,'2024-12-12','2014-01-12');
INSERT INTO `cndb_nutval` VALUES (9519,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9519,401,21.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9519,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9519,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9519,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9519,606,0.023,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9522,203,0.27,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9522,204,0.12,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9522,205,10.91,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9522,207,0.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9522,208,45,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9522,255,88.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9522,269,9.8,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9522,291,0.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9522,301,19,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9522,303,0.08,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9522,306,76,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9522,307,6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9522,320,1,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (9522,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (9522,401,31.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9522,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9522,601,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9522,605,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9522,606,0.002,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (9542,203,1.25,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,204,0.07,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,205,36.66,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,207,0.92,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,208,152,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,255,61.1,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,269,2.29,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,291,2.2,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,301,2,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,303,0.75,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,306,431,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,307,2,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (9542,328,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,401,20.2,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9542,601,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,605,0.002,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9542,606,0.121,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,203,1.09,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,204,0.08,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,205,29.15,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,207,0.6,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,208,121,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,255,69.08,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,269,2.25,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,291,2.6,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,301,3,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,303,0.3,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,306,289,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,307,2,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (9543,328,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,401,9.1,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9543,601,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,605,0.001,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9543,606,0.072,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,203,3.69,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,204,0.47,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,205,79.65,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,207,5.28,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,208,250,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,255,10.92,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,269,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,291,44.5,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,301,342,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,303,8.42,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,306,2189,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,307,10,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (9544,328,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,401,173.2,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (9544,601,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,605,0.009,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9544,606,0.244,'100g',6,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,203,1.02,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,204,0.87,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,205,7.99,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,207,0.42,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,208,41,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,255,89.7,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,269,6.04,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,291,0.9,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,301,14,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,303,1.08,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,306,169,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,307,4,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,320,2,'100g',1,1,'2024-12-12','2016-01-12');
INSERT INTO `cndb_nutval` VALUES (9552,328,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,401,6.4,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9552,601,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,605,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9552,606,0.064,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,203,1.1,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,204,0.97,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,205,11.51,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,207,0.54,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,208,55,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,255,85.88,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,269,6.56,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,291,4.3,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,301,23,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,303,0.69,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,306,195,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,307,4,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,320,5,'100g',1,1,'2024-12-12','2016-01-12');
INSERT INTO `cndb_nutval` VALUES (9553,328,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,401,14.6,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9553,601,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,605,0,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9553,606,0.062,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,203,3.04,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,204,1.34,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,205,53.19,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,207,1.29,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,208,221,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,255,41.15,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,269,38.21,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,291,1.1,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,301,97,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,303,1.16,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,306,1178,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,307,10,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,320,0,'100g',1,1,'2024-12-12','2016-01-12');
INSERT INTO `cndb_nutval` VALUES (9554,328,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,401,38.1,'100g',1,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (9554,601,NULL,'100g',NULL,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,605,0,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (9554,606,0.056,'100g',3,1,'2019-02-13','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10000,203,10.06,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10000,204,60.42,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10000,205,0.32,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10000,207,0.93,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10000,208,585,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10000,255,28.28,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10000,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10000,291,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10000,301,36,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10000,303,0.82,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10000,306,214,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10000,307,125,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10000,320,0,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (10000,328,1.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10000,401,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10000,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10000,601,81,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10000,605,0.656,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10000,606,21.382,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10001,203,13.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10001,204,35.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10001,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10001,207,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10001,208,376,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10001,255,49.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10001,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10001,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10001,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10001,303,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10001,306,253,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10001,307,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10001,320,2,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (10001,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10001,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10001,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10001,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10001,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10001,606,12.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10002,203,21.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10002,204,4.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10002,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10002,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10002,208,134,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10002,255,73.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10002,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10002,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10002,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10002,303,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10002,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10002,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10002,320,1,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10002,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10002,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10002,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10002,601,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10002,605,0.024,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10002,606,1.625,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10003,203,18.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10003,204,14.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10003,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10003,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10003,208,211,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10003,255,65.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10003,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10003,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10003,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10003,303,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10003,306,319,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10003,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10003,320,1,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10003,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10003,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10003,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10003,601,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10003,605,0.034,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10003,606,4.918,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10004,203,2.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10004,204,88.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10004,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10004,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10004,208,812,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10004,255,7.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10004,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10004,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10004,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10004,303,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10004,306,65,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10004,307,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10004,320,5,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (10004,328,3.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10004,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10004,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10004,601,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10004,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10004,606,32.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10005,203,9.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10005,204,53.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10005,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10005,207,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10005,208,518,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10005,255,36.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10005,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10005,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10005,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10005,303,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10005,306,185,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10005,307,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10005,320,3,'100g',1,1,'2024-12-12','2004-01-07');
INSERT INTO `cndb_nutval` VALUES (10005,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10005,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10005,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10005,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10005,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10005,606,19.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10006,203,9.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10006,204,65.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10006,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10006,207,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10006,208,632,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10006,255,24.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10006,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10006,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10006,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10006,303,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10006,306,333,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10006,307,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10006,320,26,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10006,328,1.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10006,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10006,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10006,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10006,605,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10006,606,21.979,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10007,203,7.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10007,204,66.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10007,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10007,207,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10007,208,626,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10007,255,26.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10007,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10007,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10007,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10007,303,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10007,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10007,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10007,320,24,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10007,328,1.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10007,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10007,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10007,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10007,605,0.475,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10007,606,23.856,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10008,203,17.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10008,204,18.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10008,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10008,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10008,208,245,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10008,255,62.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10008,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10008,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10008,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10008,303,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10008,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10008,307,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10008,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10008,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10008,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10008,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10008,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10008,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10008,606,6.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10009,203,26.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10009,204,17.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10009,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10009,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10009,208,273,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10009,255,55.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10009,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10009,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10009,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10009,303,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10009,306,352,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10009,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10009,320,3,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10009,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10009,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10009,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10009,601,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10009,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10009,606,6.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10010,203,20.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10010,204,5.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10010,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10010,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10010,208,136,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10010,255,72.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10010,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10010,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10010,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10010,303,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10010,306,369,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10010,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10010,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10010,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10010,401,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10010,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10010,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10010,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10010,606,1.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10011,203,29.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10011,204,9.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10011,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10011,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10011,208,211,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10011,255,60.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10011,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10011,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10011,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10011,303,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10011,306,373,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10011,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10011,320,3,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10011,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10011,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10011,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10011,601,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10011,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10011,606,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10012,203,20.27,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10012,204,10.63,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10012,205,0,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10012,207,1.05,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10012,208,182,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10012,255,68.64,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10012,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10012,291,0,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10012,301,12,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10012,303,0.62,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10012,306,356,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10012,307,73,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10012,320,5,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (10012,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10012,401,0,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10012,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10012,601,63,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10012,605,0.091,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10012,606,3.526,'100g',3,1,'1996-09-30','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10013,203,27.03,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10013,204,10.32,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10013,205,0,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10013,207,1.17,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10013,208,209,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10013,255,61.92,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10013,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10013,291,0,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10013,301,16,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10013,303,0.9,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10013,306,416,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10013,307,77,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10013,320,3,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10013,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10013,401,0,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10013,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10013,601,85,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10013,605,0.087,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10013,606,3.369,'100g',3,1,'1996-09-30','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10014,203,21.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10014,204,2.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10014,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10014,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10014,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10014,255,74.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10014,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10014,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10014,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10014,303,0.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10014,306,359,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10014,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10014,320,2,'100g',2,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10014,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10014,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10014,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10014,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10014,605,0.019,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10014,606,0.947,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10015,203,28.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10015,204,4.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10015,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10015,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10015,208,165,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10015,255,65.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10015,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10015,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10015,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10015,303,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10015,306,425,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10015,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10015,320,1,'100g',2,1,'2024-12-12','2011-01-01');
INSERT INTO `cndb_nutval` VALUES (10015,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10015,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10015,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10015,601,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10015,605,0.034,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10015,606,1.451,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10016,203,19.87,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10016,204,11.96,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10016,205,0,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10016,207,1.03,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10016,208,193,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10016,255,67.69,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10016,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10016,291,0,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10016,301,12,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10016,303,0.69,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10016,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10016,307,84,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10016,320,6,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10016,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10016,401,0,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10016,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10016,601,67,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10016,605,0.095,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10016,606,3.942,'100g',3,1,'1996-09-30','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10017,203,25.96,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10017,204,13.42,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10017,205,0,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10017,207,1.1,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10017,208,232,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10017,255,60.37,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10017,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10017,291,0,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10017,301,15,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10017,303,0.87,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10017,306,345,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10017,307,81,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10017,320,4,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10017,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10017,401,0,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10017,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10017,601,91,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10017,605,0.093,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10017,606,4.609,'100g',3,1,'1996-09-30','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10018,203,21.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10018,204,2.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10018,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10018,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10018,208,119,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10018,255,74.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10018,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10018,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10018,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10018,303,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10018,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10018,307,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10018,320,3,'100g',2,1,'2024-12-12','2011-01-01');
INSERT INTO `cndb_nutval` VALUES (10018,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10018,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10018,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10018,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10018,605,0.011,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10018,606,0.917,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10019,203,28.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10019,204,5.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10019,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10019,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10019,208,175,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10019,255,65.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10019,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10019,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10019,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10019,303,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10019,306,376,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10019,307,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10019,320,1,'100g',2,1,'2024-12-12','2011-01-01');
INSERT INTO `cndb_nutval` VALUES (10019,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10019,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10019,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10019,601,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10019,605,0.038,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10019,606,1.837,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10020,203,19.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10020,204,12.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10020,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10020,207,0.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10020,208,198,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10020,255,66.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10020,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10020,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10020,301,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10020,303,0.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10020,306,356,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10020,307,50,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10020,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10020,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10020,401,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10020,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10020,601,63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10020,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10020,606,4.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10021,203,27.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10021,204,13.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10021,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10021,207,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10021,208,239,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10021,255,58.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10021,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10021,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10021,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10021,303,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10021,306,374,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10021,307,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10021,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10021,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10021,401,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10021,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10021,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10021,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10021,606,5.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10022,203,27.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10022,204,13.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10022,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10022,207,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10022,208,242,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10022,255,57.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10022,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10022,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10022,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10022,303,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10022,306,423,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10022,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10022,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10022,328,1.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10022,401,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10022,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10022,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10022,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10022,606,5.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10023,203,27.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10023,204,14.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10023,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10023,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10023,208,248,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10023,255,57.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10023,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10023,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10023,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10023,303,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10023,306,408,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10023,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10023,320,3,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10023,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10023,401,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10023,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10023,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10023,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10023,606,5.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10024,203,21.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10024,204,5.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10024,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10024,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10024,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10024,255,72.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10024,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10024,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10024,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10024,303,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10024,306,389,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10024,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10024,320,2,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (10024,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10024,401,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10024,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10024,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10024,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10024,606,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10025,203,28.57,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10025,204,9.12,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10025,205,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10025,207,1.4,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10025,208,204,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10025,255,61.4,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10025,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10025,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10025,301,18,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10025,303,1.13,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10025,306,387,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10025,307,50,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10025,320,2,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (10025,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10025,401,0.6,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10025,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10025,601,79,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10025,605,NULL,'100g',NULL,1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10025,606,3.38,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10026,203,28.57,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10026,204,9.8,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10026,205,0,'100g',4,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10026,207,1.4,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10026,208,210,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10026,255,60.72,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10026,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10026,291,0,'100g',4,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10026,301,17,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10026,303,0.91,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10026,306,438,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10026,307,64,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10026,320,2,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (10026,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10026,401,0.7,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10026,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10026,601,79,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10026,605,NULL,'100g',NULL,1,'1994-03-16','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10026,606,3.64,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10027,203,28.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10027,204,9.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10027,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10027,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10027,208,209,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10027,255,61.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10027,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10027,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10027,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10027,303,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10027,306,425,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10027,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10027,320,2,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (10027,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10027,401,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10027,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10027,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10027,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10027,606,3.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10028,203,19.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10028,204,12.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10028,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10028,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10028,208,194,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10028,255,67.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10028,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10028,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10028,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10028,303,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10028,306,288,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10028,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10028,320,6,'100g',1,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10028,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10028,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10028,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10028,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10028,605,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10028,606,4.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10029,203,26.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10029,204,15.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10029,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10029,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10029,208,255,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10029,255,57.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10029,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10029,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10029,301,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10029,303,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10029,306,259,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10029,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10029,320,4,'100g',1,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10029,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10029,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10029,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10029,601,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10029,605,0.067,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10029,606,4.487,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10030,203,23.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10030,204,14.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10030,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10030,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10030,208,231,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10030,255,61.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10030,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10030,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10030,301,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10030,303,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10030,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10030,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10030,320,4,'100g',1,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10030,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10030,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10030,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10030,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10030,605,0.066,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10030,606,4.339,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10031,203,24.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10031,204,16.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10031,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10031,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10031,208,254,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10031,255,58.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10031,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10031,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10031,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10031,303,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10031,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10031,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10031,320,4,'100g',1,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10031,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10031,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10031,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10031,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10031,605,0.112,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10031,606,5.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10032,203,21.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10032,204,5.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10032,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10032,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10032,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10032,255,72.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10032,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10032,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10032,301,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10032,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10032,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10032,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10032,320,3,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10032,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10032,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10032,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10032,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10032,605,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10032,606,1.974,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10033,203,28.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10033,204,11.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10033,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10033,207,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10033,208,222,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10033,255,60.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10033,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10033,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10033,301,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10033,303,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10033,306,270,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10033,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10033,320,2,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10033,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10033,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10033,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10033,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10033,605,0.026,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10033,606,2.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10034,203,24.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10034,204,9.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10034,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10034,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10034,208,193,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10034,255,65.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10034,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10034,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10034,301,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10034,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10034,306,332,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10034,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10034,320,2,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10034,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10034,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10034,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10034,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10034,605,0.023,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10034,606,2.322,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10035,203,25.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10035,204,11.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10035,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10035,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10035,208,217,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10035,255,62.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10035,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10035,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10035,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10035,303,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10035,306,337,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10035,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10035,320,1,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10035,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10035,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10035,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10035,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10035,605,0.071,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10035,606,3.934,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10036,203,20.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10036,204,9.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10036,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10036,207,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10036,208,170,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10036,255,69.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10036,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10036,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10036,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10036,303,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10036,306,343,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10036,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10036,320,2,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (10036,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10036,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10036,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10036,601,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10036,605,0.092,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10036,606,2.993,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10037,203,28.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10037,204,13.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10037,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10037,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10037,208,242,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10037,255,58.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10037,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10037,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10037,301,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10037,303,0.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10037,306,273,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10037,307,73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10037,320,4,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10037,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10037,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10037,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10037,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10037,605,0.076,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10037,606,4.934,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10038,203,25.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10038,204,11.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10038,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10038,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10038,208,209,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10038,255,62.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10038,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10038,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10038,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10038,303,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10038,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10038,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10038,320,2,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (10038,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10038,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10038,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10038,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10038,605,0.107,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10038,606,3.518,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10039,203,27.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10039,204,12.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10039,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10039,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10039,208,231,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10039,255,60.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10039,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10039,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10039,301,33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10039,303,0.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10039,306,350,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10039,307,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10039,320,4,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10039,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10039,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10039,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10039,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10039,605,0.093,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10039,606,4.859,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10040,203,21.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10040,204,3.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10040,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10040,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10040,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10040,255,73.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10040,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10040,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10040,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10040,303,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10040,306,362,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10040,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10040,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (10040,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10040,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10040,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10040,601,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10040,605,0.033,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10040,606,1.098,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10041,203,30.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10041,204,7.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10041,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10041,207,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10041,208,200,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10041,255,61.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10041,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10041,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10041,301,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10041,303,0.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10041,306,288,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10041,307,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10041,320,2,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (10041,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10041,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10041,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10041,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10041,605,0.027,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10041,606,2.671,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10042,203,26.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10042,204,7.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10042,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10042,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10042,208,180,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10042,255,65.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10042,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10042,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10042,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10042,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10042,306,356,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10042,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10042,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (10042,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10042,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10042,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10042,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10042,605,0.065,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10042,606,2.156,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10043,203,28.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10043,204,7.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10043,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10043,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10043,208,194,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10043,255,63.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10043,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10043,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10043,301,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10043,303,0.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10043,306,370,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10043,307,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10043,320,2,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (10043,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10043,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10043,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10043,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10043,605,0.053,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10043,606,2.932,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10044,203,20.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10044,204,11.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10044,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10044,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10044,208,186,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10044,255,67.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10044,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10044,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10044,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10044,303,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10044,306,337,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10044,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10044,320,2,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10044,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10044,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10044,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10044,601,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10044,605,0.069,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (10044,606,2.365,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10045,203,26.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10045,204,16.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10045,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10045,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10045,208,261,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10045,255,56.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10045,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10045,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10045,301,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10045,303,0.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10045,306,259,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10045,307,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10045,320,5,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10045,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10045,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10045,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10045,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10045,605,0.088,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10045,606,5.435,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10046,203,24.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10046,204,13.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10046,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10046,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10046,208,222,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10046,255,61.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10046,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10046,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10046,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10046,303,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10046,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10046,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10046,320,2,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (10046,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10046,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10046,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10046,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10046,605,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10046,606,4.486,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10047,203,26.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10047,204,14.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10047,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10047,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10047,208,248,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10047,255,57.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10047,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10047,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10047,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10047,303,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10047,306,272,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10047,307,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10047,320,5,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10047,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10047,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10047,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10047,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10047,605,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10047,606,5.442,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10048,203,21.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10048,204,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10048,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10048,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10048,208,136,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10048,255,72.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10048,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10048,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10048,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10048,303,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10048,306,359,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10048,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10048,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (10048,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10048,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10048,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10048,601,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10048,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10048,606,1.617,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10049,203,29.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10049,204,9.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10049,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10049,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10049,208,208,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10049,255,61.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10049,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10049,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10049,301,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10049,303,0.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10049,306,277,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10049,307,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10049,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10049,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10049,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10049,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10049,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10049,605,0.043,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (10049,606,2.389,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (10050,203,25.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10050,204,8.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10050,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10050,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10050,208,186,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10050,255,65.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10050,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10050,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10050,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10050,303,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10050,306,343,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10050,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10050,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (10050,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10050,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10050,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10050,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10050,605,0.067,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10050,606,2.816,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10051,203,28.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10051,204,9.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10051,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10051,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10051,208,206,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10051,255,61.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10051,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10051,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10051,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10051,303,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10051,306,287,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10051,307,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10051,320,3,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (10051,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10051,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10051,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10051,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10051,605,0.054,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10051,606,3.254,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10052,203,20.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10052,204,8.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10052,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10052,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10052,208,168,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10052,255,70.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10052,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10052,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10052,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10052,303,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10052,306,336,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10052,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10052,320,2,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (10052,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10052,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10052,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10052,601,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10052,605,0.058,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10052,606,2.978,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10053,203,28.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10053,204,12.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10053,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10053,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10053,208,234,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10053,255,58.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10053,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10053,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10053,301,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10053,303,0.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10053,306,400,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10053,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10053,320,4,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10053,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10053,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10053,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10053,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10053,605,0.078,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10053,606,4.294,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10054,203,26.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10054,204,11.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10054,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10054,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10054,208,222,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10054,255,60.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10054,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10054,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10054,301,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10054,303,1.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10054,306,363,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10054,307,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10054,320,5,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10054,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10054,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10054,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10054,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10054,605,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10054,606,4.045,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10055,203,26.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10055,204,12.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10055,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10055,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10055,208,230,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10055,255,59.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10055,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10055,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10055,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10055,303,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10055,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10055,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10055,320,2,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (10055,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10055,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10055,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10055,601,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10055,605,0.103,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10055,606,4.113,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10057,203,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10057,204,6.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10057,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10057,207,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10057,208,195,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10057,255,62.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10057,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10057,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10057,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10057,303,0.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10057,306,428,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10057,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10057,320,2,'100g',2,1,'2024-12-12','2011-01-01');
INSERT INTO `cndb_nutval` VALUES (10057,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10057,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10057,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10057,601,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10057,605,0.038,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10057,606,2.327,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10058,203,29.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10058,204,5.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10058,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10058,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10058,208,174,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10058,255,64.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10058,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10058,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10058,301,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10058,303,1.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10058,306,391,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10058,307,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10058,320,2,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (10058,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10058,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10058,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10058,601,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10058,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10058,606,1.718,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10059,203,27.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10059,204,9.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10059,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10059,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10059,208,204,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10059,255,61.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10059,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10059,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10059,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10059,303,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10059,306,352,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10059,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10059,320,0,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (10059,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10059,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10059,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10059,601,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10059,605,0.063,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10059,606,2.871,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10060,203,20.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10060,204,2.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10060,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10060,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10060,208,109,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10060,255,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10060,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10060,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10060,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10060,303,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10060,306,399,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10060,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10060,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (10060,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10060,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10060,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10060,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10060,605,0.021,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10060,606,0.698,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10061,203,26.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10061,204,3.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10061,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10061,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10061,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10061,255,69.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10061,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10061,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10061,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10061,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10061,306,421,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10061,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10061,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (10061,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10061,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10061,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10061,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10061,605,0.033,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10061,606,1.198,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10062,203,21.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10062,204,6.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10062,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10062,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10062,208,155,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10062,255,70.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10062,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10062,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10062,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10062,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10062,306,373,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10062,307,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10062,320,1,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (10062,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10062,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10062,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10062,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10062,605,0.064,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10062,606,2.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10063,203,29.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10063,204,8.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10063,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10063,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10063,208,200,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10063,255,62.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10063,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10063,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10063,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10063,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10063,306,261,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10063,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10063,320,3,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10063,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10063,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10063,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10063,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10063,605,0.048,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10063,606,3.218,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10064,203,26.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10064,204,9.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10064,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10064,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10064,208,196,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10064,255,62.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10064,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10064,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10064,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10064,303,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10064,306,357,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10064,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10064,320,1,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10064,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10064,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10064,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10064,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10064,605,0.086,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10064,606,3.164,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10065,203,26.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10065,204,8.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10065,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10065,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10065,208,192,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10065,255,63.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10065,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10065,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10065,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10065,303,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10065,306,349,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10065,307,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10065,320,1,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (10065,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10065,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10065,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10065,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10065,605,0.079,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10065,606,2.839,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10066,203,22.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10066,204,3.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10066,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10066,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10066,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10066,255,72.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10066,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10066,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10066,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10066,303,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10066,306,387,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10066,307,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10066,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (10066,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10066,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10066,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10066,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10066,605,0.024,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10066,606,1.208,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10067,203,30.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10067,204,4.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10067,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10067,207,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10067,208,170,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10067,255,65.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10067,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10067,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10067,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10067,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10067,306,269,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10067,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10067,320,2,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (10067,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10067,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10067,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10067,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10067,605,0.015,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10067,606,1.657,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10068,203,27.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10068,204,6.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10068,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10068,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10068,208,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10068,255,65.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10068,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10068,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10068,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10068,303,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10068,306,367,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10068,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10068,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (10068,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10068,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10068,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10068,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10068,605,0.052,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10068,606,2.077,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10069,203,27.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10069,204,6.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10069,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10069,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10069,208,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10069,255,65.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10069,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10069,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10069,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10069,303,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10069,306,357,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10069,307,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10069,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (10069,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10069,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10069,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10069,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10069,605,0.051,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10069,606,1.927,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10070,203,17.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10070,204,17.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10070,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10070,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10070,208,236,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10070,255,64.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10070,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10070,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10070,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10070,303,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10070,306,302,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10070,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10070,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10070,328,1.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10070,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10070,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10070,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10070,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10070,606,6.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10071,203,23.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10071,204,21.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10071,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10071,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10071,208,292,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10071,255,54.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10071,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10071,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10071,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10071,303,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10071,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10071,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10071,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10071,328,1.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10071,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10071,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10071,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10071,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10071,606,7.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10072,203,19.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10072,204,7.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10072,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10072,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10072,208,148,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10072,255,72.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10072,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10072,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10072,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10072,303,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10072,306,341,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10072,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10072,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10072,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10072,401,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10072,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10072,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10072,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10072,606,2.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10073,203,25.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10073,204,13.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10073,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10073,207,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10073,208,230,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10073,255,60.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10073,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10073,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10073,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10073,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10073,306,346,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10073,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10073,320,2,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (10073,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10073,401,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10073,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10073,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10073,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10073,606,4.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10074,203,18.71,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10074,204,12.51,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10074,205,0,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10074,207,0.98,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10074,208,193,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10074,255,68.34,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10074,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10074,291,0,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10074,301,12,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10074,303,0.57,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10074,306,413,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10074,307,84,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10074,320,5,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10074,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10074,401,0,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10074,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10074,601,63,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10074,605,0.123,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10074,606,4.14,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (10075,203,24.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10075,204,14.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10075,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10075,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10075,208,235,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10075,255,60.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10075,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10075,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10075,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10075,303,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10075,306,357,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10075,307,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10075,320,4,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10075,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10075,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10075,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10075,601,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10075,605,0.181,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10075,606,4.854,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10076,203,23.47,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10076,204,24.01,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10076,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10076,207,0.99,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10076,208,317,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10076,255,52.04,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10076,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10076,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10076,301,19,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10076,303,1.18,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10076,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10076,307,70,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10076,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10076,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10076,401,0.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10076,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10076,601,94,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10076,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10076,606,8.78,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10077,203,20.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10077,204,3.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10077,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10077,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10077,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10077,255,75.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10077,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10077,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10077,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10077,303,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10077,306,427,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10077,307,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10077,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10077,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10077,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10077,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10077,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10077,605,0.045,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10077,606,1.206,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10078,203,26.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10078,204,8.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10078,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10078,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10078,208,194,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10078,255,63.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10078,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10078,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10078,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10078,303,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10078,306,382,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10078,307,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10078,320,2,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (10078,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10078,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10078,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10078,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10078,605,0.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10078,606,2.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10079,203,26.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10079,204,12.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10079,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10079,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10079,208,228,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10079,255,60.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10079,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10079,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10079,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10079,303,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10079,306,351,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10079,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10079,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10079,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10079,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10079,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10079,601,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10079,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10079,606,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10080,203,17.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10080,204,12.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10080,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10080,207,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10080,208,186,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10080,255,69.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10080,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10080,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10080,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10080,303,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10080,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10080,307,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10080,320,2,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (10080,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10080,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10080,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10080,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10080,605,0.115,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10080,606,4.348,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10081,203,25.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10081,204,17.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10081,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10081,207,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10081,208,267,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10081,255,54.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10081,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10081,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10081,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10081,303,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10081,306,305,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10081,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10081,320,2,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (10081,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10081,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10081,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10081,601,98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10081,605,0.154,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10081,606,6.584,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10082,203,25.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10082,204,16.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10082,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10082,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10082,208,259,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10082,255,57.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10082,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10082,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10082,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10082,303,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10082,306,326,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10082,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10082,320,3,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10082,328,1.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10082,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10082,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10082,601,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10082,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10082,606,5.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10083,203,23.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10083,204,18.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10083,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10083,207,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10083,208,269,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10083,255,57.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10083,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10083,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10083,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10083,303,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10083,306,332,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10083,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10083,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10083,328,1.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10083,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10083,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10083,601,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10083,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10083,606,6.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10084,203,18.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10084,204,5.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10084,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10084,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10084,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10084,255,74.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10084,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10084,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10084,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10084,303,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10084,306,339,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10084,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10084,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (10084,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10084,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10084,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10084,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10084,605,0.038,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10084,606,1.998,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10085,203,26.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10085,204,13.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10085,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10085,207,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10085,208,233,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10085,255,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10085,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10085,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10085,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10085,303,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10085,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10085,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10085,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (10085,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10085,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10085,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10085,601,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10085,605,0.102,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10085,606,5.023,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10086,203,26.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10086,204,12.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10086,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10086,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10086,208,227,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10086,255,60.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10086,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10086,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10086,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10086,303,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10086,306,343,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10086,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10086,320,2,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (10086,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10086,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10086,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10086,601,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10086,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10086,606,4.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10087,203,24.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10087,204,14.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10087,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10087,207,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10087,208,232,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10087,255,60.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10087,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10087,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10087,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10087,303,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10087,306,427,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10087,307,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10087,320,3,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (10087,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10087,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10087,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10087,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10087,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10087,606,5.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10088,203,15.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10088,204,23.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10088,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10088,207,0.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10088,208,277,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10088,255,59.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10088,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10088,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10088,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10088,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10088,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10088,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10088,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (10088,328,2.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10088,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10088,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10088,601,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10088,605,0.222,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10088,606,7.529,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10089,203,29.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10089,204,30.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10089,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10089,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10089,208,397,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10089,255,40.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10089,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10089,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10089,301,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10089,303,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10089,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10089,307,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10089,320,3,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10089,328,2.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10089,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10089,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10089,601,121,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10089,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10089,606,11.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10093,203,27.51,'100g',1,1,'2004-07-15','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10093,204,9.21,'100g',1,1,'2004-07-15','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10093,205,0,'100g',3,1,'2004-07-15','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10093,207,1.11,'100g',1,1,'2004-07-15','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10093,208,201,'100g',3,1,'2004-07-15','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10093,255,62.53,'100g',1,1,'2004-07-15','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10093,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10093,291,0,'100g',3,1,'2004-07-15','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10093,301,18,'100g',1,1,'2004-07-15','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10093,303,1,'100g',1,1,'2004-07-15','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10093,306,357,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10093,307,55,'100g',1,1,'2004-07-15','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10093,320,1,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10093,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10093,401,0.2,'100g',3,1,'2004-07-15','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10093,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10093,601,84,'100g',1,1,'2004-07-15','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10093,605,0.032,'100g',NULL,1,'2004-07-15','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10093,606,3.092,'100g',3,1,'2004-07-15','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10094,203,23.75,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10094,204,3.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10094,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10094,207,1.14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10094,208,123,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10094,255,72.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10094,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10094,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10094,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10094,303,0.48,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10094,306,386,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10094,307,87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10094,320,1,'100g',1,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (10094,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10094,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10094,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10094,601,56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10094,605,0.008,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10094,606,0.801,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10096,203,10.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10096,204,9.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10096,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10096,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10096,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10096,255,78.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10096,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10096,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10096,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10096,303,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10096,306,258,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10096,307,120,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10096,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10096,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10096,401,13.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10096,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10096,601,2195,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10096,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10096,606,2.079,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10097,203,12.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10097,204,9.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10097,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10097,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10097,208,138,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10097,255,75.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10097,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10097,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10097,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10097,303,1.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10097,306,195,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10097,307,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10097,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10097,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10097,401,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10097,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10097,601,2552,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10097,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10097,606,2.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10098,203,7.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10098,204,16.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10098,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10098,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10098,208,182,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10098,255,76.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10098,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10098,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10098,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10098,303,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10098,306,18,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10098,307,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10098,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (10098,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10098,401,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10098,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10098,601,154,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10098,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10098,606,7.619,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10099,203,12.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10099,204,20.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10099,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10099,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10099,208,233,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10099,255,67.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10099,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10099,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10099,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10099,303,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10099,306,14,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10099,307,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10099,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (10099,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10099,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10099,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10099,601,277,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10099,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10099,606,9.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10100,203,22.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10100,204,15.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10100,205,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10100,207,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10100,208,234,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10100,255,61.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10100,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10100,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10100,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10100,303,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10100,306,55,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10100,307,191,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10100,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10100,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10100,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10100,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10100,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10100,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10100,606,5.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10101,203,15.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10101,204,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10101,205,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10101,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10101,208,166,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10101,255,72.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10101,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10101,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10101,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10101,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10101,306,40,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10101,307,167,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10101,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10101,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10101,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10101,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10101,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10101,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10101,606,3.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10102,203,23.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10102,204,12.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10102,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10102,207,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10102,208,212,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10102,255,64.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10102,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10102,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10102,301,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10102,303,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10102,306,63,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10102,307,132,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10102,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (10102,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10102,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10102,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10102,601,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10102,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10102,606,3.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10103,203,17.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10103,204,4.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10103,205,1.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10103,207,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10103,208,118,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10103,255,76.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10103,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10103,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10103,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10103,303,4.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10103,306,294,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10103,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10103,320,8,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (10103,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10103,401,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10103,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10103,601,131,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10103,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10103,606,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10104,203,23.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10104,204,5.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10104,205,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10104,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10104,208,148,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10104,255,68.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10104,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10104,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10104,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10104,303,5.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10104,306,206,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10104,307,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10104,320,7,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10104,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10104,401,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10104,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10104,601,221,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10104,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10104,606,1.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10105,203,6.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10105,204,69.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10105,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10105,207,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10105,208,655,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10105,255,22.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10105,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10105,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10105,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10105,303,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10105,306,148,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10105,307,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10105,320,3,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (10105,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10105,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10105,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10105,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10105,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10105,606,25.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10106,203,16.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10106,204,3.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10106,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10106,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10106,208,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10106,255,80.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10106,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10106,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10106,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10106,303,4.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10106,306,229,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10106,307,121,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10106,320,59,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10106,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10106,401,13.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10106,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10106,601,319,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10106,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10106,606,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10107,203,25.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10107,204,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10107,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10107,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10107,208,151,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10107,255,68.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10107,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10107,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10107,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10107,303,5.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10107,306,143,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10107,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10107,320,78,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10107,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10107,401,10.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10107,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10107,601,480,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10107,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10107,606,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10109,203,1.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10109,204,94.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10109,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10109,207,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10109,208,857,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10109,255,4.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10109,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10109,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10109,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10109,303,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10109,306,31,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10109,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10109,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10109,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10109,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10109,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10109,601,110,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10109,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10109,606,45.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10110,203,21.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10110,204,3.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10110,205,2.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10110,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10110,208,134,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10110,255,71.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10110,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10110,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10110,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10110,303,23.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10110,306,273,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10110,307,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10110,320,6502,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10110,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10110,401,25.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10110,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10110,601,301,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10110,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10110,606,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10111,203,26.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10111,204,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10111,205,3.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10111,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10111,208,165,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10111,255,64.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10111,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10111,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10111,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10111,303,17.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10111,306,150,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10111,307,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10111,320,5405,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10111,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10111,401,23.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10111,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10111,601,355,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10111,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10111,606,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10112,203,14.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10112,204,2.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10112,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10112,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10112,208,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10112,255,79.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10112,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10112,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10112,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10112,303,18.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10112,306,303,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10112,307,153,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10112,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10112,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10112,401,12.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10112,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10112,601,320,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10112,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10112,606,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10113,203,16.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10113,204,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10113,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10113,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10113,208,99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10113,255,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10113,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10113,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10113,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10113,303,16.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10113,306,151,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10113,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10113,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10113,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10113,401,7.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10113,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10113,601,387,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10113,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10113,606,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10114,203,15.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10114,204,26.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10114,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10114,207,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10114,208,304,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10114,255,56.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10114,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10114,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10114,301,315,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10114,303,4.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10114,306,298,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10114,307,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10114,320,3,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10114,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10114,401,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10114,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10114,601,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10114,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10114,606,9.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10115,203,18.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10115,204,13.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10115,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10115,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10115,208,199,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10115,255,67.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10115,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10115,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10115,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10115,303,2.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10115,306,197,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10115,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10115,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10115,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10115,401,15.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10115,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10115,601,193,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10115,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10115,606,4.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10116,203,28.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10116,204,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10116,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10116,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10116,208,219,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10116,255,60.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10116,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10116,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10116,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10116,303,2.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10116,306,168,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10116,307,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10116,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10116,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10116,401,5.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10116,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10116,601,315,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10116,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10116,606,3.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10117,203,17.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10117,204,2.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10117,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10117,207,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10117,208,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10117,255,78.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10117,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10117,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10117,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10117,303,22.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10117,306,396,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10117,307,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10117,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10117,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10117,401,28.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10117,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10117,601,363,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10117,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10117,606,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10118,203,28.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10118,204,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10118,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10118,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10118,208,149,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10118,255,66.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10118,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10118,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10118,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10118,303,22.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10118,306,227,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10118,307,107,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10118,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10118,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10118,401,11.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10118,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10118,601,504,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10118,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10118,606,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10119,203,16.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10119,204,10.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10119,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10119,207,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10119,208,159,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10119,255,73.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10119,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10119,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10119,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10119,303,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10119,306,140,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10119,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10119,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (10119,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10119,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10119,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10119,601,223,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10119,605,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10119,606,4.025,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10120,203,26.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10120,204,12.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10120,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10120,207,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10120,208,222,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10120,255,61.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10120,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10120,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10120,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10120,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10120,306,335,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10120,307,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10120,320,3,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10120,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10120,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10120,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10120,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10120,605,0.025,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10120,606,2.557,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10121,203,16.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10121,204,17.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10121,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10121,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10121,208,225,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10121,255,65.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10121,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10121,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10121,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10121,303,3.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10121,306,243,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10121,307,110,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10121,320,0,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (10121,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10121,401,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10121,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10121,601,101,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10121,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10121,606,5.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10122,203,24.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10122,204,18.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10122,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10122,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10122,208,271,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10122,255,56.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10122,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10122,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10122,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10122,303,4.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10122,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10122,307,109,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10122,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10122,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10122,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10122,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10122,601,146,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10122,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10122,606,6.449,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10123,203,13.66,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10123,204,37.13,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10123,205,0,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10123,207,2.59,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10123,208,393,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10123,255,46.74,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10123,269,0.35,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10123,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10123,301,6,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10123,303,0.38,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10123,306,201,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10123,307,751,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10123,320,11,'100g',1,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (10123,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10123,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10123,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10123,601,66,'100g',1,1,'1994-01-31','2012-05-01');
INSERT INTO `cndb_nutval` VALUES (10123,605,0.147,'100g',3,1,'2006-01-24','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10123,606,12.615,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10128,203,11.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10128,204,37.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10128,205,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10128,207,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10128,208,388,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10128,255,47.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10128,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10128,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10128,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10128,303,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10128,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10128,307,987,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10128,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10128,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10128,401,27.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10128,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10128,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10128,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10128,606,12.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10130,203,20.31,'100g',1,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10130,204,2.62,'100g',1,1,'1994-11-14','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (10130,205,1.34,'100g',3,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10130,207,3.38,'100g',1,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10130,208,110,'100g',3,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10130,255,72.34,'100g',1,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10130,269,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10130,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10130,301,6,'100g',1,1,'1994-11-14','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (10130,303,0.44,'100g',1,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10130,306,683,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10130,307,751,'100g',1,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10130,320,0,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (10130,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10130,401,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10130,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10130,601,48,'100g',1,1,'1994-11-14','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10130,605,0.007,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10130,606,0.9,'100g',3,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10132,203,11.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10132,204,10.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10132,205,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10132,207,3.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10132,208,140,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10132,255,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10132,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10132,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10132,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10132,303,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10132,306,13,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10132,307,946,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10132,320,11,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10132,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10132,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10132,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10132,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10132,605,0.065,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10132,606,2.945,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10134,203,20.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10134,204,5.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10134,205,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10134,207,4.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10134,208,145,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10134,255,67.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10134,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10134,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10134,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10134,303,1.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10134,306,287,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10134,307,1203,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10134,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (10134,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10134,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10134,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10134,601,53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10134,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10134,606,1.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10136,203,22.62,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10136,204,9.02,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10136,205,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10136,207,3.96,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10136,208,178,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10136,255,64.54,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10136,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10136,291,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10136,301,8,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10136,303,1.34,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10136,306,409,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10136,307,1500,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10136,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (10136,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10136,401,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10136,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10136,601,59,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10136,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10136,606,3.12,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10137,203,18.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10137,204,4.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10137,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10137,207,3.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10137,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10137,255,73.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10137,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10137,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10137,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10137,303,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10137,306,364,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10137,307,1255,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10137,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (10137,328,2.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10137,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10137,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10137,601,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10137,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10137,606,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10138,203,21.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10138,204,4.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10138,205,0.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10138,207,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10138,208,136,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10138,255,69.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10138,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10138,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10138,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10138,303,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10138,306,348,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10138,307,1135,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10138,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10138,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10138,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10138,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10138,601,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10138,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10138,606,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10140,203,20.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10140,204,15.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10140,205,0.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10140,207,2.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10140,208,226,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10140,255,60.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10140,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10140,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10140,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10140,303,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10140,306,357,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10140,307,941,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10140,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10140,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10140,401,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10140,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10140,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10140,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10140,606,5.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10141,203,27.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10141,204,8.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10141,205,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10141,207,7.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10141,208,195,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10141,255,55.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10141,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10141,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10141,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10141,303,1.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10141,306,510,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10141,307,2695,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10141,320,0,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10141,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10141,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10141,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10141,601,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10141,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10141,606,2.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10142,203,20.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10142,204,12.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10142,205,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10142,207,3.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10142,208,203,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10142,255,63.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10142,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10142,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10142,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10142,303,0.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10142,306,337,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10142,307,1386,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10142,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10142,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10142,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10142,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10142,601,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10142,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10142,606,4.572,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10146,203,12.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10146,204,28.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10146,205,1.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10146,207,2.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10146,208,315,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10146,255,54.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10146,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10146,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10146,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10146,303,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10146,306,239,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10146,307,1088,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10146,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10146,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10146,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10146,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10146,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10146,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10146,606,10.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10149,203,19.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10149,204,4.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10149,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10149,207,3.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10149,208,122,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10149,255,72.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10149,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10149,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10149,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10149,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10149,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10149,307,1269,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10149,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10149,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10149,401,32.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10149,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10149,601,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10149,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10149,606,1.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10150,203,18.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10150,204,18.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10150,205,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10150,207,3.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10150,208,246,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10150,255,59.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10150,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10150,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10150,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10150,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10150,306,310,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10150,307,1284,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10150,320,0,'100g',2,1,'2024-12-12','2004-01-08');
INSERT INTO `cndb_nutval` VALUES (10150,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10150,401,34.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10150,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10150,601,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10150,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10150,606,6.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10152,203,22.32,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10152,204,5.71,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10152,205,0.05,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10152,207,3.66,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10152,208,147,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10152,255,68.26,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10152,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10152,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10152,301,7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10152,303,0.81,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10152,306,371,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10152,307,1516,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10152,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10152,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10152,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10152,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10152,601,52,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10152,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10152,606,1.92,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10153,203,25.05,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10153,204,5.5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10153,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10153,207,3.74,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10153,208,157,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10153,255,65.78,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10153,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10153,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10153,301,7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10153,303,0.94,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10153,306,316,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10153,307,1327,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10153,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10153,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10153,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10153,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10153,601,55,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10153,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10153,606,1.84,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10163,203,30.02,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10163,204,4.65,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10163,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10163,207,1.1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10163,208,162,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10163,255,65.07,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10163,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10163,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10163,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10163,303,0.64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10163,306,407,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10163,307,91,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10163,320,2,'100g',1,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (10163,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10163,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10163,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10163,601,74,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10163,605,0.014,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10163,606,1.658,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10164,203,21.14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10164,204,12.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10164,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10164,207,1.03,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10164,208,201,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10164,255,65.15,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10164,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10164,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10164,301,9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10164,303,0.48,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10164,306,345,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10164,307,82,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10164,320,5,'100g',1,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (10164,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10164,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10164,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10164,601,59,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10164,605,0.081,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10164,606,4.413,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10165,203,5.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10165,204,80.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10165,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10165,207,3.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10165,208,748,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10165,255,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10165,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10165,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10165,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10165,303,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10165,306,66,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10165,307,2684,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10165,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10165,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10165,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10165,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10165,601,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10165,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10165,606,29.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10166,203,5.68,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10166,204,61.41,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10166,205,0.09,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10166,207,1.77,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10166,208,579,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10166,255,31.06,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10166,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10166,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10166,301,5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10166,303,0.39,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10166,306,105,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10166,307,505,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10166,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10166,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10166,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10166,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10166,601,68,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10166,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10166,606,22.52,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10167,203,7.64,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10167,204,61.86,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10167,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10167,207,1.68,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10167,208,591,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10167,255,28.89,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10167,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10167,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10167,301,8,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10167,303,0.61,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10167,306,164,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10167,307,624,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10167,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10167,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10167,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10167,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10167,601,86,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10167,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10167,606,22.69,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10168,203,20.43,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10168,204,21.35,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10168,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10168,207,3.51,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10168,208,280,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10168,255,54.73,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10168,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10168,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10168,301,10,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10168,303,0.95,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10168,306,258,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10168,307,1072,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10168,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10168,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10168,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10168,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10168,601,58,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10168,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10168,606,7.67,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10169,203,24.94,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10169,204,7.04,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10169,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10169,207,4.16,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10169,208,170,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10169,255,63.86,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10169,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10169,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10169,301,11,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10169,303,1.08,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10169,306,292,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10169,307,1231,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10169,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10169,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10169,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10169,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10169,601,48,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10169,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10169,606,2.36,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10170,203,16.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10170,204,21.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10170,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10170,207,3.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10170,208,269,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10170,255,59.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10170,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10170,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10170,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10170,303,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10170,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10170,307,1250,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10170,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10170,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10170,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10170,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10170,601,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10170,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10170,606,7.939,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10171,203,17.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10171,204,23.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10171,205,0.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10171,207,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10171,208,287,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10171,255,56.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10171,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10171,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10171,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10171,303,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10171,306,194,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10171,307,973,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10171,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10171,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10171,401,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10171,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10171,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10171,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10171,606,8.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10173,203,21.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10173,204,16.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10173,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10173,207,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10173,208,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10173,255,62.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10173,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10173,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10173,301,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10173,303,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10173,306,33,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10173,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10173,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (10173,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10173,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10173,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10173,601,107,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10173,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10173,606,4.343,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10174,203,17.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10174,204,33.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10174,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10174,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10174,208,378,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10174,255,46.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10174,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10174,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10174,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10174,303,0.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10174,306,349,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10174,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10174,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10174,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10174,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10174,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10174,601,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10174,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10174,606,11.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10175,203,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10175,204,35.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10175,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10175,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10175,208,396,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10175,255,46.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10175,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10175,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10175,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10175,303,0.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10175,306,157,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10175,307,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10175,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10175,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10175,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10175,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10175,601,129,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10175,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10175,606,12.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10176,203,29.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10176,204,7.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10176,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10176,207,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10176,208,195,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10176,255,62.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10176,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10176,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10176,301,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10176,303,0.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10176,306,378,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10176,307,99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10176,320,3,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (10176,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10176,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10176,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10176,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10176,605,0.026,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10176,606,2.597,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10177,203,28.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10177,204,9.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10177,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10177,207,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10177,208,211,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10177,255,61.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10177,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10177,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10177,301,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10177,303,0.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10177,306,335,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10177,307,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10177,320,3,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (10177,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10177,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10177,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10177,601,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10177,605,0.025,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10177,606,2.563,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10178,203,25.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10178,204,16.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10178,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10178,207,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10178,208,256,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10178,255,58.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10178,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10178,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10178,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10178,303,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10178,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10178,307,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10178,320,5,'100g',1,1,'2024-12-12','2013-01-07');
INSERT INTO `cndb_nutval` VALUES (10178,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10178,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10178,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10178,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10178,605,0.119,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (10178,606,4.266,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10179,203,27.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10179,204,13.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10179,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10179,207,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10179,208,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10179,255,58.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10179,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10179,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10179,301,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10179,303,0.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10179,306,353,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10179,307,94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10179,320,5,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10179,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10179,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10179,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10179,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10179,605,0.075,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10179,606,4.867,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10180,203,26.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10180,204,15.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10180,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10180,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10180,208,256,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10180,255,57.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10180,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10180,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10180,301,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10180,303,0.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10180,306,313,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10180,307,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10180,320,6,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10180,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10180,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10180,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10180,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10180,605,0.079,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10180,606,5.056,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10181,203,30.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10181,204,4.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10181,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10181,207,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10181,208,172,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10181,255,64.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10181,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10181,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10181,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10181,303,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10181,306,390,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10181,307,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10181,320,3,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10181,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10181,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10181,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10181,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10181,605,0.017,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10181,606,1.784,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10182,203,18.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10182,204,8.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10182,205,2.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10182,207,4.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10182,208,162,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10182,255,66.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10182,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10182,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10182,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10182,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10182,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10182,307,1278,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10182,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10182,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10182,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10182,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10182,601,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10182,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10182,606,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10183,203,21.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10183,204,7.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10183,205,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10183,207,4.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10183,208,165,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10183,255,65.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10183,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10183,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10183,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10183,303,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10183,306,362,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10183,307,1385,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10183,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10183,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10183,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10183,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10183,601,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10183,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10183,606,2.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10184,203,17.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10184,204,7.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10184,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10184,207,3.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10184,208,144,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10184,255,71.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10184,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10184,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10184,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10184,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10184,306,334,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10184,307,1276,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10184,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10184,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10184,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10184,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10184,601,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10184,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10184,606,2.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10185,203,20.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10185,204,8.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10185,205,0.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10185,207,3.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10185,208,167,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10185,255,66.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10185,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10185,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10185,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10185,303,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10185,306,351,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10185,307,1068,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10185,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10185,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10185,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10185,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10185,601,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10185,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10185,606,2.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10186,203,29.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10186,204,7.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10186,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10186,207,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10186,208,196,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10186,255,62.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10186,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10186,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10186,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10186,303,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10186,306,376,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10186,307,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10186,320,4,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10186,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10186,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10186,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10186,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10186,605,0.044,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10186,606,3.058,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10187,203,18.95,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10187,204,14.95,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10187,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10187,207,0.94,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10187,208,216,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10187,255,65.11,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10187,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10187,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10187,301,19,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10187,303,0.86,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10187,306,335,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10187,307,55,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10187,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10187,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10187,401,0.5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10187,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10187,601,67,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10187,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10187,606,5.28,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10188,203,26.36,'100g',1,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10188,204,13.89,'100g',1,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10188,205,0,'100g',3,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10188,207,1.02,'100g',1,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10188,208,238,'100g',3,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10188,255,58.53,'100g',1,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10188,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10188,291,0,'100g',3,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10188,301,20,'100g',1,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10188,303,1.11,'100g',1,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10188,306,341,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10188,307,57,'100g',1,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10188,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10188,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10188,401,0.1,'100g',3,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10188,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10188,601,88,'100g',1,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10188,605,0.081,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10188,606,4.893,'100g',3,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10189,203,26.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10189,204,13.6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10189,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10189,207,1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10189,208,229,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10189,255,59.42,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10189,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10189,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10189,301,9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10189,303,0.62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10189,306,366,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10189,307,86,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10189,320,5,'100g',1,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (10189,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10189,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10189,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10189,601,75,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10189,605,0.081,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10189,606,4.89,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10192,203,19.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10192,204,16.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10192,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10192,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10192,208,224,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10192,255,63.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10192,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10192,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10192,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10192,303,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10192,306,247,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10192,307,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10192,320,7,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10192,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10192,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10192,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10192,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10192,605,0.141,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10192,606,5.783,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10193,203,23.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10193,204,21.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10193,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10193,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10193,208,292,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10193,255,54.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10193,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10193,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10193,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10193,303,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10193,306,240,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10193,307,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10193,320,6,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (10193,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10193,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10193,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10193,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10193,605,0.188,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10193,606,7.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10194,203,19.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10194,204,14.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10194,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10194,207,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10194,208,211,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10194,255,66.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10194,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10194,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10194,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10194,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10194,306,384,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10194,307,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10194,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10194,328,1.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10194,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10194,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10194,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10194,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10194,606,4.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10195,203,26.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10195,204,15.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10195,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10195,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10195,208,255,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10195,255,58.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10195,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10195,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10195,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10195,303,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10195,306,387,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10195,307,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10195,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10195,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10195,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10195,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10195,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10195,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10195,606,6.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10196,203,27.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10196,204,15.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10196,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10196,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10196,208,260,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10196,255,53.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10196,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10196,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10196,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10196,303,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10196,306,401,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10196,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10196,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10196,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10196,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10196,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10196,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10196,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10196,606,5.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10197,203,25.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10197,204,18.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10197,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10197,207,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10197,208,273,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10197,255,56.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10197,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10197,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10197,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10197,303,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10197,306,428,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10197,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10197,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10197,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10197,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10197,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10197,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10197,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10197,606,6.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10198,203,26.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10198,204,15.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10198,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10198,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10198,208,252,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10198,255,57.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10198,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10198,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10198,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10198,303,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10198,306,346,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10198,307,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10198,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10198,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10198,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10198,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10198,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10198,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10198,606,5.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10199,203,21.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10199,204,6.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10199,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10199,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10199,208,152,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10199,255,71.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10199,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10199,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10199,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10199,303,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10199,306,421,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10199,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10199,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10199,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10199,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10199,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10199,601,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10199,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10199,606,2.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10200,203,27.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10200,204,10.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10200,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10200,207,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10200,208,211,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10200,255,62.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10200,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10200,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10200,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10200,303,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10200,306,405,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10200,307,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10200,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10200,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10200,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10200,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10200,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10200,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10200,606,3.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10201,203,29.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10201,204,10.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10201,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10201,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10201,208,216,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10201,255,56.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10201,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10201,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10201,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10201,303,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10201,306,420,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10201,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10201,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10201,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10201,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10201,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10201,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10201,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10201,606,3.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10202,203,27.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10202,204,11.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10202,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10202,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10202,208,224,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10202,255,60.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10202,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10202,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10202,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10202,303,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10202,306,454,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10202,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10202,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10202,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10202,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10202,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10202,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10202,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10202,606,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10203,203,28.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10203,204,10.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10203,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10203,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10203,208,214,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10203,255,60.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10203,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10203,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10203,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10203,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10203,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10203,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10203,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10203,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10203,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10203,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10203,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10203,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10203,606,3.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10204,203,19.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10204,204,11.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10204,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10204,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10204,208,189,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10204,255,68.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10204,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10204,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10204,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10204,303,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10204,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10204,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10204,320,2,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (10204,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10204,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10204,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10204,601,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10204,605,0.067,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (10204,606,2.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10205,203,26.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10205,204,17.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10205,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10205,207,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10205,208,273,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10205,255,53.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10205,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10205,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10205,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10205,303,1.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10205,306,288,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10205,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10205,320,2,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (10205,328,1.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10205,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10205,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10205,601,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10205,605,0.153,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10205,606,6.302,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10206,203,21.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10206,204,29.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10206,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10206,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10206,208,359,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10206,255,48.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10206,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10206,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10206,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10206,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10206,306,322,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10206,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10206,320,2,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10206,328,1.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10206,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10206,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10206,601,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10206,605,0.048,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10206,606,10.689,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10207,203,20.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10207,204,5.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10207,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10207,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10207,208,140,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10207,255,72.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10207,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10207,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10207,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10207,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10207,306,338,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10207,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10207,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10207,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10207,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10207,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10207,601,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10207,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10207,606,2.012,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10208,203,27.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10208,204,14.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10208,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10208,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10208,208,247,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10208,255,56.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10208,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10208,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10208,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10208,303,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10208,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10208,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10208,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (10208,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10208,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10208,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10208,601,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10208,605,0.112,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10208,606,5.086,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10209,203,29.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10209,204,11.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10209,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10209,207,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10209,208,227,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10209,255,58.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10209,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10209,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10209,301,31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10209,303,0.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10209,306,390,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10209,307,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10209,320,1,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10209,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10209,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10209,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10209,601,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10209,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10209,606,3.766,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10210,203,22.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10210,204,4.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10210,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10210,207,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10210,208,133,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10210,255,73.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10210,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10210,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10210,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10210,303,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10210,306,354,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10210,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10210,320,3,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10210,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10210,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10210,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10210,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10210,605,0.021,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10210,606,1.393,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10211,203,28.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10211,204,5.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10211,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10211,207,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10211,208,171,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10211,255,65.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10211,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10211,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10211,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10211,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10211,306,411,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10211,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10211,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10211,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10211,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10211,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10211,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10211,605,0.008,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10211,606,1.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10212,203,28.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10212,204,5.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10212,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10212,207,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10212,208,170,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10212,255,65.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10212,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10212,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10212,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10212,303,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10212,306,420,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10212,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10212,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10212,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10212,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10212,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10212,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10212,605,0.019,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10212,606,1.785,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10213,203,29.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10213,204,7.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10213,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10213,207,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10213,208,192,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10213,255,62.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10213,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10213,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10213,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10213,303,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10213,306,398,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10213,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10213,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10213,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10213,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10213,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10213,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10213,605,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10213,606,2.528,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10214,203,22.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10214,204,2.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10214,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10214,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10214,208,121,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10214,255,74.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10214,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10214,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10214,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10214,303,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10214,306,354,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10214,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10214,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10214,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10214,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10214,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10214,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10214,605,0.007,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10214,606,0.906,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10215,203,28.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10215,204,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10215,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10215,207,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10215,208,163,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10215,255,66.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10215,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10215,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10215,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10215,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10215,306,416,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10215,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10215,320,2,'100g',2,1,'2024-12-12','2011-01-01');
INSERT INTO `cndb_nutval` VALUES (10215,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10215,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10215,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10215,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10215,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10215,606,1.517,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10216,203,28.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10216,204,4.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10216,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10216,207,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10216,208,161,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10216,255,66.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10216,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10216,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10216,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10216,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10216,306,425,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10216,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10216,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10216,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10216,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10216,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10216,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10216,605,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10216,606,1.357,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10217,203,30.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10217,204,5.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10217,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10217,207,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10217,208,178,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10217,255,64.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10217,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10217,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10217,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10217,303,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10217,306,408,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10217,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10217,320,1,'100g',2,1,'2024-12-12','2011-01-01');
INSERT INTO `cndb_nutval` VALUES (10217,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10217,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10217,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10217,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10217,605,0.026,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10217,606,1.798,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10218,203,20.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10218,204,3.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10218,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10218,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10218,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10218,255,74.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10218,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10218,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10218,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10218,303,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10218,306,393,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10218,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10218,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (10218,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10218,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10218,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10218,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10218,605,0.036,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10218,606,1.181,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10219,203,16.88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10219,204,21.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10219,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10219,207,0.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10219,208,263,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10219,255,61.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10219,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10219,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10219,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10219,303,0.88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10219,306,287,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10219,307,56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10219,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10219,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10219,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10219,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10219,601,72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10219,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10219,606,7.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (10220,203,25.69,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10220,204,20.77,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10220,205,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10220,207,1.29,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10220,208,297,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10220,255,52.75,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10220,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10220,291,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10220,301,22,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10220,303,1.29,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10220,306,362,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10220,307,73,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10220,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10220,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10220,401,0.7,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10220,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10220,601,94,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10220,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10220,606,7.72,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (10221,203,29.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10221,204,8.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10221,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10221,207,2.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10221,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10221,255,61.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10221,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10221,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10221,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10221,303,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10221,306,444,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10221,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10221,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10221,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10221,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10221,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10221,601,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10221,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10221,606,2.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10222,203,26.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10222,204,3.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10222,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10222,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10222,208,147,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10222,255,69.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10222,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10222,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10222,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10222,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10222,306,419,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10222,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10222,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (10222,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10222,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10222,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10222,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10222,605,0.038,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10222,606,1.358,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10223,203,30.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10223,204,6.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10223,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10223,207,2.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10223,208,187,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10223,255,62.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10223,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10223,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10223,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10223,303,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10223,306,451,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10223,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10223,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10223,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10223,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10223,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10223,601,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10223,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10223,606,2.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10224,203,21.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10224,204,8.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10224,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10224,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10224,208,166,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10224,255,70.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10224,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10224,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10224,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10224,303,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10224,306,358,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10224,307,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10224,320,2,'100g',2,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (10224,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10224,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10224,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10224,601,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10224,605,0.081,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10224,606,2.76,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10225,203,22.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10225,204,4.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10225,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10225,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10225,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10225,255,73.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10225,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10225,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10225,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10225,303,0.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10225,306,374,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10225,307,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10225,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (10225,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10225,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10225,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10225,601,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10225,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10225,606,1.248,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10226,203,20.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10226,204,10.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10226,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10226,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10226,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10226,255,69.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10226,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10226,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10226,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10226,303,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10226,306,345,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10226,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10226,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10226,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10226,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10226,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10226,601,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10226,605,0.065,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10226,606,3.106,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10227,203,26.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10227,204,13.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10227,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10227,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10227,208,235,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10227,255,59.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10227,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10227,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10227,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10227,303,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10227,306,345,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10227,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10227,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10227,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10227,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10227,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10227,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10227,605,0.058,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10227,606,4.703,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10228,203,21.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10228,204,5.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10228,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10228,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10228,208,144,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10228,255,72.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10228,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10228,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10228,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10228,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10228,306,384,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10228,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10228,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10228,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10228,401,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10228,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10228,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10228,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10228,606,2.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10229,203,29.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10229,204,9.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10229,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10229,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10229,208,211,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10229,255,60.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10229,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10229,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10229,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10229,303,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10229,306,377,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10229,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10229,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (10229,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10229,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10229,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10229,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10229,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10229,606,3.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10858,203,28.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10858,204,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10858,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10858,207,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10858,208,169,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10858,255,64.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10858,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10858,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10858,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10858,303,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10858,306,517,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10858,307,209,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10858,320,0,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (10858,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10858,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10858,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10858,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10858,605,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10858,606,1.797,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10859,203,28.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10859,204,7.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10859,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10859,207,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10859,208,190,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10859,255,62.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10859,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10859,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10859,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10859,303,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10859,306,512,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10859,307,205,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10859,320,2,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (10859,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10859,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10859,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10859,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10859,605,0.087,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10859,606,2.725,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10860,203,35.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10860,204,43.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10860,205,1.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10860,207,7.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10860,208,548,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10860,255,12.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10860,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10860,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10860,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10860,303,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10860,306,539,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10860,307,2193,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10860,320,11,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (10860,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10860,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10860,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10860,601,107,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10860,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10860,606,14.187,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10861,203,39.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10861,204,34.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10861,205,0.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10861,207,6.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10861,208,476,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10861,255,20.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10861,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10861,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10861,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10861,303,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10861,306,525,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10861,307,1783,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10861,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (10861,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10861,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10861,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10861,601,111,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10861,605,0.119,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10861,606,11.644,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10862,203,33.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10862,204,35.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10862,205,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10862,207,5.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10862,208,468,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10862,255,23.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10862,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10862,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10862,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10862,303,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10862,306,499,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10862,307,1684,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10862,320,11,'100g',1,1,'2024-12-12','2013-01-06');
INSERT INTO `cndb_nutval` VALUES (10862,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10862,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10862,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10862,601,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10862,605,0.144,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10862,606,11.964,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10863,203,21.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10863,204,7.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10863,205,0.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10863,207,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10863,208,157,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10863,255,70.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10863,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10863,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10863,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10863,303,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10863,306,85,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10863,307,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10863,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (10863,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10863,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10863,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10863,601,316,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10863,605,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10863,606,2.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10864,203,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10864,204,99.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10864,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10864,207,0.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10864,208,898,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10864,255,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10864,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10864,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10864,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10864,303,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10864,306,15,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10864,307,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10864,320,11,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (10864,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10864,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10864,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10864,601,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10864,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10864,606,31.991,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10865,203,21.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10865,204,3.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10865,205,0.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10865,207,3.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10865,208,121,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10865,255,70.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10865,269,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10865,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10865,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10865,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10865,306,250,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10865,307,1150,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10865,320,11,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10865,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10865,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10865,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10865,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10865,605,0.032,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10865,606,1.254,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10866,203,15.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10866,204,3.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10866,205,0.67,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10866,207,3.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10866,208,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10866,255,77.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10866,269,0.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10866,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10866,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10866,303,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10866,306,205,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10866,307,1170,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10866,320,9,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (10866,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10866,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10866,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10866,601,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10866,605,0.031,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10866,606,1.227,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10867,203,20.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10867,204,4.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10867,205,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10867,207,3.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10867,208,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10867,255,69.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10867,269,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10867,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10867,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10867,303,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10867,306,241,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10867,307,1060,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10867,320,11,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10867,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10867,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10867,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10867,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10867,605,0.028,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10867,606,1.402,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10868,203,22.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10868,204,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10868,205,1.48,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10868,207,4.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10868,208,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10868,255,68.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10868,269,1.48,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10868,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10868,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10868,303,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10868,306,289,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10868,307,1374,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10868,320,12,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10868,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10868,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10868,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10868,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10868,605,0.035,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10868,606,1.439,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10869,203,20.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10869,204,3.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10869,205,1.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10869,207,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10869,208,122,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10869,255,70.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10869,269,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10869,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10869,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10869,303,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10869,306,289,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10869,307,1237,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10869,320,11,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10869,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10869,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10869,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10869,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10869,605,0.029,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10869,606,1.217,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10870,203,15.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10870,204,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10870,205,4.69,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10870,207,4.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10870,208,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10870,255,71.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10870,269,4.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10870,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10870,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10870,303,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10870,306,272,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10870,307,1390,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10870,320,13,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10870,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10870,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10870,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10870,601,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10870,605,0.037,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10870,606,1.528,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10871,203,13.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10871,204,5.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10871,205,4.61,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10871,207,4.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10871,208,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10871,255,72.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10871,269,4.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10871,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10871,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10871,303,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10871,306,245,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10871,307,1335,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10871,320,13,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10871,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10871,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10871,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10871,601,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10871,605,0.047,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10871,606,1.841,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10872,203,14.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10872,204,4.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10872,205,4.22,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10872,207,4.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10872,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10872,255,73.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10872,269,4.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10872,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10872,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10872,303,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10872,306,268,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10872,307,1310,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10872,320,13,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10872,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10872,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10872,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10872,601,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10872,605,0.036,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10872,606,1.447,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10873,203,24.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10873,204,4.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10873,205,0.48,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10873,207,3.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10873,208,137,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10873,255,67.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10873,269,0.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10873,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10873,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10873,303,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10873,306,511,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10873,307,861,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10873,320,11,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10873,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10873,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10873,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10873,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10873,605,0.035,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10873,606,1.418,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10874,203,24.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10874,204,4.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10874,205,0.34,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10874,207,3.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10874,208,145,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10874,255,66.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10874,269,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10874,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10874,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10874,303,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10874,306,458,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10874,307,820,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10874,320,11,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10874,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10874,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10874,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10874,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10874,605,0.036,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10874,606,1.564,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10875,203,27.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10875,204,4.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10875,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10875,207,2.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10875,208,150,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10875,255,65.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10875,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10875,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10875,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10875,303,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10875,306,358,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10875,307,835,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10875,320,13,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10875,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10875,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10875,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10875,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10875,605,0.019,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10875,606,1.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10876,203,22.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10876,204,3.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10876,205,1.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10876,207,3.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10876,208,126,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10876,255,69.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10876,269,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10876,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10876,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10876,303,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10876,306,349,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10876,307,986,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10876,320,13,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10876,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10876,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10876,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10876,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10876,605,0.011,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10876,606,0.493,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10877,203,21.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10877,204,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10877,205,1.15,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10877,207,3.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10877,208,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10877,255,69.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10877,269,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10877,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10877,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10877,303,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10877,306,264,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10877,307,1267,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10877,320,11,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10877,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10877,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10877,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10877,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10877,605,0.039,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10877,606,1.536,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10878,203,18.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10878,204,4.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10878,205,1.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10878,207,3.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10878,208,119,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10878,255,72.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10878,269,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10878,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10878,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10878,303,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10878,306,337,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10878,307,1223,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10878,320,13,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10878,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10878,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10878,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10878,601,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10878,605,0.032,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10878,606,1.401,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10879,203,17.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10879,204,4.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10879,205,1.57,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10879,207,3.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10879,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10879,255,72.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10879,269,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10879,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10879,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10879,303,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10879,306,316,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10879,307,1193,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10879,320,13,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10879,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10879,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10879,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10879,601,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10879,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10879,606,1.424,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10880,203,17.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10880,204,3.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10880,205,1.45,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10880,207,3.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10880,208,110,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10880,255,73.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10880,269,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10880,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10880,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10880,303,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10880,306,317,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10880,307,1141,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10880,320,13,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10880,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10880,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10880,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10880,601,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10880,605,0.036,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10880,606,1.428,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10881,203,21.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10881,204,4.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10881,205,1.26,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10881,207,3.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10881,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10881,255,69.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10881,269,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10881,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10881,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10881,303,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10881,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10881,307,1045,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10881,320,11,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10881,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10881,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10881,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10881,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10881,605,0.043,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10881,606,1.471,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10882,203,20.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10882,204,3.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10882,205,1.05,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10882,207,3.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10882,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10882,255,71.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10882,269,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10882,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10882,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10882,303,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10882,306,364,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10882,307,1163,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10882,320,13,'100g',1,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (10882,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10882,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10882,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10882,601,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10882,605,0.022,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10882,606,0.975,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10883,203,20.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10883,204,3.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10883,205,0.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10883,207,3.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10883,208,113,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10883,255,71.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10883,269,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10883,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10883,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10883,303,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10883,306,367,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10883,307,1180,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10883,320,13,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10883,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10883,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10883,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10883,601,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10883,605,0.021,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10883,606,1.044,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10884,203,19.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10884,204,3.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10884,205,1.03,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10884,207,3.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10884,208,111,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10884,255,72.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10884,269,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10884,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10884,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10884,303,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10884,306,347,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10884,307,1098,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10884,320,13,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10884,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10884,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10884,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10884,601,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10884,605,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10884,606,0.934,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10885,203,18.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10885,204,1.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10885,205,0.71,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10885,207,3.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10885,208,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10885,255,76.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10885,269,0.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10885,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10885,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10885,303,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10885,306,229,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10885,307,1040,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10885,320,9,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (10885,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10885,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10885,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10885,601,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10885,605,0.012,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10885,606,0.592,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10886,203,17.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10886,204,2.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10886,205,1.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10886,207,3.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10886,208,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10886,255,76.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10886,269,1.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10886,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10886,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10886,303,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10886,306,221,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10886,307,1090,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10886,320,9,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10886,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10886,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10886,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10886,601,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10886,605,0.019,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10886,606,0.768,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10887,203,17.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10887,204,3.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10887,205,1.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10887,207,3.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10887,208,107,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10887,255,74.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10887,269,0.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10887,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10887,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10887,303,0.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10887,306,221,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10887,307,1070,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10887,320,10,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (10887,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10887,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10887,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10887,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10887,605,0.028,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10887,606,1.105,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10888,203,14.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10888,204,3.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10888,205,2.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10888,207,3.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10888,208,103,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10888,255,75.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10888,269,0.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10888,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10888,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10888,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10888,306,209,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10888,307,1160,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10888,320,9,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10888,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10888,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10888,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10888,601,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10888,605,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10888,606,1.266,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10889,203,17.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10889,204,4.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10889,205,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10889,207,3.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10889,208,113,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10889,255,73.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10889,269,1.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10889,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10889,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10889,303,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10889,306,234,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10889,307,1090,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10889,320,9,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10889,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10889,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10889,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10889,601,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10889,605,0.041,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10889,606,1.384,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10890,203,22.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10890,204,3.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10890,205,0.43,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10890,207,2.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10890,208,122,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10890,255,70.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10890,269,0.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10890,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10890,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10890,303,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10890,306,303,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10890,307,893,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10890,320,10,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10890,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10890,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10890,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10890,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10890,605,0.029,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10890,606,1.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10891,203,25.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10891,204,3.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10891,205,0.3,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10891,207,2.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10891,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10891,255,70.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10891,269,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10891,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10891,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10891,303,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10891,306,299,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10891,307,809,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10891,320,10,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (10891,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10891,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10891,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10891,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10891,605,0.024,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10891,606,1.048,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10892,203,24.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10892,204,2.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10892,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10892,207,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10892,208,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10892,255,70.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10892,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10892,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10892,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10892,303,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10892,306,300,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10892,307,861,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10892,320,12,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10892,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10892,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10892,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10892,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10892,605,0.012,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10892,606,0.726,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10893,203,19.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10893,204,3.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10893,205,1.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10893,207,4.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10893,208,109,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10893,255,72.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10893,269,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10893,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10893,301,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10893,303,0.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10893,306,317,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10893,307,895,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10893,320,12,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10893,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10893,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10893,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10893,601,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10893,605,0.022,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10893,606,1.009,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10894,203,8.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10894,204,51.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10894,205,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10894,207,2.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10894,208,507,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10894,255,35.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10894,269,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10894,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10894,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10894,303,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10894,306,195,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10894,307,677,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10894,320,12,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10894,328,1.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10894,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10894,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10894,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10894,605,0.371,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10894,606,17.048,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10895,203,7.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10895,204,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10895,205,1.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10895,207,1.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10895,208,515,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10895,255,35.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10895,269,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10895,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10895,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10895,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10895,306,174,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10895,307,616,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10895,320,13,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10895,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10895,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10895,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10895,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10895,605,0.412,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10895,606,17.433,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10898,203,19.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10898,204,10.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10898,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10898,207,2.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10898,208,171,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10898,255,68.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10898,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10898,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10898,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10898,303,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10898,306,47,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10898,307,1050,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10898,320,23,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10898,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10898,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10898,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10898,601,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10898,605,0.113,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10898,606,3.231,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10899,203,27.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10899,204,4.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10899,205,0.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10899,207,3.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10899,208,148,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10899,255,65.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10899,269,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10899,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10899,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10899,303,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10899,306,427,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10899,307,870,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10899,320,0,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10899,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10899,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10899,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10899,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10899,605,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10899,606,1.253,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10900,203,19.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10900,204,3.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10900,205,1.02,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10900,207,3.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10900,208,112,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10900,255,72.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10900,269,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10900,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10900,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10900,303,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10900,306,346,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10900,307,1096,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10900,320,13,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10900,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10900,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10900,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10900,601,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10900,605,0.022,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10900,606,1.005,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10901,203,18.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10901,204,5.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10901,205,1.18,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10901,207,4.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10901,208,129,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10901,255,70.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10901,269,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10901,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10901,301,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10901,303,0.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10901,306,310,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10901,307,881,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10901,320,12,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10901,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10901,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10901,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10901,601,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10901,605,0.042,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10901,606,1.833,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10902,203,22.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10902,204,7.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10902,205,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10902,207,2.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10902,208,159,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10902,255,67.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10902,269,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10902,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10902,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10902,303,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10902,306,289,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10902,307,839,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10902,320,12,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (10902,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10902,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10902,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10902,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10902,605,0.049,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10902,606,2.236,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10903,203,22.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10903,204,11.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10903,205,0.32,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10903,207,2.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10903,208,191,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10903,255,65.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10903,269,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10903,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10903,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10903,303,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10903,306,279,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10903,307,779,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10903,320,10,'100g',2,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10903,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10903,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10903,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10903,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10903,605,0.085,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10903,606,3.614,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10904,203,19.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10904,204,13.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10904,205,0.43,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10904,207,2.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10904,208,200,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10904,255,63.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10904,269,0.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10904,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10904,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10904,303,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10904,306,278,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10904,307,838,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10904,320,11,'100g',2,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10904,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10904,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10904,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10904,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10904,605,0.105,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10904,606,4.373,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10905,203,14.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10905,204,4.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10905,205,4.21,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10905,207,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10905,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10905,255,72.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10905,269,4.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10905,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10905,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10905,303,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10905,306,267,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10905,307,1308,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10905,320,13,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10905,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10905,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10905,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10905,601,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10905,605,0.037,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10905,606,1.489,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10906,203,13.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10906,204,9.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10906,205,2.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10906,207,3.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10906,208,149,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10906,255,71.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10906,269,0.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10906,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10906,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10906,303,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10906,306,205,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10906,307,1099,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10906,320,10,'100g',2,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10906,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10906,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10906,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10906,601,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10906,605,0.072,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10906,606,3.076,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10907,203,14.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10907,204,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10907,205,1.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10907,207,2.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10907,208,243,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10907,255,61.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10907,269,0.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10907,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10907,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10907,303,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10907,306,215,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10907,307,936,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10907,320,11,'100g',2,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10907,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10907,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10907,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10907,601,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10907,605,0.161,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10907,606,6.583,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10908,203,16.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10908,204,12.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10908,205,1.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10908,207,2.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10908,208,179,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10908,255,67.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10908,269,0.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10908,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10908,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10908,303,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10908,306,213,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10908,307,990,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10908,320,10,'100g',2,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10908,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10908,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10908,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10908,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10908,605,0.096,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10908,606,3.984,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10909,203,17.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10909,204,5.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10909,205,1.42,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10909,207,3.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10909,208,121,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10909,255,72.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10909,269,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10909,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10909,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10909,303,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10909,306,312,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10909,307,1126,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10909,320,13,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10909,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10909,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10909,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10909,601,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10909,605,0.047,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10909,606,1.889,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10910,203,15.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10910,204,10.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10910,205,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10910,207,3.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10910,208,164,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10910,255,69.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10910,269,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10910,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10910,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10910,303,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10910,306,213,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10910,307,1011,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10910,320,9,'100g',2,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10910,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10910,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10910,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10910,601,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10910,605,0.084,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10910,606,3.554,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10911,203,16.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10911,204,11.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10911,205,0.66,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10911,207,2.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10911,208,167,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10911,255,69.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10911,269,0.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10911,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10911,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10911,303,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10911,306,219,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10911,307,964,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10911,320,9,'100g',2,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10911,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10911,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10911,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10911,601,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10911,605,0.084,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10911,606,3.607,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10912,203,13.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10912,204,12.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10912,205,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10912,207,3.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10912,208,172,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10912,255,69.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10912,269,0.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10912,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10912,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10912,303,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10912,306,199,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10912,307,1069,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10912,320,10,'100g',2,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10912,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10912,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10912,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10912,601,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10912,605,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10912,606,4.176,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10913,203,20.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10913,204,8.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10913,205,0.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10913,207,3.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10913,208,161,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10913,255,67.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10913,269,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10913,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10913,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10913,303,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10913,306,244,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10913,307,1101,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10913,320,11,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10913,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10913,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10913,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10913,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10913,605,0.067,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10913,606,2.897,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10914,203,18.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10914,204,13.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10914,205,1.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10914,207,3.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10914,208,200,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10914,255,63.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10914,269,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10914,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10914,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10914,303,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10914,306,232,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10914,307,988,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10914,320,11,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10914,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10914,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10914,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10914,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10914,605,0.093,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10914,606,4.371,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10915,203,20.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10915,204,8.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10915,205,1.54,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10915,207,3.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10915,208,166,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10915,255,65.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10915,269,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10915,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10915,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10915,303,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10915,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10915,307,1309,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10915,320,12,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10915,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10915,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10915,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10915,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10915,605,0.067,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10915,606,2.901,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10916,203,18.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10916,204,5.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10916,205,1.72,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10916,207,3.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10916,208,125,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10916,255,71.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10916,269,1.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10916,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10916,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10916,303,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10916,306,334,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10916,307,1212,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10916,320,13,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10916,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10916,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10916,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10916,601,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10916,605,0.039,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10916,606,1.717,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10917,203,17.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10917,204,5.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10917,205,1.54,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10917,207,3.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10917,208,126,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10917,255,71.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10917,269,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10917,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10917,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10917,303,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10917,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10917,307,1181,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10917,320,13,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10917,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10917,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10917,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10917,601,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10917,605,0.009,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10917,606,1.787,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10918,203,19.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10918,204,11.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10918,205,1.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10918,207,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10918,208,186,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10918,255,64.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10918,269,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10918,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10918,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10918,303,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10918,306,254,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10918,307,1181,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10918,320,12,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10918,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10918,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10918,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10918,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10918,605,0.087,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10918,606,3.783,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10919,203,18.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10919,204,17.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10919,205,1.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10919,207,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10919,208,234,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10919,255,60.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10919,269,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10919,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10919,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10919,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10919,306,216,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10919,307,945,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10919,320,12,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10919,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10919,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10919,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10919,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10919,605,0.133,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10919,606,5.715,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10920,203,19.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10920,204,7.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10920,205,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10920,207,3.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10920,208,155,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10920,255,67.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10920,269,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10920,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10920,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10920,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10920,306,281,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10920,307,1188,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10920,320,11,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10920,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10920,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10920,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10920,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10920,605,0.058,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10920,606,2.586,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10921,203,15.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10921,204,5.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10921,205,4.69,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10921,207,4.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10921,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10921,255,71.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10921,269,4.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10921,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10921,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10921,303,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10921,306,272,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10921,307,1389,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10921,320,13,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10921,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10921,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10921,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10921,601,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10921,605,0.001,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10921,606,1.553,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10922,203,13.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10922,204,5.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10922,205,4.61,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10922,207,4.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10922,208,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10922,255,72.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10922,269,4.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10922,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10922,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10922,303,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10922,306,245,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10922,307,1335,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10922,320,13,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10922,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10922,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10922,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10922,601,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10922,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10922,606,1.841,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10923,203,22.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10923,204,9.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10923,205,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10923,207,3.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10923,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10923,255,64.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10923,269,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10923,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10923,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10923,303,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10923,306,477,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10923,307,841,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10923,320,11,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10923,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10923,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10923,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10923,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10923,605,0.072,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10923,606,3.116,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10924,203,22.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10924,204,10.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10924,205,0.33,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10924,207,2.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10924,208,191,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10924,255,62.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10924,269,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10924,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10924,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10924,303,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10924,306,424,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10924,307,801,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10924,320,11,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10924,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10924,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10924,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10924,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10924,605,0.079,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10924,606,3.545,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10925,203,26.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10925,204,8.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10925,205,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10925,207,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10925,208,180,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10925,255,63.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10925,269,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10925,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10925,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10925,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10925,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10925,307,821,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10925,320,13,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10925,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10925,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10925,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10925,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10925,605,0.048,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10925,606,2.427,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10926,203,20.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10926,204,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10926,205,1.04,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10926,207,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10926,208,118,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10926,255,70.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10926,269,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10926,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10926,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10926,303,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10926,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10926,307,1160,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10926,320,13,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10926,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10926,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10926,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10926,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10926,605,0.002,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10926,606,1.054,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10927,203,22.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10927,204,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10927,205,1.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10927,207,3.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10927,208,139,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10927,255,68.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10927,269,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10927,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10927,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10927,303,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10927,306,345,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10927,307,977,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10927,320,13,'100g',2,1,'2024-12-12','2013-01-07');
INSERT INTO `cndb_nutval` VALUES (10927,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10927,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10927,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10927,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10927,605,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10927,606,0.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10928,203,20.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10928,204,3.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10928,205,0.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10928,207,3.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10928,208,114,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10928,255,71.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10928,269,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10928,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10928,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10928,303,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10928,306,367,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10928,307,1179,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10928,320,13,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10928,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10928,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10928,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10928,601,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10928,605,0.001,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10928,606,1.084,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10929,203,23.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10929,204,8.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10929,205,0.64,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10929,207,2.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10929,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10929,255,63.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10929,269,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10929,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10929,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10929,303,1.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10929,306,370,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10929,307,826,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10929,320,1,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10929,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10929,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10929,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10929,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10929,605,0.063,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10929,606,2.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10931,203,26.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10931,204,3.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10931,205,0.68,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10931,207,3.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10931,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10931,255,67.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10931,269,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10931,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10931,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10931,303,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10931,306,394,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10931,307,846,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10931,320,0,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10931,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10931,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10931,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10931,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10931,605,0.021,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10931,606,0.917,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10932,203,24.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10932,204,2.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10932,205,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10932,207,2.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10932,208,125,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10932,255,69.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10932,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10932,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10932,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10932,303,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10932,306,385,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10932,307,737,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10932,320,0,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10932,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10932,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10932,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10932,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10932,605,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10932,606,0.874,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10933,203,26.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10933,204,3.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10933,205,0.68,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10933,207,2.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10933,208,139,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10933,255,67.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10933,269,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10933,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10933,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10933,303,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10933,306,378,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10933,307,828,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10933,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10933,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10933,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10933,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10933,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10933,605,0.025,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10933,606,1.134,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10934,203,23.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10934,204,3.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10934,205,0.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10934,207,3.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10934,208,125,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10934,255,69.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10934,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10934,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10934,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10934,303,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10934,306,364,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10934,307,846,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10934,320,0,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10934,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10934,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10934,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10934,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10934,605,0.022,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10934,606,0.981,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10935,203,24.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10935,204,9.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10935,205,0.64,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10935,207,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10935,208,191,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10935,255,63.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10935,269,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10935,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10935,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10935,303,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10935,306,356,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10935,307,810,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10935,320,1,'100g',1,1,'2024-12-12','2013-01-07');
INSERT INTO `cndb_nutval` VALUES (10935,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10935,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10935,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10935,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10935,605,0.066,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10935,606,3.018,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10936,203,21.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10936,204,9.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10936,205,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10936,207,2.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10936,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10936,255,65.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10936,269,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10936,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10936,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10936,303,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10936,306,339,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10936,307,816,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10936,320,2,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10936,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10936,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10936,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10936,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10936,605,0.074,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10936,606,3.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10937,203,25.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10937,204,8.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10937,205,0.7,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10937,207,3.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10937,208,181,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10937,255,62.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10937,269,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10937,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10937,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10937,303,1.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10937,306,405,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10937,307,852,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10937,320,1,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10937,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10937,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10937,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10937,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10937,605,0.06,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (10937,606,2.75,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (10938,203,24.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10938,204,3.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10938,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10938,207,2.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10938,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10938,255,69.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10938,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10938,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10938,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10938,303,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10938,306,370,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10938,307,760,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10938,320,0,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10938,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10938,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10938,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10938,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10938,605,0.027,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10938,606,1.099,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10939,203,22.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10939,204,9.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10939,205,0.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10939,207,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10939,208,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10939,255,66.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10939,269,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10939,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10939,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10939,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10939,306,348,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10939,307,744,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10939,320,1,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (10939,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10939,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10939,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10939,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10939,605,0.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10939,606,2.945,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10940,203,20.89,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10940,204,30.86,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10940,205,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10940,207,0.82,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10940,208,361,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10940,255,48.11,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10940,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10940,291,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10940,301,19,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10940,303,1.43,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10940,306,265,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10940,307,91,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10940,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (10940,328,2.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10940,401,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10940,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10940,601,105,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10940,605,0.236,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10940,606,9.242,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10942,203,9.27,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10942,204,52.33,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10942,205,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10942,207,0.72,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10942,208,508,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10942,255,38.32,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10942,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10942,291,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10942,301,22,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10942,303,0.47,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10942,306,191,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10942,307,81,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10942,320,0,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (10942,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10942,401,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10942,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10942,601,83,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10942,605,0.579,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10942,606,18.488,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10943,203,21.61,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10943,204,3.15,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10943,205,0.31,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10943,207,1.86,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10943,208,116,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10943,255,73.07,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10943,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10943,291,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10943,301,5,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10943,303,0.98,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10943,306,567,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10943,307,231,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10943,320,0,'100g',1,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (10943,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10943,401,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10943,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10943,601,57,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10943,605,0.03,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10943,606,1.077,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10944,203,20.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10944,204,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10944,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10944,207,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10944,208,106,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10944,255,76.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10944,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10944,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10944,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10944,303,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10944,306,527,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10944,307,243,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10944,320,0,'100g',1,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (10944,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10944,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10944,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10944,601,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10944,605,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10944,606,0.671,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10945,203,27.58,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10945,204,12.14,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10945,205,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10945,207,1.21,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10945,208,227,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10945,255,59.2,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10945,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10945,291,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10945,301,26,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10945,303,1.82,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10945,306,388,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10945,307,154,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10945,320,0,'100g',1,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (10945,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10945,401,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10945,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10945,601,98,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10945,605,0.094,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10945,606,4.62,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10946,203,18.29,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10946,204,5.36,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10946,205,0.18,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10946,207,1.32,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10946,208,122,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10946,255,74.85,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10946,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10946,291,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10946,301,14,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10946,303,1.04,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10946,306,419,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10946,307,165,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10946,320,0,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (10946,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10946,401,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10946,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10946,601,59,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10946,605,0.036,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10946,606,1.873,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10947,203,29.65,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10947,204,5.73,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10947,205,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10947,207,2.09,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10947,208,170,'100g',3,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10947,255,63.06,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10947,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10947,291,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10947,301,9,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10947,303,0.56,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10947,306,608,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10947,307,315,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10947,320,0,'100g',1,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (10947,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10947,401,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10947,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10947,601,70,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10947,605,0.017,'100g',3,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10947,606,1.957,'100g',3,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10948,203,21.09,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10948,204,3.48,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10948,205,0.22,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10948,207,1.68,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10948,208,117,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10948,255,73.53,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10948,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10948,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10948,301,7,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10948,303,0.41,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10948,306,537,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10948,307,278,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10948,320,0,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (10948,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10948,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10948,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10948,601,51,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10948,605,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10948,606,1.052,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10949,203,19.45,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10949,204,10.26,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10949,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10949,207,1.55,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10949,208,171,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10949,255,68.65,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10949,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10949,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10949,301,9,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10949,303,0.42,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10949,306,489,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10949,307,251,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10949,320,0,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (10949,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10949,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10949,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10949,601,56,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10949,605,0.131,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (10949,606,2.53,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10950,203,28.33,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10950,204,9.42,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10950,205,0.02,'100g',3,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10950,207,2.01,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10950,208,198,'100g',3,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10950,255,60.71,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10950,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10950,291,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10950,301,11,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10950,303,0.57,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10950,306,581,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10950,307,302,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10950,320,0,'100g',1,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (10950,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10950,401,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10950,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10950,601,71,'100g',1,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10950,605,0.06,'100g',3,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10950,606,3.268,'100g',3,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10951,203,20.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10951,204,3.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10951,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10951,207,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10951,208,114,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10951,255,76.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10951,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10951,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10951,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10951,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10951,306,519,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10951,307,239,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10951,320,0,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (10951,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10951,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10951,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10951,601,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10951,605,0.032,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10951,606,1.045,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10952,203,21.5,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10952,204,3.7,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10952,205,0.31,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10952,207,1.85,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10952,208,121,'100g',3,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10952,255,72.64,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10952,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10952,291,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10952,301,5,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10952,303,0.97,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10952,306,563,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10952,307,230,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10952,320,0,'100g',1,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (10952,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10952,401,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10952,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10952,601,57,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10952,605,0.036,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10952,606,1.27,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10953,203,17.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10953,204,11.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10953,205,0.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10953,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10953,208,169,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10953,255,70.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10953,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10953,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10953,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10953,303,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10953,306,391,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10953,307,155,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10953,320,0,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (10953,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10953,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10953,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10953,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10953,605,0.103,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10953,606,3.912,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10954,203,25.84,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10954,204,16.94,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10954,205,0.03,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10954,207,1.19,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10954,208,263,'100g',3,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10954,255,56.13,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10954,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10954,291,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10954,301,27,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10954,303,1.72,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10954,306,370,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10954,307,151,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10954,320,0,'100g',1,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (10954,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10954,401,0,'100g',4,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10954,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10954,601,97,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10954,605,0.15,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10954,606,6.288,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10955,203,22.27,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10955,204,9.38,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10955,205,0.52,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10955,207,2.65,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10955,208,176,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10955,255,65.19,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10955,269,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10955,291,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10955,301,7,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10955,303,1.01,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10955,306,358,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10955,307,722,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10955,320,2,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (10955,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10955,401,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10955,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (10955,601,62,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10955,605,0.07,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10955,606,3.008,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (10956,203,27.57,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10956,204,4.41,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10956,205,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10956,207,1.07,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10956,208,158,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10956,255,68.72,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10956,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10956,291,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10956,301,7,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10956,303,0.97,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10956,306,366,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10956,307,76,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10956,320,0,'100g',1,1,'2024-12-12','2008-01-02');
INSERT INTO `cndb_nutval` VALUES (10956,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10956,401,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10956,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10956,601,81,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10956,605,0.022,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10956,606,1.358,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10957,203,21.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10957,204,3.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10957,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10957,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10957,208,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10957,255,75.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10957,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10957,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10957,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10957,303,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10957,306,365,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10957,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10957,320,0,'100g',1,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (10957,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10957,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10957,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10957,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10957,605,0.016,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10957,606,1.187,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10958,203,22.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10958,204,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10958,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10958,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10958,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10958,255,74.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10958,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10958,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10958,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10958,303,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10958,306,378,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10958,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10958,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (10958,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10958,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10958,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10958,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10958,605,0.015,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10958,606,1.074,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10959,203,28.47,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10959,204,4.49,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10959,205,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10959,207,1.13,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10959,208,162,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10959,255,67.26,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10959,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10959,291,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10959,301,7,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10959,303,0.92,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10959,306,364,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10959,307,54,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10959,320,0,'100g',1,1,'2024-12-12','2008-01-02');
INSERT INTO `cndb_nutval` VALUES (10959,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10959,401,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10959,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10959,601,78,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10959,605,0.02,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10959,606,1.325,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10960,203,27.47,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10960,204,4.23,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10960,205,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10960,207,1.21,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10960,208,155,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10960,255,68.7,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10960,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10960,291,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10960,301,8,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10960,303,1.25,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10960,306,415,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10960,307,53,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10960,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (10960,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10960,401,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10960,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10960,601,82,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10960,605,0.022,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10960,606,1.322,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10961,203,21.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10961,204,3.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10961,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10961,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10961,208,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10961,255,74.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10961,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10961,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10961,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10961,303,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10961,306,391,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10961,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10961,320,0,'100g',1,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (10961,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10961,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10961,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10961,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10961,605,0.014,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10961,606,1.012,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10962,203,31.11,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10962,204,2.56,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10962,205,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10962,207,1.14,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10962,208,156,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10962,255,66.99,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10962,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10962,291,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10962,301,5,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10962,303,1.06,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10962,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10962,307,43,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10962,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (10962,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10962,401,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10962,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10962,601,84,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10962,605,0.012,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10962,606,0.791,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (10963,203,22.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10963,204,1.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10963,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10963,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10963,208,113,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10963,255,75.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10963,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10963,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10963,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10963,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10963,306,399,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10963,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10963,320,0,'100g',1,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (10963,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10963,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10963,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10963,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10963,605,0.009,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10963,606,0.524,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (10972,203,17.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10972,204,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10972,205,0.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10972,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10972,208,218,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10972,255,64.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10972,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10972,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10972,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10972,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10972,306,244,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10972,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10972,320,0,'100g',1,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (10972,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10972,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10972,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10972,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10972,605,0.124,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10972,606,4.93,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10973,203,21.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10973,204,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10973,205,0.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10973,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10973,208,121,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10973,255,73.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10973,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10973,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10973,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10973,303,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10973,306,310,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10973,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10973,320,0,'100g',1,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (10973,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10973,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10973,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10973,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10973,605,0.032,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (10973,606,1.42,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10974,203,22.83,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10974,204,32.93,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10974,205,1.39,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10974,207,1.18,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10974,208,393,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10974,255,41.67,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10974,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10974,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10974,301,20,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10974,303,1.15,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10974,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10974,307,94,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10974,320,0,'100g',1,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (10974,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10974,401,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10974,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10974,601,100,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10974,605,0.229,'100g',3,1,'2010-01-04','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10974,606,11.345,'100g',3,1,'2010-01-04','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (10975,203,26.69,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10975,204,20.04,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10975,205,0.58,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10975,207,1.34,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10975,208,289,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10975,255,51.35,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10975,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10975,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10975,301,20,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10975,303,1.1,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10975,306,354,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10975,307,89,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10975,320,0,'100g',1,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (10975,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10975,401,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10975,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10975,601,89,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10975,605,0.15,'100g',3,1,'2010-01-04','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10975,606,6.631,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10976,203,30.55,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10976,204,7.15,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10976,205,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10976,207,1.49,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10976,208,187,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10976,255,61.03,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10976,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10976,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10976,301,19,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10976,303,1.05,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10976,306,428,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10976,307,84,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10976,320,0,'100g',1,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (10976,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10976,401,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10976,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10976,601,78,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10976,605,0.07,'100g',1,1,'2010-01-04','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10976,606,1.951,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10977,203,22.59,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10977,204,31.42,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10977,205,1.08,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10977,207,1.05,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10977,208,377,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10977,255,43.85,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10977,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10977,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10977,301,20,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10977,303,1.21,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10977,306,275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10977,307,91,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10977,320,0,'100g',1,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (10977,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10977,401,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10977,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10977,601,99,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10977,605,0.229,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10977,606,10.804,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10978,203,27.14,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10978,204,21.39,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10978,205,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10978,207,1.26,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10978,208,301,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10978,255,51.97,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10978,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10978,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10978,301,20,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10978,303,1.16,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10978,306,345,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10978,307,89,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10978,320,0,'100g',1,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (10978,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10978,401,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10978,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10978,601,97,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10978,605,0.192,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10978,606,7.453,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10979,203,31.69,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10979,204,6.2,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10979,205,0.57,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10979,207,1.47,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10979,208,185,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10979,255,60.08,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10979,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10979,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10979,301,20,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10979,303,1.11,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10979,306,415,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10979,307,88,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10979,320,0,'100g',1,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (10979,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10979,401,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10979,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10979,601,85,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (10979,605,0.068,'100g',1,1,'2010-01-04','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10979,606,1.86,'100g',3,1,'2010-01-04','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (10980,203,20.85,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10980,204,9.84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10980,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10980,207,1.1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10980,208,172,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10980,255,68.57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10980,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10980,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10980,301,26,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10980,303,0.84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10980,306,268,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10980,307,95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10980,320,3,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (10980,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10980,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10980,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10980,601,66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10980,605,0.083,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10980,606,3.477,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10981,203,24.15,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10981,204,17.65,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10981,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10981,207,1.08,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10981,208,255,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10981,255,57.58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10981,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10981,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10981,301,44,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10981,303,0.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10981,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10981,307,98,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10981,320,4,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (10981,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10981,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10981,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10981,601,84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10981,605,0.159,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10981,606,6.221,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (10982,203,21.35,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10982,204,3.78,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10982,205,0.82,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10982,207,1.11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10982,208,123,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10982,255,72.94,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10982,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10982,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10982,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10982,303,0.77,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10982,306,375,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10982,307,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10982,320,3,'100g',2,1,'2024-12-12','2011-01-01');
INSERT INTO `cndb_nutval` VALUES (10982,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10982,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10982,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10982,601,58,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10982,605,0.039,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10982,606,1.384,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10983,203,27.58,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10983,204,7.14,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10983,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10983,207,1.24,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10983,208,175,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10983,255,64.76,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10983,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10983,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10983,301,11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10983,303,0.92,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10983,306,457,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10983,307,68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10983,320,1,'100g',2,1,'2024-12-12','2011-01-01');
INSERT INTO `cndb_nutval` VALUES (10983,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10983,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10983,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10983,601,76,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10983,605,0.052,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10983,606,2.56,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10984,203,26.14,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10984,204,6.74,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10984,205,0.89,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10984,207,1.22,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10984,208,169,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10984,255,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10984,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10984,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10984,301,7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10984,303,0.92,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10984,306,430,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10984,307,58,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10984,320,2,'100g',2,1,'2024-12-12','2011-01-01');
INSERT INTO `cndb_nutval` VALUES (10984,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10984,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10984,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10984,601,76,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10984,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10984,606,1.638,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10985,203,27.83,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10985,204,11.65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10985,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10985,207,1.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10985,208,216,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10985,255,59.98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10985,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10985,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10985,301,7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10985,303,0.92,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10985,306,431,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10985,307,58,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10985,320,3,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10985,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10985,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10985,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10985,601,89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10985,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10985,606,2.831,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10986,203,27.83,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10986,204,11.65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10986,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10986,207,1.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10986,208,216,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10986,255,59.98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10986,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10986,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10986,301,61,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10986,303,1.02,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10986,306,370,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10986,307,84,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10986,320,3,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10986,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10986,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10986,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10986,601,89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10986,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10986,606,3.096,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10987,203,29.2,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10987,204,11.38,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10987,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10987,207,1.26,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10987,208,219,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10987,255,58.72,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10987,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10987,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10987,301,12,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10987,303,0.98,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10987,306,486,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10987,307,72,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10987,320,1,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10987,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10987,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10987,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10987,601,99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10987,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10987,606,4.079,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10988,203,24.73,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10988,204,11.13,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10988,205,0.83,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10988,207,1.16,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10988,208,202,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10988,255,62.14,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10988,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10988,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10988,301,8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10988,303,0.89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10988,306,407,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10988,307,58,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10988,320,4,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10988,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10988,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10988,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10988,601,77,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10988,605,0.035,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10988,606,3.28,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10989,203,20.54,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10989,204,7.94,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10989,205,0.76,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10989,207,1.07,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10989,208,157,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10989,255,69.7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10989,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10989,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10989,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10989,303,0.74,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10989,306,372,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10989,307,64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10989,320,4,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10989,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10989,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10989,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10989,601,59,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10989,605,0.077,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10989,606,2.767,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10990,203,26.48,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10990,204,10.32,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10990,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10990,207,1.2,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10990,208,199,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10990,255,62.69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10990,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10990,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10990,301,12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10990,303,0.89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10990,306,439,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10990,307,67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10990,320,2,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10990,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10990,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10990,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10990,601,76,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10990,605,0.074,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10990,606,3.706,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10991,203,26.28,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10991,204,15.73,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10991,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10991,207,1.05,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10991,208,247,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10991,255,57.45,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10991,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10991,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10991,301,8,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10991,303,0.89,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10991,306,408,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10991,307,58,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10991,320,4,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10991,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10991,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10991,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10991,601,88,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10991,605,0.036,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10991,606,4.408,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10992,203,25.58,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10992,204,17.56,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10992,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10992,207,1.02,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10992,208,260,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10992,255,56.32,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10992,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10992,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10992,301,57,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10992,303,0.96,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10992,306,344,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10992,307,81,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10992,320,5,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10992,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10992,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10992,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10992,601,87,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10992,605,0.052,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10992,606,5.311,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10993,203,26.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10993,204,18.31,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10993,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10993,207,1.16,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10993,208,270,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10993,255,54.61,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10993,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10993,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10993,301,13,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10993,303,0.91,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10993,306,441,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10993,307,70,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10993,320,4,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (10993,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10993,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10993,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10993,601,96,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10993,605,0.06,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10993,606,6.581,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (10998,203,28.31,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10998,204,2.78,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10998,205,1.8,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (10998,207,4.6,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10998,208,146,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10998,255,62.5,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10998,269,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10998,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10998,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10998,303,0.56,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10998,306,999,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10998,307,993,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10998,320,0,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (10998,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (10998,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10998,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (10998,601,67,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (10998,605,0.008,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (10998,606,1.039,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11001,203,3.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11001,204,0.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11001,205,2.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11001,207,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11001,208,23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11001,255,92.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11001,269,0.2,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11001,291,1.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11001,301,32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11001,303,0.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11001,306,79,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11001,307,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11001,320,8,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (11001,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11001,401,8.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11001,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11001,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11001,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11001,606,0.069,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11003,203,2.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11003,204,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11003,205,4.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11003,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11003,208,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11003,255,91.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11003,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11003,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11003,301,215,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11003,303,2.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11003,306,611,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11003,307,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11003,320,146,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11003,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11003,401,43.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11003,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11003,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11003,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11003,606,0.091,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11004,203,2.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11004,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11004,205,4.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11004,207,2.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11004,208,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11004,255,91.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11004,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11004,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11004,301,209,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11004,303,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11004,306,641,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11004,307,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11004,320,139,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11004,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11004,401,41.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11004,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11004,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11004,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11004,606,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11007,203,3.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11007,204,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11007,205,10.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11007,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11007,208,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11007,255,84.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11007,269,0.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11007,291,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11007,301,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11007,303,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11007,306,370,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11007,307,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11007,320,1,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11007,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11007,401,11.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11007,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11007,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11007,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11007,606,0.036,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11008,203,2.89,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11008,204,0.34,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11008,205,11.95,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11008,207,0.74,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11008,208,53,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11008,255,84.08,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11008,269,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11008,291,5.7,'100g',3,1,'1996-09-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11008,301,21,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11008,303,0.61,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11008,306,286,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11008,307,60,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11008,320,1,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11008,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11008,401,7.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11008,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11008,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11008,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11008,606,0.079,'100g',1,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11009,203,2.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11009,204,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11009,205,7.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11009,207,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11009,208,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11009,255,88.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11009,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11009,291,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11009,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11009,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11009,306,248,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11009,307,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11009,320,8,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11009,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11009,401,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11009,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11009,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11009,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11009,606,0.099,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11010,203,3.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11010,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11010,205,9.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11010,207,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11010,208,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11010,255,86.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11010,269,0.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11010,291,4.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11010,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11010,303,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11010,306,264,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11010,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11010,320,1,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11010,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11010,401,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11010,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11010,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11010,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11010,606,0.119,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11011,203,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11011,204,0.12,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11011,205,3.88,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11011,207,0.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11011,208,20,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11011,255,93.22,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11011,269,1.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11011,291,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11011,301,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11011,303,2.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11011,306,202,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11011,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11011,320,38,'100g',1,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (11011,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11011,401,5.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11011,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11011,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11011,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11011,606,0.04,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11012,203,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11012,204,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11012,205,4.11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11012,207,0.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11012,208,22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11012,255,92.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11012,269,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11012,291,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11012,301,23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11012,303,0.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11012,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11012,307,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11012,320,50,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11012,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11012,401,7.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11012,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11012,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11012,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11012,606,0.048,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11013,203,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11013,204,0.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11013,205,2.48,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11013,207,1.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11013,208,15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11013,255,94.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11013,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11013,291,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11013,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11013,303,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11013,306,172,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11013,307,284,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11013,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11013,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11013,401,16.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11013,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11013,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11013,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11013,606,0.044,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11015,203,2.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11015,204,0.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11015,205,2.46,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11015,207,0.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11015,208,19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11015,255,93.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11015,269,1.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11015,291,1.6,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11015,301,16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11015,303,1.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11015,306,172,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11015,307,287,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11015,320,41,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (11015,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11015,401,18.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11015,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11015,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11015,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11015,606,0.147,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11018,203,3.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11018,204,0.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11018,205,4.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11018,207,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11018,208,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11018,255,91.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11018,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11018,291,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11018,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11018,303,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11018,306,253,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11018,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11018,320,47,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11018,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11018,401,31.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11018,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11018,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11018,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11018,606,0.052,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11019,203,2.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11019,204,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11019,205,1.92,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11019,207,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11019,208,18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11019,255,94.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11019,269,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11019,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11019,301,18,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11019,303,0.56,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11019,306,172,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11019,307,3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11019,320,40,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (11019,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11019,401,24.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11019,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11019,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11019,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11019,606,0.096,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11023,203,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11023,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11023,205,6.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11023,207,0.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11023,208,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11023,255,88.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11023,269,1.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11023,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11023,301,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11023,303,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11023,306,602,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11023,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11023,320,121,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11023,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11023,401,55.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11023,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11023,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11023,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11023,606,0.032,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11025,203,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11025,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11025,205,4.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11025,207,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11025,208,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11025,255,93.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11025,269,1.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11025,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11025,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11025,303,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11025,306,319,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11025,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11025,320,6,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (11025,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11025,401,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11025,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11025,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11025,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11025,606,0.014,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11026,203,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11026,204,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11026,205,5.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11026,207,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11026,208,27,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11026,255,91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11026,269,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11026,291,2.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11026,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11026,303,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11026,306,533,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11026,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11026,320,1,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11026,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11026,401,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11026,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11026,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11026,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11026,606,0.069,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11027,203,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11027,204,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11027,205,1.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11027,207,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11027,208,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11027,255,95.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11027,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11027,291,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11027,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11027,303,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11027,306,533,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11027,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11027,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11027,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11027,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11027,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11027,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11027,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11027,606,0.051,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11028,203,1.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11028,204,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11028,205,3.22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11028,207,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11028,208,19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11028,255,94.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11028,269,1.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11028,291,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11028,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11028,303,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11028,306,80,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11028,307,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11028,320,1,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11028,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11028,401,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11028,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11028,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11028,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11028,606,0.092,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11029,203,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11029,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11029,205,4.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11029,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11029,208,29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11029,255,90.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11029,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11029,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11029,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11029,303,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11029,306,187,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11029,307,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11029,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11029,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11029,401,38.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11029,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11029,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11029,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11029,606,0.072,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11030,203,4.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11030,204,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11030,205,4.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11030,207,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11030,208,33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11030,255,89.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11030,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11030,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11030,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11030,303,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11030,306,194,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11030,307,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11030,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11030,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11030,401,35.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11030,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11030,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11030,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11030,606,0.083,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11031,203,6.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11031,204,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11031,205,20.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11031,207,1.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11031,208,113,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11031,255,70.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11031,269,1.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11031,291,4.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11031,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11031,303,3.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11031,306,467,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11031,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11031,320,10,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11031,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11031,401,23.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11031,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11031,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11031,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11031,606,0.198,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11032,203,6.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11032,204,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11032,205,23.64,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11032,207,2.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11032,208,123,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11032,255,67.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11032,269,1.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11032,291,5.4,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11032,301,32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11032,303,2.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11032,306,570,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11032,307,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11032,320,15,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (11032,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11032,401,10.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11032,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11032,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11032,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11032,606,0.073,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11033,203,4.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11033,204,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11033,205,13.33,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11033,207,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11033,208,71,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11033,255,81.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11033,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11033,291,3.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11033,301,28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11033,303,1.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11033,306,285,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11033,307,252,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11033,320,8,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11033,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11033,401,7.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11033,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11033,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11033,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11033,606,0.066,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11037,203,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11037,204,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11037,205,19.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11037,207,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11037,208,106,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11037,255,72.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11037,269,1.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11037,291,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11037,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11037,303,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11037,306,478,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11037,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11037,320,11,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11037,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11037,401,19.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11037,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11037,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11037,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11037,606,0.081,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11038,203,6.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11038,204,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11038,205,19.32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11038,207,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11038,208,103,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11038,255,72.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11038,269,1.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11038,291,5.3,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11038,301,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11038,303,1.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11038,306,304,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11038,307,69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11038,320,10,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11038,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11038,401,12.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11038,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11038,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11038,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11038,606,0.077,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11039,203,7.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11039,204,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11039,205,25.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11039,207,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11039,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11039,255,65.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11039,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11039,291,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11039,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11039,303,2.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11039,306,452,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11039,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11039,320,9,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11039,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11039,401,8.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11039,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11039,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11039,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11039,606,0.102,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11040,203,6.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11040,204,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11040,205,19.45,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11040,207,1.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11040,208,105,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11040,255,72.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11040,269,1.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11040,291,4.8,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11040,301,28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11040,303,1.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11040,306,411,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11040,307,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11040,320,8,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11040,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11040,401,5.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11040,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11040,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11040,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11040,606,0.068,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11043,203,3.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11043,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11043,205,5.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11043,207,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11043,208,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11043,255,90.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11043,269,4.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11043,291,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11043,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11043,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11043,306,149,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11043,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11043,320,1,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11043,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11043,401,13.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11043,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11043,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11043,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11043,606,0.046,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11044,203,2.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11044,204,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11044,205,4.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11044,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11044,208,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11044,255,93.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11044,269,2.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11044,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11044,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11044,303,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11044,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11044,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11044,320,1,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11044,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11044,401,11.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11044,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11044,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11044,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11044,606,0.025,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11045,203,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11045,204,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11045,205,10.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11045,207,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11045,208,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11045,255,84.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11045,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11045,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11045,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11045,303,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11045,306,219,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11045,307,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11045,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11045,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11045,401,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11045,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11045,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11045,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11045,606,0.039,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11046,203,6.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11046,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11046,205,13.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11046,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11046,208,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11046,255,79.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11046,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11046,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11046,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11046,303,1.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11046,306,307,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11046,307,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11046,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11046,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11046,401,18.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11046,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11046,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11046,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11046,606,0.085,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11047,203,7.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11047,204,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11047,205,15.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11047,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11047,208,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11047,255,76.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11047,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11047,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11047,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11047,303,2.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11047,306,317,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11047,307,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11047,320,0,'100g',1,1,'2024-12-12','2008-01-06');
INSERT INTO `cndb_nutval` VALUES (11047,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11047,401,17.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11047,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11047,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11047,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11047,606,0.098,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11048,203,9.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11048,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11048,205,32.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11048,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11048,208,170,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11048,255,55.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11048,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11048,291,5.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11048,301,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11048,303,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11048,306,756,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11048,307,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11048,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11048,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11048,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11048,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11048,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11048,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11048,606,0.061,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11049,203,9.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11049,204,0.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11049,205,30.87,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11049,207,1.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11049,208,162,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11049,255,58.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11049,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11049,291,5.4,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11049,301,52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11049,303,2.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11049,306,646,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11049,307,83,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11049,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11049,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11049,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11049,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11049,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11049,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11049,606,0.058,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11050,203,1.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11050,204,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11050,205,6.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11050,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11050,208,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11050,255,90.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11050,269,0.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11050,291,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11050,301,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11050,303,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11050,306,109,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11050,307,334,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11050,320,11,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11050,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11050,401,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11050,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11050,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11050,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11050,606,0.023,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11052,203,1.83,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11052,204,0.22,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11052,205,6.97,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11052,207,0.66,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11052,208,31,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11052,255,90.32,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11052,269,3.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11052,291,2.7,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11052,301,37,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11052,303,1.03,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11052,306,211,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11052,307,6,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11052,320,35,'100g',1,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (11052,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11052,401,12.2,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11052,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11052,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11052,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11052,606,0.05,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11053,203,1.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11053,204,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11053,205,7.88,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11053,207,0.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11053,208,35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11053,255,89.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11053,269,3.63,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11053,291,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11053,301,44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11053,303,0.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11053,306,146,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11053,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11053,320,32,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (11053,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11053,401,9.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11053,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11053,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11053,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11053,606,0.064,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11054,203,0.72,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11054,204,0.17,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11054,205,3.27,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11054,207,0.77,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11054,208,15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11054,255,95.06,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11054,269,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11054,291,1.5,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11054,301,29,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11054,303,1.02,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11054,306,92,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11054,307,192,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11054,320,13,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (11054,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11054,401,2.2,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11054,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11054,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11054,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11054,606,0.04,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11056,203,1.05,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11056,204,0.41,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11056,205,4.19,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11056,207,0.83,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11056,208,21,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11056,255,93.52,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11056,269,1.44,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11056,291,1.9,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11056,301,37,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11056,303,0.89,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11056,306,96,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11056,307,268,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11056,320,18,'100g',1,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (11056,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11056,401,2.8,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11056,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11056,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11056,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11056,606,0.093,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11058,203,0.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11058,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11058,205,3.49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11058,207,1.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11058,208,16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11058,255,94.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11058,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11058,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11058,301,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11058,303,0.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11058,306,93,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11058,307,373,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11058,320,26,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11058,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11058,401,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11058,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11058,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11058,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11058,606,0.045,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11060,203,1.79,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11060,204,0.21,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11060,205,7.54,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11060,207,0.53,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11060,208,33,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11060,255,89.93,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11060,269,2.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11060,291,2.6,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11060,301,42,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11060,303,0.85,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11060,306,186,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11060,307,3,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11060,320,27,'100g',2,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (11060,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11060,401,12.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11060,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11060,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11060,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11060,606,0.047,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11061,203,1.49,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11061,204,0.17,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11061,205,6.45,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11061,207,0.47,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11061,208,28,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11061,255,91.42,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11061,269,1.88,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11061,291,3,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11061,301,42,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11061,303,0.66,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11061,306,159,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11061,307,1,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11061,320,21,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (11061,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11061,401,4.1,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11061,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11061,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11061,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11061,606,0.044,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11062,203,1.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11062,204,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11062,205,6.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11062,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11062,208,33,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11062,255,89.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11062,269,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11062,291,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11062,301,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11062,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11062,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11062,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11062,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11062,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11062,401,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11062,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11062,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11062,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11062,606,0.092,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11080,203,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11080,204,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11080,205,9.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11080,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11080,208,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11080,255,87.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11080,269,6.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11080,291,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11080,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11080,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11080,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11080,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11080,320,2,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11080,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11080,401,4.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11080,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11080,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11080,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11080,606,0.027,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11081,203,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11081,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11081,205,9.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11081,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11081,208,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11081,255,87.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11081,269,7.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11081,291,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11081,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11081,303,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11081,306,305,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11081,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11081,320,2,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11081,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11081,401,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11081,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11081,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11081,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11081,606,0.028,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11082,203,0.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11082,204,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11082,205,7.14,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11082,207,0.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11082,208,30,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11082,255,91.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11082,269,6.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11082,291,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11082,301,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11082,303,0.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11082,306,159,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11082,307,143,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11082,320,1,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11082,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11082,401,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11082,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11082,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11082,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11082,606,0.011,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11084,203,0.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11084,204,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11084,205,7.21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11084,207,0.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11084,208,31,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11084,255,90.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11084,269,5.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11084,291,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11084,301,15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11084,303,1.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11084,306,148,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11084,307,194,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11084,320,1,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (11084,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11084,401,4.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11084,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11084,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11084,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11084,606,0.022,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11086,203,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11086,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11086,205,4.33,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11086,207,2.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11086,208,22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11086,255,91.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11086,269,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11086,291,3.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11086,301,117,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11086,303,2.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11086,306,762,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11086,307,226,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11086,320,316,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11086,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11086,401,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11086,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11086,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11086,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11086,606,0.02,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11087,203,2.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11087,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11087,205,5.46,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11087,207,2.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11087,208,27,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11087,255,89.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11087,269,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11087,291,2.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11087,301,114,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11087,303,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11087,306,909,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11087,307,241,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11087,320,383,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11087,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11087,401,24.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11087,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11087,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11087,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11087,606,0.031,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11088,203,5.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11088,204,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11088,205,11.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11088,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11088,208,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11088,255,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11088,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11088,291,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11088,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11088,303,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11088,306,250,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11088,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11088,320,18,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11088,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11088,401,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11088,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11088,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11088,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11088,606,0.138,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11089,203,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11089,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11089,205,10.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11089,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11089,208,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11089,255,83.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11089,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11089,291,3.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11089,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11089,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11089,306,193,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11089,307,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11089,320,14,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11089,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11089,401,19.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11089,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11089,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11089,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11089,606,0.142,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11090,203,2.82,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11090,204,0.37,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11090,205,6.64,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11090,207,0.87,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11090,208,34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11090,255,89.3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11090,269,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11090,291,2.6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11090,301,47,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11090,303,0.73,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11090,306,316,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11090,307,33,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11090,320,31,'100g',2,1,'2024-12-12','2006-01-08');
INSERT INTO `cndb_nutval` VALUES (11090,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11090,401,89.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11090,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11090,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11090,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11090,606,0.114,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11091,203,2.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11091,204,0.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11091,205,7.18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11091,207,0.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11091,208,35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11091,255,89.25,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11091,269,1.39,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11091,291,3.3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11091,301,40,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11091,303,0.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11091,306,293,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11091,307,41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11091,320,77,'100g',1,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (11091,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11091,401,64.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11091,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11091,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11091,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11091,606,0.079,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11092,203,2.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11092,204,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11092,205,4.78,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11092,207,0.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11092,208,26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11092,255,91.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11092,269,1.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11092,291,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11092,301,56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11092,303,0.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11092,306,212,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11092,307,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11092,320,52,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11092,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11092,401,56.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11092,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11092,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11092,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11092,606,0.044,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11093,203,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11093,204,0.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11093,205,5.35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11093,207,0.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11093,208,28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11093,255,90.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11093,269,1.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11093,291,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11093,301,33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11093,303,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11093,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11093,307,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11093,320,51,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11093,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11093,401,40.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11093,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11093,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11093,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11093,606,0.018,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11094,203,3.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11094,204,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11094,205,5.35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11094,207,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11094,208,29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11094,255,90.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11094,269,1.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11094,291,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11094,301,41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11094,303,0.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11094,306,250,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11094,307,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11094,320,57,'100g',2,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (11094,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11094,401,68.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11094,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11094,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11094,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11094,606,0.052,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11095,203,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11095,204,0.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11095,205,5.36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11095,207,0.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11095,208,28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11095,255,90.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11095,269,1.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11095,291,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11095,301,51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11095,303,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11095,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11095,307,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11095,320,51,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11095,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11095,401,40.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11095,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11095,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11095,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11095,606,0.018,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11096,203,3.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11096,204,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11096,205,2.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11096,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11096,208,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11096,255,92.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11096,269,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11096,291,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11096,301,108,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11096,303,2.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11096,306,196,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11096,307,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11096,320,131,'100g',1,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (11096,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11096,401,20.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11096,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11096,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11096,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11096,606,0.083,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11097,203,3.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11097,204,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11097,205,3.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11097,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11097,208,25,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11097,255,91.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11097,269,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11097,291,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11097,301,118,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11097,303,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11097,306,343,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11097,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11097,320,227,'100g',1,1,'2024-12-12','2006-01-08');
INSERT INTO `cndb_nutval` VALUES (11097,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11097,401,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11097,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11097,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11097,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11097,606,0.089,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11098,203,3.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11098,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11098,205,8.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11098,207,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11098,208,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11098,255,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11098,269,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11098,291,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11098,301,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11098,303,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11098,306,389,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11098,307,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11098,320,38,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11098,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11098,401,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11098,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11098,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11098,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11098,606,0.062,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11099,203,2.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11099,204,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11099,205,7.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11099,207,0.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11099,208,36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11099,255,88.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11099,269,1.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11099,291,2.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11099,301,36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11099,303,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11099,306,317,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11099,307,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11099,320,39,'100g',1,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (11099,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11099,401,62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11099,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11099,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11099,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11099,606,0.102,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11100,203,3.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11100,204,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11100,205,7.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11100,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11100,208,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11100,255,87.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11100,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11100,291,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11100,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11100,303,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11100,306,370,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11100,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11100,320,31,'100g',2,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (11100,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11100,401,74.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11100,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11100,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11100,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11100,606,0.084,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11101,203,3.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11101,204,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11101,205,8.32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11101,207,0.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11101,208,42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11101,255,86.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11101,269,2.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11101,291,4.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11101,301,26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11101,303,0.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11101,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11101,307,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11101,320,46,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11101,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11101,401,45.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11101,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11101,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11101,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11101,606,0.081,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11104,203,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11104,204,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11104,205,17.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11104,207,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11104,208,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11104,255,80.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11104,269,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11104,291,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11104,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11104,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11104,306,308,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11104,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11104,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11104,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11104,401,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11104,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11104,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11104,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11104,606,0.025,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11105,203,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11105,204,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11105,205,21.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11105,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11105,208,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11105,255,75.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11105,269,3.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11105,291,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11105,301,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11105,303,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11105,306,360,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11105,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11105,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11105,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11105,401,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11105,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11105,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11105,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11105,606,0.023,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11109,203,1.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11109,204,0.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11109,205,5.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11109,207,0.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11109,208,25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11109,255,92.18,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11109,269,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11109,291,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11109,301,40,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11109,303,0.47,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11109,306,170,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11109,307,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11109,320,5,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11109,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11109,401,36.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11109,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11109,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11109,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11109,606,0.034,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11110,203,1.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11110,204,0.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11110,205,5.51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11110,207,0.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11110,208,23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11110,255,92.57,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11110,269,2.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11110,291,1.9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11110,301,48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11110,303,0.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11110,306,196,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11110,307,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11110,320,4,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11110,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11110,401,37.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11110,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11110,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11110,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11110,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11112,203,1.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11112,204,0.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11112,205,7.37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11112,207,0.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11112,208,31,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11112,255,90.39,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11112,269,3.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11112,291,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11112,301,45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11112,303,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11112,306,243,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11112,307,27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11112,320,56,'100g',1,1,'2024-12-12','2006-01-06');
INSERT INTO `cndb_nutval` VALUES (11112,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11112,401,57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11112,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11112,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11112,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11112,606,0.021,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11113,203,1.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11113,204,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11113,205,6.94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11113,207,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11113,208,29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11113,255,90.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11113,269,3.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11113,291,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11113,301,42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11113,303,0.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11113,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11113,307,28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11113,320,2,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11113,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11113,401,34.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11113,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11113,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11113,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11113,606,0.011,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11114,203,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11114,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11114,205,6.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11114,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11114,208,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11114,255,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11114,269,2.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11114,291,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11114,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11114,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11114,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11114,307,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11114,320,50,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (11114,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11114,401,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11114,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11114,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11114,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11114,606,0.013,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11115,203,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11115,204,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11115,205,5.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11115,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11115,208,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11115,255,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11115,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11115,291,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11115,301,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11115,303,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11115,306,184,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11115,307,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11115,320,44,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11115,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11115,401,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11115,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11115,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11115,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11115,606,0.012,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11116,203,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11116,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11116,205,2.18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11116,207,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11116,208,13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11116,255,95.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11116,269,1.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11116,291,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11116,301,105,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11116,303,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11116,306,252,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11116,307,65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11116,320,223,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (11116,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11116,401,45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11116,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11116,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11116,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11116,606,0.027,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11117,203,1.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11117,204,0.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11117,205,1.78,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11117,207,0.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11117,208,12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11117,255,95.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11117,269,0.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11117,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11117,301,93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11117,303,1.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11117,306,371,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11117,307,34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11117,320,212,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11117,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11117,401,26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11117,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11117,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11117,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11117,606,0.021,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11118,203,1.1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11118,204,0.5,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11118,205,2.4,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11118,207,1.7,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11118,208,15,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11118,255,94.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11118,269,1.06,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11118,291,1.6,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11118,301,33,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11118,303,2.5,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11118,306,151,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11118,307,498,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11118,320,5,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (11118,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11118,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11118,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11118,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11118,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (11118,606,0.067,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11119,203,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11119,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11119,205,3.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11119,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11119,208,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11119,255,94.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11119,269,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11119,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11119,301,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11119,303,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11119,306,238,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11119,307,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11119,320,16,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (11119,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11119,401,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11119,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11119,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11119,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11119,606,0.043,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11120,203,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11120,204,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11120,205,2.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11120,207,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11120,208,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11120,255,95.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11120,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11120,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11120,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11120,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11120,306,225,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11120,307,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11120,320,48,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11120,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11120,401,15.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11120,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11120,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11120,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11120,606,0.036,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11122,203,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11122,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11122,205,4.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11122,207,1.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11122,208,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11122,255,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11122,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11122,291,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11122,301,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11122,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11122,306,400,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11122,307,170,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11122,320,0,'100g',1,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (11122,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11122,401,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11122,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11122,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11122,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11122,606,0.011,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11123,203,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11123,204,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11123,205,5.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11123,207,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11123,208,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11123,255,93.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11123,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11123,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11123,301,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11123,303,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11123,306,392,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11123,307,176,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11123,320,6,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11123,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11123,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11123,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11123,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11123,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11123,606,0.012,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11124,203,0.93,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11124,204,0.24,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11124,205,9.58,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11124,207,0.97,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11124,208,41,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11124,255,88.29,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11124,269,4.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11124,291,2.8,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11124,301,33,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11124,303,0.3,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11124,306,320,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11124,307,69,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11124,320,835,'100g',2,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (11124,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11124,401,5.9,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11124,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11124,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11124,605,0,'100g',4,1,'2006-01-24','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11124,606,0.032,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11125,203,0.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11125,204,0.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11125,205,8.22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11125,207,0.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11125,208,35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11125,255,90.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11125,269,3.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11125,291,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11125,301,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11125,303,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11125,306,235,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11125,307,58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11125,320,852,'100g',2,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (11125,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11125,401,3.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11125,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11125,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11125,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11125,606,0.03,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11126,203,0.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11126,204,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11126,205,5.37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11126,207,0.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11126,208,23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11126,255,92.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11126,269,2.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11126,291,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11126,301,31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11126,303,0.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11126,306,173,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11126,307,240,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11126,320,613,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11126,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11126,401,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11126,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11126,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11126,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11126,606,0.025,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11128,203,0.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11128,204,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11128,205,5.54,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11128,207,0.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11128,208,25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11128,255,92.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11128,269,2.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11128,291,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11128,301,25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11128,303,0.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11128,306,179,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11128,307,242,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11128,320,558,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11128,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11128,401,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11128,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11128,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11128,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11128,606,0.036,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11130,203,0.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11130,204,0.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11130,205,7.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11130,207,0.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11130,208,36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11130,255,90.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11130,269,4.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11130,291,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11130,301,36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11130,303,0.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11130,306,235,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11130,307,68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11130,320,710,'100g',2,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (11130,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11130,401,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11130,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11130,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11130,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11130,606,0.047,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11131,203,0.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11131,204,0.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11131,205,7.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11131,207,0.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11131,208,37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11131,255,90.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11131,269,4.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11131,291,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11131,301,35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11131,303,0.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11131,306,192,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11131,307,59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11131,320,846,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11131,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11131,401,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11131,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11131,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11131,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11131,606,0.12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11134,203,1.36,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11134,204,0.28,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11134,205,38.06,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11134,207,0.62,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11134,208,160,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11134,255,59.68,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11134,269,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11134,291,1.8,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11134,301,16,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11134,303,0.27,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11134,306,271,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11134,307,14,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11134,320,1,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11134,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11134,401,20.6,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11134,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11134,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11134,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11134,606,0.074,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11135,203,1.92,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11135,204,0.28,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11135,205,4.97,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11135,207,0.76,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11135,208,25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11135,255,92.07,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11135,269,1.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11135,291,2,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11135,301,22,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11135,303,0.42,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11135,306,299,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11135,307,30,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11135,320,0,'100g',1,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (11135,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11135,401,48.2,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11135,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11135,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11135,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11135,606,0.13,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11136,203,1.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11136,204,0.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11136,205,4.11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11136,207,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11136,208,23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11136,255,93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11136,269,2.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11136,291,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11136,301,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11136,303,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11136,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11136,307,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11136,320,1,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11136,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11136,401,44.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11136,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11136,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11136,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11136,606,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11137,203,2.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11137,204,0.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11137,205,4.68,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11137,207,0.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11137,208,24,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11137,255,92.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11137,269,2.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11137,291,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11137,301,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11137,303,0.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11137,306,193,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11137,307,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11137,320,1,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11137,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11137,401,48.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11137,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11137,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11137,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11137,606,0.041,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11138,203,1.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11138,204,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11138,205,3.75,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11138,207,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11138,208,19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11138,255,94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11138,269,1.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11138,291,2.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11138,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11138,303,0.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11138,306,139,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11138,307,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11138,320,0,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11138,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11138,401,31.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11138,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11138,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11138,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11138,606,0.034,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11141,203,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11141,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11141,205,9.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11141,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11141,208,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11141,255,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11141,269,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11141,291,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11141,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11141,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11141,306,300,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11141,307,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11141,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11141,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11141,401,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11141,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11141,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11141,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11141,606,0.079,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11143,203,0.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11143,204,0.17,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11143,205,2.97,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11143,207,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11143,208,14,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11143,255,95.43,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11143,269,1.34,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11143,291,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11143,301,40,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11143,303,0.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11143,306,260,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11143,307,80,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11143,320,22,'100g',1,1,'2024-12-12','2006-01-08');
INSERT INTO `cndb_nutval` VALUES (11143,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11143,401,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11143,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11143,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11143,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11143,606,0.042,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11144,203,0.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11144,204,0.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11144,205,4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11144,207,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11144,208,18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11144,255,94.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11144,269,2.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11144,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11144,301,42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11144,303,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11144,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11144,307,91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11144,320,26,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11144,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11144,401,6.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11144,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11144,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11144,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11144,606,0.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11147,203,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11147,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11147,205,3.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11147,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11147,208,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11147,255,92.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11147,269,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11147,291,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11147,301,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11147,303,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11147,306,379,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11147,307,213,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11147,320,306,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11147,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11147,401,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11147,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11147,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11147,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11147,606,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11148,203,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11148,204,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11148,205,4.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11148,207,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11148,208,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11148,255,92.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11148,269,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11148,291,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11148,301,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11148,303,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11148,306,549,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11148,307,179,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11148,320,306,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11148,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11148,401,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11148,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11148,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11148,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11148,606,0.012,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11149,203,0.82,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11149,204,0.13,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11149,205,4.51,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11149,207,0.3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11149,208,19,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11149,255,94.24,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11149,269,1.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11149,291,1.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11149,301,17,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11149,303,0.34,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11149,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11149,307,2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11149,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11149,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11149,401,7.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11149,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11149,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11149,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11149,606,0.028,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11150,203,0.62,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11150,204,0.48,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11150,205,5.09,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11150,207,0.38,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11150,208,24,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11150,255,93.43,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11150,269,1.89,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11150,291,2.8,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11150,301,13,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11150,303,0.22,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11150,306,173,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11150,307,1,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11150,320,0,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (11150,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11150,401,8,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11150,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11150,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11150,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11150,606,0,'100g',3,1,'1997-08-29','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11151,203,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11151,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11151,205,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11151,207,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11151,208,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11151,255,94.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11151,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11151,291,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11151,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11151,303,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11151,306,211,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11151,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11151,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11151,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11151,401,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11151,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11151,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11151,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11151,606,0.024,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11152,203,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11152,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11152,205,4.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11152,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11152,208,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11152,255,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11152,269,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11152,291,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11152,301,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11152,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11152,306,420,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11152,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11152,320,286,'100g',2,1,'2024-12-12','2007-01-06');
INSERT INTO `cndb_nutval` VALUES (11152,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11152,401,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11152,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11152,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11152,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11152,606,0.073,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11154,203,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11154,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11154,205,17.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11154,207,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11154,208,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11154,255,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11154,269,8.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11154,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11154,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11154,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11154,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11154,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11154,320,0,'100g',3,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (11154,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11154,401,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11154,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11154,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11154,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11154,606,0.048,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11156,203,3.27,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11156,204,0.73,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11156,205,4.35,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11156,207,1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11156,208,30,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11156,255,90.65,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11156,269,1.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11156,291,2.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11156,301,92,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11156,303,1.6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11156,306,296,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11156,307,3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11156,320,218,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11156,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11156,401,58.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11156,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11156,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11156,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11156,606,0.146,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11158,203,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11158,204,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11158,205,4.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11158,207,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11158,208,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11158,255,92.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11158,269,2.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11158,291,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11158,301,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11158,303,3.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11158,306,569,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11158,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11158,320,129,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11158,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11158,401,23.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11158,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11158,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11158,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11158,606,0.022,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11161,203,3.02,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11161,204,0.61,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11161,205,5.42,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11161,207,1.32,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11161,208,32,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11161,255,89.62,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11161,269,0.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11161,291,4,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11161,301,232,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11161,303,0.47,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11161,306,213,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11161,307,17,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11161,320,251,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (11161,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11161,401,35.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11161,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11161,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11161,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11161,606,0.055,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11162,203,2.71,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11162,204,0.72,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11162,205,5.65,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11162,207,0.73,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11162,208,33,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11162,255,90.18,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11162,269,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11162,291,4,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11162,301,141,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11162,303,1.13,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11162,306,117,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11162,307,15,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11162,320,380,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (11162,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11162,401,18.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11162,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11162,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11162,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11162,606,0.047,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11163,203,2.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11163,204,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11163,205,6.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11163,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11163,208,33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11163,255,89.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11163,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11163,291,3.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11163,301,201,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11163,303,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11163,306,253,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11163,307,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11163,320,459,'100g',1,1,'2024-12-12','2003-01-07');
INSERT INTO `cndb_nutval` VALUES (11163,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11163,401,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11163,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11163,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11163,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11163,606,0.048,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11164,203,2.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11164,204,0.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11164,205,7.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11164,207,1.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11164,208,36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11164,255,88.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11164,269,0.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11164,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11164,301,210,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11164,303,1.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11164,306,251,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11164,307,50,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11164,320,575,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11164,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11164,401,26.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11164,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11164,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11164,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11164,606,0.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11165,203,2.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11165,204,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11165,205,3.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11165,207,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11165,208,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11165,255,92.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11165,269,0.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11165,291,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11165,301,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11165,303,1.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11165,306,521,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11165,307,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11165,320,337,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11165,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11165,401,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11165,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11165,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11165,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11165,606,0.014,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11167,203,3.27,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11167,204,1.35,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11167,205,18.7,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11167,207,0.62,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11167,208,86,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11167,255,76.05,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11167,269,6.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11167,291,2,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11167,301,2,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11167,303,0.52,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11167,306,270,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11167,307,15,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11167,320,9,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (11167,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11167,401,6.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11167,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11167,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11167,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11167,606,0.325,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11168,203,3.41,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11168,204,1.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11168,205,20.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11168,207,0.71,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11168,208,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11168,255,73.41,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11168,269,4.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11168,291,2.4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11168,301,3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11168,303,0.45,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11168,306,218,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11168,307,1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11168,320,13,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (11168,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11168,401,5.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11168,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11168,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11168,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11168,606,0.197,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11170,203,1.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11170,204,0.77,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11170,205,13.86,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11170,207,0.8,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11170,208,61,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11170,255,82.61,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11170,269,4.15,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11170,291,1.7,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11170,301,4,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11170,303,0.36,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11170,306,136,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11170,307,195,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11170,320,2,'100g',1,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (11170,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11170,401,2.6,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11170,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11170,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11170,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11170,606,0.077,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11172,203,2.29,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11172,204,1.22,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11172,205,14.34,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11172,207,0.75,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11172,208,67,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11172,255,81.41,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11172,269,4.44,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11172,291,2,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11172,301,3,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11172,303,0.27,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11172,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11172,307,205,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11172,320,2,'100g',1,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (11172,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11172,401,1.8,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11172,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11172,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11172,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11172,606,0.245,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11174,203,1.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11174,204,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11174,205,18.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11174,207,0.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11174,208,72,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11174,255,78.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11174,269,3.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11174,291,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11174,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11174,303,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11174,306,134,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11174,307,261,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11174,320,4,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11174,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11174,401,4.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11174,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11174,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11174,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11174,606,0.065,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11176,203,2.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11176,204,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11176,205,19.44,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11176,207,1.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11176,208,79,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11176,255,76.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11176,269,5.59,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11176,291,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11176,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11176,303,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11176,306,186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11176,307,272,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11176,320,4,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11176,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11176,401,8.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11176,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11176,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11176,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11176,606,0.077,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11177,203,2.18,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11177,204,1.43,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11177,205,13.02,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11177,207,0.57,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11177,208,64,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11177,255,82.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11177,269,4.11,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11177,291,1.7,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11177,301,2,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11177,303,0.22,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11177,306,116,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11177,307,163,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11177,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11177,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11177,401,1.7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11177,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11177,601,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11177,605,0,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11177,606,0.219,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11178,203,3.02,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11178,204,0.78,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11178,205,20.71,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11178,207,0.48,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11178,208,88,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11178,255,75,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11178,269,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11178,291,2.1,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11178,301,4,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11178,303,0.42,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11178,306,213,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11178,307,3,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11178,320,10,'100g',2,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (11178,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11178,401,6.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11178,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11178,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11178,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11178,606,0.119,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11179,203,2.55,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11179,204,0.67,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11179,205,19.3,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11179,207,0.44,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11179,208,81,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11179,255,77.03,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11179,269,3.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11179,291,2.4,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11179,301,3,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11179,303,0.47,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11179,306,233,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11179,307,1,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11179,320,10,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11179,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11179,401,3.5,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11179,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11179,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11179,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11179,606,0.103,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11180,203,3.28,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11180,204,0.78,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11180,205,23.5,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11180,207,0.65,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11180,208,98,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11180,255,71.79,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11180,269,3.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11180,291,2.8,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11180,301,4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11180,303,0.68,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11180,306,294,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11180,307,5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11180,320,12,'100g',2,1,'2024-12-12','2010-01-03');
INSERT INTO `cndb_nutval` VALUES (11180,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11180,401,7.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11180,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11180,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11180,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11180,606,0.12,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11181,203,3.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11181,204,0.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11181,205,22.33,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11181,207,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11181,208,94,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11181,255,73.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11181,269,3.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11181,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11181,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11181,303,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11181,306,251,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11181,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11181,320,12,'100g',2,1,'2024-12-12','2010-01-03');
INSERT INTO `cndb_nutval` VALUES (11181,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11181,401,4.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11181,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11181,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11181,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11181,606,0.114,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11182,203,3.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11182,204,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11182,205,25.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11182,207,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11182,208,113,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11182,255,68.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11182,269,3.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11182,291,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11182,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11182,303,0.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11182,306,276,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11182,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11182,320,12,'100g',2,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (11182,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11182,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11182,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11182,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11182,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11182,606,0.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11184,203,2.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11184,204,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11184,205,18.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11184,207,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11184,208,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11184,255,77.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11184,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11184,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11184,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11184,303,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11184,306,153,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11184,307,347,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11184,320,12,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11184,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11184,401,8.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11184,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11184,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11184,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11184,606,0.085,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11191,203,2.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11191,204,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11191,205,18.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11191,207,0.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11191,208,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11191,255,77.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11191,269,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11191,291,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11191,301,126,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11191,303,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11191,306,431,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11191,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11191,320,41,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (11191,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11191,401,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11191,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11191,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11191,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11191,606,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11192,203,3.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11192,204,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11192,205,20.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11192,207,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11192,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11192,255,75.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11192,269,3.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11192,291,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11192,301,128,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11192,303,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11192,306,418,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11192,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11192,320,40,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11192,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11192,401,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11192,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11192,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11192,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11192,606,0.096,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11195,203,8.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11195,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11195,205,25.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11195,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11195,208,139,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11195,255,64.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11195,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11195,291,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11195,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11195,303,2.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11195,306,441,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11195,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11195,320,4,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11195,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11195,401,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11195,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11195,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11195,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11195,606,0.185,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11196,203,8.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11196,204,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11196,205,23.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11196,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11196,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11196,255,66.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11196,269,4.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11196,291,6.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11196,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11196,303,2.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11196,306,375,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11196,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11196,320,4,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11196,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11196,401,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11196,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11196,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11196,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11196,606,0.175,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11197,203,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11197,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11197,205,9.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11197,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11197,208,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11197,255,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11197,269,5.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11197,291,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11197,301,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11197,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11197,306,215,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11197,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11197,320,68,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (11197,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11197,401,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11197,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11197,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11197,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11197,606,0.079,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11198,203,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11198,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11198,205,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11198,207,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11198,208,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11198,255,89.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11198,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11198,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11198,301,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11198,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11198,306,196,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11198,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11198,320,70,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11198,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11198,401,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11198,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11198,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11198,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11198,606,0.079,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11199,203,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11199,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11199,205,8.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11199,207,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11199,208,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11199,255,87.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11199,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11199,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11199,301,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11199,303,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11199,306,240,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11199,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11199,320,43,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11199,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11199,401,18.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11199,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11199,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11199,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11199,606,0.105,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11200,203,2.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11200,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11200,205,9.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11200,207,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11200,208,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11200,255,87.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11200,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11200,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11200,301,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11200,303,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11200,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11200,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11200,320,23,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11200,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11200,401,16.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11200,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11200,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11200,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11200,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11201,203,4.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11201,204,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11201,205,4.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11201,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11201,208,29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11201,255,89.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11201,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11201,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11201,301,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11201,303,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11201,306,455,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11201,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11201,320,36,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11201,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11201,401,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11201,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11201,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11201,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11201,606,0.066,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11202,203,4.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11202,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11202,205,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11202,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11202,208,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11202,255,91.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11202,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11202,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11202,301,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11202,303,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11202,306,351,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11202,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11202,320,29,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11202,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11202,401,18.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11202,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11202,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11202,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11202,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11203,203,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11203,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11203,205,5.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11203,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11203,208,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11203,255,89.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11203,269,4.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11203,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11203,301,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11203,303,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11203,306,606,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11203,307,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11203,320,346,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11203,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11203,401,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11203,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11203,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11203,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11203,606,0.023,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11204,203,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11204,204,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11204,205,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11204,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11204,208,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11204,255,92.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11204,269,3.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11204,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11204,301,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11204,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11204,306,353,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11204,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11204,320,232,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11204,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11204,401,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11204,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11204,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11204,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11204,606,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11205,203,0.65,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11205,204,0.11,'100g',7,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11205,205,3.63,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11205,207,0.38,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11205,208,15,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11205,255,95.23,'100g',7,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11205,269,1.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11205,291,0.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11205,301,16,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11205,303,0.28,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11205,306,147,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11205,307,2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11205,320,5,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11205,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11205,401,2.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11205,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11205,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11205,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11205,606,0.037,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11206,203,0.59,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11206,204,0.16,'100g',7,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11206,205,2.16,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11206,207,0.36,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11206,208,10,'100g',3,1,'1995-06-15','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11206,255,96.73,'100g',7,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11206,269,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11206,291,0.7,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11206,301,14,'100g',7,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11206,303,0.22,'100g',7,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11206,306,136,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11206,307,2,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11206,320,4,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11206,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11206,401,3.2,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11206,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11206,601,0,'100g',4,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11206,605,0,'100g',NULL,1,'1995-06-27','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11206,606,0.078,'100g',3,1,'1995-06-15','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11207,203,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11207,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11207,205,9.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11207,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11207,208,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11207,255,85.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11207,269,0.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11207,291,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11207,301,187,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11207,303,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11207,306,397,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11207,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11207,320,508,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (11207,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11207,401,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11207,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11207,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11207,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11207,606,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11208,203,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11208,204,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11208,205,6.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11208,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11208,208,33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11208,255,89.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11208,269,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11208,291,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11208,301,140,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11208,303,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11208,306,232,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11208,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11208,320,342,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (11208,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11208,401,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11208,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11208,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11208,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11208,606,0.146,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11209,203,0.98,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11209,204,0.18,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11209,205,5.88,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11209,207,0.66,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11209,208,25,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11209,255,92.3,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11209,269,3.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11209,291,3,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11209,301,9,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11209,303,0.23,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11209,306,229,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11209,307,2,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11209,320,1,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11209,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11209,401,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11209,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11209,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11209,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11209,606,0.034,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11210,203,0.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11210,204,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11210,205,8.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11210,207,0.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11210,208,35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11210,255,89.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11210,269,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11210,291,2.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11210,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11210,303,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11210,306,123,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11210,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11210,320,2,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11210,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11210,401,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11210,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11210,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11210,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11210,606,0.044,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11212,203,11.91,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11212,204,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11212,205,8.91,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11212,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11212,208,121,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11212,255,72.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11212,269,2.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11212,291,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11212,301,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11212,303,2.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11212,306,436,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11212,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11212,320,15,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (11212,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11212,401,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11212,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11212,601,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11212,605,0.009,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11212,606,0.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11213,203,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11213,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11213,205,3.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11213,207,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11213,208,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11213,255,93.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11213,269,0.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11213,291,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11213,301,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11213,303,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11213,306,314,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11213,307,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11213,320,108,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11213,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11213,401,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11213,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11213,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11213,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11213,606,0.048,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11214,203,1.15,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11214,204,0.18,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11214,205,3.07,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11214,207,1.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11214,208,15,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11214,255,94.29,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11214,269,0.23,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11214,291,2.8,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11214,301,46,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11214,303,0.72,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11214,306,245,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11214,307,19,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11214,320,94,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (11214,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11214,401,3.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11214,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11214,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11214,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (11214,606,0.042,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11215,203,6.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11215,204,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11215,205,33.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11215,207,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11215,208,149,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11215,255,58.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11215,269,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11215,291,2.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11215,301,181,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11215,303,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11215,306,401,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11215,307,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11215,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11215,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11215,401,31.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11215,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11215,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11215,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11215,606,0.089,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11216,203,1.82,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11216,204,0.75,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11216,205,17.77,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11216,207,0.77,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11216,208,80,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11216,255,78.89,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11216,269,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11216,291,2,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11216,301,16,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11216,303,0.6,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11216,306,415,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11216,307,13,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11216,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11216,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11216,401,5,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11216,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11216,601,0,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11216,605,0,'100g',NULL,1,'1995-06-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11216,606,0.203,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11218,203,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11218,204,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11218,205,3.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11218,207,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11218,208,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11218,255,95.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11218,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11218,291,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11218,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11218,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11218,306,150,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11218,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11218,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11218,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11218,401,10.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11218,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11218,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11218,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11218,606,0.002,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11219,203,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11219,204,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11219,205,3.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11219,207,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11219,208,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11219,255,95.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11219,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11219,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11219,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11219,303,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11219,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11219,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11219,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11219,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11219,401,8.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11219,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11219,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11219,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11219,606,0.002,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11220,203,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11220,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11220,205,4.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11220,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11220,208,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11220,255,93.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11220,269,2.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11220,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11220,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11220,303,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11220,306,139,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11220,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11220,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11220,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11220,401,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11220,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11220,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11220,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11220,606,0.016,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11221,203,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11221,204,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11221,205,14.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11221,207,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11221,208,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11221,255,84.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11221,269,5.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11221,291,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11221,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11221,303,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11221,306,453,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11221,307,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11221,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11221,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11221,401,5.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11221,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11221,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11221,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11221,606,0.027,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11223,203,5.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11223,204,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11223,205,11.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11223,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11223,208,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11223,255,81.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11223,269,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11223,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11223,301,151,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11223,303,2.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11223,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11223,307,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11223,320,351,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11223,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11223,401,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11223,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11223,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11223,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11223,606,0.152,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11224,203,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11224,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11224,205,9.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11224,207,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11224,208,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11224,255,87.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11224,269,4.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11224,291,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11224,301,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11224,303,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11224,306,252,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11224,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11224,320,43,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (11224,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11224,401,12.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11224,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11224,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11224,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11224,606,0.088,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11225,203,2.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11225,204,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11225,205,9.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11225,207,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11225,208,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11225,255,86.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11225,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11225,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11225,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11225,303,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11225,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11225,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11225,320,7,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11225,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11225,401,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11225,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11225,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11225,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11225,606,0.119,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11226,203,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11226,204,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11226,205,17.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11226,207,2.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11226,208,73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11226,255,78.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11226,269,9.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11226,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11226,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11226,303,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11226,306,429,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11226,307,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11226,320,1,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11226,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11226,401,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11226,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11226,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11226,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11226,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11231,203,4.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11231,204,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11231,205,5.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11231,207,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11231,208,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11231,255,87.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11231,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11231,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11231,301,208,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11231,303,4.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11231,306,559,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11231,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11231,320,278,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11231,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11231,401,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11231,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11231,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11231,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11231,606,0.038,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11232,203,3.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11232,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11232,205,7.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11232,207,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11232,208,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11232,255,87.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11232,269,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11232,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11232,301,211,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11232,303,3.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11232,306,550,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11232,307,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11232,320,259,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11232,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11232,401,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11232,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11232,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11232,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11232,606,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11233,203,2.92,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11233,204,1.49,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11233,205,4.42,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11233,207,1.54,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11233,208,35,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11233,255,89.63,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11233,269,0.99,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11233,291,4.1,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11233,301,254,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11233,303,1.6,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11233,306,348,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11233,307,53,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11233,320,241,'100g',1,1,'2024-12-12','2016-01-10');
INSERT INTO `cndb_nutval` VALUES (11233,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11233,401,93.4,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11233,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11233,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11233,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11233,606,0.178,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11234,203,2.94,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11234,204,1.21,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11234,205,5.3,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11234,207,0.73,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11234,208,36,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11234,255,89.82,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11234,269,1.21,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11234,291,4,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11234,301,150,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11234,303,0.84,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11234,306,144,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11234,307,16,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11234,320,146,'100g',1,1,'2024-12-12','2016-01-12');
INSERT INTO `cndb_nutval` VALUES (11234,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11234,401,17.8,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11234,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11234,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11234,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11234,606,0.175,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11235,203,2.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11235,204,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11235,205,4.88,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11235,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11235,208,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11235,255,91.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11235,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11235,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11235,301,136,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11235,303,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11235,306,333,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11235,307,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11235,320,206,'100g',2,1,'2024-12-12','2016-01-12');
INSERT INTO `cndb_nutval` VALUES (11235,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11235,401,39.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11235,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11235,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11235,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11235,606,0.059,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11236,203,2.94,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11236,204,1.21,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11236,205,5.3,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11236,207,0.73,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11236,208,36,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11236,255,89.82,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11236,269,1.21,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11236,291,2.3,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11236,301,150,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11236,303,0.84,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11236,306,144,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11236,307,16,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11236,320,146,'100g',1,1,'2024-12-12','2016-01-10');
INSERT INTO `cndb_nutval` VALUES (11236,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11236,401,17.8,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11236,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11236,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11236,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11236,606,0.158,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11237,203,8.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11237,204,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11237,205,65.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11237,207,5.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11237,208,258,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11237,255,19.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11237,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11237,291,9.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11237,301,280,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11237,303,5.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11237,306,1582,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11237,307,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11237,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11237,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11237,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11237,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11237,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11237,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11237,606,0.045,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11240,203,3.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11240,204,0.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11240,205,5.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11240,207,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11240,208,31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11240,255,89.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11240,269,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11240,291,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11240,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11240,303,12.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11240,306,411,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11240,307,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11240,320,0,'100g',1,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (11240,328,5.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11240,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11240,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11240,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11240,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11240,606,0.065,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11241,203,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11241,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11241,205,6.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11241,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11241,208,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11241,255,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11241,269,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11241,291,3.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11241,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11241,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11241,306,350,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11241,307,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11241,320,2,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11241,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11241,401,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11241,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11241,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11241,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11241,606,0.013,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11242,203,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11242,204,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11242,205,6.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11242,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11242,208,29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11242,255,90.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11242,269,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11242,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11242,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11242,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11242,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11242,307,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11242,320,2,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11242,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11242,401,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11242,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11242,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11242,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11242,606,0.014,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11243,203,3.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11243,204,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11243,205,4.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11243,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11243,208,29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11243,255,90.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11243,269,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11243,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11243,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11243,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11243,306,437,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11243,307,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11243,320,0,'100g',1,1,'2024-12-12','2009-01-08');
INSERT INTO `cndb_nutval` VALUES (11243,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11243,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11243,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11243,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11243,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11243,606,0.064,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11244,203,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11244,204,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11244,205,7.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11244,207,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11244,208,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11244,255,84.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11244,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11244,291,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11244,301,309,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11244,303,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11244,306,452,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11244,307,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11244,320,580,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11244,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11244,401,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11244,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11244,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11244,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11244,606,0.059,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11245,203,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11245,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11245,205,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11245,207,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11245,208,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11245,255,88.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11245,269,0.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11245,291,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11245,301,258,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11245,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11245,306,288,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11245,307,29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11245,320,391,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11245,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11245,401,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11245,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11245,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11245,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11245,606,0.052,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11246,203,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11246,204,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11246,205,14.15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11246,207,1.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11246,208,61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11246,255,83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11246,269,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11246,291,1.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11246,301,59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11246,303,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11246,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11246,307,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11246,320,83,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11246,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11246,401,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11246,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11246,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11246,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11246,606,0.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11247,203,0.81,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11247,204,0.2,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11247,205,7.62,'100g',3,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11247,207,0.57,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11247,208,31,'100g',3,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11247,255,90.8,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11247,269,2.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11247,291,1,'100g',3,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11247,301,30,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11247,303,1.1,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11247,306,87,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11247,307,10,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11247,320,41,'100g',2,1,'2024-12-12','2007-01-11');
INSERT INTO `cndb_nutval` VALUES (11247,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11247,401,4.2,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11247,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11247,601,0,'100g',4,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11247,605,0,'100g',NULL,1,'1998-03-27','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11247,606,0.027,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11248,203,8.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11248,204,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11248,205,22.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11248,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11248,208,106,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11248,255,67.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11248,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11248,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11248,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11248,303,3.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11248,306,322,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11248,307,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11248,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11248,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11248,401,16.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11248,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11248,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11248,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11248,606,0.057,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11249,203,8.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11249,204,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11249,205,21.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11249,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11249,208,101,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11249,255,68.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11249,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11249,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11249,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11249,303,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11249,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11249,307,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11249,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11249,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11249,401,12.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11249,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11249,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11249,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11249,606,0.053,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11250,203,1.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11250,204,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11250,205,2.23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11250,207,0.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11250,208,13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11250,255,95.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11250,269,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11250,291,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11250,301,35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11250,303,1.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11250,306,238,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11250,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11250,320,166,'100g',1,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (11250,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11250,401,3.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11250,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11250,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11250,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11250,606,0.029,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11251,203,1.23,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11251,204,0.3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11251,205,3.29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11251,207,0.58,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11251,208,17,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11251,255,94.61,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11251,269,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11251,291,2.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11251,301,33,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11251,303,0.97,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11251,306,247,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11251,307,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11251,320,436,'100g',1,1,'2024-12-12','2008-01-02');
INSERT INTO `cndb_nutval` VALUES (11251,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11251,401,4,'100g',7,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11251,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11251,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11251,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11251,606,0.039,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11252,203,0.9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11252,204,0.14,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11252,205,2.97,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11252,207,0.36,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11252,208,14,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11252,255,95.64,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11252,269,1.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11252,291,1.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11252,301,18,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11252,303,0.41,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11252,306,141,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11252,307,10,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11252,320,25,'100g',1,1,'2024-12-12','2007-01-06');
INSERT INTO `cndb_nutval` VALUES (11252,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11252,401,2.8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11252,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11252,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11252,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11252,606,0.018,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11253,203,1.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11253,204,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11253,205,2.87,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11253,207,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11253,208,15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11253,255,94.98,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11253,269,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11253,291,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11253,301,36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11253,303,0.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11253,306,194,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11253,307,28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11253,320,370,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (11253,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11253,401,9.2,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11253,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11253,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11253,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11253,606,0.02,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11254,203,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11254,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11254,205,17.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11254,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11254,208,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11254,255,79.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11254,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11254,291,4.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11254,301,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11254,303,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11254,306,556,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11254,307,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11254,320,0,'100g',1,1,'2024-12-12','2002-01-12');
INSERT INTO `cndb_nutval` VALUES (11254,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11254,401,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11254,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11254,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11254,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11254,606,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11255,203,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11255,204,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11255,205,16.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11255,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11255,208,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11255,255,81.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11255,269,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11255,291,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11255,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11255,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11255,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11255,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11255,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11255,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11255,401,27.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11255,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11255,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11255,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11255,606,0.021,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11257,203,1.33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (11257,204,0.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (11257,205,2.26,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (11257,207,0.55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (11257,208,13,'100g',3,1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11257,255,95.64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (11257,269,0.48,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (11257,291,0.9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (11257,301,33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (11257,303,1.2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (11257,306,187,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11257,307,25,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (11257,320,375,'100g',1,1,'2024-12-12','2006-01-08');
INSERT INTO `cndb_nutval` VALUES (11257,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11257,401,3.7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (11257,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11257,601,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (11257,605,0,'100g',NULL,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11257,606,0.028,'100g',3,1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11258,203,1.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11258,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11258,205,16.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11258,207,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11258,208,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11258,255,81.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11258,269,0.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11258,291,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11258,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11258,303,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11258,306,418,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11258,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11258,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11258,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11258,401,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11258,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11258,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11258,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11258,606,0.022,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11259,203,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11259,204,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11259,205,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11259,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11259,208,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11259,255,77.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11259,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11259,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11259,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11259,303,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11259,306,495,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11259,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11259,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11259,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11259,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11259,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11259,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11259,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11259,606,0.018,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11260,203,3.09,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11260,204,0.34,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11260,205,3.26,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11260,207,0.85,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11260,208,22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11260,255,92.45,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11260,269,1.98,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11260,291,1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11260,301,3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11260,303,0.5,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11260,306,318,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11260,307,5,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11260,320,0,'100g',1,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (11260,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11260,401,2.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11260,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11260,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11260,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11260,606,0.05,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11261,203,2.17,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11261,204,0.47,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11261,205,5.29,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11261,207,0.99,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11261,208,28,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11261,255,91.08,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11261,269,2.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11261,291,2.2,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11261,301,6,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11261,303,1.74,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11261,306,356,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11261,307,2,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11261,320,0,'100g',2,1,'2024-12-12','2009-01-08');
INSERT INTO `cndb_nutval` VALUES (11261,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11261,401,4,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11261,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11261,601,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11261,605,0,'100g',NULL,1,'2004-07-15','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11261,606,0.061,'100g',1,1,'2004-07-15','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11263,203,3.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11263,204,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11263,205,4.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11263,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11263,208,26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11263,255,91.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11263,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11263,291,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11263,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11263,303,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11263,306,396,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11263,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11263,320,0,'100g',1,1,'2024-12-12','2009-01-08');
INSERT INTO `cndb_nutval` VALUES (11263,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11263,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11263,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11263,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11263,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11263,606,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11264,203,1.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11264,204,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11264,205,5.09,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11264,207,1.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11264,208,25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11264,255,91.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11264,269,2.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11264,291,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11264,301,11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11264,303,0.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11264,306,129,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11264,307,425,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11264,320,0,'100g',2,1,'2024-12-12','2009-01-08');
INSERT INTO `cndb_nutval` VALUES (11264,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11264,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11264,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11264,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11264,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11264,606,0.038,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11265,203,2.11,'100g',1,1,'2002-06-08','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11265,204,0.35,'100g',1,1,'2002-06-08','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11265,205,3.87,'100g',3,1,'2002-06-08','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11265,207,0.85,'100g',1,1,'2002-06-08','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11265,208,22,'100g',3,1,'2002-06-08','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11265,255,92.82,'100g',1,1,'2002-06-08','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11265,269,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11265,291,1.3,'100g',1,1,'2002-06-08','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11265,301,3,'100g',1,1,'2002-06-08','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11265,303,0.31,'100g',1,1,'2002-06-08','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11265,306,364,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11265,307,9,'100g',1,1,'2002-06-08','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11265,320,0,'100g',1,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (11265,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11265,401,0,'100g',4,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11265,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11265,601,0,'100g',4,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11265,605,0,'100g',NULL,1,'2002-06-08','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11265,606,0.01,'100g',3,1,'2002-06-08','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11266,203,2.5,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11266,204,0.1,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11266,205,4.3,'100g',3,1,'2002-06-08','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11266,207,0.98,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11266,208,22,'100g',3,1,'2002-06-08','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11266,255,92.12,'100g',1,1,'2002-06-08','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11266,269,1.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11266,291,0.6,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11266,301,18,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11266,303,0.4,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11266,306,448,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11266,307,6,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11266,320,0,'100g',2,1,'2024-12-12','2010-01-12');
INSERT INTO `cndb_nutval` VALUES (11266,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11266,401,0,'100g',4,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11266,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11266,601,0,'100g',4,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11266,605,0,'100g',NULL,1,'2002-06-08','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11266,606,0.014,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11267,203,3.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11267,204,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11267,205,7.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11267,207,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11267,208,39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11267,255,87.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11267,269,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11267,291,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11267,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11267,303,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11267,306,326,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11267,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11267,320,0,'100g',1,1,'2024-12-12','2010-01-02');
INSERT INTO `cndb_nutval` VALUES (11267,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11267,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11267,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11267,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11267,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11267,606,0.032,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11268,203,9.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11268,204,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11268,205,75.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11268,207,4.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11268,208,296,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11268,255,9.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11268,269,2.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11268,291,11.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11268,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11268,303,1.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11268,306,1534,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11268,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11268,320,0,'100g',2,1,'2024-12-12','2010-01-02');
INSERT INTO `cndb_nutval` VALUES (11268,328,3.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11268,401,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11268,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11268,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11268,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11268,606,0.225,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11269,203,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11269,204,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11269,205,14.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11269,207,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11269,208,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11269,255,83.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11269,269,3.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11269,291,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11269,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11269,303,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11269,306,117,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11269,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11269,320,0,'100g',1,1,'2024-12-12','2010-01-02');
INSERT INTO `cndb_nutval` VALUES (11269,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11269,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11269,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11269,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11269,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11269,606,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11270,203,2.86,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11270,204,0.42,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11270,205,4.67,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11270,207,1.36,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11270,208,27,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11270,255,90.7,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11270,269,1.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11270,291,3.2,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11270,301,115,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11270,303,1.64,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11270,306,384,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11270,307,20,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11270,320,151,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (11270,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11270,401,70,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11270,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11270,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11270,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11270,606,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11271,203,2.56,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11271,204,0.47,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11271,205,4.51,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11271,207,0.69,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11271,208,26,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11271,255,91.78,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11271,269,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11271,291,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11271,301,118,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11271,303,0.87,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11271,306,162,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11271,307,9,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11271,320,618,'100g',2,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (11271,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11271,401,25.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11271,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11271,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11271,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11271,606,0.012,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11272,203,2.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11272,204,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11272,205,3.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11272,207,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11272,208,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11272,255,93.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11272,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11272,291,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11272,301,116,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11272,303,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11272,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11272,307,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11272,320,258,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11272,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11272,401,25.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11272,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11272,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11272,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11272,606,0.014,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11273,203,2.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11273,204,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11273,205,3.11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11273,207,0.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11273,208,19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11273,255,93.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11273,269,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11273,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11273,301,101,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11273,303,1.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11273,306,139,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11273,307,25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11273,320,354,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11273,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11273,401,13.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11273,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11273,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11273,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11273,606,0.013,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11274,203,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11274,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11274,205,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11274,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11274,208,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11274,255,92.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11274,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11274,291,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11274,301,210,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11274,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11274,306,449,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11274,307,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11274,320,495,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11274,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11274,401,130,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11274,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11274,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11274,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11274,606,0.015,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11276,203,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11276,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11276,205,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11276,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11276,208,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11276,255,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11276,269,0.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11276,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11276,301,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11276,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11276,306,130,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11276,307,130,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11276,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11276,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11276,401,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11276,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11276,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11276,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11276,606,0.032,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11277,203,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11277,204,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11277,205,2.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11277,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11277,208,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11277,255,94.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11277,269,0.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11277,291,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11277,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11277,303,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11277,306,102,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11277,307,107,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11277,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11277,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11277,401,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11277,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11277,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11277,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11277,606,0.027,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11278,203,1.93,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11278,204,0.19,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11278,205,7.45,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11278,207,0.86,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11278,208,33,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11278,255,89.58,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11278,269,1.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11278,291,3.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11278,301,82,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11278,303,0.62,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11278,306,299,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11278,307,7,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11278,320,36,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (11278,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11278,401,23,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11278,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11278,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11278,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11278,606,0.026,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11279,203,1.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11279,204,0.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11279,205,4.51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11279,207,0.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11279,208,22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11279,255,92.57,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11279,269,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11279,291,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11279,301,77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11279,303,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11279,306,135,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11279,307,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11279,320,14,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11279,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11279,401,16.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11279,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11279,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11279,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11279,606,0.045,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11280,203,1.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11280,204,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11280,205,6.63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11280,207,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11280,208,30,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11280,255,90.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11280,269,2.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11280,291,2.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11280,301,81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11280,303,0.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11280,306,211,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11280,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11280,320,18,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11280,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11280,401,12.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11280,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11280,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11280,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11280,606,0.065,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11281,203,1.63,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11281,204,0.24,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11281,205,6.41,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11281,207,0.59,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11281,208,29,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11281,255,91.12,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11281,269,2.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11281,291,2.1,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11281,301,74,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11281,303,0.52,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11281,306,184,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11281,307,3,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11281,320,15,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (11281,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11281,401,9.6,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11281,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11281,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11281,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11281,606,0.063,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11282,203,1.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11282,204,0.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11282,205,9.34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11282,207,0.35,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11282,208,40,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11282,255,89.11,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11282,269,4.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11282,291,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11282,301,23,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11282,303,0.21,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11282,306,146,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11282,307,4,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11282,320,0,'100g',2,1,'2024-12-12','2006-01-06');
INSERT INTO `cndb_nutval` VALUES (11282,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11282,401,7.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11282,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11282,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11282,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11282,606,0.042,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11283,203,1.36,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11283,204,0.19,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11283,205,10.15,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11283,207,0.44,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11283,208,44,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11283,255,87.86,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11283,269,4.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11283,291,1.4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11283,301,22,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11283,303,0.24,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11283,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11283,307,3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11283,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11283,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11283,401,5.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11283,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11283,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11283,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11283,606,0.031,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11284,203,8.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11284,204,0.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11284,205,83.28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11284,207,3.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11284,208,349,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11284,255,3.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11284,269,37.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11284,291,9.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11284,301,257,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11284,303,1.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11284,306,1622,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11284,307,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11284,320,1,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11284,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11284,401,75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11284,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11284,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11284,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11284,606,0.078,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11285,203,0.85,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11285,204,0.09,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11285,205,4.02,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11285,207,0.94,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11285,208,19,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11285,255,94.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11285,269,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11285,291,1.2,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11285,301,45,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11285,303,0.13,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11285,306,111,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11285,307,371,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11285,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (11285,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11285,401,4.3,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11285,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11285,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11285,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11285,606,0.016,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11286,203,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11286,204,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11286,205,7.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11286,207,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11286,208,123,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11286,255,80.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11286,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11286,291,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11286,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11286,303,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11286,306,133,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11286,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11286,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11286,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11286,401,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11286,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11286,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11286,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11286,606,1.477,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11287,203,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11287,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11287,205,6.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11287,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11287,208,29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11287,255,91.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11287,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11287,291,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11287,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11287,303,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11287,306,124,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11287,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11287,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11287,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11287,401,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11287,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11287,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11287,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11287,606,0.017,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11288,203,0.77,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11288,204,0.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11288,205,6.59,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11288,207,0.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11288,208,28,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11288,255,92.24,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11288,269,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11288,291,1.8,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11288,301,16,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11288,303,0.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11288,306,108,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11288,307,12,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11288,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11288,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11288,401,2.6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11288,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11288,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11288,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11288,606,0.016,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11289,203,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11289,204,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11289,205,8.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11289,207,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11289,208,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11289,255,90.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11289,269,3.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11289,291,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11289,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11289,303,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11289,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11289,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11289,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11289,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11289,401,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11289,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11289,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11289,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11289,606,0.011,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11290,203,0.71,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11290,204,0.05,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11290,205,6.7,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11290,207,0.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11290,208,28,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11290,255,92.24,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11290,269,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11290,291,1.4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11290,301,27,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11290,303,0.34,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11290,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11290,307,8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11290,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11290,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11290,401,5.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11290,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11290,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11290,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11290,606,0.009,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11291,203,1.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11291,204,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11291,205,7.34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11291,207,0.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11291,208,32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11291,255,89.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11291,269,2.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11291,291,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11291,301,72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11291,303,1.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11291,306,276,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11291,307,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11291,320,50,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11291,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11291,401,18.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11291,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11291,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11291,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11291,606,0.032,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11292,203,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11292,204,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11292,205,5.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11292,207,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11292,208,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11292,255,92.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11292,269,3.91,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11292,291,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11292,301,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11292,303,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11292,306,159,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11292,307,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11292,320,200,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (11292,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11292,401,13.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11292,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11292,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11292,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11292,606,0.165,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11293,203,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11293,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11293,205,6.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11293,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11293,208,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11293,255,90.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11293,269,2.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11293,291,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11293,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11293,303,1.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11293,306,212,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11293,307,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11293,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11293,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11293,401,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11293,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11293,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11293,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11293,606,0.067,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11295,203,3.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11295,204,14.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11295,205,30.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11295,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11295,208,258,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11295,255,51.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11295,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11295,291,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11295,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11295,303,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11295,306,190,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11295,307,246,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11295,320,0,'100g',1,1,'2024-12-12','2006-01-02');
INSERT INTO `cndb_nutval` VALUES (11295,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11295,401,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11295,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11295,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11295,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11295,606,4.534,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11296,203,4.14,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11296,204,14.3,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11296,205,33.79,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11296,207,1.4,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11296,208,276,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11296,255,46.37,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11296,269,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11296,291,2.2,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11296,301,31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11296,303,1.25,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11296,306,123,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11296,307,370,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11296,320,0,'100g',1,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (11296,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11296,401,1.6,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11296,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11296,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11296,605,0.053,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11296,606,2.137,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11297,203,2.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11297,204,0.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11297,205,6.33,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11297,207,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11297,208,36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11297,255,87.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11297,269,0.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11297,291,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11297,301,138,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11297,303,6.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11297,306,554,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11297,307,56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11297,320,421,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11297,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11297,401,133,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11297,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11297,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11297,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11297,606,0.132,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11298,203,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11298,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11298,205,17.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11298,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11298,208,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11298,255,79.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11298,269,4.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11298,291,4.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11298,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11298,303,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11298,306,375,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11298,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11298,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (11298,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11298,401,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11298,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11298,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11298,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11298,606,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11299,203,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11299,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11299,205,17.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11299,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11299,208,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11299,255,80.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11299,269,4.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11299,291,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11299,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11299,303,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11299,306,367,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11299,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11299,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11299,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11299,401,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11299,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11299,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11299,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11299,606,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11300,203,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11300,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11300,205,7.55,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11300,207,0.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11300,208,42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11300,255,88.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11300,269,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11300,291,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11300,301,43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11300,303,2.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11300,306,200,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11300,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11300,320,54,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11300,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11300,401,60,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11300,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11300,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11300,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11300,606,0.039,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11301,203,3.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11301,204,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11301,205,7.05,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11301,207,0.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11301,208,42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11301,255,88.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11301,269,3.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11301,291,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11301,301,42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11301,303,1.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11301,306,240,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11301,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11301,320,52,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11301,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11301,401,47.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11301,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11301,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11301,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11301,606,0.044,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11302,203,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11302,204,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11302,205,7.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11302,207,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11302,208,42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11302,255,89.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11302,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11302,291,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11302,301,50,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11302,303,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11302,306,192,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11302,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11302,320,7,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11302,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11302,401,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11302,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11302,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11302,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11302,606,0.058,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11303,203,3.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11303,204,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11303,205,9.02,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11303,207,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11303,208,52,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11303,255,86.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11303,269,4.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11303,291,3.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11303,301,59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11303,303,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11303,306,217,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11303,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11303,320,66,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11303,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11303,401,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11303,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11303,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11303,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11303,606,0.073,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11304,203,5.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11304,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11304,205,14.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11304,207,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11304,208,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11304,255,78.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11304,269,5.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11304,291,5.7,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11304,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11304,303,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11304,306,244,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11304,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11304,320,38,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11304,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11304,401,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11304,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11304,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11304,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11304,606,0.071,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11305,203,5.36,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11305,204,0.22,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11305,205,15.63,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11305,207,0.92,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11305,208,84,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11305,255,77.87,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11305,269,5.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11305,291,5.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11305,301,27,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11305,303,1.54,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11305,306,271,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11305,307,3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11305,320,40,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11305,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11305,401,14.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11305,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11305,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11305,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11305,606,0.039,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11306,203,3.01,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11306,204,0.48,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11306,205,10.6,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11306,207,0.77,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11306,208,58,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11306,255,85.13,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11306,269,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11306,291,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11306,301,20,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11306,303,1.29,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11306,306,106,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11306,307,185,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11306,320,76,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (11306,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11306,401,7.8,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11306,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11306,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11306,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11306,606,0.086,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11308,203,4.47,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11308,204,0.8,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11308,205,11.36,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11308,207,1.09,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11308,208,68,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11308,255,82.29,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11308,269,2.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11308,291,4.9,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11308,301,23,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11308,303,1.18,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11308,306,106,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11308,307,273,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11308,320,43,'100g',1,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (11308,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11308,401,4.2,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11308,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11308,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11308,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11308,606,0.143,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11310,203,3.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11310,204,0.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11310,205,9.25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11310,207,0.88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11310,208,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11310,255,86.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11310,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11310,291,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11310,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11310,303,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11310,306,122,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11310,307,254,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11310,320,22,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11310,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11310,401,11.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11310,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11310,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11310,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11310,606,0.048,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11311,203,4.33,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11311,204,0.95,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11311,205,11.82,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11311,207,1.01,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11311,208,71,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11311,255,81.89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11311,269,NULL,'100g',NULL,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11311,291,NULL,'100g',NULL,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11311,301,24,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11311,303,1.09,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11311,306,105,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11311,307,231,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11311,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11311,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11311,401,9.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11311,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11311,601,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11311,605,0,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11311,606,0.17,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (11312,203,5.22,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11312,204,0.4,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11312,205,13.62,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11312,207,0.78,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11312,208,77,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11312,255,79.98,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11312,269,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11312,291,4.5,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11312,301,22,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11312,303,1.53,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11312,306,153,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11312,307,108,'100g',7,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (11312,320,103,'100g',2,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (11312,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11312,401,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11312,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11312,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11312,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11312,606,0.066,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11313,203,5.15,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11313,204,0.27,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11313,205,14.26,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11313,207,0.8,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11313,208,78,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11313,255,79.52,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11313,269,4.4,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11313,291,4.5,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11313,301,24,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11313,303,1.52,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11313,306,110,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11313,307,72,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11313,320,105,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (11313,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11313,401,9.9,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11313,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11313,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11313,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11313,606,0.049,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11316,203,8.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11316,204,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11316,205,27.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11316,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11316,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11316,255,62.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11316,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11316,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11316,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11316,303,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11316,306,381,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11316,307,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11316,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11316,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11316,401,10.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11316,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11316,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11316,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11316,606,0.124,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11317,203,7.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11317,204,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11317,205,17.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11317,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11317,208,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11317,255,74.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11317,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11317,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11317,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11317,303,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11317,306,268,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11317,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11317,320,5,'100g',2,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11317,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11317,401,6.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11317,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11317,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11317,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11317,606,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11318,203,2.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11318,204,0.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11318,205,8.48,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11318,207,0.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11318,208,38,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11318,255,88.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11318,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11318,291,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11318,301,23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11318,303,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11318,306,100,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11318,307,260,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11318,320,289,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11318,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11318,401,6.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11318,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11318,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11318,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11318,606,0.049,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11322,203,3.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11322,204,0.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11322,205,11.15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11322,207,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11322,208,53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11322,255,84.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11322,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11322,291,3.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11322,301,27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11322,303,1.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11322,306,194,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11322,307,79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11322,320,475,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11322,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11322,401,11.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11322,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11322,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11322,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11322,606,0.084,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11323,203,3.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11323,204,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11323,205,10.12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11323,207,0.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11323,208,48,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11323,255,85.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11323,269,4.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11323,291,3.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11323,301,23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11323,303,0.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11323,306,158,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11323,307,68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11323,320,476,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11323,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11323,401,8.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11323,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11323,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11323,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11323,606,0.077,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11324,203,3.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11324,204,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11324,205,8.57,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11324,207,1.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11324,208,51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11324,255,86.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11324,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11324,291,2.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11324,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11324,303,0.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11324,306,96,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11324,307,442,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11324,320,8,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11324,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11324,401,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11324,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11324,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11324,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11324,606,0.068,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11326,203,3.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11326,204,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11326,205,13.51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11326,207,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11326,208,70,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11326,255,81.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11326,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11326,291,3.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11326,301,23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11326,303,1.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11326,306,203,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11326,307,61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11326,320,27,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11326,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11326,401,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11326,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11326,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11326,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11326,606,0.057,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11327,203,2.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11327,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11327,205,8.63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11327,207,0.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11327,208,45,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11327,255,88.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11327,269,3.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11327,291,2.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11327,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11327,303,0.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11327,306,117,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11327,307,37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11327,320,53,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11327,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11327,401,6.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11327,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11327,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11327,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11327,606,0.036,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11329,203,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11329,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11329,205,5.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11329,207,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11329,208,21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11329,255,92.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11329,269,3.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11329,291,1.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11329,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11329,303,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11329,306,187,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11329,307,1173,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11329,320,36,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11329,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11329,401,68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11329,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11329,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11329,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11329,606,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11333,203,0.86,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11333,204,0.17,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11333,205,4.64,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11333,207,0.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11333,208,20,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11333,255,93.89,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11333,269,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11333,291,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11333,301,10,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11333,303,0.34,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11333,306,175,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11333,307,3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11333,320,18,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11333,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11333,401,80.4,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11333,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11333,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11333,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11333,606,0.058,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11334,203,0.92,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11334,204,0.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11334,205,6.7,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11334,207,0.31,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11334,208,28,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11334,255,91.87,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11334,269,3.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11334,291,1.2,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11334,301,9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11334,303,0.46,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11334,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11334,307,2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11334,320,23,'100g',2,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (11334,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11334,401,74.4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11334,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11334,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11334,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11334,606,0.029,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11335,203,0.8,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11335,204,0.3,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11335,205,3.9,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11335,207,3.75,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11335,208,18,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11335,255,91.25,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11335,269,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11335,291,1.2,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11335,301,41,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11335,303,0.8,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11335,306,146,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11335,307,1369,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11335,320,8,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11335,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11335,401,46.5,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11335,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11335,601,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11335,605,0,'100g',NULL,1,'2010-01-04','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11335,606,0.045,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11337,203,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11337,204,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11337,205,4.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11337,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11337,208,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11337,255,93.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11337,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11337,291,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11337,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11337,303,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11337,306,91,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11337,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11337,320,18,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11337,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11337,401,58.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11337,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11337,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11337,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11337,606,0.031,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11338,203,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11338,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11338,205,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11338,207,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11338,208,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11338,255,94.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11338,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11338,291,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11338,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11338,303,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11338,306,72,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11338,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11338,320,15,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11338,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11338,401,41.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11338,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11338,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11338,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11338,606,0.027,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11339,203,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11339,204,11.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11339,205,4.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11339,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11339,208,116,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11339,255,82.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11339,269,2.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11339,291,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11339,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11339,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11339,306,134,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11339,307,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11339,320,14,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11339,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11339,401,177,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11339,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11339,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11339,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11339,606,1.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11344,203,7.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11344,204,1.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11344,205,23.88,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11344,207,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11344,208,136,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11344,255,65.88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11344,269,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11344,291,5.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11344,301,42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11344,303,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11344,306,552,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11344,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11344,320,3,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11344,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11344,401,39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11344,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11344,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11344,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11344,606,0.354,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11345,203,5.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11345,204,1.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11345,205,19.49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11345,207,1.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11345,208,111,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11345,255,71.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11345,269,2.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11345,291,4.2,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11345,301,41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11345,303,1.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11345,306,456,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11345,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11345,320,2,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11345,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11345,401,28.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11345,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11345,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11345,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11345,606,0.365,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11349,203,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11349,204,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11349,205,27.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11349,207,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11349,208,112,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11349,255,71.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11349,269,0.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11349,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11349,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11349,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11349,306,183,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11349,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11349,320,3,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11349,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11349,401,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11349,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11349,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11349,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11349,606,0.029,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11351,203,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11351,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11351,205,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11351,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11351,208,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11351,255,92.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11351,269,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11351,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11351,301,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11351,303,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11351,306,184,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11351,307,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11351,320,435,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11351,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11351,401,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11351,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11351,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11351,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11351,606,0.092,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11352,203,2.05,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11352,204,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11352,205,17.49,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11352,207,1.11,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11352,208,77,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11352,255,79.25,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11352,269,0.82,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11352,291,2.1,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11352,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11352,303,0.81,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11352,306,425,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11352,307,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11352,320,0,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (11352,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11352,401,19.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11352,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11352,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11352,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11352,606,0.025,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11353,203,2.14,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11353,204,0.08,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11353,205,18.07,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11353,207,1.13,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11353,208,79,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11353,255,78.58,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11353,269,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11353,291,1.3,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11353,301,13,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11353,303,0.86,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11353,306,417,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11353,307,5,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11353,320,0,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (11353,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11353,401,5.7,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11353,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11353,601,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11353,605,0,'100g',NULL,1,'2006-02-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11353,606,0.026,'100g',1,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11354,203,1.68,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11354,204,0.1,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11354,205,15.71,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11354,207,0.94,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11354,208,69,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11354,255,81.58,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11354,269,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11354,291,2.4,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11354,301,9,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11354,303,0.52,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11354,306,407,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11354,307,16,'100g',1,1,'2006-02-23','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11354,320,0,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (11354,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11354,401,9.1,'100g',1,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11354,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11354,601,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11354,605,0,'100g',NULL,1,'2006-02-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11354,606,0.026,'100g',1,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11355,203,1.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11355,204,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11355,205,15.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11355,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11355,208,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11355,255,80.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11355,269,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11355,291,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11355,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11355,303,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11355,306,455,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11355,307,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11355,320,0,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (11355,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11355,401,8.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11355,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11355,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11355,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11355,606,0.035,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11356,203,2.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11356,204,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11356,205,21.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11356,207,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11356,208,95,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11356,255,74.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11356,269,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11356,291,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11356,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11356,303,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11356,306,550,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11356,307,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11356,320,1,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (11356,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11356,401,8.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11356,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11356,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11356,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11356,606,0.032,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11357,203,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11357,204,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11357,205,21.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11357,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11357,208,92,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11357,255,75.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11357,269,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11357,291,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11357,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11357,303,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11357,306,544,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11357,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11357,320,1,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (11357,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11357,401,12.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11357,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11357,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11357,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11357,606,0.04,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11358,203,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11358,204,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11358,205,19.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11358,207,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11358,208,87,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11358,255,76.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11358,269,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11358,291,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11358,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11358,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11358,306,545,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11358,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11358,320,1,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (11358,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11358,401,12.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11358,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11358,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11358,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11358,606,0.04,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11359,203,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11359,204,4.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11359,205,23.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11359,207,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11359,208,146,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11359,255,67.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11359,269,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11359,291,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11359,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11359,303,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11359,306,380,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11359,307,349,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11359,320,0,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (11359,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11359,401,7.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11359,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11359,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11359,605,0.106,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11359,606,1.249,'100g',7,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11360,203,2.51,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11360,204,5.13,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11360,205,27.5,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11360,207,1.79,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11360,208,161,'100g',3,1,'2006-02-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11360,255,63.07,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11360,269,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11360,291,2.3,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11360,301,13,'100g',7,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11360,303,0.75,'100g',7,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11360,306,471,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11360,307,391,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11360,320,0,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (11360,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11360,401,11.8,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11360,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11360,601,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11360,605,NULL,'100g',NULL,1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11360,606,1.082,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11361,203,2.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11361,204,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11361,205,26.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11361,207,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11361,208,127,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11361,255,68.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11361,269,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11361,291,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11361,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11361,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11361,306,450,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11361,307,298,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11361,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11361,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11361,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11361,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11361,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11361,605,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11361,606,0.167,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11362,203,2.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11362,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11362,205,12.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11362,207,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11362,208,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11362,255,83.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11362,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11362,291,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11362,301,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11362,303,3.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11362,306,413,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11362,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11362,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11362,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11362,401,11.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11362,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11362,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11362,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11362,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11363,203,1.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11363,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11363,205,21.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11363,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11363,208,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11363,255,75.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11363,269,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11363,291,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11363,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11363,303,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11363,306,391,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11363,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11363,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11363,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11363,401,12.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11363,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11363,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11363,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11363,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11364,203,4.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11364,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11364,205,46.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11364,207,2.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11364,208,198,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11364,255,47.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11364,269,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11364,291,7.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11364,301,34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11364,303,7.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11364,306,573,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11364,307,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11364,320,1,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11364,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11364,401,13.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11364,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11364,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11364,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11364,606,0.026,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11365,203,1.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11365,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11365,205,20.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11365,207,0.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11365,208,87,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11365,255,76.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11365,269,0.91,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11365,291,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11365,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11365,303,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11365,306,379,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11365,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11365,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11365,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11365,401,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11365,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11365,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11365,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11365,606,0.026,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11366,203,2.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11366,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11366,205,17.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11366,207,2.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11366,208,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11366,255,77.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11366,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11366,291,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11366,301,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11366,303,6.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11366,306,407,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11366,307,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11366,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11366,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11366,401,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11366,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11366,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11366,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11366,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11367,203,1.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11367,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11367,205,20.01,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11367,207,0.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11367,208,86,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11367,255,77.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11367,269,0.89,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11367,291,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11367,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11367,303,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11367,306,328,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11367,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11367,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11367,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11367,401,7.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11367,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11367,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11367,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11367,606,0.026,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11368,203,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11368,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11368,205,23.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11368,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11368,208,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11368,255,73.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11368,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11368,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11368,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11368,303,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11368,306,411,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11368,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11368,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11368,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11368,401,15.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11368,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11368,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11368,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11368,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11369,203,4.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11369,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11369,205,29.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11369,207,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11369,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11369,255,63.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11369,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11369,291,5.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11369,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11369,303,5.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11369,306,650,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11369,307,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11369,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11369,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11369,401,15.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11369,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11369,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11369,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11369,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11370,203,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11370,204,12.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11370,205,35.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11370,207,2.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11370,208,265,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11370,255,47.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11370,269,1.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11370,291,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11370,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11370,303,0.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11370,306,576,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11370,307,342,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11370,320,0,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (11370,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11370,401,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11370,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11370,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11370,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11370,606,1.883,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11371,203,1.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11371,204,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11371,205,16.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11371,207,1.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11371,208,113,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11371,255,75.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11371,269,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11371,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11371,301,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11371,303,0.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11371,306,326,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11371,307,333,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11371,320,44,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (11371,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11371,401,10.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11371,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11371,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11371,605,0.517,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11371,606,0.745,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11372,203,2.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11372,204,3.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11372,205,10.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11372,207,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11372,208,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11372,255,80.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11372,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11372,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11372,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11372,303,0.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11372,306,378,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11372,307,335,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11372,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11372,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11372,401,10.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11372,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11372,601,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11372,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11372,606,2.255,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11373,203,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11373,204,7.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11373,205,11.26,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11373,207,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11373,208,134,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11373,255,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11373,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11373,291,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11373,301,119,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11373,303,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11373,306,396,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11373,307,433,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11373,320,64,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11373,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11373,401,9.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11373,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11373,601,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11373,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11373,606,4.733,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11374,203,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11374,204,0.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11374,205,9.89,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11374,207,0.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11374,208,44,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11374,255,87.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11374,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11374,291,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11374,301,39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11374,303,0.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11374,306,205,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11374,307,217,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11374,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11374,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11374,401,7.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11374,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11374,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11374,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11374,606,0.029,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11376,203,1.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11376,204,0.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11376,205,13.61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11376,207,0.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11376,208,60,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11376,255,84.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11376,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11376,291,2.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11376,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11376,303,1.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11376,306,229,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11376,307,219,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11376,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11376,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11376,401,5.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11376,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11376,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11376,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11376,606,0.054,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11378,203,8.34,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11378,204,0.41,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11378,205,81.17,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11378,207,3.5,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11378,208,354,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11378,255,6.58,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11378,269,3.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11378,291,6.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11378,301,27,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11378,303,1.21,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11378,306,1098,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11378,307,77,'100g',6,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11378,320,1,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11378,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11378,401,81,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11378,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11378,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11378,605,NULL,'100g',NULL,1,'1994-01-31','2007-03-25');
INSERT INTO `cndb_nutval` VALUES (11378,606,0.169,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11379,203,1.77,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11379,204,5.13,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11379,205,10.87,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11379,207,1.03,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11379,208,97,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11379,255,81.2,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11379,269,1.61,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11379,291,0.8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11379,301,32,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11379,303,0.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11379,306,164,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11379,307,164,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11379,320,47,'100g',2,1,'2024-12-12','2008-01-12');
INSERT INTO `cndb_nutval` VALUES (11379,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11379,401,9.7,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11379,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11379,601,14,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11379,605,0.175,'100g',7,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11379,606,3.191,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11380,203,8.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11380,204,0.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11380,205,85.51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11380,207,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11380,208,372,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11380,255,3.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11380,269,3.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11380,291,7.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11380,301,41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11380,303,1.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11380,306,703,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11380,307,67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11380,320,1,'100g',2,1,'2024-12-12','2008-01-12');
INSERT INTO `cndb_nutval` VALUES (11380,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11380,401,37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11380,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11380,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11380,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11380,606,0.138,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11381,203,2.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11381,204,4.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11381,205,14.36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11381,207,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11381,208,108,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11381,255,77.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11381,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11381,291,2.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11381,301,35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11381,303,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11381,306,144,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11381,307,257,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11381,320,43,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (11381,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11381,401,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11381,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11381,601,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11381,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11381,606,3.056,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11382,203,10.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11382,204,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11382,205,77.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11382,207,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11382,208,357,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11382,255,6.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11382,269,3.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11382,291,6.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11382,301,142,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11382,303,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11382,306,1848,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11382,307,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11382,320,18,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11382,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11382,401,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11382,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11382,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11382,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11382,606,0.461,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11383,203,2.13,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11383,204,4.8,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11383,205,16.13,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11383,207,0.93,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11383,208,116,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11383,255,76.01,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11383,269,1.74,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11383,291,1.3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11383,301,35,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11383,303,0.2,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11383,306,155,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11383,307,172,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11383,320,51,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (11383,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11383,401,6.5,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11383,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11383,601,2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11383,605,0.599,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11383,606,0.955,'100g',7,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11384,203,8.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11384,204,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11384,205,74.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11384,207,8.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11384,208,314,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11384,255,4.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11384,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11384,291,4.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11384,301,311,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11384,303,1.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11384,306,990,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11384,307,2095,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11384,320,54,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (11384,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11384,401,15.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11384,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11384,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11384,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11384,606,2.323,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11385,203,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11385,204,4.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11385,205,12.84,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11385,207,1.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11385,208,93,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11385,255,78.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11385,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11385,291,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11385,301,83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11385,303,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11385,306,219,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11385,307,439,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11385,320,52,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11385,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11385,401,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11385,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11385,601,15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11385,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11385,606,2.586,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11386,203,7.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11386,204,4.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11386,205,73.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11386,207,7.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11386,208,358,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11386,255,6.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11386,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11386,291,8.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11386,301,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11386,303,2.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11386,306,905,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11386,307,1578,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11386,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11386,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11386,401,16.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11386,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11386,601,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11386,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11386,606,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11387,203,2.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11387,204,4.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11387,205,12.77,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11387,207,1.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11387,208,93,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11387,255,79.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11387,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11387,291,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11387,301,36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11387,303,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11387,306,203,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11387,307,341,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11387,320,35,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11387,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11387,401,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11387,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11387,601,11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11387,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11387,606,2.633,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11390,203,2.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11390,204,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11390,205,17.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11390,207,0.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11390,208,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11390,255,78.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11390,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11390,291,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11390,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11390,303,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11390,306,285,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11390,307,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11390,320,0,'100g',1,1,'2024-12-12','2006-01-02');
INSERT INTO `cndb_nutval` VALUES (11390,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11390,401,8.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11390,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11390,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11390,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11390,606,0.163,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11391,203,2.65,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11391,204,11.59,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11391,205,28.51,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11391,207,1.3,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11391,208,219,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11391,255,55.95,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11391,269,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11391,291,3.2,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11391,301,17,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11391,303,0.54,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11391,306,496,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11391,307,15,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11391,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11391,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11391,401,6.7,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11391,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11391,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11391,605,0.036,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11391,606,0.934,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11392,203,1.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11392,204,6.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11392,205,18.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11392,207,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11392,208,135,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11392,255,72.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11392,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11392,291,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11392,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11392,303,0.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11392,306,248,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11392,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11392,320,19,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11392,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11392,401,5.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11392,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11392,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11392,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11392,606,2.556,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11393,203,2.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11393,204,8.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11393,205,24.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11393,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11393,208,178,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11393,255,63.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11393,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11393,291,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11393,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11393,303,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11393,306,327,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11393,307,101,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11393,320,26,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11393,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11393,401,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11393,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11393,601,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11393,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11393,606,3.373,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11394,203,2.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11394,204,6.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11394,205,25.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11394,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11394,208,163,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11394,255,64.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11394,269,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11394,291,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11394,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11394,303,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11394,306,379,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11394,307,323,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11394,320,0,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (11394,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11394,401,12.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11394,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11394,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11394,605,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11394,606,1.371,'100g',7,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11395,203,2.9,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11395,204,6.76,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11395,205,31.66,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11395,207,2.07,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11395,208,194,'100g',3,1,'2006-02-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11395,255,56.62,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11395,269,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11395,291,2.8,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11395,301,12,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11395,303,0.8,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11395,306,505,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11395,307,400,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11395,320,0,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (11395,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11395,401,14.2,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11395,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11395,601,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11395,605,NULL,'100g',NULL,1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11395,606,1.267,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11396,203,1.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11396,204,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11396,205,17.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11396,207,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11396,208,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11396,255,79.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11396,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11396,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11396,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11396,303,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11396,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11396,307,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11396,320,7,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11396,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11396,401,11.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11396,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11396,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11396,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11396,606,0.032,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11397,203,2.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11397,204,13.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11397,205,21.86,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11397,207,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11397,208,204,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11397,255,61.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11397,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11397,291,1.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11397,301,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11397,303,0.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11397,306,473,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11397,307,43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11397,320,9,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11397,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11397,401,10.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11397,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11397,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11397,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11397,606,3.313,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11398,203,1.93,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11398,204,8.71,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11398,205,24.8,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11398,207,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11398,208,178,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11398,255,62.8,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11398,269,0.28,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11398,291,2.3,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11398,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11398,303,0.47,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11398,306,247,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11398,307,428,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11398,320,0,'100g',2,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11398,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11398,401,6.9,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11398,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11398,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11398,605,0.063,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11398,606,1.418,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11399,203,2.13,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11399,204,9.05,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11399,205,27.29,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11399,207,1.89,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11399,208,192,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11399,255,59.65,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11399,269,0.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11399,291,2,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11399,301,14,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11399,303,0.58,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11399,306,287,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11399,307,463,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11399,320,0,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (11399,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11399,401,4,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11399,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11399,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11399,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11399,606,1.657,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11401,203,1.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11401,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11401,205,14.52,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11401,207,0.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11401,208,65,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11401,255,82.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11401,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11401,291,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11401,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11401,303,0.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11401,306,287,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11401,307,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11401,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11401,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11401,401,9.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11401,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11401,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11401,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11401,606,0.034,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11402,203,2.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11402,204,4.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11402,205,24.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11402,207,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11402,208,147,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11402,255,66.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11402,269,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11402,291,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11402,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11402,303,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11402,306,408,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11402,307,332,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11402,320,0,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11402,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11402,401,17.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11402,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11402,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11402,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11402,606,1.005,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11403,203,2.75,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11403,204,5.48,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11403,205,25.55,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11403,207,1.77,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11403,208,158,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11403,255,64.44,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11403,269,0.37,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11403,291,2,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11403,301,12,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11403,303,0.57,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11403,306,478,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11403,307,324,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11403,320,0,'100g',2,1,'2024-12-12','2010-01-02');
INSERT INTO `cndb_nutval` VALUES (11403,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11403,401,8.6,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11403,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11403,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11403,605,NULL,'100g',NULL,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11403,606,0.848,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11406,203,2.42,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11406,204,5.78,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11406,205,23.98,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11406,207,1.01,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11406,208,153,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11406,255,66.82,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11406,269,NULL,'100g',NULL,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11406,291,3,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11406,301,7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11406,303,1.05,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11406,306,338,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11406,307,32,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11406,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11406,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11406,401,8.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11406,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11406,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11406,605,NULL,'100g',NULL,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11406,606,2.743,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11407,203,3.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11407,204,8.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11407,205,34.03,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11407,207,1.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11407,208,218,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11407,255,52.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11407,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11407,291,3.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11407,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11407,303,1.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11407,306,480,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11407,307,45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11407,320,0,'100g',1,1,'2024-12-12','2006-01-02');
INSERT INTO `cndb_nutval` VALUES (11407,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11407,401,9.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11407,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11407,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11407,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11407,606,3.894,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11408,203,2.83,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11408,204,14.95,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11408,205,30.15,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11408,207,2.13,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11408,208,260,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11408,255,49.94,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11408,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11408,291,2.9,'100g',3,1,'1996-09-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11408,301,9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11408,303,1.32,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11408,306,430,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11408,307,490,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11408,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11408,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11408,401,6.3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11408,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11408,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11408,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11408,606,4.544,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11409,203,3.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11409,204,18.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11409,205,39.68,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11409,207,2.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11409,208,333,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11409,255,35.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11409,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11409,291,3.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11409,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11409,303,1.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11409,306,539,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11409,307,613,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11409,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11409,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11409,401,6.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11409,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11409,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11409,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11409,606,5.96,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11410,203,2.7,'100g',1,1,'1999-06-18','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11410,204,2.2,'100g',1,1,'1999-06-18','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11410,205,25.46,'100g',3,1,'1999-06-18','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11410,207,1.34,'100g',1,1,'1999-06-18','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11410,208,129,'100g',3,1,'1999-06-18','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11410,255,68.3,'100g',1,1,'1999-06-18','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11410,269,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11410,291,2,'100g',1,1,'1999-06-18','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11410,301,15,'100g',1,1,'1999-06-18','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11410,303,0.7,'100g',1,1,'1999-06-18','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11410,306,394,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11410,307,49,'100g',1,1,'1999-06-18','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11410,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11410,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11410,401,11.2,'100g',1,1,'1999-06-18','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11410,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11410,601,0,'100g',4,1,'1999-06-18','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11410,605,0,'100g',NULL,1,'1999-06-18','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11410,606,0.55,'100g',1,1,'1999-06-18','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11411,203,2.19,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11411,204,3.39,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11411,205,23.51,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11411,207,1.61,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11411,208,130,'100g',3,1,'2006-02-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11411,255,69.29,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11411,269,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11411,291,1.9,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11411,301,9,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11411,303,0.65,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11411,306,400,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11411,307,317,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11411,320,0,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (11411,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11411,401,18.4,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11411,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11411,601,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11411,605,NULL,'100g',NULL,1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11411,606,0.688,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11412,203,2.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11412,204,3.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11412,205,26.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11412,207,1.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11412,208,148,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11412,255,64.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11412,269,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11412,291,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11412,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11412,303,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11412,306,459,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11412,307,373,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11412,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11412,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11412,401,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11412,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11412,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11412,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11412,606,0.737,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11413,203,6.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11413,204,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11413,205,83.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11413,207,3.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11413,208,357,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11413,255,6.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11413,269,3.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11413,291,5.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11413,301,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11413,303,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11413,306,1001,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11413,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11413,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11413,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11413,401,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11413,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11413,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11413,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11413,606,0.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11414,203,2.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11414,204,8.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11414,205,11.17,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11414,207,1.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11414,208,143,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11414,255,76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11414,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11414,291,1.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11414,301,19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11414,303,0.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11414,306,254,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11414,307,529,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11414,320,32,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (11414,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11414,401,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11414,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11414,601,68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11414,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11414,606,1.429,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11416,203,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11416,204,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11416,205,3.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11416,207,0.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11416,208,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11416,255,95.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11416,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11416,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11416,301,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11416,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11416,306,173,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11416,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11416,320,97,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11416,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11416,401,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11416,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11416,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11416,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11416,606,0.036,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11417,203,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11417,204,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11417,205,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11417,207,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11417,208,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11417,255,95.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11417,269,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11417,291,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11417,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11417,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11417,306,106,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11417,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11417,320,87,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11417,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11417,401,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11417,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11417,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11417,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11417,606,0.041,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11418,203,3.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11418,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11418,205,2.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11418,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11418,208,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11418,255,92.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11418,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11418,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11418,301,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11418,303,2.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11418,306,436,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11418,307,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11418,320,97,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11418,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11418,401,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11418,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11418,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11418,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11418,606,0.207,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11419,203,2.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11419,204,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11419,205,3.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11419,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11419,208,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11419,255,92.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11419,269,0.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11419,291,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11419,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11419,303,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11419,306,438,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11419,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11419,320,80,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11419,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11419,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11419,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11419,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11419,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11419,606,0.114,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11422,203,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11422,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11422,205,6.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11422,207,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11422,208,26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11422,255,91.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11422,269,2.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11422,291,0.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11422,301,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11422,303,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11422,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11422,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11422,320,426,'100g',2,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (11422,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11422,401,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11422,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11422,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11422,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11422,606,0.052,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11423,203,0.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11423,204,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11423,205,4.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11423,207,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11423,208,20,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11423,255,93.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11423,269,2.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11423,291,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11423,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11423,303,0.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11423,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11423,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11423,320,288,'100g',2,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (11423,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11423,401,4.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11423,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11423,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11423,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11423,606,0.037,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11424,203,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11424,204,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11424,205,8.09,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11424,207,0.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11424,208,34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11424,255,89.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11424,269,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11424,291,2.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11424,301,26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11424,303,1.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11424,306,206,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11424,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11424,320,778,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11424,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11424,401,4.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11424,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11424,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11424,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11424,606,0.146,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11426,203,1.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11426,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11426,205,26.39,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11426,207,0.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11426,208,104,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11426,255,71.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11426,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11426,291,8.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11426,301,37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11426,303,1.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11426,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11426,307,208,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11426,320,415,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11426,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11426,401,3.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11426,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11426,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11426,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11426,606,0.065,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11429,203,0.68,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11429,204,0.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11429,205,3.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11429,207,0.55,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11429,208,16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11429,255,95.27,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11429,269,1.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11429,291,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11429,301,25,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11429,303,0.34,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11429,306,233,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11429,307,39,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11429,320,0,'100g',1,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (11429,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11429,401,14.8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11429,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11429,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11429,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11429,606,0.032,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11430,203,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11430,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11430,205,4.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11430,207,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11430,208,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11430,255,94.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11430,269,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11430,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11430,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11430,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11430,306,227,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11430,307,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11430,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11430,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11430,401,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11430,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11430,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11430,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11430,606,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11431,203,0.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11431,204,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11431,205,3.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11431,207,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11431,208,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11431,255,95.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11431,269,1.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11431,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11431,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11431,303,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11431,306,285,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11431,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11431,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11431,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11431,401,15.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11431,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11431,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11431,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11431,606,0.073,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11432,203,7.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11432,204,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11432,205,63.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11432,207,8.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11432,208,271,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11432,255,19.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11432,269,37.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11432,291,23.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11432,301,629,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11432,303,6.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11432,306,3494,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11432,307,278,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11432,320,0,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (11432,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11432,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11432,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11432,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11432,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11432,606,0.218,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11435,203,1.08,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11435,204,0.16,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11435,205,8.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11435,207,0.71,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11435,208,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11435,255,89.43,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11435,269,4.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11435,291,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11435,301,43,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11435,303,0.44,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11435,306,305,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11435,307,12,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11435,320,0,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (11435,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11435,401,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11435,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11435,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11435,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11435,606,0.027,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11436,203,0.93,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11436,204,0.18,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11436,205,6.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11436,207,0.51,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11436,208,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11436,255,91.54,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11436,269,3.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11436,291,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11436,301,18,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11436,303,0.18,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11436,306,216,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11436,307,5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11436,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11436,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11436,401,18.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11436,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11436,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11436,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11436,606,0.029,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11438,203,2.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11438,204,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11438,205,15.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11438,207,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11438,208,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11438,255,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11438,269,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11438,291,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11438,301,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11438,303,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11438,306,283,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11438,307,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11438,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11438,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11438,401,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11438,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11438,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11438,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11438,606,0.041,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11439,203,0.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11439,204,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11439,205,4.28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11439,207,2.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11439,208,19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11439,255,92.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11439,269,1.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11439,291,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11439,301,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11439,303,1.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11439,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11439,307,661,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11439,320,1,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11439,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11439,401,14.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11439,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11439,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11439,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11439,606,0.034,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11442,203,0.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11442,204,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11442,205,6.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11442,207,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11442,208,26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11442,255,91.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11442,269,0.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11442,291,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11442,301,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11442,303,1.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11442,306,226,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11442,307,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11442,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11442,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11442,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11442,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11442,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11442,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11442,606,0.006,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11444,203,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11444,204,0.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11444,205,12.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11444,207,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11444,208,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11444,255,81.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11444,269,0.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11444,291,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11444,301,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11444,303,8.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11444,306,63,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11444,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11444,320,6,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11444,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11444,401,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11444,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11444,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11444,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11444,606,0.033,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11445,203,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11445,204,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11445,205,9.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11445,207,6.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11445,208,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11445,255,81.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11445,269,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11445,291,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11445,301,168,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11445,303,2.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11445,306,89,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11445,307,233,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11445,320,6,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11445,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11445,401,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11445,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11445,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11445,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11445,606,0.247,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11446,203,5.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11446,204,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11446,205,5.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11446,207,3.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11446,208,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11446,255,85.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11446,269,0.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11446,291,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11446,301,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11446,303,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11446,306,356,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11446,307,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11446,320,260,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11446,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11446,401,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11446,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11446,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11446,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11446,606,0.061,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11450,203,12.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11450,204,6.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11450,205,11.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11450,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11450,208,147,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11450,255,67.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11450,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11450,291,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11450,301,197,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11450,303,3.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11450,306,620,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11450,307,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11450,320,9,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11450,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11450,401,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11450,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11450,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11450,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11450,606,0.786,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11451,203,12.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11451,204,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11451,205,11.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11451,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11451,208,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11451,255,68.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11451,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11451,291,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11451,301,145,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11451,303,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11451,306,539,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11451,307,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11451,320,8,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11451,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11451,401,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11451,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11451,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11451,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11451,606,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11452,203,13.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11452,204,6.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11452,205,9.57,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11452,207,1.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11452,208,122,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11452,255,69.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11452,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11452,291,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11452,301,67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11452,303,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11452,306,484,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11452,307,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11452,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11452,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11452,401,15.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11452,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11452,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11452,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11452,606,0.929,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11453,203,8.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11453,204,4.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11453,205,6.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11453,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11453,208,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11453,255,79.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11453,269,0.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11453,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11453,301,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11453,303,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11453,306,355,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11453,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11453,320,2,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11453,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11453,401,8.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11453,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11453,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11453,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11453,606,0.617,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11454,203,13.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11454,204,7.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11454,205,9.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11454,207,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11454,208,125,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11454,255,67.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11454,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11454,291,0.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11454,301,82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11454,303,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11454,306,567,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11454,307,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11454,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11454,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11454,401,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11454,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11454,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11454,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11454,606,0.985,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11457,203,2.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11457,204,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11457,205,3.63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11457,207,1.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11457,208,23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11457,255,91.4,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11457,269,0.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11457,291,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11457,301,99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11457,303,2.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11457,306,558,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11457,307,79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11457,320,469,'100g',1,1,'2024-12-12','2008-01-10');
INSERT INTO `cndb_nutval` VALUES (11457,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11457,401,28.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11457,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11457,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11457,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11457,606,0.063,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11458,203,2.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11458,204,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11458,205,3.75,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11458,207,1.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11458,208,23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11458,255,91.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11458,269,0.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11458,291,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11458,301,136,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11458,303,3.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11458,306,466,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11458,307,70,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11458,320,524,'100g',1,1,'2024-12-12','2008-01-10');
INSERT INTO `cndb_nutval` VALUES (11458,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11458,401,9.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11458,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11458,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11458,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11458,606,0.043,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11459,203,2.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11459,204,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11459,205,2.92,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11459,207,1.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11459,208,19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11459,255,93.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11459,269,0.33,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11459,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11459,301,83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11459,303,1.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11459,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11459,307,319,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11459,320,404,'100g',2,1,'2024-12-12','2015-01-01');
INSERT INTO `cndb_nutval` VALUES (11459,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11459,401,13.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11459,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11459,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11459,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11459,606,0.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11461,203,2.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11461,204,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11461,205,3.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11461,207,1.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11461,208,23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11461,255,91.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11461,269,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11461,291,2.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11461,301,127,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11461,303,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11461,306,346,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11461,307,322,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11461,320,490,'100g',2,1,'2024-12-12','2009-01-01');
INSERT INTO `cndb_nutval` VALUES (11461,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11461,401,14.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11461,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11461,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11461,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11461,606,0.081,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11463,203,3.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11463,204,0.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11463,205,4.21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11463,207,1.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11463,208,29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11463,255,90.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11463,269,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11463,291,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11463,301,129,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11463,303,1.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11463,306,346,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11463,307,74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11463,320,586,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (11463,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11463,401,5.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11463,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11463,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11463,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11463,606,0.041,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11464,203,4.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11464,204,0.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11464,205,4.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11464,207,1.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11464,208,34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11464,255,88.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11464,269,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11464,291,3.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11464,301,153,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11464,303,1.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11464,306,302,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11464,307,97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11464,320,603,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (11464,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11464,401,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11464,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11464,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11464,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11464,606,0.157,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11467,203,1.01,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11467,204,0.27,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11467,205,3.88,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11467,207,0.56,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11467,208,19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11467,255,94.28,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11467,269,2.88,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11467,291,1,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11467,301,21,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11467,303,0.44,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11467,306,222,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11467,307,2,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11467,320,8,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (11467,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11467,401,19.3,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11467,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11467,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11467,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11467,606,0.093,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11468,203,1.04,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11468,204,0.39,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11468,205,3.79,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11468,207,0.53,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11468,208,19,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11468,255,94.25,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11468,269,2.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11468,291,1.1,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11468,301,22,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11468,303,0.37,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11468,306,177,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11468,307,1,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11468,320,56,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (11468,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11468,401,11.6,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11468,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11468,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11468,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11468,606,0.064,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11471,203,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11471,204,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11471,205,2.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11471,207,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11471,208,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11471,255,96.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11471,269,1.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11471,291,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11471,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11471,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11471,306,96,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11471,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11471,320,5,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11471,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11471,401,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11471,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11471,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11471,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11471,606,0.015,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11473,203,0.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11473,204,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11473,205,4.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11473,207,0.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11473,208,20,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11473,255,93.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11473,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11473,291,1.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11473,301,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11473,303,0.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11473,306,209,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11473,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11473,320,14,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11473,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11473,401,6.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11473,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11473,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11473,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11473,606,0.029,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11474,203,1.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11474,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11474,205,5.54,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11474,207,0.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11474,208,25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11474,255,92.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11474,269,2.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11474,291,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11474,301,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11474,303,0.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11474,306,253,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11474,307,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11474,320,10,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11474,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11474,401,6.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11474,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11474,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11474,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11474,606,0.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11475,203,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11475,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11475,205,3.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11475,207,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11475,208,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11475,255,94.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11475,269,2.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11475,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11475,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11475,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11475,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11475,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11475,320,11,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (11475,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11475,401,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11475,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11475,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11475,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11475,606,0.041,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11476,203,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11476,204,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11476,205,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11476,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11476,208,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11476,255,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11476,269,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11476,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11476,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11476,303,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11476,306,140,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11476,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11476,320,4,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11476,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11476,401,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11476,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11476,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11476,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11476,606,0.035,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11477,203,1.21,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11477,204,0.32,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11477,205,3.11,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11477,207,0.58,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11477,208,17,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11477,255,94.79,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11477,269,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11477,291,1,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11477,301,16,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11477,303,0.37,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11477,306,261,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11477,307,8,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11477,320,10,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (11477,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11477,401,17.9,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11477,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11477,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11477,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11477,606,0.084,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11478,203,1.14,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11478,204,0.36,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11478,205,2.69,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11478,207,0.59,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11478,208,15,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11478,255,95.22,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11478,269,1.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11478,291,1,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11478,301,18,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11478,303,0.37,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11478,306,264,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11478,307,3,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11478,320,56,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (11478,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11478,401,12.9,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11478,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11478,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11478,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11478,606,0.072,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11479,203,1.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11479,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11479,205,3.58,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11479,207,0.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11479,208,17,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11479,255,94.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11479,269,1.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11479,291,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11479,301,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11479,303,0.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11479,306,218,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11479,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11479,320,10,'100g',2,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (11479,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11479,401,5.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11479,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11479,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11479,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11479,606,0.027,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11480,203,1.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11480,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11480,205,3.56,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11480,207,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11480,208,17,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11480,255,94.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11480,269,1.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11480,291,1.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11480,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11480,303,0.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11480,306,194,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11480,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11480,320,9,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11480,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11480,401,3.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11480,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11480,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11480,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11480,606,0.027,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11481,203,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11481,204,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11481,205,6.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11481,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11481,208,29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11481,255,90.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11481,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11481,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11481,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11481,303,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11481,306,274,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11481,307,374,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11481,320,27,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11481,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11481,401,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11481,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11481,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11481,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11481,606,0.023,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11482,203,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11482,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11482,205,10.42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11482,207,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11482,208,40,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11482,255,87.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11482,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11482,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11482,301,33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11482,303,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11482,306,347,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11482,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11482,320,18,'100g',1,1,'2024-12-12','2003-01-06');
INSERT INTO `cndb_nutval` VALUES (11482,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11482,401,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11482,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11482,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11482,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11482,606,0.021,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11483,203,1.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11483,204,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11483,205,14.58,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11483,207,1.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11483,208,56,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11483,255,82.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11483,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11483,291,4.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11483,301,44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11483,303,0.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11483,306,437,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11483,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11483,320,21,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11483,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11483,401,10.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11483,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11483,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11483,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11483,606,0.029,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11484,203,0.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11484,204,0.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11484,205,8.79,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11484,207,0.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11484,208,34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11484,255,89.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11484,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11484,291,2.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11484,301,26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11484,303,0.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11484,306,263,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11484,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11484,320,41,'100g',1,1,'2024-12-12','2003-01-06');
INSERT INTO `cndb_nutval` VALUES (11484,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11484,401,6.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11484,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11484,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11484,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11484,606,0.017,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11485,203,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11485,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11485,205,11.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11485,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11485,208,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11485,255,86.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11485,269,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11485,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11485,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11485,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11485,306,352,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11485,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11485,320,532,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (11485,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11485,401,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11485,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11485,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11485,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11485,606,0.021,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11486,203,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11486,204,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11486,205,10.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11486,207,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11486,208,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11486,255,87.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11486,269,1.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11486,291,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11486,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11486,303,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11486,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11486,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11486,320,558,'100g',2,1,'2024-12-12','2009-01-10');
INSERT INTO `cndb_nutval` VALUES (11486,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11486,401,15.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11486,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11486,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11486,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11486,606,0.019,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11487,203,1.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11487,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11487,205,14.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11487,207,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11487,208,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11487,255,82.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11487,269,2.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11487,291,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11487,301,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11487,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11487,306,212,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11487,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11487,320,240,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (11487,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11487,401,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11487,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11487,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11487,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11487,606,0.021,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11488,203,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11488,204,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11488,205,10.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11488,207,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11488,208,39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11488,255,87.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11488,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11488,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11488,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11488,303,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11488,306,133,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11488,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11488,320,167,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11488,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11488,401,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11488,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11488,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11488,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11488,606,0.014,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11489,203,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11489,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11489,205,8.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11489,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11489,208,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11489,255,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11489,269,3.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11489,291,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11489,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11489,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11489,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11489,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11489,320,68,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (11489,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11489,401,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11489,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11489,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11489,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11489,606,0.103,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11490,203,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11490,204,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11490,205,10.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11490,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11490,208,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11490,255,85.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11490,269,4.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11490,291,4.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11490,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11490,303,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11490,306,358,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11490,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11490,320,335,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (11490,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11490,401,9.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11490,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11490,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11490,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11490,606,0.128,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11491,203,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11491,204,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11491,205,6.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11491,207,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11491,208,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11491,255,91.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11491,269,2.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11491,291,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11491,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11491,303,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11491,306,214,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11491,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11491,320,200,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11491,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11491,401,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11491,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11491,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11491,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11491,606,0.076,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11492,203,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11492,204,0.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11492,205,6.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11492,207,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11492,208,31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11492,255,91.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11492,269,2.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11492,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11492,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11492,303,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11492,306,108,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11492,307,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11492,320,6,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (11492,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11492,401,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11492,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11492,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11492,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11492,606,0.117,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11493,203,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11493,204,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11493,205,6.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11493,207,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11493,208,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11493,255,92.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11493,269,2.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11493,291,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11493,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11493,303,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11493,306,117,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11493,307,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11493,320,6,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11493,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11493,401,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11493,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11493,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11493,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11493,606,0.062,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11495,203,5.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11495,204,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11495,205,19.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11495,207,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11495,208,99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11495,255,73.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11495,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11495,291,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11495,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11495,303,1.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11495,306,369,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11495,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11495,320,15,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11495,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11495,401,15.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11495,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11495,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11495,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11495,606,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11496,203,5.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11496,204,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11496,205,24.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11496,207,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11496,208,115,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11496,255,68.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11496,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11496,291,4.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11496,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11496,303,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11496,306,410,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11496,307,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11496,320,15,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11496,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11496,401,8.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11496,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11496,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11496,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11496,606,0.148,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11497,203,2.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11497,204,0.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11497,205,17.61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11497,207,1.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11497,208,77,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11497,255,78.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11497,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11497,291,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11497,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11497,303,0.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11497,306,183,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11497,307,245,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11497,320,7,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11497,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11497,401,6.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11497,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11497,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11497,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11497,606,0.101,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11499,203,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11499,204,0.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11499,205,13.98,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11499,207,0.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11499,208,63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11499,255,81.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11499,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11499,291,2.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11499,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11499,303,0.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11499,306,163,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11499,307,221,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11499,320,7,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11499,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11499,401,4.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11499,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11499,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11499,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11499,606,0.092,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11501,203,4.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11501,204,0.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11501,205,19.94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11501,207,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11501,208,93,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11501,255,74.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11501,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11501,291,4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11501,301,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11501,303,0.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11501,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11501,307,45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11501,320,13,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11501,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11501,401,8.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11501,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11501,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11501,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11501,606,0.166,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11502,203,4.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11502,204,0.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11502,205,19.95,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11502,207,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11502,208,93,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11502,255,74.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11502,269,2.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11502,291,4.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11502,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11502,303,0.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11502,306,265,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11502,307,45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11502,320,10,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11502,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11502,401,5.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11502,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11502,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11502,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11502,606,0.166,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11504,203,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11504,204,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11504,205,3.7,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11504,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11504,208,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11504,255,92.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11504,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11504,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11504,301,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11504,303,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11504,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11504,307,122,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11504,320,260,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11504,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11504,401,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11504,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11504,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11504,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11504,606,0.039,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11505,203,2.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11505,204,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11505,205,8.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11505,207,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11505,208,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11505,255,86.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11505,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11505,291,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11505,301,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11505,303,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11505,306,508,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11505,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11505,320,189,'100g',1,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (11505,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11505,401,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11505,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11505,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11505,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11505,606,0.111,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11506,203,2.18,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11506,204,0.34,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11506,205,7.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11506,207,0.89,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11506,208,35,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11506,255,89.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11506,269,5.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11506,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11506,301,33,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11506,303,0.63,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11506,306,312,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11506,307,7,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11506,320,147,'100g',2,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (11506,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11506,401,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11506,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11506,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11506,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11506,606,0.065,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11507,203,1.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11507,204,0.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11507,205,20.12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11507,207,0.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11507,208,86,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11507,255,77.28,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11507,269,4.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11507,291,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11507,301,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11507,303,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11507,306,337,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11507,307,55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11507,320,709,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11507,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11507,401,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11507,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11507,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11507,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11507,606,0.018,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11508,203,2.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11508,204,0.15,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11508,205,20.71,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11508,207,1.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11508,208,90,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11508,255,75.78,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11508,269,6.48,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11508,291,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11508,301,38,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11508,303,0.69,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11508,306,475,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11508,307,36,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11508,320,961,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11508,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11508,401,19.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11508,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11508,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11508,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11508,606,0.052,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11510,203,1.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11510,204,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11510,205,17.72,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11510,207,0.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11510,208,76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11510,255,80.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11510,269,5.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11510,291,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11510,301,27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11510,303,0.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11510,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11510,307,27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11510,320,787,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11510,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11510,401,12.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11510,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11510,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11510,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11510,606,0.031,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11512,203,1.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11512,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11512,205,21.12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11512,207,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11512,208,91,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11512,255,76.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11512,269,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11512,291,1.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11512,301,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11512,303,0.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11512,306,312,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11512,307,53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11512,320,399,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11512,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11512,401,26.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11512,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11512,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11512,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11512,606,0.041,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11514,203,1.98,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11514,204,0.2,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11514,205,23.19,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11514,207,0.75,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11514,208,101,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11514,255,73.88,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11514,269,5.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11514,291,1.7,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11514,301,30,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11514,303,1.33,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11514,306,210,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11514,307,75,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11514,320,435,'100g',2,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11514,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11514,401,5.2,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11514,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11514,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11514,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11514,606,0.041,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11516,203,1.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11516,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11516,205,22.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11516,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11516,208,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11516,255,74.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11516,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11516,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11516,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11516,303,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11516,306,365,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11516,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11516,320,518,'100g',1,1,'2024-12-12','2004-01-07');
INSERT INTO `cndb_nutval` VALUES (11516,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11516,401,13.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11516,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11516,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11516,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11516,606,0.039,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11517,203,1.71,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11517,204,0.12,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11517,205,23.4,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11517,207,1.07,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11517,208,100,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11517,255,73.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11517,269,9.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11517,291,1.8,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11517,301,35,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11517,303,0.54,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11517,306,377,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11517,307,8,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11517,320,1043,'100g',2,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11517,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11517,401,9.1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11517,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11517,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11517,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11517,606,0.025,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11518,203,1.5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11518,204,0.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11518,205,26.46,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11518,207,1.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11518,208,112,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11518,255,70.64,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11518,269,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11518,291,4.1,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11518,301,43,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11518,303,0.55,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11518,306,591,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11518,307,11,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11518,320,4,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11518,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11518,401,4.5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11518,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11518,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11518,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11518,606,0.041,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11519,203,0.52,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11519,204,0.11,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11519,205,34.6,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11519,207,0.97,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11519,208,142,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11519,255,63.8,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11519,269,0.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11519,291,5.1,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11519,301,18,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11519,303,0.72,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11519,306,484,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11519,307,15,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11519,320,4,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11519,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11519,401,5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11519,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11519,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11519,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11519,606,0.023,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11520,203,4.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11520,204,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11520,205,6.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11520,207,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11520,208,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11520,255,85.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11520,269,3.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11520,291,3.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11520,301,107,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11520,303,2.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11520,306,648,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11520,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11520,320,241,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11520,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11520,401,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11520,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11520,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11520,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11520,606,0.151,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11521,203,2.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11521,204,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11521,205,4.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11521,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11521,208,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11521,255,92.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11521,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11521,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11521,301,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11521,303,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11521,306,460,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11521,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11521,320,212,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (11521,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11521,401,35.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11521,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11521,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11521,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11521,606,0.083,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11522,203,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11522,204,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11522,205,2.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11522,207,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11522,208,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11522,255,95.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11522,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11522,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11522,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11522,303,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11522,306,332,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11522,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11522,320,3,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11522,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11522,401,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11522,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11522,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11522,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11522,606,0.018,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11523,203,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11523,204,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11523,205,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11523,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11523,208,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11523,255,95.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11523,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11523,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11523,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11523,303,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11523,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11523,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11523,320,3,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11523,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11523,401,18.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11523,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11523,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11523,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11523,606,0.016,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11525,203,2.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11525,204,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11525,205,6.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11525,207,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11525,208,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11525,255,87.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11525,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11525,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11525,301,129,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11525,303,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11525,306,606,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11525,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11525,320,102,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11525,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11525,401,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11525,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11525,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11525,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11525,606,0.197,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11526,203,4.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11526,204,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11526,205,6.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11526,207,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11526,208,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11526,255,86.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11526,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11526,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11526,301,149,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11526,303,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11526,306,623,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11526,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11526,320,88,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11526,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11526,401,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11526,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11526,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11526,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11526,606,0.139,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11527,203,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11527,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11527,205,5.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11527,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11527,208,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11527,255,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11527,269,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11527,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11527,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11527,303,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11527,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11527,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11527,320,32,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11527,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11527,401,23.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11527,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11527,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11527,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11527,606,0.028,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11529,203,0.88,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11529,204,0.2,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11529,205,3.89,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11529,207,0.5,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11529,208,18,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11529,255,94.52,'100g',7,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11529,269,2.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11529,291,1.2,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11529,301,10,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11529,303,0.27,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11529,306,237,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11529,307,5,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11529,320,42,'100g',1,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (11529,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11529,401,13.7,'100g',7,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11529,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11529,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11529,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11529,606,0.028,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11530,203,0.95,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11530,204,0.11,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11530,205,4.01,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11530,207,0.6,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11530,208,18,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11530,255,94.34,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11530,269,2.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11530,291,0.7,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11530,301,11,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11530,303,0.68,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11530,306,218,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11530,307,11,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11530,320,24,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11530,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11530,401,22.8,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11530,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11530,601,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11530,605,0,'100g',NULL,1,'2004-07-15','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11530,606,0.015,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11531,203,0.79,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11531,204,0.25,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11531,205,3.47,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11531,207,0.74,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11531,208,16,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11531,255,94.75,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11531,269,2.55,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11531,291,1.9,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11531,301,33,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11531,303,0.57,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11531,306,191,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11531,307,115,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11531,320,20,'100g',2,1,'2024-12-12','2014-01-08');
INSERT INTO `cndb_nutval` VALUES (11531,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11531,401,12.6,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11531,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11531,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11531,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11531,606,0.034,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11533,203,0.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11533,204,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11533,205,6.19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11533,207,1.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11533,208,26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11533,255,91.54,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11533,269,3.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11533,291,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11533,301,34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11533,303,1.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11533,306,207,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11533,307,221,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11533,320,9,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11533,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11533,401,7.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11533,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11533,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11533,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11533,606,0.026,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11537,203,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11537,204,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11537,205,3.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11537,207,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11537,208,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11537,255,94.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11537,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11537,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11537,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11537,303,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11537,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11537,307,401,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11537,320,20,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11537,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11537,401,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11537,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11537,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11537,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11537,606,0.011,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11540,203,0.85,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11540,204,0.29,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11540,205,3.53,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11540,207,1.09,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11540,208,17,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11540,255,94.24,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11540,269,2.58,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11540,291,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11540,301,10,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11540,303,0.39,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11540,306,217,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11540,307,253,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11540,320,23,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11540,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11540,401,70.1,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11540,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11540,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11540,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11540,606,0.019,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11546,203,4.32,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11546,204,0.47,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11546,205,18.91,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11546,207,2.8,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11546,208,82,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11546,255,73.5,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11546,269,12.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11546,291,4.1,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11546,301,36,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11546,303,2.98,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11546,306,1014,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11546,307,59,'100g',6,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11546,320,76,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11546,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11546,401,21.9,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11546,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11546,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11546,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11546,606,0.1,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11547,203,1.65,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11547,204,0.21,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11547,205,8.98,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11547,207,1.28,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11547,208,38,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11547,255,87.88,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11547,269,4.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11547,291,1.9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11547,301,18,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11547,303,1.78,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11547,306,439,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11547,307,28,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11547,320,26,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11547,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11547,401,10.6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11547,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11547,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11547,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11547,606,0.029,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11548,203,12.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11548,204,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11548,205,74.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11548,207,8.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11548,208,302,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11548,255,3.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11548,269,43.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11548,291,16.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11548,301,166,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11548,303,4.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11548,306,1927,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11548,307,134,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11548,320,862,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (11548,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11548,401,116.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11548,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11548,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11548,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11548,606,0.062,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11549,203,1.2,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11549,204,0.3,'100g',7,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11549,205,5.31,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11549,207,1.92,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11549,208,24,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11549,255,91.28,'100g',7,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11549,269,3.56,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11549,291,1.5,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11549,301,14,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11549,303,0.96,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11549,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11549,307,474,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11549,320,22,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (11549,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11549,401,7,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11549,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11549,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11549,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11549,606,0.041,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11551,203,1.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11551,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11551,205,8.43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11551,207,2.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11551,208,35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11551,255,87.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11551,269,5.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11551,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11551,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11551,303,0.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11551,306,380,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11551,307,452,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11551,320,48,'100g',2,1,'2024-12-12','2008-01-06');
INSERT INTO `cndb_nutval` VALUES (11551,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11551,401,12.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11551,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11551,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11551,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11551,606,0.017,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11553,203,1.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11553,204,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11553,205,9.94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11553,207,2.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11553,208,42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11553,255,86.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11553,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11553,291,1.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11553,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11553,303,0.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11553,306,413,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11553,307,551,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11553,320,43,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11553,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11553,401,12.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11553,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11553,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11553,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11553,606,0.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11555,203,2.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11555,204,1.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11555,205,10.24,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11555,207,2.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11555,208,59,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11555,255,83.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11555,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11555,291,2.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11555,301,37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11555,303,0.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11555,306,356,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11555,307,543,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11555,320,49,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11555,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11555,401,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11555,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11555,601,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11555,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11555,606,0.627,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11557,203,0.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11557,204,0.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11557,205,8.77,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11557,207,1.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11557,208,41,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11557,255,88.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11557,269,7.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11557,291,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11557,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11557,303,0.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11557,306,398,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11557,307,368,'100g',6,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11557,320,41,'100g',2,1,'2024-12-12','2008-01-06');
INSERT INTO `cndb_nutval` VALUES (11557,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11557,401,13.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11557,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11557,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11557,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11557,606,0.133,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11559,203,1.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11559,204,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11559,205,7.09,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11559,207,2.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11559,208,32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11559,255,89.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11559,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11559,291,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11559,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11559,303,0.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11559,306,373,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11559,307,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11559,320,40,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11559,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11559,401,21.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11559,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11559,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11559,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11559,606,0.055,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11563,203,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11563,204,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11563,205,10.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11563,207,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11563,208,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11563,255,88.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11563,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11563,291,3.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11563,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11563,303,0.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11563,306,5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11563,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11563,320,10,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11563,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11563,401,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11563,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11563,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11563,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11563,606,0.009,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11564,203,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11564,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11564,205,6.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11564,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11564,208,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11564,255,91.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11564,269,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11564,291,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11564,301,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11564,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11564,306,191,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11564,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11564,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11564,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11564,401,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11564,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11564,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11564,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11564,606,0.011,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11565,203,0.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11565,204,0.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11565,205,5.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11565,207,0.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11565,208,22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11565,255,93.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11565,269,2.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11565,291,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11565,301,33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11565,303,0.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11565,306,177,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11565,307,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11565,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11565,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11565,401,11.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11565,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11565,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11565,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11565,606,0.008,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11566,203,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11566,204,0.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11566,205,2.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11566,207,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11566,208,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11566,255,95.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11566,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11566,291,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11566,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11566,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11566,306,137,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11566,307,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11566,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11566,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11566,401,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11566,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11566,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11566,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11566,606,0.017,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11567,203,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11567,204,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11567,205,4.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11567,207,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11567,208,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11567,255,93.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11567,269,2.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11567,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11567,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11567,303,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11567,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11567,307,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11567,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11567,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11567,401,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11567,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11567,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11567,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11567,606,0.025,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11568,203,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11568,204,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11568,205,7.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11568,207,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11568,208,32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11568,255,89.67,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11568,269,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11568,291,3.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11568,301,190,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11568,303,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11568,306,296,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11568,307,40,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11568,320,579,'100g',2,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11568,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11568,401,60,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11568,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11568,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11568,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11568,606,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11569,203,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11569,204,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11569,205,4.36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11569,207,1.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11569,208,20,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11569,255,93.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11569,269,0.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11569,291,3.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11569,301,137,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11569,303,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11569,306,203,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11569,307,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11569,320,381,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11569,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11569,401,27.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11569,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11569,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11569,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11569,606,0.053,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11570,203,1.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11570,204,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11570,205,2.42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11570,207,1.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11570,208,14,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11570,255,94.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11570,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11570,291,1.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11570,301,118,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11570,303,1.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11570,306,141,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11570,307,277,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11570,320,179,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11570,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11570,401,15.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11570,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11570,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11570,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11570,606,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11574,203,2.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11574,204,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11574,205,3.67,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11574,207,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11574,208,22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11574,255,92.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11574,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11574,291,2.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11574,301,118,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11574,303,1.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11574,306,184,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11574,307,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11574,320,309,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11574,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11574,401,26.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11574,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11574,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11574,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11574,606,0.073,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11575,203,3.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11575,204,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11575,205,4.98,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11575,207,0.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11575,208,29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11575,255,90.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11575,269,0.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11575,291,3.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11575,301,152,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11575,303,1.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11575,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11575,307,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11575,320,538,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11575,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11575,401,21.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11575,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11575,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11575,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11575,606,0.099,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11576,203,2.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11576,204,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11576,205,3.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11576,207,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11576,208,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11576,255,93.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11576,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11576,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11576,301,114,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11576,303,1.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11576,306,82,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11576,307,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11576,320,305,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11576,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11576,401,25.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11576,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11576,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11576,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11576,606,0.032,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11577,203,2.99,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11577,204,0.38,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11577,205,4.85,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11577,207,0.74,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11577,208,35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11577,255,91.04,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11577,269,1.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11577,291,3.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11577,301,128,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11577,303,1.75,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11577,306,216,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11577,307,19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11577,320,431,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11577,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11577,401,18.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11577,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11577,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11577,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11577,606,0.085,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11578,203,0.93,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11578,204,0.31,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11578,205,3.87,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11578,207,0.8,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11578,208,22,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11578,255,94.09,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11578,269,2.84,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11578,291,0.5,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11578,301,14,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11578,303,0.28,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11578,306,185,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11578,307,169,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11578,320,35,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (11578,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11578,401,54.3,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11578,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11578,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11578,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11578,606,0.088,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11579,203,1.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11579,204,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11579,205,7.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11579,207,0.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11579,208,36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11579,255,90.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11579,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11579,291,3.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11579,301,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11579,303,0.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11579,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11579,307,224,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11579,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11579,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11579,401,3.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11579,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11579,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11579,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11579,606,0.051,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11581,203,2.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11581,204,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11581,205,9.26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11581,207,0.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11581,208,49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11581,255,87.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11581,269,2.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11581,291,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11581,301,27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11581,303,1.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11581,306,291,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11581,307,214,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11581,320,583,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11581,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11581,401,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11581,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11581,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11581,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11581,606,0.051,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11583,203,3.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11583,204,0.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11583,205,13.47,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11583,207,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11583,208,72,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11583,255,82.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11583,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11583,291,4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11583,301,25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11583,303,0.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11583,306,212,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11583,307,47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11583,320,254,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11583,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11583,401,10.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11583,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11583,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11583,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11583,606,0.098,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11584,203,2.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11584,204,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11584,205,13.09,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11584,207,0.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11584,208,65,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11584,255,83.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11584,269,3.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11584,291,4.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11584,301,25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11584,303,0.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11584,306,169,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11584,307,35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11584,320,214,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11584,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11584,401,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11584,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11584,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11584,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11584,606,0.031,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11585,203,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11585,204,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11585,205,3.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11585,207,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11585,208,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11585,255,94.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11585,269,2.78,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11585,291,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11585,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11585,303,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11585,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11585,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11585,320,35,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (11585,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11585,401,54.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11585,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11585,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11585,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11585,606,0.089,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11588,203,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11588,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11588,205,23.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11588,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11588,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11588,255,73.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11588,269,4.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11588,291,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11588,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11588,303,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11588,306,584,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11588,307,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11588,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11588,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11588,401,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11588,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11588,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11588,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11588,606,0.026,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11590,203,0.88,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11590,204,0.06,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11590,205,12.3,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11590,207,0.34,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11590,208,50,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11590,255,86.42,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11590,269,2.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11590,291,2.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11590,301,4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11590,303,0.87,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11590,306,118,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11590,307,8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11590,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11590,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11590,401,1.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11590,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11590,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11590,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11590,606,0.016,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11591,203,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11591,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11591,205,1.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11591,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11591,208,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11591,255,95.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11591,269,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11591,291,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11591,301,120,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11591,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11591,306,330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11591,307,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11591,320,160,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11591,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11591,401,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11591,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11591,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11591,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11591,606,0.027,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11593,203,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11593,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11593,205,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11593,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11593,208,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11593,255,96.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11593,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11593,291,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11593,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11593,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11593,306,6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11593,307,111,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11593,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11593,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11593,401,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11593,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11593,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11593,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11593,606,0.016,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11594,203,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11594,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11594,205,3.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11594,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11594,208,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11594,255,96.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11594,269,1.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11594,291,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11594,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11594,303,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11594,306,5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11594,307,107,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11594,320,0,'100g',2,1,'2024-12-12','2007-01-06');
INSERT INTO `cndb_nutval` VALUES (11594,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11594,401,10.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11594,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11594,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11594,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11594,606,0.016,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11595,203,6.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11595,204,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11595,205,4.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11595,207,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11595,208,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11595,255,87.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11595,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11595,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11595,301,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11595,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11595,306,223,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11595,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11595,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11595,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11595,401,18.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11595,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11595,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11595,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11595,606,0.238,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11596,203,5.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11596,204,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11596,205,3.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11596,207,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11596,208,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11596,255,90.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11596,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11596,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11596,301,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11596,303,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11596,306,274,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11596,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11596,320,4,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11596,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11596,401,9.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11596,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11596,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11596,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11596,606,0.181,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11597,203,5.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11597,204,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11597,205,14.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11597,207,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11597,208,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11597,255,76.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11597,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11597,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11597,301,224,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11597,303,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11597,306,176,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11597,307,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11597,320,405,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11597,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11597,401,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11597,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11597,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11597,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11597,606,0.272,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11599,203,11.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11599,204,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11599,205,28.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11599,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11599,208,148,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11599,255,57.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11599,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11599,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11599,301,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11599,303,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11599,306,586,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11599,307,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11599,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11599,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11599,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11599,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11599,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11599,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11599,606,0.222,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11601,203,1.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11601,204,0.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11601,205,27.88,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11601,207,0.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11601,208,118,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11601,255,69.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11601,269,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11601,291,4.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11601,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11601,303,0.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11601,306,816,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11601,307,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11601,320,7,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11601,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11601,401,17.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11601,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11601,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11601,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11601,606,0.037,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11602,203,1.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11602,204,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11602,205,27.48,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11602,207,0.76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11602,208,116,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11602,255,70.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11602,269,0.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11602,291,3.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11602,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11602,303,0.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11602,306,670,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11602,307,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11602,320,6,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11602,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11602,401,12.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11602,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11602,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11602,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11602,606,0.029,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11603,203,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11603,204,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11603,205,8.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11603,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11603,208,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11603,255,90.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11603,269,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11603,291,4.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11603,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11603,303,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11603,306,150,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11603,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11603,320,1,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11603,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11603,401,20.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11603,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11603,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11603,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11603,606,0.021,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11605,203,0.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11605,204,0.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11605,205,18.18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11605,207,0.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11605,208,73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11605,255,80.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11605,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11605,291,2.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11605,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11605,303,0.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11605,306,164,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11605,307,162,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11605,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11605,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11605,401,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11605,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11605,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11605,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11605,606,0.009,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11609,203,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11609,204,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11609,205,16.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11609,207,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11609,208,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11609,255,81.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11609,269,11.05,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11609,291,0.8,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11609,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11609,303,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11609,306,115,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11609,307,149,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11609,320,2,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (11609,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11609,401,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11609,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11609,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11609,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11609,606,0.013,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11613,203,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11613,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11613,205,3.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11613,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11613,208,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11613,255,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11613,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11613,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11613,301,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11613,303,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11613,306,470,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11613,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11613,320,210,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11613,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11613,401,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11613,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11613,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11613,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11613,606,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11614,203,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11614,204,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11614,205,3.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11614,207,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11614,208,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11614,255,91.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11614,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11614,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11614,301,102,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11614,303,3.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11614,306,491,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11614,307,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11614,320,219,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11614,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11614,401,32.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11614,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11614,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11614,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11614,606,0.197,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11615,203,21.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11615,204,3.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11615,205,64.29,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11615,207,9.01,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11615,208,311,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11615,255,2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11615,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11615,291,26.2,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11615,301,813,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11615,303,20,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11615,306,2960,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11615,307,70,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11615,320,3415,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11615,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11615,401,660,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11615,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11615,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11615,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11615,606,0.591,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11620,203,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11620,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11620,205,8.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11620,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11620,208,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11620,255,88.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11620,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11620,291,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11620,301,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11620,303,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11620,306,461,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11620,307,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11620,320,4,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11620,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11620,401,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11620,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11620,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11620,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11620,606,0.033,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11621,203,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11621,204,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11621,205,8.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11621,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11621,208,36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11621,255,88.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11621,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11621,291,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11621,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11621,303,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11621,306,457,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11621,307,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11621,320,4,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11621,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11621,401,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11621,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11621,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11621,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11621,606,0.031,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11624,203,15.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11624,204,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11624,205,74.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11624,207,6.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11624,208,321,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11624,255,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11624,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11624,291,10.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11624,301,360,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11624,303,7.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11624,306,2400,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11624,307,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11624,320,14,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11624,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11624,401,118,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11624,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11624,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11624,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11624,606,0.279,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11626,203,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11626,204,0.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11626,205,2.14,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11626,207,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11626,208,12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11626,255,96.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11626,269,0.7,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11626,291,0.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11626,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11626,303,0.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11626,306,27,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11626,307,42,'100g',6,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11626,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11626,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11626,401,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11626,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11626,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11626,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11626,606,0.016,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11632,203,0.92,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11632,204,0.94,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11632,205,4.74,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11632,207,4.51,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11632,208,27,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11632,255,88.89,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11632,269,2.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11632,291,2.6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11632,301,23,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11632,303,1.88,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11632,306,193,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11632,307,1671,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11632,320,85,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (11632,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11632,401,10,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11632,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11632,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11632,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11632,606,0.097,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11637,203,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11637,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11637,205,2.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11637,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11637,208,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11637,255,95.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11637,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11637,291,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11637,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11637,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11637,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11637,307,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11637,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11637,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11637,401,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11637,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11637,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11637,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11637,606,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11640,203,12.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11640,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11640,205,80.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11640,207,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11640,208,348,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11640,255,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11640,269,38.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11640,291,15.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11640,301,183,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11640,303,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11640,306,1650,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11640,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11640,320,1,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (11640,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11640,401,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11640,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11640,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11640,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11640,606,0.084,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11641,203,1.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11641,204,0.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11641,205,3.35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11641,207,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11641,208,16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11641,255,94.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11641,269,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11641,291,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11641,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11641,303,0.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11641,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11641,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11641,320,10,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11641,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11641,401,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11641,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11641,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11641,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11641,606,0.044,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11642,203,0.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11642,204,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11642,205,4.31,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11642,207,0.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11642,208,20,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11642,255,93.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11642,269,2.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11642,291,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11642,301,27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11642,303,0.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11642,306,192,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11642,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11642,320,11,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11642,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11642,401,5.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11642,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11642,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11642,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11642,606,0.064,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11643,203,0.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11643,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11643,205,8.59,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11643,207,0.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11643,208,34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11643,255,89.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11643,269,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11643,291,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11643,301,28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11643,303,0.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11643,306,350,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11643,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11643,320,68,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11643,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11643,401,12.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11643,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11643,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11643,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11643,606,0.027,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11644,203,0.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11644,204,0.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11644,205,8.85,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11644,207,0.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11644,208,37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11644,255,89.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11644,269,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11644,291,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11644,301,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11644,303,0.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11644,306,241,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11644,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11644,320,261,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11644,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11644,401,9.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11644,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11644,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11644,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11644,606,0.072,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11645,203,0.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11645,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11645,205,20.93,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11645,207,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11645,208,89,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11645,255,77.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11645,269,15.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11645,291,2.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11645,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11645,303,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11645,306,185,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11645,307,29,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11645,320,377,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11645,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11645,401,10.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11645,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11645,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11645,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11645,606,0.041,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11647,203,1.28,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11647,204,0.32,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11647,205,25.36,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11647,207,0.57,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11647,208,108,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11647,255,72.47,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11647,269,5.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11647,291,3,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11647,301,17,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11647,303,0.95,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11647,306,193,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11647,307,39,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11647,320,458,'100g',2,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11647,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11647,401,10.8,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11647,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11647,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11647,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11647,606,0.069,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11649,203,1.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11649,204,0.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11649,205,7.24,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11649,207,1.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11649,208,33,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11649,255,89.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11649,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11649,291,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11649,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11649,303,3.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11649,306,369,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11649,307,472,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11649,320,49,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11649,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11649,401,8.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11649,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11649,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11649,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11649,606,0.038,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11653,203,5.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11653,204,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11653,205,11.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11653,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11653,208,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11653,255,81.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11653,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11653,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11653,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11653,303,1.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11653,306,307,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11653,307,153,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11653,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11653,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11653,401,21.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11653,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11653,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11653,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11653,606,0.109,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11654,203,1.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11654,204,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11654,205,4.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11654,207,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11654,208,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11654,255,93.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11654,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11654,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11654,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11654,303,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11654,306,98,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11654,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11654,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11654,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11654,401,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11654,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11654,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11654,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11654,606,0.039,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11655,203,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11655,204,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11655,205,9.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11655,207,0.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11655,208,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11655,255,88.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11655,269,3.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11655,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11655,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11655,303,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11655,306,292,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11655,307,66,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11655,320,956,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11655,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11655,401,8.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11655,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11655,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11655,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11655,606,0.027,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11656,203,4.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11656,204,5.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11656,205,16.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11656,207,1.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11656,208,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11656,255,72.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11656,269,6.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11656,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11656,301,39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11656,303,0.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11656,306,176,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11656,307,282,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11656,320,57,'100g',2,1,'2024-12-12','2009-01-01');
INSERT INTO `cndb_nutval` VALUES (11656,328,0.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11656,401,3.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11656,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11656,601,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11656,605,0.093,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11656,606,2.451,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11657,203,1.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11657,204,0.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11657,205,17.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11657,207,1.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11657,208,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11657,255,78.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11657,269,1.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11657,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11657,301,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11657,303,0.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11657,306,296,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11657,307,302,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11657,320,7,'100g',2,1,'2024-12-12','2008-01-12');
INSERT INTO `cndb_nutval` VALUES (11657,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11657,401,6.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11657,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11657,601,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11657,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11657,606,0.302,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11658,203,7.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11658,204,12.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11658,205,5.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11658,207,2.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11658,208,172,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11658,255,70.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11658,269,1.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11658,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11658,301,165,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11658,303,1.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11658,306,231,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11658,307,566,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11658,320,244,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (11658,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11658,401,7.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11658,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11658,601,118,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11658,605,0.188,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11658,606,6.091,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11659,203,0.89,'100g',3,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (11659,204,3.54,'100g',3,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (11659,205,32.12,'100g',3,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (11659,207,0.69,'100g',3,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (11659,208,164,'100g',3,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (11659,255,62.75,'100g',3,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (11659,269,27.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11659,291,2.1,'100g',3,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (11659,301,26,'100g',3,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (11659,303,0.79,'100g',3,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (11659,306,178,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11659,307,119,'100g',3,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (11659,320,349,'100g',2,1,'2024-12-12','2012-01-06');
INSERT INTO `cndb_nutval` VALUES (11659,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11659,401,9,'100g',3,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (11659,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11659,601,9,'100g',3,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (11659,605,0.136,'100g',3,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11659,606,2.171,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11660,203,1.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11660,204,2.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11660,205,13.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11660,207,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11660,208,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11660,255,80.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11660,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11660,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11660,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11660,303,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11660,306,247,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11660,307,455,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11660,320,33,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11660,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11660,401,18.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11660,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11660,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11660,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11660,606,0.521,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11663,203,6.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11663,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11663,205,80.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11663,207,3.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11663,208,306,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11663,255,8.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11663,269,2.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11663,291,7.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11663,301,625,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11663,303,21.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11663,306,1125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11663,307,102,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11663,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11663,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11663,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11663,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11663,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11663,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11663,606,0.061,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11666,203,5.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11666,204,0.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11666,205,2.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11666,207,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11666,208,26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11666,255,90.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11666,269,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11666,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11666,301,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11666,303,2.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11666,306,127,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11666,307,98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11666,320,3,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11666,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11666,401,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11666,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11666,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11666,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11666,606,0.135,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11667,203,57.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11667,204,7.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11667,205,23.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11667,207,6.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11667,208,290,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11667,255,4.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11667,269,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11667,291,3.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11667,301,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11667,303,28.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11667,306,1363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11667,307,1048,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11667,320,29,'100g',2,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (11667,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11667,401,10.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11667,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11667,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11667,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11667,606,2.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11669,203,3.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11669,204,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11669,205,9.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11669,207,7.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11669,208,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11669,255,79.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11669,269,0.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11669,291,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11669,301,150,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11669,303,2.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11669,306,50,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11669,307,872,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11669,320,18,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11669,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11669,401,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11669,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11669,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11669,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11669,606,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11670,203,2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11670,204,0.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11670,205,9.46,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11670,207,0.6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11670,208,40,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11670,255,87.74,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11670,269,5.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11670,291,1.5,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11670,301,18,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11670,303,1.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11670,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11670,307,7,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11670,320,59,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11670,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11670,401,242.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11670,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11670,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11670,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11670,606,0.021,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11671,203,2.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11671,204,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11671,205,15.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11671,207,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11671,208,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11671,255,79.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11671,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11671,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11671,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11671,303,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11671,306,266,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11671,307,217,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11671,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11671,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11671,401,16.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11671,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11671,601,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11671,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11671,606,0.797,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11672,203,6.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11672,204,14.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11672,205,27.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11672,207,3.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11672,208,268,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11672,255,47.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11672,269,1.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11672,291,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11672,301,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11672,303,1.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11672,306,622,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11672,307,764,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11672,320,32,'100g',2,1,'2024-12-12','2009-01-01');
INSERT INTO `cndb_nutval` VALUES (11672,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11672,401,27.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11672,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11672,601,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11672,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11672,606,2.496,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11674,203,2.5,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11674,204,0.13,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11674,205,21.15,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11674,207,1.33,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11674,208,93,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11674,255,74.89,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11674,269,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11674,291,2.2,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11674,301,15,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11674,303,1.08,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11674,306,535,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11674,307,10,'100g',7,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11674,320,1,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11674,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11674,401,9.6,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11674,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11674,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11674,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11674,606,0.034,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11675,203,2.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11675,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11675,205,24.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11675,207,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11675,208,105,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11675,255,72.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11675,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11675,291,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11675,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11675,303,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11675,306,447,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11675,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11675,320,0,'100g',1,1,'2024-12-12','2004-01-08');
INSERT INTO `cndb_nutval` VALUES (11675,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11675,401,15.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11675,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11675,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11675,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11675,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11676,203,3.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11676,204,2.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11676,205,3.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11676,207,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11676,208,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11676,255,90.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11676,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11676,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11676,301,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11676,303,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11676,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11676,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11676,320,20,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11676,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11676,401,28.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11676,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11676,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11676,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11676,606,0.767,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11677,203,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11677,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11677,205,16.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11677,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11677,208,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11677,255,79.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11677,269,7.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11677,291,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11677,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11677,303,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11677,306,334,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11677,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11677,320,0,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (11677,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11677,401,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11677,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11677,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11677,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11677,606,0.017,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11683,203,8.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11683,204,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11683,205,79.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11683,207,6.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11683,208,341,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11683,255,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11683,269,38.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11683,291,23.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11683,301,212,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11683,303,3.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11683,306,2540,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11683,307,275,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11683,320,3423,'100g',2,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (11683,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11683,401,14.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11683,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11683,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11683,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11683,606,0.256,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11693,203,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11693,204,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11693,205,7.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11693,207,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11693,208,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11693,255,89.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11693,269,4.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11693,291,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11693,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11693,303,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11693,306,293,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11693,307,186,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11693,320,11,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (11693,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11693,401,9.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11693,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11693,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11693,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11693,606,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11695,203,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11695,204,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11695,205,3.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11695,207,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11695,208,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11695,255,94.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11695,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11695,291,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11695,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11695,303,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11695,306,212,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11695,307,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11695,320,75,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11695,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11695,401,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11695,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11695,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11695,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11695,606,0.025,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11696,203,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11696,204,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11696,205,2.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11696,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11696,208,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11696,255,95.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11696,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11696,291,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11696,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11696,303,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11696,306,258,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11696,307,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11696,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11696,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11696,401,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11696,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11696,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11696,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11696,606,0.036,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11697,203,4.24,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11697,204,0.2,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11697,205,13.39,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11697,207,1.42,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11697,208,65,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11697,255,80.75,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11697,269,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11697,291,1.3,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11697,301,6,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11697,303,2.22,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11697,306,454,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11697,307,26,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11697,320,1,'100g',1,1,'2024-12-12','2003-01-06');
INSERT INTO `cndb_nutval` VALUES (11697,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11697,401,1.9,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11697,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11697,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11697,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11697,606,0.039,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11700,203,2.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11700,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11700,205,4.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11700,207,2.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11700,208,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11700,255,91.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11700,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11700,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11700,301,209,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11700,303,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11700,306,641,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11700,307,257,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11700,320,139,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11700,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11700,401,41.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11700,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11700,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11700,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11700,606,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11702,203,2.89,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11702,204,0.34,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11702,205,11.39,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11702,207,1.3,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11702,208,51,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11702,255,84.08,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11702,269,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11702,291,5.7,'100g',3,1,'1996-09-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11702,301,21,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11702,303,0.61,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11702,306,286,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11702,307,296,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (11702,320,1,'100g',1,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11702,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11702,401,7.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11702,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11702,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11702,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11702,606,0.079,'100g',1,1,'1996-09-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11703,203,3.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11703,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11703,205,9.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11703,207,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11703,208,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11703,255,86.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11703,269,0.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11703,291,4.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11703,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11703,303,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11703,306,264,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11703,307,289,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11703,320,1,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11703,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11703,401,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11703,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11703,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11703,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11703,606,0.119,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11705,203,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11705,204,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11705,205,4.11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11705,207,0.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11705,208,22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11705,255,92.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11705,269,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11705,291,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11705,301,23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11705,303,0.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11705,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11705,307,240,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11705,320,50,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11705,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11705,401,7.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11705,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11705,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11705,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11705,606,0.048,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11707,203,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11707,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11707,205,2.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11707,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11707,208,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11707,255,94.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11707,269,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11707,291,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11707,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11707,303,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11707,306,172,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11707,307,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11707,320,39,'100g',2,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11707,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11707,401,16.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11707,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11707,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11707,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11707,606,0.041,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11709,203,2.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11709,204,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11709,205,1.92,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11709,207,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11709,208,18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11709,255,94.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11709,269,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11709,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11709,301,18,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11709,303,0.56,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11709,306,172,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11709,307,240,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11709,320,40,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (11709,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11709,401,24.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11709,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11709,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11709,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11709,606,0.096,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11712,203,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11712,204,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11712,205,1.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11712,207,0.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11712,208,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11712,255,95.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11712,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11712,291,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11712,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11712,303,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11712,306,533,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11712,307,240,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11712,320,0,'100g',1,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (11712,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11712,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11712,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11712,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11712,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11712,606,0.051,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11713,203,4.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11713,204,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11713,205,4.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11713,207,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11713,208,33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11713,255,89.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11713,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11713,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11713,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11713,303,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11713,306,194,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11713,307,243,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11713,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11713,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11713,401,35.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11713,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11713,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11713,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11713,606,0.083,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11714,203,6.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11714,204,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11714,205,23.64,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11714,207,2.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11714,208,123,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11714,255,67.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11714,269,1.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11714,291,5.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11714,301,32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11714,303,2.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11714,306,570,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11714,307,253,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11714,320,19,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11714,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11714,401,10.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11714,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11714,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11714,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11714,606,0.073,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11715,203,4.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11715,204,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11715,205,13.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11715,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11715,208,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11715,255,81.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11715,269,0.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11715,291,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11715,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11715,303,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11715,306,285,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11715,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11715,320,8,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11715,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11715,401,8.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11715,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11715,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11715,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11715,606,0.066,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11716,203,6.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11716,204,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11716,205,19.45,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11716,207,1.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11716,208,105,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11716,255,72.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11716,269,1.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11716,291,4.8,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11716,301,28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11716,303,1.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11716,306,411,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11716,307,265,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11716,320,8,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11716,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11716,401,5.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11716,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11716,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11716,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11716,606,0.068,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11717,203,6.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11717,204,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11717,205,19.32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11717,207,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11717,208,103,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11717,255,72.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11717,269,1.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11717,291,5.3,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11717,301,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11717,303,1.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11717,306,304,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11717,307,289,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11717,320,10,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11717,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11717,401,12.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11717,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11717,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11717,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11717,606,0.077,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11718,203,2.03,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11718,204,0.09,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11718,205,3.6,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11718,207,0.89,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11718,208,19,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11718,255,93.39,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11718,269,2.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11718,291,0.8,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11718,301,12,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11718,303,0.65,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11718,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11718,307,246,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11718,320,1,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11718,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11718,401,11.4,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11718,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11718,601,0,'100g',4,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11718,605,0,'100g',NULL,1,'1994-03-16','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11718,606,0.025,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11719,203,7.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11719,204,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11719,205,15.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11719,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11719,208,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11719,255,76.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11719,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11719,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11719,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11719,303,2.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11719,306,317,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11719,307,250,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11719,320,0,'100g',1,1,'2024-12-12','2008-01-06');
INSERT INTO `cndb_nutval` VALUES (11719,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11719,401,17.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11719,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11719,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11719,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11719,606,0.098,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11720,203,9.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11720,204,0.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11720,205,30.87,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11720,207,1.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11720,208,162,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11720,255,58.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11720,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11720,291,5.4,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11720,301,52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11720,303,2.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11720,306,646,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11720,307,319,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11720,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11720,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11720,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11720,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11720,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11720,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11720,606,0.058,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11721,203,1.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11721,204,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11721,205,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11721,207,0.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11721,208,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11721,255,93.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11721,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11721,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11721,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11721,303,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11721,306,98,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11721,307,287,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11721,320,0,'100g',1,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (11721,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11721,401,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11721,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11721,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11721,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11721,606,0.039,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11722,203,1.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11722,204,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11722,205,7.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11722,207,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11722,208,31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11722,255,90.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11722,269,3.27,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11722,291,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11722,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11722,303,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11722,306,209,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11722,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11722,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11722,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11722,401,16.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11722,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11722,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11722,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11722,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11723,203,1.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11723,204,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11723,205,7.88,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11723,207,0.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11723,208,35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11723,255,89.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11723,269,3.63,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11723,291,3.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11723,301,44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11723,303,0.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11723,306,146,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11723,307,239,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11723,320,35,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (11723,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11723,401,9.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11723,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11723,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11723,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11723,606,0.064,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11724,203,1.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11724,204,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11724,205,7.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11724,207,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11724,208,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11724,255,89.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11724,269,3.63,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11724,291,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11724,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11724,303,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11724,306,299,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11724,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11724,320,4,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11724,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11724,401,9.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11724,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11724,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11724,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11724,606,0.064,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11725,203,1.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11725,204,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11725,205,7.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11725,207,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11725,208,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11725,255,89.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11725,269,3.63,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11725,291,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11725,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11725,303,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11725,306,299,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11725,307,239,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11725,320,4,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11725,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11725,401,9.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11725,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11725,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11725,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11725,606,0.064,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11726,203,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11726,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11726,205,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11726,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11726,208,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11726,255,94.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11726,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11726,291,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11726,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11726,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11726,306,92,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11726,307,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11726,320,16,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11726,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11726,401,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11726,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11726,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11726,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11726,606,0.023,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11727,203,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11727,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11727,205,3.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11727,207,0.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11727,208,15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11727,255,94.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11727,269,0.62,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11727,291,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11727,301,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11727,303,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11727,306,98,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11727,307,259,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11727,320,4,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (11727,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11727,401,3.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11727,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11727,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11727,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11727,606,0.023,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11728,203,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11728,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11728,205,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11728,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11728,208,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11728,255,94.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11728,269,0.62,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11728,291,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11728,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11728,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11728,306,98,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11728,307,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11728,320,4,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (11728,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11728,401,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11728,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11728,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11728,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11728,606,0.023,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11729,203,1.12,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11729,204,0.46,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11729,205,4.32,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11729,207,0.73,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11729,208,22,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11729,255,93.38,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11729,269,0.78,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11729,291,1.9,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11729,301,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11729,303,1.06,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11729,306,96,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11729,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11729,320,18,'100g',1,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (11729,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11729,401,2.8,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11729,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11729,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11729,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11729,606,0.103,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11730,203,1.8,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11730,204,0.21,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11730,205,7.58,'100g',3,1,'1996-09-30','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11730,207,0.53,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11730,208,33,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11730,255,89.88,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11730,269,2.22,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11730,291,2.8,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11730,301,42,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11730,303,0.86,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11730,306,186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11730,307,3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11730,320,7,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (11730,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11730,401,12.9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11730,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11730,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11730,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11730,606,0.047,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11731,203,1.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11731,204,0.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11731,205,6.45,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11731,207,0.47,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11731,208,28,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11731,255,91.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11731,269,1.88,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11731,291,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11731,301,42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11731,303,0.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11731,306,159,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11731,307,245,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11731,320,23,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (11731,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11731,401,4.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11731,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11731,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11731,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11731,606,0.044,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11732,203,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11732,204,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11732,205,6.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11732,207,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11732,208,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11732,255,91.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11732,269,1.88,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11732,291,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11732,301,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11732,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11732,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11732,307,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11732,320,6,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11732,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11732,401,4.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11732,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11732,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11732,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11732,606,0.044,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11733,203,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11733,204,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11733,205,6.45,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11733,207,0.47,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11733,208,28,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11733,255,91.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11733,269,1.88,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11733,291,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11733,301,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11733,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11733,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11733,307,245,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11733,320,6,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11733,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11733,401,4.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11733,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11733,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11733,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11733,606,0.044,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11734,203,1.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11734,204,0.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11734,205,9.96,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11734,207,1.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11734,208,44,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11734,255,87.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11734,269,7.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11734,291,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11734,301,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11734,303,0.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11734,306,305,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11734,307,285,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11734,320,2,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11734,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11734,401,3.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11734,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11734,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11734,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11734,606,0.028,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11735,203,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11735,204,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11735,205,6.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11735,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11735,208,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11735,255,91.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11735,269,5.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11735,291,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11735,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11735,303,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11735,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11735,307,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11735,320,1,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11735,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11735,401,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11735,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11735,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11735,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11735,606,0.011,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11736,203,2.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11736,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11736,205,5.46,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11736,207,2.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11736,208,27,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11736,255,89.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11736,269,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11736,291,2.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11736,301,114,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11736,303,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11736,306,909,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11736,307,477,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11736,320,383,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11736,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11736,401,24.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11736,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11736,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11736,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11736,606,0.031,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11737,203,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11737,204,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11737,205,3.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11737,207,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11737,208,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11737,255,91.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11737,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11737,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11737,301,102,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11737,303,3.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11737,306,491,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11737,307,324,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11737,320,219,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11737,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11737,401,32.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11737,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11737,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11737,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11737,606,0.197,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11738,203,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11738,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11738,205,10.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11738,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11738,208,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11738,255,83.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11738,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11738,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11738,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11738,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11738,306,193,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11738,307,277,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11738,320,14,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11738,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11738,401,19.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11738,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11738,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11738,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11738,606,0.142,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11739,203,2.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11739,204,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11739,205,5.06,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11739,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11739,208,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11739,255,90.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11739,269,1.48,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11739,291,2.3,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11739,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11739,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11739,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11739,307,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11739,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11739,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11739,401,93.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11739,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11739,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11739,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11739,606,0.054,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11740,203,2.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11740,204,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11740,205,5.06,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11740,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11740,208,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11740,255,90.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11740,269,1.48,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11740,291,2.3,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11740,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11740,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11740,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11740,307,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11740,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11740,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11740,401,93.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11740,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11740,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11740,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11740,606,0.054,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11741,203,2.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11741,204,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11741,205,5.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11741,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11741,208,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11741,255,90.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11741,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11741,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11741,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11741,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11741,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11741,307,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11741,320,20,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11741,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11741,401,93.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11741,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11741,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11741,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11741,606,0.054,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11742,203,2.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11742,204,0.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11742,205,7.18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11742,207,0.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11742,208,35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11742,255,89.25,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11742,269,1.39,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11742,291,3.3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11742,301,40,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11742,303,0.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11742,306,293,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11742,307,262,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11742,320,77,'100g',1,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (11742,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11742,401,64.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11742,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11742,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11742,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11742,606,0.079,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11743,203,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11743,204,0.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11743,205,5.35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11743,207,0.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11743,208,28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11743,255,90.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11743,269,1.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11743,291,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11743,301,33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11743,303,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11743,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11743,307,260,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11743,320,51,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (11743,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11743,401,40.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11743,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11743,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11743,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11743,606,0.018,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11744,203,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11744,204,0.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11744,205,5.35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11744,207,0.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11744,208,28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11744,255,90.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11744,269,1.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11744,291,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11744,301,51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11744,303,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11744,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11744,307,260,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11744,320,56,'100g',2,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (11744,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11744,401,40.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11744,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11744,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11744,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11744,606,0.018,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11745,203,2.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11745,204,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11745,205,7.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11745,207,0.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11745,208,36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11745,255,88.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11745,269,1.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11745,291,2.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11745,301,36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11745,303,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11745,306,317,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11745,307,257,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11745,320,39,'100g',1,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (11745,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11745,401,62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11745,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11745,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11745,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11745,606,0.102,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11746,203,3.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11746,204,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11746,205,8.32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11746,207,0.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11746,208,42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11746,255,86.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11746,269,2.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11746,291,4.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11746,301,26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11746,303,0.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11746,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11746,307,259,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11746,320,46,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (11746,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11746,401,45.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11746,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11746,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11746,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11746,606,0.081,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11749,203,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11749,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11749,205,5.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11749,207,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11749,208,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11749,255,92.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11749,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11749,291,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11749,301,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11749,303,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11749,306,246,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11749,307,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11749,320,6,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11749,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11749,401,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11749,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11749,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11749,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11749,606,0.023,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11750,203,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11750,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11750,205,5.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11750,207,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11750,208,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11750,255,92.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11750,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11750,291,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11750,301,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11750,303,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11750,306,246,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11750,307,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11750,320,6,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11750,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11750,401,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11750,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11750,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11750,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11750,606,0.023,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11751,203,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11751,204,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11751,205,5.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11751,207,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11751,208,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11751,255,92.57,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11751,269,2.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11751,291,1.9,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11751,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11751,303,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11751,306,196,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11751,307,255,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11751,320,4,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11751,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11751,401,37.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11751,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11751,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11751,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11751,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11752,203,1.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11752,204,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11752,205,6.94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11752,207,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11752,208,29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11752,255,90.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11752,269,3.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11752,291,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11752,301,42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11752,303,0.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11752,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11752,307,244,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11752,320,2,'100g',1,1,'2024-12-12','2006-01-06');
INSERT INTO `cndb_nutval` VALUES (11752,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11752,401,10.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11752,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11752,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11752,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11752,606,0.011,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11753,203,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11753,204,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11753,205,5.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11753,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11753,208,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11753,255,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11753,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11753,291,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11753,301,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11753,303,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11753,306,184,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11753,307,260,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11753,320,44,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11753,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11753,401,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11753,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11753,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11753,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11753,606,0.012,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11754,203,1.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11754,204,0.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11754,205,1.78,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11754,207,0.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11754,208,12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11754,255,95.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11754,269,0.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11754,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11754,301,93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11754,303,1.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11754,306,371,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11754,307,270,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11754,320,212,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11754,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11754,401,26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11754,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11754,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11754,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11754,606,0.021,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11755,203,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11755,204,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11755,205,2.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11755,207,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11755,208,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11755,255,95.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11755,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11755,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11755,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11755,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11755,306,225,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11755,307,245,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11755,320,48,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11755,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11755,401,15.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11755,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11755,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11755,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11755,606,0.036,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11756,203,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11756,204,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11756,205,4.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11756,207,0.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11756,208,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11756,255,93.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11756,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11756,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11756,301,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11756,303,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11756,306,392,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11756,307,412,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11756,320,0,'100g',1,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (11756,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11756,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11756,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11756,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11756,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11756,606,0.012,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11757,203,0.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11757,204,0.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11757,205,8.22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11757,207,0.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11757,208,35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11757,255,90.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11757,269,3.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11757,291,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11757,301,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11757,303,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11757,306,235,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11757,307,302,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11757,320,852,'100g',2,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (11757,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11757,401,3.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11757,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11757,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11757,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11757,606,0.037,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11758,203,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11758,204,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11758,205,5.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11758,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11758,208,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11758,255,92.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11758,269,2.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11758,291,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11758,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11758,303,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11758,306,158,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11758,307,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11758,320,558,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11758,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11758,401,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11758,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11758,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11758,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11758,606,0.024,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11759,203,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11759,204,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11759,205,5.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11759,207,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11759,208,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11759,255,92.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11759,269,2.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11759,291,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11759,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11759,303,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11759,306,179,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11759,307,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11759,320,558,'100g',1,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (11759,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11759,401,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11759,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11759,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11759,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11759,606,0.036,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11760,203,0.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11760,204,0.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11760,205,7.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11760,207,0.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11760,208,37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11760,255,90.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11760,269,4.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11760,291,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11760,301,35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11760,303,0.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11760,306,192,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11760,307,295,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11760,320,846,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11760,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11760,401,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11760,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11760,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11760,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11760,606,0.132,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11761,203,1.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11761,204,0.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11761,205,4.11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11761,207,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11761,208,23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11761,255,93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11761,269,1.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11761,291,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11761,301,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11761,303,0.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11761,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11761,307,242,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11761,320,1,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (11761,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11761,401,44.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11761,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11761,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11761,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11761,606,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11762,203,1.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11762,204,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11762,205,3.16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11762,207,1.01,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11762,208,17,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11762,255,94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11762,269,0.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11762,291,2.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11762,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11762,303,0.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11762,306,139,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11762,307,254,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11762,320,0,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11762,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11762,401,31.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11762,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11762,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11762,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11762,606,0.034,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11764,203,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11764,204,0.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11764,205,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11764,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11764,208,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11764,255,94.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11764,269,2.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11764,291,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11764,301,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11764,303,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11764,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11764,307,327,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11764,320,26,'100g',2,1,'2024-12-12','2010-01-03');
INSERT INTO `cndb_nutval` VALUES (11764,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11764,401,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11764,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11764,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11764,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11764,606,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11766,203,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11766,204,0.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11766,205,4.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11766,207,0.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11766,208,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11766,255,93.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11766,269,1.89,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11766,291,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11766,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11766,303,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11766,306,173,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11766,307,237,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11766,320,0,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (11766,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11766,401,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11766,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11766,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11766,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11766,606,0.031,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11768,203,2.71,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11768,204,0.72,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11768,205,5.65,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11768,207,0.73,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11768,208,33,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11768,255,90.18,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11768,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11768,291,4,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11768,301,141,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11768,303,1.13,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11768,306,117,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11768,307,252,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11768,320,380,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (11768,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11768,401,18.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11768,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11768,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11768,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11768,606,0.047,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11769,203,2.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11769,204,0.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11769,205,7.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11769,207,1.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11769,208,36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11769,255,88.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11769,269,0.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11769,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11769,301,210,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11769,303,1.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11769,306,251,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11769,307,286,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11769,320,575,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11769,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11769,401,26.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11769,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11769,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11769,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11769,606,0.04,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11770,203,3.41,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11770,204,1.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11770,205,20.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11770,207,0.71,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11770,208,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11770,255,73.41,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11770,269,4.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11770,291,2.4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11770,301,3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11770,303,0.45,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11770,306,218,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11770,307,253,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11770,320,13,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (11770,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11770,401,5.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11770,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11770,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11770,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11770,606,0.197,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11771,203,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11771,204,0.77,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11771,205,13.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11771,207,0.8,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11771,208,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11771,255,82.61,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11771,269,4.15,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11771,291,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11771,301,4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11771,303,0.36,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11771,306,136,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11771,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11771,320,2,'100g',1,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (11771,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11771,401,2.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11771,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11771,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11771,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11771,606,0.077,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11772,203,1.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11772,204,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11772,205,18.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11772,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11772,208,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11772,255,78.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11772,269,3.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11772,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11772,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11772,303,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11772,306,134,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11772,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11772,320,4,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11772,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11772,401,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11772,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11772,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11772,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11772,606,0.065,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11773,203,2.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11773,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11773,205,19.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11773,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11773,208,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11773,255,76.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11773,269,5.59,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11773,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11773,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11773,303,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11773,306,186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11773,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11773,320,4,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11773,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11773,401,8.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11773,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11773,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11773,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11773,606,0.077,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11774,203,2.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11774,204,0.67,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11774,205,18.71,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11774,207,1.03,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11774,208,79,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11774,255,77.03,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11774,269,3.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11774,291,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11774,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11774,303,0.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11774,306,233,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11774,307,245,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11774,320,10,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (11774,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11774,401,3.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11774,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11774,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11774,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11774,606,0.066,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11775,203,3.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11775,204,0.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11775,205,22.33,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11775,207,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11775,208,94,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11775,255,73.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11775,269,3.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11775,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11775,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11775,303,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11775,306,251,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11775,307,240,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11775,320,12,'100g',2,1,'2024-12-12','2010-01-03');
INSERT INTO `cndb_nutval` VALUES (11775,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11775,401,4.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11775,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11775,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11775,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11775,606,0.114,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11777,203,3.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11777,204,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11777,205,19.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11777,207,1.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11777,208,94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11777,255,75.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11777,269,3.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11777,291,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11777,301,128,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11777,303,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11777,306,418,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11777,307,240,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11777,320,40,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11777,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11777,401,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11777,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11777,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11777,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11777,606,0.096,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11778,203,8.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11778,204,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11778,205,23.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11778,207,1.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11778,208,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11778,255,66.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11778,269,4.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11778,291,6.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11778,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11778,303,2.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11778,306,375,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11778,307,241,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11778,320,4,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (11778,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11778,401,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11778,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11778,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11778,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11778,606,0.175,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11779,203,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11779,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11779,205,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11779,207,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11779,208,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11779,255,89.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11779,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11779,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11779,301,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11779,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11779,306,196,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11779,307,239,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11779,320,70,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11779,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11779,401,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11779,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11779,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11779,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11779,606,0.079,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11780,203,4.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11780,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11780,205,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11780,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11780,208,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11780,255,91.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11780,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11780,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11780,301,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11780,303,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11780,306,351,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11780,307,242,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11780,320,29,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11780,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11780,401,18.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11780,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11780,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11780,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11780,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11781,203,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11781,204,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11781,205,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11781,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11781,208,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11781,255,92.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11781,269,3.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11781,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11781,301,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11781,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11781,306,353,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11781,307,244,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11781,320,232,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11781,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11781,401,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11781,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11781,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11781,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11781,606,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11783,203,0.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11783,204,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11783,205,8.14,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11783,207,1.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11783,208,33,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11783,255,89.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11783,269,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11783,291,2.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11783,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11783,303,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11783,306,123,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11783,307,239,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11783,320,2,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11783,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11783,401,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11783,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11783,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11783,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11783,606,0.044,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11784,203,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11784,204,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11784,205,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11784,207,0.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11784,208,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11784,255,95.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11784,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11784,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11784,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11784,303,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11784,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11784,307,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11784,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11784,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11784,401,8.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11784,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11784,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11784,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11784,606,0.002,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11785,203,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11785,204,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11785,205,13.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11785,207,0.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11785,208,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11785,255,84.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11785,269,5.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11785,291,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11785,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11785,303,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11785,306,453,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11785,307,257,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11785,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11785,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11785,401,5.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11785,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11785,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11785,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11785,606,0.027,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11788,203,2.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11788,204,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11788,205,9.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11788,207,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11788,208,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11788,255,86.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11788,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11788,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11788,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11788,303,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11788,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11788,307,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11788,320,7,'100g',2,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11788,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11788,401,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11788,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11788,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11788,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11788,606,0.119,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11789,203,3.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11789,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11789,205,7.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11789,207,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11789,208,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11789,255,87.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11789,269,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11789,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11789,301,211,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11789,303,3.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11789,306,550,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11789,307,247,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11789,320,259,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11789,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11789,401,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11789,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11789,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11789,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11789,606,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11790,203,2.94,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11790,204,1.21,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11790,205,5.3,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11790,207,0.73,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11790,208,44,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11790,255,89.82,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11790,269,1.21,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11790,291,2.3,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11790,301,150,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11790,303,0.84,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11790,306,144,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11790,307,252,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11790,320,146,'100g',1,1,'2024-12-12','2016-01-10');
INSERT INTO `cndb_nutval` VALUES (11790,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11790,401,17.8,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11790,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11790,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11790,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11790,606,0.156,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11791,203,2.94,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11791,204,1.21,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11791,205,5.3,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11791,207,0.73,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11791,208,36,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11791,255,89.82,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11791,269,1.21,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11791,291,2.3,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11791,301,150,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11791,303,0.84,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11791,306,144,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11791,307,252,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11791,320,146,'100g',1,1,'2024-12-12','2016-01-10');
INSERT INTO `cndb_nutval` VALUES (11791,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11791,401,17.8,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11791,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11791,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11791,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11791,606,0.158,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11793,203,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11793,204,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11793,205,6.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11793,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11793,208,29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11793,255,90.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11793,269,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11793,291,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11793,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11793,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11793,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11793,307,257,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11793,320,2,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11793,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11793,401,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11793,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11793,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11793,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11793,606,0.014,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11794,203,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11794,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11794,205,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11794,207,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11794,208,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11794,255,88.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11794,269,0.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11794,291,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11794,301,258,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11794,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11794,306,288,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11794,307,265,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11794,320,391,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11794,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11794,401,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11794,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11794,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11794,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11794,606,0.052,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11795,203,0.81,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11795,204,0.2,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11795,205,7.62,'100g',3,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11795,207,0.57,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11795,208,31,'100g',3,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11795,255,90.8,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11795,269,2.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11795,291,1,'100g',3,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11795,301,30,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11795,303,1.1,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11795,306,87,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11795,307,246,'100g',3,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11795,320,41,'100g',2,1,'2024-12-12','2007-01-11');
INSERT INTO `cndb_nutval` VALUES (11795,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11795,401,4.2,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11795,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11795,601,0,'100g',4,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11795,605,0,'100g',NULL,1,'1998-03-27','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11795,606,0.027,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11796,203,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11796,204,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11796,205,16.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11796,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11796,208,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11796,255,81.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11796,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11796,291,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11796,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11796,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11796,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11796,307,281,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11796,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11796,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11796,401,27.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11796,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11796,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11796,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11796,606,0.021,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11797,203,2.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11797,204,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11797,205,5.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11797,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11797,208,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11797,255,91.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11797,269,2.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11797,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11797,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11797,303,1.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11797,306,356,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11797,307,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11797,320,0,'100g',2,1,'2024-12-12','2009-01-08');
INSERT INTO `cndb_nutval` VALUES (11797,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11797,401,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11797,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11797,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11797,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11797,606,0.061,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11798,203,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11798,204,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11798,205,14.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11798,207,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11798,208,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11798,255,83.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11798,269,3.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11798,291,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11798,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11798,303,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11798,306,117,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11798,307,240,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11798,320,0,'100g',1,1,'2024-12-12','2010-01-02');
INSERT INTO `cndb_nutval` VALUES (11798,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11798,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11798,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11798,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11798,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11798,606,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11799,203,2.56,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11799,204,0.47,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11799,205,4.51,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11799,207,0.69,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11799,208,26,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11799,255,91.78,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11799,269,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11799,291,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11799,301,118,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11799,303,0.87,'100g',7,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (11799,306,162,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11799,307,252,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11799,320,527,'100g',2,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (11799,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11799,401,25.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11799,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11799,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11799,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11799,606,0.012,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11800,203,2.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11800,204,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11800,205,3.11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11800,207,0.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11800,208,19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11800,255,93.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11800,269,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11800,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11800,301,101,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11800,303,1.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11800,306,139,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11800,307,261,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11800,320,354,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11800,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11800,401,13.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11800,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11800,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11800,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11800,606,0.013,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11802,203,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11802,204,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11802,205,2.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11802,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11802,208,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11802,255,94.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11802,269,0.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11802,291,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11802,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11802,303,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11802,306,102,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11802,307,343,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11802,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11802,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11802,401,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11802,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11802,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11802,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11802,606,0.027,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11803,203,1.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11803,204,0.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11803,205,4.51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11803,207,0.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11803,208,22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11803,255,92.57,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11803,269,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11803,291,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11803,301,77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11803,303,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11803,306,135,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11803,307,241,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11803,320,14,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11803,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11803,401,16.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11803,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11803,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11803,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11803,606,0.045,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11804,203,1.63,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11804,204,0.24,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11804,205,6.41,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11804,207,0.59,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11804,208,29,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11804,255,91.12,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11804,269,2.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11804,291,2.1,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11804,301,74,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11804,303,0.52,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11804,306,184,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11804,307,239,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11804,320,15,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (11804,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11804,401,9.6,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11804,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11804,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11804,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11804,606,0.063,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11805,203,1.36,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11805,204,0.19,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11805,205,9.56,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11805,207,1.03,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11805,208,42,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11805,255,87.86,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11805,269,4.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11805,291,1.4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11805,301,22,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11805,303,0.24,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11805,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11805,307,239,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11805,320,0,'100g',2,1,'2024-12-12','2007-01-06');
INSERT INTO `cndb_nutval` VALUES (11805,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11805,401,5.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11805,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11805,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11805,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11805,606,0.031,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11806,203,0.77,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11806,204,0.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11806,205,6,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11806,207,0.89,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11806,208,26,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11806,255,92.24,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11806,269,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11806,291,1.7,'100g',3,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11806,301,16,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11806,303,0.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11806,306,108,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11806,307,248,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11806,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11806,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11806,401,2.6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11806,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11806,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11806,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11806,606,0.016,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11807,203,0.71,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11807,204,0.05,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11807,205,6.11,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11807,207,0.89,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11807,208,26,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11807,255,92.24,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11807,269,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11807,291,1.4,'100g',3,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11807,301,27,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11807,303,0.34,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11807,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11807,307,244,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11807,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11807,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11807,401,5.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11807,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11807,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11807,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11807,606,0.009,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11808,203,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11808,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11808,205,17.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11808,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11808,208,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11808,255,80.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11808,269,4.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11808,291,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11808,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11808,303,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11808,306,367,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11808,307,246,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11808,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11808,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11808,401,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11808,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11808,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11808,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11808,606,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11809,203,3.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11809,204,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11809,205,6.46,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11809,207,1.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11809,208,40,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11809,255,88.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11809,269,3.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11809,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11809,301,42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11809,303,1.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11809,306,240,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11809,307,240,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11809,320,52,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (11809,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11809,401,47.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11809,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11809,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11809,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11809,606,0.044,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11810,203,3.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11810,204,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11810,205,8.43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11810,207,1.09,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11810,208,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11810,255,86.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11810,269,4.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11810,291,3.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11810,301,59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11810,303,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11810,306,217,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11810,307,241,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11810,320,66,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11810,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11810,401,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11810,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11810,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11810,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11810,606,0.073,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11811,203,5.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11811,204,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11811,205,15.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11811,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11811,208,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11811,255,77.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11811,269,5.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11811,291,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11811,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11811,303,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11811,306,271,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11811,307,239,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11811,320,40,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11811,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11811,401,14.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11811,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11811,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11811,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11811,606,0.039,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11812,203,3.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11812,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11812,205,9.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11812,207,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11812,208,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11812,255,85.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11812,269,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11812,291,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11812,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11812,303,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11812,306,100,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11812,307,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11812,320,72,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11812,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11812,401,9.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11812,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11812,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11812,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11812,606,0.054,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11813,203,4.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11813,204,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11813,205,12.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11813,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11813,208,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11813,255,81.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11813,269,4.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11813,291,4.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11813,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11813,303,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11813,306,173,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11813,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11813,320,27,'100g',1,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (11813,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11813,401,9.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11813,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11813,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11813,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11813,606,0.062,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11814,203,5.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11814,204,0.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11814,205,14.26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11814,207,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11814,208,78,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11814,255,79.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11814,269,4.4,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11814,291,4.5,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11814,301,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11814,303,1.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11814,306,110,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11814,307,323,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11814,320,105,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (11814,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11814,401,9.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11814,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11814,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11814,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11814,606,0.049,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11815,203,7.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11815,204,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11815,205,17.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11815,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11815,208,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11815,255,74.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11815,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11815,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11815,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11815,303,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11815,306,268,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11815,307,239,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11815,320,5,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11815,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11815,401,6.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11815,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11815,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11815,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11815,606,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11816,203,2.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11816,204,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11816,205,8.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11816,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11816,208,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11816,255,88.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11816,269,2.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11816,291,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11816,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11816,303,0.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11816,306,100,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11816,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11816,320,343,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11816,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11816,401,6.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11816,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11816,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11816,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11816,606,0.049,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11817,203,3.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11817,204,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11817,205,10.12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11817,207,0.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11817,208,48,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11817,255,85.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11817,269,4.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11817,291,3.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11817,301,23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11817,303,0.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11817,306,158,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11817,307,304,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11817,320,476,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11817,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11817,401,8.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11817,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11817,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11817,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11817,606,0.077,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11818,203,2.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11818,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11818,205,8.63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11818,207,0.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11818,208,45,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11818,255,88.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11818,269,3.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11818,291,2.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11818,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11818,303,0.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11818,306,117,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11818,307,273,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11818,320,53,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11818,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11818,401,6.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11818,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11818,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11818,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11818,606,0.036,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11819,203,1.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11819,204,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11819,205,8.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11819,207,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11819,208,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11819,255,88.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11819,269,5.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11819,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11819,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11819,303,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11819,306,322,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11819,307,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11819,320,48,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11819,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11819,401,143.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11819,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11819,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11819,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11819,606,0.042,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11820,203,0.9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11820,204,0.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11820,205,5.1,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11820,207,1.4,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11820,208,21,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11820,255,92.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11820,269,3.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11820,291,1.3,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11820,301,7,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11820,303,0.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11820,306,187,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11820,307,1173,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11820,320,595,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11820,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11820,401,68,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11820,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11820,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11820,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11820,606,0.01,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11821,203,0.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11821,204,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11821,205,6.03,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11821,207,0.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11821,208,26,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11821,255,92.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11821,269,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11821,291,2.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11821,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11821,303,0.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11821,306,211,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11821,307,4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11821,320,157,'100g',1,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (11821,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11821,401,127.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11821,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11821,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11821,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11821,606,0.059,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11822,203,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11822,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11822,205,6.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11822,207,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11822,208,26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11822,255,91.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11822,269,3.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11822,291,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11822,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11822,303,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11822,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11822,307,238,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11822,320,23,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11822,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11822,401,74.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11822,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11822,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11822,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11822,606,0.029,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11823,203,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11823,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11823,205,6.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11823,207,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11823,208,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11823,255,91.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11823,269,4.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11823,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11823,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11823,303,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11823,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11823,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11823,320,147,'100g',2,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (11823,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11823,401,171,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11823,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11823,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11823,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11823,606,0.029,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11824,203,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11824,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11824,205,6.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11824,207,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11824,208,26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11824,255,91.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11824,269,4.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11824,291,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11824,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11824,303,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11824,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11824,307,238,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11824,320,147,'100g',2,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (11824,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11824,401,171,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11824,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11824,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11824,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11824,606,0.029,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11825,203,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11825,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11825,205,3.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11825,207,0.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11825,208,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11825,255,94.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11825,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11825,291,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11825,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11825,303,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11825,306,72,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11825,307,240,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11825,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11825,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11825,401,41.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11825,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11825,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11825,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11825,606,0.027,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11826,203,5.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11826,204,1.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11826,205,19.49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11826,207,1.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11826,208,111,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11826,255,71.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11826,269,2.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11826,291,4.2,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11826,301,41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11826,303,1.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11826,306,456,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11826,307,240,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11826,320,2,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11826,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11826,401,28.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11826,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11826,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11826,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11826,606,0.365,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11828,203,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11828,204,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11828,205,21.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11828,207,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11828,208,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11828,255,74.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11828,269,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11828,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11828,301,15,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11828,303,1.08,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11828,306,535,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11828,307,10,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11828,320,1,'100g',2,1,'2024-12-12','2004-01-05');
INSERT INTO `cndb_nutval` VALUES (11828,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11828,401,9.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11828,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11828,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11828,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11828,606,0.034,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11829,203,1.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11829,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11829,205,21.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11829,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11829,208,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11829,255,75.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11829,269,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11829,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11829,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11829,303,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11829,306,391,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11829,307,241,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11829,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11829,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11829,401,12.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11829,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11829,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11829,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11829,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11830,203,4.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11830,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11830,205,46.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11830,207,2.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11830,208,198,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11830,255,47.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11830,269,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11830,291,7.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11830,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11830,303,7.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11830,306,573,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11830,307,257,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11830,320,1,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11830,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11830,401,13.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11830,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11830,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11830,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11830,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11831,203,1.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11831,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11831,205,20.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11831,207,0.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11831,208,87,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11831,255,76.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11831,269,0.91,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11831,291,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11831,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11831,303,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11831,306,379,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11831,307,240,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11831,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11831,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11831,401,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11831,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11831,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11831,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11831,606,0.026,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11832,203,2.86,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11832,204,0.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11832,205,17.2,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11832,207,2.04,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11832,208,78,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11832,255,77.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11832,269,NULL,'100g',NULL,1,'1994-09-21','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11832,291,3.3,'100g',3,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11832,301,45,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11832,303,6.07,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11832,306,407,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11832,307,250,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11832,320,0,'100g',1,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (11832,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11832,401,5.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11832,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11832,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11832,605,0,'100g',NULL,1,'1994-09-21','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11832,606,0.026,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11833,203,1.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11833,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11833,205,20.01,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11833,207,0.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11833,208,86,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11833,255,77.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11833,269,0.89,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11833,291,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11833,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11833,303,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11833,306,328,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11833,307,241,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11833,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11833,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11833,401,7.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11833,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11833,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11833,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11833,606,0.026,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11834,203,2.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11834,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11834,205,24.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11834,207,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11834,208,105,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11834,255,72.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11834,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11834,291,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11834,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11834,303,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11834,306,447,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11834,307,244,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11834,320,0,'100g',1,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (11834,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11834,401,15.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11834,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11834,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11834,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11834,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11835,203,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11835,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11835,205,23.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11835,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11835,208,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11835,255,73.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11835,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11835,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11835,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11835,303,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11835,306,411,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11835,307,243,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11835,320,0,'100g',1,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (11835,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11835,401,15.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11835,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11835,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11835,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11835,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11836,203,4.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11836,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11836,205,29.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11836,207,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11836,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11836,255,63.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11836,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11836,291,5.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11836,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11836,303,5.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11836,306,650,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11836,307,252,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11836,320,0,'100g',1,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (11836,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11836,401,15.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11836,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11836,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11836,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11836,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11837,203,1.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11837,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11837,205,13.93,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11837,207,1.16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11837,208,63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11837,255,82.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11837,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11837,291,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11837,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11837,303,0.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11837,306,287,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11837,307,256,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11837,320,0,'100g',1,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (11837,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11837,401,9.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11837,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11837,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11837,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11837,606,0.034,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11840,203,3.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11840,204,8.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11840,205,34.03,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11840,207,1.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11840,208,218,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11840,255,52.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11840,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11840,291,3.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11840,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11840,303,1.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11840,306,480,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11840,307,281,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11840,320,0,'100g',1,1,'2024-12-12','2006-01-02');
INSERT INTO `cndb_nutval` VALUES (11840,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11840,401,9.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11840,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11840,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11840,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11840,606,3.894,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11841,203,2.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11841,204,5.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11841,205,28.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11841,207,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11841,208,168,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11841,255,61.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11841,269,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11841,291,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11841,301,12,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11841,303,0.74,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11841,306,451,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11841,307,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11841,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11841,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11841,401,13.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11841,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11841,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11841,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11841,606,1.029,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11842,203,2.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11842,204,4.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11842,205,24.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11842,207,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11842,208,147,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11842,255,66.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11842,269,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11842,291,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11842,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11842,303,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11842,306,408,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11842,307,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11842,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11842,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11842,401,17.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11842,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11842,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11842,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11842,606,0.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11843,203,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11843,204,7.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11843,205,11.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11843,207,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11843,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11843,255,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11843,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11843,291,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11843,301,119,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11843,303,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11843,306,396,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11843,307,433,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11843,320,64,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (11843,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11843,401,9.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11843,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11843,601,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11843,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11843,606,3.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11844,203,2.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11844,204,3.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11844,205,10.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11844,207,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11844,208,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11844,255,80.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11844,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11844,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11844,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11844,303,0.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11844,306,378,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11844,307,335,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11844,320,33,'100g',2,1,'2024-12-12','2006-01-02');
INSERT INTO `cndb_nutval` VALUES (11844,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11844,401,10.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11844,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11844,601,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11844,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11844,606,1.377,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11845,203,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11845,204,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11845,205,4.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11845,207,1.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11845,208,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11845,255,93.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11845,269,2.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11845,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11845,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11845,303,0.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11845,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11845,307,237,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11845,320,288,'100g',2,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (11845,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11845,401,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11845,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11845,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11845,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11845,606,0.037,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11846,203,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11846,204,0.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11846,205,8.09,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11846,207,0.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11846,208,34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11846,255,89.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11846,269,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11846,291,2.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11846,301,26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11846,303,1.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11846,306,206,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11846,307,241,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11846,320,778,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11846,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11846,401,4.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11846,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11846,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11846,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11846,606,0.146,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11847,203,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11847,204,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11847,205,3.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11847,207,0.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11847,208,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11847,255,95.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11847,269,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11847,291,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11847,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11847,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11847,306,106,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11847,307,242,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11847,320,87,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11847,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11847,401,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11847,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11847,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11847,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11847,606,0.041,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11848,203,2.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11848,204,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11848,205,3.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11848,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11848,208,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11848,255,92.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11848,269,0.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11848,291,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11848,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11848,303,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11848,306,438,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11848,307,244,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11848,320,80,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11848,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11848,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11848,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11848,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11848,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11848,606,0.114,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11850,203,0.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11850,204,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11850,205,3.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11850,207,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11850,208,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11850,255,95.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11850,269,1.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11850,291,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11850,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11850,303,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11850,306,285,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11850,307,249,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11850,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11850,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11850,401,15.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11850,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11850,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11850,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11850,606,0.073,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11851,203,0.93,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11851,204,0.18,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11851,205,6.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11851,207,0.51,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11851,208,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11851,255,91.54,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11851,269,3.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11851,291,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11851,301,18,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11851,303,0.18,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11851,306,216,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11851,307,254,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11851,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11851,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11851,401,18.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11851,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11851,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11851,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11851,606,0.029,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11853,203,12.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11853,204,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11853,205,11.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11853,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11853,208,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11853,255,68.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11853,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11853,291,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11853,301,145,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11853,303,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11853,306,539,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11853,307,250,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11853,320,8,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11853,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11853,401,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11853,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11853,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11853,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11853,606,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11854,203,2.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11854,204,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11854,205,3.75,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11854,207,1.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11854,208,23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11854,255,91.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11854,269,0.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11854,291,2.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11854,301,136,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11854,303,3.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11854,306,466,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11854,307,306,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11854,320,524,'100g',1,1,'2024-12-12','2008-01-10');
INSERT INTO `cndb_nutval` VALUES (11854,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11854,401,9.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11854,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11854,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11854,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11854,606,0.043,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11855,203,2.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11855,204,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11855,205,2.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11855,207,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11855,208,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11855,255,93.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11855,269,0.33,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11855,291,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11855,301,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11855,303,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11855,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11855,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11855,320,404,'100g',2,1,'2024-12-12','2015-01-01');
INSERT INTO `cndb_nutval` VALUES (11855,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11855,401,13.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11855,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11855,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11855,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11855,606,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11856,203,4.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11856,204,0.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11856,205,4.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11856,207,1.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11856,208,34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11856,255,88.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11856,269,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11856,291,3.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11856,301,153,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11856,303,1.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11856,306,302,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11856,307,322,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11856,320,603,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (11856,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11856,401,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11856,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11856,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11856,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11856,606,0.036,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11857,203,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11857,204,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11857,205,4.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11857,207,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11857,208,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11857,255,93.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11857,269,2.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11857,291,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11857,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11857,303,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11857,306,192,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11857,307,237,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11857,320,11,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11857,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11857,401,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11857,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11857,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11857,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11857,606,0.064,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11858,203,1.04,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11858,204,0.39,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11858,205,3.79,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11858,207,0.53,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11858,208,19,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11858,255,94.25,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11858,269,2.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11858,291,1.1,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11858,301,22,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11858,303,0.37,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11858,306,177,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11858,307,237,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11858,320,56,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (11858,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11858,401,11.6,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11858,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11858,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11858,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11858,606,0.064,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11859,203,1.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11859,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11859,205,5.54,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11859,207,0.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11859,208,25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11859,255,92.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11859,269,2.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11859,291,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11859,301,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11859,303,0.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11859,306,253,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11859,307,242,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11859,320,10,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11859,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11859,401,6.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11859,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11859,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11859,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11859,606,0.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11860,203,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11860,204,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11860,205,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11860,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11860,208,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11860,255,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11860,269,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11860,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11860,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11860,303,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11860,306,140,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11860,307,237,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11860,320,4,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11860,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11860,401,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11860,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11860,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11860,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11860,606,0.035,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11861,203,1.14,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11861,204,0.36,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11861,205,2.69,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11861,207,0.59,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11861,208,15,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11861,255,95.22,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11861,269,1.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11861,291,1,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11861,301,18,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11861,303,0.37,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11861,306,264,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11861,307,239,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11861,320,56,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (11861,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11861,401,12.9,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11861,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11861,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11861,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11861,606,0.072,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (11862,203,1.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11862,204,0.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11862,205,2.97,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11862,207,1.01,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11862,208,14,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11862,255,94.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11862,269,1.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11862,291,1.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11862,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11862,303,0.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11862,306,194,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11862,307,238,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11862,320,9,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11862,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11862,401,3.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11862,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11862,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11862,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11862,606,0.027,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11863,203,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11863,204,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11863,205,8.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11863,207,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11863,208,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11863,255,89.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11863,269,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11863,291,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11863,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11863,303,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11863,306,241,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11863,307,237,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11863,320,261,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11863,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11863,401,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11863,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11863,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11863,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11863,606,0.072,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11864,203,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11864,204,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11864,205,14.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11864,207,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11864,208,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11864,255,82.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11864,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11864,291,4.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11864,301,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11864,303,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11864,306,437,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11864,307,240,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11864,320,21,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11864,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11864,401,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11864,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11864,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11864,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11864,606,0.029,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11865,203,0.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11865,204,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11865,205,8.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11865,207,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11865,208,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11865,255,89.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11865,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11865,291,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11865,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11865,303,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11865,306,263,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11865,307,239,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11865,320,13,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11865,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11865,401,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11865,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11865,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11865,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11865,606,0.017,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11866,203,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11866,204,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11866,205,10.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11866,207,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11866,208,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11866,255,87.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11866,269,1.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11866,291,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11866,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11866,303,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11866,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11866,307,240,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11866,320,558,'100g',2,1,'2024-12-12','2009-01-10');
INSERT INTO `cndb_nutval` VALUES (11866,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11866,401,15.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11866,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11866,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11866,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11866,606,0.019,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11867,203,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11867,204,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11867,205,10.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11867,207,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11867,208,39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11867,255,87.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11867,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11867,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11867,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11867,303,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11867,306,133,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11867,307,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11867,320,167,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11867,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11867,401,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11867,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11867,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11867,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11867,606,0.014,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11868,203,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11868,204,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11868,205,10.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11868,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11868,208,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11868,255,85.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11868,269,4.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11868,291,4.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11868,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11868,303,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11868,306,358,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11868,307,244,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11868,320,335,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (11868,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11868,401,9.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11868,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11868,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11868,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11868,606,0.128,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11869,203,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11869,204,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11869,205,6.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11869,207,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11869,208,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11869,255,91.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11869,269,2.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11869,291,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11869,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11869,303,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11869,306,214,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11869,307,241,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11869,320,200,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11869,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11869,401,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11869,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11869,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11869,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11869,606,0.076,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11870,203,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11870,204,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11870,205,6.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11870,207,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11870,208,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11870,255,92.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11870,269,2.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11870,291,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11870,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11870,303,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11870,306,117,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11870,307,254,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11870,320,6,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11870,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11870,401,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11870,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11870,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11870,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11870,606,0.062,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11871,203,5.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11871,204,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11871,205,24.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11871,207,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11871,208,111,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11871,255,68.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11871,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11871,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11871,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11871,303,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11871,306,410,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11871,307,253,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11871,320,15,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11871,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11871,401,8.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11871,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11871,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11871,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11871,606,0.148,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11872,203,4.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11872,204,0.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11872,205,19.95,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11872,207,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11872,208,93,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11872,255,74.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11872,269,2.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11872,291,4.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11872,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11872,303,0.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11872,306,265,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11872,307,281,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11872,320,10,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11872,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11872,401,5.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11872,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11872,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11872,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11872,606,0.166,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11874,203,2.18,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11874,204,0.34,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11874,205,7.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11874,207,0.89,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11874,208,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11874,255,89.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11874,269,5.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11874,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11874,301,33,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11874,303,0.63,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11874,306,312,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11874,307,249,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11874,320,147,'100g',2,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (11874,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11874,401,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11874,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11874,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11874,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11874,606,0.065,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11875,203,2.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11875,204,0.15,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11875,205,20.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11875,207,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11875,208,90,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11875,255,75.78,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11875,269,6.48,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11875,291,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11875,301,38,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11875,303,0.69,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11875,306,475,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11875,307,246,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11875,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11875,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11875,401,19.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11875,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11875,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11875,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11875,606,0.052,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11876,203,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11876,204,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11876,205,17.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11876,207,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11876,208,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11876,255,80.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11876,269,5.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11876,291,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11876,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11876,303,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11876,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11876,307,263,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11876,320,787,'100g',1,1,'2024-12-12','2009-01-08');
INSERT INTO `cndb_nutval` VALUES (11876,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11876,401,12.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11876,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11876,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11876,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11876,606,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11877,203,1.71,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11877,204,0.12,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11877,205,23.4,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11877,207,1.07,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11877,208,100,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11877,255,73.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11877,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11877,291,1.8,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11877,301,35,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11877,303,0.54,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11877,306,377,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11877,307,244,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11877,320,821,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11877,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11877,401,9.1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11877,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11877,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11877,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11877,606,0.026,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11878,203,0.52,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11878,204,0.11,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11878,205,34.6,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11878,207,0.97,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11878,208,142,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11878,255,63.8,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11878,269,0.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11878,291,5.1,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11878,301,18,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11878,303,0.72,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11878,306,484,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11878,307,251,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11878,320,4,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11878,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11878,401,5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11878,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11878,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11878,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11878,606,0.023,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11879,203,2.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11879,204,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11879,205,3.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11879,207,0.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11879,208,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11879,255,92.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11879,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11879,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11879,301,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11879,303,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11879,306,460,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11879,307,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11879,320,212,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11879,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11879,401,35.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11879,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11879,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11879,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11879,606,0.083,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11880,203,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11880,204,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11880,205,3.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11880,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11880,208,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11880,255,95.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11880,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11880,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11880,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11880,303,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11880,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11880,307,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11880,320,3,'100g',2,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11880,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11880,401,18.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11880,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11880,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11880,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11880,606,0.016,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11881,203,4.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11881,204,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11881,205,6.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11881,207,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11881,208,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11881,255,86.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11881,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11881,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11881,301,149,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11881,303,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11881,306,623,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11881,307,290,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11881,320,88,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11881,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11881,401,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11881,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11881,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11881,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11881,606,0.139,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11884,203,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11884,204,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11884,205,4.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11884,207,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11884,208,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11884,255,94.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11884,269,2.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11884,291,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11884,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11884,303,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11884,306,218,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11884,307,247,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11884,320,24,'100g',1,1,'2024-12-12','2004-01-05');
INSERT INTO `cndb_nutval` VALUES (11884,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11884,401,22.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11884,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11884,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11884,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11884,606,0.015,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11885,203,0.79,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11885,204,0.25,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11885,205,3.47,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11885,207,0.74,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11885,208,16,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11885,255,94.75,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11885,269,2.55,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11885,291,1.9,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11885,301,33,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11885,303,0.57,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11885,306,191,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11885,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11885,320,22,'100g',2,1,'2024-12-12','2014-01-08');
INSERT INTO `cndb_nutval` VALUES (11885,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11885,401,12.6,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11885,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11885,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11885,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11885,606,0.034,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11886,203,0.85,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11886,204,0.29,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11886,205,3.53,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11886,207,1.09,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11886,208,17,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11886,255,94.24,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11886,269,2.58,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11886,291,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11886,301,10,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11886,303,0.39,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11886,306,217,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11886,307,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11886,320,23,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11886,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11886,401,70.1,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11886,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11886,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11886,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11886,606,0.019,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11888,203,1.65,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11888,204,0.21,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11888,205,8.98,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11888,207,1.28,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11888,208,38,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11888,255,87.88,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11888,269,4.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11888,291,1.9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11888,301,18,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11888,303,1.78,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11888,306,439,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11888,307,202,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11888,320,26,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11888,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11888,401,10.6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11888,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11888,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11888,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11888,606,0.029,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11889,203,0.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11889,204,0.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11889,205,5.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11889,207,0.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11889,208,22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11889,255,93.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11889,269,2.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11889,291,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11889,301,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11889,303,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11889,306,135,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11889,307,286,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11889,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11889,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11889,401,11.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11889,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11889,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11889,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11889,606,0.008,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11890,203,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11890,204,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11890,205,3.73,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11890,207,0.9,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11890,208,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11890,255,93.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11890,269,1.73,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11890,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11890,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11890,303,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11890,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11890,307,272,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11890,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11890,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11890,401,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11890,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11890,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11890,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11890,606,0.025,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11891,203,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11891,204,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11891,205,4.36,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11891,207,1.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11891,208,20,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11891,255,93.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11891,269,0.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11891,291,3.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11891,301,137,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11891,303,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11891,306,203,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11891,307,265,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11891,320,381,'100g',1,1,'2024-12-12','2002-01-12');
INSERT INTO `cndb_nutval` VALUES (11891,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11891,401,27.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11891,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11891,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11891,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11891,606,0.053,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11892,203,3.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11892,204,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11892,205,4.98,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11892,207,0.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11892,208,29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11892,255,90.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11892,269,0.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11892,291,3.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11892,301,152,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11892,303,1.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11892,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11892,307,251,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11892,320,538,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11892,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11892,401,21.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11892,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11892,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11892,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11892,606,0.099,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11893,203,2.99,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11893,204,0.38,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11893,205,4.74,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11893,207,0.85,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11893,208,34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11893,255,91.04,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11893,269,0.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11893,291,3.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11893,301,128,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11893,303,1.75,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11893,306,216,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11893,307,255,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11893,320,431,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11893,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11893,401,18.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11893,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11893,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11893,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11893,606,0.085,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11894,203,2.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11894,204,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11894,205,13.09,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11894,207,0.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11894,208,60,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11894,255,83.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11894,269,3.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11894,291,4.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11894,301,25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11894,303,0.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11894,306,169,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11894,307,271,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11894,320,214,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11894,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11894,401,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11894,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11894,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11894,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11894,606,0.031,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11895,203,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11895,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11895,205,2.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11895,207,0.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11895,208,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11895,255,96.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11895,269,1.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11895,291,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11895,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11895,303,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11895,306,5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11895,307,343,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11895,320,0,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (11895,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11895,401,10.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11895,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11895,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11895,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11895,606,0.016,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11896,203,5.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11896,204,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11896,205,3.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11896,207,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11896,208,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11896,255,90.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11896,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11896,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11896,301,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11896,303,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11896,306,274,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11896,307,240,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11896,320,4,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11896,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11896,401,9.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11896,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11896,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11896,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11896,606,0.101,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11897,203,1.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11897,204,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11897,205,26.99,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11897,207,1.25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11897,208,114,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11897,255,70.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11897,269,0.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11897,291,3.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11897,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11897,303,0.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11897,306,670,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11897,307,244,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11897,320,6,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11897,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11897,401,12.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11897,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11897,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11897,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11897,606,0.029,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11899,203,2.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11899,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11899,205,9.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11899,207,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11899,208,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11899,255,87.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11899,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11899,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11899,301,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11899,303,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11899,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11899,307,240,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11899,320,23,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11899,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11899,401,16.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11899,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11899,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11899,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11899,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11900,203,3.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11900,204,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11900,205,19.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11900,207,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11900,208,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11900,255,75.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11900,269,3.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11900,291,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11900,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11900,303,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11900,306,270,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11900,307,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11900,320,0,'100g',1,1,'2024-12-12','2004-01-07');
INSERT INTO `cndb_nutval` VALUES (11900,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11900,401,6.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11900,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11900,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11900,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11900,606,0.182,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11901,203,3.34,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11901,204,1.41,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11901,205,21.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11901,207,0.7,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11901,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11901,255,72.84,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11901,269,7.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11901,291,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11901,301,2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11901,303,0.55,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11901,306,252,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11901,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11901,320,0,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (11901,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11901,401,6.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11901,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11901,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11901,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11901,606,0.197,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11902,203,3.34,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11902,204,1.41,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11902,205,21.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11902,207,0.7,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11902,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11902,255,72.84,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11902,269,7.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11902,291,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11902,301,2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11902,303,0.55,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11902,306,252,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11902,307,253,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11902,320,0,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (11902,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11902,401,6.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11902,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11902,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11902,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11902,606,0.197,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11903,203,1.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11903,204,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11903,205,15.41,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11903,207,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11903,208,64,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11903,255,81.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11903,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11903,291,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11903,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11903,303,0.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11903,306,164,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11903,307,213,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11903,320,0,'100g',1,1,'2024-12-12','2006-01-01');
INSERT INTO `cndb_nutval` VALUES (11903,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11903,401,5.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11903,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11903,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11903,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11903,606,0.077,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11904,203,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11904,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11904,205,15.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11904,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11904,208,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11904,255,81.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11904,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11904,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11904,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11904,303,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11904,306,164,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11904,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11904,320,0,'100g',2,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (11904,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11904,401,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11904,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11904,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11904,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11904,606,0.077,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11905,203,2.29,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11905,204,1.22,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11905,205,14.34,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11905,207,0.75,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11905,208,67,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11905,255,81.41,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11905,269,4.44,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11905,291,2,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11905,301,3,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11905,303,0.27,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11905,306,132,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11905,307,205,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11905,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11905,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11905,401,1.8,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11905,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11905,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11905,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11905,606,0.245,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11906,203,1.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11906,204,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11906,205,18.62,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11906,207,0.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11906,208,74,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11906,255,78.24,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11906,269,6.09,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11906,291,1.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11906,301,4,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11906,303,0.31,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11906,306,119,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11906,307,261,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11906,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11906,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11906,401,4.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11906,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11906,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11906,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11906,606,0.065,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (11907,203,1.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11907,204,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11907,205,18.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11907,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11907,208,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11907,255,78.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11907,269,2.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11907,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11907,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11907,303,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11907,306,134,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11907,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11907,320,0,'100g',2,1,'2024-12-12','2010-01-03');
INSERT INTO `cndb_nutval` VALUES (11907,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11907,401,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11907,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11907,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11907,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11907,606,0.065,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11908,203,2.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11908,204,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11908,205,19.44,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11908,207,1.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11908,208,79,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11908,255,76.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11908,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11908,291,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11908,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11908,303,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11908,306,186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11908,307,272,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11908,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (11908,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11908,401,8.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11908,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11908,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11908,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11908,606,0.077,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11909,203,2.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11909,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11909,205,19.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11909,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11909,208,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11909,255,76.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11909,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11909,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11909,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11909,303,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11909,306,186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11909,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11909,320,0,'100g',2,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (11909,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11909,401,8.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11909,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11909,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11909,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11909,606,0.077,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11910,203,3.02,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11910,204,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11910,205,20.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11910,207,0.48,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11910,208,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11910,255,75,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11910,269,9.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11910,291,2.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11910,301,4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11910,303,0.41,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11910,306,213,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11910,307,3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11910,320,0,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (11910,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11910,401,6.3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11910,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11910,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11910,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11910,606,0.184,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11911,203,2.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11911,204,0.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11911,205,19.56,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11911,207,0.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11911,208,80,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11911,255,76.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11911,269,3.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11911,291,2.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11911,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11911,303,0.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11911,306,147,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11911,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11911,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11911,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11911,401,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11911,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11911,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11911,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11911,606,0.066,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11912,203,2.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11912,204,0.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11912,205,19.56,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11912,207,0.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11912,208,80,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11912,255,76.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11912,269,3.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11912,291,2.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11912,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11912,303,0.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11912,306,147,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11912,307,245,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11912,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11912,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11912,401,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11912,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11912,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11912,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11912,606,0.066,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11913,203,3.28,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11913,204,0.78,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11913,205,23.5,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11913,207,0.65,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11913,208,98,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11913,255,71.79,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11913,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11913,291,2.8,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11913,301,4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11913,303,0.68,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11913,306,294,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11913,307,5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11913,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (11913,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11913,401,7.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11913,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11913,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11913,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11913,606,0.12,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11914,203,3.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11914,204,0.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11914,205,22.33,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11914,207,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11914,208,94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11914,255,73.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11914,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11914,291,2.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11914,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11914,303,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11914,306,251,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11914,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11914,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (11914,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11914,401,4.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11914,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11914,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11914,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11914,606,0.114,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11915,203,3.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11915,204,0.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11915,205,22.33,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11915,207,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11915,208,94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11915,255,73.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11915,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11915,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11915,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11915,303,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11915,306,251,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11915,307,240,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11915,320,0,'100g',2,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (11915,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11915,401,4.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11915,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11915,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11915,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11915,606,0.114,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11916,203,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11916,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11916,205,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11916,207,3.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11916,208,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11916,255,91.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11916,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11916,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11916,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11916,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11916,306,146,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11916,307,1369,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11916,320,26,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11916,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11916,401,46.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11916,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11916,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11916,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11916,606,0.045,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11917,203,1.08,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11917,204,0.21,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11917,205,4.45,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11917,207,0.3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11917,208,20,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11917,255,93.96,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11917,269,3.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11917,291,1.6,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11917,301,9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11917,303,0.62,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11917,306,91,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11917,307,5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11917,320,121,'100g',2,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (11917,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11917,401,58.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11917,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11917,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11917,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11917,606,0.031,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11918,203,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11918,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11918,205,3.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11918,207,0.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11918,208,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11918,255,94.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11918,269,2.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11918,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11918,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11918,303,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11918,306,72,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11918,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11918,320,96,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (11918,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11918,401,41.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11918,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11918,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11918,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11918,606,0.027,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11919,203,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11919,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11919,205,3.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11919,207,0.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11919,208,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11919,255,94.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11919,269,2.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11919,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11919,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11919,303,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11919,306,72,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11919,307,240,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11919,320,96,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (11919,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11919,401,41.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11919,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11919,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11919,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11919,606,0.027,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11921,203,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11921,204,12.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11921,205,6.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11921,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11921,208,133,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11921,255,78.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11921,269,4.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11921,291,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11921,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11921,303,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11921,306,193,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11921,307,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11921,320,138,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11921,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11921,401,162.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11921,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11921,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11921,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11921,606,1.557,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11923,203,8.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11923,204,4.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11923,205,6.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11923,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11923,208,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11923,255,79.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11923,269,0.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11923,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11923,301,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11923,303,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11923,306,355,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11923,307,246,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11923,320,2,'100g',2,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (11923,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11923,401,8.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11923,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11923,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11923,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11923,606,0.617,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11926,203,8.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11926,204,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11926,205,21.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11926,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11926,208,101,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11926,255,68.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11926,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11926,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11926,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11926,303,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11926,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11926,307,246,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11926,320,2,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11926,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11926,401,12.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11926,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11926,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11926,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11926,606,0.053,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11927,203,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11927,204,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11927,205,19.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11927,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11927,208,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11927,255,77.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11927,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11927,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11927,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11927,303,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11927,306,495,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11927,307,248,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11927,320,0,'100g',1,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (11927,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11927,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11927,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11927,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11927,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11927,606,0.018,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11929,203,2.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11929,204,4.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11929,205,14.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11929,207,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11929,208,108,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11929,255,77.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11929,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11929,291,2.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11929,301,35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11929,303,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11929,306,145,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11929,307,263,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11929,320,44,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (11929,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11929,401,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11929,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11929,601,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11929,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11929,606,1.284,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11930,203,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11930,204,5.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11930,205,15.02,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11930,207,1.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11930,208,113,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11930,255,76.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11930,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11930,291,2.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11930,301,49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11930,303,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11930,306,233,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11930,307,332,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11930,320,46,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (11930,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11930,401,9.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11930,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11930,601,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11930,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11930,606,1.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11931,203,17.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11931,204,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11931,205,68.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11931,207,8.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11931,208,314,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11931,255,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11931,269,40.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11931,291,21.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11931,301,134,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11931,303,10.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11931,306,3170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11931,307,193,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11931,320,3863,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (11931,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11931,401,1900,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11931,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11931,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11931,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11931,606,0.447,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11932,203,1.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11932,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11932,205,4.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11932,207,0.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11932,208,20,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11932,255,93.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11932,269,0.78,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11932,291,1.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11932,301,26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11932,303,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11932,306,109,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11932,307,251,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11932,320,5,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (11932,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11932,401,4.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11932,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11932,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11932,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11932,606,0.022,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11933,203,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11933,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11933,205,4.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11933,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11933,208,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11933,255,93.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11933,269,0.78,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11933,291,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11933,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11933,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11933,306,109,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11933,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11933,320,18,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (11933,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11933,401,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11933,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11933,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11933,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11933,606,0.022,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11934,203,1.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11934,204,4.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11934,205,16.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11934,207,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11934,208,113,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11934,255,75.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11934,269,1.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11934,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11934,301,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11934,303,0.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11934,306,284,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11934,307,317,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11934,320,38,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (11934,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11934,401,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11934,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11934,601,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11934,605,0.149,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11934,606,2.613,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11935,203,1.04,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11935,204,0.1,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11935,205,27.4,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11935,207,2.94,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11935,208,101,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11935,255,68.51,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11935,269,21.27,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11935,291,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11935,301,15,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11935,303,0.35,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11935,306,281,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11935,307,907,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (11935,320,26,'100g',1,1,'2024-12-12','2014-01-08');
INSERT INTO `cndb_nutval` VALUES (11935,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11935,401,4.1,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (11935,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11935,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11935,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11935,606,0.014,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11936,203,2.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11936,204,0.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11936,205,4.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11936,207,0.98,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11936,208,22,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11936,255,92.12,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11936,269,1.72,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11936,291,0.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11936,301,18,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11936,303,0.4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11936,306,448,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11936,307,6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11936,320,0,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (11936,328,31.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11936,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11936,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11936,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11936,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (11936,606,0.014,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11937,203,0.5,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11937,204,0.3,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11937,205,2.41,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11937,207,2.45,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11937,208,12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11937,255,94.34,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11937,269,1.07,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11937,291,1,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11937,301,57,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11937,303,0.26,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11937,306,117,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11937,307,809,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11937,320,6,'100g',2,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (11937,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11937,401,2.3,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11937,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11937,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11937,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11937,606,0.079,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11938,203,3.09,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11938,204,0.34,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11938,205,3.26,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11938,207,0.85,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11938,208,22,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11938,255,92.45,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11938,269,1.98,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11938,291,1,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11938,301,3,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11938,303,0.5,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11938,306,318,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11938,307,5,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11938,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11938,328,26.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11938,401,2.1,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11938,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11938,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11938,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (11938,606,0.05,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11939,203,3.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11939,204,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11939,205,4.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11939,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11939,208,29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11939,255,90.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11939,269,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11939,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11939,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11939,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11939,306,437,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11939,307,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11939,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11939,328,13.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11939,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11939,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11939,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11939,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11939,606,0.028,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11940,203,0.58,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11940,204,0.41,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11940,205,21.15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11940,207,1.65,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11940,208,91,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11940,255,76.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11940,269,18.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11940,291,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11940,301,61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11940,303,0.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11940,306,100,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11940,307,457,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11940,320,38,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (11940,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11940,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11940,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11940,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11940,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11940,606,0.067,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11941,203,0.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11941,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11941,205,2.26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11941,207,3.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11941,208,11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11941,255,94.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11941,269,1.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11941,291,1.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11941,301,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11941,303,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11941,306,23,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11941,307,1208,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11941,320,10,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (11941,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11941,401,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11941,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11941,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11941,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11941,606,0.052,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11943,203,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11943,204,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11943,205,5.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11943,207,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11943,208,23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11943,255,93.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11943,269,2.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11943,291,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11943,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11943,303,1.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11943,306,158,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11943,307,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11943,320,133,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11943,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11943,401,84.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11943,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11943,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11943,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11943,606,0.045,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11944,203,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11944,204,0.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11944,205,23.35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11944,207,3.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11944,208,91,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11944,255,71.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11944,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11944,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11944,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11944,303,1.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11944,306,78,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11944,307,1091,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11944,320,8,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11944,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11944,401,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11944,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11944,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11944,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11944,606,0.044,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11945,203,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11945,204,0.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11945,205,35.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11945,207,2.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11945,208,130,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11945,255,62.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11945,269,29.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11945,291,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11945,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11945,303,0.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11945,306,25,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11945,307,811,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11945,320,61,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (11945,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11945,401,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11945,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11945,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11945,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11945,606,0.054,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11946,203,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11946,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11946,205,2.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11946,207,3.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11946,208,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11946,255,94.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11946,269,1.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11946,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11946,301,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11946,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11946,306,23,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11946,307,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11946,320,10,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (11946,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11946,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11946,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11946,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11946,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11946,606,0.052,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11947,203,0.5,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11947,204,0.3,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11947,205,2.41,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11947,207,2.45,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11947,208,12,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11947,255,94.34,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11947,269,1.07,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11947,291,1,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11947,301,57,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11947,303,0.26,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11947,306,117,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11947,307,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11947,320,6,'100g',2,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (11947,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11947,401,2.3,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11947,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11947,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11947,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11947,606,0.079,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11948,203,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11948,204,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11948,205,33.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11948,207,0.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11948,208,122,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11948,255,65.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11948,269,26.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11948,291,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11948,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11948,303,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11948,306,32,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11948,307,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11948,320,56,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (11948,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11948,401,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11948,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11948,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11948,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11948,606,0.067,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11949,203,1.04,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11949,204,0.1,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11949,205,27.4,'100g',3,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11949,207,2.94,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11949,208,101,'100g',3,1,'1994-11-14','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11949,255,68.51,'100g',1,1,'1994-11-14','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11949,269,21.27,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11949,291,0.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11949,301,15,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11949,303,0.35,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11949,306,281,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11949,307,20,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11949,320,26,'100g',1,1,'2024-12-12','2014-01-08');
INSERT INTO `cndb_nutval` VALUES (11949,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11949,401,4.1,'100g',1,1,'1994-11-14','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (11949,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11949,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11949,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11949,606,0.014,'100g',3,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11950,203,2.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11950,204,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11950,205,7.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11950,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11950,208,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11950,255,88.34,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11950,269,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11950,291,2.7,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11950,301,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11950,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11950,306,359,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11950,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11950,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (11950,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11950,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11950,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11950,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11950,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11950,606,0.027,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11951,203,1,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11951,204,0.21,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11951,205,6.32,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11951,207,0.45,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11951,208,27,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11951,255,92.02,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11951,269,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11951,291,0.9,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11951,301,11,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11951,303,0.46,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11951,306,212,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11951,307,2,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11951,320,10,'100g',1,1,'2024-12-12','2003-01-07');
INSERT INTO `cndb_nutval` VALUES (11951,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11951,401,183.5,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11951,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11951,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11951,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11951,606,0.031,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11952,203,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11952,204,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11952,205,4.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11952,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11952,208,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11952,255,93.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11952,269,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11952,291,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11952,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11952,303,0.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11952,306,302,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11952,307,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11952,320,1,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (11952,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11952,401,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11952,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11952,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11952,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11952,606,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11953,203,2.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11953,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11953,205,3.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11953,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11953,208,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11953,255,92.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11953,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11953,291,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11953,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11953,303,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11953,306,459,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11953,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11953,320,25,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11953,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11953,401,34.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11953,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11953,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11953,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11953,606,0.083,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11954,203,0.96,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11954,204,1.02,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11954,205,5.84,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11954,207,0.55,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11954,208,32,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11954,255,91.63,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11954,269,3.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11954,291,1.9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11954,301,7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11954,303,0.62,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11954,306,268,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11954,307,1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11954,320,6,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11954,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11954,401,11.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11954,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11954,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11954,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11954,606,0.139,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11955,203,14.11,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11955,204,2.97,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11955,205,55.76,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11955,207,12.6,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11955,208,258,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11955,255,14.56,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11955,269,37.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11955,291,12.3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11955,301,110,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11955,303,9.09,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11955,306,3427,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11955,307,107,'100g',6,1,'1996-09-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11955,320,44,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11955,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11955,401,39.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11955,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11955,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11955,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11955,606,0.426,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11956,203,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11956,204,14.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11956,205,23.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11956,207,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11956,208,213,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11956,255,53.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11956,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11956,291,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11956,301,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11956,303,2.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11956,306,1565,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11956,307,266,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11956,320,64,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11956,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11956,401,101.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11956,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11956,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11956,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11956,606,1.893,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11957,203,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11957,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11957,205,7.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11957,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11957,208,31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11957,255,90.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11957,269,3.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11957,291,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11957,301,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11957,303,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11957,306,414,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11957,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11957,320,48,'100g',2,1,'2024-12-12','2012-01-11');
INSERT INTO `cndb_nutval` VALUES (11957,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11957,401,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11957,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11957,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11957,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11957,606,0.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11958,203,0.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11958,204,0.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11958,205,34.48,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11958,207,3.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11958,208,129,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11958,255,61.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11958,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11958,291,3.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11958,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11958,303,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11958,306,76,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11958,307,1096,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11958,320,13,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11958,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11958,401,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11958,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11958,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11958,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11958,606,0.052,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11959,203,2.58,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11959,204,0.66,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11959,205,3.65,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11959,207,1.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11959,208,25,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11959,255,91.71,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11959,269,2.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11959,291,1.6,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11959,301,160,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11959,303,1.46,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11959,306,369,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11959,307,27,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11959,320,119,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (11959,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11959,401,15,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11959,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11959,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11959,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11959,606,0.086,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11960,203,0.64,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11960,204,0.13,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11960,205,8.24,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11960,207,0.63,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11960,208,35,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11960,255,90.35,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11960,269,4.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11960,291,2.9,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11960,301,32,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11960,303,0.89,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11960,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11960,307,78,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11960,320,690,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (11960,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11960,401,2.6,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11960,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11960,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11960,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11960,606,0.023,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11961,203,2.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11961,204,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11961,205,4.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11961,207,2.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11961,208,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11961,255,90.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11961,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11961,291,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11961,301,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11961,303,3.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11961,306,177,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11961,307,426,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11961,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11961,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11961,401,7.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11961,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11961,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11961,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11961,606,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11962,203,10.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11962,204,5.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11962,205,69.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11962,207,6.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11962,208,324,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11962,255,7.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11962,269,41.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11962,291,28.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11962,301,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11962,303,6.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11962,306,1870,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11962,307,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11962,320,1324,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11962,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11962,401,31.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11962,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11962,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11962,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11962,606,0.813,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11963,203,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11963,204,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11963,205,3.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11963,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11963,208,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11963,255,94.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11963,269,1.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11963,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11963,301,164,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11963,303,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11963,306,257,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11963,307,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11963,320,23,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11963,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11963,401,9.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11963,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11963,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11963,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11963,606,0.016,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11964,203,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11964,204,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11964,205,3.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11964,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11964,208,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11964,255,94.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11964,269,1.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11964,291,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11964,301,164,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11964,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11964,306,195,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11964,307,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11964,320,22,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11964,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11964,401,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11964,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11964,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11964,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11964,606,0.006,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11965,203,2.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11965,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11965,205,6.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11965,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11965,208,31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11965,255,89.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11965,269,3.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11965,291,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11965,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11965,303,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11965,306,300,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11965,307,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11965,320,8,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (11965,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11965,401,88.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11965,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11965,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11965,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11965,606,0.047,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11967,203,3.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11967,204,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11967,205,6.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11967,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11967,208,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11967,255,89.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11967,269,3.12,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11967,291,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11967,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11967,303,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11967,306,278,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11967,307,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11967,320,7,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (11967,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11967,401,72.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11967,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11967,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11967,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11967,606,0.043,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11968,203,3.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11968,204,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11968,205,6.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11968,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11968,208,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11968,255,89.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11968,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11968,291,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11968,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11968,303,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11968,306,278,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11968,307,259,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11968,320,7,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (11968,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11968,401,72.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11968,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11968,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11968,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11968,606,0.049,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11969,203,1.14,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11969,204,0.72,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11969,205,3.81,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11969,207,0.79,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11969,208,22,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11969,255,93.54,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11969,269,0.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11969,291,2.5,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11969,301,100,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11969,303,0.56,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11969,306,261,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11969,307,7,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11969,320,82,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (11969,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11969,401,28.2,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11969,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11969,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11969,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11969,606,0.11,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11972,203,1.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11972,204,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11972,205,25.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11972,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11972,208,99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11972,255,70.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11972,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11972,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11972,301,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11972,303,8.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11972,306,723,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11972,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11972,320,0,'100g',1,1,'2024-12-12','2004-01-02');
INSERT INTO `cndb_nutval` VALUES (11972,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11972,401,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11972,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11972,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11972,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11972,606,0.119,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11973,203,7.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11973,204,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11973,205,17.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11973,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11973,208,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11973,255,72.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11973,269,9.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11973,291,7.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11973,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11973,303,1.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11973,306,332,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11973,307,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11973,320,17,'100g',1,1,'2024-12-12','2003-01-06');
INSERT INTO `cndb_nutval` VALUES (11973,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11973,401,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11973,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11973,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11973,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11973,606,0.118,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11974,203,5.6,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11974,204,2.12,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11974,205,17.31,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11974,207,1.65,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11974,208,93,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11974,255,73.32,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11974,269,6.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11974,291,11,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11974,301,363,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11974,303,2.63,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11974,306,272,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11974,307,9,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11974,320,1376,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11974,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11974,401,11.1,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11974,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11974,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11974,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11974,606,0.336,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11975,203,4.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11975,204,1.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11975,205,11.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11975,207,5.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11975,208,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11975,255,76.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11975,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11975,291,9.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11975,301,289,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11975,303,2.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11975,306,29,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11975,307,2853,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11975,320,263,'100g',1,1,'2024-12-12','2003-01-07');
INSERT INTO `cndb_nutval` VALUES (11975,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11975,401,11.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11975,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11975,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11975,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11975,606,0.312,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11976,203,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11976,204,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11976,205,5.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11976,207,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11976,208,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11976,255,91.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11976,269,1.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11976,291,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11976,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11976,303,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11976,306,256,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11976,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11976,320,17,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11976,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11976,401,82.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11976,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11976,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11976,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11976,606,0.048,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11977,203,1.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11977,204,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11977,205,6.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11977,207,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11977,208,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11977,255,90.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11977,269,3.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11977,291,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11977,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11977,303,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11977,306,305,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11977,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11977,320,47,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11977,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11977,401,44.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11977,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11977,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11977,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11977,606,0.059,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11978,203,11.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11978,204,8.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11978,205,51.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11978,207,5.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11978,208,281,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11978,255,22.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11978,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11978,291,21.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11978,301,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11978,303,10.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11978,306,2411,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11978,307,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11978,320,1022,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11978,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11978,401,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11978,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11978,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11978,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11978,606,0.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11979,203,0.91,'100g',1,1,'1998-04-03','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11979,204,0.37,'100g',1,1,'1998-04-03','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11979,205,6.5,'100g',3,1,'1998-04-03','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11979,207,0.53,'100g',1,1,'1998-04-03','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11979,208,29,'100g',3,1,'1998-04-03','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11979,255,91.69,'100g',7,1,'1998-04-03','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11979,269,4.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11979,291,2.8,'100g',7,1,'1998-04-03','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11979,301,12,'100g',1,1,'1998-04-03','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11979,303,0.25,'100g',1,1,'1998-04-03','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11979,306,248,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11979,307,3,'100g',1,1,'1998-04-03','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11979,320,54,'100g',1,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (11979,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11979,401,118.6,'100g',1,1,'1998-04-03','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (11979,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11979,601,0,'100g',4,1,'1998-04-03','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11979,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11979,606,0.092,'100g',3,1,'1998-04-03','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11980,203,0.72,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11980,204,0.27,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11980,205,4.6,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11980,207,1.31,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11980,208,21,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11980,255,93.25,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11980,269,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11980,291,1.7,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11980,301,36,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11980,303,1.33,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11980,306,113,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11980,307,397,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11980,320,6,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (11980,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11980,401,34.2,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11980,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11980,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11980,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11980,606,0.028,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11981,203,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11981,204,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11981,205,6.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11981,207,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11981,208,29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11981,255,91.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11981,269,3.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11981,291,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11981,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11981,303,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11981,306,202,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11981,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11981,320,41,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (11981,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11981,401,92.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11981,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11981,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11981,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11981,606,0.046,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11983,203,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11983,204,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11983,205,26.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11983,207,2.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11983,208,121,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11983,255,68.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11983,269,23.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11983,291,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11983,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11983,303,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11983,306,200,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11983,307,527,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11983,320,5,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (11983,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11983,401,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11983,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (11983,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11983,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11983,606,0.149,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (11987,203,3.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11987,204,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11987,205,6.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11987,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11987,208,33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11987,255,89.18,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11987,269,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11987,291,2.3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11987,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11987,303,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11987,306,420,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11987,307,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11987,320,2,'100g',1,1,'2024-12-12','2010-01-02');
INSERT INTO `cndb_nutval` VALUES (11987,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11987,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11987,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11987,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11987,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11987,606,0.062,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (11989,203,3.83,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11989,204,0.68,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11989,205,4.64,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11989,207,0.97,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11989,208,32,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11989,255,89.88,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11989,269,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11989,291,2.5,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11989,301,10,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11989,303,1.43,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11989,306,78,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11989,307,384,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11989,320,0,'100g',1,1,'2024-12-12','2003-01-07');
INSERT INTO `cndb_nutval` VALUES (11989,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11989,401,0,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11989,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11989,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11989,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11989,606,0.089,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11991,203,1.46,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11991,204,0.4,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11991,205,23.63,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11991,207,1.45,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11991,208,98,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11991,255,73.06,'100g',7,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11991,269,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (11991,291,1.5,'100g',7,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11991,301,9,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11991,303,0.98,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11991,306,598,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11991,307,21,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11991,320,0,'100g',1,1,'2024-12-12','2003-01-07');
INSERT INTO `cndb_nutval` VALUES (11991,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11991,401,5.2,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11991,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11991,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11991,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11991,606,0.082,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (11992,203,3.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11992,204,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11992,205,6.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11992,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11992,208,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11992,255,88.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11992,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11992,291,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11992,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11992,303,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11992,306,488,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11992,307,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11992,320,0,'100g',1,1,'2024-12-12','2009-01-08');
INSERT INTO `cndb_nutval` VALUES (11992,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11992,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11992,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11992,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11992,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11992,606,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11993,203,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11993,204,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11993,205,6.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11993,207,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11993,208,31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11993,255,90.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11993,269,2.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11993,291,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11993,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11993,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11993,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11993,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11993,320,0,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (11993,328,28.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11993,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11993,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11993,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11993,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (11993,606,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11994,203,1.2,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11994,204,0.76,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11994,205,4.67,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11994,207,0.83,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11994,208,26,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11994,255,92.55,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11994,269,0.88,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11994,291,2.6,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11994,301,105,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11994,303,0.59,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11994,306,274,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11994,307,7,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11994,320,86,'100g',2,1,'2024-12-12','2015-01-01');
INSERT INTO `cndb_nutval` VALUES (11994,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11994,401,29.6,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11994,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11994,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11994,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (11994,606,0.116,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (11998,203,2.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11998,204,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11998,205,3.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11998,207,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11998,208,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11998,255,92.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11998,269,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11998,291,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11998,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11998,303,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11998,306,364,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11998,307,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11998,320,0,'100g',3,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (11998,328,28.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (11998,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11998,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (11998,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (11998,605,0.004,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (11998,606,0.06,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12001,203,7.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12001,204,5.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12001,205,29.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12001,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12001,208,191,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12001,255,56.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12001,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12001,291,5.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12001,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12001,303,3.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12001,306,941,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12001,307,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12001,320,13,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12001,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12001,401,6.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12001,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12001,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12001,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12001,606,1.509,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12003,203,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12003,204,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12003,205,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12003,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12003,208,168,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12003,255,59.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12003,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12003,291,4.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12003,301,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12003,303,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12003,306,875,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12003,307,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12003,320,12,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12003,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12003,401,6.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12003,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12003,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12003,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12003,606,0.621,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12004,203,5.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12004,204,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12004,205,46.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12004,207,1.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12004,208,217,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12004,255,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12004,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12004,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12004,301,98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12004,303,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12004,306,1183,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12004,307,31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12004,320,12,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12004,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12004,401,27.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12004,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12004,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12004,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12004,606,0.267,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12005,203,8.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12005,204,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12005,205,79.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12005,207,3.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12005,208,367,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12005,255,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12005,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12005,291,14.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12005,301,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12005,303,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12005,306,2011,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12005,307,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12005,320,11,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12005,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12005,401,46.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12005,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12005,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12005,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12005,606,0.454,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12006,203,16.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12006,204,30.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12006,205,42.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12006,207,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12006,208,486,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12006,255,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12006,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12006,291,34.4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12006,301,631,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12006,303,7.72,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12006,306,407,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12006,307,16,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12006,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (12006,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12006,401,1.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12006,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12006,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12006,605,0.14,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12006,606,3.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12007,203,40.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12007,204,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12007,205,40.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12007,207,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12007,208,359,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12007,255,6.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12007,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12007,291,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12007,301,478,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12007,303,12.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12007,306,1772,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12007,307,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12007,320,22,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12007,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12007,401,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12007,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12007,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12007,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12007,606,1.588,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12008,203,49.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12008,204,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12008,205,36.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12008,207,5.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12008,208,332,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12008,255,6.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12008,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12008,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12008,301,474,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12008,303,12.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12008,306,1761,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12008,307,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12008,320,22,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12008,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12008,401,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12008,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12008,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12008,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12008,606,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12011,203,49.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12011,204,4.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12011,205,38.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12011,207,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12011,208,367,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12011,255,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12011,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12011,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12011,301,504,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12011,303,13.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12011,306,1869,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12011,307,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12011,320,23,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12011,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12011,401,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12011,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12011,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12011,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12011,606,1.207,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12012,203,31.56,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12012,204,48.75,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12012,205,8.67,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12012,207,6.06,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12012,208,553,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12012,255,4.96,'100g',7,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12012,269,1.5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12012,291,4,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12012,301,70,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12012,303,7.95,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12012,306,1200,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12012,307,5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12012,320,1,'100g',2,1,'2024-12-12','2015-01-01');
INSERT INTO `cndb_nutval` VALUES (12012,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12012,401,0.5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12012,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12012,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12012,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12012,606,4.6,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12013,203,15.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12013,204,1.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12013,205,64.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12013,207,3.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12013,208,332,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12013,255,14.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12013,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12013,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12013,301,163,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12013,303,3.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12013,306,1368,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12013,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12013,320,3,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12013,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12013,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12013,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12013,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12013,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12013,606,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12014,203,30.23,'100g',1,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12014,204,49.05,'100g',1,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12014,205,10.71,'100g',3,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12014,207,4.78,'100g',1,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12014,208,559,'100g',3,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12014,255,5.23,'100g',1,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12014,269,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12014,291,6,'100g',1,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12014,301,46,'100g',1,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12014,303,8.82,'100g',1,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12014,306,809,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12014,307,7,'100g',1,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12014,320,1,'100g',1,1,'2024-12-12','2008-01-12');
INSERT INTO `cndb_nutval` VALUES (12014,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12014,401,1.9,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12014,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12014,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12014,605,0.064,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12014,606,8.659,'100g',3,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12016,203,29.84,'100g',1,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12016,204,49.05,'100g',1,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12016,205,14.71,'100g',3,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12016,207,4.37,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12016,208,574,'100g',3,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12016,255,2.03,'100g',1,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12016,269,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12016,291,6.5,'100g',1,1,'1994-11-22','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12016,301,52,'100g',1,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12016,303,8.07,'100g',1,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12016,306,788,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12016,307,18,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12016,320,0,'100g',1,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (12016,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12016,401,1.8,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12016,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12016,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12016,605,0.042,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12016,606,8.544,'100g',3,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12021,203,16.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12021,204,38.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12021,205,34.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12021,207,5.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12021,208,517,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12021,255,5.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12021,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12021,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12021,301,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12021,303,4.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12021,306,687,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12021,307,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12021,320,3,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12021,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12021,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12021,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12021,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12021,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12021,606,3.682,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12022,203,35.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12022,204,2.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12022,205,48.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12022,207,6.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12022,208,342,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12022,255,6.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12022,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12022,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12022,301,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12022,303,4.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12022,306,68,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12022,307,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12022,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12022,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12022,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12022,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12022,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12022,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12022,606,0.207,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12023,203,17.73,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12023,204,49.67,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12023,205,23.45,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12023,207,4.45,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12023,208,573,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12023,255,4.69,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12023,269,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12023,291,11.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12023,301,975,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12023,303,14.55,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12023,306,468,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12023,307,11,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12023,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (12023,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12023,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12023,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12023,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12023,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12023,606,6.957,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12024,203,16.96,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12024,204,48,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12024,205,25.74,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12024,207,6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12024,208,565,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12024,255,3.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12024,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12024,291,14,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12024,301,989,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12024,303,14.76,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12024,306,475,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12024,307,11,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12024,320,0,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (12024,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12024,401,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12024,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12024,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12024,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12024,606,6.722,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12029,203,16.96,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12029,204,48,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12029,205,26.04,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12029,207,4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12029,208,567,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12029,255,5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12029,269,0.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12029,291,16.9,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12029,301,131,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12029,303,7.78,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12029,306,406,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12029,307,39,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12029,320,3,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (12029,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12029,401,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12029,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12029,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12029,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12029,606,6.722,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12032,203,40.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12032,204,11.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12032,205,35.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12032,207,6.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12032,208,382,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12032,255,6.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12032,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12032,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12032,301,150,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12032,303,14.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12032,306,425,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12032,307,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12032,320,3,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12032,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12032,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12032,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12032,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12032,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12032,606,1.634,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12033,203,50.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12033,204,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12033,205,35.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12033,207,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12033,208,333,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12033,255,7.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12033,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12033,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12033,301,149,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12033,303,14.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12033,306,397,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12033,307,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12033,320,3,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12033,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12033,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12033,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12033,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12033,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12033,606,0.201,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12034,203,16.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12034,204,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12034,205,26.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12034,207,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12034,208,567,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12034,255,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12034,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12034,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12034,301,153,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12034,303,14.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12034,306,406,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12034,307,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12034,320,3,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12034,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12034,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12034,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12034,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12034,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12034,606,6.722,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12036,203,20.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12036,204,51.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12036,205,20,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12036,207,3.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12036,208,584,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12036,255,4.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12036,269,2.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12036,291,8.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12036,301,78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12036,303,5.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12036,306,645,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12036,307,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12036,320,3,'100g',2,1,'2024-12-12','2008-01-11');
INSERT INTO `cndb_nutval` VALUES (12036,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12036,401,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12036,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12036,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12036,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12036,606,4.455,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12037,203,19.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12037,204,49.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12037,205,24.07,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12037,207,5.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12037,208,582,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12037,255,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12037,269,2.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12037,291,11.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12037,301,70,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12037,303,3.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12037,306,850,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12037,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12037,320,0,'100g',2,1,'2024-12-12','2004-01-05');
INSERT INTO `cndb_nutval` VALUES (12037,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12037,401,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12037,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12037,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12037,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12037,606,5.219,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12038,203,20.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12038,204,51.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12038,205,22.89,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12038,207,4.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12038,208,592,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12038,255,1.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12038,269,3.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12038,291,10.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12038,301,87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12038,303,4.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12038,306,483,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12038,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12038,320,0,'100g',1,1,'2024-12-12','2004-01-05');
INSERT INTO `cndb_nutval` VALUES (12038,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12038,401,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12038,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12038,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12038,605,0.158,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12038,606,7.068,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12039,203,17.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12039,204,56.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12039,205,20.59,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12039,207,4.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12039,208,619,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12039,255,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12039,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12039,291,11.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12039,301,57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12039,303,6.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12039,306,491,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12039,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12039,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12039,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12039,401,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12039,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12039,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12039,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12039,606,5.953,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12040,203,17.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12040,204,55.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12040,205,23.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12040,207,3.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12040,208,617,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12040,255,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12040,269,10.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12040,291,5.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12040,301,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12040,303,4.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12040,306,576,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12040,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12040,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (12040,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12040,401,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12040,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12040,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12040,605,0.027,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12040,606,4.678,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12041,203,48.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12041,204,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12041,205,35.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12041,207,7.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12041,208,326,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12041,255,7.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12041,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12041,291,5.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12041,301,114,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12041,303,6.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12041,306,67,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12041,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12041,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12041,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12041,401,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12041,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12041,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12041,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12041,606,0.138,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12058,203,6.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12058,204,23.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12058,205,40.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12058,207,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12058,208,387,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12058,255,27.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12058,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12058,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12058,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12058,303,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12058,306,539,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12058,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12058,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12058,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12058,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12058,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12058,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12058,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12058,606,3.102,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12059,203,8.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12059,204,31.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12059,205,53.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12059,207,1.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12059,208,509,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12059,255,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12059,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12059,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12059,301,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12059,303,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12059,306,709,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12059,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12059,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12059,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12059,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12059,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12059,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12059,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12059,606,4.084,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12060,203,7.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12060,204,30.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12060,205,54.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12060,207,1.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12060,208,501,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12060,255,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12060,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12060,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12060,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12060,303,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12060,306,712,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12060,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12060,320,3,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12060,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12060,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12060,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12060,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12060,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12060,606,3.923,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12061,203,21.15,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12061,204,49.93,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12061,205,21.55,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12061,207,2.97,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12061,208,579,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12061,255,4.41,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12061,269,4.35,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12061,291,12.5,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12061,301,269,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12061,303,3.71,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12061,306,733,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12061,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12061,320,0,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (12061,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12061,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12061,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12061,601,0,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (12061,605,0.015,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12061,606,3.802,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12062,203,21.4,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12062,204,52.52,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12062,205,18.67,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12062,207,2.91,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12062,208,590,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12062,255,4.51,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12062,269,4.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12062,291,9.9,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12062,301,236,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12062,303,3.28,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12062,306,659,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12062,307,19,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12062,320,0,'100g',1,1,'2024-12-12','2010-01-03');
INSERT INTO `cndb_nutval` VALUES (12062,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12062,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12062,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12062,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12062,605,0.019,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12062,606,3.953,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12063,203,20.96,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12063,204,52.54,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12063,205,21.01,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12063,207,3.07,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12063,208,598,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12063,255,2.41,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12063,269,4.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12063,291,10.9,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12063,301,268,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12063,303,3.73,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12063,306,713,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12063,307,3,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12063,320,0,'100g',1,1,'2024-12-12','2010-01-03');
INSERT INTO `cndb_nutval` VALUES (12063,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12063,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12063,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12063,601,0,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (12063,605,0.007,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12063,606,4.092,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12065,203,21.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12065,204,55.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12065,205,17.68,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12065,207,3.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12065,208,607,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12065,255,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12065,269,4.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12065,291,10.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12065,301,291,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12065,303,3.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12065,306,699,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12065,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12065,320,0,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (12065,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12065,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12065,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12065,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12065,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12065,606,4.208,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12071,203,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12071,204,27.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12071,205,47.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12071,207,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12071,208,458,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12071,255,14.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12071,269,36.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12071,291,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12071,301,172,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12071,303,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12071,306,314,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12071,307,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12071,320,0,'100g',1,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (12071,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12071,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12071,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12071,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12071,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12071,606,2.629,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12077,203,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12077,204,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12077,205,33.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12077,207,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12077,208,576,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12077,255,6.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12077,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12077,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12077,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12077,303,2.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12077,306,1017,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12077,307,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12077,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12077,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12077,401,15.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12077,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12077,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12077,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12077,606,5.719,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12078,203,14.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12078,204,67.1,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12078,205,11.74,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12078,207,3.43,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12078,208,659,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12078,255,3.42,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12078,269,2.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12078,291,7.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12078,301,160,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12078,303,2.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12078,306,659,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12078,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12078,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (12078,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12078,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12078,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12078,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12078,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12078,606,16.134,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12084,203,24.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12084,204,56.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12084,205,12.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12084,207,2.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12084,208,612,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12084,255,3.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12084,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12084,291,4.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12084,301,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12084,303,4.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12084,306,421,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12084,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12084,320,6,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12084,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12084,401,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12084,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12084,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12084,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12084,606,1.306,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12085,203,15.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12085,204,46.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12085,205,32.69,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12085,207,3.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12085,208,574,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12085,255,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12085,269,5.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12085,291,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12085,301,45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12085,303,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12085,306,565,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12085,307,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12085,320,0,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (12085,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12085,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12085,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12085,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12085,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12085,606,9.157,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12086,203,16.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12086,204,47.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12086,205,29.87,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12086,207,2.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12086,208,580,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12086,255,3.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12086,269,5.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12086,291,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12086,301,43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12086,303,6.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12086,306,632,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12086,307,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12086,320,0,'100g',1,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (12086,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12086,401,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12086,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12086,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12086,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12086,606,8.478,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12087,203,18.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12087,204,43.85,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12087,205,30.19,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12087,207,2.54,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12087,208,553,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12087,255,5.2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12087,269,5.91,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12087,291,3.3,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12087,301,37,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12087,303,6.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12087,306,660,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12087,307,12,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12087,320,0,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (12087,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12087,401,0.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12087,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12087,601,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12087,605,NULL,'100g',NULL,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12087,606,7.783,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12088,203,17.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12088,204,49.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12088,205,27.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12088,207,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12088,208,587,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12088,255,2.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12088,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12088,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12088,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12088,303,5.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12088,306,546,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12088,307,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12088,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12088,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12088,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12088,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12088,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12088,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12088,606,9.763,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12093,203,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12093,204,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12093,205,49.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12093,207,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12093,208,224,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12093,255,43.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12093,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12093,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12093,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12093,303,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12093,306,447,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12093,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12093,320,10,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12093,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12093,401,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12093,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12093,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12093,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12093,606,0.164,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12094,203,6.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12094,204,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12094,205,79.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12094,207,2.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12094,208,363,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12094,255,8.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12094,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12094,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12094,301,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12094,303,2.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12094,306,726,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12094,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12094,320,16,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12094,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12094,401,58.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12094,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12094,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12094,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12094,606,0.266,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12095,203,2.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12095,204,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12095,205,33.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12095,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12095,208,153,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12095,255,61.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12095,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12095,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12095,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12095,303,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12095,306,306,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12095,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12095,320,7,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12095,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12095,401,24.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12095,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12095,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12095,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12095,606,0.112,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12096,203,4.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12096,204,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12096,205,52.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12096,207,1.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12096,208,239,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12096,255,40.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12096,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12096,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12096,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12096,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12096,306,477,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12096,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12096,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12096,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12096,401,38.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12096,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12096,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12096,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12096,606,0.175,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12097,203,2.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12097,204,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12097,205,45.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12097,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12097,208,213,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12097,255,48.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12097,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12097,291,8.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12097,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12097,303,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12097,306,518,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12097,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12097,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12097,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12097,401,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12097,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12097,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12097,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12097,606,0.425,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12098,203,1.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12098,204,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12098,205,44.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12098,207,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12098,208,196,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12098,255,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12098,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12098,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12098,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12098,303,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12098,306,484,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12098,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12098,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12098,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12098,401,40.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12098,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12098,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12098,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12098,606,0.235,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12099,203,6.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12099,204,4.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12099,205,77.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12099,207,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12099,208,374,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12099,255,9.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12099,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12099,291,11.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12099,301,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12099,303,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12099,306,986,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12099,307,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12099,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12099,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12099,401,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12099,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12099,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12099,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12099,606,0.837,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12100,203,5.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12100,204,3.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12100,205,78.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12100,207,3.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12100,208,369,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12100,255,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12100,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12100,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12100,301,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12100,303,2.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12100,306,991,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12100,307,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12100,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12100,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12100,401,15.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12100,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12100,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12100,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12100,606,0.736,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12101,203,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12101,204,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12101,205,27.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12101,207,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12101,208,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12101,255,68.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12101,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12101,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12101,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12101,303,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12101,306,715,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12101,307,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12101,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12101,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12101,401,26.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12101,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12101,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12101,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12101,606,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12104,203,3.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12104,204,33.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12104,205,15.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12104,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12104,208,354,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12104,255,46.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12104,269,6.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12104,291,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12104,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12104,303,2.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12104,306,356,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12104,307,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12104,320,0,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (12104,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12104,401,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12104,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12104,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12104,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12104,606,29.698,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12108,203,6.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12108,204,64.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12108,205,23.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12108,207,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12108,208,660,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12108,255,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12108,269,7.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12108,291,16.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12108,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12108,303,3.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12108,306,543,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12108,307,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12108,320,0,'100g',1,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (12108,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12108,401,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12108,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12108,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12108,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12108,606,57.218,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12109,203,3.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12109,204,27.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12109,205,51.85,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12109,207,1.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12109,208,456,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12109,255,15.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12109,269,36.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12109,291,9.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12109,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12109,303,1.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12109,306,361,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12109,307,285,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12109,320,0,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (12109,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12109,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12109,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (12109,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12109,605,0.002,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12109,606,26.396,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12110,203,3.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12110,204,31.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12110,205,40.91,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12110,207,0.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12110,208,443,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12110,255,23.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12110,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12110,291,4.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12110,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12110,303,1.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12110,306,324,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12110,307,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12110,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12110,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12110,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12110,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (12110,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12110,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12110,606,28.101,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12114,203,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12114,204,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12114,205,44.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12114,207,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12114,208,592,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12114,255,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12114,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12114,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12114,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12114,303,3.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12114,306,554,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12114,307,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12114,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12114,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12114,401,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12114,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12114,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12114,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12114,606,41.678,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12115,203,3.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12115,204,34.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12115,205,6.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12115,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12115,208,330,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12115,255,53.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12115,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12115,291,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12115,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12115,303,2.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12115,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12115,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12115,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12115,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12115,401,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12115,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12115,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12115,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12115,606,30.753,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12116,203,1.17,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12116,204,16.31,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12116,205,53.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12116,207,0.34,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12116,208,357,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12116,255,28.97,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12116,269,51.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12116,291,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12116,301,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12116,303,0.13,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12116,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12116,307,36,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12116,320,0,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (12116,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12116,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12116,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (12116,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12116,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12116,606,15.472,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12117,203,2.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12117,204,23.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12117,205,5.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12117,207,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12117,208,230,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12117,255,67.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12117,269,3.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12117,291,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12117,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12117,303,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12117,306,263,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12117,307,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12117,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (12117,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12117,401,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12117,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (12117,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12117,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12117,606,21.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12118,203,2.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12118,204,21.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12118,205,2.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12118,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12118,208,197,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12118,255,72.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12118,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12118,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12118,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12118,303,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12118,306,220,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12118,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12118,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (12118,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12118,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12118,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (12118,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12118,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12118,606,18.915,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12119,203,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12119,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12119,205,3.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12119,207,0.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12119,208,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12119,255,94.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12119,269,2.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12119,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12119,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12119,303,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12119,306,250,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12119,307,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12119,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (12119,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12119,401,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12119,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (12119,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12119,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12119,606,0.176,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12120,203,14.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12120,204,60.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12120,205,16.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12120,207,2.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12120,208,628,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12120,255,5.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12120,269,4.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12120,291,9.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12120,301,114,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12120,303,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12120,306,680,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12120,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12120,320,1,'100g',1,1,'2024-12-12','2002-01-12');
INSERT INTO `cndb_nutval` VALUES (12120,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12120,401,6.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12120,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12120,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12120,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12120,606,4.464,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12121,203,13.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12121,204,61.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12121,205,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12121,207,2.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12121,208,629,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12121,255,5.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12121,269,3.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12121,291,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12121,301,149,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12121,303,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12121,306,658,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12121,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12121,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12121,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12121,401,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12121,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12121,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12121,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12121,606,4.669,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12122,203,15.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12122,204,62.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12122,205,17.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12122,207,2.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12122,208,646,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12122,255,2.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12122,269,4.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12122,291,9.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12122,301,123,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12122,303,4.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12122,306,755,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12122,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12122,320,3,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12122,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12122,401,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12122,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12122,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12122,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12122,606,4.511,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12127,203,4.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12127,204,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12127,205,37.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12127,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12127,208,182,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12127,255,55.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12127,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12127,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12127,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12127,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12127,306,510,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12127,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12127,320,28,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12127,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12127,401,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12127,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12127,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12127,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12127,606,0.319,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12128,203,10.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12128,204,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12128,205,72.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12128,207,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12128,208,348,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12128,255,12.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12128,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12128,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12128,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12128,303,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12128,306,998,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12128,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12128,320,55,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12128,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12128,401,29.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12128,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12128,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12128,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12128,606,0.381,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12129,203,2.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12129,204,1.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12129,205,22.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12129,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12129,208,111,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12129,255,72.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12129,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12129,291,9.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12129,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12129,303,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12129,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12129,307,307,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12129,320,17,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12129,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12129,401,9.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12129,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12129,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12129,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12129,606,0.309,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12130,203,12.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12130,204,64.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12130,205,18.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12130,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12130,208,657,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12130,255,2.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12130,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12130,291,6.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12130,301,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12130,303,2.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12130,306,436,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12130,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12130,320,7,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12130,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12130,401,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12130,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12130,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12130,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12130,606,7.038,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12131,203,7.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12131,204,75.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12131,205,13.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12131,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12131,208,718,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12131,255,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12131,269,4.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12131,291,8.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12131,301,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12131,303,3.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12131,306,368,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12131,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12131,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12131,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12131,401,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12131,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12131,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12131,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12131,606,12.061,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12132,203,7.79,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12132,204,76.08,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12132,205,13.38,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12132,207,1.14,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12132,208,718,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12132,255,1.61,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12132,269,4.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12132,291,8,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12132,301,70,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12132,303,2.65,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12132,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12132,307,4,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12132,320,0,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (12132,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12132,401,0.7,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12132,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12132,601,0,'100g',4,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12132,605,NULL,'100g',NULL,1,'2002-06-08','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12132,606,11.947,'100g',3,1,'2013-07-31','2013-07-31');
INSERT INTO `cndb_nutval` VALUES (12135,203,19.5,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12135,204,53.5,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12135,205,22.42,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12135,207,2.45,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12135,208,607,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12135,255,2.13,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12135,269,5,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12135,291,6.4,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12135,301,87,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12135,303,3.73,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12135,306,643,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12135,307,4,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12135,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12135,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12135,401,0.8,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12135,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12135,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12135,605,0.033,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12135,606,8.01,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12137,203,20.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12137,204,53.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12137,205,21.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12137,207,2.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12137,208,607,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12137,255,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12137,269,4.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12137,291,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12137,301,117,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12137,303,2.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12137,306,632,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12137,307,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12137,320,0,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (12137,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12137,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12137,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12137,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12137,605,0.055,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12137,606,8.711,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12138,203,15.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12138,204,56.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12138,205,22.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12138,207,2.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12138,208,615,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12138,255,3.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12138,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12138,291,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12138,301,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12138,303,2.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12138,306,544,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12138,307,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12138,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12138,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12138,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12138,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12138,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12138,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12138,606,9.087,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12140,203,13.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12140,204,57.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12140,205,23.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12140,207,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12140,208,622,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12140,255,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12140,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12140,291,5.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12140,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12140,303,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12140,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12140,307,505,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12140,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12140,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12140,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12140,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12140,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12140,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12140,606,8.701,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12142,203,9.17,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12142,204,71.97,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12142,205,13.86,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12142,207,1.49,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12142,208,691,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12142,255,3.52,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12142,269,3.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12142,291,9.6,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12142,301,70,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12142,303,2.53,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12142,306,410,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12142,307,0,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12142,320,3,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (12142,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12142,401,1.1,'100g',1,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12142,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12142,601,0,'100g',4,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12142,605,NULL,'100g',NULL,1,'1995-06-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12142,606,6.18,'100g',3,1,'1995-06-26','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12143,203,9.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12143,204,74.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12143,205,13.55,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12143,207,1.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12143,208,710,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12143,255,1.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12143,269,4.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12143,291,9.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12143,301,72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12143,303,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12143,306,424,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12143,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12143,320,7,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12143,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12143,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12143,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12143,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12143,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12143,606,6.283,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12144,203,9.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12144,204,75.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12144,205,13.01,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12144,207,1.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12144,208,715,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12144,255,1.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12144,269,3.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12144,291,9.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12144,301,67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12144,303,2.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12144,306,392,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12144,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12144,320,5,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12144,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12144,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12144,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12144,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12144,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12144,606,7.238,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12145,203,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12145,204,79.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12145,205,3.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12145,207,2.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12145,208,719,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12145,255,2.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12145,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12145,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12145,301,145,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12145,303,3.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12145,306,507,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12145,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12145,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12145,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12145,401,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12145,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12145,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12145,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12145,606,31.184,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12147,203,13.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12147,204,68.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12147,205,13.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12147,207,2.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12147,208,673,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12147,255,2.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12147,269,3.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12147,291,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12147,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12147,303,5.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12147,306,597,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12147,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12147,320,1,'100g',2,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (12147,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12147,401,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12147,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12147,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12147,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12147,606,4.899,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12149,203,11.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12149,204,60.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12149,205,19.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12149,207,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12149,208,629,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12149,255,5.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12149,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12149,291,10.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12149,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12149,303,3.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12149,306,628,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12149,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12149,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12149,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12149,401,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12149,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12149,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12149,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12149,606,9.377,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12151,203,20.16,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12151,204,45.32,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12151,205,27.17,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12151,207,2.99,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12151,208,560,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12151,255,4.37,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12151,269,7.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12151,291,10.6,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12151,301,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12151,303,3.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12151,306,1025,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12151,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12151,320,26,'100g',1,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (12151,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12151,401,5.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12151,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12151,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12151,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12151,606,5.907,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12152,203,21.05,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12152,204,45.82,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12152,205,28.28,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12152,207,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12152,208,572,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12152,255,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12152,269,7.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12152,291,10.3,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12152,301,107,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12152,303,4.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12152,306,1007,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12152,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12152,320,13,'100g',1,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (12152,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12152,401,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12152,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12152,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12152,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12152,606,5.645,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12154,203,24.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12154,204,59.33,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12154,205,9.58,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12154,207,2.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12154,208,619,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12154,255,4.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12154,269,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12154,291,6.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12154,301,61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12154,303,3.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12154,306,523,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12154,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12154,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12154,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12154,401,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12154,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12154,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12154,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12154,606,3.483,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12155,203,15.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12155,204,65.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12155,205,13.71,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12155,207,1.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12155,208,654,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12155,255,4.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12155,269,2.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12155,291,6.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12155,301,98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12155,303,2.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12155,306,441,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12155,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12155,320,1,'100g',1,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (12155,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12155,401,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12155,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12155,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12155,605,NULL,'100g',NULL,1,'1994-01-31','2007-03-25');
INSERT INTO `cndb_nutval` VALUES (12155,606,6.126,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12156,203,8.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12156,204,35.71,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12156,205,47.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12156,207,2.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12156,208,500,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12156,255,6.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12156,269,32.14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12156,291,3.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12156,301,71,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12156,303,1.29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12156,306,232,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12156,307,446,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12156,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (12156,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12156,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12156,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (12156,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12156,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12156,606,3.571,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12157,203,14.29,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12157,204,60.71,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12157,205,17.86,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12157,207,2.76,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12157,208,643,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12157,255,4.39,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12157,269,3.57,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12157,291,7.1,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12157,301,71,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12157,303,2.57,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12157,306,459,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12157,307,643,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12157,320,1,'100g',2,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (12157,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12157,401,1.4,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12157,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12157,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12157,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12157,606,5.357,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (12158,203,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12158,204,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12158,205,40.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12158,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12158,208,207,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12158,255,49.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12158,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12158,291,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12158,301,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12158,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12158,306,1082,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12158,307,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12158,320,15,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12158,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12158,401,7.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12158,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12158,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12158,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12158,606,0.729,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12160,203,32.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12160,204,36.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12160,205,21.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12160,207,4.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12160,208,506,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12160,255,4.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12160,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12160,291,5.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12160,301,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12160,303,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12160,306,1350,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12160,307,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12160,320,22,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12160,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12160,401,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12160,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12160,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12160,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12160,606,9.699,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12163,203,18.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12163,204,19.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12163,205,53.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12163,207,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12163,208,446,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12163,255,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12163,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12163,291,18.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12163,301,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12163,303,3.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12163,306,919,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12163,307,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12163,320,3,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (12163,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12163,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12163,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12163,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12163,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12163,606,3.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12166,203,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12166,204,53.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12166,205,21.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12166,207,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12166,208,595,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12166,255,3.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12166,269,0.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12166,291,9.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12166,301,426,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12166,303,8.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12166,306,414,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12166,307,115,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12166,320,3,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (12166,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12166,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12166,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12166,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12166,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12166,606,7.529,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12167,203,3.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12167,204,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12167,205,52.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12167,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12167,208,245,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12167,255,40.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12167,269,10.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12167,291,5.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12167,301,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12167,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12167,306,592,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12167,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12167,320,1,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (12167,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12167,401,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12167,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12167,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12167,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12167,606,0.414,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12169,203,18.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12169,204,50.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12169,205,24.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12169,207,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12169,208,586,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12169,255,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12169,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12169,291,5.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12169,301,960,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12169,303,19.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12169,306,582,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12169,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12169,320,3,'100g',1,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (12169,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12169,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12169,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12169,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12169,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12169,606,7.124,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12170,203,30.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12170,204,37.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12170,205,26.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12170,207,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12170,208,526,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12170,255,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12170,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12170,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12170,301,159,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12170,303,15.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12170,306,423,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12170,307,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12170,320,3,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12170,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12170,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12170,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12170,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12170,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12170,606,5.196,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12171,203,17.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12171,204,56.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12171,205,17.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12171,207,4.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12171,208,607,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12171,255,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12171,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12171,291,9.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12171,301,141,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12171,303,6.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12171,306,459,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12171,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12171,320,3,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12171,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12171,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12171,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12171,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12171,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12171,606,7.904,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12174,203,28.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12174,204,47.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12174,205,15.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12174,207,3.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12174,208,557,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12174,255,5.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12174,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12174,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12174,301,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12174,303,7.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12174,306,648,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12174,307,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12174,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12174,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12174,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12174,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12174,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12174,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12174,606,9.779,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12175,203,5.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12175,204,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12175,205,81.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12175,207,2.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12175,208,360,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12175,255,9.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12175,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12175,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12175,301,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12175,303,3.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12175,306,768,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12175,307,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12175,320,4,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12175,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12175,401,61.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12175,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12175,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12175,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12175,606,0.183,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12176,203,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12176,204,20.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12176,205,5.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12176,207,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12176,208,202,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12176,255,71.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12176,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12176,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12176,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12176,303,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12176,306,232,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12176,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12176,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12176,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12176,401,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12176,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12176,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12176,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12176,606,18.445,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12177,203,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12177,204,69.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12177,205,21.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12177,207,2.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12177,208,684,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12177,255,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12177,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12177,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12177,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12177,303,3.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12177,306,551,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12177,307,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12177,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12177,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12177,401,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12177,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12177,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12177,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12177,606,61.257,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12179,203,2.88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12179,204,35.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12179,205,47.67,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12179,207,1.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12179,208,501,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12179,255,12.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12179,269,43.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12179,291,4.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12179,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12179,303,1.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12179,306,337,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12179,307,262,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12179,320,0,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (12179,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12179,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12179,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (12179,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12179,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12179,606,31.468,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12193,203,12.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12193,204,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12193,205,58.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12193,207,18.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12193,208,318,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12193,255,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12193,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12193,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12193,301,1633,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12193,303,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12193,306,2130,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12193,307,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12193,320,3,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12193,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12193,401,30.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12193,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12193,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12193,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12193,606,0.902,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12195,203,20.96,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12195,204,55.5,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12195,205,18.82,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12195,207,3.09,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12195,208,614,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12195,255,1.64,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12195,269,4.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12195,291,10.3,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12195,301,347,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12195,303,3.49,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12195,306,748,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12195,307,7,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12195,320,0,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (12195,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12195,401,0,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12195,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12195,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12195,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12195,606,4.152,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12198,203,17.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12198,204,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12198,205,26.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12198,207,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12198,208,570,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12198,255,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12198,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12198,291,9.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12198,301,420,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12198,303,2.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12198,306,414,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12198,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12198,320,3,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12198,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12198,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12198,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12198,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12198,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12198,606,6.722,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12200,203,13.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12200,204,62.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12200,205,20.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12200,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12200,208,647,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12200,255,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12200,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12200,291,5.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12200,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12200,303,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12200,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12200,307,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12200,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12200,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12200,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12200,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12200,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12200,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12200,606,9.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12201,203,20.45,'100g',1,1,'1995-06-13','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12201,204,61.21,'100g',1,1,'1995-06-13','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12201,205,11.73,'100g',3,1,'1995-06-13','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12201,207,2.86,'100g',1,1,'1995-06-13','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12201,208,631,'100g',3,1,'1995-06-13','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12201,255,3.75,'100g',1,1,'1995-06-13','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12201,269,0.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12201,291,11.6,'100g',1,1,'1995-06-13','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12201,301,60,'100g',1,1,'1995-06-13','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12201,303,6.36,'100g',1,1,'1995-06-13','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12201,306,370,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12201,307,47,'100g',1,1,'1995-06-13','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12201,320,3,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (12201,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12201,401,0,'100g',3,1,'1995-06-13','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12201,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12201,601,0,'100g',4,1,'1995-06-13','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12201,605,0,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12201,606,9.055,'100g',3,1,'1995-06-13','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12202,203,2.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12202,204,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12202,205,34.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12202,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12202,208,154,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12202,255,61.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12202,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12202,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12202,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12202,303,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12202,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12202,307,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12202,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12202,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12202,401,26.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12202,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12202,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12202,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12202,606,0.078,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12203,203,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12203,204,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12203,205,12.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12203,207,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12203,208,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12203,255,86.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12203,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12203,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12203,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12203,303,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12203,306,119,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12203,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12203,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12203,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12203,401,9.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12203,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12203,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12203,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12203,606,0.028,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12204,203,2.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12204,204,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12204,205,45.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12204,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12204,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12204,255,49.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12204,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12204,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12204,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12204,303,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12204,306,427,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12204,307,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12204,320,4,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12204,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12204,401,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12204,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12204,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12204,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12204,606,0.118,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12205,203,4.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12205,204,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12205,205,17.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12205,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12205,208,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12205,255,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12205,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12205,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12205,301,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12205,303,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12205,306,367,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12205,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12205,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12205,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12205,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12205,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12205,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12205,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12205,606,0.088,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12206,203,18.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12206,204,49.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12206,205,27.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12206,207,2.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12206,208,594,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12206,255,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12206,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12206,291,13.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12206,301,263,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12206,303,2.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12206,306,560,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12206,307,130,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12206,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12206,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12206,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12206,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (12206,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12206,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12206,606,4.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12220,203,18.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12220,204,42.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12220,205,28.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12220,207,3.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12220,208,534,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12220,255,6.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12220,269,1.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12220,291,27.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12220,301,255,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12220,303,5.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12220,306,813,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12220,307,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12220,320,0,'100g',1,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (12220,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12220,401,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12220,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12220,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12220,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12220,606,3.663,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12516,203,29.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12516,204,49.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12516,205,14.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12516,207,4.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12516,208,574,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12516,255,2.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12516,269,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12516,291,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12516,301,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12516,303,8.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12516,306,788,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12516,307,256,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12516,320,0,'100g',1,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (12516,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12516,401,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12516,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12516,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12516,605,0.042,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12516,606,8.544,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12529,203,16.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12529,204,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12529,205,26.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12529,207,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12529,208,567,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12529,255,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12529,269,0.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12529,291,16.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12529,301,131,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12529,303,7.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12529,306,406,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12529,307,588,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12529,320,3,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (12529,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12529,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12529,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12529,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12529,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12529,606,6.722,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12536,203,19.33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12536,204,49.8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12536,205,15.31,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12536,207,14.36,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12536,208,546,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12536,255,1.2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12536,269,2.73,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12536,291,9,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12536,301,70,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12536,303,3.8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12536,306,850,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12536,307,6008,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12536,320,0,'100g',2,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (12536,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12536,401,1.4,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12536,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12536,601,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12536,605,NULL,'100g',NULL,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12536,606,5.219,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12537,203,19.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12537,204,49.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12537,205,24.07,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12537,207,5.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12537,208,582,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12537,255,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12537,269,2.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12537,291,9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12537,301,70,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12537,303,3.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12537,306,850,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12537,307,655,'100g',6,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12537,320,0,'100g',2,1,'2024-12-12','2004-01-05');
INSERT INTO `cndb_nutval` VALUES (12537,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12537,401,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12537,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12537,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12537,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12537,606,5.219,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12538,203,20.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12538,204,51.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12538,205,22.89,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12538,207,4.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12538,208,592,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12538,255,1.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12538,269,3.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12538,291,10.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12538,301,87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12538,303,4.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12538,306,483,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12538,307,303,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (12538,320,0,'100g',1,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (12538,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12538,401,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12538,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12538,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12538,605,0.158,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12538,606,7.068,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12539,203,17.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12539,204,56.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12539,205,20.59,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12539,207,4.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12539,208,619,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12539,255,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12539,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12539,291,11.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12539,301,57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12539,303,6.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12539,306,491,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12539,307,613,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12539,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12539,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12539,401,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12539,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12539,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12539,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12539,606,5.953,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12540,203,17.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12540,204,55.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12540,205,23.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12540,207,3.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12540,208,617,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12540,255,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12540,269,10.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12540,291,5.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12540,301,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12540,303,4.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12540,306,576,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12540,307,331,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12540,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (12540,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12540,401,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12540,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12540,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12540,605,0.027,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12540,606,4.678,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12563,203,20.96,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12563,204,52.54,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12563,205,21.01,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12563,207,3.07,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12563,208,598,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12563,255,2.41,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12563,269,4.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12563,291,10.9,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12563,301,268,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12563,303,3.73,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12563,306,713,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12563,307,234,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (12563,320,0,'100g',1,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (12563,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12563,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12563,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12563,601,0,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (12563,605,0.007,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12563,606,4.092,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12565,203,21.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12565,204,55.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12565,205,17.68,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12565,207,3.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12565,208,607,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12565,255,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12565,269,4.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12565,291,10.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12565,301,291,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12565,303,3.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12565,306,699,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12565,307,339,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12565,320,0,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (12565,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12565,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12565,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12565,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12565,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12565,606,4.208,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12567,203,21.43,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12567,204,55.89,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12567,205,17.86,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12567,207,2.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12567,208,607,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12567,255,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12567,269,3.57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12567,291,10.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12567,301,286,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12567,303,3.86,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12567,306,679,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12567,307,548,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12567,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (12567,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12567,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12567,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12567,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12567,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12567,606,3.571,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12585,203,15.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12585,204,46.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12585,205,32.69,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12585,207,3.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12585,208,574,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12585,255,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12585,269,5.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12585,291,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12585,301,45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12585,303,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12585,306,565,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12585,307,640,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12585,320,0,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (12585,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12585,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12585,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12585,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12585,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12585,606,9.157,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12586,203,16.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12586,204,47.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12586,205,30.16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12586,207,2.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12586,208,581,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12586,255,2.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12586,269,5.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12586,291,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12586,301,43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12586,303,6.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12586,306,632,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12586,307,308,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12586,320,0,'100g',1,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (12586,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12586,401,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12586,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12586,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12586,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12586,606,8.478,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12588,203,12.12,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12588,204,53.03,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12588,205,30.3,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12588,207,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12588,208,609,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12588,255,2.34,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12588,269,9.09,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12588,291,3,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12588,301,61,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12588,303,4.91,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12588,306,447,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12588,307,295,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12588,320,0,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (12588,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12588,401,0,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12588,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12588,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12588,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12588,606,10.606,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12632,203,7.79,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12632,204,76.08,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12632,205,12.83,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12632,207,1.7,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12632,208,716,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12632,255,1.61,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12632,269,4.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12632,291,8,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12632,301,70,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12632,303,2.65,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12632,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12632,307,353,'100g',6,1,'2002-06-08','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (12632,320,0,'100g',1,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (12632,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12632,401,0.7,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12632,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12632,601,0,'100g',4,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12632,605,NULL,'100g',NULL,1,'2002-06-08','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12632,606,11.947,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12635,203,17.3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12635,204,51.45,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12635,205,25.35,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12635,207,4.15,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12635,208,594,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12635,255,1.75,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12635,269,4.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12635,291,9,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12635,301,70,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12635,303,3.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12635,306,693,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12635,307,345,'100g',6,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (12635,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (12635,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12635,401,0.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12635,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12635,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12635,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12635,606,6.5,'100g',6,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (12637,203,20.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12637,204,53.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12637,205,21.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12637,207,2.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12637,208,607,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12637,255,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12637,269,4.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12637,291,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12637,301,117,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12637,303,2.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12637,306,632,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12637,307,273,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12637,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (12637,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12637,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12637,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12637,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12637,605,0.055,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12637,606,8.711,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12638,203,15.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12638,204,56.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12638,205,22.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12638,207,2.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12638,208,615,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12638,255,3.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12638,269,4.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12638,291,5.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12638,301,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12638,303,2.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12638,306,544,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12638,307,306,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12638,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (12638,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12638,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12638,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12638,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12638,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12638,606,9.087,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12643,203,9.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12643,204,74.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12643,205,13.55,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12643,207,1.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12643,208,710,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12643,255,1.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12643,269,4.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12643,291,9.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12643,301,72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12643,303,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12643,306,424,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12643,307,383,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12643,320,7,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12643,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12643,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12643,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12643,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12643,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12643,606,6.283,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12644,203,9.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12644,204,75.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12644,205,13.01,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12644,207,1.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12644,208,715,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12644,255,1.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12644,269,3.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12644,291,9.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12644,301,67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12644,303,2.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12644,306,392,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12644,307,393,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12644,320,5,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (12644,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12644,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12644,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12644,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12644,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12644,606,7.238,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12652,203,21.05,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12652,204,45.82,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12652,205,27.55,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12652,207,3.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12652,208,569,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12652,255,1.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12652,269,7.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12652,291,10.3,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12652,301,107,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12652,303,4.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12652,306,1007,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12652,307,428,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12652,320,13,'100g',1,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (12652,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12652,401,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12652,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12652,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12652,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12652,606,5.645,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12663,203,18.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12663,204,19.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12663,205,53.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12663,207,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12663,208,446,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12663,255,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12663,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12663,291,18.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12663,301,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12663,303,3.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12663,306,919,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12663,307,2541,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12663,320,3,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (12663,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12663,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12663,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12663,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12663,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12663,606,3.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12665,203,21.23,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12665,204,55.17,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12665,205,17.68,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12665,207,3.13,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12665,208,607,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12665,255,2.8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12665,269,4.55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12665,291,10.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12665,301,291,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12665,303,3.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12665,306,699,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12665,307,143,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12665,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (12665,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12665,401,0,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12665,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12665,601,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12665,605,NULL,'100g',NULL,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12665,606,4.207,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (12695,203,20.96,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12695,204,55.5,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12695,205,18.82,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12695,207,3.09,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12695,208,614,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12695,255,1.64,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12695,269,6.27,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12695,291,10.3,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12695,301,347,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12695,303,3.49,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12695,306,748,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12695,307,227,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (12695,320,0,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (12695,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12695,401,0,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (12695,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12695,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12695,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (12695,606,6.55,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (12698,203,17.4,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12698,204,53.01,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12698,205,21.5,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12698,207,5.09,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12698,208,592,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12698,255,3,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12698,269,NULL,'100g',NULL,1,'2002-06-08','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12698,291,4.7,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12698,301,141,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12698,303,4.42,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12698,306,459,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12698,307,35,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12698,320,3,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (12698,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12698,401,4.2,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12698,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12698,601,0,'100g',3,1,'2002-06-08','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (12698,605,NULL,'100g',NULL,1,'2002-06-08','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (12698,606,7.423,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (12737,203,20.04,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12737,204,53.95,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12737,205,21.05,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12737,207,2.88,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12737,208,607,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12737,255,2.08,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12737,269,4.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12737,291,7,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12737,301,117,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12737,303,2.61,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12737,306,632,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12737,307,161,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12737,320,0,'100g',2,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (12737,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12737,401,0.5,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12737,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12737,601,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12737,605,0.055,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (12737,606,8.711,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (12738,203,17.86,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12738,204,50,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12738,205,25,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12738,207,3.18,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12738,208,607,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12738,255,3.15,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12738,269,5.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (12738,291,7.1,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12738,301,130,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12738,303,5.18,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12738,306,714,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12738,307,143,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12738,320,1,'100g',2,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (12738,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (12738,401,0.6,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12738,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (12738,601,0,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12738,605,0,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (12738,606,7.143,'100g',6,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13000,203,23.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13000,204,2.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13000,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13000,207,1.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13000,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13000,255,73.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13000,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13000,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13000,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13000,303,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13000,306,342,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13000,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13000,320,0,'100g',1,1,'2024-12-12','2007-01-10');
INSERT INTO `cndb_nutval` VALUES (13000,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13000,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13000,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13000,601,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13000,605,0.113,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13000,606,1.032,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13001,203,17.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13001,204,24.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13001,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13001,207,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13001,208,291,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13001,255,57.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13001,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13001,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13001,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13001,303,1.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13001,306,267,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13001,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13001,320,0,'100g',2,1,'2024-12-12','2010-01-09');
INSERT INTO `cndb_nutval` VALUES (13001,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13001,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13001,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13001,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13001,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13001,606,9.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13002,203,17.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13002,204,22.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13002,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13002,207,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13002,208,278,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13002,255,58.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13002,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13002,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13002,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13002,303,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13002,306,271,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13002,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13002,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (13002,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13002,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13002,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13002,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13002,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13002,606,9.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13019,203,8.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13019,204,70.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13019,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13019,207,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13019,208,674,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13019,255,20.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13019,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13019,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13019,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13019,303,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13019,306,96,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13019,307,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13019,320,0,'100g',1,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (13019,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13019,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13019,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13019,601,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13019,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13019,606,29.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13020,203,10.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13020,204,70.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13020,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13020,207,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13020,208,680,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13020,255,18.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13020,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13020,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13020,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13020,303,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13020,306,99,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13020,307,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13020,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (13020,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13020,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13020,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13020,601,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13020,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13020,606,28.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13023,203,20.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13023,204,7.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13023,205,0.6,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13023,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13023,208,157,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13023,255,70.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13023,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13023,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13023,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13023,303,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13023,306,330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13023,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13023,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (13023,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13023,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13023,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13023,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13023,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13023,606,2.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13047,203,19.42,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (13047,204,12.73,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (13047,205,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (13047,207,1.71,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (13047,208,198,'100g',3,1,'2009-01-25','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13047,255,67.13,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (13047,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13047,291,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (13047,301,12,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (13047,303,1.99,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (13047,306,289,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13047,307,68,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (13047,320,0,'100g',1,1,'2024-12-12','2007-01-06');
INSERT INTO `cndb_nutval` VALUES (13047,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13047,401,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (13047,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13047,601,62,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (13047,605,0.751,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (13047,606,5.335,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (13055,203,28.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13055,204,17.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13055,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13055,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13055,208,280,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13055,255,53.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13055,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13055,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13055,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13055,303,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13055,306,237,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13055,307,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13055,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13055,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13055,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13055,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13055,601,107,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13055,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13055,606,6.888,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13065,203,21.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13065,204,8.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13065,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13065,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13065,208,165,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13065,255,69.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13065,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13065,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13065,301,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13065,303,1.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13065,306,330,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13065,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13065,320,0,'100g',1,1,'2024-12-12','2003-01-08');
INSERT INTO `cndb_nutval` VALUES (13065,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13065,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13065,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13065,601,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13065,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13065,606,3.443,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13066,203,26.98,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13066,204,16.44,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13066,205,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13066,207,2.04,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13066,208,263,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13066,255,54.95,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13066,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13066,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13066,301,6,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13066,303,3.33,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13066,306,337,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13066,307,70,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13066,320,0,'100g',1,1,'2024-12-12','2004-01-09');
INSERT INTO `cndb_nutval` VALUES (13066,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13066,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13066,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13066,601,72,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13066,605,NULL,'100g',NULL,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13066,606,6.92,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13067,203,27.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13067,204,9.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13067,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13067,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13067,208,202,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13067,255,63.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13067,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13067,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13067,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13067,303,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13067,306,326,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13067,307,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13067,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13067,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13067,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13067,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13067,601,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13067,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13067,606,3.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13068,203,21.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13068,204,6.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13068,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13068,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13068,208,149,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13068,255,68.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13068,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13068,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13068,301,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13068,303,1.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13068,306,340,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13068,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13068,320,0,'100g',1,1,'2024-12-12','2003-01-06');
INSERT INTO `cndb_nutval` VALUES (13068,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13068,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13068,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13068,601,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13068,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13068,606,2.612,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13069,203,28.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13069,204,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13069,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13069,207,2.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13069,208,237,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13069,255,57.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13069,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13069,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13069,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13069,303,3.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13069,306,351,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13069,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13069,320,0,'100g',1,1,'2024-12-12','2002-01-07');
INSERT INTO `cndb_nutval` VALUES (13069,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13069,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13069,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13069,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13069,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13069,606,5.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13070,203,27.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13070,204,8.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13070,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13070,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13070,208,194,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13070,255,64.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13070,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13070,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13070,301,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13070,303,1.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13070,306,338,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13070,307,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13070,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13070,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13070,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13070,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13070,601,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13070,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13070,606,3.452,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13095,203,17.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13095,204,22.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13095,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13095,207,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13095,208,274,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13095,255,58.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13095,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13095,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13095,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13095,303,1.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13095,306,305,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13095,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13095,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13095,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13095,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13095,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13095,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13095,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13095,606,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13096,203,26.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13096,204,16.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13096,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13096,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13096,208,265,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13096,255,55.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13096,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13096,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13096,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13096,303,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13096,306,326,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13096,307,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13096,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13096,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13096,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13096,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13096,601,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13096,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13096,606,6.506,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13097,203,20.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13097,204,8.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13097,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13097,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13097,208,161,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13097,255,68.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13097,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13097,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13097,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13097,303,2.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13097,306,373,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13097,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13097,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13097,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13097,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13097,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13097,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13097,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13097,606,3.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13098,203,28.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13098,204,9.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13098,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13098,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13098,208,205,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13098,255,61.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13098,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13098,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13098,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13098,303,1.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13098,306,363,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13098,307,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13098,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13098,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13098,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13098,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13098,601,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13098,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13098,606,3.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13147,203,14.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13147,204,36.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13147,205,0.4,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13147,207,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13147,208,390,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13147,255,48.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13147,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13147,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13147,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13147,303,1.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13147,306,232,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13147,307,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13147,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13147,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13147,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13147,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13147,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13147,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13147,606,15.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13148,203,21.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13148,204,41.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13148,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13148,207,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13148,208,471,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13148,255,35.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13148,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13148,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13148,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13148,303,2.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13148,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13148,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13148,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (13148,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13148,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13148,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13148,601,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13148,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13148,606,17.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13149,203,19.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13149,204,10.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13149,205,0.4,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13149,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13149,208,175,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13149,255,69.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13149,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13149,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13149,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13149,303,2.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13149,306,357,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13149,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13149,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13149,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13149,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13149,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13149,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13149,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13149,606,4.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13150,203,30.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13150,204,18.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13150,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13150,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13150,208,295,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13150,255,50.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13150,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13150,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13150,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13150,303,3.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13150,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13150,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13150,320,0,'100g',1,1,'2024-12-12','2002-01-07');
INSERT INTO `cndb_nutval` VALUES (13150,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13150,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13150,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13150,601,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13150,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13150,606,7.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13156,203,29.21,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13156,204,7.31,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13156,205,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13156,207,1.41,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13156,208,191,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13156,255,60.5,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13156,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13156,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13156,301,5,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13156,303,2.7,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13156,306,422,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13156,307,64,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13156,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (13156,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13156,401,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13156,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13156,601,78,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13156,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13156,606,2.56,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13158,203,29.25,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13158,204,5.22,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13158,205,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13158,207,1.41,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13158,208,172,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13158,255,62.44,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13158,269,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13158,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13158,301,5,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13158,303,2.71,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13158,306,423,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13158,307,64,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13158,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13158,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13158,401,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13158,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13158,601,78,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13158,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13158,606,1.83,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13165,203,32.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13165,204,9.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13165,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13165,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13165,208,221,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13165,255,58.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13165,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13165,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13165,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13165,303,2.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13165,306,254,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13165,307,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13165,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13165,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13165,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13165,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13165,601,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13165,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13165,606,3.638,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13227,203,21.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13227,204,3.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13227,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13227,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13227,208,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13227,255,73.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13227,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13227,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13227,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13227,303,2.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13227,306,387,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13227,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13227,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13227,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13227,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13227,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13227,601,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13227,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13227,606,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13228,203,33.68,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13228,204,6.36,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13228,205,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13228,207,2.39,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13228,208,201,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13228,255,58.21,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13228,269,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13228,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13228,301,32,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13228,303,3.86,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13228,306,447,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13228,307,64,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13228,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13228,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13228,401,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13228,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13228,601,78,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13228,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13228,606,2.29,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13231,203,22.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13231,204,7.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13231,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13231,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13231,208,161,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13231,255,69.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13231,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13231,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13231,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13231,303,1.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13231,306,276,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13231,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13231,320,0,'100g',1,1,'2024-12-12','2002-01-08');
INSERT INTO `cndb_nutval` VALUES (13231,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13231,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13231,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13231,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13231,605,0.356,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13231,606,2.894,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13232,203,27.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13232,204,11.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13232,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13232,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13232,208,221,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13232,255,60.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13232,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13232,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13232,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13232,303,3.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13232,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13232,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13232,320,1,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13232,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13232,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13232,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13232,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13232,605,0.565,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13232,606,4.407,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13235,203,22.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13235,204,7.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13235,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13235,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13235,208,160,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13235,255,69.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13235,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13235,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13235,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13235,303,1.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13235,306,263,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13235,307,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13235,320,0,'100g',1,1,'2024-12-12','2002-01-08');
INSERT INTO `cndb_nutval` VALUES (13235,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13235,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13235,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13235,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13235,605,0.303,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13235,606,2.782,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13236,203,27.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13236,204,11.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13236,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13236,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13236,208,217,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13236,255,60.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13236,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13236,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13236,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13236,303,3.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13236,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13236,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13236,320,1,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13236,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13236,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13236,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13236,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13236,605,0.595,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13236,606,4.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13284,203,21.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13284,204,6.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13284,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13284,207,0.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13284,208,149,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13284,255,71.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13284,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13284,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13284,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13284,303,1.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13284,306,297,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13284,307,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13284,320,0,'100g',2,1,'2024-12-12','2009-01-11');
INSERT INTO `cndb_nutval` VALUES (13284,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13284,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13284,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13284,601,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13284,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13284,606,2.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13285,203,30.54,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13285,204,10.46,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13285,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13285,207,1.39,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13285,208,216,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13285,255,58.22,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13285,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13285,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13285,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13285,303,3.19,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13285,306,306,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13285,307,65,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13285,320,2,'100g',1,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (13285,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13285,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13285,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13285,601,104,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13285,605,0.429,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13285,606,4.002,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13293,203,21.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13293,204,6.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13293,205,0.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13293,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13293,208,140,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13293,255,71.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13293,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13293,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13293,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13293,303,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13293,306,369,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13293,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13293,320,2,'100g',1,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (13293,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13293,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13293,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13293,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13293,605,0.296,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13293,606,2.58,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13294,203,21.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13294,204,6.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13294,205,0.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13294,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13294,208,145,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13294,255,70.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13294,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13294,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13294,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13294,303,2.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13294,306,361,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13294,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13294,320,2,'100g',1,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (13294,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13294,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13294,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13294,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13294,605,0.292,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13294,606,2.76,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13317,203,23.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13317,204,21.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13317,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13317,207,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13317,208,295,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13317,255,53.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13317,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13317,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13317,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13317,303,2.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13317,306,305,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13317,307,77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13317,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (13317,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13317,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13317,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13317,601,84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13317,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13317,606,8.805,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13318,203,10.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13318,204,10.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13318,205,1.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13318,207,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13318,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13318,255,76.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13318,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13318,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13318,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13318,303,2.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13318,306,274,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13318,307,126,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13318,320,7,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (13318,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13318,401,10.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13318,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13318,601,3010,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13318,605,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13318,606,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13319,203,12.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13319,204,15.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13319,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13319,207,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13319,208,196,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13319,255,70.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13319,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13319,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13319,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13319,303,2.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13319,306,354,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13319,307,158,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13319,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13319,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13319,401,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13319,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13319,601,1995,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13319,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13319,606,3.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13320,203,11.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13320,204,10.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13320,205,1.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13320,207,1.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13320,208,151,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13320,255,74.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13320,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13320,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13320,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13320,303,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13320,306,244,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13320,307,108,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13320,320,6,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (13320,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13320,401,10.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13320,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13320,601,3100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13320,605,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13320,606,2.394,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13321,203,17.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13321,204,3.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13321,205,0.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13321,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13321,208,112,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13321,255,77.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13321,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13321,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13321,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13321,303,4.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13321,306,287,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13321,307,98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13321,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (13321,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13321,401,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13321,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13321,601,124,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13321,605,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13321,606,1.383,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13322,203,28.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13322,204,4.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13322,205,0.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13322,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13322,208,165,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13322,255,65.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13322,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13322,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13322,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13322,303,6.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13322,306,219,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13322,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13322,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (13322,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13322,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13322,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13322,601,212,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13322,605,0.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13322,606,1.404,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13323,203,17.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13323,204,3.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13323,205,0.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13323,207,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13323,208,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13323,255,77.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13323,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13323,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13323,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13323,303,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13323,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13323,307,182,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13323,320,419,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (13323,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13323,401,9.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13323,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13323,601,411,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13323,605,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13323,606,0.868,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13324,203,27.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13324,204,4.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13324,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13324,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13324,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13324,255,66.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13324,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13324,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13324,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13324,303,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13324,306,135,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13324,307,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13324,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (13324,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13324,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13324,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13324,601,716,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13324,605,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13324,606,1.439,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13325,203,20.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13325,204,3.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13325,205,3.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13325,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13325,208,135,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13325,255,70.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13325,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13325,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13325,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13325,303,4.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13325,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13325,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13325,320,4968,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (13325,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13325,401,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13325,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13325,601,275,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13325,605,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13325,606,1.233,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13326,203,29.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13326,204,5.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13326,205,5.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13326,207,1.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13326,208,191,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13326,255,58.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13326,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13326,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13326,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13326,303,6.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13326,306,352,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13326,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13326,320,9442,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (13326,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13326,401,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13326,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13326,601,396,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13326,605,0.365,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13326,606,2.947,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13327,203,26.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13327,204,4.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13327,205,5.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13327,207,1.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13327,208,175,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13327,255,62.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13327,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13327,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13327,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13327,303,6.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13327,306,351,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13327,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13327,320,7744,'100g',1,1,'2024-12-12','2004-01-10');
INSERT INTO `cndb_nutval` VALUES (13327,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13327,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13327,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13327,601,381,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13327,605,0.335,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13327,606,2.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13328,203,16.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13328,204,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13328,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13328,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13328,208,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13328,255,79.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13328,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13328,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13328,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13328,303,7.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13328,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13328,307,198,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13328,320,14,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13328,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13328,401,38.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13328,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13328,601,242,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13328,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13328,606,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13329,203,20.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13329,204,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13329,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13329,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13329,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13329,255,76.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13329,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13329,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13329,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13329,303,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13329,306,173,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13329,307,101,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13329,320,12,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13329,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13329,401,32.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13329,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13329,601,277,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13329,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13329,606,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13330,203,14.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13330,204,23.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13330,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13330,207,2.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13330,208,276,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13330,255,59.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13330,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13330,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13330,301,485,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13330,303,5.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13330,306,277,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13330,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13330,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13330,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13330,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13330,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13330,601,209,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13330,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13330,606,11.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13331,203,15.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13331,204,18.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13331,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13331,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13331,208,235,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13331,255,65.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13331,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13331,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13331,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13331,303,2.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13331,306,276,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13331,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13331,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13331,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13331,401,13.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13331,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13331,601,205,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13331,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13331,606,6.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13332,203,27.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13332,204,17.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13332,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13332,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13332,208,271,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13332,255,55.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13332,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13332,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13332,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13332,303,2.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13332,306,246,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13332,307,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13332,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13332,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13332,401,20.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13332,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13332,601,262,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13332,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13332,606,5.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13333,203,18.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13333,204,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13333,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13333,207,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13333,208,105,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13333,255,77.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13333,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13333,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13333,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13333,303,44.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13333,306,429,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13333,307,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13333,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13333,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13333,401,45.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13333,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13333,601,263,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13333,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13333,606,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13334,203,25.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13334,204,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13334,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13334,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13334,208,145,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13334,255,69.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13334,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13334,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13334,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13334,303,39.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13334,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13334,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13334,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13334,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13334,401,50.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13334,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13334,601,347,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13334,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13334,606,1.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13335,203,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13335,204,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13335,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13335,207,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13335,208,854,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13335,255,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13335,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13335,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13335,301,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13335,303,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13335,306,16,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13335,307,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13335,320,0,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (13335,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13335,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13335,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13335,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13335,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13335,606,52.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13337,203,12.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13337,204,20.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13337,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13337,207,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13337,208,236,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13337,255,67.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13337,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13337,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13337,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13337,303,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13337,306,360,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13337,307,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13337,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13337,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13337,401,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13337,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13337,601,223,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13337,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13337,606,7.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13338,203,21.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13338,204,24.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13338,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13338,207,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13338,208,319,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13338,255,52.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13338,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13338,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13338,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13338,303,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13338,306,433,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13338,307,116,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13338,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13338,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13338,401,30.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13338,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13338,601,294,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13338,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13338,606,8.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13339,203,14.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13339,204,16.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13339,205,3.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13339,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13339,208,224,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13339,255,64.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13339,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13339,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13339,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13339,303,2.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13339,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13339,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13339,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13339,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13339,401,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13339,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13339,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13339,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13339,606,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13340,203,19.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13340,204,22.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13340,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13340,207,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13340,208,284,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13340,255,57.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13340,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13340,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13340,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13340,303,2.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13340,306,184,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13340,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13340,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (13340,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13340,401,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13340,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13340,601,132,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13340,605,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13340,606,8.125,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13341,203,12.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13341,204,3.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13341,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13341,207,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13341,208,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13341,255,84.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13341,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13341,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13341,301,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13341,303,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13341,306,67,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13341,307,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13341,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (13341,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13341,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13341,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13341,601,122,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13341,605,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13341,606,1.291,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13342,203,16.5,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13342,204,27,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13342,205,0,'100g',6,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13342,207,0.8,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13342,208,309,'100g',6,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13342,255,56,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13342,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13342,291,0,'100g',4,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13342,301,12,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13342,303,1.86,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13342,306,233,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13342,307,68,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13342,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (13342,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13342,401,0,'100g',4,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13342,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13342,601,71,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13342,605,NULL,'100g',NULL,1,'2002-06-08','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (13342,606,11.538,'100g',1,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13343,203,32.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13343,204,8.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13343,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13343,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13343,208,212,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13343,255,59.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13343,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13343,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13343,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13343,303,2.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13343,306,256,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13343,307,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13343,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13343,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13343,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13343,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13343,601,99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13343,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13343,606,3.053,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13344,203,12.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13344,204,38.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13344,205,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13344,207,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13344,208,406,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13344,255,45.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13344,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13344,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13344,301,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13344,303,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13344,306,153,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13344,307,955,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13344,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13344,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13344,401,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13344,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (13344,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13344,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13344,606,15.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13345,203,31.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13345,204,34.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13345,205,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13345,207,6.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13345,208,449,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13345,255,26.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13345,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13345,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13345,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13345,303,3.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13345,306,412,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13345,307,2253,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13345,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (13345,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13345,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13345,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (13345,601,119,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13345,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (13345,606,14.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13346,203,14.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13346,204,14.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13346,205,0.14,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13346,207,3.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13346,208,198,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13346,255,66.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13346,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (13346,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13346,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13346,303,1.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13346,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13346,307,1217,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13346,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13346,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13346,401,27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13346,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (13346,601,54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13346,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (13346,606,4.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13347,203,18.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13347,204,18.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13347,205,0.47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13347,207,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13347,208,251,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13347,255,59.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13347,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13347,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13347,301,8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13347,303,1.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13347,306,145,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13347,307,973,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (13347,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (13347,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13347,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13347,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (13347,601,98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13347,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (13347,606,6.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13348,203,27.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13348,204,14.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13348,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13348,207,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13348,208,250,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13348,255,57.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13348,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13348,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13348,301,12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13348,303,2.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13348,306,136,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13348,307,897,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (13348,320,0,'100g',1,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (13348,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13348,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13348,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (13348,601,86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13348,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (13348,606,6.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13349,203,21.03,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13349,204,5.41,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13349,205,0.19,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13349,207,1.07,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13349,208,134,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13349,255,72.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13349,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13349,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13349,301,12,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13349,303,2.43,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13349,306,380,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13349,307,81,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13349,320,2,'100g',1,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (13349,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13349,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13349,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13349,601,66,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13349,605,0.307,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13349,606,2.572,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13350,203,31.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13350,204,1.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13350,205,2.76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13350,207,10.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13350,208,153,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13350,255,53.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13350,269,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13350,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13350,301,8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13350,303,2.42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13350,306,235,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13350,307,2790,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13350,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (13350,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13350,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13350,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (13350,601,79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13350,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (13350,606,0.95,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13351,203,26.5,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13351,204,12.64,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13351,205,0.14,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13351,207,1,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13351,208,220,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13351,255,59.72,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13351,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13351,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13351,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13351,303,3.31,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13351,306,314,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13351,307,73,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13351,320,2,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (13351,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13351,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13351,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13351,601,93,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (13351,605,0.798,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13351,606,5.28,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13352,203,26.49,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13352,204,13.42,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13352,205,0.28,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13352,207,0.99,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13352,208,228,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13352,255,58.83,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13352,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13352,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13352,301,12,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13352,303,3.32,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13352,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13352,307,73,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13352,320,1,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (13352,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13352,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13352,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13352,601,89,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (13352,605,0.813,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13352,606,5.565,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13353,203,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13353,204,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13353,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13353,207,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13353,208,111,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13353,255,74.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13353,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13353,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13353,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13353,303,3.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13353,306,402,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13353,307,1322,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13353,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13353,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13353,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13353,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (13353,601,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13353,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13353,606,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13354,203,26.53,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13354,204,11.46,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13354,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13354,207,1.02,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13354,208,209,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13354,255,61.06,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13354,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13354,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13354,301,16,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13354,303,3.37,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13354,306,306,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13354,307,74,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13354,320,2,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (13354,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13354,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13354,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13354,601,98,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (13354,605,0.756,'100g',3,1,'2011-01-18','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13354,606,4.73,'100g',3,1,'2011-01-18','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13355,203,21.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13355,204,5.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13355,205,0.36,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13355,207,3.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13355,208,147,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13355,255,69.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13355,269,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13355,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13355,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13355,303,2.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13355,306,210,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13355,307,1078,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (13355,320,2,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (13355,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13355,401,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13355,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (13355,601,68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13355,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (13355,606,2.681,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13356,203,19.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13356,204,9.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13356,205,0.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13356,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13356,208,170,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13356,255,69.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13356,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13356,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13356,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13356,303,2.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13356,306,321,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13356,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13356,320,2,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (13356,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13356,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13356,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13356,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13356,605,0.611,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13356,606,4.132,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13357,203,14.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13357,204,26.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13357,205,2.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13357,207,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13357,208,312,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13357,255,53.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13357,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13357,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13357,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13357,303,1.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13357,306,176,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13357,307,1131,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13357,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13357,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13357,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13357,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (13357,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13357,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13357,606,11.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13358,203,20.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13358,204,4.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13358,205,1.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13358,207,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13358,208,133,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13358,255,68.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13358,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13358,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13358,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13358,303,2.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13358,306,377,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13358,307,1258,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13358,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13358,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13358,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13358,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (13358,601,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13358,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13358,606,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13359,203,19.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13359,204,10.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13359,205,0.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13359,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13359,208,178,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13359,255,68.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13359,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13359,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13359,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13359,303,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13359,306,317,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13359,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13359,320,2,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (13359,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13359,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13359,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13359,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13359,605,0.676,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13359,606,4.588,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13361,203,28.4,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13361,204,12.42,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13361,205,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13361,207,1.12,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13361,208,230,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13361,255,58.61,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13361,269,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13361,291,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13361,301,14,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13361,303,2.82,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13361,306,323,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13361,307,62,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13361,320,4,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13361,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13361,401,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13361,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13361,601,89,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13361,605,0.366,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13361,606,4.853,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13362,203,28.17,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13362,204,12.53,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13362,205,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13362,207,1.12,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13362,208,233,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13362,255,58.7,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13362,269,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13362,291,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13362,301,15,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13362,303,2.79,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13362,306,321,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13362,307,62,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13362,320,4,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13362,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13362,401,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13362,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13362,601,86,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13362,605,0.365,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13362,606,5.016,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13363,203,28.61,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13363,204,9.18,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13363,205,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13363,207,1.16,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13363,208,203,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13363,255,61.79,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13363,269,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13363,291,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13363,301,15,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13363,303,2.69,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13363,306,333,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13363,307,62,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13363,320,4,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13363,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13363,401,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13363,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13363,601,85,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13363,605,0.327,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13363,606,3.69,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13364,203,29.9,'100g',3,1,'2004-07-15','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13364,204,8.37,'100g',3,1,'2004-07-15','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13364,205,0,'100g',3,1,'2004-07-15','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13364,207,1.16,'100g',3,1,'2004-07-15','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13364,208,203,'100g',3,1,'2004-07-15','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13364,255,61.02,'100g',3,1,'2004-07-15','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13364,269,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13364,291,0,'100g',3,1,'2004-07-15','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13364,301,14,'100g',3,1,'2004-07-15','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13364,303,2.98,'100g',3,1,'2004-07-15','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13364,306,339,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13364,307,64,'100g',3,1,'2004-07-15','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13364,320,1,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13364,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13364,401,0,'100g',3,1,'2004-07-15','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13364,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13364,601,90,'100g',3,1,'2004-07-15','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13364,605,0.259,'100g',NULL,1,'2004-07-15','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13364,606,3.247,'100g',3,1,'2004-07-15','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13365,203,29.51,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13365,204,8.87,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13365,205,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13365,207,1.16,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13365,208,206,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13365,255,60.93,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13365,269,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13365,291,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13365,301,14,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13365,303,2.98,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13365,306,338,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13365,307,63,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13365,320,1,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13365,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13365,401,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13365,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13365,601,89,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13365,605,0.272,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13365,606,3.374,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13366,203,29.88,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13366,204,7.12,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13366,205,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13366,207,1.18,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13366,208,188,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13366,255,62.48,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13366,269,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13366,291,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13366,301,14,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13366,303,2.88,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13366,306,346,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13366,307,64,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13366,320,2,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13366,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13366,401,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13366,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13366,601,89,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13366,605,0.263,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13366,606,2.7,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13367,203,26.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13367,204,19.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13367,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13367,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13367,208,291,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13367,255,51.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13367,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13367,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13367,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13367,303,2.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13367,306,259,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13367,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13367,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (13367,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13367,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13367,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13367,601,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13367,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13367,606,7.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13368,203,29.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13368,204,10.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13368,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13368,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13368,208,218,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13368,255,57.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13368,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13368,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13368,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13368,303,2.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13368,306,285,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13368,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13368,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (13368,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13368,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13368,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13368,601,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13368,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13368,606,3.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13369,203,32.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13369,204,8.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13369,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13369,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13369,208,213,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13369,255,58.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13369,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13369,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13369,301,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13369,303,2.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13369,306,264,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13369,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13369,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13369,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13369,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13369,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13369,601,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13369,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13369,606,3.152,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13370,203,33.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13370,204,6.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13370,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13370,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13370,208,205,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13370,255,59.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13370,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13370,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13370,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13370,303,2.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13370,306,267,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13370,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13370,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13370,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13370,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13370,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13370,601,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13370,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13370,606,2.647,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13371,203,23.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13371,204,28.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13371,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13371,207,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13371,208,358,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13371,255,46.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13371,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13371,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13371,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13371,303,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13371,306,233,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13371,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13371,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13371,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13371,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13371,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13371,601,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13371,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13371,606,11.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13372,203,28.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13372,204,13.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13372,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13372,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13372,208,244,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13372,255,55.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13372,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13372,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13372,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13372,303,2.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13372,306,273,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13372,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13372,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13372,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13372,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13372,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13372,601,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13372,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13372,606,5.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13373,203,28.94,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13373,204,19.17,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13373,205,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13373,207,0.9,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13373,208,297,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13373,255,51.9,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13373,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13373,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13373,301,16,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13373,303,2.42,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13373,306,231,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13373,307,47,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13373,320,0,'100g',1,1,'2024-12-12','2003-01-06');
INSERT INTO `cndb_nutval` VALUES (13373,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13373,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13373,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13373,601,116,'100g',3,1,'2006-02-23','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13373,605,NULL,'100g',NULL,1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (13373,606,7.548,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13375,203,29.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13375,204,17.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13375,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13375,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13375,208,283,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13375,255,53.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13375,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13375,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13375,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13375,303,2.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13375,306,235,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13375,307,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13375,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13375,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13375,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13375,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13375,601,115,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13375,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13375,606,6.911,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13377,203,33.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13377,204,7.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13377,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13377,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13377,208,212,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13377,255,58.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13377,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13377,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13377,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13377,303,2.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13377,306,262,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13377,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13377,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13377,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13377,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13377,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13377,601,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13377,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13377,606,2.903,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13378,203,33.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13378,204,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13378,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13378,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13378,208,195,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13378,255,61.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13378,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13378,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13378,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13378,303,2.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13378,306,270,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13378,307,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13378,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13378,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13378,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13378,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13378,601,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13378,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13378,606,2.194,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13379,203,27.18,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13379,204,24.14,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13379,205,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13379,207,0.89,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13379,208,334,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13379,255,47.92,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13379,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13379,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13379,301,13,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13379,303,3.18,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13379,306,236,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13379,307,65,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13379,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (13379,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13379,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13379,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13379,601,104,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13379,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (13379,606,9.59,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13380,203,26.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13380,204,21.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13380,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13380,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13380,208,306,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13380,255,51.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13380,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13380,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13380,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13380,303,2.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13380,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13380,307,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13380,320,8,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13380,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13380,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13380,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13380,601,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13380,605,1.193,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13380,606,8.532,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13381,203,27.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13381,204,19.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13381,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13381,207,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13381,208,288,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13381,255,53.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13381,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13381,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13381,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13381,303,2.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13381,306,261,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13381,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13381,320,8,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13381,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13381,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13381,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13381,601,98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13381,605,1.178,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13381,606,7.854,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13382,203,31.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13382,204,13.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13382,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13382,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13382,208,253,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13382,255,54.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13382,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13382,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13382,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13382,303,3.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13382,306,263,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13382,307,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13382,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (13382,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13382,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13382,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13382,601,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13382,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13382,606,5.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13383,203,30.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13383,204,11.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13383,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13383,207,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13383,208,231,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13383,255,57.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13383,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13383,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13383,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13383,303,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13383,306,307,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13383,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13383,320,2,'100g',1,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (13383,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13383,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13383,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13383,601,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13383,605,0.436,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13383,606,4.344,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13384,203,30.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13384,204,9.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13384,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13384,207,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13384,208,216,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13384,255,58.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13384,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13384,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13384,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13384,303,3.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13384,306,306,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13384,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13384,320,2,'100g',1,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (13384,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13384,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13384,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13384,601,102,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13384,605,0.418,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13384,606,3.487,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13386,203,22.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13386,204,30.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13386,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13386,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13386,208,372,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13386,255,46.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13386,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13386,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13386,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13386,303,2.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13386,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13386,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13386,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13386,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13386,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13386,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13386,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13386,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13386,606,12.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13387,203,23.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13387,204,25.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13387,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13387,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13387,208,331,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13387,255,49.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13387,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13387,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13387,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13387,303,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13387,306,300,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13387,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13387,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13387,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13387,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13387,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13387,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13387,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13387,606,10.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13388,203,27.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13388,204,13.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13388,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13388,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13388,208,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13388,255,57.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13388,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13388,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13388,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13388,303,2.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13388,306,357,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13388,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13388,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (13388,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13388,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13388,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13388,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13388,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13388,606,5.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13389,203,27.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13389,204,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13389,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13389,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13389,208,253,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13389,255,56.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13389,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13389,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13389,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13389,303,2.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13389,306,357,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13389,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13389,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13389,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13389,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13389,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13389,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13389,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13389,606,5.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13390,203,27.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13390,204,11.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13390,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13390,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13390,208,220,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13390,255,59.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13390,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13390,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13390,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13390,303,2.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13390,306,357,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13390,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13390,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13390,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13390,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13390,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13390,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13390,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13390,606,4.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13391,203,27.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13391,204,14.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13391,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13391,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13391,208,249,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13391,255,57.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13391,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13391,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13391,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13391,303,1.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13391,306,340,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13391,307,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13391,320,0,'100g',1,1,'2024-12-12','2003-01-08');
INSERT INTO `cndb_nutval` VALUES (13391,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13391,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13391,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13391,601,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13391,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13391,606,5.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13392,203,24.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13392,204,22.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13392,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13392,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13392,208,312,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13392,255,51.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13392,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13392,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13392,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13392,303,2.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13392,306,342,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13392,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13392,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13392,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13392,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13392,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13392,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13392,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13392,606,9.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13393,203,24.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13393,204,19.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13393,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13393,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13393,208,285,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13393,255,52.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13393,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13393,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13393,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13393,303,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13393,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13393,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13393,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13393,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13393,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13393,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13393,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13393,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13393,606,8.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13394,203,29.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13394,204,7.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13394,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13394,207,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13394,208,193,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13394,255,62.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13394,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13394,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13394,301,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13394,303,1.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13394,306,376,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13394,307,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13394,320,0,'100g',1,1,'2024-12-12','2003-01-08');
INSERT INTO `cndb_nutval` VALUES (13394,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13394,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13394,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13394,601,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13394,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13394,606,2.868,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13395,203,28.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13395,204,11.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13395,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13395,207,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13395,208,225,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13395,255,58.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13395,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13395,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13395,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13395,303,2.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13395,306,394,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13395,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13395,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13395,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13395,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13395,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13395,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13395,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13395,606,4.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13396,203,28.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13396,204,8.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13396,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13396,207,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13396,208,198,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13396,255,60.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13396,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13396,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13396,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13396,303,2.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13396,306,394,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13396,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13396,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13396,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13396,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13396,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13396,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13396,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13396,606,3.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13398,203,33.56,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13398,204,8.86,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13398,205,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13398,207,1,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13398,208,223,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13398,255,57.33,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13398,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13398,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13398,301,8,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13398,303,2.72,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13398,306,271,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13398,307,44,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13398,320,0,'100g',1,1,'2024-12-12','2003-01-08');
INSERT INTO `cndb_nutval` VALUES (13398,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13398,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13398,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13398,601,95,'100g',3,1,'2006-02-23','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13398,605,NULL,'100g',NULL,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13398,606,3.184,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13399,203,27.42,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13399,204,7.72,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13399,205,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13399,207,1.09,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13399,208,187,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13399,255,64.46,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13399,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13399,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13399,301,7,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13399,303,2.24,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13399,306,223,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13399,307,36,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13399,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13399,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13399,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13399,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13399,601,79,'100g',3,1,'2006-02-23','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13399,605,NULL,'100g',NULL,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13399,606,2.773,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13401,203,32.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13401,204,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13401,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13401,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13401,208,230,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13401,255,56.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13401,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13401,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13401,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13401,303,2.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13401,306,264,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13401,307,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13401,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13401,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13401,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13401,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13401,601,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13401,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13401,606,3.593,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13402,203,26.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13402,204,9.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13402,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13402,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13402,208,199,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13402,255,63.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13402,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13402,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13402,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13402,303,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13402,306,215,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13402,307,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13402,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13402,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13402,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13402,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13402,601,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13402,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13402,606,3.366,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13404,203,34.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13404,204,7.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13404,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13404,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13404,208,217,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13404,255,57.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13404,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13404,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13404,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13404,303,2.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13404,306,279,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13404,307,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13404,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13404,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13404,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13404,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13404,601,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13404,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13404,606,2.775,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13405,203,28.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13405,204,6.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13405,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13405,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13405,208,175,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13405,255,65.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13405,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13405,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13405,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13405,303,2.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13405,306,232,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13405,307,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13405,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13405,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13405,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13405,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13405,601,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13405,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13405,606,2.179,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13407,203,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13407,204,7.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13407,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13407,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13407,208,214,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13407,255,58.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13407,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13407,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13407,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13407,303,2.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13407,306,278,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13407,307,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13407,320,0,'100g',1,1,'2024-12-12','2003-01-08');
INSERT INTO `cndb_nutval` VALUES (13407,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13407,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13407,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13407,601,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13407,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13407,606,2.675,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13408,203,27.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13408,204,6.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13408,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13408,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13408,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13408,255,65.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13408,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13408,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13408,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13408,303,2.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13408,306,228,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13408,307,36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13408,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13408,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13408,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13408,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13408,601,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13408,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13408,606,2.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13410,203,33.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13410,204,9.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13410,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13410,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13410,208,223,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13410,255,57.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13410,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13410,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13410,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13410,303,2.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13410,306,271,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13410,307,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13410,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13410,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13410,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13410,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13410,601,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13410,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13410,606,3.152,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13411,203,27.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13411,204,7.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13411,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13411,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13411,208,185,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13411,255,64.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13411,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13411,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13411,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13411,303,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13411,306,222,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13411,307,36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13411,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13411,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13411,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13411,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13411,601,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13411,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13411,606,2.661,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13413,203,34.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13413,204,6.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13413,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13413,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13413,208,206,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13413,255,58.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13413,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13413,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13413,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13413,303,2.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13413,306,289,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13413,307,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13413,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13413,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13413,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13413,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13413,601,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13413,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13413,606,2.198,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13414,203,28.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13414,204,5.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13414,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13414,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13414,208,169,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13414,255,65.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13414,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13414,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13414,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13414,303,2.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13414,306,238,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13414,307,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13414,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13414,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13414,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13414,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13414,601,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13414,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13414,606,1.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13415,203,29.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13415,204,4.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13415,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13415,207,1.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13415,208,167,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13415,255,65.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13415,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13415,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13415,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13415,303,1.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13415,306,401,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13415,307,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13415,320,4,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (13415,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13415,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13415,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13415,601,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13415,605,0.214,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13415,606,1.615,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13416,203,29.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13416,204,4.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13416,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13416,207,1.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13416,208,171,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13416,255,64.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13416,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13416,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13416,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13416,303,1.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13416,306,408,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13416,307,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13416,320,4,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (13416,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13416,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13416,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13416,601,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13416,605,0.213,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13416,606,1.656,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13417,203,29.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13417,204,3.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13417,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13417,207,1.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13417,208,162,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13417,255,65.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13417,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13417,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13417,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13417,303,1.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13417,306,392,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13417,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13417,320,6,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13417,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13417,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13417,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13417,601,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13417,605,0.215,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13417,606,1.555,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13418,203,29.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13418,204,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13418,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13418,207,1.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13418,208,163,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13418,255,65.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13418,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13418,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13418,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13418,303,1.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13418,306,404,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13418,307,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13418,320,1,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13418,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13418,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13418,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13418,601,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13418,605,0.177,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13418,606,1.375,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13419,203,29.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13419,204,4.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13419,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13419,207,1.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13419,208,166,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13419,255,64.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13419,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13419,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13419,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13419,303,1.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13419,306,411,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13419,307,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13419,320,2,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13419,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13419,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13419,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13419,601,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13419,605,0.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13419,606,1.439,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13420,203,29.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13420,204,3.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13420,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13420,207,1.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13420,208,157,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13420,255,66.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13420,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13420,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13420,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13420,303,1.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13420,306,394,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13420,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13420,320,3,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13420,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13420,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13420,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13420,601,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13420,605,0.173,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13420,606,1.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13421,203,26.79,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13421,204,8.21,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13421,205,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13421,207,1.11,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13421,208,188,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13421,255,64.67,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13421,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13421,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13421,301,6,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13421,303,2.18,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13421,306,217,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13421,307,35,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13421,320,0,'100g',1,1,'2024-12-12','2003-01-08');
INSERT INTO `cndb_nutval` VALUES (13421,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13421,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13421,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13421,601,78,'100g',3,1,'2006-02-23','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13421,605,NULL,'100g',NULL,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13421,606,3.007,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13422,203,27.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13422,204,8.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13422,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13422,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13422,208,196,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13422,255,63.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13422,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13422,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13422,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13422,303,2.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13422,306,216,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13422,307,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13422,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13422,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13422,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13422,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13422,601,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13422,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13422,606,3.257,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13423,203,26.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13423,204,7.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13423,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13423,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13423,208,181,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13423,255,65.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13423,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13423,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13423,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13423,303,2.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13423,306,218,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13423,307,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13423,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13423,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13423,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13423,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13423,601,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13423,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13423,606,2.756,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13424,203,27.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13424,204,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13424,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13424,207,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13424,208,174,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13424,255,66.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13424,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13424,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13424,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13424,303,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13424,306,226,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13424,307,36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13424,320,0,'100g',1,1,'2024-12-12','2003-01-06');
INSERT INTO `cndb_nutval` VALUES (13424,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13424,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13424,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13424,601,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13424,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13424,606,2.209,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13425,203,27.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13425,204,6.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13425,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13425,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13425,208,176,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13425,255,65.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13425,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13425,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13425,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13425,303,2.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13425,306,225,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13425,307,36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13425,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13425,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13425,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13425,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13425,601,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13425,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13425,606,2.288,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13426,203,27.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13426,204,4.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13426,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13426,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13426,208,149,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13426,255,67.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13426,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13426,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13426,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13426,303,2.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13426,306,230,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13426,307,36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13426,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13426,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13426,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13426,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13426,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13426,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13426,606,1.563,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13428,203,35.62,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13428,204,6.31,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13428,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13428,207,1.72,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13428,208,209,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13428,255,57.9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13428,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13428,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13428,301,4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13428,303,3.27,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13428,306,330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13428,307,45,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13428,320,0,'100g',2,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (13428,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13428,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13428,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13428,601,90,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13428,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (13428,606,2.25,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13430,203,35.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13430,204,7.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13430,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13430,207,1.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13430,208,216,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13430,255,57.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13430,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13430,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13430,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13430,303,3.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13430,306,330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13430,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13430,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13430,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13430,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13430,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13430,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13430,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13430,606,2.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13432,203,35.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13432,204,5.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13432,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13432,207,1.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13432,208,200,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13432,255,58.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13432,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13432,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13432,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13432,303,3.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13432,306,330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13432,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13432,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13432,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13432,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13432,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13432,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13432,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13432,606,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13436,203,36.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13436,204,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13436,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13436,207,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13436,208,207,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13436,255,58.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13436,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13436,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13436,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13436,303,3.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13436,306,334,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13436,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13436,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13436,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13436,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13436,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13436,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13436,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13436,606,1.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13438,203,36.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13438,204,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13438,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13438,207,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13438,208,190,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13438,255,59.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13438,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13438,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13438,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13438,303,3.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13438,306,334,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13438,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13438,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13438,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13438,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13438,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13438,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13438,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13438,606,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13439,203,30.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13439,204,8.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13439,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13439,207,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13439,208,211,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13439,255,60.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13439,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13439,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13439,301,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13439,303,3.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13439,306,350,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13439,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13439,320,7,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (13439,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13439,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13439,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13439,601,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13439,605,0.477,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13439,606,3.525,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13440,203,30.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13440,204,9.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13440,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13440,207,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13440,208,217,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13440,255,59.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13440,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13440,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13440,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13440,303,3.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13440,306,356,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13440,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13440,320,7,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (13440,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13440,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13440,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13440,601,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13440,605,0.518,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13440,606,3.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13441,203,30.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13441,204,7.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13441,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13441,207,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13441,208,202,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13441,255,61.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13441,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13441,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13441,301,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13441,303,3.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13441,306,348,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13441,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13441,320,7,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (13441,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13441,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13441,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13441,601,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13441,605,0.414,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13441,606,3.036,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13442,203,30.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13442,204,8.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13442,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13442,207,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13442,208,198,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13442,255,60.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13442,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13442,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13442,301,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13442,303,3.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13442,306,390,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13442,307,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13442,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (13442,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13442,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13442,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13442,601,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13442,605,0.438,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13442,606,3.296,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13443,203,30.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13443,204,9.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13443,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13443,207,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13443,208,211,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13443,255,60.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13443,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13443,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13443,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13443,303,4.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13443,306,443,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13443,307,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13443,320,1,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (13443,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13443,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13443,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13443,601,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13443,605,0.472,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13443,606,3.576,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13444,203,31.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13444,204,7.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13444,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13444,207,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13444,208,198,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13444,255,61.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13444,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13444,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13444,301,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13444,303,3.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13444,306,359,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13444,307,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13444,320,2,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13444,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13444,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13444,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13444,601,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13444,605,0.388,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13444,606,2.876,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13445,203,28.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13445,204,11.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13445,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13445,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13445,208,223,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13445,255,59.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13445,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13445,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13445,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13445,303,3.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13445,306,366,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13445,307,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13445,320,7,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (13445,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13445,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13445,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13445,601,81,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13445,605,0.626,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13445,606,4.534,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13446,203,28.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13446,204,12.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13446,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13446,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13446,208,233,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13446,255,58.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13446,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13446,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13446,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13446,303,3.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13446,306,361,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13446,307,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13446,320,7,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (13446,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13446,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13446,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13446,601,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13446,605,0.679,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13446,606,5.111,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13447,203,29.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13447,204,9.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13447,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13447,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13447,208,207,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13447,255,61.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13447,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13447,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13447,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13447,303,3.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13447,306,371,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13447,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13447,320,6,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (13447,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13447,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13447,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13447,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13447,605,0.548,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13447,606,3.667,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13448,203,29.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13448,204,8.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13448,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13448,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13448,208,202,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13448,255,61.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13448,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13448,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13448,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13448,303,3.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13448,306,376,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13448,307,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13448,320,2,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13448,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13448,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13448,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13448,601,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13448,605,0.437,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13448,606,3.413,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13449,203,29.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13449,204,9.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13449,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13449,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13449,208,211,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13449,255,60.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13449,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13449,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13449,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13449,303,3.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13449,306,367,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13449,307,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13449,320,1,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13449,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13449,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13449,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13449,601,87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13449,605,0.472,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13449,606,3.899,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13450,203,29.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13450,204,6.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13450,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13450,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13450,208,189,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13450,255,63.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13450,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13450,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13450,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13450,303,3.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13450,306,375,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13450,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13450,320,2,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13450,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13450,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13450,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13450,601,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13450,605,0.385,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13450,606,2.685,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13451,203,29.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13451,204,9.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13451,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13451,207,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13451,208,212,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13451,255,60.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13451,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13451,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13451,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13451,303,1.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13451,306,368,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13451,307,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13451,320,0,'100g',1,1,'2024-12-12','2003-01-08');
INSERT INTO `cndb_nutval` VALUES (13451,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13451,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13451,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13451,601,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13451,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13451,606,3.754,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13452,203,29.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13452,204,10.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13452,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13452,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13452,208,219,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13452,255,59.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13452,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13452,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13452,301,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13452,303,1.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13452,306,355,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13452,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13452,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13452,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13452,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13452,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13452,601,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13452,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13452,606,4.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13453,203,29.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13453,204,8.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13453,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13453,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13453,208,206,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13453,255,60.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13453,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13453,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13453,301,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13453,303,1.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13453,306,381,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13453,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13453,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13453,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13453,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13453,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13453,601,87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13453,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13453,606,3.417,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13454,203,30.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13454,204,5.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13454,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13454,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13454,208,183,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13454,255,62.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13454,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13454,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13454,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13454,303,1.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13454,306,393,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13454,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13454,320,0,'100g',1,1,'2024-12-12','2003-01-08');
INSERT INTO `cndb_nutval` VALUES (13454,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13454,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13454,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13454,601,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13454,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13454,606,2.205,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13455,203,30.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13455,204,6.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13455,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13455,207,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13455,208,188,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13455,255,62.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13455,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13455,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13455,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13455,303,2.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13455,306,380,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13455,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13455,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13455,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13455,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13455,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13455,601,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13455,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13455,606,2.495,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13456,203,30.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13456,204,5.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13456,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13456,207,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13456,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13456,255,63.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13456,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13456,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13456,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13456,303,1.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13456,306,410,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13456,307,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13456,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13456,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13456,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13456,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13456,601,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13456,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13456,606,1.915,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13459,203,23.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13459,204,19.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13459,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13459,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13459,208,276,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13459,255,54.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13459,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13459,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13459,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13459,303,2.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13459,306,299,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13459,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13459,320,0,'100g',2,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13459,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13459,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13459,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13459,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13459,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13459,606,7.271,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13460,203,23.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13460,204,20.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13460,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13460,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13460,208,283,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13460,255,53.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13460,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13460,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13460,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13460,303,2.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13460,306,278,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13460,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13460,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13460,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13460,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13460,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13460,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13460,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13460,606,7.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13463,203,24.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13463,204,17.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13463,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13463,207,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13463,208,267,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13463,255,55.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13463,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13463,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13463,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13463,303,2.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13463,306,330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13463,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13463,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13463,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13463,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13463,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13463,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13463,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13463,606,7.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13464,203,22.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13464,204,6.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13464,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13464,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13464,208,155,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13464,255,70.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13464,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13464,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13464,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13464,303,2.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13464,306,274,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13464,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13464,320,2,'100g',2,1,'2024-12-12','2013-01-06');
INSERT INTO `cndb_nutval` VALUES (13464,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13464,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13464,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13464,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13464,605,0.325,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13464,606,2.557,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13465,203,28.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13465,204,10.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13465,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13465,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13465,208,213,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13465,255,61.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13465,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13465,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13465,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13465,303,3.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13465,306,291,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13465,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13465,320,7,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13465,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13465,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13465,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13465,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13465,605,0.532,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13465,606,4.026,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13466,203,26.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13466,204,11.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13466,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13466,207,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13466,208,212,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13466,255,60.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13466,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13466,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13466,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13466,303,3.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13466,306,328,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13466,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13466,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13466,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13466,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13466,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13466,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13466,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13466,606,3.912,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13467,203,25.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13467,204,12.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13467,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13467,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13467,208,224,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13467,255,59.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13467,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13467,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13467,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13467,303,3.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13467,306,301,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13467,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13467,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (13467,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13467,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13467,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13467,601,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13467,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13467,606,4.345,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13468,203,22.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13468,204,5.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13468,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13468,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13468,208,145,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13468,255,71.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13468,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13468,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13468,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13468,303,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13468,306,266,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13468,307,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13468,320,4,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13468,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13468,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13468,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13468,601,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13468,605,0.278,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13468,606,2.051,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13469,203,28.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13469,204,8.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13469,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13469,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13469,208,203,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13469,255,62.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13469,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13469,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13469,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13469,303,3.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13469,306,292,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13469,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13469,320,2,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13469,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13469,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13469,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13469,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13469,605,0.483,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13469,606,3.454,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13470,203,26.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13470,204,8.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13470,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13470,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13470,208,194,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13470,255,62.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13470,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13470,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13470,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13470,303,3.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13470,306,367,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13470,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13470,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (13470,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13470,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13470,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13470,601,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13470,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13470,606,3.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13473,203,24.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13473,204,15.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13473,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13473,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13473,208,247,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13473,255,57.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13473,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13473,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13473,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13473,303,3.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13473,306,302,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13473,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13473,320,0,'100g',2,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13473,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13473,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13473,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13473,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13473,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13473,606,6.074,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13474,203,24.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13474,204,17.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13474,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13474,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13474,208,258,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13474,255,56.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13474,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13474,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13474,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13474,303,3.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13474,306,300,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13474,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13474,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13474,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13474,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13474,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13474,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13474,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13474,606,6.449,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13477,203,24.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13477,204,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13477,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13477,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13477,208,230,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13477,255,58.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13477,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13477,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13477,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13477,303,3.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13477,306,305,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13477,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13477,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13477,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13477,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13477,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13477,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13477,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13477,606,5.527,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13478,203,22.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13478,204,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13478,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13478,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13478,208,153,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13478,255,70.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13478,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13478,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13478,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13478,303,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13478,306,267,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13478,307,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13478,320,2,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13478,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13478,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13478,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13478,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13478,605,0.292,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13478,606,2.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13479,203,27.86,'100g',1,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13479,204,10.37,'100g',1,1,'2010-01-04','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13479,205,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (13479,207,1.05,'100g',1,1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (13479,208,212,'100g',3,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13479,255,61.15,'100g',1,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13479,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13479,291,0,'100g',4,1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (13479,301,18,'100g',1,1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (13479,303,3.57,'100g',1,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13479,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13479,307,67,'100g',1,1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (13479,320,2,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13479,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13479,401,0,'100g',4,1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (13479,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13479,601,82,'100g',1,1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (13479,605,0.572,'100g',NULL,1,'2010-01-04','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13479,606,4.219,'100g',3,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13481,203,25.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13481,204,9.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13481,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13481,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13481,208,198,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13481,255,62.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13481,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13481,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13481,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13481,303,3.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13481,306,327,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13481,307,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13481,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (13481,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13481,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13481,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13481,601,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13481,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13481,606,3.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13482,203,22.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13482,204,5.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13482,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13482,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13482,208,144,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13482,255,71.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13482,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13482,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13482,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13482,303,1.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13482,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13482,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13482,320,2,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13482,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13482,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13482,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13482,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13482,605,0.274,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13482,606,2.152,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13483,203,28.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13483,204,9.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13483,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13483,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13483,208,206,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13483,255,61.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13483,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13483,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13483,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13483,303,3.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13483,306,304,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13483,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13483,320,2,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13483,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13483,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13483,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13483,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13483,605,0.537,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13483,606,3.648,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13484,203,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13484,204,7.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13484,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13484,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13484,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13484,255,63.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13484,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13484,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13484,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13484,303,3.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13484,306,327,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13484,307,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13484,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (13484,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13484,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13484,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13484,601,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13484,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13484,606,2.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13485,203,33.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13485,204,5.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13485,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13485,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13485,208,198,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13485,255,59.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13485,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13485,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13485,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13485,303,2.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13485,306,279,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13485,307,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13485,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13485,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13485,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13485,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13485,601,102,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13485,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13485,606,2.241,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13486,203,20.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13486,204,7.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13486,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13486,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13486,208,151,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13486,255,72.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13486,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13486,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13486,301,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13486,303,1.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13486,306,318,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13486,307,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13486,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13486,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13486,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13486,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13486,601,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13486,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13486,606,2.778,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13487,203,20.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13487,204,7.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13487,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13487,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13487,208,156,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13487,255,71.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13487,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13487,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13487,301,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13487,303,1.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13487,306,309,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13487,307,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13487,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13487,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13487,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13487,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13487,601,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13487,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13487,606,3.066,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13488,203,20.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13488,204,6.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13488,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13488,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13488,208,145,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13488,255,72.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13488,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13488,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13488,301,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13488,303,1.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13488,306,327,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13488,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13488,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13488,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13488,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13488,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13488,601,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13488,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13488,606,2.489,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13490,203,29.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13490,204,6.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13490,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13490,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13490,208,182,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13490,255,63.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13490,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13490,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13490,301,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13490,303,1.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13490,306,392,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13490,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13490,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13490,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13490,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13490,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13490,601,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13490,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13490,606,2.305,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13491,203,30.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13491,204,3.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13491,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13491,207,1.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13491,208,162,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13491,255,64.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13491,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13491,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13491,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13491,303,3.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13491,306,435,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13491,307,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13491,320,3,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13491,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13491,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13491,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13491,601,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13491,605,0.191,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13491,606,1.556,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13492,203,30.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13492,204,4.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13492,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13492,207,1.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13492,208,166,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13492,255,64.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13492,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13492,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13492,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13492,303,3.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13492,306,429,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13492,307,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13492,320,3,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13492,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13492,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13492,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13492,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13492,605,0.18,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13492,606,1.562,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13493,203,29.81,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13493,204,3.37,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13493,205,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13493,207,1.26,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13493,208,158,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13493,255,65.87,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13493,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13493,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13493,301,19,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13493,303,3.26,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13493,306,438,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13493,307,76,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13493,320,3,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13493,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13493,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13493,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13493,601,88,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13493,605,0.178,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13493,606,1.278,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13494,203,25.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13494,204,17.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13494,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13494,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13494,208,270,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13494,255,55.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13494,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13494,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13494,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13494,303,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13494,306,328,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13494,307,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13494,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (13494,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13494,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13494,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13494,601,89,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13494,605,1.147,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13494,606,6.942,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13495,203,23.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13495,204,15.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13495,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13495,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13495,208,241,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13495,255,58.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13495,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13495,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13495,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13495,303,2.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13495,306,241,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13495,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13495,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (13495,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13495,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13495,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13495,601,88,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13495,605,1.173,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13495,606,6.073,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13496,203,22.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13496,204,15.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13496,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13496,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13496,208,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13496,255,59.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13496,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13496,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13496,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13496,303,2.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13496,306,308,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13496,307,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13496,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (13496,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13496,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13496,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13496,601,84,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13496,605,1.27,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13496,606,6.075,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13497,203,25.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13497,204,18.66,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13497,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13497,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13497,208,277,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13497,255,55.85,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13497,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13497,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13497,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13497,303,2.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13497,306,275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13497,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13497,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (13497,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13497,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13497,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13497,601,88,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13497,605,1.168,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13497,606,7.344,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13498,203,14.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13498,204,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13498,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13498,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13498,208,332,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13498,255,54.3,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13498,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13498,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13498,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13498,303,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13498,306,218,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13498,307,66,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13498,320,4,'100g',1,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (13498,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13498,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13498,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13498,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13498,605,1.82,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13498,606,11.754,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13499,203,19.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13499,204,8.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13499,205,0.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13499,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13499,208,157,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13499,255,70.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13499,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13499,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13499,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13499,303,2.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13499,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13499,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13499,320,2,'100g',2,1,'2024-12-12','2010-01-05');
INSERT INTO `cndb_nutval` VALUES (13499,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13499,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13499,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13499,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13499,605,0.514,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13499,606,3.449,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13500,203,28.15,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13500,204,9.23,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13500,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13500,207,1.13,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13500,208,196,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13500,255,62.11,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13500,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13500,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13500,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13500,303,3.14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13500,306,390,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13500,307,87,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13500,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13500,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13500,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13500,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13500,601,95,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13500,605,0.369,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13500,606,3.771,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13501,203,28.28,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13501,204,9.83,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13501,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13501,207,1.04,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13501,208,202,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13501,255,61.73,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13501,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13501,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13501,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13501,303,3.23,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13501,306,389,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13501,307,85,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13501,320,1,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13501,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13501,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13501,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13501,601,93,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13501,605,0.357,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13501,606,3.984,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13502,203,27.96,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13502,204,8.34,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13502,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13502,207,1.27,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13502,208,187,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13502,255,62.67,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13502,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13502,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13502,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13502,303,3.07,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13502,306,394,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13502,307,89,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13502,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13502,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13502,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13502,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13502,601,98,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13502,605,0.388,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13502,606,3.451,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13519,203,20.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13519,204,6.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13519,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13519,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13519,208,139,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13519,255,72.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13519,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13519,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13519,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13519,303,2.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13519,306,338,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13519,307,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13519,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13519,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13519,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13519,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13519,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13519,605,0.262,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13519,606,2.73,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13520,203,20.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13520,204,6.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13520,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13520,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13520,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13520,255,71.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13520,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13520,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13520,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13520,303,2.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13520,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13520,307,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13520,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13520,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13520,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13520,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13520,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13520,605,0.259,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13520,606,2.9,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13523,203,20.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13523,204,5.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13523,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13523,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13523,208,133,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13523,255,73.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13523,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13523,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13523,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13523,303,2.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13523,306,346,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13523,307,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13523,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13523,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13523,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13523,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13523,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13523,605,0.268,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13523,606,2.472,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13595,203,21.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13595,204,5.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13595,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13595,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13595,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13595,255,72.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13595,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13595,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13595,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13595,303,2.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13595,306,362,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13595,307,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13595,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13595,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13595,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13595,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13595,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13595,605,0.202,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13595,606,1.844,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13596,203,21.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13596,204,5.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13596,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13596,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13596,208,137,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13596,255,72.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13596,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13596,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13596,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13596,303,2.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13596,306,367,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13596,307,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13596,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13596,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13596,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13596,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13596,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13596,605,0.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13596,606,1.993,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13597,203,21.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13597,204,4.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13597,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13597,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13597,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13597,255,73.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13597,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13597,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13597,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13597,303,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13597,306,353,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13597,307,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13597,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13597,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13597,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13597,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13597,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13597,605,0.185,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13597,606,1.58,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13598,203,27.59,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13598,204,11.07,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13598,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13598,207,1.11,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13598,208,210,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13598,255,61.04,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13598,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13598,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13598,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13598,303,3.04,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13598,306,379,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13598,307,85,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13598,320,7,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13598,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13598,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13598,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13598,601,95,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13598,605,0.506,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13598,606,4.528,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13647,203,21.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13647,204,4.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13647,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13647,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13647,208,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13647,255,73.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13647,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13647,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13647,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13647,303,2.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13647,306,399,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13647,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13647,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13647,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13647,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13647,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13647,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13647,605,0.191,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13647,606,1.653,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13648,203,21.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13648,204,4.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13648,205,0.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13648,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13648,208,125,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13648,255,72.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13648,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13648,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13648,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13648,303,2.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13648,306,408,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13648,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13648,320,2,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13648,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13648,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13648,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13648,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13648,605,0.176,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13648,606,1.709,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13649,203,21.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13649,204,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13649,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13649,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13649,208,121,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13649,255,73.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13649,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13649,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13649,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13649,303,2.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13649,306,386,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13649,307,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13649,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13649,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13649,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13649,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13649,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13649,605,0.207,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13649,606,1.53,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13650,203,27.51,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13650,204,12.26,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13650,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13650,207,1.02,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13650,208,220,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13650,255,60.31,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13650,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13650,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13650,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13650,303,3.11,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13650,306,374,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13650,307,84,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13650,320,6,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13650,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13650,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13650,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13650,601,92,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (13650,605,0.536,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13650,606,4.968,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13786,203,19.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13786,204,11.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13786,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13786,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13786,208,180,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13786,255,68.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13786,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13786,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13786,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13786,303,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13786,306,332,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13786,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13786,320,4,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13786,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13786,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13786,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13786,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13786,605,0.688,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13786,606,5.042,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13788,203,19.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13788,204,12.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13788,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13788,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13788,208,185,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13788,255,68.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13788,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13788,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13788,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13788,303,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13788,306,310,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13788,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13788,320,4,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13788,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13788,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13788,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13788,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13788,605,0.688,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13788,606,5.072,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13791,203,19.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13791,204,10.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13791,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13791,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13791,208,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13791,255,69.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13791,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13791,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13791,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13791,303,2.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13791,306,367,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13791,307,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13791,320,4,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13791,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13791,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13791,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13791,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13791,605,0.687,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13791,606,4.998,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13795,203,20.01,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13795,204,14.42,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13795,205,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13795,207,0.96,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13795,208,215,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13795,255,64.81,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13795,269,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13795,291,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13795,301,17,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13795,303,1.69,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13795,306,283,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13795,307,52,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13795,320,2,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13795,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13795,401,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13795,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13795,601,72,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13795,605,0.464,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13795,606,6.036,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13796,203,26.11,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13796,204,16.59,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13796,205,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13796,207,1.01,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13796,208,259,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13796,255,56.97,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13796,269,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13796,291,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13796,301,13,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13796,303,2.2,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13796,306,271,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13796,307,50,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13796,320,3,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (13796,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13796,401,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13796,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13796,601,87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13796,605,0.592,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13796,606,6.782,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13797,203,19.79,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13797,204,15.42,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13797,205,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13797,207,0.94,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13797,208,224,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13797,255,63.98,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13797,269,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13797,291,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13797,301,17,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13797,303,1.73,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13797,306,276,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13797,307,50,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13797,320,2,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13797,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13797,401,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13797,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13797,601,72,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13797,605,0.488,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13797,606,6.43,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13798,203,25.85,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13798,204,17.68,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13798,205,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13798,207,0.99,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13798,208,268,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13798,255,55.96,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13798,269,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13798,291,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13798,301,13,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13798,303,2.24,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13798,306,265,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13798,307,49,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13798,320,3,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13798,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13798,401,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13798,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13798,601,89,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13798,605,0.622,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13798,606,7.243,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13799,203,19.06,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13799,204,12.4,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13799,205,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13799,207,0.92,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13799,208,193,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13799,255,61.88,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13799,269,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13799,291,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13799,301,17,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13799,303,1.52,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13799,306,279,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13799,307,51,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13799,320,2,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13799,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13799,401,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13799,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13799,601,68,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13799,605,0.381,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13799,606,5.219,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13800,203,26.06,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13800,204,15.09,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13800,205,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13800,207,1.04,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13800,208,245,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13800,255,58.68,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13800,269,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13800,291,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13800,301,13,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13800,303,2.11,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13800,306,262,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13800,307,51,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13800,320,3,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13800,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13800,401,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13800,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13800,601,85,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13800,605,0.521,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13800,606,6.163,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13803,203,18.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13803,204,19.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13803,205,0.56,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13803,207,0.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13803,208,253,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13803,255,61.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13803,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13803,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13803,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13803,303,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13803,306,282,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13803,307,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13803,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13803,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13803,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13803,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13803,601,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13803,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13803,606,7.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13804,203,25.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13804,204,24.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13804,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13804,207,0.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13804,208,331,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13804,255,49.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13804,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13804,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13804,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13804,303,2.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13804,306,251,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13804,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13804,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (13804,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13804,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13804,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13804,601,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13804,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13804,606,9.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13805,203,17.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13805,204,22.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13805,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13805,207,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13805,208,277,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13805,255,59.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13805,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13805,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13805,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13805,303,1.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13805,306,276,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13805,307,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13805,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13805,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13805,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13805,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13805,601,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13805,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13805,606,8.951,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13806,203,28.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13806,204,18.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13806,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13806,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13806,208,289,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13806,255,52.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13806,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13806,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13806,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13806,303,2.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13806,306,232,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13806,307,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13806,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13806,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13806,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13806,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13806,601,106,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13806,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13806,606,7.305,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13807,203,17.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13807,204,20.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13807,205,0.59,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13807,207,0.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13807,208,267,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13807,255,59.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13807,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13807,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13807,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13807,303,1.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13807,306,264,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13807,307,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13807,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13807,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13807,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13807,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13807,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13807,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13807,606,8.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13808,203,24.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13808,204,27.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13808,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13808,207,0.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13808,208,349,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13808,255,48.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13808,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13808,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13808,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13808,303,2.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13808,306,241,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13808,307,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13808,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13808,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13808,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13808,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13808,601,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13808,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13808,606,10.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13809,203,19.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13809,204,17.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13809,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13809,207,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13809,208,244,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13809,255,62.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13809,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13809,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13809,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13809,303,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13809,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13809,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13809,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13809,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13809,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13809,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13809,601,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13809,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13809,606,7.254,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13810,203,30.12,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13810,204,19.22,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13810,205,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13810,207,0.92,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13810,208,302,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13810,255,50.45,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13810,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13810,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13810,301,17,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13810,303,2.53,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13810,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13810,307,50,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13810,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13810,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13810,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13810,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13810,601,120,'100g',3,1,'2006-02-23','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13810,605,NULL,'100g',NULL,1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (13810,606,7.62,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13811,203,19.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13811,204,18.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13811,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13811,207,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13811,208,249,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13811,255,61.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13811,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13811,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13811,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13811,303,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13811,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13811,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13811,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13811,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13811,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13811,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13811,601,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13811,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13811,606,7.492,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13812,203,30.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13812,204,19.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13812,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13812,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13812,208,309,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13812,255,49.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13812,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13812,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13812,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13812,303,2.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13812,306,241,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13812,307,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13812,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13812,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13812,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13812,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13812,601,121,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13812,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13812,606,7.902,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13813,203,19.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13813,204,17.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13813,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13813,207,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13813,208,239,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13813,255,62.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13813,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13813,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13813,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13813,303,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13813,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13813,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13813,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13813,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13813,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13813,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13813,601,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13813,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13813,606,7.016,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13814,203,30.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13814,204,18.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13814,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13814,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13814,208,295,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13814,255,51.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13814,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13814,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13814,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13814,303,2.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13814,306,243,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13814,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13814,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13814,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13814,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13814,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13814,601,119,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13814,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13814,606,7.337,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13815,203,17.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13815,204,19.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13815,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13815,207,0.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13815,208,248,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13815,255,61.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13815,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13815,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13815,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13815,303,2.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13815,306,271,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13815,307,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13815,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (13815,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13815,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13815,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13815,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13815,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13815,606,7.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13816,203,26.78,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13816,204,25.12,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13816,205,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13816,207,0.88,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13816,208,341,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13816,255,47.67,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13816,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13816,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13816,301,13,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13816,303,3.13,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13816,306,233,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13816,307,65,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13816,320,0,'100g',1,1,'2024-12-12','2004-01-11');
INSERT INTO `cndb_nutval` VALUES (13816,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13816,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13816,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13816,601,104,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13816,605,NULL,'100g',NULL,1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (13816,606,10,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13817,203,16.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13817,204,21.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13817,205,0.97,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13817,207,0.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13817,208,268,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13817,255,59.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13817,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13817,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13817,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13817,303,2.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13817,306,267,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13817,307,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13817,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13817,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13817,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13817,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13817,601,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13817,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13817,606,8.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13818,203,26.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13818,204,27.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13818,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13818,207,0.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13818,208,359,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13818,255,46.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13818,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13818,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13818,301,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13818,303,3.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13818,306,230,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13818,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13818,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (13818,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13818,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13818,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13818,601,103,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13818,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13818,606,10.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13819,203,17.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13819,204,17.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13819,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13819,207,0.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13819,208,230,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13819,255,62.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13819,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13819,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13819,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13819,303,2.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13819,306,276,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13819,307,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13819,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (13819,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13819,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13819,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13819,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13819,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13819,606,6.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13820,203,27.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13820,204,22.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13820,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13820,207,0.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13820,208,318,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13820,255,49.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13820,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13820,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13820,301,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13820,303,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13820,306,237,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13820,307,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13820,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13820,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13820,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13820,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13820,601,104,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13820,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13820,606,8.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13821,203,26.65,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13821,204,8.46,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13821,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13821,207,1,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13821,208,183,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13821,255,64.79,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13821,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13821,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13821,301,19,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13821,303,2.47,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13821,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13821,307,80,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13821,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13821,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13821,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13821,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13821,601,83,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (13821,605,0.373,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13821,606,3.422,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13822,203,26.41,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13822,204,9.36,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13822,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13822,207,0.99,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13822,208,190,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13822,255,63.88,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13822,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13822,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13822,301,18,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13822,303,2.52,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13822,306,339,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13822,307,79,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13822,320,1,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13822,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13822,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13822,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13822,601,84,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (13822,605,0.402,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13822,606,3.751,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13823,203,27.02,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13823,204,7.12,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13823,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13823,207,1.01,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13823,208,172,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13823,255,66.16,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13823,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13823,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13823,301,20,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13823,303,2.42,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13823,306,351,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13823,307,81,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13823,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13823,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13823,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13823,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13823,601,81,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13823,605,0.329,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13823,606,2.929,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13824,203,16.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13824,204,26.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13824,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13824,207,0.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13824,208,306,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13824,255,55.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13824,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13824,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13824,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13824,303,1.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13824,306,272,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13824,307,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13824,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (13824,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13824,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13824,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13824,601,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13824,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13824,606,10.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13825,203,22.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13825,204,26.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13825,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13825,207,1.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13825,208,337,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13825,255,48.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13825,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13825,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13825,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13825,303,2.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13825,306,315,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13825,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13825,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (13825,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13825,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13825,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13825,601,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13825,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13825,606,10.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13826,203,22.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13826,204,28.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13826,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13826,207,0.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13826,208,351,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13826,255,48.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13826,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13826,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13826,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13826,303,2.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13826,306,305,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13826,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13826,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (13826,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13826,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13826,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13826,601,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13826,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13826,606,11.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13827,203,16.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13827,204,27.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13827,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13827,207,0.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13827,208,322,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13827,255,53.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13827,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13827,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13827,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13827,303,1.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13827,306,267,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13827,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13827,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (13827,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13827,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13827,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13827,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13827,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13827,606,11.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13828,203,22.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13828,204,28.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13828,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13828,207,1.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13828,208,352,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13828,255,47.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13828,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13828,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13828,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13828,303,2.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13828,306,313,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13828,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13828,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (13828,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13828,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13828,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13828,601,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13828,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13828,606,11.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13829,203,22.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13829,204,29.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13829,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13829,207,0.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13829,208,365,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13829,255,46.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13829,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13829,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13829,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13829,303,2.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13829,306,302,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13829,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13829,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (13829,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13829,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13829,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13829,601,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13829,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13829,606,12.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13830,203,16.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13830,204,23.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13830,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13830,207,0.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13830,208,288,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13830,255,57.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13830,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13830,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13830,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13830,303,1.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13830,306,278,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13830,307,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13830,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (13830,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13830,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13830,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13830,601,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13830,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13830,606,9.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13831,203,22.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13831,204,24.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13831,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13831,207,1.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13831,208,315,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13831,255,50.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13831,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13831,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13831,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13831,303,2.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13831,306,321,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13831,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13831,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (13831,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13831,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13831,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13831,601,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13831,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13831,606,9.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13832,203,23.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13832,204,25.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13832,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13832,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13832,208,330,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13832,255,49.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13832,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13832,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13832,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13832,303,2.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13832,306,310,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13832,307,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13832,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (13832,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13832,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13832,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13832,601,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13832,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13832,606,10.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13833,203,16.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13833,204,31.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13833,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13833,207,0.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13833,208,355,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13833,255,51.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13833,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13833,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13833,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13833,303,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13833,306,263,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13833,307,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13833,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (13833,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13833,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13833,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13833,601,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13833,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13833,606,13.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13834,203,21.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13834,204,32.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13834,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13834,207,0.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13834,208,386,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13834,255,44.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13834,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13834,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13834,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13834,303,2.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13834,306,310,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13834,307,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13834,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13834,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13834,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13834,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13834,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13834,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13834,606,13.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13835,203,22.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13835,204,33.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13835,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13835,207,0.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13835,208,400,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13835,255,43.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13835,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13835,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13835,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13835,303,2.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13835,306,304,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13835,307,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13835,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13835,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13835,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13835,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13835,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13835,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13835,606,13.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13838,203,16.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13838,204,27.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13838,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13838,207,0.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13838,208,316,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13838,255,54.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13838,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13838,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13838,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13838,303,1.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13838,306,260,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13838,307,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13838,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13838,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13838,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13838,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13838,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13838,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13838,606,11.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13839,203,21.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13839,204,27.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13839,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13839,207,1.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13839,208,338,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13839,255,48.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13839,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13839,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13839,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13839,303,2.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13839,306,309,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13839,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13839,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13839,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13839,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13839,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13839,601,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13839,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13839,606,11.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13840,203,23.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13840,204,28.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13840,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13840,207,0.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13840,208,355,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13840,255,47.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13840,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13840,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13840,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13840,303,2.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13840,306,293,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13840,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13840,320,0,'100g',1,1,'2024-12-12','2004-01-11');
INSERT INTO `cndb_nutval` VALUES (13840,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13840,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13840,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13840,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13840,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13840,606,11.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13841,203,16.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13841,204,29.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13841,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13841,207,0.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13841,208,333,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13841,255,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13841,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13841,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13841,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13841,303,1.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13841,306,254,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13841,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13841,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13841,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13841,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13841,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13841,601,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13841,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13841,606,12.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13842,203,20.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13842,204,31.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13842,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13842,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13842,208,370,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13842,255,45.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13842,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13842,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13842,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13842,303,2.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13842,306,297,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13842,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13842,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13842,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13842,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13842,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13842,601,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13842,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13842,606,12.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13843,203,22.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13843,204,31.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13843,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13843,207,0.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13843,208,378,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13843,255,45.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13843,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13843,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13843,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13843,303,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13843,306,286,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13843,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13843,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13843,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13843,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13843,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13843,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13843,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13843,606,12.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13844,203,16.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13844,204,24.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13844,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13844,207,0.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13844,208,295,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13844,255,56.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13844,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13844,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13844,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13844,303,1.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13844,306,266,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13844,307,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13844,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13844,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13844,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13844,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13844,601,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13844,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13844,606,10.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13845,203,21.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13845,204,25.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13845,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13845,207,1.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13845,208,324,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13845,255,50.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13845,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13845,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13845,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13845,303,2.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13845,306,309,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13845,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13845,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13845,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13845,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13845,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13845,601,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13845,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13845,606,10.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13846,203,23.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13846,204,25.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13846,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13846,207,0.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13846,208,333,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13846,255,49.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13846,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13846,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13846,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13846,303,2.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13846,306,299,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13846,307,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13846,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13846,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13846,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13846,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13846,601,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13846,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13846,606,10.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13847,203,15.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13847,204,33.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13847,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13847,207,0.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13847,208,367,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13847,255,50.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13847,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13847,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13847,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13847,303,1.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13847,306,248,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13847,307,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13847,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13847,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13847,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13847,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13847,601,73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13847,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13847,606,13.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13848,203,20.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13848,204,34.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13848,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13848,207,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13848,208,404,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13848,255,43.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13848,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13848,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13848,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13848,303,2.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13848,306,298,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13848,307,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13848,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13848,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13848,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13848,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13848,601,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13848,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13848,606,14.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13849,203,22.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13849,204,32.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13849,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13849,207,0.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13849,208,393,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13849,255,44.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13849,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13849,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13849,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13849,303,2.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13849,306,291,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13849,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13849,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13849,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13849,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13849,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13849,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13849,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13849,606,13.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13850,203,19.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13850,204,19.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13850,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13850,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13850,208,254,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13850,255,61.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13850,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13850,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13850,301,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13850,303,1.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13850,306,295,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13850,307,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13850,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13850,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13850,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13850,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13850,601,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13850,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13850,606,7.692,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13851,203,25.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13851,204,20.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13851,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13851,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13851,208,291,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13851,255,53.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13851,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13851,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13851,301,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13851,303,1.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13851,306,323,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13851,307,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13851,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13851,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13851,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13851,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13851,601,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13851,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13851,606,7.894,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13852,203,22.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13852,204,27.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13852,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13852,207,1.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13852,208,341,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13852,255,48.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13852,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13852,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13852,301,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13852,303,2.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13852,306,324,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13852,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13852,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13852,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13852,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13852,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13852,601,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13852,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13852,606,10.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13853,203,19.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13853,204,20.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13853,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13853,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13853,208,263,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13853,255,60.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13853,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13853,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13853,301,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13853,303,1.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13853,306,293,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13853,307,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13853,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13853,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13853,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13853,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13853,601,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13853,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13853,606,8.121,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13854,203,24.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13854,204,22.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13854,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13854,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13854,208,304,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13854,255,52.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13854,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13854,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13854,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13854,303,1.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13854,306,298,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13854,307,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13854,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13854,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13854,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13854,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13854,601,94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13854,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13854,606,8.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13855,203,22.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13855,204,29.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13855,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13855,207,1.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13855,208,359,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13855,255,47.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13855,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13855,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13855,301,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13855,303,2.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13855,306,319,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13855,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13855,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13855,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13855,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13855,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13855,601,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13855,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13855,606,11.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13856,203,19.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13856,204,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13856,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13856,207,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13856,208,246,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13856,255,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13856,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13856,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13856,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13856,303,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13856,306,297,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13856,307,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13856,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13856,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13856,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13856,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13856,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13856,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13856,606,7.264,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13857,203,27.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13857,204,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13857,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13857,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13857,208,278,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13857,255,54.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13857,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13857,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13857,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13857,303,1.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13857,306,349,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13857,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13857,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13857,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13857,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13857,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13857,601,103,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13857,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13857,606,7.088,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13858,203,22.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13858,204,25.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13858,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13858,207,1.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13858,208,323,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13858,255,50.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13858,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13858,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13858,301,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13858,303,2.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13858,306,328,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13858,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13858,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13858,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13858,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13858,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13858,601,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13858,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13858,606,10.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13859,203,16.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13859,204,29.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13859,205,0.06,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13859,207,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13859,208,335,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13859,255,53.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13859,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13859,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13859,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13859,303,1.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13859,306,286,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13859,307,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13859,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13859,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13859,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13859,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13859,601,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13859,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13859,606,12.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13860,203,24.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13860,204,27.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13860,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13860,207,1.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13860,208,354,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13860,255,47.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13860,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13860,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13860,301,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13860,303,2.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13860,306,332,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13860,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13860,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13860,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13860,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13860,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13860,601,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13860,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13860,606,11.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13861,203,22.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13861,204,35.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13861,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13861,207,0.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13861,208,411,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13861,255,41.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13861,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13861,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13861,301,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13861,303,1.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13861,306,323,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13861,307,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13861,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (13861,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13861,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13861,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13861,601,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13861,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13861,606,14.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13862,203,27.7,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13862,204,9.29,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13862,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13862,207,1.25,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13862,208,194,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13862,255,62.15,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13862,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13862,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13862,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13862,303,3.02,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13862,306,388,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13862,307,88,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13862,320,7,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13862,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13862,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13862,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13862,601,98,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13862,605,0.461,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13862,606,3.868,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13863,203,20.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13863,204,7.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13863,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13863,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13863,208,146,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13863,255,71.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13863,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13863,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13863,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13863,303,2.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13863,306,335,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13863,307,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13863,320,3,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13863,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13863,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13863,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13863,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13863,605,0.331,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13863,606,3.153,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13864,203,20.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13864,204,11.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13864,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13864,207,0.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13864,208,195,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13864,255,65.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13864,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13864,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13864,301,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13864,303,1.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13864,306,342,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13864,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13864,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (13864,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13864,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13864,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13864,601,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13864,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13864,606,4.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13865,203,27.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13865,204,12.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13865,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13865,207,1.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13865,208,235,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13865,255,56.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13865,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13865,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13865,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13865,303,2.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13865,306,395,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13865,307,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13865,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (13865,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13865,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13865,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13865,601,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13865,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13865,606,4.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13866,203,20.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13866,204,10.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13866,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13866,207,0.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13866,208,184,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13866,255,66.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13866,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13866,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13866,301,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13866,303,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13866,306,342,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13866,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13866,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13866,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13866,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13866,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13866,601,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13866,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13866,606,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13867,203,27.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13867,204,11.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13867,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13867,207,1.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13867,208,218,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13867,255,58.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13867,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13867,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13867,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13867,303,2.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13867,306,395,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13867,307,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13867,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13867,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13867,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13867,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13867,601,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13867,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13867,606,4.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13868,203,20.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13868,204,11.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13868,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13868,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13868,208,192,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13868,255,66.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13868,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13868,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13868,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13868,303,1.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13868,306,327,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13868,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13868,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13868,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13868,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13868,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13868,601,73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13868,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13868,606,4.544,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13869,203,32.76,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13869,204,11.87,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13869,205,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13869,207,0.98,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13869,208,247,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13869,255,54.97,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13869,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13869,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13869,301,8,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13869,303,2.67,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13869,306,266,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13869,307,43,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13869,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13869,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13869,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13869,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13869,601,100,'100g',3,1,'2006-02-23','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13869,605,NULL,'100g',NULL,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13869,606,4.506,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13870,203,26.41,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13870,204,11.64,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13870,205,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13870,207,1.05,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13870,208,218,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13870,255,61.6,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13870,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13870,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13870,301,6,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13870,303,2.16,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13870,306,214,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13870,307,35,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13870,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13870,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13870,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13870,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13870,601,85,'100g',3,1,'2006-02-23','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13870,605,NULL,'100g',NULL,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13870,606,4.418,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13871,203,20.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13871,204,12.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13871,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13871,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13871,208,198,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13871,255,66.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13871,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13871,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13871,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13871,303,1.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13871,306,319,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13871,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13871,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13871,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13871,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13871,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13871,601,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13871,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13871,606,4.784,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13872,203,32.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13872,204,12.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13872,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13872,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13872,208,254,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13872,255,54.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13872,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13872,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13872,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13872,303,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13872,306,263,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13872,307,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13872,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13872,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13872,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13872,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13872,601,101,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13872,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13872,606,4.766,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13873,203,26.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13873,204,12.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13873,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13873,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13873,208,223,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13873,255,61.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13873,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13873,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13873,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13873,303,2.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13873,306,210,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13873,307,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13873,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13873,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13873,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13873,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13873,601,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13873,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13873,606,4.721,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13874,203,20.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13874,204,10.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13874,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13874,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13874,208,187,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13874,255,67.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13874,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13874,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13874,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13874,303,1.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13874,306,335,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13874,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13874,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13874,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13874,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13874,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13874,601,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13874,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13874,606,4.303,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13875,203,32.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13875,204,11.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13875,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13875,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13875,208,240,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13875,255,55.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13875,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13875,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13875,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13875,303,2.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13875,306,269,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13875,307,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13875,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13875,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13875,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13875,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13875,601,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13875,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13875,606,4.247,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13876,203,26.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13876,204,10.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13876,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13876,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13876,208,212,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13876,255,62.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13876,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13876,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13876,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13876,303,2.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13876,306,219,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13876,307,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13876,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13876,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13876,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13876,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13876,601,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13876,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13876,606,4.116,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13877,203,21.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13877,204,8.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13877,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13877,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13877,208,166,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13877,255,69.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13877,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13877,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13877,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13877,303,1.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13877,306,340,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13877,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13877,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13877,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13877,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13877,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13877,601,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13877,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13877,606,3.245,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13878,203,28.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13878,204,9.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13878,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13878,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13878,208,208,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13878,255,61.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13878,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13878,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13878,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13878,303,2.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13878,306,227,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13878,307,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13878,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13878,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13878,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13878,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13878,601,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13878,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13878,606,3.664,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13879,203,21.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13879,204,8.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13879,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13879,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13879,208,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13879,255,68.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13879,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13879,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13879,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13879,303,1.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13879,306,334,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13879,307,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13879,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13879,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13879,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13879,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13879,601,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13879,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13879,606,3.509,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13880,203,28.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13880,204,10.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13880,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13880,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13880,208,212,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13880,255,61.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13880,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13880,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13880,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13880,303,2.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13880,306,227,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13880,307,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13880,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13880,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13880,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13880,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13880,601,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13880,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13880,606,3.813,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13881,203,21.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13881,204,7.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13881,205,0.08,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13881,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13881,208,160,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (13881,255,70.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13881,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13881,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13881,301,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13881,303,1.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13881,306,346,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13881,307,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13881,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13881,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13881,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13881,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13881,601,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13881,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13881,606,2.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13882,203,28.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13882,204,9.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13882,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13882,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13882,208,204,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13882,255,62.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13882,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13882,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13882,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13882,303,2.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13882,306,228,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13882,307,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13882,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13882,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13882,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13882,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13882,601,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13882,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13882,606,3.515,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13883,203,19.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13883,204,11.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13883,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13883,207,0.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13883,208,189,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13883,255,66.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13883,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13883,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13883,301,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13883,303,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13883,306,329,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13883,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13883,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (13883,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13883,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13883,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13883,601,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13883,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13883,606,4.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13884,203,27.45,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13884,204,11.34,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13884,205,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13884,207,1.13,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13884,208,219,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13884,255,61.56,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13884,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13884,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13884,301,6,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13884,303,2.81,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13884,306,367,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13884,307,63,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13884,320,0,'100g',1,1,'2024-12-12','2004-01-11');
INSERT INTO `cndb_nutval` VALUES (13884,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13884,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13884,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13884,601,82,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13884,605,NULL,'100g',NULL,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13884,606,4.24,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (13885,203,19.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13885,204,12.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13885,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13885,207,0.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13885,208,199,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13885,255,65.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13885,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13885,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13885,301,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13885,303,1.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13885,306,326,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13885,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13885,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13885,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13885,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13885,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13885,601,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13885,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13885,606,5.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13886,203,27.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13886,204,12.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13886,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13886,207,1.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13886,208,228,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13886,255,60.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13886,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13886,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13886,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13886,303,2.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13886,306,365,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13886,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13886,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (13886,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13886,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13886,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13886,601,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13886,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13886,606,4.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13887,203,19.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13887,204,10.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13887,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13887,207,0.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13887,208,178,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13887,255,66.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13887,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13887,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13887,301,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13887,303,2.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13887,306,332,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13887,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13887,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13887,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13887,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13887,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13887,601,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13887,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13887,606,4.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13888,203,27.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13888,204,10.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13888,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13888,207,1.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13888,208,210,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13888,255,62.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13888,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13888,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13888,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13888,303,2.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13888,306,370,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13888,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13888,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (13888,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13888,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13888,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13888,601,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13888,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13888,606,3.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13889,203,20.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13889,204,7.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13889,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13889,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13889,208,152,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13889,255,71.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13889,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13889,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13889,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13889,303,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13889,306,336,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13889,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13889,320,3,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13889,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13889,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13889,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13889,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13889,605,0.347,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13889,606,3.462,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13890,203,33.93,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (13890,204,8.33,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (13890,205,2.03,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (13890,207,1.53,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (13890,208,228,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (13890,255,54.18,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (13890,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13890,291,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (13890,301,6,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (13890,303,3.4,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (13890,306,484,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13890,307,65,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (13890,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (13890,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13890,401,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (13890,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13890,601,102,'100g',3,1,'2007-12-03','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13890,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (13890,606,2.399,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (13891,203,22.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13891,204,7.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13891,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13891,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13891,208,166,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13891,255,69.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13891,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13891,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13891,301,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13891,303,1.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13891,306,349,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13891,307,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13891,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13891,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13891,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13891,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13891,601,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13891,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13891,606,3.123,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13892,203,34.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13892,204,10.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13892,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13892,207,1.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13892,208,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13892,255,54.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13892,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13892,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13892,301,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13892,303,3.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13892,306,319,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13892,307,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13892,320,0,'100g',1,1,'2024-12-12','2004-01-11');
INSERT INTO `cndb_nutval` VALUES (13892,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13892,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13892,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13892,601,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13892,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13892,606,3.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13893,203,30.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13893,204,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13893,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13893,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13893,208,204,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13893,255,59.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13893,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13893,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13893,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13893,303,2.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13893,306,252,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13893,307,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13893,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13893,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13893,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13893,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13893,601,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13893,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13893,606,3.415,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13894,203,21.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13894,204,8.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13894,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13894,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13894,208,168,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13894,255,68.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13894,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13894,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13894,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13894,303,1.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13894,306,341,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13894,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13894,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13894,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13894,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13894,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13894,601,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13894,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13894,606,3.224,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13895,203,34.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13895,204,11.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13895,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13895,207,1.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13895,208,250,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13895,255,53.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13895,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13895,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13895,301,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13895,303,3.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13895,306,317,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13895,307,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13895,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13895,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13895,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13895,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13895,601,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13895,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13895,606,4.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13896,203,30.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13896,204,10.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13896,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13896,207,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13896,208,224,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13896,255,58.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13896,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13896,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13896,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13896,303,2.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13896,306,248,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13896,307,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13896,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13896,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13896,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13896,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13896,601,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13896,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13896,606,3.898,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13897,203,32.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13897,204,13.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13897,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13897,207,1.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13897,208,266,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13897,255,52.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13897,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13897,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13897,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13897,303,2.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13897,306,480,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13897,307,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13897,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (13897,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13897,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13897,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13897,601,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13897,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13897,606,4.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13898,203,22.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13898,204,7.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13898,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13898,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13898,208,164,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13898,255,69.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13898,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13898,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13898,301,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13898,303,1.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13898,306,357,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13898,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13898,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13898,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13898,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13898,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13898,601,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13898,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13898,606,3.023,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13899,203,34.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13899,204,8.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13899,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13899,207,1.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13899,208,225,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13899,255,55.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13899,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13899,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13899,301,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13899,303,3.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13899,306,321,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13899,307,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13899,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13899,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13899,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13899,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13899,601,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13899,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13899,606,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13900,203,30.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13900,204,7.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13900,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13900,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13900,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13900,255,60.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13900,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13900,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13900,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13900,303,2.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13900,306,256,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13900,307,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13900,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13900,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13900,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13900,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13900,601,87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13900,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13900,606,2.933,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13901,203,22.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13901,204,8.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13901,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13901,207,1.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13901,208,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13901,255,68.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13901,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13901,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13901,301,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13901,303,2.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13901,306,371,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13901,307,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13901,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13901,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13901,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13901,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13901,601,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13901,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13901,606,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13902,203,31.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13902,204,10.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13902,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13902,207,1.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13902,208,225,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13902,255,59.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13902,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13902,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13902,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13902,303,2.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13902,306,436,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13902,307,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13902,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13902,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13902,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13902,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13902,601,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13902,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13902,606,3.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13903,203,20.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13903,204,6.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13903,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13903,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13903,208,137,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13903,255,73.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13903,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13903,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13903,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13903,303,2.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13903,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13903,307,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13903,320,3,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13903,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13903,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13903,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13903,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13903,605,0.306,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13903,606,2.69,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13904,203,20.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13904,204,9.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13904,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13904,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13904,208,165,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13904,255,69.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13904,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13904,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13904,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13904,303,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13904,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13904,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13904,320,4,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13904,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13904,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13904,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13904,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13904,605,0.501,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13904,606,3.592,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13905,203,20.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13905,204,14.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13905,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13905,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13905,208,218,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13905,255,64.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13905,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13905,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13905,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13905,303,1.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13905,306,246,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13905,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13905,320,4,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (13905,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13905,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13905,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13905,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13905,605,0.861,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13905,606,6.171,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13906,203,24.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13906,204,19.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13906,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13906,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13906,208,284,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13906,255,54.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13906,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13906,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13906,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13906,303,2.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13906,306,255,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13906,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13906,320,7,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (13906,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13906,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13906,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13906,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13906,605,1.162,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13906,606,7.905,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13907,203,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13907,204,15.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13907,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13907,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13907,208,228,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13907,255,63.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13907,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13907,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13907,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13907,303,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13907,306,229,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13907,307,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13907,320,4,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (13907,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13907,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13907,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13907,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13907,605,0.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13907,606,6.684,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13908,203,24.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13908,204,21.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13908,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13908,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13908,208,294,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13908,255,53.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13908,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13908,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13908,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13908,303,3.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13908,306,240,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13908,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13908,320,7,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (13908,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13908,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13908,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13908,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13908,605,1.299,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13908,606,8.722,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13909,203,20.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13909,204,15.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13909,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13909,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13909,208,228,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13909,255,63.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13909,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13909,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13909,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13909,303,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13909,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13909,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13909,320,0,'100g',1,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13909,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13909,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13909,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13909,601,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13909,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13909,606,6.251,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13910,203,26.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13910,204,16.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13910,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13910,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13910,208,264,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13910,255,56.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13910,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13910,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13910,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13910,303,1.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13910,306,328,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13910,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13910,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13910,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13910,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13910,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13910,601,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13910,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13910,606,6.608,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13911,203,19.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13911,204,17.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13911,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13911,207,0.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13911,208,237,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13911,255,61.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13911,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13911,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13911,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13911,303,1.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13911,306,302,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13911,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13911,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13911,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13911,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13911,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13911,601,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13911,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13911,606,6.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13912,203,26.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13912,204,18.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13912,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13912,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13912,208,278,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13912,255,54.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13912,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13912,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13912,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13912,303,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13912,306,316,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13912,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13912,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13912,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13912,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13912,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13912,601,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13912,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13912,606,7.264,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13913,203,20.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13913,204,15.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13913,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13913,207,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13913,208,224,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13913,255,63.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13913,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13913,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13913,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13913,303,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13913,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13913,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13913,320,0,'100g',1,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13913,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13913,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13913,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13913,601,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13913,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13913,606,6.067,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13914,203,26.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13914,204,15.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13914,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13914,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13914,208,250,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13914,255,57.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13914,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13914,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13914,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13914,303,1.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13914,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13914,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13914,320,0,'100g',1,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13914,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13914,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13914,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13914,601,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13914,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13914,606,5.951,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13915,203,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13915,204,22.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13915,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13915,207,0.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13915,208,281,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13915,255,58.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13915,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13915,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13915,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13915,303,1.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13915,306,295,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13915,307,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13915,320,0,'100g',1,1,'2024-12-12','2008-01-05');
INSERT INTO `cndb_nutval` VALUES (13915,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13915,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13915,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13915,601,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13915,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13915,606,9.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13916,203,25.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13916,204,22.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13916,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13916,207,1.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13916,208,310,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13916,255,51.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13916,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13916,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13916,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13916,303,2.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13916,306,354,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13916,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13916,320,0,'100g',1,1,'2024-12-12','2008-01-05');
INSERT INTO `cndb_nutval` VALUES (13916,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13916,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13916,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13916,601,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13916,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13916,606,8.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13917,203,19.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13917,204,18.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13917,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13917,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13917,208,247,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13917,255,61.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13917,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13917,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13917,301,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13917,303,1.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13917,306,302,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13917,307,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13917,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13917,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13917,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13917,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13917,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13917,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13917,606,8.41,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13918,203,26.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13918,204,17.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13918,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13918,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13918,208,267,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13918,255,56.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13918,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13918,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13918,301,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13918,303,1.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13918,306,329,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13918,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13918,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13918,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13918,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13918,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13918,601,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13918,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13918,606,6.743,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13919,203,23.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13919,204,24.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13919,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13919,207,1.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13919,208,324,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13919,255,48.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13919,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13919,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13919,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13919,303,3.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13919,306,331,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13919,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13919,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13919,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13919,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13919,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13919,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13919,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13919,606,9.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13920,203,19.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13920,204,17.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13920,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13920,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13920,208,246,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13920,255,61.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13920,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13920,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13920,301,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13920,303,1.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13920,306,303,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13920,307,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13920,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13920,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13920,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13920,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13920,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13920,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13920,606,7.214,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13921,203,26.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13921,204,17.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13921,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13921,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13921,208,273,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13921,255,55.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13921,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13921,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13921,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13921,303,1.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13921,306,318,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13921,307,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13921,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13921,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13921,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13921,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13921,601,99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13921,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13921,606,7.001,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13922,203,23.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13922,204,25.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13922,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13922,207,1.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13922,208,331,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13922,255,47.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13922,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13922,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13922,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13922,303,3.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13922,306,407,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13922,307,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13922,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13922,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13922,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13922,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13922,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13922,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13922,606,10.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13923,203,19.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13923,204,18.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13923,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13923,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13923,208,249,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13923,255,61.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13923,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13923,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13923,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13923,303,1.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13923,306,300,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13923,307,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13923,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13923,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13923,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13923,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13923,601,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13923,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13923,606,7.451,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13924,203,26.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13924,204,16.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13924,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13924,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13924,208,262,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13924,255,56.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13924,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13924,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13924,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13924,303,1.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13924,306,340,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13924,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13924,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13924,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13924,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13924,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13924,601,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13924,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13924,606,6.511,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13925,203,23.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13925,204,23.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13925,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13925,207,1.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13925,208,316,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13925,255,48.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13925,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13925,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13925,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13925,303,3.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13925,306,331,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13925,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13925,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13925,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13925,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13925,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13925,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13925,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13925,606,9.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13926,203,18.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13926,204,21.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13926,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13926,207,0.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13926,208,274,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13926,255,59.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13926,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13926,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13926,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13926,303,2.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13926,306,304,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13926,307,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13926,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13926,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13926,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13926,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13926,601,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13926,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13926,606,8.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13927,203,25.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13927,204,22.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13927,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13927,207,1.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13927,208,308,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13927,255,51.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13927,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13927,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13927,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13927,303,3.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13927,306,368,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13927,307,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13927,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (13927,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13927,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13927,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13927,601,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13927,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13927,606,8.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13928,203,24.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13928,204,26.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13928,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13928,207,1.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13928,208,343,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13928,255,48.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13928,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13928,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13928,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13928,303,3.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13928,306,336,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13928,307,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13928,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (13928,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13928,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13928,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13928,601,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13928,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13928,606,10.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13929,203,20.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13929,204,12.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13929,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13929,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13929,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13929,255,66.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13929,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13929,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13929,301,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13929,303,1.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13929,306,315,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13929,307,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13929,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13929,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13929,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13929,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13929,601,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13929,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13929,606,5.127,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13930,203,26.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13930,204,14.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13930,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13930,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13930,208,243,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13930,255,58.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13930,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13930,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13930,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13930,303,1.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13930,306,336,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13930,307,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13930,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13930,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13930,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13930,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13930,601,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13930,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13930,606,5.603,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13931,203,19.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13931,204,14.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13931,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13931,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13931,208,214,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13931,255,64.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13931,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13931,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13931,301,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13931,303,1.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13931,306,309,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13931,307,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13931,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13931,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13931,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13931,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13931,601,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13931,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13931,606,5.763,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13932,203,26.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13932,204,15.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13932,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13932,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13932,208,257,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13932,255,56.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13932,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13932,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13932,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13932,303,1.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13932,306,327,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13932,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13932,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13932,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13932,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13932,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13932,601,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13932,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13932,606,6.202,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13933,203,28.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13933,204,21.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13933,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13933,207,1.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13933,208,313,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13933,255,49.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13933,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13933,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13933,301,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13933,303,3.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13933,306,406,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13933,307,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13933,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (13933,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13933,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13933,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13933,601,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13933,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13933,606,8.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13934,203,20.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13934,204,11.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13934,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13934,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13934,208,189,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13934,255,67.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13934,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13934,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13934,301,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13934,303,1.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13934,306,321,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13934,307,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13934,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13934,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13934,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13934,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13934,601,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13934,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13934,606,4.491,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13935,203,27.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13935,204,12.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13935,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13935,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13935,208,230,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13935,255,59.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13935,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13935,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13935,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13935,303,1.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13935,306,345,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13935,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13935,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (13935,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13935,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13935,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13935,601,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13935,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13935,606,5.004,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13937,203,25.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13937,204,6.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13937,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13937,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13937,208,171,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13937,255,64.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13937,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13937,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13937,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13937,303,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13937,306,386,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13937,307,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13937,320,0,'100g',1,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (13937,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13937,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13937,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13937,601,87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13937,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13937,606,1.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13940,203,28.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13940,204,5.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13940,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13940,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13940,208,172,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13940,255,64.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13940,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13940,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13940,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13940,303,3.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13940,306,384,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13940,307,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13940,320,0,'100g',1,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (13940,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13940,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13940,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13940,601,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13940,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13940,606,2.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13943,203,28.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13943,204,6.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13943,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13943,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13943,208,178,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13943,255,64.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13943,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13943,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13943,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13943,303,2.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13943,306,372,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13943,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13943,320,1,'100g',2,1,'2024-12-12','2010-01-09');
INSERT INTO `cndb_nutval` VALUES (13943,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13943,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13943,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13943,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13943,605,0.288,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (13943,606,2.596,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13946,203,28.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13946,204,5.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13946,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13946,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13946,208,169,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13946,255,65.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13946,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13946,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13946,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13946,303,2.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13946,306,371,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13946,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13946,320,2,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13946,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13946,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13946,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13946,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13946,605,0.349,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13946,606,2.192,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13948,203,27.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13948,204,8.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13948,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13948,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13948,208,192,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13948,255,64.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13948,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13948,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13948,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13948,303,1.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13948,306,339,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13948,307,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13948,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13948,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13948,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13948,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13948,601,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13948,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13948,606,3.395,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13949,203,27.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13949,204,7.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13949,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13949,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13949,208,183,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13949,255,65.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13949,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13949,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13949,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13949,303,1.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13949,306,351,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13949,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13949,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13949,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13949,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13949,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13949,601,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13949,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13949,606,2.951,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13950,203,33.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13950,204,6.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13950,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13950,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13950,208,205,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13950,255,59.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13950,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13950,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13950,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13950,303,2.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13950,306,275,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13950,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13950,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13950,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13950,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13950,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13950,601,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13950,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13950,606,2.666,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13951,203,27.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13951,204,12.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13951,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13951,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13951,208,234,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13951,255,59.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13951,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13951,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13951,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13951,303,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13951,306,355,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13951,307,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13951,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13951,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13951,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13951,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13951,601,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13951,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13951,606,4.934,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13952,203,27.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13952,204,14.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13952,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13952,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13952,208,249,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13952,255,57.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13952,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13952,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13952,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13952,303,1.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13952,306,340,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13952,307,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13952,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13952,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13952,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13952,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13952,601,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13952,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13952,606,5.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13954,203,20.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13954,204,8.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13954,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13954,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13954,208,165,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13954,255,70.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13954,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13954,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13954,301,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13954,303,1.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13954,306,317,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13954,307,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13954,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13954,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13954,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13954,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13954,601,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13954,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13954,606,3.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13955,203,25.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13955,204,12.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13955,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13955,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13955,208,221,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13955,255,61.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13955,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13955,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13955,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13955,303,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13955,306,308,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13955,307,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13955,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13955,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13955,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13955,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13955,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13955,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13955,606,4.546,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13956,203,20.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13956,204,9.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13956,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13956,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13956,208,174,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13956,255,69.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13956,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13956,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13956,301,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13956,303,1.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13956,306,313,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13956,307,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13956,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13956,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13956,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13956,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13956,601,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13956,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13956,606,3.493,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13957,203,26.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13957,204,9.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13957,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13957,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13957,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13957,255,63.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13957,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13957,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13957,301,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13957,303,1.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13957,306,338,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13957,307,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13957,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13957,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13957,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13957,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13957,601,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13957,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13957,606,3.595,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13958,203,20.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13958,204,7.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13958,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13958,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13958,208,157,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13958,255,70.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13958,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13958,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13958,301,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13958,303,1.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13958,306,321,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13958,307,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13958,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13958,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13958,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13958,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13958,601,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13958,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13958,606,2.822,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13959,203,29.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13959,204,4.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13959,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13959,207,1.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13959,208,167,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13959,255,64.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13959,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13959,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13959,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13959,303,3.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13959,306,433,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13959,307,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13959,320,5,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13959,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13959,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13959,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13959,601,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13959,605,0.227,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13959,606,1.788,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13961,203,25.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13961,204,5.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13961,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13961,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13961,208,161,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13961,255,65.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13961,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13961,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13961,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13961,303,3.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13961,306,293,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13961,307,73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13961,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (13961,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13961,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13961,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13961,601,94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13961,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13961,606,1.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13963,203,26.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13963,204,5.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13963,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13963,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13963,208,157,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13963,255,67.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13963,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13963,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13963,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13963,303,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13963,306,293,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13963,307,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13963,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (13963,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13963,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13963,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13963,601,99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13963,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13963,606,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13965,203,26.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13965,204,11.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13965,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13965,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13965,208,217,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13965,255,61.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13965,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13965,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13965,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13965,303,2.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13965,306,304,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13965,307,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13965,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (13965,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13965,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13965,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13965,601,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13965,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13965,606,3.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13967,203,26.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13967,204,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13967,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13967,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13967,208,184,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13967,255,64.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13967,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13967,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13967,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13967,303,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13967,306,304,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13967,307,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13967,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (13967,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13967,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13967,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13967,601,94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13967,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13967,606,2.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13968,203,30.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13968,204,4.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13968,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13968,207,1.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13968,208,170,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13968,255,64.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13968,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13968,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13968,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13968,303,3.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13968,306,426,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13968,307,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13968,320,4,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13968,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13968,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13968,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13968,601,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13968,605,0.212,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13968,606,1.769,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13969,203,29.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13969,204,3.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13969,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13969,207,1.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13969,208,162,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13969,255,65.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13969,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13969,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13969,301,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13969,303,3.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13969,306,436,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13969,307,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13969,320,5,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (13969,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13969,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13969,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13969,601,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13969,605,0.212,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13969,606,1.502,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13970,203,21.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13970,204,7.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13970,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13970,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13970,208,155,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13970,255,70.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13970,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13970,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13970,301,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13970,303,1.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13970,306,328,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13970,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13970,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13970,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13970,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13970,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13970,601,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13970,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13970,606,2.978,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13971,203,21.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13971,204,6.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13971,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13971,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13971,208,145,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13971,255,71.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13971,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13971,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13971,301,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13971,303,1.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13971,306,326,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13971,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13971,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (13971,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13971,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13971,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13971,601,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13971,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13971,606,2.514,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13972,203,20.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13972,204,6.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13972,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13972,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13972,208,137,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13972,255,72.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13972,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13972,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13972,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13972,303,2.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13972,306,357,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13972,307,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13972,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13972,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13972,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13972,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13972,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13972,605,0.264,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13972,606,2.55,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13973,203,20.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13973,204,6.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13973,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13973,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13973,208,139,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13973,255,72.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13973,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13973,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13973,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13973,303,2.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13973,306,332,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13973,307,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13973,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13973,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13973,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13973,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13973,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13973,605,0.233,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13973,606,2.354,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (13974,203,20.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13974,204,5.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13974,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13974,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13974,208,133,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13974,255,72.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13974,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13974,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13974,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13974,303,2.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13974,306,393,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13974,307,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13974,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13974,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13974,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13974,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13974,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13974,605,0.34,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13974,606,1.61,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13975,203,20.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13975,204,9.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13975,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13975,207,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13975,208,169,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13975,255,69.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13975,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13975,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13975,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13975,303,1.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13975,306,349,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13975,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13975,320,4,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13975,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13975,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13975,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13975,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13975,605,0.503,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13975,606,3.704,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13977,203,26.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13977,204,10.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13977,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13977,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13977,208,205,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13977,255,61.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13977,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13977,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13977,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13977,303,2.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13977,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13977,307,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13977,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (13977,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13977,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13977,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13977,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13977,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13977,606,3.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13979,203,24.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13979,204,14.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13979,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13979,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13979,208,233,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13979,255,59.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13979,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13979,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13979,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13979,303,2.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13979,306,393,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13979,307,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13979,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (13979,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13979,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13979,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13979,601,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13979,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13979,606,5.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13980,203,28.84,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13980,204,14.95,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13980,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13980,207,0.9,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13980,208,250,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13980,255,55.94,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13980,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13980,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13980,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13980,303,3.19,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13980,306,264,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13980,307,75,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13980,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13980,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13980,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13980,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13980,601,102,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13980,605,0.962,'100g',3,1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13980,606,4.22,'100g',3,1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13981,203,28.79,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13981,204,12.08,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13981,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13981,207,0.93,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13981,208,224,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13981,255,58.71,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13981,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13981,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13981,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13981,303,3.21,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13981,306,308,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13981,307,75,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13981,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13981,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13981,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13981,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13981,601,108,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13981,605,0.798,'100g',3,1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13981,606,3.54,'100g',3,1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13982,203,28.82,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13982,204,13.8,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13982,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13982,207,0.91,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13982,208,240,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13982,255,57.05,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13982,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13982,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13982,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13982,303,3.2,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13982,306,276,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13982,307,75,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13982,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (13982,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13982,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13982,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13982,601,105,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (13982,605,0.891,'100g',3,1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13982,606,3.89,'100g',3,1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (13983,203,20.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13983,204,8.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13983,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13983,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13983,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13983,255,70.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13983,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13983,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13983,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13983,303,2.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13983,306,336,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13983,307,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13983,320,4,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (13983,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13983,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13983,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13983,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13983,605,0.497,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13983,606,3.424,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (13985,203,26.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13985,204,8.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13985,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13985,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13985,208,182,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13985,255,64.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13985,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13985,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13985,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13985,303,1.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13985,306,340,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13985,307,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13985,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (13985,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (13985,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13985,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (13985,601,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13985,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (13985,606,3.108,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14021,203,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14021,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14021,205,11.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14021,207,0.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14021,208,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14021,255,88.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14021,269,10.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14021,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14021,301,8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14021,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14021,306,4,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14021,307,10,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14021,320,0,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (14021,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14021,401,25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14021,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14021,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14021,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14021,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14031,203,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14031,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14031,205,1.25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14031,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14031,208,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14031,255,98.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14031,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14031,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14031,301,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14031,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14031,306,8,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14031,307,10,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14031,320,0,'100g',3,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (14031,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14031,401,25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14031,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14031,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14031,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14031,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14054,203,0.63,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14054,204,1.25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14054,205,9.38,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14054,207,0.37,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14054,208,50,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14054,255,88.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14054,269,8.75,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14054,291,0.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14054,301,188,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14054,303,0.53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14054,306,75,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14054,307,71,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14054,320,63,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (14054,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14054,401,4.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14054,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14054,601,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14054,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14054,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14056,203,0.83,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14056,204,0.83,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14056,205,12.83,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14056,207,0.62,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14056,208,62,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14056,255,84.88,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14056,269,11.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14056,291,1.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14056,301,19,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14056,303,0.16,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14056,306,130,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14056,307,13,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14056,320,485,'100g',1,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14056,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14056,401,42.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14056,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14056,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14056,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14056,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14058,203,58.14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14058,204,1.16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14058,205,29.07,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14058,207,10.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14058,208,359,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14058,255,0.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14058,269,1.16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14058,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14058,301,698,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14058,303,1.26,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14058,306,872,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14058,307,372,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14058,320,872,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (14058,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14058,401,34.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14058,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14058,601,12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14058,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14058,606,0.581,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14060,203,0.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14060,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14060,205,15,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14060,207,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14060,208,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14060,255,84.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14060,269,13.75,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14060,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14060,301,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14060,303,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14060,306,10,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14060,307,48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14060,320,0,'100g',3,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (14060,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14060,401,25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14060,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14060,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14060,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14060,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14061,203,0.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14061,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14061,205,0.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14061,207,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14061,208,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14061,255,99.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14061,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14061,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14061,301,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14061,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14061,306,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14061,307,42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14061,320,0,'100g',3,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (14061,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14061,401,25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14061,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14061,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14061,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14061,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14063,203,9.09,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14063,204,4.5,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14063,205,68.31,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14063,207,10.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14063,208,350,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14063,255,7.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14063,269,27.27,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14063,291,9.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14063,301,909,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14063,303,3.27,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14063,306,1705,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14063,307,500,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14063,320,0,'100g',1,1,'2024-12-12','2017-01-07');
INSERT INTO `cndb_nutval` VALUES (14063,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14063,401,54.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14063,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14063,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14063,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14063,606,0,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14064,203,0.21,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14064,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14064,205,5.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14064,207,0.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14064,208,21,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14064,255,94.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14064,269,4.17,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14064,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14064,301,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14064,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14064,306,188,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14064,307,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14064,320,10,'100g',2,1,'2024-12-12','2013-01-07');
INSERT INTO `cndb_nutval` VALUES (14064,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14064,401,30,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14064,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14064,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14064,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14064,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14066,203,78.13,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14066,204,1.56,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14066,205,6.25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14066,207,10.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14066,208,352,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14066,255,3.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14066,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14066,291,3.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14066,301,469,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14066,303,1.13,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14066,306,500,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14066,307,156,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14066,320,0,'100g',3,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (14066,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14066,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14066,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14066,601,16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14066,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14066,606,0.781,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14067,203,55.56,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14067,204,5.56,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14067,205,28.89,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14067,207,5.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14067,208,388,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14067,255,4.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14067,269,22.22,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14067,291,6.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14067,301,178,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14067,303,12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14067,306,933,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14067,307,733,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14067,320,0,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (14067,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14067,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14067,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14067,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14067,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14067,606,1.111,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14079,203,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14079,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14079,205,12.83,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14079,207,0.28,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14079,208,49,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14079,255,86.89,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14079,269,12.9,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14079,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14079,301,13,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14079,303,0.02,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14079,306,2,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14079,307,18,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14079,320,0,'100g',3,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14079,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14079,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14079,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14079,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14079,605,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14079,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14083,203,3.25,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14083,204,0.17,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14083,205,8.64,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14083,207,0.98,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14083,208,49,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14083,255,86.95,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14083,269,7.77,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14083,291,0,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14083,301,234,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14083,303,0.74,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14083,306,158,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14083,307,77,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14083,320,137,'100g',2,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (14083,328,1.5,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14083,401,3.3,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14083,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14083,601,2,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14083,605,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14083,606,0.112,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14090,203,0.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14090,204,0,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14090,205,4.24,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14090,207,0.52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14090,208,18,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14090,255,95.03,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14090,269,3.92,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14090,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14090,301,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14090,303,0.03,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14090,306,165,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14090,307,26,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14090,320,0,'100g',1,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (14090,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14090,401,9.9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14090,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14090,601,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14090,605,0,'100g',NULL,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14090,606,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14091,203,0.4,'100g',6,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14091,204,0.96,'100g',6,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14091,205,1.31,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14091,207,0.79,'100g',6,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14091,208,15,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14091,255,96.54,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14091,269,0.81,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14091,291,0.2,'100g',6,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14091,301,184,'100g',6,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14091,303,0.28,'100g',6,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14091,306,67,'100g',6,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14091,307,72,'100g',6,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14091,320,0,'100g',2,1,'2024-12-12','2016-01-10');
INSERT INTO `cndb_nutval` VALUES (14091,328,1,'100g',6,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14091,401,0,'100g',6,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14091,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14091,601,0,'100g',6,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14091,605,0,'100g',6,1,'2016-03-11','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14091,606,0.08,'100g',6,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14092,203,0.83,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14092,204,1.46,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14092,205,1.25,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14092,207,0.68,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14092,208,21,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14092,255,95.78,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14092,269,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14092,291,0.4,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14092,301,188,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14092,303,0.45,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14092,306,96,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14092,307,75,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14092,320,62,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (14092,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14092,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14092,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14092,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14092,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14092,606,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14119,203,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14119,204,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14119,205,7.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14119,207,0.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14119,208,29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14119,255,92.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14119,269,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14119,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14119,301,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14119,303,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14119,306,19,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14119,307,21,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14119,320,104,'100g',2,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (14119,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14119,401,32.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14119,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14119,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14119,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14119,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14121,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14121,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14121,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14121,207,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14121,208,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14121,255,99.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14121,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14121,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14121,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14121,303,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14121,306,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14121,307,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14121,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14121,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14121,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14121,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14121,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14121,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14121,606,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14130,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14130,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14130,205,13.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14130,207,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14130,208,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14130,255,86.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14130,269,13.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14130,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14130,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14130,303,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14130,306,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14130,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14130,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14130,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14130,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14130,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14130,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14130,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14130,606,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14136,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14136,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14136,205,8.76,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14136,207,0.01,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14136,208,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14136,255,91.23,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14136,269,8.9,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14136,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14136,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14136,303,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14136,306,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14136,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14136,320,0,'100g',1,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (14136,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14136,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14136,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14136,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14136,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14136,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14142,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14142,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14142,205,11.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14142,207,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14142,208,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14142,255,88.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14142,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14142,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14142,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14142,303,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14142,306,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14142,307,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14142,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14142,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14142,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14142,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14142,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14142,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14142,606,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14143,203,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14143,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14143,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14143,207,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14143,208,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14143,255,99.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14143,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14143,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14143,301,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14143,303,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14143,306,2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14143,307,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14143,320,0,'100g',1,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (14143,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14143,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14143,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14143,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14143,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14143,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14144,203,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14144,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14144,205,10.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14144,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14144,208,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14144,255,89.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14144,269,10.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14144,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14144,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14144,303,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14144,306,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14144,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14144,320,0,'100g',1,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (14144,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14144,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14144,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14144,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14144,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14144,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14146,203,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14146,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14146,205,0.12,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14146,207,0.03,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14146,208,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14146,255,99.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14146,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14146,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14146,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14146,303,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14146,306,7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14146,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14146,320,0,'100g',1,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (14146,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14146,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14146,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14146,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14146,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14146,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14147,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14147,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14147,205,10.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14147,207,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14147,208,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14147,255,89.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14147,269,10.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14147,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14147,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14147,303,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14147,306,3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14147,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14147,320,0,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (14147,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14147,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14147,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14147,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14147,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14147,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14148,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14148,204,0.25,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14148,205,10.36,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14148,207,0.04,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14148,208,42,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14148,255,89.36,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14148,269,9.94,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14148,291,0,'100g',4,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14148,301,1,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14148,303,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14148,306,5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14148,307,3,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14148,320,0,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (14148,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14148,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14148,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14148,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14148,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14148,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14149,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14149,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14149,205,5.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14149,207,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14149,208,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14149,255,94.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14149,269,5.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14149,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14149,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14149,303,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14149,306,3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14149,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14149,320,0,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (14149,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14149,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14149,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14149,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14149,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14149,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14150,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14150,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14150,205,12.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14150,207,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14150,208,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14150,255,87.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14150,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14150,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14150,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14150,303,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14150,306,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14150,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14150,320,0,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (14150,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14150,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14150,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14150,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14150,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14150,606,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14151,203,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14151,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14151,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14151,207,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14151,208,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14151,255,99.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14151,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14151,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14151,301,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14151,303,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14151,306,2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14151,307,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14151,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14151,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14151,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14151,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14151,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14151,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14151,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14153,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14153,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14153,205,10.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14153,207,0.03,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14153,208,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14153,255,89.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14153,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14153,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14153,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14153,303,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14153,306,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14153,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14153,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (14153,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14153,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14153,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14153,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14153,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14153,606,0.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14155,203,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14155,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14155,205,8.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14155,207,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14155,208,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14155,255,91.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14155,269,8.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14155,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14155,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14155,303,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14155,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14155,307,12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14155,320,0,'100g',1,1,'2024-12-12','2004-01-11');
INSERT INTO `cndb_nutval` VALUES (14155,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14155,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14155,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14155,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14155,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14155,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14157,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14157,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14157,205,10.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14157,207,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14157,208,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14157,255,89.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14157,269,10.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14157,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14157,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14157,303,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14157,306,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14157,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14157,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14157,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14157,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14157,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14157,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14157,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14157,606,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14161,203,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14161,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14161,205,12.26,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14161,207,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14161,208,47,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14161,255,87.74,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14161,269,11.63,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14161,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14161,301,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14161,303,0.15,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14161,306,14,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14161,307,11,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14161,320,1,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (14161,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14161,401,24.7,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14161,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14161,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14161,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14161,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14163,203,4.22,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14163,204,1.69,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14163,205,17.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14163,207,0.97,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14163,208,101,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14163,255,75.82,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14163,269,8.44,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14163,291,1.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14163,301,127,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14163,303,1.9,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14163,306,245,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14163,307,63,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14163,320,158,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (14163,328,2.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14163,401,25.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14163,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14163,601,4,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14163,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14163,606,0.422,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14164,203,3.32,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14164,204,0.97,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14164,205,8.81,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14164,207,0.95,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14164,208,57,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14164,255,85.95,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14164,269,7.81,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14164,291,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14164,301,160,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14164,303,1.14,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14164,306,191,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14164,307,60,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14164,320,171,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14164,328,2.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14164,401,3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14164,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14164,601,5,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14164,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14164,606,0.63,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14165,203,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14165,204,0.11,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14165,205,4.11,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14165,207,0.09,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14165,208,17,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14165,255,95.68,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14165,269,3.97,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14165,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14165,301,2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14165,303,0.03,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14165,306,19,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14165,307,40,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14165,320,0,'100g',1,1,'2024-12-12','2016-01-11');
INSERT INTO `cndb_nutval` VALUES (14165,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14165,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14165,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14165,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14165,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14165,606,0,'100g',4,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14166,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14166,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14166,205,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14166,207,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14166,208,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14166,255,99.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14166,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14166,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14166,301,4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14166,303,0.02,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14166,306,4,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14166,307,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14166,320,0,'100g',1,1,'2024-12-12','2002-01-12');
INSERT INTO `cndb_nutval` VALUES (14166,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14166,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14166,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14166,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14166,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14166,606,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14168,203,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14168,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14168,205,93.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14168,207,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14168,208,372,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14168,255,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14168,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14168,291,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14168,301,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14168,303,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14168,306,104,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14168,307,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14168,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14168,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14168,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14168,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14168,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14168,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14168,606,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14169,203,3.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14169,204,3.11,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14169,205,8.68,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14169,207,0.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14169,208,75,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14169,255,84.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14169,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14169,291,0.4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14169,301,98,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14169,303,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14169,306,131,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14169,307,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14169,320,27,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (14169,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14169,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14169,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14169,601,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14169,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14169,606,1.779,'100g',7,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14171,203,0.21,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14171,204,2.08,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14171,205,2.92,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14171,207,0.23,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14171,208,31,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14171,255,94.57,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14171,269,2.5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14171,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14171,301,188,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14171,303,0.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14171,306,19,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14171,307,19,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14171,320,63,'100g',2,1,'2024-12-12','2014-01-12');
INSERT INTO `cndb_nutval` VALUES (14171,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14171,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14171,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14171,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14171,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14171,606,2.083,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14173,203,2.14,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14173,204,1.07,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14173,205,4.27,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14173,207,0.47,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14173,208,36,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14173,255,92.06,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14173,269,3.91,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14173,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14173,301,71,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14173,303,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14173,306,175,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14173,307,34,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14173,320,0,'100g',3,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (14173,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14173,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14173,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14173,601,5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14173,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14173,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14174,203,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14174,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14174,205,5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14174,207,0.02,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14174,208,21,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14174,255,94.98,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14174,269,5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14174,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14174,301,2,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14174,303,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14174,306,10,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14174,307,5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14174,320,0,'100g',2,1,'2024-12-12','2014-01-12');
INSERT INTO `cndb_nutval` VALUES (14174,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14174,401,25,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14174,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14174,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14174,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14174,606,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14177,203,3.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14177,204,3.24,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14177,205,11.96,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14177,207,0.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14177,208,85,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14177,255,80.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14177,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (14177,291,0.4,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14177,301,95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14177,303,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14177,306,172,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14177,307,58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14177,320,26,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14177,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14177,401,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14177,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14177,601,9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14177,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (14177,606,1.86,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14179,203,1.98,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14179,204,1.38,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14179,205,12.6,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14179,207,0.47,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14179,208,71,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14179,255,83.56,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14179,269,10.67,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14179,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14179,301,74,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14179,303,0.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14179,306,175,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14179,307,26,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14179,320,0,'100g',2,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (14179,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14179,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14179,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14179,601,5,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14179,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14179,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14180,203,0.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14180,204,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14180,205,0.17,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14180,207,0.06,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14180,208,2,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14180,255,99.47,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14180,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14180,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14180,301,2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14180,303,0.02,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14180,306,50,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14180,307,1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14180,320,0,'100g',1,1,'2024-12-12','2016-01-11');
INSERT INTO `cndb_nutval` VALUES (14180,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14180,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14180,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14180,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14180,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14180,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14181,203,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14181,204,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14181,205,65.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14181,207,0.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14181,208,279,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14181,255,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14181,269,49.65,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14181,291,2.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14181,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14181,303,2.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14181,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14181,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14181,320,0,'100g',2,1,'2024-12-12','2008-01-01');
INSERT INTO `cndb_nutval` VALUES (14181,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14181,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14181,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14181,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14181,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14181,606,0.519,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14182,203,3.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14182,204,2.96,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14182,205,12.78,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14182,207,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14182,208,90,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14182,255,80.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14182,269,11.31,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14182,291,0.3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14182,301,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14182,303,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14182,306,145,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14182,307,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14182,320,25,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14182,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14182,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14182,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14182,601,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14182,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14182,606,1.681,'100g',7,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14183,203,1.48,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14183,204,0.98,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14183,205,11.42,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14183,207,0.44,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14183,208,60,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14183,255,85.68,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14183,269,9.23,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14183,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14183,301,52,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14183,303,0.09,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14183,306,136,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14183,307,31,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14183,320,0,'100g',1,1,'2024-12-12','2017-01-02');
INSERT INTO `cndb_nutval` VALUES (14183,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14183,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14183,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14183,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14183,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14183,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14185,203,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14185,204,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14185,205,0.15,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14185,207,0.02,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14185,208,1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14185,255,99.84,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14185,269,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14185,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14185,301,1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14185,303,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14185,306,12,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14185,307,3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14185,320,0,'100g',3,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (14185,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14185,401,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14185,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14185,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14185,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14185,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14187,203,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14187,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14187,205,10.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14187,207,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14187,208,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14187,255,87.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14187,269,3.31,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14187,291,0.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14187,301,8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14187,303,0.15,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14187,306,89,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14187,307,362,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14187,320,7,'100g',2,1,'2024-12-12','2003-01-11');
INSERT INTO `cndb_nutval` VALUES (14187,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14187,401,5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14187,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14187,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14187,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14187,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14188,203,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14188,204,0.18,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14188,205,7.16,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14188,207,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14188,208,30,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14188,255,92.65,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14188,269,6.87,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14188,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14188,301,3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14188,303,0.02,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14188,306,5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14188,307,2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14188,320,0,'100g',3,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (14188,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14188,401,7.7,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14188,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14188,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14188,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14188,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14190,203,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14190,204,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14190,205,0.93,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14190,207,0.36,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14190,208,4,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14190,255,98.71,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14190,269,0.93,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14190,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14190,301,1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14190,303,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14190,306,5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14190,307,6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14190,320,0,'100g',1,1,'2024-12-12','2016-01-11');
INSERT INTO `cndb_nutval` VALUES (14190,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14190,401,9.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14190,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14190,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14190,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14190,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14191,203,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14191,204,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14191,205,0.31,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14191,207,0.08,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14191,208,1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14191,255,99.62,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14191,269,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14191,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14191,301,1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14191,303,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14191,306,13,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14191,307,26,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14191,320,0,'100g',3,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (14191,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14191,401,39.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14191,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14191,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14191,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14191,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14192,203,6.67,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14192,204,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14192,205,83.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14192,207,4.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14192,208,398,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14192,255,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14192,269,65.55,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14192,291,3.7,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14192,301,133,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14192,303,1.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14192,306,712,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14192,307,504,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14192,320,1,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (14192,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14192,401,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14192,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14192,601,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14192,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (14192,606,2.377,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14194,203,0.92,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14194,204,0.55,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14194,205,11.54,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14194,207,0.65,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14194,208,55,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14194,255,86.34,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14194,269,9.03,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14194,291,0.5,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14194,301,21,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14194,303,0.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14194,306,99,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14194,307,73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14194,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14194,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14194,401,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14194,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14194,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14194,605,0.104,'100g',7,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14194,606,0.328,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14196,203,15.49,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14196,204,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14196,205,71.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14196,207,6.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14196,208,377,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14196,255,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14196,269,37.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14196,291,7.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14196,301,576,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14196,303,4.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14196,306,2702,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14196,307,876,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14196,320,4,'100g',2,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (14196,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14196,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14196,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14196,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14196,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14196,606,1.777,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14199,203,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14199,204,0.22,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14199,205,10.8,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14199,207,0.03,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14199,208,45,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14199,255,88.95,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14199,269,9.49,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14199,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14199,301,4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14199,303,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14199,306,14,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14199,307,3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14199,320,0,'100g',3,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (14199,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14199,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14199,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14199,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14199,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14199,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14201,203,0.1,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14201,204,0,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14201,205,0,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14201,207,0.1,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14201,208,0,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14201,255,99.3,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14201,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14201,291,0,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14201,301,2,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14201,303,0.05,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14201,306,54,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14201,307,2,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14201,320,0,'100g',1,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (14201,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14201,401,0,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14201,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14201,601,0,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14201,605,0,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14201,606,0.002,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14202,203,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14202,204,0.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14202,205,1.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14202,207,0.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14202,208,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14202,255,97.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14202,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14202,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14202,301,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14202,303,0.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14202,306,115,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14202,307,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14202,320,0,'100g',2,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (14202,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14202,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14202,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14202,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14202,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14202,606,0.092,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14203,203,14.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14203,204,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14203,205,73.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14203,207,8.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14203,208,352,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14203,255,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14203,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14203,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14203,301,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14203,303,4.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14203,306,3535,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14203,307,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14203,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (14203,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14203,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14203,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14203,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14203,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14203,606,0.197,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14204,203,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14204,204,13.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14204,205,71.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14204,207,3.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14204,208,440,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14204,255,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14204,269,34.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14204,291,4.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14204,301,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14204,303,3.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14204,306,1856,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14204,307,500,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14204,320,0,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (14204,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14204,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14204,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14204,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14204,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14204,606,11.376,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14206,203,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14206,204,0.22,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14206,205,6.2,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14206,207,0.03,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14206,208,27,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14206,255,93.54,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14206,269,5.32,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14206,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14206,301,1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14206,303,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14206,306,12,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14206,307,21,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14206,320,0,'100g',3,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (14206,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14206,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14206,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14206,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14206,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14206,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14207,203,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14207,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14207,205,0.41,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14207,207,0.04,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14207,208,2,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14207,255,99.55,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14207,269,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14207,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14207,301,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14207,303,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14207,306,37,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14207,307,1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14207,320,0,'100g',3,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (14207,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14207,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14207,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14207,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14207,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14207,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14209,203,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14209,204,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14209,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14209,207,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14209,208,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14209,255,99.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14209,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14209,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14209,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14209,303,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14209,306,49,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14209,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14209,320,0,'100g',1,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14209,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14209,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14209,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14209,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14209,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14209,606,0.002,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14210,203,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14210,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14210,205,1.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14210,207,0.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14210,208,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14210,255,97.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14210,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14210,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14210,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14210,303,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14210,306,115,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14210,307,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14210,320,0,'100g',2,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (14210,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14210,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14210,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14210,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14210,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14210,606,0.092,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14211,203,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14211,204,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14211,205,0.22,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14211,207,0.07,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14211,208,1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14211,255,99.72,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14211,269,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14211,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14211,301,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14211,303,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14211,306,14,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14211,307,17,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14211,320,0,'100g',3,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (14211,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14211,401,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14211,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14211,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14211,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14211,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14214,203,12.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14214,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14214,205,75.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14214,207,8.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14214,208,353,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14214,255,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14214,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14214,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14214,301,141,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14214,303,4.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14214,306,3535,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14214,307,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14214,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (14214,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14214,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14214,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14214,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14214,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14214,606,0.197,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14215,203,0.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14215,204,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14215,205,0.34,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14215,207,0.17,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14215,208,2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14215,255,99.09,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14215,269,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14215,291,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14215,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14215,303,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14215,306,30,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14215,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14215,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14215,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14215,401,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14215,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14215,601,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14215,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14215,606,0.002,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14216,203,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14216,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14216,205,3.75,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14216,207,0.02,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14216,208,15,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14216,255,96.23,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14216,269,3.75,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14216,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14216,301,8,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14216,303,0.15,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14216,306,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14216,307,8,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14216,320,0,'100g',3,1,'2024-12-12','2015-01-05');
INSERT INTO `cndb_nutval` VALUES (14216,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14216,401,3.8,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14216,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14216,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14216,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14216,606,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14218,203,11.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14218,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14218,205,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14218,207,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14218,208,351,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14218,255,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14218,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14218,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14218,301,140,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14218,303,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14218,306,3501,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14218,307,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14218,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (14218,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14218,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14218,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14218,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14218,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14218,606,0.101,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14219,203,0.12,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14219,204,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14219,205,0.43,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14219,207,0.19,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14219,208,2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14219,255,98.93,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14219,269,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14219,291,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14219,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14219,303,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14219,306,36,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14219,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14219,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14219,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14219,401,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14219,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14219,601,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14219,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14219,606,0.001,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14222,203,9.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14222,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14222,205,78.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14222,207,7.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14222,208,355,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14222,255,4.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14222,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14222,291,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14222,301,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14222,303,4.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14222,306,3395,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14222,307,277,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14222,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14222,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14222,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14222,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14222,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14222,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14222,606,0.071,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14223,203,0.09,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14223,204,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14223,205,0.75,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14223,207,0.17,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14223,208,3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14223,255,98.94,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14223,269,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14223,291,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14223,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14223,303,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14223,306,35,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14223,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14223,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14223,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14223,401,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14223,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14223,601,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14223,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14223,606,0.001,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14224,203,5.29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14224,204,15.87,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14224,205,74.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14224,207,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14224,208,460,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14224,255,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14224,269,58.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14224,291,1.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14224,301,271,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14224,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14224,306,1033,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14224,307,317,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14224,320,1,'100g',2,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (14224,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14224,401,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14224,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14224,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14224,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14224,606,4.934,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14236,203,6.01,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14236,204,2.52,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14236,205,78.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14236,207,5.06,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14236,208,360,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14236,255,7.99,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14236,269,4.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14236,291,23.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14236,301,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14236,303,4.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14236,306,2443,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14236,307,83,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14236,320,0,'100g',2,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (14236,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14236,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14236,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14236,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14236,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14236,606,0.603,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14237,203,0.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14237,204,0.04,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14237,205,1.3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14237,207,0.18,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14237,208,6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14237,255,98.37,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14237,269,0.08,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14237,291,0.4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14237,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14237,303,0.08,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14237,306,41,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14237,307,5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14237,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14237,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14237,401,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14237,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14237,601,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14237,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14237,606,0.01,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14238,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14238,204,0.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14238,205,15.85,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14238,207,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14238,208,63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14238,255,83.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14238,269,14.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14238,291,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14238,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14238,303,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14238,306,17,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14238,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14238,320,0,'100g',2,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (14238,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14238,401,39.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14238,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14238,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14238,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14238,606,0.013,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14240,203,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14240,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14240,205,16.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14240,207,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14240,208,64,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14240,255,83.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14240,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (14240,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14240,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14240,303,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14240,306,61,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14240,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14240,320,23,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14240,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14240,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14240,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14240,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14240,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14240,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14241,203,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14241,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14241,205,14,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14241,207,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14241,208,56,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14241,255,85.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14241,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (14241,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14241,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14241,303,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14241,306,24,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14241,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14241,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14241,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14241,401,32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14241,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14241,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14241,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14241,606,0.033,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14242,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14242,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14242,205,13.52,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14242,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14242,208,54,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14242,255,86.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14242,269,11.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14242,291,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14242,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14242,303,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14242,306,14,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14242,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14242,320,0,'100g',2,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (14242,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14242,401,42.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14242,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14242,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14242,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14242,606,0.009,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14243,203,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14243,204,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14243,205,4.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14243,207,0.18,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14243,208,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14243,255,95.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14243,269,4.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14243,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14243,301,9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14243,303,0.04,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14243,306,25,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14243,307,3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14243,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (14243,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14243,401,32.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14243,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14243,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14243,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14243,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14245,203,2.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14245,204,3.02,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14245,205,14.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14245,207,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14245,208,95,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14245,255,79.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14245,269,12.66,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14245,291,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14245,301,92,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14245,303,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14245,306,121,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14245,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14245,320,26,'100g',2,1,'2024-12-12','2017-01-02');
INSERT INTO `cndb_nutval` VALUES (14245,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14245,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14245,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14245,601,11,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14245,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14245,606,1.701,'100g',7,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14246,203,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14246,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14246,205,94.45,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14246,207,0.47,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14246,208,378,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14246,255,5.09,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14246,269,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14246,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14246,301,2,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14246,303,0.21,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14246,306,169,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14246,307,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14246,320,0,'100g',3,1,'2024-12-12','2015-01-05');
INSERT INTO `cndb_nutval` VALUES (14246,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14246,401,1342.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14246,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14246,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14246,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14246,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14260,203,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14260,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14260,205,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14260,207,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14260,208,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14260,255,99.93,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14260,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14260,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14260,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14260,303,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14260,306,15,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14260,307,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14260,320,0,'100g',3,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14260,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14260,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14260,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14260,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14260,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14260,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14261,203,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14261,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14261,205,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14261,207,0.12,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14261,208,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14261,255,99.88,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14261,269,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14261,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14261,301,1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14261,303,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14261,306,19,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14261,307,7,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14261,320,0,'100g',3,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14261,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14261,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14261,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14261,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14261,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14261,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14262,203,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14262,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14262,205,40.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14262,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14262,208,162,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14262,255,57.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14262,269,28.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14262,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14262,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14262,303,3.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14262,306,393,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14262,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14262,320,7,'100g',2,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (14262,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14262,401,95.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14262,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14262,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14262,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14262,606,0.007,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14263,203,0.34,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14263,204,0.03,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14263,205,11.42,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14263,207,0.38,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14263,208,46,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14263,255,87.83,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14263,269,8.13,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14263,291,0.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14263,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14263,303,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14263,306,112,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14263,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14263,320,2,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14263,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14263,401,27.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14263,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14263,601,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14263,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14263,606,0.002,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14264,203,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14264,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14264,205,11.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14264,207,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14264,208,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14264,255,87.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14264,269,11.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14264,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14264,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14264,303,0.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14264,306,25,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14264,307,10,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14264,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (14264,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14264,401,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14264,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14264,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14264,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14264,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14267,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14267,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14267,205,11.94,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14267,207,0.08,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14267,208,47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14267,255,87.97,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14267,269,11.29,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14267,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14267,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14267,303,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14267,306,31,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14267,307,38,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14267,320,2,'100g',2,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (14267,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14267,401,29.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14267,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14267,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14267,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14267,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14268,203,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14268,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14268,205,41.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14268,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14268,208,162,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14268,255,58.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14268,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14268,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14268,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14268,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14268,306,44,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14268,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14268,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14268,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14268,401,155.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14268,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14268,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14268,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14268,606,0.003,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14269,203,0.06,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14269,204,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14269,205,11.66,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14269,207,0.13,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14269,208,46,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14269,255,88.15,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14269,269,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14269,291,0.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14269,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14269,303,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14269,306,13,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14269,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14269,320,1,'100g',4,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (14269,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14269,401,43.8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14269,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14269,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14269,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14269,606,0.001,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14270,203,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14270,204,13.33,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14270,205,86.28,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14270,207,0.23,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14270,208,465,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14270,255,0.16,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14270,269,66.67,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14270,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14270,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14270,303,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14270,306,57,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14270,307,333,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14270,320,0,'100g',3,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14270,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14270,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14270,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14270,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14270,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14270,606,13.333,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14277,203,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14277,204,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14277,205,15.72,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14277,207,0.08,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14277,208,61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14277,255,84.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14277,269,13.06,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14277,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14277,301,52,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14277,303,0.07,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14277,306,12,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14277,307,16,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14277,320,0,'100g',2,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (14277,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14277,401,31.4,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14277,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14277,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14277,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14277,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14278,203,0.22,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14278,204,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14278,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14278,207,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14278,208,1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14278,255,99.93,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14278,269,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14278,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14278,301,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14278,303,0.02,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14278,306,8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14278,307,1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14278,320,0,'100g',1,1,'2024-12-12','2016-01-11');
INSERT INTO `cndb_nutval` VALUES (14278,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14278,401,0,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (14278,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14278,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14278,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14278,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14279,203,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14279,204,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14279,205,0.25,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14279,207,0.07,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14279,208,1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14279,255,99.68,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14279,269,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14279,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14279,301,1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14279,303,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14279,306,12,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14279,307,5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14279,320,0,'100g',3,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14279,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14279,401,5.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14279,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14279,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14279,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14279,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14280,203,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14280,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14280,205,0.83,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14280,207,0.03,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14280,208,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14280,255,99.14,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14280,269,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14280,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14280,301,11,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14280,303,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14280,306,27,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14280,307,4,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14280,320,0,'100g',3,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14280,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14280,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14280,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14280,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14280,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14280,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14281,203,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14281,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14281,205,8.75,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14281,207,0.03,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14281,208,38,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14281,255,91.22,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14281,269,7.92,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14281,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14281,301,11,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14281,303,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14281,306,27,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14281,307,8,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14281,320,0,'100g',3,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (14281,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14281,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14281,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14281,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14281,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (14281,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14282,203,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14282,204,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14282,205,14.55,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14282,207,0.12,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14282,208,57,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14282,255,85.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14282,269,14.11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14282,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14282,301,7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14282,303,0.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14282,306,33,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14282,307,9,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14282,320,0,'100g',2,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (14282,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14282,401,26.5,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14282,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14282,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14282,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14282,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14287,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14287,204,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14287,205,97.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14287,207,0.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14287,208,376,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14287,255,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14287,269,94.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14287,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14287,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14287,303,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14287,306,147,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14287,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14287,320,0,'100g',2,1,'2024-12-12','2009-01-01');
INSERT INTO `cndb_nutval` VALUES (14287,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14287,401,39.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14287,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14287,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14287,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14287,606,0.151,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14288,203,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14288,204,0.04,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14288,205,3.59,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14288,207,0.11,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14288,208,14,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14288,255,96.26,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14288,269,3.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14288,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14288,301,4,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14288,303,0.01,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14288,306,6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14288,307,6,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14288,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14288,328,0,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14288,401,1.5,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14288,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14288,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14288,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14288,606,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14292,203,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14292,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14292,205,49.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14292,207,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14292,208,196,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14292,255,49.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14292,269,44.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14292,291,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14292,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14292,303,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14292,306,72,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14292,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14292,320,0,'100g',1,1,'2024-12-12','2009-01-01');
INSERT INTO `cndb_nutval` VALUES (14292,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14292,401,13.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14292,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14292,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14292,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14292,606,0.025,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14293,203,0.07,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14293,204,0.04,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14293,205,10.42,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14293,207,0.12,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14293,208,40,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14293,255,89.35,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14293,269,9.98,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14293,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14293,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14293,303,0.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14293,306,15,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14293,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14293,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14293,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14293,401,3.9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14293,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14293,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14293,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14293,606,0.006,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14296,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14296,204,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14296,205,97.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14296,207,0.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14296,208,380,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14296,255,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14296,269,97.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14296,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14296,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14296,303,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14296,306,39,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14296,307,130,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14296,320,0,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (14296,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14296,401,40.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14296,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14296,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14296,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14296,606,0.183,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14297,203,0,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14297,204,0.07,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14297,205,6.9,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14297,207,0.13,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14297,208,27,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14297,255,92.87,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14297,269,6.87,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14297,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14297,301,4,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14297,303,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14297,306,3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14297,307,13,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14297,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14297,328,0,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14297,401,2.9,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14297,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14297,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14297,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14297,606,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14303,203,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14303,204,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14303,205,13.79,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14303,207,0.13,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14303,208,52,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14303,255,86.08,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14303,269,13.27,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14303,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14303,301,2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14303,303,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14303,306,10,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14303,307,3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14303,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14303,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14303,401,3.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14303,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14303,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14303,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14303,606,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14305,203,0.21,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14305,204,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14305,205,8.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14305,207,0.12,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14305,208,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14305,255,91.15,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14305,269,8.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14305,291,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14305,301,7,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14305,303,0.06,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14305,306,8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14305,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14305,320,0,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (14305,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14305,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14305,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14305,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14305,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14305,606,0.024,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14310,203,3.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14310,204,3.21,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14310,205,10.67,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14310,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14310,208,86,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14310,255,81.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14310,269,8.37,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14310,291,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14310,301,123,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14310,303,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14310,306,200,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14310,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14310,320,281,'100g',4,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (14310,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14310,401,10.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14310,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14310,601,11,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14310,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14310,606,1.83,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14311,203,14.29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14311,204,9.52,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14311,205,71.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14311,207,2.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14311,208,428,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14311,255,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14311,269,47.62,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14311,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14311,301,298,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14311,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14311,306,758,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14311,307,405,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14311,320,63,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (14311,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14311,401,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14311,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14311,601,24,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14311,605,NULL,'100g',NULL,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14311,606,4.762,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14312,203,3.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14312,204,3.62,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14312,205,10.23,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14312,207,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14312,208,88,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14312,255,81.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14312,269,9.56,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14312,291,0.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14312,301,117,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14312,303,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14312,306,183,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14312,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14312,320,33,'100g',2,1,'2024-12-12','2017-01-02');
INSERT INTO `cndb_nutval` VALUES (14312,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14312,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14312,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14312,601,12,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14312,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14312,606,2.039,'100g',7,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14316,203,3.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14316,204,3.26,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14316,205,11.19,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14316,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14316,208,87,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14316,255,81.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14316,269,10.49,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14316,291,0.4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14316,301,139,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14316,303,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14316,306,217,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14316,307,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14316,320,357,'100g',2,1,'2024-12-12','2017-01-02');
INSERT INTO `cndb_nutval` VALUES (14316,328,3.1,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14316,401,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14316,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14316,601,10,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14316,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14316,606,1.873,'100g',7,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14317,203,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14317,204,4.76,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14317,205,86.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14317,207,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14317,208,411,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14317,255,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14317,269,66.67,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14317,291,4.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14317,301,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14317,303,2.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14317,306,618,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14317,307,190,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14317,320,33,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (14317,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14317,401,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14317,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14317,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14317,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14317,606,2.381,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14318,203,3.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14318,204,3.29,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14318,205,11.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14318,207,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14318,208,85,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14318,255,81.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14318,269,6.68,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14318,291,0.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14318,301,98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14318,303,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14318,306,172,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14318,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14318,320,26,'100g',2,1,'2024-12-12','2017-01-02');
INSERT INTO `cndb_nutval` VALUES (14318,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14318,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14318,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14318,601,10,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14318,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14318,606,1.883,'100g',7,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14323,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14323,204,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14323,205,12.34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14323,207,0.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14323,208,49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14323,255,87.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14323,269,11.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14323,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14323,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14323,303,0.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14323,306,18,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14323,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14323,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14323,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14323,401,57.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14323,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14323,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14323,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14323,606,0.002,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14327,203,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14327,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14327,205,12.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14327,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14327,208,51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14327,255,86.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14327,269,12.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14327,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14327,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14327,303,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14327,306,80,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14327,307,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14327,320,9,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (14327,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14327,401,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14327,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14327,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14327,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14327,606,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14334,203,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14334,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14334,205,11.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14334,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14334,208,47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14334,255,87.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14334,269,11.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14334,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14334,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14334,303,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14334,306,61,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14334,307,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14334,320,0,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (14334,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14334,401,46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14334,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14334,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14334,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14334,606,0.006,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14341,203,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14341,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14341,205,11.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14341,207,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14341,208,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14341,255,86.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14341,269,11.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14341,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14341,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14341,303,0.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14341,306,46,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14341,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14341,320,1,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (14341,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14341,401,22.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14341,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14341,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14341,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14341,606,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14350,203,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14350,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14350,205,99.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14350,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14350,208,389,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14350,255,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14350,269,95.45,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14350,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14350,301,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14350,303,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14350,306,6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14350,307,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14350,320,0,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (14350,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14350,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14350,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14350,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14350,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14350,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14351,203,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14351,204,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14351,205,12.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14351,207,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14351,208,88,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14351,255,80.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14351,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (14351,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14351,301,110,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14351,303,0.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14351,306,139,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14351,307,48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14351,320,26,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (14351,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14351,401,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14351,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14351,601,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14351,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (14351,606,1.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14352,203,0,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14352,204,0,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14352,205,0.3,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14352,207,0.04,'100g',3,1,'2002-06-08','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14352,208,1,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14352,255,99.7,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14352,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14352,291,0,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14352,301,0,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14352,303,0.02,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14352,306,37,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14352,307,3,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14352,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (14352,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14352,401,0,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14352,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14352,601,0,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14352,605,0,'100g',NULL,1,'2002-06-08','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14352,606,0.002,'100g',3,1,'2002-06-08','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14353,203,20.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14353,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14353,205,58.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14353,207,16.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14353,208,315,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14353,255,5.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14353,269,5.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14353,291,8.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14353,301,118,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14353,303,2.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14353,306,6040,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14353,307,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14353,320,0,'100g',2,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (14353,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14353,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14353,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14353,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14353,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14353,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14355,203,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14355,204,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14355,205,0.3,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14355,207,0.04,'100g',3,1,'1996-09-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14355,208,1,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14355,255,99.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14355,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14355,291,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14355,301,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14355,303,0.02,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14355,306,37,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14355,307,3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14355,320,0,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (14355,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14355,401,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14355,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14355,601,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14355,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14355,606,0.002,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14356,203,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14356,204,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14356,205,85.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14356,207,7.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14356,208,338,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14356,255,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14356,269,1.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14356,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14356,301,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14356,303,8.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14356,306,2568,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14356,307,412,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14356,320,0,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (14356,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14356,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14356,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14356,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14356,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14356,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14357,203,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14357,204,0.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14357,205,98.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14357,207,0.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14357,208,401,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14357,255,0.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14357,269,95.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14357,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14357,301,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14357,303,0.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14357,306,169,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14357,307,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14357,320,0,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (14357,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14357,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14357,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14357,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14357,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14357,606,0.091,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14366,203,20.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14366,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14366,205,58.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14366,207,16.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14366,208,315,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14366,255,5.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14366,269,5.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14366,291,8.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14366,301,118,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14366,303,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14366,306,6040,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14366,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14366,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (14366,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14366,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14366,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14366,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14366,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14366,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14367,203,0.06,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14367,204,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14367,205,0.17,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14367,207,0.15,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14367,208,1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14367,255,99.62,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14367,269,0.02,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14367,291,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14367,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14367,303,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14367,306,18,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14367,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14367,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14367,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14367,401,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14367,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14367,601,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14367,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14367,606,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14368,203,7.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14368,204,0.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14368,205,78.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14368,207,9.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14368,208,345,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14368,255,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14368,269,4.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14368,291,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14368,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14368,303,0.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14368,306,3453,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14368,307,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14368,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (14368,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14368,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14368,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14368,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14368,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14368,606,0.047,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14370,203,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14370,204,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14370,205,98.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14370,207,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14370,208,401,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14370,255,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14370,269,95.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14370,291,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14370,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14370,303,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14370,306,169,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14370,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14370,320,0,'100g',2,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (14370,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14370,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14370,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14370,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14370,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14370,606,0.097,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14371,203,0.01,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14371,204,0.06,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14371,205,8.61,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14371,207,0.13,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14371,208,35,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14371,255,91.18,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14371,269,8.33,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14371,291,0.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14371,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14371,303,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14371,306,15,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14371,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14371,320,0,'100g',4,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (14371,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14371,401,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14371,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14371,601,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14371,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14371,606,0.008,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14375,203,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14375,204,0.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14375,205,85.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14375,207,7.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14375,208,338,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14375,255,3.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14375,269,1.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14375,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14375,301,21,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14375,303,8.87,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14375,306,2568,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14375,307,412,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14375,320,0,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (14375,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14375,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14375,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14375,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14375,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14375,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14376,203,0.02,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14376,204,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14376,205,0.44,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14376,207,0.14,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14376,208,2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14376,255,99.41,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14376,269,0.01,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14376,291,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14376,301,3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14376,303,0.05,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14376,306,14,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14376,307,6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14376,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14376,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14376,401,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14376,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14376,601,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14376,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14376,606,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14381,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14381,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14381,205,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14381,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14381,208,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14381,255,99.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14381,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14381,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14381,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14381,303,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14381,306,9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14381,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14381,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14381,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14381,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14381,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14381,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14381,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14381,606,0.002,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14390,203,1.21,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14390,204,0.23,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14390,205,5.61,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14390,207,0.57,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14390,208,29,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14390,255,92.38,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14390,269,2.93,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14390,291,0.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14390,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14390,303,0.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14390,306,211,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14390,307,72,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14390,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14390,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14390,401,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14390,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14390,601,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14390,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14390,606,0.139,'100g',7,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14400,203,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14400,204,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14400,205,9.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14400,207,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14400,208,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14400,255,90.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14400,269,8.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14400,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14400,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14400,303,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14400,306,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14400,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14400,320,0,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (14400,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14400,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14400,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14400,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14400,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14400,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14405,203,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14405,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14405,205,43.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14405,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14405,208,175,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14405,255,55.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14405,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14405,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14405,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14405,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14405,306,270,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14405,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14405,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14405,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14405,401,19.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14405,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14405,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14405,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14405,606,0.087,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14406,203,0.07,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14406,204,0.17,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14406,205,11.4,'100g',6,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14406,207,0.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14406,208,42,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14406,255,88.16,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14406,269,11.4,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14406,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14406,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14406,303,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14406,306,66,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14406,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14406,320,0,'100g',4,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (14406,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14406,401,4.8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14406,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14406,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14406,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14406,606,0.021,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14407,203,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14407,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14407,205,98.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14407,207,0.92,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14407,208,386,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14407,255,0.14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14407,269,92.31,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14407,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14407,301,385,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14407,303,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14407,306,190,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14407,307,17,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14407,320,599,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14407,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14407,401,230.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14407,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14407,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14407,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14407,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14408,203,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14408,204,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14408,205,12.65,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14408,207,0.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14408,208,49,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14408,255,87.15,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14408,269,11.8,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14408,291,0.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14408,301,52,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14408,303,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14408,306,25,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14408,307,5,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14408,320,77,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14408,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14408,401,29.5,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14408,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14408,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14408,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14408,606,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14409,203,3.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14409,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14409,205,85.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14409,207,8.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14409,208,217,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14409,255,1.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14409,269,2.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14409,291,3.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14409,301,1378,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14409,303,0.07,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14409,306,3132,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14409,307,81,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14409,320,6006,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (14409,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14409,401,2400,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14409,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14409,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14409,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14409,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14411,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14411,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14411,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14411,207,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14411,208,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14411,255,99.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14411,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14411,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14411,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14411,303,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14411,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14411,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14411,320,0,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (14411,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14411,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14411,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14411,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14411,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14411,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14416,203,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14416,204,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14416,205,0.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14416,207,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14416,208,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14416,255,99.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14416,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14416,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14416,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14416,303,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14416,306,8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14416,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14416,320,0,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (14416,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14416,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14416,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14416,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14416,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14416,606,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14421,203,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14421,204,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14421,205,5.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14421,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14421,208,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14421,255,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14421,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14421,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14421,301,119,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14421,303,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14421,306,172,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14421,307,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14421,320,28,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (14421,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14421,401,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14421,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14421,601,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14421,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14421,606,2.061,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14422,203,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14422,204,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14422,205,51.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14422,207,8.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14422,208,329,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14422,255,12.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14422,269,32.94,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14422,291,9.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14422,301,1412,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14422,303,7.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14422,306,2240,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14422,307,659,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14422,320,209,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (14422,328,4.7,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14422,401,5.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14422,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14422,601,24,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14422,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14422,606,1.871,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14423,203,2.19,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14423,204,0.23,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14423,205,4.51,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14423,207,0.81,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14423,208,29,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14423,255,92.26,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14423,269,2.89,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14423,291,0.8,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14423,301,127,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14423,303,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14423,306,197,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14423,307,61,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14423,320,18,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14423,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14423,401,0.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14423,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14423,601,2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14423,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14423,606,0.164,'100g',7,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14424,203,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14424,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14424,205,42.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14424,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14424,208,172,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14424,255,55.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14424,269,11.7,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14424,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14424,301,130,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14424,303,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14424,306,435,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14424,307,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14424,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14424,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14424,401,243.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14424,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14424,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14424,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14424,606,0.078,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14425,203,0.03,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14425,204,0.14,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14425,205,12.21,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14425,207,0.44,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14425,208,49,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14425,255,87.18,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14425,269,11.91,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14425,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14425,301,39,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14425,303,0.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14425,306,124,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14425,307,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14425,320,0,'100g',4,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (14425,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14425,401,69.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14425,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14425,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14425,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14425,606,0.022,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14426,203,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14426,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14426,205,39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14426,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14426,208,153,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14426,255,59.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14426,269,38.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14426,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14426,301,399,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14426,303,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14426,306,465,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14426,307,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14426,320,1,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (14426,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14426,401,189.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14426,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14426,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14426,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14426,606,0.002,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14427,203,0.12,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14427,204,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14427,205,11.32,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14427,207,0.48,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14427,208,45,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14427,255,88.08,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14427,269,11.05,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14427,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14427,301,118,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14427,303,0.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14427,306,167,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14427,307,10,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14427,320,0,'100g',4,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (14427,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14427,401,55.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14427,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14427,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14427,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14427,606,0.001,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14429,203,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14429,204,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14429,205,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14429,207,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14429,208,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14429,255,99.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14429,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14429,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14429,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14429,303,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14429,306,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14429,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14429,320,0,'100g',1,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (14429,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14429,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14429,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14429,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14429,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14429,606,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14430,203,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14430,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14430,205,51.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14430,207,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14430,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14430,255,48.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14430,269,42.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14430,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14430,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14430,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14430,306,49,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14430,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14430,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14430,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14430,401,45.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14430,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14430,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14430,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14430,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14431,203,0.01,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14431,204,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14431,205,11.81,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14431,207,0.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14431,208,47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14431,255,88.08,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14431,269,9.76,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14431,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14431,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14431,303,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14431,306,12,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14431,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14431,320,0,'100g',4,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (14431,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14431,401,10.5,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14431,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14431,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14431,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14431,606,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14436,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14436,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14436,205,13.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14436,207,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14436,208,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14436,255,85.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14436,269,8.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14436,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14436,301,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14436,303,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14436,306,83,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14436,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14436,320,21,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (14436,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14436,401,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14436,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14436,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14436,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14436,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14537,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14537,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14537,205,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14537,207,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14537,208,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14537,255,99.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14537,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14537,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14537,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14537,303,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14537,306,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14537,307,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14537,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14537,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14537,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14537,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14537,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14537,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14537,606,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14538,203,25.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14538,204,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14538,205,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14538,207,10.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14538,208,359,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14538,255,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14538,269,55.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14538,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14538,301,1440,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14538,303,4.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14538,306,2702,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14538,307,653,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14538,320,479,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (14538,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14538,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14538,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14538,601,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14538,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14538,606,1.777,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14541,203,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14541,204,0.01,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14541,205,9.47,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14541,207,0.17,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14541,208,37,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14541,255,90.35,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14541,269,9.23,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14541,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14541,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14541,303,0.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14541,306,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14541,307,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14541,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14541,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14541,401,11.8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14541,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14541,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14541,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14541,606,0.006,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14542,203,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14542,204,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14542,205,48.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14542,207,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14542,208,192,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14542,255,50.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14542,269,46.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14542,291,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14542,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14542,303,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14542,306,76,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14542,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14542,320,0,'100g',1,1,'2024-12-12','2009-01-01');
INSERT INTO `cndb_nutval` VALUES (14542,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14542,401,14.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14542,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14542,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14542,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14542,606,0.026,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14543,203,0.05,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14543,204,0.15,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14543,205,10.81,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14543,207,0.11,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14543,208,43,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14543,255,88.88,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14543,269,10.28,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14543,291,0.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14543,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14543,303,0.02,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14543,306,17,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14543,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14543,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14543,328,0,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14543,401,3.1,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14543,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14543,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14543,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14543,606,0.006,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (14544,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14544,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14544,205,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14544,207,0.02,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14544,208,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14544,255,99.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14544,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14544,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14544,301,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14544,303,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14544,306,21,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14544,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14544,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (14544,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14544,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14544,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14544,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14544,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14544,606,0.002,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14545,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14545,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14545,205,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14545,207,0.01,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14545,208,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14545,255,99.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14545,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14545,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14545,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14545,303,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14545,306,9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14545,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14545,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14545,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14545,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14545,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14545,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14545,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14545,606,0.002,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14548,203,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14548,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14548,205,97.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14548,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14548,208,385,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14548,255,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14548,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14548,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14548,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14548,303,0.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14548,306,217,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14548,307,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14548,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14548,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14548,401,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14548,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14548,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14548,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14548,606,0.037,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14552,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14552,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14552,205,10.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14552,207,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14552,208,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14552,255,89.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14552,269,10.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14552,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14552,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14552,303,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14552,306,50,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14552,307,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14552,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (14552,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14552,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14552,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14552,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14552,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14552,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14555,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14555,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14555,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14555,207,0.07,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14555,208,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14555,255,99.98,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14555,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14555,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14555,301,10,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14555,303,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14555,306,0,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14555,307,2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14555,320,0,'100g',3,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (14555,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14555,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14555,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14555,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14555,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14555,606,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14557,203,4.55,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14557,204,2.27,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14557,205,90.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14557,207,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14557,208,400,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14557,255,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14557,269,81.82,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14557,291,4.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14557,301,455,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14557,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14557,306,280,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14557,307,136,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14557,320,0,'100g',2,1,'2024-12-12','2003-01-10');
INSERT INTO `cndb_nutval` VALUES (14557,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14557,401,27.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14557,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14557,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14557,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14557,606,2.273,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14558,203,3.27,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14558,204,3.17,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14558,205,11.87,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14558,207,0.77,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14558,208,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14558,255,80.93,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14558,269,11.59,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14558,291,0.4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14558,301,141,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14558,303,0.03,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14558,306,144,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14558,307,50,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14558,320,42,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (14558,328,1.2,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14558,401,2.3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14558,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14558,601,10,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14558,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14558,606,1.899,'100g',7,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14604,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14604,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14604,205,0.13,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14604,207,0.02,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (14604,208,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14604,255,99.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14604,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14604,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14604,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14604,303,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14604,306,4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14604,307,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14604,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (14604,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14604,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14604,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (14604,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14604,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14604,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14605,203,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14605,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14605,205,5.49,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14605,207,0.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14605,208,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14605,255,94.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14605,269,5.49,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14605,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14605,301,17,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14605,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14605,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14605,307,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14605,320,32,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (14605,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14605,401,12.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14605,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14605,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14605,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14605,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14632,203,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14632,204,3.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14632,205,14.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14632,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14632,208,101,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14632,255,77.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14632,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14632,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14632,301,110,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14632,303,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14632,306,160,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14632,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14632,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (14632,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14632,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14632,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14632,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14632,605,0.411,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14632,606,0.571,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14633,203,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14633,204,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14633,205,1.1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14633,207,0.13,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14633,208,4,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14633,255,98.78,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14633,269,0.63,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14633,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14633,301,8,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14633,303,0.3,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14633,306,24,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14633,307,14,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14633,320,105,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (14633,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14633,401,25.1,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14633,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14633,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14633,605,0,'100g',NULL,1,'2010-01-04','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14633,606,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14634,203,3.05,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14634,204,1.83,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14634,205,12.08,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14634,207,0.73,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14634,208,77,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14634,255,82.32,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14634,269,11.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14634,291,0.4,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14634,301,164,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14634,303,0.03,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14634,306,130,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14634,307,49,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14634,320,51,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (14634,328,1.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14634,401,0.2,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14634,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14634,601,8,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14634,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14634,606,1.124,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14635,203,0.3,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14635,204,0.01,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14635,205,11.15,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14635,207,0.13,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14635,208,46,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14635,255,88.4,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14635,269,10.37,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14635,291,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14635,301,8,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14635,303,0.31,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14635,306,101,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14635,307,29,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14635,320,36,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (14635,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14635,401,28.5,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14635,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14635,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14635,605,0,'100g',NULL,1,'2010-01-04','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14635,606,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14636,203,0,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14636,204,0.07,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14636,205,10,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14636,207,2.35,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14636,208,39,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14636,255,87.58,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14636,269,9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14636,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14636,301,5,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14636,303,0.04,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14636,306,11,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14636,307,2,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14636,320,0,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (14636,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14636,401,0,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14636,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14636,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14636,605,0,'100g',NULL,1,'2010-01-04','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14636,606,0.008,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14637,203,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14637,204,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14637,205,4.5,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14637,207,1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14637,208,18,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14637,255,94.44,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14637,269,4.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14637,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14637,301,17,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14637,303,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14637,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14637,307,8,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14637,320,32,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (14637,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14637,401,12.7,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14637,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14637,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14637,605,0,'100g',NULL,1,'2010-01-04','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14637,606,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14639,203,0.28,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14639,204,0.97,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14639,205,9.17,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14639,207,0.3,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14639,208,47,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14639,255,89.28,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14639,269,5.28,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14639,291,0.3,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14639,301,118,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14639,303,0.2,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14639,306,27,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14639,307,39,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14639,320,63,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (14639,328,1,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14639,401,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14639,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14639,601,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14639,605,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14639,606,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (14645,203,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14645,204,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14645,205,16.03,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14645,207,0.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14645,208,64,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14645,255,83.87,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14645,269,15.85,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14645,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14645,301,3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14645,303,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14645,306,31,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14645,307,36,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14645,320,0,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (14645,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14645,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14645,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14645,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14645,605,0,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14645,606,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14646,203,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14646,204,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14646,205,6.67,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14646,207,0.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14646,208,27,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14646,255,93.2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14646,269,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14646,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14646,301,3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14646,303,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14646,306,31,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14646,307,36,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14646,320,0,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (14646,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14646,401,25,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14646,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14646,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14646,605,0,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14646,606,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14647,203,0,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14647,204,0.37,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14647,205,6.67,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14647,207,0.06,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14647,208,29,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14647,255,93,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14647,269,5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14647,291,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14647,301,42,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14647,303,0,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14647,306,31,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14647,307,25,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14647,320,0,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (14647,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14647,401,25,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14647,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14647,601,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14647,605,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14647,606,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14648,203,0.13,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14648,204,0,'100g',6,1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (14648,205,13.16,'100g',7,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14648,207,0.31,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14648,208,54,'100g',7,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14648,255,86.39,'100g',3,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (14648,269,12.11,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14648,291,0.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14648,301,3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14648,303,0.25,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14648,306,122,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14648,307,61,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14648,320,5,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (14648,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14648,401,25.4,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14648,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14648,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14648,605,0,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14648,606,0,'100g',4,1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (14649,203,0,'100g',4,1,'2012-03-02','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14649,204,0,'100g',4,1,'2012-03-02','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14649,205,0,'100g',3,1,'2012-03-02','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14649,207,0.42,'100g',3,1,'2012-03-02','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14649,208,0,'100g',3,1,'2012-03-02','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14649,255,99.58,'100g',1,1,'2012-03-02','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14649,269,0,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14649,291,0,'100g',4,1,'2012-03-02','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14649,301,8,'100g',1,1,'2012-03-02','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14649,303,0.08,'100g',1,1,'2012-03-02','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14649,306,20,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14649,307,4,'100g',1,1,'2012-03-02','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14649,320,0,'100g',1,1,'2024-12-12','2015-01-01');
INSERT INTO `cndb_nutval` VALUES (14649,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14649,401,0,'100g',1,1,'2012-03-02','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14649,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14649,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14649,605,0,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (14649,606,0,'100g',4,1,'2012-03-02','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (14651,203,0.13,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14651,204,0.11,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14651,205,11.35,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14651,207,0.31,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14651,208,46,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14651,255,88.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14651,269,10.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14651,291,0.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14651,301,3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14651,303,0.25,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14651,306,122,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14651,307,8,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14651,320,5,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (14651,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14651,401,25,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14651,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14651,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14651,605,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14651,606,0.017,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (14654,203,53.57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14654,204,10.71,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14654,205,20.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14654,207,7.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14654,208,392,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14654,255,8.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14654,269,3.57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14654,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14654,301,714,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14654,303,22.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14654,306,1000,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14654,307,1214,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14654,320,1875,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (14654,328,12.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (14654,401,75,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14654,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (14654,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14654,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (14654,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15001,203,20.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15001,204,4.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15001,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15001,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15001,208,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15001,255,73.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15001,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15001,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15001,301,147,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15001,303,3.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15001,306,383,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15001,307,104,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15001,320,15,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (15001,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15001,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15001,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15001,601,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15001,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15001,606,1.282,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15002,203,28.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15002,204,9.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15002,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15002,207,11.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15002,208,210,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15002,255,50.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15002,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15002,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15002,301,232,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15002,303,4.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15002,306,544,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15002,307,3668,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15002,320,12,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15002,328,1.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15002,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15002,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15002,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15002,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15002,606,2.203,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15003,203,18.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15003,204,3.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15003,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15003,207,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15003,208,114,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15003,255,75.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15003,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15003,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15003,301,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15003,303,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15003,306,356,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15003,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15003,320,30,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15003,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15003,401,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15003,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15003,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15003,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15003,606,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15004,203,17.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15004,204,2.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15004,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15004,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15004,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15004,255,79.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15004,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15004,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15004,301,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15004,303,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15004,306,256,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15004,307,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15004,320,27,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15004,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15004,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15004,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15004,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15004,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15004,606,0.507,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15005,203,20.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15005,204,4.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15005,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15005,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15005,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15005,255,70.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15005,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15005,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15005,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15005,303,0.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15005,306,372,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15005,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15005,320,120,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15005,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15005,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15005,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15005,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15005,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15005,606,0.915,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15006,203,19.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15006,204,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15006,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15006,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15006,208,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15006,255,79.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15006,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15006,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15006,301,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15006,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15006,306,404,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15006,307,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15006,320,5,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15006,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15006,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15006,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15006,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15006,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15006,606,0.163,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15007,203,17.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15007,204,8.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15007,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15007,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15007,208,146,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15007,255,74.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15007,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15007,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15007,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15007,303,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15007,306,375,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15007,307,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15007,320,30,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15007,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15007,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15007,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15007,601,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15007,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15007,606,3.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15008,203,17.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15008,204,5.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15008,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15008,207,1.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15008,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15008,255,76.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15008,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15008,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15008,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15008,303,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15008,306,333,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15008,307,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15008,320,9,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15008,328,24.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15008,401,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15008,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15008,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15008,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15008,606,1.083,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15009,203,22.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15009,204,7.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15009,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15009,207,1.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15009,208,162,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15009,255,69.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15009,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15009,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15009,301,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15009,303,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15009,306,427,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15009,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15009,320,10,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15009,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15009,401,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15009,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15009,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15009,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15009,606,1.388,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15010,203,16.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15010,204,2.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15010,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15010,207,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15010,208,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15010,255,80.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15010,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15010,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15010,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15010,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15010,306,358,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15010,307,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15010,320,15,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15010,328,12.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15010,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15010,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15010,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15010,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15010,606,0.722,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15011,203,18.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15011,204,13.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15011,205,8.04,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15011,207,1.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15011,208,229,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15011,255,58.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15011,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15011,291,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15011,301,44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15011,303,1.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15011,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15011,307,280,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15011,320,8,'100g',2,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (15011,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15011,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15011,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15011,601,71,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15011,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15011,606,3.288,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15012,203,24.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15012,204,17.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15012,205,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15012,207,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15012,208,264,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15012,255,47.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15012,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15012,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15012,301,275,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15012,303,11.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15012,306,181,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15012,307,1500,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15012,320,271,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (15012,328,2.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15012,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15012,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15012,601,588,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15012,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15012,606,4.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15013,203,18.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15013,204,1.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15013,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15013,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15013,208,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15013,255,78.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15013,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15013,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15013,301,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15013,303,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15013,306,354,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15013,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15013,320,30,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15013,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15013,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15013,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15013,601,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15013,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15013,606,0.421,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15014,203,16.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15014,204,11.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15014,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15014,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15014,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15014,255,69.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15014,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15014,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15014,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15014,303,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15014,306,293,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15014,307,481,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15014,320,283,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15014,328,13.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15014,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15014,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15014,601,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15014,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15014,606,1.741,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15015,203,17.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15015,204,0.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15015,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15015,207,1.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15015,208,82,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15015,255,81.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15015,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15015,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15015,301,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15015,303,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15015,306,413,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15015,307,54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15015,320,12,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15015,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15015,401,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15015,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15015,601,43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15015,605,NULL,'100g',NULL,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15015,606,0.131,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15016,203,22.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15016,204,0.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15016,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15016,207,1.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15016,208,105,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15016,255,75.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15016,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15016,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15016,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15016,303,0.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15016,306,244,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15016,307,78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15016,320,14,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15016,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15016,401,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15016,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15016,601,55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15016,605,NULL,'100g',NULL,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15016,606,0.168,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15017,203,22.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15017,204,0.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15017,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15017,207,1.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15017,208,105,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15017,255,75.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15017,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15017,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15017,301,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15017,303,0.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15017,306,528,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15017,307,218,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15017,320,14,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15017,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15017,401,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15017,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15017,601,55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15017,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15017,606,0.167,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15018,203,62.82,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15018,204,2.37,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15018,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15018,207,18.67,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15018,208,290,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15018,255,16.14,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15018,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15018,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15018,301,160,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15018,303,2.5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15018,306,1458,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15018,307,7027,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15018,320,42,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15018,328,4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15018,401,3.5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15018,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15018,601,152,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15018,605,NULL,'100g',NULL,1,'1996-09-30','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15018,606,0.462,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15019,203,15.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15019,204,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15019,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15019,207,1.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15019,208,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15019,255,83.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15019,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15019,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15019,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15019,303,0.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15019,306,235,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15019,307,303,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15019,320,2,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15019,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15019,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15019,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15019,601,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15019,605,0.005,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15019,606,0.085,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15020,203,17.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15020,204,3.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15020,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15020,207,1.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15020,208,104,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15020,255,78.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15020,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15020,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15020,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15020,303,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15020,306,345,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15020,307,56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15020,320,12,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15020,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15020,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15020,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15020,601,61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15020,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15020,606,1.088,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15021,203,18.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15021,204,12.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15021,205,7.54,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15021,207,1.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15021,208,221,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15021,255,59.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15021,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15021,291,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15021,301,32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15021,303,0.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15021,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15021,307,348,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15021,320,23,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15021,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15021,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15021,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15021,601,84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15021,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15021,606,3.476,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15022,203,18.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15022,204,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15022,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15022,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15022,208,87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15022,255,76.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15022,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15022,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15022,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15022,303,0.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15022,306,392,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15022,307,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15022,320,18,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15022,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15022,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15022,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15022,601,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15022,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15022,606,0.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15023,203,18.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15023,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15023,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15023,207,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15023,208,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15023,255,77.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15023,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15023,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15023,301,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15023,303,1.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15023,306,416,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15023,307,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15023,320,54,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15023,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15023,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15023,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15023,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15023,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15023,606,0.188,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15024,203,17.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15024,204,4.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15024,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15024,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15024,208,119,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15024,255,77.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15024,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15024,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15024,301,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15024,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15024,306,275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15024,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15024,320,51,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15024,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15024,401,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15024,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15024,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15024,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15024,606,1.119,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15025,203,18.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15025,204,11.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15025,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15025,207,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15025,208,184,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15025,255,68.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15025,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15025,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15025,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15025,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15025,306,272,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15025,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15025,320,1043,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15025,328,23.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15025,401,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15025,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15025,601,126,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15025,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15025,606,2.358,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15026,203,23.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15026,204,14.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15026,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15026,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15026,208,236,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15026,255,59.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15026,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15026,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15026,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15026,303,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15026,306,349,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15026,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15026,320,1137,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15026,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15026,401,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15026,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15026,601,161,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15026,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15026,606,3.023,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15027,203,11.01,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15027,204,16.23,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (15027,205,21.66,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15027,207,1.61,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15027,208,277,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (15027,255,49.5,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15027,269,1.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15027,291,1.5,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15027,301,16,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (15027,303,0.84,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (15027,306,185,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15027,307,402,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15027,320,4,'100g',1,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (15027,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15027,401,0,'100g',4,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (15027,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15027,601,28,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (15027,605,0.124,'100g',3,1,'2006-01-24','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15027,606,3.733,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15028,203,12.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15028,204,1.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15028,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15028,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15028,208,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15028,255,84.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15028,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15028,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15028,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15028,303,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15028,306,160,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15028,307,296,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15028,320,10,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15028,328,2.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15028,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15028,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15028,601,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15028,605,0.011,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15028,606,0.441,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15029,203,15.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15029,204,2.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15029,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15029,207,1.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15029,208,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15029,255,81.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15029,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15029,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15029,301,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15029,303,0.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15029,306,197,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15029,307,363,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15029,320,12,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15029,328,3.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15029,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15029,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15029,601,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15029,605,0.014,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15029,606,0.542,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15030,203,9.07,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15030,204,1.73,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15030,205,7.41,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15030,207,1.44,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15030,208,84,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15030,255,80.35,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15030,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15030,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15030,301,23,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15030,303,2.48,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15030,306,91,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15030,307,524,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15030,320,27,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15030,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15030,401,0.8,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15030,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15030,601,30,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15030,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15030,606,0.412,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15031,203,19.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15031,204,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15031,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15031,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15031,208,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15031,255,79.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15031,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15031,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15031,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15031,303,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15031,306,483,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15031,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15031,320,43,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15031,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15031,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15031,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15031,601,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15031,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15031,606,0.233,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15032,203,24.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15032,204,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15032,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15032,207,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15032,208,118,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15032,255,73.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15032,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15032,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15032,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15032,303,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15032,306,475,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15032,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15032,320,50,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15032,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15032,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15032,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15032,601,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15032,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15032,606,0.299,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15033,203,16.32,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15033,204,0.45,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15033,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15033,207,1.28,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15033,208,74,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15033,255,83.38,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15033,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15033,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15033,301,11,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15033,303,0.17,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15033,306,286,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15033,307,213,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15033,320,17,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15033,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15033,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15033,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15033,601,54,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15033,605,0.004,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15033,606,0.091,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15034,203,19.99,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15034,204,0.55,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15034,205,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15034,207,1.56,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15034,208,90,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15034,255,79.65,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15034,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15034,291,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15034,301,14,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15034,303,0.21,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15034,306,351,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15034,307,261,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15034,320,21,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15034,328,0.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15034,401,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15034,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15034,601,66,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15034,605,0.005,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15034,606,0.111,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15035,203,25.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15035,204,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15035,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15035,207,1.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15035,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15035,255,71.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15035,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15035,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15035,301,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15035,303,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15035,306,415,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15035,307,763,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15035,320,24,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15035,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15035,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15035,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15035,601,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15035,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15035,606,0.173,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15036,203,18.56,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15036,204,1.33,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15036,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15036,207,1.29,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15036,208,91,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15036,255,80.34,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15036,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15036,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15036,301,7,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15036,303,0.16,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15036,306,435,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15036,307,68,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15036,320,20,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15036,328,4.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15036,401,0,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15036,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15036,601,49,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15036,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15036,606,0.292,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15037,203,22.54,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15037,204,1.61,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15037,205,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15037,207,1.57,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15037,208,111,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15037,255,76.12,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15037,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15037,291,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15037,301,9,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15037,303,0.2,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15037,306,528,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15037,307,82,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15037,320,24,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15037,328,5.8,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15037,401,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15037,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15037,601,60,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15037,605,0.028,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15037,606,0.354,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15038,203,14.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15038,204,13.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15038,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15038,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15038,208,186,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15038,255,70.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15038,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15038,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15038,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15038,303,0.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15038,306,268,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15038,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15038,320,14,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15038,328,27.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15038,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15038,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15038,601,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15038,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15038,606,2.419,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15039,203,17.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15039,204,9.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15039,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15039,207,1.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15039,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15039,255,72.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15039,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15039,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15039,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15039,303,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15039,306,327,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15039,307,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15039,320,28,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15039,328,4.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15039,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15039,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15039,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15039,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15039,606,2.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15040,203,23.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15040,204,11.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15040,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15040,207,1.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15040,208,203,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15040,255,64.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15040,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15040,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15040,301,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15040,303,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15040,306,419,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15040,307,115,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15040,320,36,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15040,328,5.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15040,401,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15040,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15040,601,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15040,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15040,606,2.615,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15041,203,14.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15041,204,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15041,205,9.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15041,207,2.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15041,208,262,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15041,255,55.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15041,269,7.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15041,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15041,301,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15041,303,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15041,306,69,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15041,307,870,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15041,320,258,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15041,328,2.8,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15041,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15041,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15041,601,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15041,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15041,606,2.381,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15042,203,24.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15042,204,12.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15042,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15042,207,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15042,208,217,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15042,255,59.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15042,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15042,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15042,301,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15042,303,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15042,306,447,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15042,307,918,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15042,320,40,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15042,328,2.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15042,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15042,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15042,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15042,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15042,606,2.791,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15043,203,16.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15043,204,13.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15043,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15043,207,2.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15043,208,195,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15043,255,71.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15043,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15043,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15043,301,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15043,303,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15043,306,423,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15043,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15043,320,32,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15043,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15043,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15043,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15043,601,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15043,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15043,606,3.257,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15044,203,18.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15044,204,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15044,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15044,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15044,208,87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15044,255,79.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15044,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15044,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15044,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15044,303,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15044,306,379,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15044,307,135,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15044,320,30,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15044,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15044,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15044,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15044,601,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15044,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15044,606,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15045,203,17.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15045,204,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15045,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15045,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15045,208,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15045,255,81.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15045,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15045,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15045,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15045,303,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15045,306,437,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15045,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15045,320,15,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15045,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15045,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15045,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15045,601,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15045,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15045,606,0.197,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15046,203,18.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15046,204,13.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15046,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15046,207,1.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15046,208,205,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15046,255,63.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15046,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15046,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15046,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15046,303,1.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15046,306,314,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15046,307,90,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15046,320,50,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15046,328,16.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15046,401,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15046,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15046,601,70,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15046,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15046,606,3.257,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15047,203,23.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15047,204,17.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15047,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15047,207,1.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15047,208,262,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15047,255,53.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15047,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15047,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15047,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15047,303,1.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15047,306,401,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15047,307,83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15047,320,54,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15047,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15047,401,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15047,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15047,601,75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15047,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15047,606,4.176,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15048,203,23.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15048,204,6.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15048,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15048,207,1.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15048,208,156,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15048,255,69.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15048,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15048,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15048,301,241,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15048,303,2.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15048,306,194,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15048,307,379,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15048,320,130,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15048,328,7.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15048,401,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15048,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15048,601,79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15048,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15048,606,1.857,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15049,203,20.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15049,204,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15049,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15049,207,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15049,208,105,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15049,255,75.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15049,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15049,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15049,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15049,303,1.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15049,306,435,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15049,307,158,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15049,320,218,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15049,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15049,401,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15049,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15049,601,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15049,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15049,606,0.363,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15050,203,20.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15050,204,7.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15050,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15050,207,1.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15050,208,158,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15050,255,70.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15050,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15050,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15050,301,23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15050,303,1.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15050,306,406,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15050,307,86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15050,320,19,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15050,328,9.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15050,401,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15050,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15050,601,47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15050,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15050,606,2.247,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15051,203,19.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15051,204,6.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15051,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15051,207,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15051,208,139,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15051,255,71.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15051,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15051,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15051,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15051,303,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15051,306,446,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15051,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15051,320,39,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15051,328,7.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15051,401,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15051,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15051,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15051,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15051,606,1.828,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15052,203,23.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15052,204,6.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15052,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15052,207,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15052,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15052,255,68.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15052,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15052,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15052,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15052,303,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15052,306,554,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15052,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15052,320,33,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15052,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15052,401,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15052,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15052,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15052,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15052,606,1.801,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15053,203,20.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15053,204,6.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15053,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15053,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15053,208,148,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15053,255,70.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15053,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15053,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15053,301,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15053,303,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15053,306,292,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15053,307,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15053,320,30,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15053,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15053,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15053,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15053,601,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15053,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15053,606,1.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15054,203,14.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15054,204,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15054,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15054,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15054,208,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15054,255,83.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15054,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15054,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15054,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15054,303,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15054,306,400,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15054,307,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15054,320,12,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15054,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15054,401,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15054,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15054,601,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15054,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15054,606,0.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15055,203,19.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15055,204,3.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15055,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15055,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15055,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15055,255,77.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15055,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15055,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15055,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15055,303,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15055,306,357,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15055,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15055,320,37,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15055,328,1.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15055,401,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15055,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15055,601,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15055,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15055,606,1.116,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15056,203,24.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15056,204,4.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15056,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15056,207,1.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15056,208,150,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15056,255,70.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15056,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15056,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15056,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15056,303,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15056,306,458,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15056,307,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15056,320,42,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15056,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15056,401,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15056,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15056,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15056,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15056,606,1.431,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15057,203,15.31,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15057,204,1.54,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15057,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15057,207,1.2,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15057,208,79,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15057,255,83.07,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15057,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15057,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15057,301,28,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15057,303,0.22,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15057,306,187,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15057,307,287,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15057,320,12,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15057,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15057,401,0,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15057,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15057,601,52,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15057,605,0.009,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15057,606,0.273,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15058,203,18.51,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15058,204,1.87,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15058,205,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15058,207,1.6,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15058,208,96,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15058,255,74.24,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15058,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15058,291,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15058,301,34,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15058,303,0.27,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15058,306,226,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15058,307,347,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15058,320,15,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15058,328,1.4,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15058,401,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15058,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15058,601,63,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15058,605,0.011,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15058,606,0.33,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15059,203,16.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15059,204,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15059,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15059,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15059,208,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15059,255,81.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15059,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15059,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15059,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15059,303,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15059,306,400,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15059,307,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15059,320,12,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15059,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15059,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15059,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15059,601,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15059,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15059,606,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15060,203,19.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15060,204,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15060,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15060,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15060,208,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15060,255,79.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15060,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15060,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15060,301,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15060,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15060,306,269,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15060,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15060,320,9,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15060,328,3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15060,401,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15060,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15060,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15060,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15060,606,0.185,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15061,203,24.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15061,204,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15061,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15061,207,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15061,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15061,255,73.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15061,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15061,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15061,301,102,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15061,303,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15061,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15061,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15061,320,10,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15061,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15061,401,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15061,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15061,601,115,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15061,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15061,606,0.237,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15062,203,19.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15062,204,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15062,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15062,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15062,208,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15062,255,78.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15062,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15062,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15062,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15062,303,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15062,306,259,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15062,307,39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15062,320,21,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15062,328,2.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15062,401,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15062,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15062,601,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15062,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15062,606,0.118,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15063,203,24.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15063,204,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15063,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15063,207,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15063,208,113,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15063,255,72.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15063,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15063,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15063,301,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15063,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15063,306,331,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15063,307,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15063,320,24,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15063,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15063,401,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15063,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15063,601,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15063,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15063,606,0.151,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15064,203,19.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15064,204,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15064,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15064,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15064,208,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15064,255,79.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15064,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15064,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15064,301,110,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15064,303,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15064,306,389,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15064,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15064,320,21,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15064,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15064,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15064,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15064,601,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15064,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15064,606,0.249,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15065,203,19.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15065,204,0.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15065,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15065,207,1.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15065,208,92,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15065,255,78.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15065,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15065,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15065,301,60,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15065,303,0.46,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15065,306,356,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15065,307,86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15065,320,14,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15065,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15065,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15065,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15065,601,71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15065,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15065,606,0.135,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15066,203,12.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15066,204,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15066,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15066,207,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15066,208,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15066,255,86.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15066,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15066,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15066,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15066,303,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15066,306,160,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15066,307,333,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15066,320,3,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15066,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15066,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15066,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15066,601,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15066,605,0.016,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15066,606,0.124,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15067,203,23.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15067,204,1.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15067,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15067,207,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15067,208,111,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15067,255,73.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15067,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15067,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15067,301,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15067,303,0.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15067,306,430,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15067,307,419,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15067,320,17,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15067,328,1.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15067,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15067,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15067,601,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15067,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15067,606,0.159,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15068,203,18.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15068,204,9.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15068,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15068,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15068,208,164,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15068,255,71.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15068,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15068,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15068,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15068,303,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15068,306,381,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15068,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15068,320,40,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15068,328,11,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15068,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15068,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15068,601,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15068,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15068,606,3.509,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15069,203,23.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15069,204,12.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15069,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15069,207,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15069,208,211,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15069,255,62.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15069,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15069,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15069,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15069,303,0.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15069,306,636,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15069,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15069,320,36,'100g',2,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (15069,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15069,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15069,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15069,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15069,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15069,606,4.499,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15070,203,18.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15070,204,1.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15070,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15070,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15070,208,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15070,255,79.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15070,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15070,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15070,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15070,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15070,306,386,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15070,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15070,320,4,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15070,328,3.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15070,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15070,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15070,601,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15070,605,0.018,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (15070,606,0.336,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (15071,203,22.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15071,204,1.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15071,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15071,207,1.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15071,208,109,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15071,255,74.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15071,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15071,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15071,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15071,303,0.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15071,306,467,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15071,307,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15071,320,5,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15071,328,4.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15071,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15071,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15071,601,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15071,605,0.025,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15071,606,0.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15072,203,22.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15072,204,6.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15072,205,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15072,207,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15072,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15072,255,67.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15072,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15072,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15072,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15072,303,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15072,306,221,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15072,307,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15072,320,90,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15072,328,12.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15072,401,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15072,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15072,601,374,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15072,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15072,606,1.456,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15073,203,16.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15073,204,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15073,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15073,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15073,208,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15073,255,75.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15073,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15073,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15073,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15073,303,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15073,306,167,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15073,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15073,320,21,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (15073,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15073,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15073,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15073,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15073,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15073,606,0.015,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15074,203,13.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15074,204,15.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15074,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15074,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15074,208,195,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15074,255,71.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15074,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15074,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15074,301,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15074,303,1.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15074,306,358,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15074,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15074,320,93,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15074,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15074,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15074,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15074,601,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15074,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15074,606,3.201,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15075,203,17.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15075,204,20.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15075,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15075,207,2.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15075,208,257,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15075,255,60.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15075,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15075,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15075,301,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15075,303,1.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15075,306,471,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15075,307,737,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15075,320,122,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (15075,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15075,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15075,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15075,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15075,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15075,606,4.213,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15076,203,19.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15076,204,6.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15076,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15076,207,2.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15076,208,142,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15076,255,68.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15076,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15076,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15076,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15076,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15076,306,490,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15076,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15076,320,12,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15076,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15076,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15076,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15076,601,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15076,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15076,606,0.981,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15077,203,18.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15077,204,4.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15077,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15077,207,2.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15077,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15077,255,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15077,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15077,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15077,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15077,303,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15077,306,175,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15077,307,672,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15077,320,26,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15077,328,17.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15077,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15077,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15077,601,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15077,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15077,606,0.929,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15078,203,19.93,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15078,204,10.43,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15078,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15078,207,1.33,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15078,208,179,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15078,255,71.64,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15078,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15078,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15078,301,26,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15078,303,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15078,306,394,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15078,307,47,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15078,320,136,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (15078,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15078,401,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15078,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15078,601,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15078,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15078,606,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15079,203,20.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15079,204,3.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15079,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15079,207,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15079,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15079,255,75.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15079,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15079,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15079,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15079,303,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15079,306,429,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15079,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15079,320,30,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15079,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15079,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15079,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15079,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15079,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15079,606,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15080,203,21.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15080,204,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15080,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15080,207,2.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15080,208,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15080,255,70.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15080,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15080,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15080,301,249,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15080,303,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15080,306,300,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15080,307,391,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15080,320,18,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15080,328,9.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15080,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15080,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15080,601,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15080,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15080,606,1.486,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15081,203,21.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15081,204,5.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15081,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15081,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15081,208,146,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15081,255,72.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15081,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15081,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15081,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15081,303,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15081,306,423,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15081,307,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15081,320,40,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15081,328,9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15081,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15081,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15081,601,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15081,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15081,606,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15082,203,27.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15082,204,7.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15082,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15082,207,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15082,208,184,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15082,255,65.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15082,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15082,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15082,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15082,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15082,306,455,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15082,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15082,320,32,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15082,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15082,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15082,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15082,601,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15082,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15082,606,1.595,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15083,203,20.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15083,204,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15083,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15083,207,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15083,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15083,255,75.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15083,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15083,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15083,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15083,303,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15083,306,366,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15083,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15083,320,35,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15083,328,10.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15083,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15083,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15083,601,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15083,605,0.034,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15083,606,0.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15084,203,19.68,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15084,204,4.97,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15084,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15084,207,2.4,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15084,208,129,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15084,255,74.04,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15084,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15084,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15084,301,215,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15084,303,0.64,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15084,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15084,307,403,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15084,320,17,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15084,328,13.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15084,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15084,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15084,601,55,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15084,605,0.026,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15084,606,0.862,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15085,203,22.25,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15085,204,4.69,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (15085,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15085,207,1.26,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15085,208,131,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (15085,255,72.54,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15085,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15085,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15085,301,9,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (15085,303,0.43,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15085,306,367,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15085,307,78,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (15085,320,49,'100g',1,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (15085,328,14.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15085,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15085,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15085,601,51,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15085,605,0.019,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (15085,606,0.814,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (15086,203,26.48,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15086,204,5.57,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (15086,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15086,207,1.5,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15086,208,156,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (15086,255,67.33,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15086,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15086,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15086,301,11,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (15086,303,0.52,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15086,306,436,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15086,307,92,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (15086,320,58,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (15086,328,16.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15086,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15086,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15086,601,61,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15086,605,0.023,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (15086,606,0.969,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (15087,203,23.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15087,204,7.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15087,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15087,207,2.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15087,208,167,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15087,255,68.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15087,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15087,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15087,301,232,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15087,303,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15087,306,314,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15087,307,408,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15087,320,55,'100g',1,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (15087,328,21,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15087,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15087,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15087,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15087,605,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15087,606,1.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15088,203,24.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15088,204,11.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15088,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15088,207,3.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15088,208,208,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15088,255,59.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15088,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15088,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15088,301,382,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15088,303,2.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15088,306,397,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15088,307,307,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15088,320,32,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15088,328,4.8,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15088,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15088,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15088,601,142,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15088,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15088,606,1.528,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15089,203,20.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15089,204,10.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15089,205,0.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15089,207,1.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15089,208,185,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15089,255,66.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15089,269,0.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15089,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15089,301,240,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15089,303,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15089,306,341,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15089,307,414,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15089,320,34,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15089,328,4.8,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15089,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15089,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15089,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15089,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15089,606,2.684,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15090,203,18.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15090,204,2.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15090,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15090,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15090,208,105,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15090,255,75.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15090,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15090,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15090,301,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15090,303,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15090,306,287,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15090,307,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15090,320,27,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15090,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15090,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15090,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15090,601,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15090,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15090,606,0.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15091,203,18.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15091,204,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15091,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15091,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15091,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15091,255,78.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15091,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15091,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15091,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15091,303,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15091,306,256,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15091,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15091,320,46,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15091,328,5.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15091,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15091,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15091,601,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15091,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15091,606,0.511,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15092,203,23.63,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15092,204,2.56,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15092,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15092,207,1.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15092,208,124,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15092,255,72.14,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15092,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15092,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15092,301,13,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15092,303,0.37,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15092,306,328,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15092,307,87,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15092,320,64,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15092,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15092,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15092,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15092,601,53,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15092,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15092,606,0.655,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15093,203,16.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15093,204,3.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15093,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15093,207,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15093,208,104,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15093,255,78.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15093,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15093,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15093,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15093,303,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15093,306,341,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15093,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15093,320,30,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15093,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15093,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15093,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15093,601,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15093,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15093,606,1.009,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15094,203,16.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15094,204,13.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15094,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15094,207,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15094,208,197,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15094,255,68.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15094,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15094,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15094,301,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15094,303,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15094,306,384,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15094,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15094,320,32,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15094,328,4.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15094,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15094,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15094,601,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15094,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15094,606,3.126,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15095,203,20.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15095,204,4.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15095,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15095,207,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15095,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15095,255,73.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15095,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15095,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15095,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15095,303,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15095,306,160,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15095,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15095,320,70,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15095,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15095,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15095,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15095,601,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15095,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15095,606,0.925,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15096,203,18.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15096,204,13.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15096,205,6.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15096,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15096,208,228,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15096,255,60.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15096,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15096,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15096,301,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15096,303,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15096,306,155,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15096,307,122,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15096,320,54,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15096,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15096,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15096,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15096,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15096,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15096,606,3.205,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15097,203,20.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15097,204,2.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15097,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15097,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15097,208,108,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15097,255,77.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15097,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15097,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15097,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15097,303,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15097,306,404,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15097,307,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15097,320,30,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15097,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15097,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15097,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15097,601,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15097,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15097,606,0.609,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15098,203,26.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15098,204,1.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15098,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15098,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15098,208,126,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15098,255,69.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15098,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15098,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15098,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15098,303,0.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15098,306,512,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15098,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15098,320,35,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15098,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15098,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15098,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15098,601,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15098,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15098,606,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15099,203,17.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15099,204,2.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15099,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15099,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15099,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15099,255,78.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15099,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15099,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15099,301,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15099,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15099,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15099,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15099,320,15,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15099,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15099,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15099,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15099,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15099,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15099,606,0.452,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15100,203,22.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15100,204,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15100,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15100,207,1.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15100,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15100,255,72.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15100,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15100,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15100,301,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15100,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15100,306,372,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15100,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15100,320,17,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15100,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15100,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15100,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15100,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15100,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15100,606,0.579,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15101,203,20.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15101,204,1.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15101,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15101,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15101,208,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15101,255,76.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15101,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15101,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15101,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15101,303,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15101,306,417,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15101,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15101,320,32,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15101,328,10.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15101,401,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15101,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15101,601,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15101,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15101,606,0.285,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15102,203,26.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15102,204,1.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15102,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15102,207,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15102,208,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15102,255,70.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15102,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15102,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15102,301,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15102,303,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15102,306,522,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15102,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15102,320,35,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15102,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15102,401,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15102,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15102,601,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15102,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15102,606,0.365,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15103,203,18.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15103,204,4.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15103,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15103,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15103,208,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15103,255,75.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15103,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15103,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15103,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15103,303,0.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15103,306,496,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15103,307,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15103,320,30,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15103,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15103,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15103,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15103,601,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15103,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15103,606,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15104,203,16.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15104,204,4.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15104,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15104,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15104,208,105,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15104,255,76.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15104,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15104,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15104,301,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15104,303,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15104,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15104,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15104,320,210,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15104,328,10.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15104,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15104,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15104,601,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15104,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15104,606,0.915,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15105,203,20.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15105,204,5.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15105,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15105,207,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15105,208,135,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15105,255,69.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15105,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15105,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15105,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15105,303,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15105,306,364,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15105,307,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15105,320,263,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15105,328,12.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15105,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15105,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15105,601,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15105,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15105,606,1.173,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15106,203,31.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15106,204,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15106,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15106,207,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15106,208,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15106,255,62.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15106,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15106,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15106,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15106,303,0.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15106,306,379,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15106,307,739,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15106,320,280,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15106,328,16.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15106,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15106,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15106,601,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15106,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15106,606,1.037,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15107,203,16.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15107,204,2.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15107,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15107,207,1.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15107,208,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15107,255,79.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15107,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15107,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15107,301,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15107,303,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15107,306,380,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15107,307,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15107,320,51,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15107,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15107,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15107,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15107,601,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15107,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15107,606,0.452,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15108,203,19.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15108,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15108,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15108,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15108,208,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15108,255,79.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15108,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15108,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15108,301,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15108,303,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15108,306,350,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15108,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15108,320,15,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15108,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15108,401,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15108,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15108,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15108,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15108,606,0.139,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15109,203,15.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15109,204,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15109,205,6.85,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15109,207,0.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15109,208,99,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15109,255,76.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15109,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15109,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15109,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15109,303,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15109,306,112,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15109,307,143,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15109,320,20,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (15109,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15109,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15109,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15109,601,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15109,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15109,606,0.191,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15110,203,19.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15110,204,6.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15110,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15110,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15110,208,144,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15110,255,73.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15110,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15110,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15110,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15110,303,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15110,306,418,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15110,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15110,320,36,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15110,328,13.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15110,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15110,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15110,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15110,605,0.047,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15110,606,1.614,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (15111,203,23.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15111,204,7.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15111,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15111,207,1.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15111,208,172,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15111,255,68.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15111,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15111,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15111,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15111,303,0.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15111,306,499,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15111,307,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15111,320,43,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (15111,328,16.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15111,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15111,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15111,601,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15111,605,0.056,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15111,606,1.911,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15112,203,17.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15112,204,2.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15112,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15112,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15112,208,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15112,255,78.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15112,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15112,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15112,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15112,303,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15112,306,433,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15112,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15112,320,18,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15112,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15112,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15112,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15112,601,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15112,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15112,606,0.441,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15113,203,24.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15113,204,4.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15113,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15113,207,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15113,208,147,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15113,255,70.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15113,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15113,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15113,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15113,303,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15113,306,512,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15113,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15113,320,21,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15113,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15113,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15113,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15113,601,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15113,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15113,606,0.868,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15114,203,20.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15114,204,6.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15114,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15114,207,1.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15114,208,148,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15114,255,71.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15114,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15114,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15114,301,43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15114,303,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15114,306,361,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15114,307,52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15114,320,17,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15114,328,3.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15114,401,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15114,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15114,601,58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15114,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15114,606,1.149,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15115,203,20.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15115,204,3.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15115,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15115,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15115,208,119,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15115,255,71.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15115,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15115,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15115,301,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15115,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15115,306,481,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15115,307,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15115,320,19,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15115,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15115,401,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15115,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15115,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15115,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15115,606,0.722,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15116,203,22.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15116,204,5.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15116,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15116,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15116,208,150,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15116,255,70.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15116,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15116,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15116,301,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15116,303,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15116,306,448,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15116,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15116,320,15,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15116,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15116,401,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15116,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15116,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15116,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15116,606,1.619,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15117,203,23.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15117,204,4.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15117,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15117,207,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15117,208,144,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15117,255,68.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15117,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15117,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15117,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15117,303,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15117,306,252,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15117,307,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15117,320,655,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15117,328,5.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15117,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15117,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15117,601,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15117,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15117,606,1.257,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15118,203,29.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15118,204,6.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15118,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15118,207,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15118,208,184,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15118,255,59.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15118,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15118,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15118,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15118,303,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15118,306,323,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15118,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15118,320,757,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15118,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15118,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15118,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15118,601,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15118,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15118,606,1.612,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15119,203,29.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15119,204,8.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15119,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15119,207,2.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15119,208,198,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15119,255,59.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15119,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15119,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15119,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15119,303,1.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15119,306,207,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15119,307,416,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (15119,320,23,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15119,328,6.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15119,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15119,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15119,601,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15119,605,NULL,'100g',NULL,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15119,606,1.534,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15121,203,19.44,'100g',1,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (15121,204,0.96,'100g',1,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (15121,205,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15121,207,0.95,'100g',1,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (15121,208,86,'100g',3,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (15121,255,78.14,'100g',1,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (15121,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15121,291,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15121,301,17,'100g',1,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (15121,303,1.63,'100g',1,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (15121,306,179,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15121,307,247,'100g',1,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (15121,320,17,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15121,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15121,401,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15121,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15121,601,36,'100g',1,1,'1994-01-31','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (15121,605,0.002,'100g',3,1,'2006-02-23','2012-06-01');
INSERT INTO `cndb_nutval` VALUES (15121,606,0.211,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15123,203,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15123,204,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15123,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15123,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15123,208,103,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15123,255,70.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15123,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15123,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15123,301,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15123,303,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15123,306,407,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15123,307,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15123,320,16,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15123,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15123,401,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15123,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15123,601,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15123,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15123,606,0.328,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15124,203,26.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15124,204,8.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15124,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15124,207,2.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15124,208,186,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15124,255,64.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15124,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15124,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15124,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15124,303,0.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15124,306,333,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15124,307,396,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15124,320,5,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (15124,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15124,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15124,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15124,601,31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15124,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15124,606,1.28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15126,203,23.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15126,204,2.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15126,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15126,207,1.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15126,208,128,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15126,255,73.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15126,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15126,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15126,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15126,303,0.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15126,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15126,307,377,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15126,320,6,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15126,328,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15126,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15126,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15126,601,42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15126,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15126,606,0.792,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15127,203,24.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15127,204,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15127,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15127,207,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15127,208,109,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15127,255,74.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15127,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15127,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15127,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15127,303,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15127,306,441,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15127,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15127,320,18,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15127,328,1.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15127,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15127,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15127,601,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15127,605,0.016,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15127,606,0.172,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15128,203,16.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15128,204,9.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15128,205,9.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15128,207,2.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15128,208,187,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15128,255,63.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15128,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15128,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15128,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15128,303,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15128,306,178,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15128,307,402,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15128,320,24,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15128,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15128,401,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15128,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15128,601,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15128,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15128,606,1.544,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15129,203,16.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15129,204,2.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15129,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15129,207,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15129,208,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15129,255,76.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15129,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15129,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15129,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15129,303,0.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15129,306,238,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15129,307,150,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15129,320,11,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15129,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15129,401,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15129,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15129,601,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15129,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15129,606,0.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15130,203,19.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15130,204,5.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15130,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15130,207,1.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15130,208,134,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15130,255,72.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15130,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15130,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15130,301,26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15130,303,0.37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15130,306,317,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15130,307,51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15130,320,36,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15130,328,12,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15130,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15130,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15130,601,60,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15130,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15130,606,0.906,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15131,203,23.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15131,204,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15131,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15131,207,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15131,208,108,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15131,255,70.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15131,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15131,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15131,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15131,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15131,306,423,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15131,307,1019,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15131,320,57,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15131,328,12.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15131,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15131,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15131,601,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15131,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15131,606,0.228,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15132,203,18.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15132,204,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15132,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15132,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15132,208,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15132,255,80.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15132,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15132,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15132,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15132,303,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15132,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15132,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15132,320,30,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15132,328,1.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15132,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15132,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15132,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15132,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15132,606,0.247,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15133,203,23.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15133,204,1.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15133,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15133,207,1.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15133,208,116,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15133,255,74.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15133,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15133,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15133,301,62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15133,303,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15133,306,434,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15133,307,132,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15133,320,38,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15133,328,1.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15133,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15133,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15133,601,84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15133,605,NULL,'100g',NULL,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15133,606,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15134,203,17.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15134,204,2.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15134,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15134,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15134,208,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15134,255,79.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15134,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15134,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15134,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15134,303,0.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15134,306,300,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15134,307,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15134,320,113,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15134,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15134,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15134,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15134,601,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15134,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15134,606,0.365,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15135,203,23.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15135,204,5.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15135,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15135,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15135,208,146,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15135,255,74.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15135,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15135,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15135,301,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15135,303,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15135,306,420,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15135,307,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15135,320,29,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15135,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15135,401,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15135,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15135,601,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15135,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15135,606,1.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15136,203,18.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15136,204,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15136,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15136,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15136,208,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15136,255,79.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15136,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15136,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15136,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15136,303,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15136,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15136,307,836,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15136,320,7,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15136,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15136,401,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15136,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15136,601,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15136,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15136,606,0.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15137,203,19.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15137,204,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15137,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15137,207,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15137,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15137,255,77.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15137,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15137,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15137,301,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15137,303,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15137,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15137,307,1072,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15137,320,9,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15137,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15137,401,7.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15137,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15137,601,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15137,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15137,606,0.133,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15138,203,7.62,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15138,204,0.46,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15138,205,15,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15138,207,2.26,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15138,208,95,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15138,255,74.66,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15138,269,6.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15138,291,0.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15138,301,13,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15138,303,0.39,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15138,306,90,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15138,307,529,'100g',3,1,'1994-11-14','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (15138,320,0,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (15138,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15138,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15138,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15138,601,20,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15138,605,0.008,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (15138,606,0.216,'100g',3,1,'1994-11-14','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15139,203,18.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15139,204,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15139,205,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15139,207,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15139,208,87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15139,255,79.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15139,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15139,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15139,301,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15139,303,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15139,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15139,307,293,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15139,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15139,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15139,401,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15139,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15139,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15139,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15139,606,0.222,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15140,203,17.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15140,204,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15140,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15140,207,1.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15140,208,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15140,255,79.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15140,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15140,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15140,301,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15140,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15140,306,259,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15140,307,395,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15140,320,1,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15140,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15140,401,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15140,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15140,601,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15140,605,0.014,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15140,606,0.201,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15141,203,17.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15141,204,0.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15141,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15141,207,1.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15141,208,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15141,255,79.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15141,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15141,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15141,301,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15141,303,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15141,306,259,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15141,307,563,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15141,320,1,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15141,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15141,401,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15141,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15141,601,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15141,605,0.014,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15141,606,0.201,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15142,203,20.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15142,204,7.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15142,205,0.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15142,207,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15142,208,155,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15142,255,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15142,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15142,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15142,301,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15142,303,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15142,306,324,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15142,307,330,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15142,320,57,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15142,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15142,401,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15142,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15142,601,150,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15142,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15142,606,1.483,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15143,203,17.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15143,204,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15143,205,0.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15143,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15143,208,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15143,255,79.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15143,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15143,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15143,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15143,303,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15143,306,354,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15143,307,295,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15143,320,27,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15143,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15143,401,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15143,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15143,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15143,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15143,606,0.132,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15144,203,18.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15144,204,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15144,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15144,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15144,208,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15144,255,80.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15144,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15144,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15144,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15144,303,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15144,306,173,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15144,307,539,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15144,320,45,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15144,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15144,401,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15144,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15144,601,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15144,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15144,606,0.143,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15145,203,15.97,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15145,204,0.95,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15145,205,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15145,207,1.34,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15145,208,77,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15145,255,82.24,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15145,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15145,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15145,301,27,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15145,303,0.84,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15145,306,302,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15145,307,58,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15145,320,16,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15145,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15145,401,1.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15145,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15145,601,114,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15145,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15145,606,0.159,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15146,203,16.77,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15146,204,1.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15146,205,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15146,207,1.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15146,208,82,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15146,255,79.37,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15146,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15146,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15146,301,60,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15146,303,0.83,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15146,306,296,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15146,307,94,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15146,320,15,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15146,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15146,401,0.9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15146,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15146,601,133,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15146,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15146,606,0.181,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15147,203,16.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15147,204,0.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15147,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15147,207,1.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15147,208,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15147,255,80.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15147,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15147,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15147,301,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15147,303,0.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15147,306,200,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15147,307,423,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15147,320,1,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (15147,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15147,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15147,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15147,601,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15147,605,0.011,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15147,606,0.181,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15148,203,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15148,204,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15148,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15148,207,2.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15148,208,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15148,255,78.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15148,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15148,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15148,301,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15148,303,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15148,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15148,307,486,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15148,320,1,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15148,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15148,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15148,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15148,601,146,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15148,605,0.013,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15148,606,0.208,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15149,203,13.61,'100g',1,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15149,204,1.01,'100g',1,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15149,205,0.91,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15149,207,1.86,'100g',1,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15149,208,71,'100g',3,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15149,255,83.01,'100g',1,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15149,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15149,291,0,'100g',4,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15149,301,54,'100g',1,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15149,303,0.21,'100g',1,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15149,306,113,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15149,307,566,'100g',1,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15149,320,54,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15149,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15149,401,0,'100g',1,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15149,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15149,601,126,'100g',1,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15149,605,0.018,'100g',NULL,1,'1995-06-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15149,606,0.261,'100g',3,1,'1995-06-15','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15150,203,21.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15150,204,12.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15150,205,11.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15150,207,1.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15150,208,242,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15150,255,52.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15150,269,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15150,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15150,301,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15150,303,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15150,306,225,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15150,307,344,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15150,320,56,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (15150,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15150,401,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15150,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15150,601,138,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15150,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15150,606,2.087,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15151,203,22.78,'100g',3,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15151,204,1.7,'100g',3,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15151,205,1.52,'100g',3,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15151,207,3.11,'100g',3,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15151,208,119,'100g',3,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15151,255,71.56,'100g',3,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15151,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15151,291,0,'100g',3,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15151,301,91,'100g',3,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15151,303,0.32,'100g',3,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15151,306,170,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15151,307,947,'100g',3,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15151,320,90,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15151,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15151,401,0,'100g',3,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15151,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15151,601,211,'100g',3,1,'1995-06-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15151,605,0.035,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15151,606,0.521,'100g',3,1,'1995-06-15','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15152,203,20.42,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15152,204,1.36,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15152,205,0,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15152,207,2.54,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15152,208,100,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15152,255,75.85,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15152,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15152,291,0,'100g',4,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15152,301,145,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15152,303,2.13,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15152,306,80,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15152,307,870,'100g',3,1,'1995-06-15','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (15152,320,0,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (15152,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15152,401,4.1,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15152,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15152,601,252,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15152,605,NULL,'100g',NULL,1,'1995-06-29','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15152,606,0.188,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15153,203,12.39,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15153,204,1.47,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15153,205,9.13,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15153,207,2.11,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15153,208,101,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15153,255,74.91,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15153,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15153,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15153,301,19,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15153,303,0.6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15153,306,89,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15153,307,705,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15153,320,20,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15153,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15153,401,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15153,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15153,601,36,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15153,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15153,606,0.29,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15154,203,20.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15154,204,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15154,205,2.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15154,207,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15154,208,112,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15154,255,74.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15154,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15154,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15154,301,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15154,303,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15154,306,180,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15154,307,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15154,320,5,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15154,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15154,401,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15154,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15154,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15154,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15154,606,0.237,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15155,203,17.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15155,204,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15155,205,6.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15155,207,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15155,208,105,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15155,255,74.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15155,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15155,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15155,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15155,303,3.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15155,306,250,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15155,307,301,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15155,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15155,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15155,401,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15155,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15155,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15155,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15155,606,0.149,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15156,203,19.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15156,204,6.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15156,205,11.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15156,207,1.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15156,208,189,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15156,255,60.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15156,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15156,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15156,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15156,303,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15156,306,284,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15156,307,591,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15156,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15156,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15156,401,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15156,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15156,601,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15156,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15156,606,1.646,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15157,203,14.67,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15157,204,0.96,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15157,205,3.57,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15157,207,1.82,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15157,208,86,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15157,255,78.98,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15157,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15157,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15157,301,39,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15157,303,1.62,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15157,306,46,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15157,307,601,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15157,320,90,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15157,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15157,401,0,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15157,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15157,601,30,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15157,605,0.015,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15157,606,0.187,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15158,203,14.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15158,204,11.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15158,205,10.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15158,207,2.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15158,208,202,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15158,255,61.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15158,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15158,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15158,301,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15158,303,13.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15158,306,326,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15158,307,364,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15158,320,91,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15158,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15158,401,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15158,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15158,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15158,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15158,606,2.683,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15159,203,25.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15159,204,1.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15159,205,5.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15159,207,3.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15159,208,148,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15159,255,63.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15159,269,NULL,'100g',NULL,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15159,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15159,301,92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15159,303,2.81,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (15159,306,628,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15159,307,1202,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15159,320,171,'100g',2,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (15159,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15159,401,22.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15159,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15159,601,67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15159,605,NULL,'100g',NULL,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15159,606,0.188,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15160,203,24.25,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15160,204,1.59,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15160,205,5.9,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15160,207,3,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15160,208,142,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15160,255,65.26,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15160,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15160,291,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15160,301,65,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15160,303,2.68,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15160,306,628,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15160,307,112,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15160,320,149,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15160,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15160,401,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15160,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15160,601,50,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15160,605,0.024,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15160,606,0.309,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15162,203,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15162,204,0.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15162,205,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15162,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15162,208,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15162,255,97.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15162,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15162,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15162,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15162,303,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15162,306,149,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15162,307,215,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15162,320,9,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15162,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15162,401,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15162,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15162,601,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15162,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15162,606,0.002,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15163,203,16.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15163,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15163,205,0.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15163,207,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15163,208,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15163,255,80.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15163,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15163,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15163,301,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15163,303,6.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15163,306,354,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15163,307,372,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15163,320,113,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15163,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15163,401,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15163,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15163,601,112,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15163,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15163,606,0.118,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15164,203,11.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15164,204,2.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15164,205,3.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15164,207,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15164,208,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15164,255,80.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15164,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15164,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15164,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15164,303,3.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15164,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15164,307,286,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15164,320,48,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15164,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15164,401,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15164,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15164,601,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15164,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15164,606,0.425,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15165,203,23.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15165,204,4.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15165,205,7.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15165,207,3.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15165,208,172,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15165,255,61.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15165,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15165,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15165,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15165,303,6.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15165,306,268,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15165,307,369,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15165,320,91,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15165,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15165,401,13.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15165,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15165,601,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15165,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15165,606,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15166,203,14.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15166,204,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15166,205,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15166,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15166,208,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15166,255,80.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15166,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15166,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15166,301,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15166,303,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15166,306,350,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15166,307,230,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15166,320,45,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15166,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15166,401,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15166,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15166,601,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15166,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15166,606,0.227,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15167,203,5.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15167,204,1.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15167,205,2.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15167,207,0.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15167,208,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15167,255,89.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15167,269,0.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15167,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15167,301,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15167,303,4.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15167,306,156,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15167,307,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15167,320,13,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (15167,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15167,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15167,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15167,601,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15167,605,0.034,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15167,606,0.474,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15168,203,8.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15168,204,12.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15168,205,11.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15168,207,1.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15168,208,199,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15168,255,64.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15168,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15168,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15168,301,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15168,303,6.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15168,306,244,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15168,307,417,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15168,320,90,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (15168,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15168,401,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15168,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15168,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15168,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15168,606,3.197,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15169,203,11.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15169,204,3.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15169,205,5.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15169,207,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15169,208,102,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15169,255,78.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15169,269,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15169,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15169,301,116,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15169,303,9.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15169,306,139,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15169,307,166,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15169,320,26,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15169,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15169,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15169,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15169,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15169,605,0.068,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15169,606,0.948,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15170,203,7.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15170,204,2.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15170,205,3.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15170,207,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15170,208,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15170,255,85.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15170,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15170,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15170,301,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15170,303,6.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15170,306,229,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15170,307,112,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15170,320,90,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (15170,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15170,401,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15170,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15170,601,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15170,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15170,606,0.631,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15171,203,9.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15171,204,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15171,205,4.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15171,207,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15171,208,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15171,255,82.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15171,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15171,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15171,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15171,303,5.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15171,306,168,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15171,307,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15171,320,81,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15171,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15171,401,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15171,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15171,601,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15171,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15171,606,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15172,203,12.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15172,204,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15172,205,3.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15172,207,1.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15172,208,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15172,255,82.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15172,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15172,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15172,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15172,303,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15172,306,205,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15172,307,392,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15172,320,1,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15172,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15172,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15172,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15172,601,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15172,605,0.005,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15172,606,0.128,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15173,203,18.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15173,204,10.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15173,205,10.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15173,207,1.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15173,208,216,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15173,255,58.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15173,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15173,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15173,301,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15173,303,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15173,306,333,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15173,307,464,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15173,320,22,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (15173,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15173,401,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15173,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15173,601,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15173,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15173,606,2.669,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15174,203,12.77,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15174,204,0.41,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15174,205,10.62,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15174,207,2.37,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15174,208,99,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15174,255,73.82,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15174,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15174,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15174,301,8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15174,303,0.31,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15174,306,103,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15174,307,795,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15174,320,20,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15174,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15174,401,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15174,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15174,601,22,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15174,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15174,606,0.08,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15175,203,15.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15175,204,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15175,205,3.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15175,207,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15175,208,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15175,255,78.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15175,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15175,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15175,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15175,303,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15175,306,246,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15175,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15175,320,10,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15175,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15175,401,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15175,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15175,601,233,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15175,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15175,606,0.358,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15176,203,17.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15176,204,7.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15176,205,7.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15176,207,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15176,208,175,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15176,255,64.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15176,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15176,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15176,301,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15176,303,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15176,306,279,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15176,307,306,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15176,320,11,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15176,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15176,401,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15176,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15176,601,260,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15176,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15176,606,1.878,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15177,203,23.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15177,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15177,205,7.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15177,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15177,208,137,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15177,255,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15177,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15177,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15177,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15177,303,5.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15177,306,347,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15177,307,206,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15177,320,26,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15177,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15177,401,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15177,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15177,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15177,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15177,606,0.031,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15178,203,47.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15178,204,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15178,205,15.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15178,207,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15178,208,275,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15178,255,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15178,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15178,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15178,301,113,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15178,303,10.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15178,306,694,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15178,307,412,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15178,320,49,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15178,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15178,401,6.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15178,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15178,601,130,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15178,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15178,606,0.062,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15179,203,18.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15179,204,4.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15179,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15179,207,2.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15179,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15179,255,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15179,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15179,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15179,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15179,303,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15179,306,175,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15179,307,2000,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15179,320,26,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15179,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15179,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15179,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15179,601,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15179,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15179,606,0.929,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15180,203,21.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15180,204,5.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15180,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15180,207,2.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15180,208,141,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15180,255,70.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15180,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15180,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15180,301,249,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15180,303,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15180,306,300,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15180,307,75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15180,320,18,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15180,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15180,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15180,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15180,601,39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15180,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15180,606,1.486,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15181,203,19.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15181,204,6.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15181,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15181,207,1.38,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15181,208,139,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15181,255,70.03,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15181,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15181,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15181,301,213,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15181,303,0.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15181,306,326,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15181,307,75,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15181,320,17,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15181,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15181,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15181,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15181,601,55,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15181,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15181,606,1.535,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15182,203,20.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15182,204,7.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15182,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15182,207,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15182,208,153,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15182,255,68.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15182,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15182,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15182,301,239,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15182,303,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15182,306,377,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15182,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15182,320,53,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15182,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15182,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15182,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15182,601,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15182,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15182,606,1.644,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15183,203,29.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15183,204,8.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15183,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15183,207,2.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15183,208,198,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15183,255,59.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15183,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15183,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15183,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15183,303,1.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15183,306,207,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15183,307,50,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15183,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (15183,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15183,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15183,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15183,601,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15183,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15183,606,1.534,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15184,203,25.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15184,204,0.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15184,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15184,207,0.78,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15184,208,116,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15184,255,75.21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15184,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15184,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15184,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15184,303,1.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15184,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15184,307,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15184,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (15184,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15184,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15184,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15184,601,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15184,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15184,606,0.234,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15185,203,26.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15185,204,8.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15185,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15185,207,2.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15185,208,186,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15185,255,64.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15185,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15185,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15185,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15185,303,0.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15185,306,333,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15185,307,50,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15185,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (15185,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15185,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15185,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15185,601,31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15185,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15185,606,1.65,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15186,203,23.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15186,204,2.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15186,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15186,207,0.63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15186,208,128,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15186,255,74.02,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15186,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15186,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15186,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15186,303,0.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15186,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15186,307,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15186,320,6,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15186,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15186,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15186,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15186,601,42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15186,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15186,606,0.792,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15187,203,24.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15187,204,4.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15187,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15187,207,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15187,208,146,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15187,255,68.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15187,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15187,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15187,301,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15187,303,1.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15187,306,456,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15187,307,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15187,320,35,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15187,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15187,401,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15187,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15187,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15187,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15187,606,1.001,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15188,203,22.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15188,204,2.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15188,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15188,207,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15188,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15188,255,73.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15188,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15188,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15188,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15188,303,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15188,306,328,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15188,307,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15188,320,31,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15188,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15188,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15188,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15188,601,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15188,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15188,606,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15189,203,25.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15189,204,5.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15189,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15189,207,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15189,208,159,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15189,255,62.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15189,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15189,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15189,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15189,303,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15189,306,477,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15189,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15189,320,138,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15189,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15189,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15189,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15189,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15189,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15189,606,1.172,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15190,203,24.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15190,204,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15190,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15190,207,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15190,208,115,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15190,255,73.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15190,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15190,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15190,301,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15190,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15190,306,518,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15190,307,124,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15190,320,5,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15190,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15190,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15190,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15190,601,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15190,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15190,606,0.209,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15192,203,18.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15192,204,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15192,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15192,207,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15192,208,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15192,255,80.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15192,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15192,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15192,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15192,303,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15192,306,289,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15192,307,372,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15192,320,2,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15192,328,0.6,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (15192,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15192,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15192,601,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15192,605,0.006,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15192,606,0.105,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15194,203,23.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15194,204,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15194,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15194,207,2.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15194,208,109,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15194,255,71.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15194,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15194,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15194,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15194,303,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15194,306,533,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15194,307,113,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15194,320,62,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15194,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15194,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15194,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15194,601,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15194,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15194,606,0.241,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15195,203,22.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15195,204,6.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15195,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15195,207,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15195,208,153,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15195,255,70.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15195,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15195,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15195,301,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15195,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15195,306,353,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15195,307,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15195,320,59,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15195,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15195,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15195,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15195,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15195,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15195,606,1.434,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15196,203,18.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15196,204,17.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15196,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15196,207,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15196,208,239,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15196,255,61.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15196,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15196,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15196,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15196,303,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15196,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15196,307,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15196,320,18,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15196,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15196,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15196,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15196,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15196,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15196,606,3.102,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15197,203,21.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15197,204,17.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15197,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15197,207,3.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15197,208,250,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15197,255,63.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15197,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15197,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15197,301,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15197,303,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15197,306,542,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15197,307,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15197,320,35,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15197,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15197,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15197,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15197,601,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15197,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15197,606,4.174,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15199,203,22.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15199,204,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15199,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15199,207,1.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15199,208,109,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15199,255,75.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15199,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15199,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15199,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15199,303,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15199,306,560,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15199,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15199,320,17,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15199,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15199,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15199,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15199,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15199,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15199,606,0.255,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15200,203,26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15200,204,2.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15200,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15200,207,1.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15200,208,134,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15200,255,69.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15200,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15200,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15200,301,40,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15200,303,2.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15200,306,558,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15200,307,203,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15200,320,252,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15200,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15200,401,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15200,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15200,601,68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15200,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15200,606,0.465,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15201,203,25.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15201,204,10.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15201,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15201,207,2.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15201,208,201,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15201,255,61.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15201,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15201,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15201,301,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15201,303,1.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15201,306,521,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15201,307,110,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15201,320,23,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15201,328,11.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15201,401,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15201,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15201,601,60,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15201,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15201,606,2.881,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15204,203,24.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15204,204,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15204,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15204,207,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15204,208,119,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15204,255,73.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15204,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15204,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15204,301,141,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15204,303,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15204,306,499,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15204,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15204,320,24,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15204,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15204,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15204,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15204,601,110,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15204,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15204,606,0.319,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15205,203,24.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15205,204,1.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15205,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15205,207,1.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15205,208,118,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15205,255,72.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15205,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15205,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15205,301,77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15205,303,0.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15205,306,456,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15205,307,110,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15205,320,12,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15205,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15205,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15205,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15205,601,91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15205,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15205,606,0.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15206,203,21.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15206,204,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15206,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15206,207,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15206,208,102,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15206,255,76.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15206,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15206,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15206,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15206,303,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15206,306,513,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15206,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15206,320,14,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15206,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15206,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15206,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15206,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15206,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15206,606,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15207,203,28.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15207,204,8.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15207,205,1.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15207,207,1.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15207,208,204,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15207,255,58.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15207,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15207,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15207,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15207,303,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15207,306,283,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15207,307,117,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15207,320,91,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15207,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15207,401,16.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15207,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15207,601,479,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15207,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15207,606,1.866,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15208,203,17.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15208,204,19.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15208,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15208,207,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15208,208,250,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15208,255,62.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15208,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15208,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15208,301,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15208,303,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15208,306,459,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15208,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15208,320,102,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15208,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15208,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15208,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15208,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15208,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15208,606,4.099,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15209,203,25.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15209,204,8.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15209,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15209,207,3.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15209,208,182,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15209,255,59.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15209,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15209,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15209,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15209,303,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15209,306,628,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15209,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15209,320,13,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15209,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15209,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15209,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15209,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15209,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15209,606,1.257,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15210,203,25.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15210,204,13.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15210,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15210,207,1.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15210,208,231,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15210,255,65.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15210,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15210,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15210,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15210,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15210,306,505,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15210,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15210,320,149,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15210,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15210,401,4.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15210,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15210,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15210,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15210,606,3.214,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15211,203,25.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15211,204,4.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15211,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15211,207,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15211,208,154,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15211,255,68.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15211,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15211,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15211,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15211,303,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15211,306,550,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15211,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15211,320,34,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15211,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15211,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15211,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15211,601,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15211,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15211,606,1.077,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15212,203,24.58,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15212,204,5.28,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15212,205,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15212,207,1.82,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15212,208,153,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15212,255,70.65,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15212,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15212,291,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15212,301,8,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15212,303,0.45,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15212,306,439,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15212,307,90,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15212,320,42,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15212,328,13,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15212,401,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15212,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15212,601,55,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15212,605,0.041,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15212,606,0.971,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15214,203,21.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15214,204,4.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15214,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15214,207,1.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15214,208,133,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15214,255,71.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15214,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15214,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15214,301,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15214,303,0.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15214,306,437,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15214,307,74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15214,320,35,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15214,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15214,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15214,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15214,601,106,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15214,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15214,606,1.293,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15216,203,23.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15216,204,6.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15216,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15216,207,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15216,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15216,255,69.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15216,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15216,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15216,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15216,303,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15216,306,636,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15216,307,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15216,320,35,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15216,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15216,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15216,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15216,601,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15216,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15216,606,1.859,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15217,203,21.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15217,204,2.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15217,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15217,207,1.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15217,208,119,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15217,255,73.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15217,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15217,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15217,301,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15217,303,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15217,306,487,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15217,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15217,320,59,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15217,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15217,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15217,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15217,601,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15217,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15217,606,0.579,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15218,203,24.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15218,204,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15218,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15218,207,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15218,208,114,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15218,255,73.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15218,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15218,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15218,301,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15218,303,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15218,306,449,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15218,307,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15218,320,17,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15218,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15218,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15218,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15218,601,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15218,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15218,606,0.178,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15219,203,26.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15219,204,8.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15219,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15219,207,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15219,208,190,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15219,255,63.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15219,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15219,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15219,301,55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15219,303,1.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15219,306,463,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15219,307,67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15219,320,19,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15219,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15219,401,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15219,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15219,601,74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15219,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15219,606,1.474,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15220,203,28.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15220,204,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15220,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15220,207,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15220,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15220,255,62.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15220,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15220,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15220,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15220,303,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15220,306,522,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15220,307,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15220,320,18,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15220,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15220,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15220,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15220,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15220,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15220,606,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15221,203,29.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15221,204,0.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15221,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15221,207,1.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15221,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15221,255,68.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15221,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15221,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15221,301,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15221,303,0.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15221,306,527,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15221,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15221,320,22,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (15221,328,2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15221,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15221,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15221,601,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15221,605,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15221,606,0.205,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15223,203,24.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15223,204,7.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15223,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15223,207,1.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15223,208,172,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15223,255,65.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15223,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15223,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15223,301,33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15223,303,0.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15223,306,406,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15223,307,65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15223,320,39,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15223,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15223,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15223,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15223,601,77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15223,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15223,606,1.162,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15224,203,22.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15224,204,3.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15224,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15224,207,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15224,208,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15224,255,74.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15224,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15224,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15224,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15224,303,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15224,306,385,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15224,307,109,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15224,320,130,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15224,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15224,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15224,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15224,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15224,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15224,606,0.468,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15226,203,22.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15226,204,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15226,205,0.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15226,207,2.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15226,208,110,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15226,255,73.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15226,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15226,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15226,301,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15226,303,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15226,306,408,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15226,307,378,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15226,320,31,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15226,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15226,401,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15226,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15226,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15226,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15226,606,0.168,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15227,203,23.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15227,204,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15227,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15227,207,2.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15227,208,115,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15227,255,75.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15227,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15227,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15227,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15227,303,2.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15227,306,200,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15227,307,691,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15227,320,52,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15227,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15227,401,7.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15227,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15227,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15227,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15227,606,0.183,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15228,203,26.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15228,204,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15228,205,3.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15228,207,1.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15228,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15228,255,66.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15228,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15228,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15228,301,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15228,303,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15228,306,208,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15228,307,227,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15228,320,6,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15228,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15228,401,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15228,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15228,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15228,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15228,606,0.303,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15229,203,32.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15229,204,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15229,205,1.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15229,207,3.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15229,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15229,255,61.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15229,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15229,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15229,301,180,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15229,303,10.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15229,306,637,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15229,307,744,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15229,320,203,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15229,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15229,401,8.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15229,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15229,601,224,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15229,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15229,606,0.236,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15230,203,29.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15230,204,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15230,205,4.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15230,207,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15230,208,164,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15230,255,60.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15230,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15230,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15230,301,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15230,303,9.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15230,306,630,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15230,307,460,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15230,320,90,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15230,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15230,401,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15230,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15230,601,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15230,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15230,606,0.453,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15231,203,18.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15231,204,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15231,205,9.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15231,207,2.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15231,208,163,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15231,255,64.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15231,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15231,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15231,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15231,303,9.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15231,306,302,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15231,307,212,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15231,320,146,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (15231,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15231,401,12.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15231,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15231,601,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15231,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15231,606,1.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15232,203,22.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15232,204,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15232,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15232,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15232,208,105,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15232,255,66.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15232,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15232,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15232,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15232,303,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15232,306,181,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15232,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15232,320,24,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (15232,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15232,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15232,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15232,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15232,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15232,606,0.034,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15233,203,18.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15233,204,2.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15233,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15233,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15233,208,105,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15233,255,77.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15233,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15233,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15233,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15233,303,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15233,306,419,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15233,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15233,320,15,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15233,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15233,401,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15233,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15233,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15233,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15233,606,0.744,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15234,203,15.23,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15234,204,5.94,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15234,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15234,207,1.05,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15234,208,119,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15234,255,79.06,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15234,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15234,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15234,301,8,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15234,303,0.23,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15234,306,302,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15234,307,98,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15234,320,0,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15234,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15234,401,0,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15234,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15234,601,55,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15234,605,0.052,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15234,606,1.31,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15235,203,18.44,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15235,204,7.19,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15235,205,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15235,207,1.28,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15235,208,144,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15235,255,74.65,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15235,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15235,291,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15235,301,9,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15235,303,0.28,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15235,306,366,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15235,307,119,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15235,320,1,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15235,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15235,401,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15235,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15235,601,66,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15235,605,0.063,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15235,606,1.586,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15236,203,20.42,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (15236,204,13.42,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (15236,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15236,207,1.13,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (15236,208,208,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (15236,255,64.89,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (15236,269,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15236,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15236,301,9,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (15236,303,0.34,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (15236,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15236,307,59,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (15236,320,58,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (15236,328,11,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15236,401,3.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15236,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15236,601,55,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (15236,605,NULL,'100g',NULL,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15236,606,3.05,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (15237,203,22.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15237,204,12.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15237,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15237,207,1.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15237,208,206,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15237,255,64.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15237,269,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15237,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15237,301,15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15237,303,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15237,306,384,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15237,307,61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15237,320,69,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (15237,328,13.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15237,401,3.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15237,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15237,601,63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15237,605,NULL,'100g',NULL,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (15237,606,2.397,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15238,203,21.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15238,204,7.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15238,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15238,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15238,208,160,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15238,255,70.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15238,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15238,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15238,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15238,303,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15238,306,450,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15238,307,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15238,320,56,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15238,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15238,401,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15238,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15238,601,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15238,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15238,606,1.816,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15239,203,24.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15239,204,8.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15239,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15239,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15239,208,178,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15239,255,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15239,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15239,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15239,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15239,303,0.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15239,306,460,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15239,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15239,320,59,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15239,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15239,401,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15239,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15239,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15239,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15239,606,1.944,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15240,203,19.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15240,204,6.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15240,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15240,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15240,208,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15240,255,73.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15240,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15240,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15240,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15240,303,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15240,306,377,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15240,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15240,320,84,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15240,328,15.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15240,401,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15240,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15240,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15240,605,0.047,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15240,606,1.383,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15241,203,23.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15241,204,7.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15241,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15241,207,1.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15241,208,168,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15241,255,68.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15241,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15241,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15241,301,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15241,303,0.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15241,306,450,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15241,307,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15241,320,100,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (15241,328,19,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15241,401,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15241,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15241,601,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15241,605,0.056,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15241,606,1.651,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15242,203,14.85,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15242,204,0.97,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15242,205,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15242,207,1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15242,208,72,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15242,255,84.05,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15242,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15242,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15242,301,25,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15242,303,0.55,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15242,306,261,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15242,307,62,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15242,320,15,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15242,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15242,401,0.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15242,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15242,601,107,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15242,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15242,606,0.163,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15243,203,17.52,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15243,204,1.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15243,205,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15243,207,1.07,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15243,208,87,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15243,255,80.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15243,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15243,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15243,301,51,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15243,303,1.11,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15243,306,238,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15243,307,97,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15243,320,15,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15243,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15243,401,0.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15243,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15243,601,137,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15243,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15243,606,0.216,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15244,203,8.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15244,204,2.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15244,205,4.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15244,207,1.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15244,208,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15244,255,82.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15244,269,0.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15244,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15244,301,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15244,303,7.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15244,306,242,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15244,307,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15244,320,20,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (15244,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15244,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15244,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15244,601,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15244,605,0.053,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15244,606,0.736,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15245,203,5.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15245,204,1.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15245,205,5.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15245,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15245,208,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15245,255,86.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15245,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15245,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15245,301,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15245,303,5.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15245,306,124,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15245,307,178,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15245,320,8,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15245,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15245,401,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15245,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15245,601,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15245,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15245,606,0.443,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15246,203,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15246,204,2.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15246,205,7.28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15246,207,1.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15246,208,79,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15246,255,81.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15246,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15246,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15246,301,56,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15246,303,7.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15246,306,152,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15246,307,163,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15246,320,19,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (15246,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15246,401,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15246,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15246,601,38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15246,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15246,606,0.683,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15247,203,23.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15247,204,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15247,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15247,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15247,208,139,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15247,255,71.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15247,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15247,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15247,301,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15247,303,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15247,306,434,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15247,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15247,320,51,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15247,328,11.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15247,401,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15247,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15247,601,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15247,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15247,606,1.054,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15250,203,26.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15250,204,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15250,205,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15250,207,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15250,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15250,255,69.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15250,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15250,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15250,301,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15250,303,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15250,306,163,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15250,307,153,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15250,320,7,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (15250,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15250,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15250,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15250,601,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15250,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15250,606,0.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15251,203,12.69,'100g',1,1,'1995-06-26','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15251,204,11.72,'100g',1,1,'1995-06-26','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15251,205,13.96,'100g',3,1,'1995-06-26','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15251,207,1.25,'100g',1,1,'1995-06-26','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15251,208,212,'100g',3,1,'1995-06-26','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15251,255,60.38,'100g',1,1,'1995-06-26','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15251,269,NULL,'100g',NULL,1,'1995-06-23','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (15251,291,0,'100g',1,1,'1995-06-26','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15251,301,8,'100g',1,1,'1995-06-26','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15251,303,1.24,'100g',1,1,'1995-06-26','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15251,306,165,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15251,307,173,'100g',1,1,'1995-06-26','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15251,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (15251,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15251,401,0,'100g',1,1,'1995-06-26','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15251,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15251,601,26,'100g',1,1,'1995-06-26','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (15251,605,NULL,'100g',NULL,1,'1995-06-23','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (15251,606,1.57,'100g',1,1,'1995-06-26','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15252,203,11.97,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15252,204,10.43,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15252,205,11.85,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15252,207,1.19,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15252,208,189,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15252,255,64.57,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15252,269,NULL,'100g',NULL,1,'2006-02-23','2007-03-25');
INSERT INTO `cndb_nutval` VALUES (15252,291,0,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15252,301,9,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15252,303,1.46,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15252,306,161,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15252,307,167,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15252,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (15252,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15252,401,0,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15252,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (15252,601,27,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15252,605,NULL,'100g',NULL,1,'2006-02-23','2007-03-25');
INSERT INTO `cndb_nutval` VALUES (15252,606,1.497,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15253,203,20.63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15253,204,7.17,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15253,205,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15253,207,2.45,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15253,208,153,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15253,255,71.07,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15253,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15253,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15253,301,198,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15253,303,0.57,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15253,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15253,307,433,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15253,320,39,'100g',1,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (15253,328,19,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15253,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15253,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15253,601,67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15253,605,0.041,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15253,606,1.46,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15260,203,23.1,'100g',1,1,'2006-02-23','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15260,204,5.02,'100g',1,1,'2006-02-23','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15260,205,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15260,207,2.5,'100g',1,1,'2006-02-23','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15260,208,138,'100g',3,1,'2006-02-23','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15260,255,70.71,'100g',1,1,'2006-02-23','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15260,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15260,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15260,301,283,'100g',1,1,'2006-02-23','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15260,303,0.77,'100g',1,1,'2006-02-23','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15260,306,333,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15260,307,381,'100g',1,1,'2006-02-23','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15260,320,20,'100g',1,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (15260,328,14.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15260,401,0,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15260,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15260,601,83,'100g',1,1,'2006-02-23','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15260,605,0.027,'100g',NULL,1,'2006-02-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (15260,606,0.895,'100g',3,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15261,203,20.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15261,204,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15261,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15261,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15261,208,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15261,255,78.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15261,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15261,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15261,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15261,303,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15261,306,302,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15261,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15261,320,0,'100g',1,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (15261,328,3.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15261,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15261,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15261,601,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15261,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15261,606,0.585,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15262,203,26.15,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15262,204,2.65,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15262,205,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15262,207,1.14,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15262,208,128,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15262,255,71.59,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15262,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15262,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15262,301,14,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15262,303,0.69,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15262,306,380,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15262,307,56,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15262,320,0,'100g',1,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (15262,328,3.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15262,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15262,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15262,601,57,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15262,605,NULL,'100g',NULL,1,'2006-02-23','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (15262,606,0.94,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (15264,203,26.33,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15264,204,5.87,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15264,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15264,207,1.89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15264,208,158,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15264,255,67.78,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15264,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15264,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15264,301,37,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15264,303,0.48,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15264,306,312,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15264,307,386,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15264,320,56,'100g',1,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (15264,328,21.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15264,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15264,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15264,601,66,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15264,605,0.032,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15264,606,1.211,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15265,203,24.62,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15265,204,4.21,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15265,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15265,207,1.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15265,208,136,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15265,255,70.63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15265,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15265,291,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15265,301,60,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15265,303,0.57,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15265,306,326,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15265,307,378,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15265,320,20,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (15265,328,14.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15265,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15265,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15265,601,83,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15265,605,0.022,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15265,606,0.749,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (15266,203,17.17,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15266,204,0.82,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (15266,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15266,207,1.34,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15266,208,76,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (15266,255,81.99,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15266,269,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15266,291,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15266,301,12,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15266,303,0.27,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15266,306,331,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15266,307,159,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15266,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (15266,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15266,401,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15266,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15266,601,61,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15266,605,0.003,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (15266,606,0.148,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (15267,203,19.42,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15267,204,0.995,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (15267,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15267,207,1.42,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15267,208,86.616,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (15267,255,79.34,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15267,269,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15267,291,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15267,301,13,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15267,303,0.29,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15267,306,364,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15267,307,166,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15267,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (15267,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15267,401,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15267,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15267,601,74,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15267,605,0.003,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (15267,606,0.203,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (15269,203,20.42,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15269,204,0.25,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15269,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15269,207,1.33,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15269,208,84,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15269,255,78.37,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15269,269,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15269,291,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15269,301,17,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15269,303,0.16,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15269,306,372,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15269,307,134,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15269,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (15269,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15269,401,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15269,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15269,601,61,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15269,605,0.001,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15269,606,0.048,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15270,203,20.1,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15270,204,0.51,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15270,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15270,207,1.23,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15270,208,85,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15270,255,78.45,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15270,269,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15270,291,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15270,301,64,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15270,303,0.52,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15270,306,264,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15270,307,119,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15270,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (15270,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15270,401,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15270,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15270,601,161,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15270,605,0.004,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15270,606,0.101,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (15271,203,23.98,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15271,204,0.28,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15271,205,0.2,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15271,207,1.22,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15271,208,99,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15271,255,74.33,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15271,269,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15271,291,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15271,301,70,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15271,303,0.51,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15271,306,259,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15271,307,111,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15271,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (15271,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15271,401,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15271,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15271,601,189,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15271,605,0.002,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (15271,606,0.056,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15274,203,21.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15274,204,2.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15274,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15274,207,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15274,208,110,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15274,255,75.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15274,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15274,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15274,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15274,303,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15274,306,417,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15274,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15274,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (15274,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (15274,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15274,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (15274,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (15274,605,0.019,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (15274,606,0.595,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16001,203,19.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16001,204,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16001,205,62.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16001,207,3.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16001,208,329,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16001,255,13.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16001,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16001,291,12.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16001,301,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16001,303,4.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16001,306,1254,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16001,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16001,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16001,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16001,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16001,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16001,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16001,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16001,606,0.191,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16002,203,7.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16002,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16002,205,24.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16002,207,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16002,208,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16002,255,66.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16002,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16002,291,7.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16002,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16002,303,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16002,306,532,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16002,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16002,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16002,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16002,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16002,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16002,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16002,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16002,606,0.036,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16003,203,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16003,204,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16003,205,55.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16003,207,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16003,208,237,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16003,255,40.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16003,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16003,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16003,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16003,303,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16003,306,119,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16003,307,218,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16003,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16003,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16003,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16003,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16003,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16003,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16003,606,0.011,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16004,203,3.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16004,204,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16004,205,60.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16004,207,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16004,208,260,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16004,255,35.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16004,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16004,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16004,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16004,303,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16004,306,45,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16004,307,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16004,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16004,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16004,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16004,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16004,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16004,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16004,606,0.043,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16005,203,5.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16005,204,5.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16005,205,21.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16005,207,2.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16005,208,155,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16005,255,65.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16005,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16005,291,5.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16005,301,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16005,303,1.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16005,306,358,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16005,307,422,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16005,320,0,'100g',1,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (16005,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16005,401,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16005,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16005,601,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16005,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16005,606,1.948,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16006,203,4.75,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16006,204,0.37,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16006,205,21.14,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16006,207,1.75,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16006,208,94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16006,255,72,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16006,269,7.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16006,291,4.1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16006,301,34,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16006,303,1.19,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16006,306,224,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16006,307,343,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16006,320,5,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (16006,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16006,401,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16006,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16006,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16006,605,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16006,606,0.071,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16007,203,6.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16007,204,3.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16007,205,16.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16007,207,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16007,208,121,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16007,255,71.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16007,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16007,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16007,301,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16007,303,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16007,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16007,307,475,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16007,320,11,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16007,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16007,401,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16007,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16007,601,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16007,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16007,606,1.677,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16008,203,6.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16008,204,6.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16008,205,15.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16008,207,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16008,208,142,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16008,255,69.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16008,269,6.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16008,291,6.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16008,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16008,303,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16008,306,235,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16008,307,430,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16008,320,4,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16008,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16008,401,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16008,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16008,601,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16008,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16008,606,2.352,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16009,203,5.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16009,204,1.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16009,205,19.99,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16009,207,1.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16009,208,106,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16009,255,71.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16009,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16009,291,5.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16009,301,53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16009,303,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16009,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16009,307,414,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16009,320,0,'100g',1,1,'2024-12-12','2006-01-01');
INSERT INTO `cndb_nutval` VALUES (16009,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16009,401,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16009,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16009,601,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16009,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16009,606,0.599,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16010,203,4.52,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16010,204,0.89,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16010,205,21.57,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16010,207,1.53,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16010,208,105,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16010,255,71.48,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16010,269,8.23,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16010,291,4.4,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16010,301,39,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16010,303,1.4,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16010,306,231,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16010,307,391,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16010,320,1,'100g',1,1,'2024-12-12','2012-01-06');
INSERT INTO `cndb_nutval` VALUES (16010,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16010,401,0,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16010,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16010,601,7,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16010,605,0,'100g',4,1,'2006-01-24','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16010,606,0.231,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16011,203,5.15,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16011,204,0.93,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16011,205,18.69,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16011,207,1.73,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16011,208,94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16011,255,73.5,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16011,269,5.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16011,291,4,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16011,301,56,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16011,303,3.24,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16011,306,295,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16011,307,437,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16011,320,4,'100g',1,1,'2024-12-12','2008-01-02');
INSERT INTO `cndb_nutval` VALUES (16011,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16011,401,3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16011,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16011,601,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16011,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16011,606,0.293,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (16014,203,21.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16014,204,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16014,205,62.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16014,207,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16014,208,341,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16014,255,11.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16014,269,2.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16014,291,15.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16014,301,123,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16014,303,5.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16014,306,1483,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16014,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16014,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16014,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16014,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16014,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16014,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16014,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16014,606,0.366,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16015,203,8.86,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16015,204,0.54,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16015,205,23.71,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16015,207,1.15,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16015,208,132,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16015,255,65.74,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16015,269,0.32,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16015,291,8.7,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16015,301,27,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16015,303,2.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16015,306,355,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16015,307,1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16015,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16015,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16015,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16015,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16015,601,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16015,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16015,606,0.139,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16016,203,21.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16016,204,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16016,205,63.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16016,207,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16016,208,339,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16016,255,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16016,269,2.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16016,291,15.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16016,301,160,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16016,303,8.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16016,306,1500,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16016,307,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16016,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (16016,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16016,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16016,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16016,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16016,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16016,606,0.232,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16017,203,8.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16017,204,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16017,205,24.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16017,207,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16017,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16017,255,65.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16017,269,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16017,291,8.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16017,301,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16017,303,2.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16017,306,433,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16017,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16017,320,0,'100g',1,1,'2024-12-12','2011-01-01');
INSERT INTO `cndb_nutval` VALUES (16017,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16017,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16017,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16017,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16017,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16017,606,0.089,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16018,203,6.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16018,204,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16018,205,16.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16018,207,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16018,208,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16018,255,75.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16018,269,0.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16018,291,6.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16018,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16018,303,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16018,306,308,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16018,307,384,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16018,320,0,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (16018,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16018,401,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16018,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16018,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16018,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16018,606,0.075,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16019,203,23.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16019,204,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16019,205,60.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16019,207,3.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16019,208,335,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16019,255,12.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16019,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16019,291,24.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16019,301,127,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16019,303,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16019,306,1332,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16019,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16019,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16019,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16019,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16019,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16019,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16019,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16019,606,0.316,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16020,203,9.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16020,204,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16020,205,24.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16020,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16020,208,136,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16020,255,64.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16020,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16020,291,8.6,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16020,301,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16020,303,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16020,306,387,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16020,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16020,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16020,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16020,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16020,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16020,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16020,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16020,606,0.119,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16021,203,5.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16021,204,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16021,205,15.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16021,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16021,208,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16021,255,77.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16021,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16021,291,6.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16021,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16021,303,1.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16021,306,260,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16021,307,332,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16021,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16021,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16021,401,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16021,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16021,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16021,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16021,606,0.072,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16022,203,18.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16022,204,2.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16022,205,64.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16022,207,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16022,208,343,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16022,255,10.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16022,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16022,291,25.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16022,301,186,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16022,303,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16022,306,1316,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16022,307,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16022,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16022,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16022,401,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16022,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16022,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16022,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16022,606,0.221,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16023,203,7.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16023,204,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16023,205,24.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16023,207,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16023,208,129,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16023,255,66.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16023,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16023,291,9.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16023,301,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16023,303,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16023,306,370,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16023,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16023,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16023,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16023,401,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16023,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16023,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16023,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16023,606,0.083,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16024,203,21.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16024,204,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16024,205,62.37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16024,207,3.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16024,208,339,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16024,255,10.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16024,269,2.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16024,291,20.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16024,301,175,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16024,303,5.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16024,306,1387,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16024,307,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16024,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (16024,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16024,401,5.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16024,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16024,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16024,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16024,606,0.356,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16025,203,8.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16025,204,0.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16025,205,21.09,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16025,207,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16025,208,118,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16025,255,69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16025,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16025,291,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16025,301,68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16025,303,2.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16025,306,391,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16025,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16025,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16025,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16025,401,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16025,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16025,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16025,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16025,606,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16026,203,7.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16026,204,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16026,205,21.02,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16026,207,1.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16026,208,114,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16026,255,69.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16026,269,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16026,291,4.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16026,301,53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16026,303,1.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16026,306,351,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16026,307,370,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16026,320,0,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (16026,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16026,401,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16026,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16026,601,0,'100g',4,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (16026,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16026,606,0.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16027,203,23.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16027,204,0.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16027,205,60.01,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16027,207,3.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16027,208,333,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16027,255,11.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16027,269,2.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16027,291,24.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16027,301,143,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16027,303,8.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16027,306,1406,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16027,307,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16027,320,0,'100g',2,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (16027,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16027,401,4.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16027,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16027,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16027,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16027,606,0.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16028,203,8.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16028,204,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16028,205,22.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16028,207,1.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16028,208,127,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16028,255,66.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16028,269,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16028,291,6.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16028,301,35,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16028,303,2.22,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16028,306,405,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16028,307,1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16028,320,0,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (16028,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16028,401,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16028,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16028,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16028,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16028,606,0.073,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16029,203,5.22,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16029,204,0.6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16029,205,14.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16029,207,1.64,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16029,208,84,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16029,255,78.04,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16029,269,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16029,291,4.3,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16029,301,34,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16029,303,1.17,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16029,306,237,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16029,307,296,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16029,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16029,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16029,401,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16029,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16029,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16029,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16029,606,0.141,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16030,203,24.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16030,204,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16030,205,59.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16030,207,3.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16030,208,330,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16030,255,11.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16030,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16030,291,24.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16030,301,195,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16030,303,9.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16030,306,1490,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16030,307,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16030,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16030,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16030,401,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16030,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16030,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16030,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16030,606,0.036,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16031,203,9.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16031,204,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16031,205,22.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16031,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16031,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16031,255,66.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16031,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16031,291,9.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16031,301,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16031,303,2.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16031,306,419,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16031,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16031,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16031,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16031,401,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16031,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16031,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16031,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16031,606,0.014,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16032,203,22.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16032,204,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16032,205,61.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16032,207,3.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16032,208,337,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16032,255,11.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16032,269,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16032,291,15.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16032,301,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16032,303,6.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16032,306,1359,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16032,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16032,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16032,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16032,401,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16032,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16032,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16032,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16032,606,0.154,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16033,203,8.67,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16033,204,0.5,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16033,205,22.8,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16033,207,1.09,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16033,208,127,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16033,255,66.94,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16033,269,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16033,291,7.4,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16033,301,28,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16033,303,2.94,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16033,306,403,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16033,307,2,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16033,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16033,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16033,401,1.2,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16033,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16033,601,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16033,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16033,606,0.072,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16034,203,5.22,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16034,204,0.36,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16034,205,14.83,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16034,207,1.64,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16034,208,81,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16034,255,77.96,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16034,269,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16034,291,4.3,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16034,301,29,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16034,303,1.25,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16034,306,260,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16034,307,256,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16034,320,0,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (16034,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16034,401,0.8,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16034,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16034,601,0,'100g',4,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16034,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16034,606,0.125,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16035,203,25.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16035,204,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16035,205,58.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16035,207,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16035,208,329,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16035,255,11.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16035,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16035,291,24.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16035,301,131,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16035,303,8.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16035,306,1346,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16035,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16035,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16035,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16035,401,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16035,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16035,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16035,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16035,606,0.065,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16036,203,9.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16036,204,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16036,205,21.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16036,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16036,208,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16036,255,66.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16036,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16036,291,9.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16036,301,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16036,303,2.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16036,306,378,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16036,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16036,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16036,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16036,401,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16036,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16036,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16036,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16036,606,0.024,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16037,203,22.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16037,204,1.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16037,205,60.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16037,207,3.32,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16037,208,337,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16037,255,12.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16037,269,3.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16037,291,15.3,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16037,301,147,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16037,303,5.49,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16037,306,1185,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16037,307,5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16037,320,0,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (16037,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16037,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16037,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16037,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16037,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16037,606,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16038,203,8.23,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16038,204,0.62,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16038,205,26.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16038,207,1.3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16038,208,140,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16038,255,63.81,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16038,269,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16038,291,10.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16038,301,69,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16038,303,2.36,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16038,306,389,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16038,307,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16038,320,0,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (16038,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16038,401,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16038,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16038,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16038,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16038,606,0.098,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16039,203,7.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16039,204,0.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16039,205,20.45,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16039,207,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16039,208,113,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16039,255,70.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16039,269,0.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16039,291,5.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16039,301,47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16039,303,1.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16039,306,288,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16039,307,336,'100g',6,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16039,320,0,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (16039,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16039,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16039,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16039,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16039,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16039,606,0.112,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16040,203,20.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16040,204,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16040,205,64.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16040,207,3.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16040,208,343,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16040,255,10.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16040,269,2.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16040,291,12.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16040,301,130,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16040,303,6.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16040,306,1464,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16040,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16040,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16040,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16040,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16040,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16040,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16040,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16040,606,0.292,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16041,203,9.06,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16041,204,0.49,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16041,205,27.91,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16041,207,1.34,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16041,208,149,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16041,255,61.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16041,269,0.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16041,291,5.3,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16041,301,52,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16041,303,2.3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16041,306,508,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16041,307,2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16041,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16041,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16041,401,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16041,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16041,601,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16041,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16041,606,0.126,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16042,203,21.42,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16042,204,1.23,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16042,205,62.55,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16042,207,3.46,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16042,208,347,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16042,255,11.33,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16042,269,2.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16042,291,15.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16042,301,113,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16042,303,5.07,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16042,306,1393,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16042,307,12,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16042,320,0,'100g',1,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (16042,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16042,401,6.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16042,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16042,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16042,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16042,606,0.235,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16043,203,9.01,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16043,204,0.65,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16043,205,26.22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16043,207,1.17,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16043,208,143,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16043,255,62.95,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16043,269,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16043,291,9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16043,301,46,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16043,303,2.09,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16043,306,436,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16043,307,1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16043,320,0,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (16043,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16043,401,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16043,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16043,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16043,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16043,606,0.136,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16044,203,4.6,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16044,204,0.56,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16044,205,15.18,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16044,207,1.48,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16044,208,82,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16044,255,78.19,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16044,269,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16044,291,4.6,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16044,301,47,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16044,303,1.47,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16044,306,276,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16044,307,268,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16044,320,0,'100g',1,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (16044,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16044,401,0.7,'100g',7,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16044,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16044,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16044,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16044,606,0.123,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16045,203,21.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16045,204,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16045,205,62.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16045,207,3.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16045,208,336,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16045,255,11.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16045,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16045,291,24.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16045,301,173,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16045,303,7.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16045,306,1542,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16045,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16045,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16045,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16045,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16045,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16045,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16045,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16045,606,0.304,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16046,203,8.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16046,204,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16046,205,25.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16046,207,1.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16046,208,142,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16046,255,63.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16046,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16046,291,10.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16046,301,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16046,303,2.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16046,306,463,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16046,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16046,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16046,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16046,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16046,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16046,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16046,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16046,606,0.166,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16047,203,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16047,204,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16047,205,60.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16047,207,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16047,208,345,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16047,255,11.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16047,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16047,291,25.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16047,301,166,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16047,303,7.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16047,306,1042,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16047,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16047,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16047,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16047,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16047,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16047,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16047,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16047,606,0.671,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16048,203,9.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16048,204,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16048,205,25.28,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16048,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16048,208,144,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16048,255,62.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16048,269,0.34,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16048,291,10.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16048,301,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16048,303,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16048,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16048,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16048,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16048,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16048,401,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16048,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16048,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16048,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16048,606,0.279,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16049,203,23.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16049,204,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16049,205,60.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16049,207,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16049,208,333,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16049,255,11.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16049,269,2.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16049,291,15.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16049,301,240,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16049,303,10.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16049,306,1795,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16049,307,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16049,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16049,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16049,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16049,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16049,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16049,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16049,606,0.219,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16050,203,9.73,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16050,204,0.35,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16050,205,25.09,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16050,207,1.75,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16050,208,139,'100g',3,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16050,255,63.08,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16050,269,0.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16050,291,6.3,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16050,301,90,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16050,303,3.7,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16050,306,561,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16050,307,6,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16050,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16050,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16050,401,0,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16050,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16050,601,0,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16050,605,0,'100g',NULL,1,'1995-06-27','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16050,606,0.091,'100g',1,1,'1995-06-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16051,203,7.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16051,204,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16051,205,21.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16051,207,1.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16051,208,114,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16051,255,70.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16051,269,0.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16051,291,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16051,301,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16051,303,2.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16051,306,454,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16051,307,340,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16051,320,0,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (16051,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16051,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16051,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16051,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16051,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16051,606,0.074,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16052,203,26.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16052,204,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16052,205,58.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16052,207,3.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16052,208,341,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16052,255,10.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16052,269,5.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16052,291,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16052,301,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16052,303,6.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16052,306,1062,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16052,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16052,320,3,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16052,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16052,401,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16052,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16052,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16052,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16052,606,0.254,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16053,203,7.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16053,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16053,205,19.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16053,207,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16053,208,110,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16053,255,71.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16053,269,1.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16053,291,5.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16053,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16053,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16053,306,268,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16053,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16053,320,1,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16053,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16053,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16053,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16053,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16053,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16053,606,0.066,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16054,203,5.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16054,204,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16054,205,12.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16054,207,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16054,208,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16054,255,80.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16054,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16054,291,3.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16054,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16054,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16054,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16054,307,453,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16054,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16054,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16054,401,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16054,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16054,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16054,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16054,606,0.037,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16055,203,4.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16055,204,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16055,205,88.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16055,207,2.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16055,208,222,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16055,255,3.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16055,269,49.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16055,291,39.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16055,301,348,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16055,303,2.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16055,306,827,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16055,307,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16055,320,1,'100g',2,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (16055,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16055,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16055,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16055,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16055,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16055,606,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16056,203,20.47,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16056,204,6.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16056,205,62.95,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16056,207,2.85,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16056,208,378,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16056,255,7.68,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16056,269,10.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16056,291,12.2,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16056,301,57,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16056,303,4.31,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16056,306,718,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16056,307,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16056,320,3,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16056,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16056,401,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16056,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16056,601,0,'100g',4,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16056,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16056,606,0.603,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16057,203,8.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16057,204,2.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16057,205,27.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16057,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16057,208,164,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16057,255,60.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16057,269,4.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16057,291,7.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16057,301,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16057,303,2.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16057,306,291,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16057,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16057,320,1,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16057,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16057,401,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16057,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16057,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16057,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16057,606,0.269,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16058,203,4.92,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16058,204,1.95,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16058,205,13.49,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16058,207,1.09,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16058,208,88,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16058,255,78.55,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16058,269,NULL,'100g',NULL,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16058,291,4.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16058,301,35,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16058,303,1.23,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16058,306,144,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16058,307,278,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16058,320,1,'100g',2,1,'2024-12-12','2008-01-08');
INSERT INTO `cndb_nutval` VALUES (16058,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16058,401,0.1,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16058,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16058,601,0,'100g',4,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16058,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16058,606,0.204,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16059,203,6.12,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16059,204,3.76,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16059,205,13.24,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16059,207,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16059,208,103,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16059,255,75.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16059,269,1.65,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16059,291,3.3,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16059,301,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16059,303,3.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16059,306,365,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16059,307,423,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16059,320,17,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16059,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16059,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16059,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16059,601,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16059,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16059,606,1.133,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16060,203,23.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16060,204,2.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16060,205,59.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16060,207,3.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16060,208,343,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16060,255,11.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16060,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16060,291,10.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16060,301,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16060,303,9.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16060,306,1375,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16060,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16060,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16060,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16060,401,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16060,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16060,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16060,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16060,606,0.542,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16061,203,8.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16061,204,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16061,205,20.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16061,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16061,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16061,255,69.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16061,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16061,291,3.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16061,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16061,303,3.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16061,306,375,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16061,307,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16061,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16061,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16061,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16061,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16061,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16061,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16061,606,0.185,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16062,203,23.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16062,204,1.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16062,205,60.03,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16062,207,3.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16062,208,336,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16062,255,11.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16062,269,6.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16062,291,10.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16062,301,110,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16062,303,8.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16062,306,1112,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16062,307,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16062,320,3,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16062,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16062,401,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16062,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16062,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16062,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16062,606,0.331,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16063,203,7.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16063,204,0.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16063,205,20.76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16063,207,0.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16063,208,116,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16063,255,70.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16063,269,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16063,291,6.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16063,301,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16063,303,2.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16063,306,278,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16063,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16063,320,1,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16063,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16063,401,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16063,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16063,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16063,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16063,606,0.138,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16064,203,4.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16064,204,0.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16064,205,13.63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16064,207,1.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16064,208,77,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16064,255,79.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16064,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16064,291,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16064,301,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16064,303,0.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16064,306,172,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16064,307,293,'100g',6,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16064,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16064,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16064,401,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16064,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16064,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16064,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16064,606,0.144,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16065,203,2.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16065,204,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16065,205,16.53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16065,207,1.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16065,208,83,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16065,255,77.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16065,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16065,291,3.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16065,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16065,303,1.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16065,306,178,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16065,307,350,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16065,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16065,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16065,401,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16065,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16065,601,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16065,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16065,606,0.605,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16067,203,23.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16067,204,1.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16067,205,60.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16067,207,4.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16067,208,344,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16067,255,9.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16067,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16067,291,25.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16067,301,130,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16067,303,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16067,306,1235,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16067,307,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16067,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16067,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16067,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16067,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16067,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16067,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16067,606,0.288,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16068,203,8.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16068,204,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16068,205,20.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16068,207,1.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16068,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16068,255,69.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16068,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16068,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16068,301,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16068,303,4.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16068,306,337,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16068,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16068,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16068,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16068,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16068,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16068,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16068,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16068,606,0.099,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16069,203,24.63,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16069,204,1.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16069,205,63.35,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16069,207,2.71,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16069,208,352,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16069,255,8.26,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16069,269,2.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16069,291,10.7,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16069,301,35,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16069,303,6.51,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16069,306,677,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16069,307,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16069,320,2,'100g',2,1,'2024-12-12','2010-01-03');
INSERT INTO `cndb_nutval` VALUES (16069,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16069,401,4.5,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16069,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16069,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16069,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16069,606,0.154,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16070,203,9.02,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16070,204,0.38,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16070,205,20.13,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16070,207,0.83,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16070,208,116,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16070,255,69.64,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16070,269,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16070,291,7.9,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16070,301,19,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16070,303,3.33,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16070,306,369,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16070,307,2,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16070,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16070,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16070,401,1.5,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16070,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16070,601,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16070,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16070,606,0.053,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16071,203,21.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16071,204,0.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16071,205,63.38,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16071,207,4.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16071,208,338,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16071,255,10.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16071,269,8.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16071,291,19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16071,301,81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16071,303,7.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16071,306,1724,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16071,307,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16071,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16071,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16071,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16071,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16071,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16071,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16071,606,0.161,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16072,203,7.8,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16072,204,0.38,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16072,205,20.88,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16072,207,1.15,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16072,208,115,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16072,255,69.79,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16072,269,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16072,291,7,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16072,301,17,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16072,303,2.39,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16072,306,508,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16072,307,2,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16072,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16072,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16072,401,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16072,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16072,601,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16072,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16072,606,0.089,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16073,203,4.93,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16073,204,0.17,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16073,205,14.91,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16073,207,2.92,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16073,208,79,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16073,255,77.08,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16073,269,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16073,291,4.8,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16073,301,21,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16073,303,1.81,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16073,306,220,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16073,307,336,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16073,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16073,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16073,401,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16073,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16073,601,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16073,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16073,606,0.039,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16074,203,20.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16074,204,0.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16074,205,62.83,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16074,207,3.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16074,208,335,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16074,255,12.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16074,269,8.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16074,291,20.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16074,301,81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16074,303,6.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16074,306,1403,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16074,307,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16074,320,0,'100g',2,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (16074,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16074,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16074,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16074,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16074,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16074,606,0.219,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16075,203,8.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16075,204,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16075,205,23.31,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16075,207,1.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16075,208,126,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16075,255,67.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16075,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16075,291,7.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16075,301,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16075,303,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16075,306,401,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16075,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16075,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16075,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16075,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16075,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16075,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16075,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16075,606,0.088,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16076,203,36.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16076,204,9.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16076,205,40.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16076,207,3.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16076,208,371,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16076,255,10.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16076,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16076,291,18.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16076,301,176,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16076,303,4.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16076,306,1013,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16076,307,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16076,320,0,'100g',1,1,'2024-12-12','2011-01-11');
INSERT INTO `cndb_nutval` VALUES (16076,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16076,401,4.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16076,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16076,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16076,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16076,606,1.156,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16077,203,15.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16077,204,2.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16077,205,9.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16077,207,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16077,208,119,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16077,255,71.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16077,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16077,291,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16077,301,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16077,303,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16077,306,245,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16077,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16077,320,0,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (16077,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16077,401,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16077,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16077,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16077,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16077,606,0.346,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16078,203,22.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16078,204,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16078,205,61.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16078,207,4.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16078,208,343,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16078,255,9.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16078,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16078,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16078,301,150,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16078,303,10.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16078,306,1191,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16078,307,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16078,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16078,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16078,401,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16078,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16078,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16078,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16078,606,0.364,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16079,203,7.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16079,204,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16079,205,20.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16079,207,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16079,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16079,255,69.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16079,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16079,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16079,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16079,303,3.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16079,306,304,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16079,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16079,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16079,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16079,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16079,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16079,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16079,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16079,606,0.124,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16080,203,23.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16080,204,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16080,205,62.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16080,207,3.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16080,208,347,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16080,255,9.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16080,269,6.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16080,291,16.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16080,301,132,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16080,303,6.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16080,306,1246,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16080,307,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16080,320,6,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16080,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16080,401,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16080,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16080,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16080,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16080,606,0.348,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16081,203,7.02,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16081,204,0.38,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16081,205,19.15,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16081,207,0.79,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16081,208,105,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16081,255,72.66,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16081,269,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16081,291,7.6,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16081,301,27,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16081,303,1.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16081,306,266,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16081,307,2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16081,320,1,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16081,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16081,401,1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16081,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16081,601,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16081,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16081,606,0.116,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16082,203,0.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16082,204,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16082,205,86.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16082,207,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16082,208,351,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16082,255,13.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16082,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16082,291,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16082,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16082,303,2.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16082,306,10,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16082,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16082,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16082,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16082,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16082,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16082,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16082,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16082,606,0.017,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16083,203,25.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16083,204,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16083,205,58.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16083,207,3.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16083,208,341,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16083,255,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16083,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16083,291,18.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16083,301,138,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16083,303,7.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16083,306,983,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16083,307,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16083,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16083,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16083,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16083,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16083,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16083,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16083,606,0.114,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16084,203,7.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16084,204,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16084,205,18.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16084,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16084,208,105,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16084,255,72.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16084,269,2.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16084,291,6.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16084,301,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16084,303,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16084,306,231,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16084,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16084,320,2,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16084,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16084,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16084,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16084,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16084,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16084,606,0.038,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16085,203,23.12,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16085,204,3.89,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16085,205,61.63,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16085,207,2.67,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16085,208,364,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16085,255,8.69,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16085,269,3.14,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16085,291,22.2,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16085,301,46,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16085,303,4.73,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16085,306,852,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16085,307,5,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16085,320,7,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16085,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16085,401,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16085,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16085,601,0,'100g',4,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16085,605,0.004,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16085,606,0.408,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16086,203,8.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16086,204,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16086,205,21.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16086,207,0.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16086,208,118,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16086,255,69.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16086,269,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16086,291,8.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16086,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16086,303,1.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16086,306,362,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16086,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16086,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16086,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16086,401,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16086,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16086,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16086,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16086,606,0.054,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16087,203,25.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16087,204,49.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16087,205,16.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16087,207,2.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16087,208,567,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16087,255,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16087,269,4.72,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16087,291,8.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16087,301,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16087,303,4.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16087,306,705,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16087,307,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16087,320,0,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (16087,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16087,401,0,'100g',4,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16087,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16087,601,0,'100g',4,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16087,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16087,606,6.279,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16088,203,13.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16088,204,22.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16088,205,21.26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16088,207,1.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16088,208,318,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16088,255,41.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16088,269,2.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16088,291,8.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16088,301,55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16088,303,1.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16088,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16088,307,751,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16088,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (16088,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16088,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16088,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16088,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16088,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16088,606,3.055,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16089,203,28.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16089,204,52.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16089,205,15.26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16089,207,2.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16089,208,599,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16089,255,1.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16089,269,4.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16089,291,9.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16089,301,61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16089,303,1.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16089,306,726,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16089,307,320,'100g',1,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (16089,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (16089,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16089,401,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16089,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16089,601,0,'100g',4,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16089,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16089,606,8.655,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16090,203,24.35,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16090,204,49.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16090,205,21.26,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16090,207,2.92,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16090,208,587,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16090,255,1.81,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16090,269,4.9,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16090,291,8.4,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16090,301,58,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16090,303,1.58,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16090,306,634,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16090,307,410,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16090,320,0,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (16090,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16090,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16090,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16090,601,0,'100g',4,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16090,605,0.027,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16090,606,7.723,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16091,203,26.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16091,204,49.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16091,205,15.83,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16091,207,2.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16091,208,570,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16091,255,6.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16091,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16091,291,9.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16091,301,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16091,303,3.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16091,306,744,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16091,307,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16091,320,0,'100g',2,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (16091,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16091,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16091,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16091,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16091,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16091,606,7.098,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16092,203,28.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16092,204,49.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16092,205,17.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16092,207,3.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16092,208,579,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16092,255,1.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16092,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16092,291,8.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16092,301,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16092,303,2.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16092,306,776,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16092,307,433,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16092,320,0,'100g',1,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (16092,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16092,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16092,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16092,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16092,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16092,606,7.555,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16093,203,25.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16093,204,47.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16093,205,20.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16093,207,2.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16093,208,570,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16093,255,4.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16093,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16093,291,8.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16093,301,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16093,303,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16093,306,332,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16093,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16093,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16093,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16093,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16093,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16093,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16093,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16093,606,7.329,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16094,203,27.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16094,204,51.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16094,205,16.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16094,207,3.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16094,208,589,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16094,255,2.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16094,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16094,291,8.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16094,301,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16094,303,1.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16094,306,612,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16094,307,772,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16094,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16094,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16094,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16094,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16094,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16094,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16094,606,7.894,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16095,203,25.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16095,204,48.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16095,205,16.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16095,207,2.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16095,208,563,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16095,255,6.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16095,269,3.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16095,291,8.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16095,301,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16095,303,2.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16095,306,690,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16095,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16095,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (16095,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16095,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16095,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16095,601,0,'100g',4,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16095,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16095,606,6.434,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16096,203,25.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16096,204,48.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16096,205,19.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16096,207,3.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16096,208,578,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16096,255,2.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16096,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16096,291,8.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16096,301,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16096,303,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16096,306,652,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16096,307,433,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16096,320,0,'100g',1,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (16096,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16096,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16096,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16096,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16096,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16096,606,6.345,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16097,203,24.06,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16097,204,49.94,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16097,205,21.57,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16097,207,3.29,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16097,208,589,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16097,255,1.14,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16097,269,8.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16097,291,8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16097,301,45,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16097,303,1.9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16097,306,745,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16097,307,486,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16097,320,0,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (16097,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16097,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16097,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16097,601,0,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16097,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16097,606,7.607,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16098,203,22.21,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16098,204,51.36,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16098,205,22.31,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16098,207,2.89,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16098,208,598,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16098,255,1.23,'100g',7,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16098,269,10.49,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16098,291,5,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16098,301,49,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16098,303,1.74,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16098,306,558,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16098,307,426,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16098,320,0,'100g',1,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (16098,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16098,401,0,'100g',4,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16098,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16098,601,0,'100g',4,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16098,605,0.075,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16098,606,10.325,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16099,203,52.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16099,204,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16099,205,34.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16099,207,4.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16099,208,327,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16099,255,7.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16099,269,8.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16099,291,15.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16099,301,140,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16099,303,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16099,306,1290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16099,307,180,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16099,320,0,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (16099,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16099,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16099,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16099,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16099,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16099,606,0.063,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16100,203,33.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16100,204,21.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16100,205,31.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16100,207,5.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16100,208,428,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16100,255,7.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16100,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16100,291,15.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16100,301,130,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16100,303,4.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16100,306,1358,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16100,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16100,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (16100,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16100,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16100,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16100,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16100,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16100,606,3.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16101,203,21.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16101,204,1.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16101,205,62.78,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16101,207,3.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16101,208,343,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16101,255,10.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16101,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16101,291,15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16101,301,130,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16101,303,5.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16101,306,1392,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16101,307,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16101,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16101,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16101,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16101,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16101,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16101,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16101,606,0.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16102,203,6.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16102,204,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16102,205,23.25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16102,207,1.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16102,208,121,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16102,255,68.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16102,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16102,291,6.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16102,301,43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16102,303,1.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16102,306,384,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16102,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16102,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16102,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16102,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16102,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16102,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16102,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16102,606,0.083,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16103,203,4.98,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16103,204,2.01,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16103,205,13.55,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16103,207,1.71,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16103,208,90,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16103,255,77.75,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16103,269,0.54,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16103,291,3.7,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16103,301,29,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16103,303,1.44,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16103,306,319,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16103,307,370,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16103,320,0,'100g',2,1,'2024-12-12','2014-01-08');
INSERT INTO `cndb_nutval` VALUES (16103,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16103,401,6,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16103,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16103,601,0,'100g',4,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16103,605,0.016,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16103,606,0.631,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16104,203,11.69,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16104,204,29.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16104,205,5.31,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16104,207,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16104,208,309,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16104,255,48.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16104,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16104,291,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16104,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16104,303,2.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16104,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16104,307,1465,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16104,320,4,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16104,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16104,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16104,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16104,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16104,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16104,606,4.622,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16106,203,41.71,'100g',1,1,'1994-11-14','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16106,204,2.97,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16106,205,34.71,'100g',3,1,'1994-11-14','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16106,207,13.13,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16106,208,311,'100g',3,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16106,255,7.48,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16106,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16106,291,17.5,'100g',3,1,'1994-12-07','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16106,301,204,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16106,303,11.99,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16106,306,1902,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16106,307,10,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16106,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16106,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16106,401,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16106,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16106,601,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16106,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16106,606,0.424,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16107,203,20.28,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16107,204,18.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16107,205,8.09,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16107,207,3.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16107,208,255,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16107,255,50.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16107,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16107,291,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16107,301,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16107,303,3.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16107,306,231,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16107,307,888,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16107,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16107,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16107,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16107,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16107,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16107,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16107,606,2.926,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16108,203,36.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16108,204,19.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16108,205,30.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16108,207,4.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16108,208,446,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16108,255,8.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16108,269,7.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16108,291,9.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16108,301,277,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16108,303,15.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16108,306,1797,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16108,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16108,320,1,'100g',2,1,'2024-12-12','2007-01-09');
INSERT INTO `cndb_nutval` VALUES (16108,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16108,401,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16108,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16108,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16108,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16108,606,2.884,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16109,203,18.21,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16109,204,8.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16109,205,8.36,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16109,207,1.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16109,208,172,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16109,255,62.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16109,269,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16109,291,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16109,301,102,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16109,303,5.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16109,306,515,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16109,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16109,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16109,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16109,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16109,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16109,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16109,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16109,606,1.297,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16110,203,38.55,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16110,204,25.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16110,205,30.22,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16110,207,3.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16110,208,469,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16110,255,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16110,269,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16110,291,17.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16110,301,138,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16110,303,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16110,306,1470,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16110,307,163,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16110,320,10,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16110,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16110,401,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16110,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16110,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16110,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16110,606,3.674,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16111,203,43.32,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16111,204,21.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16111,205,28.98,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16111,207,5.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16111,208,449,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16111,255,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16111,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16111,291,8.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16111,301,140,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16111,303,3.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16111,306,1364,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16111,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16111,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (16111,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16111,401,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16111,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16111,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16111,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16111,606,3.127,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16112,203,12.79,'100g',7,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16112,204,6.01,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16112,205,25.37,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16112,207,12.81,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16112,208,198,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16112,255,43.02,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16112,269,6.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16112,291,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16112,301,57,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16112,303,2.49,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16112,306,210,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16112,307,3728,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16112,320,4,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16112,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16112,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16112,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16112,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16112,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16112,606,1.025,'100g',7,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16113,203,19.4,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16113,204,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16113,205,12.68,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16113,207,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16113,208,211,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16113,255,55.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16113,269,4.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16113,291,5.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16113,301,217,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16113,303,8.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16113,306,729,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16113,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16113,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16113,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16113,401,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16113,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16113,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16113,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16113,606,1.591,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16114,203,20.29,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16114,204,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16114,205,7.64,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16114,207,1.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16114,208,192,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16114,255,59.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16114,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16114,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16114,301,111,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16114,303,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16114,306,412,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16114,307,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16114,320,0,'100g',1,1,'2024-12-12','2003-01-12');
INSERT INTO `cndb_nutval` VALUES (16114,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16114,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16114,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16114,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16114,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16114,606,2.539,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16115,203,37.81,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16115,204,20.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16115,205,31.92,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16115,207,4.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16115,208,434,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16115,255,5.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16115,269,7.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16115,291,9.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16115,301,206,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16115,303,6.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16115,306,2515,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16115,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16115,320,6,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16115,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16115,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16115,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16115,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16115,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16115,606,2.987,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16116,203,38.09,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16116,204,21.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16116,205,30.38,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16116,207,5.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16116,208,439,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16116,255,3.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16116,269,7.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16116,291,9.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16116,301,188,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16116,303,5.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16116,306,2041,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16116,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16116,320,6,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (16116,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16116,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16116,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16116,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16116,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16116,606,3.162,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16117,203,51.46,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16117,204,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16117,205,33.92,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16117,207,6.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16117,208,327,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16117,255,7.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16117,269,16.42,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16117,291,17.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16117,301,241,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16117,303,9.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16117,306,2384,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16117,307,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16117,320,2,'100g',2,1,'2024-12-12','2008-01-01');
INSERT INTO `cndb_nutval` VALUES (16117,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16117,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16117,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16117,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16117,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16117,606,0.136,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16118,203,49.81,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16118,204,8.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16118,205,30.63,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16118,207,6.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16118,208,372,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16118,255,4.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16118,269,9.33,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16118,291,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16118,301,285,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16118,303,8.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16118,306,2090,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16118,307,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16118,320,2,'100g',2,1,'2024-12-12','2008-01-01');
INSERT INTO `cndb_nutval` VALUES (16118,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16118,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16118,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16118,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16118,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16118,606,1.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16119,203,49.2,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16119,204,2.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16119,205,35.89,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16119,207,5.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16119,208,337,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16119,255,6.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16119,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16119,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16119,301,244,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16119,303,13.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16119,306,2490,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16119,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16119,320,2,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16119,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16119,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16119,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16119,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16119,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16119,606,0.268,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16120,203,3.27,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16120,204,1.75,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16120,205,6.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16120,207,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16120,208,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16120,255,88.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16120,269,3.99,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16120,291,0.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16120,301,25,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16120,303,0.64,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16120,306,118,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16120,307,51,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16120,320,0,'100g',2,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (16120,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16120,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16120,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16120,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16120,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16120,606,0.205,'100g',7,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16121,203,63.63,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16121,204,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16121,205,25.41,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16121,207,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16121,208,328,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16121,255,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16121,269,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16121,291,5.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16121,301,363,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16121,303,10.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16121,306,2202,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16121,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16121,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (16121,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16121,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16121,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16121,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16121,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16121,606,0.052,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16122,203,88.32,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16122,204,3.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16122,205,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16122,207,3.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16122,208,335,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16122,255,4.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16122,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16122,291,0,'100g',4,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16122,301,178,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16122,303,14.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16122,306,81,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16122,307,1005,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16122,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16122,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16122,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16122,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16122,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16122,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16122,606,0.422,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16123,203,8.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16123,204,0.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16123,205,4.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16123,207,15.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16123,208,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16123,255,71.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16123,269,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16123,291,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16123,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16123,303,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16123,306,435,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16123,307,5493,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16123,320,0,'100g',1,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (16123,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16123,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16123,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16123,601,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16123,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16123,606,0.073,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16124,203,10.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16124,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16124,205,5.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16124,207,17.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16124,208,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16124,255,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16124,269,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16124,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16124,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16124,303,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16124,306,212,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16124,307,5586,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16124,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16124,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16124,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16124,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16124,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16124,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16124,606,0.011,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16125,203,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16125,204,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16125,205,7.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16125,207,16.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16125,208,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16125,255,68.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16125,269,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16125,291,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16125,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16125,303,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16125,306,447,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16125,307,6820,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16125,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16125,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16125,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16125,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16125,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16125,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16125,606,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16126,203,9.04,'100g',1,1,'1996-09-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16126,204,4.17,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16126,205,2.85,'100g',3,1,'1996-09-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16126,207,1.01,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16126,208,78,'100g',3,1,'1996-09-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16126,255,82.93,'100g',7,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16126,269,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16126,291,0.9,'100g',7,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16126,301,201,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16126,303,1.61,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16126,306,148,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16126,307,12,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16126,320,0,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (16126,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16126,401,0.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16126,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16126,601,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16126,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16126,606,0.793,'100g',7,1,'1996-09-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16127,203,7.17,'100g',1,1,'1994-11-14','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16127,204,3.69,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16127,205,1.18,'100g',3,1,'1994-11-14','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16127,207,0.7,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16127,208,61,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16127,255,87.26,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16127,269,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16127,291,0.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16127,301,111,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16127,303,1.11,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16127,306,120,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16127,307,8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16127,320,0,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (16127,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16127,401,0.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16127,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16127,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16127,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16127,606,0.533,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16128,203,52.47,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16128,204,30.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16128,205,10.03,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16128,207,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16128,208,477,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16128,255,5.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16128,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16128,291,7.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16128,301,364,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16128,303,9.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16128,306,20,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16128,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16128,320,26,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16128,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16128,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16128,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16128,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16128,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16128,606,4.388,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16129,203,18.82,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16129,204,20.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16129,205,8.86,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16129,207,1.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16129,208,270,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16129,255,50.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16129,269,2.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16129,291,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16129,301,372,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16129,303,4.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16129,306,146,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16129,307,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16129,320,1,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16129,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16129,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16129,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16129,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16129,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16129,606,2.918,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16130,203,3.52,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16130,204,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16130,205,12.23,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16130,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16130,208,76,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16130,255,81.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16130,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16130,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16130,301,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16130,303,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16130,306,213,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16130,307,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16130,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16130,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16130,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16130,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16130,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16130,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16130,606,0.193,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16132,203,8.92,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16132,204,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16132,205,4.38,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16132,207,8.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16132,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16132,255,70.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16132,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16132,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16132,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16132,303,1.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16132,306,75,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16132,307,2873,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16132,320,0,'100g',1,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (16132,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16132,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16132,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16132,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16132,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16132,606,1.157,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16133,203,24.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16133,204,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16133,205,61.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16133,207,4.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16133,208,347,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16133,255,8.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16133,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16133,291,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16133,301,138,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16133,303,8.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16133,306,1157,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16133,307,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16133,320,3,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16133,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16133,401,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16133,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16133,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16133,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16133,606,0.339,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16134,203,8.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16134,204,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16134,205,21.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16134,207,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16134,208,118,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16134,255,68.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16134,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16134,291,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16134,301,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16134,303,2.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16134,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16134,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16134,320,0,'100g',1,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (16134,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16134,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16134,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16134,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16134,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16134,606,0.116,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16135,203,29.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16135,204,16.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16135,205,41.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16135,207,3.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16135,208,409,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16135,255,8.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16135,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16135,291,25.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16135,301,440,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16135,303,13.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16135,306,977,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16135,307,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16135,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16135,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16135,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16135,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16135,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16135,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16135,606,2.303,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16136,203,10.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16136,204,5.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16136,205,14.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16136,207,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16136,208,147,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16136,255,67.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16136,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16136,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16136,301,142,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16136,303,4.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16136,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16136,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16136,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16136,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16136,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16136,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16136,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16136,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16136,606,0.825,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16137,203,4.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16137,204,8.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16137,205,20.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16137,207,1.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16137,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16137,255,64.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16137,269,0.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16137,291,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16137,301,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16137,303,1.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16137,306,173,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16137,307,242,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16137,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16137,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16137,401,7.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16137,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16137,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16137,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16137,606,1.141,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16138,203,13.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16138,204,17.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16138,205,31.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16138,207,2.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16138,208,333,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16138,255,34.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16138,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16138,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16138,301,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16138,303,3.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16138,306,585,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16138,307,294,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16138,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16138,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16138,401,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16138,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16138,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16138,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16138,606,2.383,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16139,203,2.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16139,204,1.47,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16139,205,4.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16139,207,0.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16139,208,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16139,255,90.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16139,269,3.65,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16139,291,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16139,301,123,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16139,303,0.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16139,306,122,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16139,307,47,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16139,320,55,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (16139,328,1.1,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16139,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16139,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16139,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16139,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16139,606,0.205,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16144,203,23.91,'100g',1,1,'1997-08-29','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16144,204,2.17,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16144,205,63.1,'100g',3,1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16144,207,3,'100g',1,1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16144,208,358,'100g',3,1,'1997-08-29','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16144,255,7.82,'100g',1,1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16144,269,NULL,'100g',NULL,1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16144,291,10.8,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16144,301,48,'100g',1,1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16144,303,7.39,'100g',1,1,'1997-08-29','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16144,306,668,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16144,307,7,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16144,320,3,'100g',1,1,'2024-12-12','2003-01-07');
INSERT INTO `cndb_nutval` VALUES (16144,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16144,401,1.7,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16144,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16144,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16144,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16144,606,0.379,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16145,203,7.98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16145,204,1.05,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16145,205,21.49,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16145,207,1.36,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16145,208,124,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16145,255,68.11,'100g',7,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16145,269,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16145,291,5.5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16145,301,57,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16145,303,1.5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16145,306,277,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16145,307,231,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16145,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16145,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16145,401,0.2,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16145,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16145,601,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16145,605,0,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16145,606,0.181,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16146,203,6.99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16146,204,0.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16146,205,20.22,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16146,207,1.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16146,208,114,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16146,255,70.6,'100g',7,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16146,269,0.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16146,291,5.5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16146,301,63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16146,303,1.33,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16146,306,274,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16146,307,239,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16146,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16146,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16146,401,0.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16146,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16146,601,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16146,605,0,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16146,606,0.158,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16147,203,15.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16147,204,6.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16147,205,14.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16147,207,2.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16147,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16147,255,61.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16147,269,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16147,291,4.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16147,301,136,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16147,303,2.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16147,306,333,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16147,307,569,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16147,320,1,'100g',2,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (16147,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16147,401,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16147,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16147,601,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16147,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16147,606,1.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16149,203,24.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16149,204,54.89,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16149,205,14.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16149,207,4.15,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16149,208,650,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16149,255,1.93,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16149,269,6.35,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16149,291,7.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16149,301,72,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16149,303,2.84,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16149,306,818,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16149,307,292,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16149,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16149,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16149,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16149,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16149,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16149,605,0.16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16149,606,10.22,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16150,203,25.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16150,204,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16150,205,35.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16150,207,3.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16150,208,520,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16150,255,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16150,269,9.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16150,291,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16150,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16150,303,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16150,306,669,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16150,307,540,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16150,320,0,'100g',2,1,'2024-12-12','2010-01-02');
INSERT INTO `cndb_nutval` VALUES (16150,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16150,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16150,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16150,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16150,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16150,606,5.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16155,203,25.72,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16155,204,50.81,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16155,205,18.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16155,207,3.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16155,208,591,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16155,255,1.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16155,269,10.47,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16155,291,5.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16155,301,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16155,303,16.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16155,306,667,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16155,307,420,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16155,320,1172,'100g',2,1,'2024-12-12','2010-01-02');
INSERT INTO `cndb_nutval` VALUES (16155,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16155,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16155,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16155,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16155,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16155,606,10.125,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16156,203,26.06,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16156,204,51.47,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16156,205,17.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16156,207,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16156,208,593,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16156,255,1.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16156,269,10.94,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16156,291,5.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16156,301,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16156,303,17.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16156,306,744,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16156,307,366,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16156,320,1172,'100g',2,1,'2024-12-12','2010-01-02');
INSERT INTO `cndb_nutval` VALUES (16156,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16156,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16156,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16156,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16156,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16156,606,7.972,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16157,203,22.39,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16157,204,6.69,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16157,205,57.82,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16157,207,2.82,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16157,208,387,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16157,255,10.28,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16157,269,10.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16157,291,10.8,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16157,301,45,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16157,303,4.86,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16157,306,846,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16157,307,64,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16157,320,2,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (16157,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16157,401,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16157,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16157,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16157,605,0,'100g',NULL,1,'1997-08-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16157,606,0.693,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16158,203,7.78,'100g',1,1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16158,204,17.82,'100g',1,1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16158,205,15,'100g',3,1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16158,207,2,'100g',1,1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16158,208,237,'100g',3,1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16158,255,57.4,'100g',1,1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16158,269,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16158,291,5.5,'100g',1,1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16158,301,47,'100g',1,1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16158,303,2.54,'100g',1,1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16158,306,312,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16158,307,426,'100g',1,1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16158,320,1,'100g',1,1,'2024-12-12','2016-01-12');
INSERT INTO `cndb_nutval` VALUES (16158,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16158,401,0,'100g',1,1,'1997-08-29','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16158,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16158,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16158,605,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16158,606,2.562,'100g',3,1,'2004-07-15','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16159,203,9.98,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16159,204,5.26,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16159,205,1.18,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16159,207,1.28,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16159,208,83,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16159,255,82.31,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16159,269,0.71,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16159,291,1,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16159,301,282,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16159,303,2.04,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16159,306,130,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16159,307,4,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16159,320,0,'100g',1,1,'2024-12-12','2003-01-12');
INSERT INTO `cndb_nutval` VALUES (16159,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16159,401,0,'100g',4,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16159,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16159,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16159,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16159,606,0.919,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16160,203,12.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16160,204,9.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16160,205,4.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16160,207,1.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16160,208,145,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16160,255,71.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16160,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16160,291,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16160,301,345,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16160,303,2.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16160,306,146,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16160,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16160,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16160,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16160,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16160,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16160,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16160,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16160,606,1.445,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16166,203,2.26,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16166,204,1.53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16166,205,9.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16166,207,0.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16166,208,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16166,255,85.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16166,269,7.86,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16166,291,0.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16166,301,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16166,303,0.48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16166,306,143,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16166,307,53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16166,320,0,'100g',2,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (16166,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16166,401,1.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16166,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16166,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16166,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16166,606,0.24,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16167,203,21.93,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16167,204,49.54,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16167,205,23.98,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16167,207,3,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16167,208,588,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16167,255,1.55,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16167,269,6.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16167,291,5.7,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16167,301,54,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16167,303,2.16,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16167,306,592,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16167,307,476,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16167,320,0,'100g',2,1,'2024-12-12','2009-01-11');
INSERT INTO `cndb_nutval` VALUES (16167,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16167,401,0,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16167,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16167,601,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16167,605,0,'100g',NULL,1,'2004-07-15','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16167,606,9.519,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16168,203,2.26,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16168,204,1.53,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16168,205,9.95,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16168,207,0.65,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16168,208,63,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16168,255,85.61,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16168,269,7.86,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16168,291,0.4,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16168,301,126,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16168,303,0.48,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16168,306,143,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16168,307,53,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16168,320,70,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (16168,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16168,401,1.7,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16168,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16168,601,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16168,605,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16168,606,0.24,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16171,203,5.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16171,204,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16171,205,13.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16171,207,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16171,208,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16171,255,78.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16171,269,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16171,291,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16171,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16171,303,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16171,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16171,307,430,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16171,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16171,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16171,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16171,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16171,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16171,605,0.003,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16171,606,0.142,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16172,203,5.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16172,204,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16172,205,13.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16172,207,2.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16172,208,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16172,255,78.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16172,269,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16172,291,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16172,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16172,303,1.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16172,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16172,307,350,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (16172,320,0,'100g',2,1,'2024-12-12','2009-01-08');
INSERT INTO `cndb_nutval` VALUES (16172,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16172,401,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16172,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16172,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16172,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16172,606,0.093,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16173,203,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16173,204,6.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16173,205,15.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16173,207,1.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16173,208,144,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16173,255,70.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16173,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16173,291,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16173,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16173,303,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16173,306,310,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16173,307,375,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16173,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16173,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16173,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16173,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16173,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16173,605,0.171,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16173,606,0.926,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16174,203,19.91,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16174,204,11.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16174,205,7.62,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16174,207,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16174,208,195,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16174,255,59.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16174,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16174,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16174,301,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16174,303,2.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16174,306,401,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16174,307,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16174,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16174,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16174,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16174,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16174,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16174,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16174,606,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16222,203,2.86,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16222,204,1.61,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16222,205,1.74,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16222,207,0.64,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16222,208,33,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16222,255,93.14,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16222,269,0.41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16222,291,0.5,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16222,301,124,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16222,303,0.46,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16222,306,120,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16222,307,37,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16222,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16222,328,1.2,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16222,401,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16222,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16222,601,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16222,605,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16222,606,0.206,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16223,203,2.94,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16223,204,1.99,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16223,205,3.45,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16223,207,0.64,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16223,208,45,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16223,255,90.98,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16223,269,2.53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16223,291,0.4,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16223,301,140,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16223,303,0.49,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16223,306,141,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16223,307,50,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16223,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16223,328,1.2,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16223,401,7.2,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16223,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16223,601,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16223,605,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16223,606,0.206,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16225,203,2.38,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16225,204,0.77,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16225,205,3.51,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16225,207,0.64,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16225,208,30,'100g',6,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16225,255,92.69,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16225,269,2.61,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16225,291,0.3,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16225,301,123,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16225,303,0.43,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16225,306,117,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16225,307,48,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16225,320,61,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (16225,328,1.2,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16225,401,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16225,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16225,601,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16225,605,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16225,606,0.005,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16227,203,2.1,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16227,204,0.64,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16227,205,8.24,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16227,207,0.64,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16227,208,47,'100g',6,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16227,255,88.38,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16227,269,7.13,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16227,291,0.7,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16227,301,123,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16227,303,0.59,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16227,306,144,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16227,307,46,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16227,320,61,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (16227,328,1.2,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16227,401,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16227,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16227,601,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16227,605,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16227,606,0.032,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16228,203,2.62,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16228,204,0.85,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16228,205,3.85,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16228,207,0.64,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16228,208,34,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16228,255,92.03,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16228,269,0.41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16228,291,0.6,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16228,301,123,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16228,303,0.46,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16228,306,117,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16228,307,63,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16228,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16228,328,1,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16228,401,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16228,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16228,601,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16228,605,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16228,606,0.078,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16229,203,1.65,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16229,204,0.62,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16229,205,7.2,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16229,207,0.64,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16229,208,43,'100g',6,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16229,255,89.89,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16229,269,3.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16229,291,0.8,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16229,301,82,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16229,303,0.44,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16229,306,64,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16229,307,37,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16229,320,62,'100g',1,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (16229,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16229,401,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16229,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16229,601,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16229,605,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16229,606,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16230,203,2.47,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16230,204,0.04,'100g',3,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16230,205,4.14,'100g',6,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16230,207,0.64,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16230,208,28,'100g',6,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16230,255,92.67,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16230,269,3.65,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16230,291,0.2,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16230,301,116,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16230,303,0.35,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16230,306,105,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16230,307,57,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16230,320,61,'100g',2,1,'2024-12-12','2008-01-10');
INSERT INTO `cndb_nutval` VALUES (16230,328,1,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16230,401,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16230,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16230,601,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16230,605,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16230,606,0,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (16231,203,2.47,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16231,204,0.04,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16231,205,8.51,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16231,207,0.64,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16231,208,44,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16231,255,88.38,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16231,269,3.65,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16231,291,0.2,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16231,301,116,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16231,303,0.35,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16231,306,105,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16231,307,57,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16231,320,61,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (16231,328,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16231,401,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16231,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16231,601,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16231,605,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16231,606,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16302,203,7.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16302,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16302,205,24.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16302,207,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16302,208,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16302,255,66.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16302,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16302,291,7.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16302,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16302,303,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16302,306,532,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16302,307,244,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16302,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16302,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16302,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16302,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16302,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16302,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16302,606,0.036,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16315,203,8.86,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16315,204,0.54,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16315,205,23.71,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16315,207,1.15,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16315,208,132,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16315,255,65.74,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16315,269,0.32,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16315,291,8.7,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16315,301,27,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16315,303,2.1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16315,306,355,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16315,307,237,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16315,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16315,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16315,401,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16315,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16315,601,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16315,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16315,606,0.139,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16316,203,6.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16316,204,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16316,205,16.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16316,207,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16316,208,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16316,255,75.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16316,269,0.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16316,291,6.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16316,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16316,303,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16316,306,308,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16316,307,138,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16316,320,0,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (16316,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16316,401,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16316,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16316,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16316,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16316,606,0.075,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16317,203,8.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16317,204,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16317,205,24.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16317,207,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16317,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16317,255,65.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16317,269,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16317,291,8.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16317,301,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16317,303,2.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16317,306,433,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16317,307,239,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16317,320,0,'100g',1,1,'2024-12-12','2011-01-01');
INSERT INTO `cndb_nutval` VALUES (16317,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16317,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16317,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16317,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16317,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16317,606,0.089,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16320,203,9.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16320,204,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16320,205,24.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16320,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16320,208,136,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16320,255,64.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16320,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16320,291,8.6,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16320,301,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16320,303,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16320,306,387,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16320,307,237,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16320,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16320,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16320,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16320,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16320,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16320,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16320,606,0.119,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16323,203,7.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16323,204,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16323,205,24.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16323,207,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16323,208,129,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16323,255,66.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16323,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16323,291,9.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16323,301,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16323,303,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16323,306,370,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16323,307,242,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16323,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16323,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16323,401,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16323,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16323,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16323,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16323,606,0.083,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16325,203,8.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16325,204,0.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16325,205,21.09,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16325,207,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16325,208,118,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16325,255,69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16325,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16325,291,7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16325,301,68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16325,303,2.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16325,306,391,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16325,307,238,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16325,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16325,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16325,401,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16325,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16325,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16325,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16325,606,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16326,203,7.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16326,204,0.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16326,205,21.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16326,207,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16326,208,114,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16326,255,69.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16326,269,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16326,291,4.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16326,301,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16326,303,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16326,306,351,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16326,307,177,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16326,320,0,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (16326,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16326,401,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16326,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16326,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16326,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16326,606,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16328,203,8.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16328,204,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16328,205,22.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16328,207,1.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16328,208,127,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16328,255,66.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16328,269,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16328,291,6.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16328,301,28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16328,303,2.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16328,306,403,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16328,307,238,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16328,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (16328,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16328,401,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16328,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16328,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16328,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16328,606,0.072,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16331,203,9.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16331,204,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16331,205,22.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16331,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16331,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16331,255,66.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16331,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16331,291,9.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16331,301,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16331,303,2.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16331,306,419,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16331,307,240,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16331,320,0,'100g',1,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (16331,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16331,401,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16331,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16331,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16331,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16331,606,0.014,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16333,203,8.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16333,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16333,205,22.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16333,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16333,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16333,255,66.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16333,269,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16333,291,7.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16333,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16333,303,2.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16333,306,403,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16333,307,238,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16333,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16333,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16333,401,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16333,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16333,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16333,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16333,606,0.072,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16335,203,8.12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16335,204,0.93,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16335,205,20.8,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16335,207,1.29,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16335,208,121,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16335,255,68.86,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16335,269,NULL,'100g',NULL,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16335,291,6,'100g',3,1,'2012-03-02','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16335,301,58,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16335,303,1.5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16335,306,250,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16335,307,208,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16335,320,0,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (16335,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16335,401,0.2,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16335,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16335,601,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16335,605,0,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16335,606,0.328,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16336,203,9.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16336,204,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16336,205,21.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16336,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16336,208,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16336,255,66.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16336,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16336,291,9.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16336,301,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16336,303,2.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16336,306,378,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16336,307,241,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16336,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16336,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16336,401,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16336,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16336,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16336,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16336,606,0.024,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16337,203,5.22,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16337,204,0.36,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16337,205,14.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16337,207,1.64,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16337,208,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16337,255,77.96,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16337,269,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16337,291,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16337,301,29,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16337,303,1.25,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16337,306,260,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16337,307,117,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16337,320,0,'100g',1,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (16337,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16337,401,0.8,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16337,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16337,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16337,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16337,606,0.125,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16338,203,8.23,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16338,204,0.62,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16338,205,26.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16338,207,1.3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16338,208,140,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16338,255,63.81,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16338,269,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16338,291,10.5,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16338,301,69,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16338,303,2.36,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16338,306,389,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16338,307,237,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16338,320,0,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (16338,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16338,401,0.9,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16338,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16338,601,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16338,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16338,606,0.032,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16341,203,9.06,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16341,204,0.49,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16341,205,27.91,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16341,207,1.34,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16341,208,149,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16341,255,61.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16341,269,0.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16341,291,5.3,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16341,301,52,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16341,303,2.3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16341,306,508,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16341,307,238,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16341,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16341,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16341,401,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16341,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16341,601,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16341,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16341,606,0.126,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16343,203,9.01,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16343,204,0.65,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16343,205,26.22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16343,207,1.17,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16343,208,143,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16343,255,62.95,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16343,269,0.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16343,291,9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16343,301,46,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16343,303,2.09,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16343,306,436,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16343,307,238,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16343,320,0,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (16343,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16343,401,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16343,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16343,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16343,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16343,606,0.109,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16346,203,8.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16346,204,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16346,205,25.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16346,207,1.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16346,208,142,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16346,255,63.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16346,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16346,291,10.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16346,301,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16346,303,2.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16346,306,463,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16346,307,238,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16346,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16346,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16346,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16346,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16346,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16346,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16346,606,0.166,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16347,203,4.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16347,204,0.56,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16347,205,15.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16347,207,1.48,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16347,208,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16347,255,78.19,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16347,269,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16347,291,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16347,301,47,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16347,303,1.47,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16347,306,276,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16347,307,146,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16347,320,0,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (16347,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16347,401,0.7,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16347,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16347,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16347,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16347,606,0.116,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16348,203,9.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16348,204,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16348,205,25.28,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16348,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16348,208,144,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16348,255,62.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16348,269,0.34,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16348,291,10.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16348,301,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16348,303,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16348,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16348,307,241,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16348,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16348,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16348,401,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16348,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16348,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16348,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16348,606,0.279,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16350,203,9.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16350,204,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16350,205,25.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16350,207,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16350,208,139,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16350,255,63.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16350,269,0.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16350,291,6.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16350,301,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16350,303,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16350,306,561,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16350,307,242,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16350,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16350,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16350,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16350,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16350,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16350,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16350,606,0.091,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16353,203,7.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16353,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16353,205,19.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16353,207,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16353,208,110,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16353,255,71.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16353,269,1.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16353,291,5.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16353,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16353,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16353,306,268,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16353,307,241,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16353,320,1,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16353,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16353,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16353,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16353,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16353,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16353,606,0.066,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16357,203,8.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16357,204,2.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16357,205,27.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16357,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16357,208,164,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16357,255,60.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16357,269,4.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16357,291,7.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16357,301,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16357,303,2.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16357,306,291,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16357,307,243,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16357,320,1,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16357,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16357,401,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16357,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16357,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16357,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16357,606,0.269,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16358,203,7.05,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16358,204,2.77,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16358,205,22.53,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16358,207,0.91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16358,208,139,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16358,255,66.72,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16358,269,4.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16358,291,6.4,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16358,301,45,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16358,303,1.07,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16358,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16358,307,246,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16358,320,1,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (16358,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16358,401,0.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16358,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16358,601,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16358,605,0,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16358,606,0.214,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16359,203,7.04,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16359,204,2.47,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16359,205,22.87,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16359,207,0.74,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16359,208,138,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16359,255,66.87,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16359,269,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16359,291,6.3,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16359,301,43,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16359,303,0.98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16359,306,109,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16359,307,212,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16359,320,1,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (16359,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16359,401,0.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16359,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16359,601,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16359,605,0,'100g',NULL,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16359,606,0.213,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (16360,203,4.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16360,204,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16360,205,13.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16360,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16360,208,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16360,255,78.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16360,269,2.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16360,291,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16360,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16360,303,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16360,306,144,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16360,307,132,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16360,320,1,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (16360,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16360,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16360,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16360,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16360,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16360,606,0.204,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16361,203,8.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16361,204,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16361,205,20.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16361,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16361,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16361,255,69.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16361,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16361,291,3.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16361,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16361,303,3.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16361,306,375,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16361,307,255,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16361,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16361,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16361,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16361,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16361,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16361,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16361,606,0.185,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16363,203,7.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16363,204,0.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16363,205,20.76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16363,207,0.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16363,208,116,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16363,255,70.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16363,269,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16363,291,6.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16363,301,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16363,303,2.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16363,306,278,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16363,307,240,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16363,320,1,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16363,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16363,401,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16363,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16363,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16363,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16363,606,0.138,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16368,203,8.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16368,204,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16368,205,20.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16368,207,1.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16368,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16368,255,69.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16368,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16368,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16368,301,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16368,303,4.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16368,306,337,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16368,307,243,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16368,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16368,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16368,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16368,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16368,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16368,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16368,606,0.099,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16370,203,9.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16370,204,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16370,205,19.54,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16370,207,1.42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16370,208,114,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16370,255,69.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16370,269,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16370,291,7.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16370,301,19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16370,303,3.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16370,306,369,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16370,307,238,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16370,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16370,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16370,401,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16370,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16370,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16370,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16370,606,0.053,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16372,203,7.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16372,204,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16372,205,20.88,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16372,207,1.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16372,208,115,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16372,255,69.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16372,269,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16372,291,7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16372,301,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16372,303,2.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16372,306,508,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16372,307,238,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16372,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16372,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16372,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16372,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16372,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16372,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16372,606,0.089,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16375,203,8.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16375,204,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16375,205,23.31,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16375,207,1.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16375,208,126,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16375,255,67.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16375,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16375,291,7.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16375,301,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16375,303,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16375,306,401,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16375,307,239,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16375,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16375,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16375,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16375,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16375,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16375,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16375,606,0.088,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16377,203,15.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16377,204,2.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16377,205,9.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16377,207,1.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16377,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16377,255,71.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16377,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16377,291,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16377,301,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16377,303,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16377,306,245,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16377,307,240,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16377,320,0,'100g',1,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (16377,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16377,401,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16377,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16377,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16377,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16377,606,0.346,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16379,203,7.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16379,204,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16379,205,20.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16379,207,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16379,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16379,255,69.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16379,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16379,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16379,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16379,303,3.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16379,306,304,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16379,307,246,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16379,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16379,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16379,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16379,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16379,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16379,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16379,606,0.124,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16381,203,7.02,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16381,204,0.38,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16381,205,19.15,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16381,207,0.79,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16381,208,105,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16381,255,72.66,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16381,269,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16381,291,7.6,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16381,301,27,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16381,303,1.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16381,306,266,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16381,307,238,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16381,320,1,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16381,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16381,401,1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16381,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16381,601,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16381,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16381,606,0.116,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16384,203,7.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16384,204,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16384,205,18.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16384,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16384,208,105,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16384,255,72.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16384,269,2.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16384,291,6.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16384,301,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16384,303,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16384,306,231,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16384,307,243,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16384,320,2,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16384,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16384,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16384,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16384,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16384,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16384,606,0.038,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16386,203,8.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16386,204,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16386,205,20.51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16386,207,1.27,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16386,208,116,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16386,255,69.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16386,269,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16386,291,8.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16386,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16386,303,1.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16386,306,362,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16386,307,238,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16386,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (16386,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16386,401,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16386,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16386,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16386,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16386,606,0.054,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16389,203,28.03,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16389,204,52.5,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16389,205,15.26,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16389,207,2.75,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16389,208,599,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16389,255,1.45,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16389,269,4.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16389,291,9.4,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16389,301,61,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16389,303,1.52,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16389,306,726,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16389,307,6,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16389,320,0,'100g',1,1,'2024-12-12','2011-01-10');
INSERT INTO `cndb_nutval` VALUES (16389,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16389,401,0.8,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16389,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16389,601,0,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16389,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (16389,606,8.686,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16390,203,24.35,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16390,204,49.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16390,205,21.26,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16390,207,2.92,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16390,208,587,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16390,255,1.81,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16390,269,4.9,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16390,291,8.4,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16390,301,58,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16390,303,1.58,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16390,306,634,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16390,307,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16390,320,0,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (16390,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16390,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16390,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16390,601,0,'100g',4,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16390,605,0.027,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16390,606,7.723,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16392,203,28.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16392,204,49.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16392,205,17.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16392,207,3.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16392,208,579,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16392,255,1.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16392,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16392,291,8.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16392,301,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16392,303,2.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16392,306,776,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16392,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16392,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16392,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16392,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16392,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16392,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16392,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16392,606,7.555,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16394,203,27.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16394,204,51.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16394,205,16.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16394,207,3.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16394,208,589,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16394,255,2.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16394,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16394,291,8.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16394,301,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16394,303,1.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16394,306,612,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16394,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16394,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16394,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16394,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16394,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16394,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16394,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16394,606,7.894,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16396,203,25.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16396,204,48.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16396,205,19.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16396,207,3.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16396,208,578,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16396,255,2.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16396,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16396,291,8.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16396,301,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16396,303,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16396,306,652,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16396,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16396,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16396,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16396,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16396,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16396,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16396,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16396,606,6.345,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16397,203,24.06,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16397,204,49.94,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16397,205,21.57,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16397,207,3.29,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16397,208,589,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16397,255,1.14,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16397,269,8.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16397,291,8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16397,301,45,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16397,303,1.9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16397,306,745,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16397,307,17,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (16397,320,0,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (16397,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16397,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16397,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16397,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16397,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16397,606,7.607,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16398,203,22.21,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16398,204,51.36,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16398,205,22.31,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16398,207,2.89,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16398,208,598,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16398,255,1.23,'100g',7,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16398,269,10.49,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16398,291,5,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16398,301,49,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16398,303,1.74,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16398,306,558,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16398,307,17,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16398,320,0,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (16398,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16398,401,0,'100g',4,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16398,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16398,601,0,'100g',4,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16398,605,0.075,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16398,606,10.325,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16399,203,24.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16399,204,54.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16399,205,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16399,207,3.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16399,208,608,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16399,255,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16399,269,3.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16399,291,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16399,301,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16399,303,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16399,306,780,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16399,307,356,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16399,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16399,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16399,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16399,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16399,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16399,605,0.037,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16399,606,9.691,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16402,203,6.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16402,204,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16402,205,23.25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16402,207,1.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16402,208,121,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16402,255,68.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16402,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16402,291,6.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16402,301,43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16402,303,1.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16402,306,384,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16402,307,241,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16402,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16402,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16402,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16402,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16402,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16402,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16402,606,0.083,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16403,203,4.98,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16403,204,2.01,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16403,205,13.55,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16403,207,1.71,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16403,208,89,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16403,255,77.75,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16403,269,0.54,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16403,291,3.7,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16403,301,29,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16403,303,1.44,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16403,306,319,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16403,307,138,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16403,320,0,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (16403,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16403,401,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16403,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16403,601,0,'100g',4,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16403,605,0.016,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16403,606,0.631,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16409,203,18.21,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16409,204,8.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16409,205,8.36,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16409,207,1.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16409,208,172,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16409,255,62.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16409,269,2.36,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16409,291,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16409,301,102,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16409,303,5.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16409,306,515,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16409,307,237,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16409,320,0,'100g',2,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (16409,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16409,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16409,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16409,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16409,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16409,606,1.297,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16410,203,38.55,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16410,204,25.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16410,205,30.22,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16410,207,3.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16410,208,469,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16410,255,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16410,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16410,291,17.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16410,301,138,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16410,303,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16410,306,1470,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16410,307,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16410,320,0,'100g',1,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (16410,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16410,401,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16410,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16410,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16410,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16410,606,3.674,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16420,203,63.63,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16420,204,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16420,205,25.41,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16420,207,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16420,208,328,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16420,255,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16420,269,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16420,291,5.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16420,301,363,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16420,303,10.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16420,306,450,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16420,307,900,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16420,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (16420,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16420,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16420,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16420,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16420,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16420,606,0.052,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16422,203,88.32,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16422,204,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16422,205,2.59,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16422,207,3.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16422,208,321,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16422,255,4.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16422,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16422,291,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16422,301,178,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16422,303,14.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16422,306,1590,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16422,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16422,320,0,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (16422,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16422,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16422,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16422,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16422,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16422,606,0.077,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16424,203,9.05,'100g',1,1,'1994-11-14','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (16424,204,0.3,'100g',1,1,'1994-11-14','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (16424,205,5.59,'100g',3,1,'1994-11-14','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (16424,207,9.92,'100g',1,1,'1994-11-14','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (16424,208,57,'100g',3,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16424,255,75.14,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16424,269,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16424,291,0.7,'100g',1,1,'1994-11-14','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (16424,301,30,'100g',1,1,'1994-11-14','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (16424,303,1.35,'100g',1,1,'1994-11-14','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (16424,306,352,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16424,307,3598,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16424,320,0,'100g',1,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (16424,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16424,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16424,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16424,601,0,'100g',4,1,'1994-11-14','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (16424,605,0,'100g',NULL,1,'1995-06-29','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16424,606,0.035,'100g',3,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16425,203,8.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16425,204,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16425,205,14.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16425,207,13.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16425,208,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16425,255,63.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16425,269,5.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16425,291,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16425,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16425,303,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16425,306,3098,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16425,307,2890,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16425,320,0,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (16425,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16425,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16425,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (16425,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16425,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16425,606,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16426,203,17.27,'100g',1,1,'1996-09-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16426,204,8.72,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16426,205,2.78,'100g',3,1,'1996-09-30','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16426,207,1.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16426,208,144,'100g',3,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16426,255,69.83,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16426,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (16426,291,2.3,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16426,301,683,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16426,303,2.66,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16426,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16426,307,14,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16426,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16426,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16426,401,0.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16426,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16426,601,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16426,605,0,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16426,606,1.261,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16427,203,8.08,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16427,204,4.78,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16427,205,1.87,'100g',3,1,'1994-11-14','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16427,207,0.72,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16427,208,76,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16427,255,84.55,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16427,269,0.62,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16427,291,0.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16427,301,350,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16427,303,5.36,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16427,306,121,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16427,307,7,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16427,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16427,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16427,401,0.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16427,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16427,601,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16427,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16427,606,0.691,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (16428,203,52.43,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16428,204,30.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16428,205,8.3,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16428,207,3.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16428,208,470,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16428,255,5.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16428,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16428,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16428,301,2134,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16428,303,9.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16428,306,20,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16428,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16428,320,0,'100g',1,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (16428,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16428,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16428,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16428,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16428,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16428,606,4.388,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16429,203,18.82,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16429,204,20.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16429,205,8.86,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (16429,207,1.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16429,208,270,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16429,255,50.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16429,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16429,291,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16429,301,961,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16429,303,4.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16429,306,146,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16429,307,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16429,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (16429,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16429,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16429,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16429,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16429,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16429,606,2.918,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16432,203,8.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16432,204,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16432,205,5.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16432,207,8.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16432,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16432,255,70.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16432,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16432,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16432,301,1229,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16432,303,1.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16432,306,75,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16432,307,2873,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16432,320,0,'100g',3,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (16432,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16432,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16432,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16432,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16432,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16432,606,1.157,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (16434,203,8.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16434,204,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16434,205,21.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16434,207,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16434,208,118,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16434,255,68.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16434,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16434,291,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16434,301,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16434,303,2.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16434,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16434,307,241,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16434,320,1,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16434,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16434,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16434,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16434,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16434,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16434,606,0.116,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (16436,203,10.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16436,204,5.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16436,205,14.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16436,207,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16436,208,147,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16436,255,67.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16436,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16436,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16436,301,142,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16436,303,4.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16436,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16436,307,249,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16436,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (16436,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (16436,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16436,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (16436,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (16436,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (16436,606,0.825,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17000,203,21.7,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17000,204,4.63,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17000,205,1.4,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17000,207,1.01,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17000,208,134,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17000,255,71.26,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17000,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17000,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17000,301,10,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17000,303,1.58,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17000,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17000,307,83,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17000,320,0,'100g',1,1,'2024-12-12','2012-01-05');
INSERT INTO `cndb_nutval` VALUES (17000,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17000,401,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17000,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17000,601,58,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17000,605,0.245,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17000,606,2.053,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17001,203,16.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17001,204,21.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17001,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17001,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17001,208,267,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17001,255,60.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17001,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17001,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17001,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17001,303,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17001,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17001,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17001,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17001,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17001,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17001,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17001,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17001,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17001,606,9.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17002,203,24.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17002,204,20.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17002,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17002,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17002,208,294,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17002,255,53.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17002,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17002,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17002,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17002,303,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17002,306,310,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17002,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17002,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17002,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17002,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17002,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17002,601,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17002,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17002,606,8.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17003,203,20.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17003,204,5.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17003,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17003,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17003,208,134,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17003,255,73.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17003,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17003,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17003,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17003,303,1.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17003,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17003,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17003,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17003,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17003,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17003,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17003,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17003,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17003,606,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17004,203,28.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17004,204,9.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17004,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17004,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17004,208,206,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17004,255,61.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17004,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17004,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17004,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17004,303,2.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17004,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17004,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17004,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17004,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17004,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17004,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17004,601,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17004,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17004,606,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17005,203,6.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17005,204,70.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17005,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17005,207,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17005,208,665,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17005,255,22.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17005,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17005,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17005,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17005,303,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17005,306,82,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17005,307,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17005,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17005,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17005,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17005,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17005,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17005,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17005,606,32.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17006,203,12.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17006,204,59.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17006,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17006,207,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17006,208,586,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17006,255,26.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17006,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17006,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17006,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17006,303,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17006,306,194,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17006,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17006,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17006,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17006,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17006,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17006,601,114,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17006,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17006,606,27.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17007,203,18.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17007,204,13.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17007,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17007,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17007,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17007,255,67.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17007,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17007,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17007,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17007,303,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17007,306,214,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17007,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17007,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17007,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17007,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17007,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17007,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17007,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17007,606,5.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17008,203,28.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17008,204,13.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17008,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17008,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17008,208,243,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17008,255,56.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17008,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17008,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17008,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17008,303,2.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17008,306,257,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17008,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17008,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17008,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17008,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17008,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17008,601,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17008,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17008,606,5.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17009,203,21.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17009,204,3.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17009,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17009,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17009,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17009,255,74.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17009,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17009,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17009,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17009,303,1.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17009,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17009,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17009,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17009,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17009,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17009,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17009,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17009,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17009,606,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17010,203,31.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17010,204,6.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17010,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17010,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17010,208,187,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17010,255,61.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17010,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17010,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17010,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17010,303,2.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17010,306,267,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17010,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17010,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17010,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17010,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17010,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17010,601,104,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17010,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17010,606,2.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17011,203,17.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17011,204,17.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17011,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17011,207,0.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17011,208,230,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17011,255,64.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17011,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (17011,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17011,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17011,303,1.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17011,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17011,307,56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17011,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17011,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17011,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17011,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17011,601,69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17011,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (17011,606,7.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17012,203,25.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17012,204,16.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17012,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17012,207,1.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17012,208,258,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17012,255,57.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17012,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17012,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17012,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17012,303,1.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17012,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17012,307,66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17012,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17012,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17012,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17012,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17012,601,93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17012,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (17012,606,6.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17013,203,20.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17013,204,4.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17013,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17013,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17013,208,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17013,255,74.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17013,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17013,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17013,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17013,303,1.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17013,306,289,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17013,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17013,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17013,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17013,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17013,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17013,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17013,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17013,606,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17014,203,28.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17014,204,7.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17014,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17014,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17014,208,191,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17014,255,63.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17014,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17014,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17014,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17014,303,2.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17014,306,338,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17014,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17014,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17014,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17014,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17014,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17014,601,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17014,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17014,606,2.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17015,203,18.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17015,204,13.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17015,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17015,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17015,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17015,255,67.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17015,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17015,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17015,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17015,303,1.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17015,306,261,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17015,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17015,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17015,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17015,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17015,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17015,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17015,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17015,606,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17016,203,26.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17016,204,12.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17016,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17016,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17016,208,225,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17016,255,60.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17016,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17016,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17016,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17016,303,1.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17016,306,326,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17016,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17016,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17016,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17016,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17016,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17016,601,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17016,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17016,606,5.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17017,203,20.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17017,204,4.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17017,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17017,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17017,208,125,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17017,255,74.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17017,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17017,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17017,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17017,303,1.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17017,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17017,307,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17017,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17017,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17017,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17017,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17017,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17017,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17017,606,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17018,203,28.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17018,204,6.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17018,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17018,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17018,208,180,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17018,255,64.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17018,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17018,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17018,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17018,303,2.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17018,306,342,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17018,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17018,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17018,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17018,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17018,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17018,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17018,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17018,606,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17019,203,16.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17019,204,22.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17019,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17019,207,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17019,208,272,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17019,255,60.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17019,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17019,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17019,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17019,303,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17019,306,231,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17019,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17019,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17019,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17019,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17019,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17019,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17019,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17019,606,9.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17020,203,24.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17020,204,20.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17020,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17020,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17020,208,292,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17020,255,54.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17020,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17020,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17020,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17020,303,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17020,306,301,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17020,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17020,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17020,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17020,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17020,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17020,601,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17020,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17020,606,8.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17021,203,20.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17021,204,5.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17021,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17021,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17021,208,134,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17021,255,73.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17021,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17021,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17021,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17021,303,1.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17021,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17021,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17021,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17021,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17021,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17021,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17021,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17021,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17021,606,1.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17022,203,28.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17022,204,9.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17022,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17022,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17022,208,204,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17022,255,62.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17022,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17022,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17022,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17022,303,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17022,306,333,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17022,307,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17022,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17022,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17022,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17022,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17022,601,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17022,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17022,606,3.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17023,203,16.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17023,204,26.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17023,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17023,207,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17023,208,310,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17023,255,56.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17023,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17023,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17023,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17023,303,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17023,306,214,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17023,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17023,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17023,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17023,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17023,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17023,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17023,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17023,606,11.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17024,203,25.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17024,204,23.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17024,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17024,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17024,208,316,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17024,255,51.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17024,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17024,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17024,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17024,303,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17024,306,327,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17024,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17024,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17024,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17024,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17024,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17024,601,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17024,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17024,606,9.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17025,203,22.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17025,204,23.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17025,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17025,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17025,208,309,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17025,255,52.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17025,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17025,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17025,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17025,303,2.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17025,306,246,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17025,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17025,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17025,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17025,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17025,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17025,601,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17025,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17025,606,10.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17026,203,20.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17026,204,5.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17026,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17026,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17026,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17026,255,72.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17026,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17026,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17026,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17026,303,1.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17026,306,276,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17026,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17026,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17026,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17026,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17026,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17026,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17026,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17026,606,2.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17027,203,29.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17027,204,9.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17027,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17027,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17027,208,216,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17027,255,60.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17027,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17027,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17027,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17027,303,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17027,306,376,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17027,307,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17027,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17027,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17027,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17027,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17027,601,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17027,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17027,606,3.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17028,203,26.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17028,204,9.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17028,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17028,207,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17028,208,202,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17028,255,62.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17028,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17028,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17028,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17028,303,2.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17028,306,267,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17028,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17028,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17028,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17028,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17028,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17028,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17028,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17028,606,3.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17029,203,14.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17029,204,34.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17029,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17029,207,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17029,208,372,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17029,255,50.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17029,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17029,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17029,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17029,303,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17029,306,190,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17029,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17029,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17029,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17029,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17029,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17029,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17029,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17029,606,15.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17030,203,22.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17030,204,29.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17030,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17030,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17030,208,361,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17030,255,47.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17030,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17030,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17030,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17030,303,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17030,306,270,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17030,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17030,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17030,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17030,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17030,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17030,601,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17030,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17030,606,12.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17031,203,21.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17031,204,29.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17031,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17031,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17031,208,359,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17031,255,47.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17031,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17031,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17031,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17031,303,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17031,306,271,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17031,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17031,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17031,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17031,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17031,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17031,601,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17031,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17031,606,12.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17032,203,19.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17032,204,9.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17032,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17032,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17032,208,169,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17032,255,70.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17032,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17032,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17032,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17032,303,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17032,306,265,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17032,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17032,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17032,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17032,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17032,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17032,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17032,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17032,606,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17033,203,27.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17033,204,12.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17033,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17033,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17033,208,235,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17033,255,58.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17033,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17033,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17033,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17033,303,2.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17033,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17033,307,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17033,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17033,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17033,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17033,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17033,601,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17033,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17033,606,4.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17034,203,26.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17034,204,13.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17034,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17034,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17034,208,232,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17034,255,60.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17034,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17034,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17034,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17034,303,1.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17034,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17034,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17034,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17034,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17034,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17034,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17034,601,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17034,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17034,606,4.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17035,203,16.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17035,204,21.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17035,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17035,207,0.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17035,208,264,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17035,255,61.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17035,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17035,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17035,301,16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17035,303,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17035,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17035,307,61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17035,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17035,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17035,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17035,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17035,601,72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17035,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (17035,606,9.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17036,203,28.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17036,204,24.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17036,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17036,207,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17036,208,344,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17036,255,45.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17036,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17036,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17036,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17036,303,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17036,306,248,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17036,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17036,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17036,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17036,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17036,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17036,601,116,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17036,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17036,606,10.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17037,203,24.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17037,204,19.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17037,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17037,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17037,208,278,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17037,255,55.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17037,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17037,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17037,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17037,303,2.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17037,306,301,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17037,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17037,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17037,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17037,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17037,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17037,601,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17037,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17037,606,8.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17038,203,22.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17038,204,19.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17038,205,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17038,207,1.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17038,208,276,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17038,255,56.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17038,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17038,291,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17038,301,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17038,303,1.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17038,306,251,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17038,307,66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17038,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17038,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17038,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17038,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17038,601,92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17038,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (17038,606,8.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17039,203,19.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17039,204,6.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17039,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17039,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17039,208,144,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17039,255,72.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17039,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17039,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17039,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17039,303,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17039,306,274,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17039,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17039,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17039,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17039,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17039,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17039,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17039,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17039,606,2.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17040,203,32.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17040,204,15.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17040,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17040,207,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17040,208,283,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17040,255,49.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17040,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17040,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17040,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17040,303,2.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17040,306,261,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17040,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17040,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17040,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17040,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17040,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17040,601,117,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17040,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17040,606,6.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17041,203,27.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17041,204,10.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17041,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17041,207,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17041,208,210,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17041,255,61.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17041,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17041,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17041,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17041,303,2.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17041,306,324,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17041,307,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17041,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17041,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17041,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17041,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17041,601,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17041,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17041,606,3.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17042,203,24.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17042,204,10.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17042,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17042,207,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17042,208,204,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17042,255,63.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17042,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17042,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17042,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17042,303,2.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17042,306,265,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17042,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17042,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17042,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17042,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17042,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17042,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17042,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17042,606,4.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17043,203,16.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17043,204,20.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17043,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17043,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17043,208,260,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17043,255,61.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17043,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17043,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17043,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17043,303,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17043,306,238,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17043,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17043,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17043,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17043,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17043,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17043,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17043,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17043,606,9.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17044,203,30.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17044,204,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17044,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17044,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17044,208,346,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17044,255,44.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17044,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17044,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17044,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17044,303,2.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17044,306,306,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17044,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17044,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17044,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17044,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17044,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17044,601,120,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17044,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17044,606,9.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17045,203,24.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17045,204,19.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17045,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17045,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17045,208,281,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17045,255,54.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17045,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17045,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17045,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17045,303,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17045,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17045,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17045,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17045,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17045,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17045,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17045,601,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17045,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17045,606,8.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17046,203,22.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17046,204,20.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17046,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17046,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17046,208,279,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17046,255,55.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17046,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17046,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17046,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17046,303,2.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17046,306,259,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17046,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17046,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17046,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17046,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17046,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17046,601,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17046,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17046,606,8.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17047,203,19.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17047,204,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17047,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17047,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17047,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17047,255,74.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17047,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17047,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17047,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17047,303,1.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17047,306,287,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17047,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17047,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17047,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17047,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17047,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17047,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17047,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17047,606,1.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17048,203,35.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17048,204,14.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17048,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17048,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17048,208,279,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17048,255,49.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17048,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17048,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17048,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17048,303,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17048,306,338,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17048,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17048,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17048,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17048,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17048,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17048,601,121,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17048,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17048,606,5.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17049,203,27.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17049,204,9.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17049,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17049,207,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17049,208,200,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17049,255,62.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17049,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17049,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17049,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17049,303,2.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17049,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17049,307,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17049,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17049,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17049,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17049,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17049,601,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17049,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17049,606,3.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17050,203,25.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17050,204,9.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17050,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17050,207,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17050,208,192,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17050,255,64.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17050,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17050,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17050,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17050,303,2.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17050,306,277,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17050,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17050,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17050,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17050,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17050,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17050,601,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17050,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17050,606,3.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17051,203,16.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17051,204,20.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17051,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17051,207,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17051,208,259,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17051,255,61.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17051,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17051,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17051,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17051,303,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17051,306,229,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17051,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17051,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17051,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17051,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17051,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17051,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17051,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17051,606,8.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17052,203,28.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17052,204,24.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17052,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17052,207,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17052,208,345,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17052,255,45.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17052,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17052,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17052,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17052,303,2.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17052,306,243,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17052,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17052,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17052,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17052,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17052,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17052,601,116,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17052,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17052,606,10.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17053,203,23.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17053,204,19.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17053,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17053,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17053,208,278,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17053,255,55.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17053,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17053,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17053,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17053,303,1.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17053,306,336,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17053,307,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17053,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17053,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17053,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17053,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17053,601,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17053,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17053,606,8.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17054,203,22.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17054,204,20.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17054,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17054,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17054,208,281,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17054,255,55.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17054,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17054,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17054,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17054,303,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17054,306,246,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17054,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17054,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17054,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17054,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17054,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17054,601,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17054,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17054,606,8.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17055,203,19.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17055,204,7.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17055,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17055,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17055,208,151,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17055,255,72.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17055,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17055,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17055,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17055,303,1.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17055,306,268,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17055,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17055,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17055,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17055,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17055,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17055,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17055,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17055,606,2.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17056,203,32.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17056,204,16.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17056,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17056,207,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17056,208,288,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17056,255,49.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17056,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17056,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17056,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17056,303,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17056,306,254,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17056,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17056,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17056,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17056,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17056,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17056,601,117,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17056,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17056,606,6.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17057,203,25.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17057,204,11.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17057,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17057,207,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17057,208,211,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17057,255,62.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17057,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17057,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17057,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17057,303,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17057,306,368,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17057,307,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17057,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17057,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17057,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17057,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17057,601,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17057,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17057,606,4.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17058,203,24.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17058,204,11.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17058,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17058,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17058,208,209,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17058,255,62.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17058,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17058,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17058,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17058,303,2.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17058,306,258,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17058,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17058,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17058,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17058,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17058,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17058,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17058,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17058,606,4.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17059,203,20.21,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17059,204,5.28,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17059,205,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17059,207,1.06,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17059,208,134,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17059,255,73.74,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17059,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (17059,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17059,301,9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17059,303,1.77,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17059,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17059,307,65,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17059,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17059,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17059,401,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17059,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17059,601,65,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17059,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (17059,606,1.89,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17060,203,33.69,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17060,204,8.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17060,205,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17060,207,1.77,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17060,208,223,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17060,255,56.23,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17060,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17060,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17060,301,15,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17060,303,2.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17060,306,260,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17060,307,70,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17060,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17060,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17060,401,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17060,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17060,601,108,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17060,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (17060,606,3.15,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17061,203,28.08,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17061,204,7.33,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17061,205,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17061,207,1.48,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17061,208,186,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17061,255,63.53,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17061,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (17061,291,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17061,301,13,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17061,303,2.34,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17061,306,335,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17061,307,76,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17061,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17061,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17061,401,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17061,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17061,601,90,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17061,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (17061,606,2.62,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17062,203,16.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17062,204,22.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17062,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17062,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17062,208,277,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17062,255,59.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17062,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17062,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17062,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17062,303,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17062,306,136,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17062,307,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17062,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17062,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17062,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17062,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17062,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17062,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17062,606,11.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17063,203,24.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17063,204,22.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17063,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17063,207,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17063,208,305,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17063,255,51.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17063,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17063,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17063,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17063,303,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17063,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17063,307,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17063,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17063,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17063,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17063,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17063,601,109,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17063,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17063,606,11.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17064,203,20.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17064,204,4.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17064,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17064,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17064,208,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17064,255,73.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17064,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17064,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17064,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17064,303,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17064,306,171,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17064,307,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17064,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17064,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17064,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17064,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17064,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17064,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17064,606,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17065,203,29.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17065,204,8.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17065,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17065,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17065,208,206,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17065,255,59.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17065,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17065,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17065,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17065,303,2.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17065,306,188,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17065,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17065,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17065,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17065,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17065,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17065,601,109,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17065,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17065,606,3.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17066,203,6.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17066,204,67.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17066,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17066,207,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17066,208,640,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17066,255,25.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17066,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17066,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17066,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17066,303,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17066,306,51,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17066,307,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17066,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17066,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17066,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17066,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17066,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17066,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17066,606,35.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17067,203,9.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17067,204,60.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17067,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17067,207,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17067,208,586,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17067,255,26.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17067,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17067,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17067,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17067,303,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17067,306,87,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17067,307,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17067,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17067,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17067,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17067,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17067,601,109,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17067,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17067,606,31.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17068,203,20.09,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17068,204,11.38,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17068,205,0.09,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17068,207,0.93,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17068,208,183,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17068,255,68.69,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17068,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17068,291,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17068,301,7,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17068,303,1.28,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17068,306,286,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17068,307,76,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17068,320,8,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17068,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17068,401,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17068,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17068,601,66,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17068,605,0.524,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17068,606,4.621,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17069,203,30.35,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17069,204,14.99,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17069,205,0.03,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17069,207,0.89,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17069,208,256,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17069,255,55.58,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17069,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17069,291,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17069,301,11,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17069,303,2.11,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17069,306,250,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17069,307,74,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17069,320,8,'100g',1,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (17069,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17069,401,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17069,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17069,601,110,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17069,605,0.642,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17069,606,5.56,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17070,203,22.05,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17070,204,3.77,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17070,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17070,207,1.02,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17070,208,122,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17070,255,74.49,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17070,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17070,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17070,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17070,303,1.37,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17070,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17070,307,82,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17070,320,3,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17070,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17070,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17070,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17070,601,65,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17070,605,0.086,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17070,606,1.278,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17071,203,33.31,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17071,204,8.4,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17071,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17071,207,0.96,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17071,208,209,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17071,255,59.33,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17071,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17071,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17071,301,11,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17071,303,2.24,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17071,306,258,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17071,307,77,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17071,320,3,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17071,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17071,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17071,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17071,601,115,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17071,605,0.219,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17071,606,2.631,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17072,203,18.64,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17072,204,14.52,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17072,205,0.13,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17072,207,0.95,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17072,208,206,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17072,255,66.75,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17072,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17072,291,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17072,301,10,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17072,303,1.49,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17072,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17072,307,59,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17072,320,9,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17072,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17072,401,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17072,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17072,601,67,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17072,605,0.739,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17072,606,5.902,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17073,203,24.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17073,204,15.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17073,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17073,207,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17073,208,246,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17073,255,57.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17073,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17073,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17073,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17073,303,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17073,306,167,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17073,307,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17073,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17073,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17073,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17073,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17073,601,101,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17073,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17073,606,7.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17074,203,21.1,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17074,204,4.64,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17074,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17074,207,1.08,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17074,208,126,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17074,255,74.35,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17074,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17074,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17074,301,11,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17074,303,1.64,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17074,306,350,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17074,307,64,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17074,320,3,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17074,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17074,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17074,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17074,601,66,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17074,605,0.168,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17074,606,1.512,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17075,203,27.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17075,204,7.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17075,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17075,207,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17075,208,181,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17075,255,63.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17075,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17075,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17075,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17075,303,2.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17075,306,183,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17075,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17075,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17075,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17075,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17075,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17075,601,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17075,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17075,606,3.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17076,203,15.4,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17076,204,26.19,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17076,205,0.22,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17076,207,0.82,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17076,208,298,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17076,255,56.89,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17076,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17076,291,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17076,301,14,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17076,303,1.24,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17076,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17076,307,63,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17076,320,16,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17076,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17076,401,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17076,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17076,601,69,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17076,605,1.35,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17076,606,11.161,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17077,203,23.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17077,204,23.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17077,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17077,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17077,208,315,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17077,255,50.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17077,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17077,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17077,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17077,303,2.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17077,306,159,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17077,307,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17077,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (17077,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17077,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17077,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17077,601,112,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17077,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17077,606,11.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17078,203,19.98,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17078,204,6.88,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17078,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17078,207,1.05,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17078,208,142,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17078,255,71.4,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17078,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17078,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17078,301,18,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17078,303,1.52,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17078,306,327,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17078,307,77,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17078,320,5,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17078,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17078,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17078,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17078,601,66,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17078,605,0.249,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17078,606,2.764,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17079,203,29.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17079,204,8.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17079,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17079,207,1.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17079,208,199,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17079,255,60.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17079,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17079,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17079,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17079,303,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17079,306,189,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17079,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17079,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17079,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17079,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17079,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17079,601,114,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17079,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17079,606,3.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17080,203,18.12,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17080,204,18.52,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17080,205,0.13,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17080,207,0.84,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17080,208,240,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17080,255,62.78,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17080,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17080,291,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17080,301,10,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17080,303,1.3,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17080,306,277,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17080,307,61,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17080,320,11,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17080,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17080,401,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17080,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17080,601,66,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17080,605,0.89,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17080,606,7.229,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17081,203,22.06,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17081,204,18.29,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17081,205,0.04,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17081,207,0.98,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17081,208,253,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17081,255,59.66,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17081,269,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17081,291,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17081,301,20,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17081,303,1.57,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17081,306,304,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17081,307,69,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17081,320,10,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (17081,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17081,401,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17081,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17081,601,76,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17081,605,0.907,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17081,606,7.066,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17082,203,20.65,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17082,204,8.61,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17082,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17082,207,0.94,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17082,208,160,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17082,255,70.24,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17082,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17082,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17082,301,12,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17082,303,1.43,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17082,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17082,307,67,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17082,320,5,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17082,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17082,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17082,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17082,601,64,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17082,605,0.313,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17082,606,2.782,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17083,203,24.43,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17083,204,10.63,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17083,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17083,207,1.09,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17083,208,193,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17083,255,64.96,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17083,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17083,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17083,301,22,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17083,303,1.65,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17083,306,323,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17083,307,72,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17083,320,4,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17083,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17083,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17083,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17083,601,76,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17083,605,0.422,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17083,606,3.664,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17084,203,16.16,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17084,204,22.89,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17084,205,0.24,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17084,207,0.8,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17084,208,272,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17084,255,61.07,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17084,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17084,291,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17084,301,10,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17084,303,1.01,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17084,306,261,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17084,307,64,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17084,320,14,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17084,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17084,401,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17084,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17084,601,60,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17084,605,1.174,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17084,606,9.855,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17085,203,28.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17085,204,26.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17085,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17085,207,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17085,208,357,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17085,255,42.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17085,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17085,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17085,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17085,303,2.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17085,306,147,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17085,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17085,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17085,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17085,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17085,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17085,601,123,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17085,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17085,606,12.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17086,203,19.72,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17086,204,8.3,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17086,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17086,207,0.98,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17086,208,154,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17086,255,72.51,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17086,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17086,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17086,301,12,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17086,303,1.12,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17086,306,307,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17086,307,73,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17086,320,4,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17086,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17086,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17086,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17086,601,56,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17086,605,0.296,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17086,606,3.371,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17087,203,34.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17087,204,15.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17087,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17087,207,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17087,208,285,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17087,255,47.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17087,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17087,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17087,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17087,303,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17087,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17087,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17087,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17087,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17087,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17087,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17087,601,127,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17087,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17087,606,6.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17088,203,19.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17088,204,6.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17088,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17088,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17088,208,144,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17088,255,72.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17088,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17088,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17088,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17088,303,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17088,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17088,307,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17088,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17088,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17088,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17088,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17088,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17088,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17088,606,2.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17089,203,30.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17089,204,11.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17089,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17089,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17089,208,231,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17089,255,57.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17089,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17089,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17089,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17089,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17089,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17089,307,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17089,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17089,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17089,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17089,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17089,601,114,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17089,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17089,606,4.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17090,203,20.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17090,204,2.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17090,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17090,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17090,208,112,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17090,255,75.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17090,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17090,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17090,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17090,303,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17090,306,328,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17090,307,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17090,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17090,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17090,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17090,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17090,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17090,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17090,606,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17091,203,31.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17091,204,6.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17091,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17091,207,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17091,208,196,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17091,255,60.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17091,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17091,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17091,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17091,303,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17091,306,338,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17091,307,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17091,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17091,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17091,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17091,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17091,601,118,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17091,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17091,606,1.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17092,203,6.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17092,204,67.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17092,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17092,207,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17092,208,638,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17092,255,24.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17092,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17092,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17092,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17092,303,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17092,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17092,307,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17092,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17092,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17092,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17092,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17092,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17092,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17092,606,32.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17093,203,9.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17093,204,66.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17093,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17093,207,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17093,208,642,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17093,255,21.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17093,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17093,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17093,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17093,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17093,306,173,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17093,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17093,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17093,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17093,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17093,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17093,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17093,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17093,606,32.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17094,203,20.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17094,204,3.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17094,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17094,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17094,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17094,255,74.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17094,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17094,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17094,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17094,303,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17094,306,367,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17094,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17094,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17094,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17094,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17094,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17094,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17094,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17094,606,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17095,203,36.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17095,204,6.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17095,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17095,207,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17095,208,211,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17095,255,55.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17095,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17095,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17095,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17095,303,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17095,306,383,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17095,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17095,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17095,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17095,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17095,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17095,601,134,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17095,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17095,606,2.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17096,203,27.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17096,204,9.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17096,205,9.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17096,207,2.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17096,208,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17096,255,51.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17096,269,0.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17096,291,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17096,301,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17096,303,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17096,306,371,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17096,307,454,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17096,320,10,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17096,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17096,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17096,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17096,601,112,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17096,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17096,606,3.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17097,203,31.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17097,204,8.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17097,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17097,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17097,208,211,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17097,255,58.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17097,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17097,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17097,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17097,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17097,306,425,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17097,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17097,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17097,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17097,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17097,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17097,601,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17097,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17097,606,3.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17098,203,27.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17098,204,4.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17098,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17098,207,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17098,208,160,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17098,255,66.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17098,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17098,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17098,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17098,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17098,306,389,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17098,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17098,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17098,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17098,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17098,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17098,601,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17098,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17098,606,1.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17099,203,21.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17099,204,1.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17099,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17099,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17099,208,107,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17099,255,75.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17099,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17099,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17099,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17099,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17099,306,372,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17099,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17099,320,0,'100g',2,1,'2024-12-12','2002-01-08');
INSERT INTO `cndb_nutval` VALUES (17099,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17099,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17099,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17099,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17099,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17099,606,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17100,203,36.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17100,204,5.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17100,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17100,207,1.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17100,208,203,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17100,255,56.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17100,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17100,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17100,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17100,303,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17100,306,387,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17100,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17100,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17100,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17100,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17100,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17100,601,135,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17100,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17100,606,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17101,203,28.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17101,204,6.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17101,205,9.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17101,207,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17101,208,216,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17101,255,53.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17101,269,0.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17101,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17101,301,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17101,303,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17101,306,383,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17101,307,455,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17101,320,10,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17101,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17101,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17101,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17101,601,113,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17101,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17101,606,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17102,203,33.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17102,204,4.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17102,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17102,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17102,208,183,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17102,255,60.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17102,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17102,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17102,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17102,303,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17102,306,442,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17102,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17102,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17102,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17102,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17102,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17102,601,107,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17102,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17102,606,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17103,203,28.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17103,204,3.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17103,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17103,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17103,208,150,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17103,255,67.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17103,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17103,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17103,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17103,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17103,306,393,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17103,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17103,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17103,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17103,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17103,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17103,601,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17103,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17103,606,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17104,203,20.07,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17104,204,10.07,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17104,205,0.07,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17104,207,0.96,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17104,208,177,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17104,255,69.44,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17104,269,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17104,291,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17104,301,14,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17104,303,0.84,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17104,306,241,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17104,307,98,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17104,320,0,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (17104,328,1.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17104,401,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17104,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17104,601,59,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17104,605,0.413,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17104,606,3.607,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17105,203,30.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17105,204,17.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17105,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17105,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17105,208,284,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17105,255,52.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17105,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17105,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17105,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17105,303,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17105,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17105,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17105,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17105,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17105,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17105,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17105,601,118,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17105,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17105,606,6.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17106,203,24.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17106,204,12.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17106,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17106,207,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17106,208,217,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17106,255,60.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17106,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17106,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17106,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17106,303,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17106,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17106,307,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17106,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17106,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17106,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17106,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17106,601,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17106,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17106,606,5.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17107,203,21.85,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17107,204,2.9,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17107,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17107,207,1.04,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17107,208,114,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17107,255,74.79,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17107,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17107,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17107,301,11,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17107,303,0.85,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17107,306,260,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17107,307,99,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17107,320,0,'100g',2,1,'2024-12-12','2016-01-03');
INSERT INTO `cndb_nutval` VALUES (17107,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17107,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17107,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17107,601,55,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17107,605,0.113,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17107,606,1.121,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17108,203,33.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17108,204,9.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17108,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17108,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17108,208,226,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17108,255,56.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17108,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17108,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17108,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17108,303,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17108,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17108,307,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17108,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17108,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17108,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17108,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17108,601,125,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17108,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17108,606,2.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17109,203,26.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17109,204,6.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17109,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17109,207,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17109,208,175,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17109,255,64.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17109,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17109,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17109,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17109,303,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17109,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17109,307,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17109,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17109,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17109,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17109,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17109,601,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17109,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17109,606,2.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17110,203,18.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17110,204,9.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17110,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17110,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17110,208,162,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17110,255,71.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17110,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17110,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17110,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17110,303,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17110,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17110,307,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17110,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17110,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17110,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17110,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17110,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17110,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17110,606,3.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17111,203,32.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17111,204,12.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17111,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17111,207,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17111,208,251,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17111,255,53.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17111,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17111,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17111,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17111,303,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17111,306,306,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17111,307,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17111,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17111,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17111,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17111,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17111,601,139,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17111,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17111,606,4.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17112,203,23.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17112,204,13.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17112,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17112,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17112,208,228,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17112,255,59.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17112,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17112,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17112,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17112,303,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17112,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17112,307,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17112,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17112,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17112,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17112,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17112,601,110,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17112,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17112,606,5.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17113,203,19.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17113,204,3.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17113,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17113,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17113,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17113,255,75.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17113,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17113,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17113,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17113,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17113,306,306,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17113,307,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17113,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17113,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17113,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17113,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17113,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17113,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17113,606,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17114,203,34.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17114,204,7.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17114,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17114,207,1.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17114,208,218,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17114,255,56.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17114,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17114,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17114,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17114,303,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17114,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17114,307,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17114,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17114,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17114,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17114,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17114,601,144,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17114,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17114,606,2.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17115,203,25.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17115,204,7.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17115,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17115,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17115,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17115,255,64.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17115,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17115,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17115,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17115,303,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17115,306,311,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17115,307,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17115,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17115,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17115,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17115,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17115,601,115,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17115,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17115,606,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17116,203,19.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17116,204,5.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17116,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17116,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17116,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17116,255,74.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17116,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17116,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17116,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17116,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17116,306,302,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17116,307,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17116,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17116,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17116,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17116,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17116,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17116,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17116,606,2.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17117,203,32.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17117,204,10.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17117,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17117,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17117,208,228,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17117,255,56.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17117,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17117,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17117,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17117,303,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17117,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17117,307,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17117,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17117,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17117,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17117,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17117,601,126,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17117,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17117,606,3.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17118,203,25.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17118,204,8.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17118,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17118,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17118,208,184,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17118,255,65.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17118,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17118,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17118,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17118,303,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17118,306,322,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17118,307,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17118,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17118,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17118,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17118,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17118,601,113,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17118,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17118,606,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17119,203,19.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17119,204,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17119,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17119,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17119,208,112,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17119,255,76.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17119,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17119,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17119,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17119,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17119,306,311,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17119,307,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17119,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17119,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17119,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17119,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17119,601,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17119,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17119,606,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17120,203,33.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17120,204,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17120,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17120,207,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17120,208,199,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17120,255,58.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17120,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17120,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17120,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17120,303,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17120,306,319,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17120,307,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17120,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17120,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17120,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17120,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17120,601,130,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17120,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17120,606,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17121,203,25.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17121,204,6.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17121,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17121,207,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17121,208,170,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17121,255,66.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17121,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17121,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17121,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17121,303,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17121,306,327,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17121,307,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17121,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17121,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17121,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17121,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17121,601,114,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17121,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17121,606,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17122,203,19.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17122,204,5.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17122,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17122,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17122,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17122,255,74.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17122,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17122,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17122,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17122,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17122,306,327,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17122,307,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17122,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17122,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17122,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17122,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17122,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17122,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17122,606,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17123,203,33.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17123,204,10.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17123,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17123,207,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17123,208,236,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17123,255,55.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17123,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17123,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17123,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17123,303,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17123,306,333,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17123,307,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17123,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17123,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17123,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17123,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17123,601,148,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17123,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17123,606,3.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17124,203,25.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17124,204,8.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17124,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17124,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17124,208,183,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17124,255,64.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17124,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17124,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17124,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17124,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17124,306,348,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17124,307,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17124,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17124,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17124,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17124,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17124,601,108,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17124,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17124,606,3.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17125,203,20.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17125,204,2.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17125,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17125,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17125,208,105,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17125,255,76.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17125,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17125,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17125,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17125,303,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17125,306,339,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17125,307,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17125,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17125,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17125,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17125,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17125,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17125,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17125,606,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17126,203,35.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17126,204,5.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17126,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17126,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17126,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17126,255,58.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17126,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17126,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17126,301,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17126,303,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17126,306,347,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17126,307,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17126,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17126,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17126,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17126,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17126,601,155,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17126,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17126,606,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17127,203,26.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17127,204,5.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17127,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17127,207,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17127,208,164,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17127,255,66.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17127,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17127,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17127,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17127,303,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17127,306,356,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17127,307,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17127,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17127,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17127,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17127,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17127,601,109,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17127,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17127,606,2.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17128,203,18.72,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17128,204,7.61,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17128,205,0.03,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17128,207,0.97,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17128,208,148,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17128,255,72.6,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17128,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17128,291,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17128,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17128,303,1.22,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17128,306,198,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17128,307,91,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17128,320,0,'100g',2,1,'2024-12-12','2016-01-03');
INSERT INTO `cndb_nutval` VALUES (17128,328,1.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17128,401,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17128,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17128,601,62,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17128,605,0.301,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17128,606,2.701,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17129,203,31.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17129,204,10.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17129,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17129,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17129,208,225,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17129,255,56.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17129,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17129,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17129,301,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17129,303,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17129,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17129,307,98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17129,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17129,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17129,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17129,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17129,601,153,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17129,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17129,606,3.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17130,203,25.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17130,204,8.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17130,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17130,207,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17130,208,186,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17130,255,65.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17130,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17130,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17130,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17130,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17130,306,306,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17130,307,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17130,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17130,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17130,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17130,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17130,601,117,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17130,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17130,606,3.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17131,203,19.6,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17131,204,2.88,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17131,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17131,207,1.01,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17131,208,110,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17131,255,76.29,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17131,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17131,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17131,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17131,303,1.26,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17131,306,203,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17131,307,92,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17131,320,0,'100g',2,1,'2024-12-12','2016-01-03');
INSERT INTO `cndb_nutval` VALUES (17131,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17131,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17131,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17131,601,60,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17131,605,0.106,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17131,606,1.113,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17132,203,32.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17132,204,6.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17132,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17132,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17132,208,198,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17132,255,59.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17132,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17132,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17132,301,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17132,303,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17132,306,305,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17132,307,101,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17132,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17132,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17132,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17132,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17132,601,158,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17132,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17132,606,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17133,203,25.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17133,204,6.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17133,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17133,207,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17133,208,171,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17133,255,66.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17133,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17133,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17133,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17133,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17133,306,310,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17133,307,102,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17133,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17133,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17133,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17133,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17133,601,119,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17133,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17133,606,2.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17134,203,19.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17134,204,7.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17134,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17134,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17134,208,152,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17134,255,71.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17134,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17134,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17134,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17134,303,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17134,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17134,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17134,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17134,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17134,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17134,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17134,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17134,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17134,606,3.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17135,203,31.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17135,204,13.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17135,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17135,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17135,208,252,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17135,255,54.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17135,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17135,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17135,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17135,303,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17135,306,321,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17135,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17135,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17135,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17135,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17135,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17135,601,108,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17135,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17135,606,5.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17136,203,25.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17136,204,10.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17136,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17136,207,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17136,208,202,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17136,255,62.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17136,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17136,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17136,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17136,303,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17136,306,351,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17136,307,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17136,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17136,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17136,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17136,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17136,601,102,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17136,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17136,606,4.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17137,203,20.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17137,204,2.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17137,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17137,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17137,208,110,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17137,255,75.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17137,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17137,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17137,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17137,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17137,306,348,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17137,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17137,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17137,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17137,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17137,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17137,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17137,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17137,606,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17138,203,33.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17138,204,6.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17138,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17138,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17138,208,204,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17138,255,58.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17138,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17138,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17138,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17138,303,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17138,306,339,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17138,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17138,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17138,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17138,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17138,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17138,601,113,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17138,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17138,606,1.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17139,203,26.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17139,204,6.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17139,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17139,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17139,208,168,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17139,255,65.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17139,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17139,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17139,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17139,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17139,306,365,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17139,307,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17139,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17139,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17139,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17139,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17139,601,104,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17139,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17139,606,2.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17140,203,20.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17140,204,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17140,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17140,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17140,208,109,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17140,255,76.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17140,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17140,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17140,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17140,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17140,306,331,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17140,307,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17140,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17140,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17140,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17140,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17140,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17140,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17140,606,0.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17141,203,34.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17141,204,4.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17141,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17141,207,1.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17141,208,188,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17141,255,59.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17141,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17141,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17141,301,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17141,303,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17141,306,342,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17141,307,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17141,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17141,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17141,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17141,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17141,601,145,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17141,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17141,606,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17142,203,18.58,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17142,204,13.06,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17142,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17142,207,0.93,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17142,208,197,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17142,255,66.16,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17142,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17142,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17142,301,12,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17142,303,1.37,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17142,306,198,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17142,307,103,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17142,320,0,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (17142,328,1.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17142,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17142,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17142,601,49,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17142,605,0.696,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17142,606,5.108,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (17143,203,24.38,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17143,204,7.56,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17143,205,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17143,207,1.31,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17143,208,172,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17143,255,66.76,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17143,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17143,291,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17143,301,17,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17143,303,0.99,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17143,306,337,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17143,307,83,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17143,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17143,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17143,401,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17143,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17143,601,103,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17143,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (17143,606,3.04,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17144,203,22.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17144,204,2.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17144,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17144,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17144,208,114,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17144,255,74.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17144,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17144,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17144,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17144,303,3.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17144,306,353,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17144,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17144,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17144,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17144,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17144,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17144,601,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17144,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17144,606,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17145,203,29.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17145,204,2.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17145,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17145,207,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17145,208,150,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17145,255,65.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17145,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17145,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17145,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17145,303,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17145,306,372,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17145,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17145,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17145,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17145,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17145,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17145,601,126,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17145,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17145,606,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17147,203,32.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17147,204,13.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17147,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17147,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17147,208,259,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17147,255,53.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17147,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17147,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17147,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17147,303,10.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17147,306,263,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17147,307,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17147,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17147,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17147,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17147,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17147,601,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17147,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17147,606,3.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17148,203,25.45,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (17148,204,8.62,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (17148,205,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (17148,207,1.02,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (17148,208,179,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (17148,255,65.09,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (17148,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17148,291,0,'100g',4,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (17148,301,14,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (17148,303,3.19,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (17148,306,353,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17148,307,76,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (17148,320,0,'100g',2,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (17148,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17148,401,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (17148,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17148,601,71,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (17148,605,NULL,'100g',NULL,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (17148,606,3.489,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (17149,203,20.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17149,204,7.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17149,205,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17149,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17149,208,146,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17149,255,71.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17149,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17149,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17149,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17149,303,2.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17149,306,328,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17149,307,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17149,320,0,'100g',1,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (17149,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17149,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17149,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17149,601,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17149,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17149,606,2.917,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17151,203,34.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17151,204,6.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17151,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17151,207,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17151,208,212,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17151,255,57.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17151,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17151,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17151,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17151,303,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17151,306,403,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17151,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17151,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17151,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17151,401,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17151,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17151,601,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17151,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17151,606,2.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17152,203,23.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17152,204,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17152,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17152,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17152,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17152,255,70.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17152,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17152,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17152,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17152,303,2.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17152,306,436,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17152,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17152,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17152,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17152,401,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17152,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17152,601,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17152,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17152,606,2.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17153,203,30.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17153,204,6.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17153,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17153,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17153,208,188,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17153,255,61.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17153,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17153,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17153,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17153,303,3.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17153,306,459,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17153,307,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17153,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17153,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17153,401,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17153,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17153,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17153,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17153,606,2.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17154,203,9.91,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17154,204,52.17,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17154,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17154,207,0.5,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17154,208,509,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17154,255,38.1,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17154,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17154,291,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17154,301,2,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17154,303,0.93,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17154,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17154,307,44,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17154,320,42,'100g',1,1,'2024-12-12','2012-01-05');
INSERT INTO `cndb_nutval` VALUES (17154,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17154,401,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17154,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17154,601,66,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17154,605,3.212,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17154,606,23.564,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17155,203,19.6,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17155,204,13.1,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17155,205,1.15,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17155,207,0.92,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17155,208,201,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17155,255,65.35,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17155,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17155,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17155,301,9,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17155,303,1.46,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17155,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17155,307,76,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17155,320,8,'100g',2,1,'2024-12-12','2016-01-03');
INSERT INTO `cndb_nutval` VALUES (17155,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17155,401,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17155,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17155,601,60,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17155,605,0.773,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17155,606,5.886,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17156,203,21.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17156,204,1.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17156,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17156,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17156,208,109,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17156,255,74.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17156,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17156,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17156,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17156,303,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17156,306,343,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17156,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17156,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17156,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17156,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17156,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17156,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17156,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17156,606,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17157,203,28.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17157,204,2.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17157,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17157,207,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17157,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17157,255,66.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17157,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17157,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17157,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17157,303,3.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17157,306,361,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17157,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17157,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17157,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17157,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17157,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17157,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17157,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17157,606,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17159,203,28.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17159,204,4.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17159,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17159,207,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17159,208,160,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17159,255,63.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17159,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17159,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17159,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17159,303,1.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17159,306,396,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17159,307,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17159,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17159,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17159,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17159,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17159,601,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17159,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17159,606,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17160,203,20.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17160,204,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17160,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17160,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17160,208,99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17160,255,76.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17160,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17160,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17160,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17160,303,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17160,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17160,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17160,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17160,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17160,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17160,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17160,601,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17160,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17160,606,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17161,203,26.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17161,204,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17161,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17161,207,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17161,208,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17161,255,68.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17161,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17161,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17161,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17161,303,2.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17161,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17161,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17161,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17161,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17161,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17161,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17161,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17161,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17161,606,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17162,203,22.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17162,204,3.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17162,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17162,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17162,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17162,255,71.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17162,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17162,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17162,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17162,303,4.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17162,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17162,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17162,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17162,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17162,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17162,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17162,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17162,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17162,606,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17163,203,29.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17163,204,4.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17163,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17163,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17163,208,167,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17163,255,62.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17163,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17163,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17163,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17163,303,6.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17163,306,310,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17163,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17163,320,0,'100g',1,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17163,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17163,401,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17163,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17163,601,109,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17163,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17163,606,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17164,203,22.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17164,204,2.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17164,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17164,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17164,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17164,255,73.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17164,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17164,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17164,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17164,303,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17164,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17164,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17164,320,0,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (17164,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17164,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17164,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17164,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17164,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17164,606,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17165,203,30.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17165,204,3.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17165,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17165,207,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17165,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17165,255,65.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17165,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17165,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17165,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17165,303,4.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17165,306,335,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17165,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17165,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17165,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17165,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17165,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17165,601,112,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17165,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17165,606,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17166,203,22.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17166,204,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17166,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17166,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17166,208,111,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17166,255,74.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17166,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17166,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17166,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17166,303,2.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17166,306,312,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17166,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17166,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17166,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17166,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17166,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17166,601,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17166,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17166,606,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17167,203,30.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17167,204,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17167,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17167,207,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17167,208,146,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17167,255,66.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17167,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17167,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17167,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17167,303,3.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17167,306,328,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17167,307,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17167,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17167,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17167,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17167,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17167,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17167,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17167,606,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17168,203,20.6,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17168,204,2.31,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17168,205,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17168,207,1.11,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17168,208,109,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17168,255,75.84,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17168,269,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (17168,291,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17168,301,13,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17168,303,2.83,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17168,306,385,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17168,307,82,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17168,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17168,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17168,401,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17168,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17168,601,57,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17168,605,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (17168,606,0.71,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17169,203,27.1,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17169,204,3.03,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17169,205,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17169,207,1.46,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17169,208,143,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17169,255,68.21,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17169,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17169,291,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17169,301,17,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17169,303,3.73,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17169,306,405,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17169,307,86,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17169,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17169,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17169,401,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17169,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17169,601,75,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17169,605,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (17169,606,0.93,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (17170,203,21.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17170,204,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17170,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17170,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17170,208,133,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17170,255,72.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17170,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17170,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17170,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17170,303,3.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17170,306,360,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17170,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17170,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17170,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17170,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17170,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17170,601,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17170,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17170,606,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17171,203,28.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17171,204,6.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17171,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17171,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17171,208,175,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17171,255,63.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17171,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17171,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17171,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17171,303,5.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17171,306,379,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17171,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17171,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17171,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17171,401,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17171,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17171,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17171,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17171,606,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17172,203,22.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17172,204,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17172,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17172,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17172,208,102,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17172,255,75.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17172,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17172,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17172,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17172,303,3.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17172,306,317,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17172,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17172,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17172,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17172,401,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17172,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17172,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17172,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17172,606,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17173,203,29.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17173,204,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17173,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17173,207,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17173,208,134,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17173,255,67.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17173,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17173,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17173,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17173,303,4.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17173,306,334,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17173,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17173,320,0,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (17173,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17173,401,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17173,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17173,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17173,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17173,606,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17176,203,30.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17176,204,10.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17176,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17176,207,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17176,208,221,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17176,255,58.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17176,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17176,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17176,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17176,303,4.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17176,306,438,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17176,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17176,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17176,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17176,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17176,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17176,601,129,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17176,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17176,606,1.206,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17177,203,20.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17177,204,5.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17177,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17177,207,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17177,208,136,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17177,255,72.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17177,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17177,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17177,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17177,303,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17177,306,330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17177,307,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17177,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17177,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17177,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17177,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17177,601,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17177,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17177,606,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17178,203,29.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17178,204,8.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17178,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17178,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17178,208,197,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17178,255,60.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17178,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17178,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17178,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17178,303,2.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17178,306,383,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17178,307,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17178,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17178,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17178,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17178,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17178,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17178,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17178,606,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17179,203,30.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17179,204,8.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17179,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17179,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17179,208,206,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17179,255,58.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17179,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17179,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17179,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17179,303,2.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17179,306,300,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17179,307,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17179,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17179,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17179,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17179,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17179,601,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17179,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17179,606,2.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17180,203,21.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17180,204,2.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17180,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17180,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17180,208,114,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17180,255,74.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17180,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17180,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17180,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17180,303,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17180,306,378,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17180,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17180,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17180,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17180,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17180,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17180,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17180,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17180,606,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17181,203,33.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17181,204,3.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17181,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17181,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17181,208,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17181,255,61.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17181,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17181,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17181,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17181,303,4.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17181,306,343,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17181,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17181,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17181,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17181,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17181,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17181,601,123,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17181,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17181,606,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17182,203,29.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17182,204,14.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17182,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17182,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17182,208,255,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17182,255,54.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17182,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17182,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17182,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17182,303,7.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17182,306,398,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17182,307,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17182,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17182,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17182,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17182,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17182,601,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17182,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17182,606,4.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17183,203,21.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17183,204,3.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17183,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17183,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17183,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17183,255,73.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17183,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17183,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17183,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17183,303,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17183,306,304,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17183,307,103,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17183,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17183,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17183,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17183,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17183,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17183,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17183,606,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17184,203,30.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17184,204,4.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17184,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17184,207,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17184,208,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17184,255,62.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17184,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17184,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17184,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17184,303,6.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17184,306,352,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17184,307,119,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17184,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17184,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17184,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17184,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17184,601,121,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17184,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17184,606,0.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17185,203,10.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17185,204,8.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17185,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17185,207,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17185,208,122,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17185,255,79.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17185,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17185,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17185,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17185,303,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17185,306,296,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17185,307,112,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17185,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17185,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17185,401,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17185,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17185,601,1352,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17185,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17185,606,2.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17186,203,12.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17186,204,10.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17186,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17186,207,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17186,208,145,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17186,255,75.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17186,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17186,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17186,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17186,303,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17186,306,205,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17186,307,134,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17186,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17186,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17186,401,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17186,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17186,601,2043,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17186,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17186,606,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17187,203,16.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17187,204,22.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17187,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17187,207,1.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17187,208,273,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17187,255,60.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17187,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17187,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17187,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17187,303,2.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17187,306,358,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17187,307,157,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17187,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17187,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17187,401,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17187,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17187,601,2504,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17187,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17187,606,5.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17188,203,10.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17188,204,8.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17188,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17188,207,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17188,208,118,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17188,255,79.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17188,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17188,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17188,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17188,303,2.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17188,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17188,307,127,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17188,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17188,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17188,401,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17188,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17188,601,1590,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17188,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17188,606,1.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17189,203,11.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17189,204,9.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17189,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17189,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17189,208,136,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17189,255,76.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17189,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17189,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17189,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17189,303,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17189,306,214,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17189,307,156,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17189,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17189,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17189,401,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17189,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17189,601,3100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17189,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17189,606,2.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17190,203,14.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17190,204,16.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17190,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17190,207,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17190,208,213,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17190,255,68.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17190,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17190,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17190,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17190,303,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17190,306,472,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17190,307,176,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17190,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17190,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17190,401,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17190,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17190,601,2120,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17190,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17190,606,3.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17191,203,16.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17191,204,5.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17191,205,0.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17191,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17191,208,122,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17191,255,76.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17191,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17191,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17191,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17191,303,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17191,306,316,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17191,307,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17191,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17191,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17191,401,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17191,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17191,601,135,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17191,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17191,606,2.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17192,203,24.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17192,204,7.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17192,205,1.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17192,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17192,208,185,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17192,255,64.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17192,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17192,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17192,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17192,303,5.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17192,306,188,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17192,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17192,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17192,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17192,401,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17192,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17192,601,249,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17192,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17192,606,3.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17193,203,17.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17193,204,3.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17193,205,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17193,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17193,208,110,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17193,255,77.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17193,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17193,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17193,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17193,303,4.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17193,306,261,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17193,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17193,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17193,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17193,401,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17193,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17193,601,104,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17193,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17193,606,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17194,203,29.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17194,204,6.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17194,205,0.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17194,207,1.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17194,208,186,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17194,255,62.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17194,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17194,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17194,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17194,303,4.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17194,306,199,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17194,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17194,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17194,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17194,401,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17194,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17194,601,176,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17194,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17194,606,1.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17195,203,15.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17195,204,2.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17195,205,0.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17195,207,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17195,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17195,255,79.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17195,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17195,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17195,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17195,303,6.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17195,306,277,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17195,307,156,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17195,320,95,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17195,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17195,401,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17195,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17195,601,337,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17195,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17195,606,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17196,203,23.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17196,204,3.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17196,205,0.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17196,207,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17196,208,137,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17196,255,70.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17196,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17196,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17196,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17196,303,12.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17196,306,178,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17196,307,151,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17196,320,137,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17196,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17196,401,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17196,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17196,601,565,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17196,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17196,606,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17197,203,15.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17197,204,3.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17197,205,0.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17197,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17197,208,99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17197,255,79.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17197,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17197,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17197,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17197,303,3.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17197,306,272,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17197,307,178,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17197,320,92,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17197,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17197,401,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17197,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17197,601,364,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17197,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17197,606,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17198,203,26.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17198,204,5.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17198,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17198,207,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17198,208,163,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17198,255,67.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17198,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17198,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17198,301,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17198,303,3.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17198,306,159,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17198,307,110,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17198,320,201,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17198,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17198,401,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17198,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17198,601,791,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17198,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17198,606,1.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17199,203,20.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17199,204,5.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17199,205,1.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17199,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17199,208,139,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17199,255,71.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17199,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17199,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17199,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17199,303,7.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17199,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17199,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17199,320,7391,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17199,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17199,401,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17199,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17199,601,371,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17199,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17199,606,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17200,203,30.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17200,204,8.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17200,205,2.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17200,207,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17200,208,220,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17200,255,56.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17200,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17200,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17200,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17200,303,8.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17200,306,221,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17200,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17200,320,7491,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17200,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17200,401,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17200,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17200,601,501,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17200,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17200,606,3.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17201,203,25.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17201,204,12.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17201,205,3.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17201,207,1.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17201,208,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17201,255,56.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17201,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17201,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17201,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17201,303,10.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17201,306,352,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17201,307,124,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17201,320,7782,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17201,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17201,401,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17201,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17201,601,493,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17201,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17201,606,4.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17202,203,19.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17202,204,4.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17202,205,2.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17202,207,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17202,208,140,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17202,255,70.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17202,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17202,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17202,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17202,303,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17202,306,308,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17202,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17202,320,11707,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (17202,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17202,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17202,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17202,601,334,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17202,605,0.215,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17202,606,1.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17203,203,28.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17203,204,6.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17203,205,3.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17203,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17203,208,192,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17203,255,59.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17203,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17203,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17203,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17203,303,5.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17203,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17203,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17203,320,21145,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (17203,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17203,401,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17203,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17203,601,511,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17203,605,0.305,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17203,606,1.986,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17204,203,27.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17204,204,6.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17204,205,4.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17204,207,1.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17204,208,193,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17204,255,59.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17204,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17204,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17204,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17204,303,5.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17204,306,353,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17204,307,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17204,320,20074,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (17204,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17204,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17204,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17204,601,485,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17204,605,0.285,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17204,606,2.109,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17205,203,16.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17205,204,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17205,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17205,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17205,208,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17205,255,79.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17205,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17205,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17205,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17205,303,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17205,306,238,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17205,307,157,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17205,320,27,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17205,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17205,401,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17205,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17205,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17205,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17205,606,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17206,203,19.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17206,204,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17206,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17206,207,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17206,208,113,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17206,255,75.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17206,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17206,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17206,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17206,303,4.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17206,306,127,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17206,307,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17206,320,32,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17206,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17206,401,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17206,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17206,601,284,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17206,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17206,606,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17207,203,16.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17207,204,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17207,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17207,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17207,208,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17207,255,80.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17207,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17207,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17207,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17207,303,5.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17207,306,274,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17207,307,108,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17207,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17207,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17207,401,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17207,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17207,601,229,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17207,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17207,606,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17208,203,18.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17208,204,2.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17208,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17208,207,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17208,208,104,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17208,255,77.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17208,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17208,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17208,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17208,303,3.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17208,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17208,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17208,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17208,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17208,401,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17208,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17208,601,263,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17208,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17208,606,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17209,203,14.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17209,204,23.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17209,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17209,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17209,208,276,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17209,255,58.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17209,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17209,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17209,301,162,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17209,303,5.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17209,306,288,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17209,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17209,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17209,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17209,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17209,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17209,601,213,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17209,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17209,606,11.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17210,203,14.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17210,204,9.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17210,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17210,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17210,208,152,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17210,255,73.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17210,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17210,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17210,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17210,303,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17210,306,420,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17210,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17210,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17210,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17210,401,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17210,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17210,601,260,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17210,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17210,606,4.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17211,203,22.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17211,204,15.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17211,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17211,207,2.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17211,208,234,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17211,255,59.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17211,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17211,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17211,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17211,303,2.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17211,306,291,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17211,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17211,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17211,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17211,401,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17211,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17211,601,400,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17211,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17211,606,6.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17212,203,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17212,204,13.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17212,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17212,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17212,208,182,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17212,255,70.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17212,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17212,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17212,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17212,303,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17212,306,278,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17212,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17212,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17212,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17212,401,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17212,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17212,601,173,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17212,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17212,606,4.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17213,203,29.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17213,204,14.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17213,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17213,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17213,208,256,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17213,255,55.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17213,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17213,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17213,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17213,303,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17213,306,278,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17213,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17213,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17213,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17213,401,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17213,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17213,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17213,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17213,606,5.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17214,203,17.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17214,204,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17214,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17214,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17214,208,101,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17214,255,78.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17214,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17214,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17214,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17214,303,41.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17214,306,358,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17214,307,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17214,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17214,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17214,401,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17214,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17214,601,250,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17214,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17214,606,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17215,203,26.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17215,204,4.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17215,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17215,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17215,208,156,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17215,255,66.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17215,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17215,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17215,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17215,303,38.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17215,306,248,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17215,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17215,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17215,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17215,401,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17215,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17215,601,385,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17215,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17215,606,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17216,203,18.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17216,204,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17216,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17216,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17216,208,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17216,255,78.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17216,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17216,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17216,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17216,303,9.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17216,306,362,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17216,307,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17216,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17216,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17216,401,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17216,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17216,601,340,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17216,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17216,606,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17217,203,24.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17217,204,2.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17217,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17217,207,1.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17217,208,129,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17217,255,71.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17217,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17217,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17217,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17217,303,7.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17217,306,215,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17217,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17217,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17217,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17217,401,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17217,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17217,601,447,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17217,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17217,606,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17218,203,17.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17218,204,3.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17218,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17218,207,2.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17218,208,101,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17218,255,79.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17218,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17218,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17218,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17218,303,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17218,306,488,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17218,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17218,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (17218,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17218,401,49.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17218,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17218,601,250,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17218,605,0.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17218,606,0.806,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17219,203,22.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17219,204,3.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17219,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17219,207,2.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17219,208,125,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17219,255,73.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17219,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17219,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17219,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17219,303,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17219,306,435,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17219,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17219,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (17219,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17219,401,39.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17219,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17219,601,350,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17219,605,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17219,606,0.942,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17220,203,15.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17220,204,17.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17220,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17220,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17220,208,222,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17220,255,66.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17220,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17220,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17220,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17220,303,2.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17220,306,257,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17220,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17220,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17220,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17220,401,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17220,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17220,601,156,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17220,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17220,606,6.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17221,203,21.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17221,204,20.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17221,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17221,207,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17221,208,275,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17221,255,57.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17221,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17221,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17221,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17221,303,2.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17221,306,158,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17221,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17221,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17221,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17221,401,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17221,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17221,601,189,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17221,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17221,606,7.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17222,203,17.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17222,204,5.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17222,205,1.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17222,207,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17222,208,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17222,255,74.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17222,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17222,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17222,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17222,303,2.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17222,306,271,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17222,307,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17222,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17222,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17222,401,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17222,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17222,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17222,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17222,606,2.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17223,203,25.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17223,204,10.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17223,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17223,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17223,208,202,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17223,255,64.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17223,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17223,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17223,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17223,303,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17223,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17223,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17223,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17223,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17223,401,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17223,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17223,601,238,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17223,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17223,606,4.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17224,203,16.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17224,204,23.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17224,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17224,207,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17224,208,282,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17224,255,59.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17224,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17224,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17224,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17224,303,1.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17224,306,222,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17224,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17224,320,0,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (17224,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17224,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17224,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17224,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17224,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17224,606,10.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17225,203,24.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17225,204,19.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17225,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17225,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17225,208,283,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17225,255,55.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17225,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17225,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17225,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17225,303,1.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17225,306,339,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17225,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17225,320,0,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (17225,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17225,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17225,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17225,601,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17225,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17225,606,8.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17226,203,17.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17226,204,18.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17226,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17226,207,0.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17226,208,243,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17226,255,63.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17226,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17226,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17226,301,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17226,303,1.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17226,306,239,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17226,307,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17226,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17226,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17226,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17226,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17226,601,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17226,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17226,606,8.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17227,203,25.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17227,204,18.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17227,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17227,207,1.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17227,208,271,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17227,255,55.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17227,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17227,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17227,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17227,303,1.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17227,306,318,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17227,307,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17227,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17227,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17227,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17227,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17227,601,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17227,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17227,606,7.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17228,203,18.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17228,204,13.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17228,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17228,207,0.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17228,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17228,255,67.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17228,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17228,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17228,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17228,303,1.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17228,306,214,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17228,307,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17228,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17228,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17228,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17228,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17228,601,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17228,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17228,606,5.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17229,203,28.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17229,204,13.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17229,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17229,207,0.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17229,208,243,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17229,255,56.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17229,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17229,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17229,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17229,303,2.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17229,306,257,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17229,307,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17229,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17229,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17229,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17229,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17229,601,106,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17229,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17229,606,5.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17230,203,18.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17230,204,14.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17230,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17230,207,0.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17230,208,209,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17230,255,66.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17230,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17230,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17230,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17230,303,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17230,306,258,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17230,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17230,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17230,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17230,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17230,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17230,601,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17230,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17230,606,6.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17231,203,26.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17231,204,14.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17231,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17231,207,1.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17231,208,242,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17231,255,58.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17231,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17231,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17231,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17231,303,2.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17231,306,319,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17231,307,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17231,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17231,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17231,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17231,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17231,601,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17231,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17231,606,5.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17232,203,18.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17232,204,11.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17232,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17232,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17232,208,185,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17232,255,68.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17232,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17232,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17232,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17232,303,1.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17232,306,267,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17232,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17232,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17232,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17232,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17232,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17232,601,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17232,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17232,606,4.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17233,203,26.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17233,204,11.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17233,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17233,207,1.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17233,208,217,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17233,255,61.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17233,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17233,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17233,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17233,303,1.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17233,306,329,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17233,307,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17233,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17233,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17233,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17233,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17233,601,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17233,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17233,606,4.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17234,203,17.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17234,204,20.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17234,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17234,207,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17234,208,261,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17234,255,61.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17234,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17234,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17234,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17234,303,1.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17234,306,235,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17234,307,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17234,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17234,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17234,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17234,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17234,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17234,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17234,606,9.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17235,203,24.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17235,204,19.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17235,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17235,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17235,208,284,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17235,255,54.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17235,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17235,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17235,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17235,303,2.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17235,306,304,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17235,307,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17235,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17235,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17235,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17235,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17235,601,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17235,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17235,606,8.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17236,203,17.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17236,204,22.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17236,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17236,207,0.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17236,208,279,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17236,255,59.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17236,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17236,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17236,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17236,303,1.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17236,306,226,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17236,307,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17236,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17236,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17236,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17236,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17236,601,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17236,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17236,606,9.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17237,203,26.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17237,204,20.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17237,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17237,207,1.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17237,208,297,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17237,255,53.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17237,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17237,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17237,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17237,303,1.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17237,306,336,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17237,307,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17237,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17237,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17237,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17237,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17237,601,99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17237,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17237,606,8.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17238,203,23.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17238,204,21.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17238,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17238,207,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17238,208,290,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17238,255,54.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17238,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17238,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17238,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17238,303,2.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17238,306,250,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17238,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17238,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17238,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17238,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17238,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17238,601,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17238,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17238,606,9.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17239,203,15.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17239,204,30.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17239,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17239,207,0.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17239,208,342,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17239,255,53.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17239,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17239,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17239,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17239,303,1.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17239,306,201,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17239,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17239,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17239,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17239,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17239,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17239,601,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17239,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17239,606,13.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17240,203,23.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17240,204,26.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17240,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17240,207,1.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17240,208,340,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17240,255,49.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17240,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17240,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17240,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17240,303,1.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17240,306,277,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17240,307,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17240,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17240,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17240,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17240,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17240,601,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17240,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17240,606,11.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17241,203,21.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17241,204,27.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17241,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17241,207,0.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17241,208,341,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17241,255,49.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17241,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17241,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17241,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17241,303,1.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17241,306,277,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17241,307,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17241,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17241,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17241,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17241,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17241,601,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17241,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17241,606,11.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17242,203,17.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17242,204,18.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17242,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17242,207,0.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17242,208,244,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17242,255,63.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17242,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17242,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17242,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17242,303,1.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17242,306,237,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17242,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17242,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17242,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17242,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17242,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17242,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17242,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17242,606,8.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17243,203,29.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17243,204,23.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17243,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17243,207,1.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17243,208,338,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17243,255,45.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17243,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17243,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17243,301,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17243,303,2.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17243,306,261,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17243,307,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17243,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17243,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17243,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17243,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17243,601,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17243,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17243,606,9.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17244,203,23.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17244,204,18.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17244,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17244,207,1.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17244,208,268,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17244,255,56.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17244,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17244,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17244,301,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17244,303,1.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17244,306,335,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17244,307,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17244,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17244,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17244,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17244,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17244,601,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17244,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17244,606,7.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17245,203,22.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17245,204,19.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17245,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17245,207,1.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17245,208,269,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17245,255,56.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17245,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17245,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17245,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17245,303,1.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17245,306,251,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17245,307,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17245,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17245,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17245,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17245,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17245,601,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17245,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17245,606,7.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17246,203,17.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17246,204,18.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17246,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17246,207,0.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17246,208,244,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17246,255,63.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17246,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17246,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17246,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17246,303,1.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17246,306,244,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17246,307,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17246,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17246,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17246,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17246,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17246,601,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17246,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17246,606,8.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17247,203,31.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17247,204,22.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17247,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17247,207,1.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17247,208,337,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17247,255,44.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17247,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17247,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17247,301,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17247,303,2.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17247,306,311,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17247,307,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17247,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17247,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17247,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17247,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17247,601,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17247,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17247,606,9.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17248,203,24.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17248,204,18.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17248,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17248,207,1.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17248,208,269,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17248,255,55.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17248,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17248,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17248,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17248,303,2.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17248,306,314,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17248,307,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17248,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17248,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17248,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17248,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17248,601,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17248,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17248,606,7.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17249,203,22.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17249,204,18.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17249,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17249,207,1.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17249,208,267,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17249,255,57.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17249,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17249,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17249,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17249,303,2.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17249,306,262,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17249,307,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17249,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17249,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17249,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17249,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17249,601,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17249,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17249,606,8.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17250,203,17.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17250,204,18.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17250,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17250,207,0.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17250,208,244,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17250,255,63.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17250,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17250,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17250,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17250,303,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17250,306,234,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17250,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17250,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17250,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17250,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17250,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17250,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17250,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17250,606,8.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17251,203,28.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17251,204,23.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17251,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17251,207,1.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17251,208,339,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17251,255,45.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17251,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17251,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17251,301,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17251,303,2.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17251,306,244,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17251,307,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17251,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17251,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17251,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17251,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17251,601,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17251,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17251,606,9.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17252,203,23.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17252,204,18.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17252,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17252,207,1.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17252,208,267,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17252,255,57.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17252,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17252,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17252,301,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17252,303,1.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17252,306,341,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17252,307,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17252,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17252,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17252,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17252,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17252,601,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17252,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17252,606,7.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17253,203,22.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17253,204,19.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17253,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17253,207,1.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17253,208,270,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17253,255,56.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17253,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17253,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17253,301,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17253,303,1.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17253,306,248,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17253,307,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17253,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17253,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17253,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17253,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17253,601,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17253,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17253,606,7.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17254,203,17.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17254,204,17.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17254,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17254,207,0.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17254,208,232,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17254,255,64.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17254,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17254,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17254,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17254,303,1.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17254,306,147,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17254,307,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17254,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17254,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17254,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17254,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17254,601,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17254,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17254,606,8.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17255,203,25.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17255,204,17.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17255,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17255,207,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17255,208,270,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17255,255,54.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17255,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17255,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17255,301,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17255,303,2.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17255,306,161,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17255,307,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17255,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17255,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17255,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17255,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17255,601,106,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17255,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17255,606,8.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17256,203,18.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17256,204,16.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17256,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17256,207,1.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17256,208,223,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17256,255,66.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17256,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17256,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17256,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17256,303,1.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17256,306,131,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17256,307,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17256,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17256,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17256,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17256,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17256,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17256,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17256,606,8.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17257,203,26.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17257,204,15.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17257,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17257,207,1.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17257,208,258,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17257,255,56.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17257,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17257,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17257,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17257,303,2.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17257,306,118,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17257,307,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17257,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17257,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17257,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17257,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17257,601,102,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17257,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17257,606,7.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17258,203,18.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17258,204,13.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17258,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17258,207,1.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17258,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17258,255,67.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17258,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17258,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17258,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17258,303,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17258,306,160,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17258,307,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17258,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17258,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17258,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17258,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17258,601,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17258,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17258,606,6.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17259,203,25.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17259,204,13.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17259,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17259,207,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17259,208,234,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17259,255,59.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17259,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17259,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17259,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17259,303,2.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17259,306,170,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17259,307,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17259,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17259,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17259,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17259,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17259,601,101,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17259,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17259,606,6.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17260,203,17.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17260,204,22.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17260,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17260,207,0.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17260,208,273,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17260,255,59.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17260,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17260,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17260,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17260,303,1.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17260,306,128,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17260,307,39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17260,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17260,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17260,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17260,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17260,601,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17260,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17260,606,11.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17261,203,24.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17261,204,21.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17261,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17261,207,1.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17261,208,296,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17261,255,52.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17261,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17261,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17261,301,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17261,303,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17261,306,164,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17261,307,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17261,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17261,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17261,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17261,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17261,601,113,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17261,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17261,606,10.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17262,203,15.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17262,204,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17262,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17262,207,0.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17262,208,311,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17262,255,56.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17262,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17262,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17262,301,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17262,303,1.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17262,306,120,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17262,307,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17262,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17262,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17262,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17262,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17262,601,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17262,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17262,606,13.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17263,203,19.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17263,204,25.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17263,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17263,207,1.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17263,208,317,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17263,255,52.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17263,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17263,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17263,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17263,303,1.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17263,306,128,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17263,307,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17263,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17263,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17263,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17263,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17263,601,99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17263,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17263,606,12.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17264,203,17.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17264,204,19.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17264,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17264,207,0.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17264,208,251,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17264,255,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17264,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17264,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17264,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17264,303,1.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17264,306,137,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17264,307,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17264,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17264,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17264,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17264,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17264,601,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17264,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17264,606,9.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17265,203,29.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17265,204,24.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17265,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17265,207,1.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17265,208,342,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17265,255,43.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17265,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17265,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17265,301,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17265,303,2.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17265,306,151,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17265,307,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17265,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17265,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17265,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17265,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17265,601,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17265,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17265,606,11.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17267,203,21.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17267,204,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17267,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17267,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17267,208,113,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17267,255,74.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17267,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17267,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17267,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17267,303,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17267,306,335,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17267,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17267,320,1,'100g',1,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (17267,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17267,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17267,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17267,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17267,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17267,606,0.885,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17268,203,22.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17268,204,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17268,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17268,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17268,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17268,255,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17268,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17268,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17268,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17268,303,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17268,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17268,307,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17268,320,1,'100g',1,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (17268,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17268,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17268,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17268,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17268,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17268,606,0.898,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17269,203,21.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17269,204,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17269,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17269,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17269,208,109,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17269,255,75.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17269,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17269,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17269,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17269,303,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17269,306,322,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17269,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17269,320,1,'100g',1,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (17269,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17269,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17269,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17269,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17269,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17269,606,0.749,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17270,203,9.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17270,204,53.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17270,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17270,207,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17270,208,521,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17270,255,36.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17270,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17270,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17270,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17270,303,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17270,306,181,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17270,307,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17270,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17270,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17270,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17270,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17270,601,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17270,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17270,606,21.407,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17271,203,17.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17271,204,14.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17271,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17271,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17271,208,208,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17271,255,67.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17271,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17271,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17271,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17271,303,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17271,306,286,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17271,307,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17271,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17271,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17271,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17271,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17271,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17271,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17271,606,5.896,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17272,203,26.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17272,204,16.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17272,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17272,207,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17272,208,266,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17272,255,55.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17272,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17272,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17272,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17272,303,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17272,306,272,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17272,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17272,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17272,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17272,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17272,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17272,601,113,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17272,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17272,606,6.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17273,203,25.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17273,204,18.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17273,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17273,207,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17273,208,282,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17273,255,54.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17273,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17273,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17273,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17273,303,0.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17273,306,266,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17273,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17273,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17273,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17273,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17273,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17273,601,112,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17273,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17273,606,7.434,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17274,203,28.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17274,204,14.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17274,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17274,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17274,208,248,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17274,255,57.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17274,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17274,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17274,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17274,303,0.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17274,306,278,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17274,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17274,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17274,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17274,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17274,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17274,601,114,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17274,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17274,606,5.489,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17275,203,30.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17275,204,9.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17275,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17275,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17275,208,218,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17275,255,59.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17275,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17275,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17275,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17275,303,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17275,306,289,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17275,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17275,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17275,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17275,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17275,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17275,601,116,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17275,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17275,606,3.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17276,203,19.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17276,204,3.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17276,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17276,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17276,208,113,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17276,255,76.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17276,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17276,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17276,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17276,303,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17276,306,314,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17276,307,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17276,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17276,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17276,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17276,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17276,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17276,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17276,606,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17277,203,31.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17277,204,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17277,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17277,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17277,208,191,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17277,255,61.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17277,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17277,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17277,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17277,303,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17277,306,305,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17277,307,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17277,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17277,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17277,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17277,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17277,601,124,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17277,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17277,606,2.078,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17278,203,19.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17278,204,2.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17278,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17278,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17278,208,108,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17278,255,77.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17278,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17278,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17278,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17278,303,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17278,306,316,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17278,307,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17278,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17278,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17278,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17278,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17278,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17278,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17278,606,0.738,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17279,203,32.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17279,204,4.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17279,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17279,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17279,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17279,255,62.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17279,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17279,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17279,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17279,303,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17279,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17279,307,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17279,320,0,'100g',3,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (17279,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17279,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17279,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17279,601,126,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17279,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17279,606,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17280,203,17.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17280,204,16.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17280,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17280,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17280,208,229,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17280,255,64.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17280,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17280,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17280,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17280,303,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17280,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17280,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17280,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17280,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17280,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17280,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17280,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17280,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17280,606,8.189,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17281,203,24.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17281,204,16.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17281,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17281,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17281,208,256,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17281,255,58.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17281,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17281,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17281,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17281,303,1.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17281,306,301,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17281,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17281,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17281,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17281,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17281,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17281,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17281,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17281,606,7.94,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17282,203,20.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17282,204,6.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17282,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17282,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17282,208,142,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17282,255,73.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17282,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17282,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17282,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17282,303,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17282,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17282,307,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17282,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17282,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17282,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17282,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17282,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17282,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17282,606,2.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17283,203,26.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17283,204,9.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17283,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17283,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17283,208,201,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17283,255,63.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17283,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17283,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17283,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17283,303,2.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17283,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17283,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17283,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17283,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17283,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17283,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17283,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17283,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17283,606,4.048,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17284,203,6.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17284,204,68.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17284,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17284,207,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17284,208,648,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17284,255,25.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17284,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17284,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17284,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17284,303,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17284,306,112,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17284,307,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17284,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17284,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17284,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17284,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17284,601,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17284,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17284,606,35.353,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17285,203,9.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17285,204,66.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17285,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17285,207,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17285,208,639,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17285,255,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17285,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17285,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17285,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17285,303,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17285,306,179,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17285,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17285,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17285,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17285,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17285,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17285,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17285,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17285,606,34.751,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17286,203,18.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17286,204,12.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17286,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17286,207,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17286,208,195,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17286,255,68.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17286,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17286,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17286,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17286,303,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17286,306,270,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17286,307,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17286,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17286,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17286,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17286,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17286,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17286,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17286,606,5.981,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17287,203,24.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17287,204,14.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17287,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17287,207,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17287,208,236,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17287,255,60.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17287,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17287,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17287,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17287,303,1.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17287,306,244,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17287,307,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17287,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17287,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17287,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17287,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17287,601,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17287,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17287,606,6.794,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17288,203,20.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17288,204,3.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17288,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17288,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17288,208,123,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17288,255,75.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17288,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17288,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17288,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17288,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17288,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17288,307,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17288,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17288,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17288,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17288,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17288,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17288,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17288,606,1.344,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17289,203,27.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17289,204,5.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17289,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17289,207,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17289,208,165,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17289,255,66.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17289,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17289,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17289,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17289,303,1.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17289,306,255,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17289,307,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17289,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17289,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17289,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17289,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17289,601,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17289,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17289,606,1.884,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17290,203,18.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17290,204,15.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17290,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17290,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17290,208,215,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17290,255,66.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17290,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17290,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17290,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17290,303,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17290,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17290,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17290,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17290,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17290,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17290,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17290,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17290,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17290,606,7.288,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17291,203,25.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17291,204,15.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17291,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17291,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17291,208,244,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17291,255,59.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17291,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17291,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17291,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17291,303,2.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17291,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17291,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17291,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17291,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17291,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17291,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17291,601,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17291,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17291,606,7.091,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17292,203,20.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17292,204,5.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17292,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17292,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17292,208,135,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17292,255,73.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17292,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17292,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17292,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17292,303,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17292,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17292,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17292,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17292,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17292,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17292,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17292,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17292,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17292,606,2.081,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17293,203,27.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17293,204,8.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17293,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17293,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17293,208,190,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17293,255,64.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17293,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17293,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17293,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17293,303,2.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17293,306,326,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17293,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17293,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17293,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17293,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17293,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17293,601,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17293,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17293,606,3.297,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17294,203,18.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17294,204,13.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17294,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17294,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17294,208,201,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17294,255,67.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17294,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17294,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17294,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17294,303,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17294,306,301,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17294,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17294,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17294,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17294,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17294,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17294,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17294,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17294,606,6.389,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17295,203,25.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17295,204,13.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17295,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17295,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17295,208,231,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17295,255,60.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17295,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17295,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17295,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17295,303,2.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17295,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17295,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17295,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17295,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17295,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17295,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17295,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17295,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17295,606,6.341,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17296,203,20.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17296,204,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17296,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17296,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17296,208,133,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17296,255,74.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17296,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17296,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17296,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17296,303,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17296,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17296,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17296,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17296,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17296,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17296,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17296,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17296,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17296,606,2.008,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17297,203,27.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17297,204,7.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17297,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17297,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17297,208,182,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17297,255,65.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17297,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17297,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17297,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17297,303,2.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17297,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17297,307,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17297,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17297,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17297,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17297,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17297,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17297,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17297,606,2.918,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17298,203,17.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17298,204,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17298,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17298,207,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17298,208,254,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17298,255,62.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17298,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17298,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17298,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17298,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17298,306,279,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17298,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17298,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17298,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17298,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17298,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17298,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17298,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17298,606,9.754,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17299,203,24.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17299,204,19.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17299,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17299,207,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17299,208,281,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17299,255,56.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17299,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17299,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17299,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17299,303,2.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17299,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17299,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17299,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17299,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17299,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17299,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17299,601,102,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17299,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17299,606,9.245,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17300,203,20.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17300,204,5.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17300,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17300,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17300,208,138,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17300,255,73.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17300,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17300,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17300,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17300,303,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17300,306,328,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17300,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17300,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17300,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17300,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17300,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17300,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17300,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17300,606,2.308,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17301,203,27.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17301,204,10.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17301,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17301,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17301,208,215,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17301,255,62.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17301,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17301,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17301,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17301,303,2.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17301,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17301,307,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17301,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17301,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17301,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17301,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17301,601,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17301,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17301,606,4.508,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17302,203,18.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17302,204,14.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17302,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17302,207,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17302,208,208,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17302,255,66.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17302,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17302,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17302,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17302,303,1.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17302,306,308,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17302,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17302,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17302,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17302,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17302,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17302,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17302,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17302,606,6.898,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17303,203,25.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17303,204,13.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17303,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17303,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17303,208,235,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17303,255,59.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17303,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17303,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17303,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17303,303,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17303,306,336,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17303,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17303,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17303,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17303,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17303,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17303,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17303,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17303,606,6.414,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17304,203,20.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17304,204,4.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17304,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17304,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17304,208,132,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17304,255,74.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17304,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17304,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17304,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17304,303,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17304,306,342,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17304,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17304,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17304,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17304,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17304,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17304,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17304,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17304,606,1.948,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17305,203,27.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17305,204,7.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17305,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17305,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17305,208,188,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17305,255,64.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17305,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17305,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17305,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17305,303,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17305,306,354,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17305,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17305,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17305,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17305,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17305,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17305,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17305,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17305,606,3.159,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17306,203,19.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17306,204,12.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17306,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17306,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17306,208,195,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17306,255,68.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17306,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17306,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17306,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17306,303,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17306,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17306,307,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17306,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17306,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17306,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17306,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17306,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17306,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17306,606,5.813,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17307,203,25.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17307,204,11.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17307,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17307,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17307,208,215,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17307,255,61.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17307,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17307,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17307,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17307,303,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17307,306,342,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17307,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17307,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17307,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17307,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17307,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17307,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17307,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17307,606,5.32,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17308,203,20.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17308,204,6.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17308,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17308,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17308,208,143,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17308,255,73.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17308,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17308,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17308,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17308,303,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17308,306,342,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17308,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17308,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17308,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17308,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17308,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17308,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17308,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17308,606,2.413,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17309,203,26.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17309,204,7.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17309,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17309,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17309,208,183,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17309,255,64.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17309,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17309,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17309,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17309,303,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17309,306,354,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17309,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17309,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17309,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17309,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17309,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17309,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17309,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17309,606,3.111,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17310,203,19.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17310,204,13.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17310,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17310,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17310,208,203,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17310,255,66.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17310,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17310,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17310,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17310,303,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17310,306,302,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17310,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17310,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17310,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17310,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17310,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17310,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17310,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17310,606,6.401,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17311,203,25.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17311,204,12.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17311,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17311,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17311,208,219,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17311,255,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17311,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17311,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17311,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17311,303,2.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17311,306,331,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17311,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17311,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17311,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17311,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17311,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17311,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17311,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17311,606,5.572,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17312,203,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17312,204,6.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17312,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17312,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17312,208,146,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17312,255,72.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17312,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17312,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17312,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17312,303,1.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17312,306,327,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17312,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17312,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17312,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17312,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17312,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17312,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17312,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17312,606,2.673,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17313,203,26.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17313,204,8.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17313,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17313,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17313,208,192,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17313,255,64.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17313,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17313,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17313,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17313,303,2.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17313,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17313,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17313,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17313,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17313,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17313,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17313,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17313,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17313,606,3.687,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17314,203,21.26,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17314,204,16.89,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17314,205,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17314,207,0.86,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17314,208,237,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17314,255,61.86,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17314,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17314,291,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17314,301,7,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17314,303,1.55,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17314,306,189,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17314,307,69,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17314,320,4,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17314,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17314,401,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17314,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17314,601,69,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17314,605,1.145,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17314,606,8.128,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17315,203,28.48,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17315,204,21.2,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17315,205,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17315,207,1.05,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17315,208,305,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17315,255,49.65,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17315,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17315,291,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17315,301,11,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17315,303,2.24,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17315,306,292,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17315,307,79,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17315,320,3,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17315,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17315,401,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17315,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17315,601,91,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17315,605,1.444,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17315,606,10.666,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17316,203,24.07,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17316,204,5.59,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17316,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17316,207,0.96,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17316,208,147,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17316,255,70.48,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17316,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17316,291,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17316,301,7,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17316,303,1.75,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17316,306,209,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17316,307,71,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17316,320,5,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17316,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17316,401,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17316,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17316,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17316,605,0.278,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17316,606,2.532,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17317,203,32.16,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17317,204,11.68,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17317,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17317,207,1.15,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17317,208,234,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17317,255,56.33,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17317,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17317,291,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17317,301,11,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17317,303,2.36,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17317,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17317,307,85,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17317,320,4,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17317,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17317,401,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17317,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17317,601,92,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17317,605,0.631,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (17317,606,5.69,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17318,203,16.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17318,204,20.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17318,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17318,207,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17318,208,256,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17318,255,62.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17318,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17318,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17318,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17318,303,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17318,306,267,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17318,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17318,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17318,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17318,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17318,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17318,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17318,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17318,606,9.907,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17319,203,23.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17319,204,21.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17319,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17319,207,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17319,208,296,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17319,255,55.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17319,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17319,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17319,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17319,303,1.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17319,306,288,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17319,307,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17319,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17319,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17319,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17319,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17319,601,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17319,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17319,606,10.324,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17320,203,19.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17320,204,8.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17320,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17320,207,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17320,208,155,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17320,255,72.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17320,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17320,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17320,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17320,303,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17320,306,306,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17320,307,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17320,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17320,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17320,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17320,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17320,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17320,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17320,606,3.355,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17321,203,26.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17321,204,13.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17321,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17321,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17321,208,233,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17321,255,61.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17321,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17321,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17321,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17321,303,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17321,306,308,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17321,307,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17321,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17321,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17321,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17321,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17321,601,91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17321,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17321,606,5.843,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17322,203,17.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17322,204,18.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17322,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17322,207,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17322,208,243,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17322,255,63.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17322,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17322,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17322,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17322,303,1.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17322,306,281,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17322,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17322,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17322,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17322,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17322,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17322,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17322,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17322,606,9.125,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17323,203,29.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17323,204,20.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17323,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17323,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17323,208,311,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17323,255,51.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17323,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17323,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17323,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17323,303,2.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17323,306,268,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17323,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17323,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17323,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17323,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17323,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17323,601,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17323,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17323,606,9.696,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17324,203,19.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17324,204,5.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17324,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17324,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17324,208,137,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17324,255,73.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17324,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17324,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17324,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17324,303,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17324,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17324,307,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17324,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17324,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17324,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17324,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17324,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17324,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17324,606,2.335,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17325,203,34.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17325,204,10.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17325,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17325,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17325,208,238,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17325,255,56.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17325,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17325,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17325,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17325,303,2.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17325,306,287,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17325,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17325,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17325,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17325,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17325,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17325,601,111,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17325,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17325,606,4.173,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17326,203,16.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17326,204,21.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17326,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17326,207,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17326,208,262,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17326,255,62.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17326,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17326,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17326,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17326,303,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17326,306,260,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17326,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17326,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17326,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17326,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17326,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17326,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17326,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17326,606,10.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17327,203,21.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17327,204,22.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17327,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17327,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17327,208,291,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17327,255,56.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17327,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17327,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17327,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17327,303,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17327,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17327,307,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17327,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17327,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17327,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17327,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17327,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17327,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17327,606,10.51,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17328,203,19.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17328,204,9.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17328,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17328,207,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17328,208,164,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17328,255,71.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17328,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17328,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17328,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17328,303,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17328,306,298,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17328,307,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17328,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17328,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17328,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17328,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17328,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17328,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17328,606,3.883,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17329,203,23.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17329,204,14.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17329,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17329,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17329,208,231,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17329,255,62.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17329,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17329,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17329,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17329,303,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17329,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17329,307,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17329,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17329,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17329,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17329,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17329,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17329,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17329,606,6.334,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17330,203,18.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17330,204,15.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17330,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17330,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17330,208,223,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17330,255,64.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17330,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17330,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17330,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17330,303,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17330,306,307,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17330,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17330,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (17330,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17330,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17330,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17330,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17330,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17330,606,6.802,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17331,203,23.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17331,204,15.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17331,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17331,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17331,208,238,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17331,255,59.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17331,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17331,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17331,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17331,303,3.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17331,306,341,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17331,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17331,320,0,'100g',1,1,'2024-12-12','2008-01-03');
INSERT INTO `cndb_nutval` VALUES (17331,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17331,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17331,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17331,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17331,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17331,606,6.461,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17332,203,28.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17332,204,5.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17332,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17332,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17332,208,171,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17332,255,65.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17332,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17332,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17332,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17332,303,3.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17332,306,387,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17332,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17332,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (17332,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17332,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17332,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17332,601,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17332,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17332,606,2.412,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17333,203,33.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17333,204,5.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17333,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17333,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17333,208,193,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17333,255,60.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17333,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17333,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17333,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17333,303,4.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17333,306,316,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17333,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17333,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (17333,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17333,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17333,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17333,601,111,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17333,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17333,606,2.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17334,203,21.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17334,204,3.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17334,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17334,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17334,208,119,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17334,255,75.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17334,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17334,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17334,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17334,303,2.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17334,306,353,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17334,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17334,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (17334,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17334,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17334,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17334,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17334,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17334,606,1.345,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17335,203,29.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17335,204,5.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17335,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17335,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17335,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17335,255,64.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17335,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17335,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17335,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17335,303,2.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17335,306,371,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17335,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17335,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (17335,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17335,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17335,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17335,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17335,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17335,606,2.419,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17336,203,30.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17336,204,4.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17336,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17336,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17336,208,174,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17336,255,65.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17336,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17336,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17336,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17336,303,3.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17336,306,382,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17336,307,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17336,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (17336,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17336,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17336,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17336,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17336,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17336,606,1.957,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17337,203,23.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17337,204,2.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17337,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17337,207,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17337,208,122,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17337,255,73.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17337,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17337,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17337,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17337,303,2.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17337,306,390,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17337,307,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17337,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (17337,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17337,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17337,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17337,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17337,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17337,606,1.039,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17338,203,21.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17338,204,8.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17338,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17338,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17338,208,172,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17338,255,68.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17338,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17338,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17338,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17338,303,2.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17338,306,322,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17338,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17338,320,0,'100g',1,1,'2024-12-12','2002-01-02');
INSERT INTO `cndb_nutval` VALUES (17338,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17338,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17338,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17338,601,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17338,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17338,606,3.469,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17339,203,26.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17339,204,8.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17339,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17339,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17339,208,193,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17339,255,64.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17339,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17339,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17339,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17339,303,3.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17339,306,354,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17339,307,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17339,320,0,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (17339,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17339,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17339,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17339,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17339,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17339,606,4.002,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17340,203,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17340,204,3.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17340,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17340,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17340,208,167,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17340,255,64.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17340,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17340,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17340,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17340,303,3.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17340,306,404,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17340,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17340,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (17340,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17340,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17340,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17340,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17340,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17340,606,1.511,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17341,203,30.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17341,204,2.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17341,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17341,207,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17341,208,156,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17341,255,65.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17341,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17341,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17341,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17341,303,4.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17341,306,392,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17341,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17341,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (17341,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17341,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17341,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17341,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17341,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17341,606,1.037,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17342,203,30.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17342,204,3.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17342,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17342,207,1.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17342,208,162,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17342,255,64.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17342,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17342,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17342,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17342,303,4.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17342,306,392,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17342,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17342,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (17342,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17342,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17342,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17342,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17342,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17342,606,1.342,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17343,203,21.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17343,204,7.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17343,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17343,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17343,208,157,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17343,255,71.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17343,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17343,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17343,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17343,303,2.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17343,306,330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17343,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17343,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (17343,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17343,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17343,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17343,601,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17343,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17343,606,3.361,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17344,203,26.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17344,204,8.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17344,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17344,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17344,208,187,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17344,255,64.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17344,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17344,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17344,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17344,303,3.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17344,306,364,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17344,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17344,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (17344,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17344,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17344,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17344,601,98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17344,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17344,606,3.993,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17345,203,30.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17345,204,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17345,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17345,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17345,208,150,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17345,255,67.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17345,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17345,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17345,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17345,303,4.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17345,306,398,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17345,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17345,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17345,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17345,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17345,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17345,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17345,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17345,606,1.351,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17346,203,36.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17346,204,3.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17346,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17346,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17346,208,191,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17346,255,59.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17346,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17346,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17346,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17346,303,5.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17346,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17346,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17346,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (17346,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17346,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17346,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17346,601,113,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17346,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17346,606,2.239,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17347,203,29.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17347,204,2.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17347,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17347,207,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17347,208,149,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17347,255,67.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17347,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17347,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17347,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17347,303,4.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17347,306,434,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17347,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17347,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (17347,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17347,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17347,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17347,601,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17347,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17347,606,1.142,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17348,203,31.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17348,204,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17348,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17348,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17348,208,152,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17348,255,66.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17348,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17348,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17348,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17348,303,4.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17348,306,377,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17348,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17348,320,0,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (17348,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17348,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17348,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17348,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17348,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17348,606,1.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17349,203,20.18,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17349,204,4.65,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17349,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17349,207,1.03,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17349,208,123,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17349,255,74.7,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17349,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17349,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17349,301,16,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17349,303,1,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17349,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17349,307,112,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17349,320,0,'100g',1,1,'2024-12-12','2012-01-05');
INSERT INTO `cndb_nutval` VALUES (17349,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17349,401,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17349,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17349,601,65,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17349,605,0.151,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17349,606,1.672,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17350,203,19.58,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17350,204,7.42,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17350,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17350,207,1,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17350,208,145,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17350,255,72.57,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17350,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17350,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17350,301,15,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17350,303,0.99,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17350,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17350,307,108,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17350,320,2,'100g',2,1,'2024-12-12','2016-01-03');
INSERT INTO `cndb_nutval` VALUES (17350,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17350,401,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17350,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17350,601,65,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17350,605,0.33,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17350,606,2.948,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17351,203,20.37,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17351,204,4.47,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17351,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17351,207,1.01,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17351,208,122,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17351,255,75.38,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17351,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17351,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17351,301,17,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17351,303,3.08,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17351,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17351,307,98,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17351,320,0,'100g',1,1,'2024-12-12','2012-01-05');
INSERT INTO `cndb_nutval` VALUES (17351,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17351,401,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17351,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17351,601,59,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17351,605,0.142,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17351,606,1.7,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17352,203,19.78,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17352,204,7.2,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17352,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17352,207,0.98,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17352,208,144,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17352,255,73.25,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17352,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (17352,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17352,301,16,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17352,303,2.95,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17352,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17352,307,95,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17352,320,2,'100g',1,1,'2024-12-12','2012-01-10');
INSERT INTO `cndb_nutval` VALUES (17352,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17352,401,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17352,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17352,601,60,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17352,605,0.318,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17352,606,2.951,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17353,203,17.14,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17353,204,20.71,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17353,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17353,207,0.82,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17353,208,255,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17353,255,61.46,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17353,269,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17353,291,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17353,301,9,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17353,303,1.41,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17353,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17353,307,77,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17353,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17353,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17353,401,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17353,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17353,601,73,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (17353,605,1.625,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17353,606,9.926,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (17354,203,8.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17354,204,62.44,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17354,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17354,207,0.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17354,208,596,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17354,255,29.57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17354,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17354,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17354,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17354,303,1.39,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17354,306,198,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17354,307,52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17354,320,34,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (17354,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17354,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17354,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17354,601,82,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17354,605,3.611,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17354,606,26.327,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17355,203,4.63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17355,204,68.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17355,205,1.26,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17355,207,0.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17355,208,640,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17355,255,25.36,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17355,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17355,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17355,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17355,303,0.72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17355,306,119,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17355,307,34,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17355,320,46,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (17355,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17355,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17355,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17355,601,75,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17355,605,4.095,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17355,606,30.741,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17356,203,3.87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17356,204,76.16,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17356,205,0.55,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17356,207,0.25,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17356,208,703,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17356,255,19.17,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17356,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17356,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17356,301,3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17356,303,0.47,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17356,306,93,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17356,307,28,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17356,320,44,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (17356,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17356,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17356,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17356,601,78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17356,605,4.049,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17356,606,32.369,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17357,203,14.03,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17357,204,10.92,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17357,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17357,207,3.39,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17357,208,154,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17357,255,73.11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17357,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17357,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17357,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17357,303,1.21,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17357,306,258,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17357,307,101,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17357,320,2,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (17357,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17357,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17357,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (17357,601,2559,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17357,605,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17357,606,1.365,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17358,203,11.33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17358,204,8.03,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17358,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17358,207,2.52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17358,208,118,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17358,255,78.52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17358,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17358,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17358,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17358,303,1.07,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17358,306,307,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17358,307,117,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17358,320,3,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (17358,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17358,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17358,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17358,601,2100,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17358,605,0.025,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17358,606,1.035,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17359,203,28.16,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17359,204,17.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17359,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17359,207,0.75,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17359,208,270,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17359,255,54.77,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17359,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17359,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17359,301,25,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17359,303,1.89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17359,306,183,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17359,307,86,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17359,320,5,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (17359,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17359,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17359,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17359,601,102,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17359,605,0.475,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17359,606,6.004,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17360,203,18.31,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17360,204,7.98,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17360,205,1.02,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17360,207,1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17360,208,149,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17360,255,71.69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17360,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17360,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17360,301,13,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17360,303,1.15,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17360,306,293,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17360,307,107,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17360,320,9,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (17360,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17360,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17360,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17360,601,65,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17360,605,0.22,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17360,606,2.738,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17361,203,23.69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17361,204,5.27,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17361,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17361,207,1.2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17361,208,142,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17361,255,70.59,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17361,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17361,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17361,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17361,303,1.73,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17361,306,339,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17361,307,61,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17361,320,5,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (17361,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17361,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17361,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17361,601,74,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17361,605,0.139,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17361,606,1.769,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17362,203,5.24,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17362,204,72.28,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17362,205,0.62,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17362,207,0.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17362,208,674,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17362,255,21.77,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17362,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17362,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17362,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17362,303,0.7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17362,306,164,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17362,307,43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17362,320,60,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (17362,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17362,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17362,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17362,601,66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17362,605,4.419,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17362,606,31.441,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17363,203,21.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17363,204,3.83,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17363,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17363,207,1.24,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17363,208,121,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17363,255,74.58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17363,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17363,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17363,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17363,303,1.52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17363,306,346,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17363,307,62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17363,320,5,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (17363,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17363,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17363,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17363,601,65,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17363,605,0.077,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17363,606,1.265,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17364,203,19.78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17364,204,3.56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17364,205,0.18,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17364,207,1.41,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17364,208,112,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17364,255,75.07,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17364,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17364,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17364,301,9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17364,303,14.7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17364,306,271,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17364,307,199,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17364,320,85,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17364,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17364,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17364,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (17364,601,508,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17364,605,0.044,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17364,606,0.92,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17365,203,27.88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17365,204,13.6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17365,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17365,207,0.69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17365,208,234,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17365,255,60.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17365,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17365,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17365,301,9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17365,303,1.21,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17365,306,186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17365,307,54,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17365,320,10,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17365,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17365,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17365,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17365,601,78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17365,605,0.397,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17365,606,5.056,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17366,203,21.72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17366,204,10.31,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17366,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17366,207,0.98,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17366,208,180,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17366,255,69.49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17366,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17366,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17366,301,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17366,303,0.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17366,306,303,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17366,307,87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17366,320,9,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17366,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17366,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17366,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17366,601,58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17366,605,0.285,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17366,606,3.918,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17367,203,15.21,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17367,204,2.54,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17367,205,0.03,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17367,207,1.19,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17367,208,84,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17367,255,81.02,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17367,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17367,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17367,301,8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17367,303,6.6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17367,306,231,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17367,307,168,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17367,320,61,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17367,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17367,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17367,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17367,601,369,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17367,605,0.046,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17367,606,0.768,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17368,203,25.8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17368,204,6.56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17368,205,1.48,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17368,207,1.56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17368,208,168,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17368,255,64.6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17368,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17368,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17368,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17368,303,5.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17368,306,287,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17368,307,59,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17368,320,19872,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17368,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17368,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17368,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17368,601,566,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17368,605,0.192,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17368,606,1.959,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17369,203,20.7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17369,204,4.92,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17369,205,2.22,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17369,207,1.36,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17369,208,136,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17369,255,70.8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17369,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17369,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17369,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17369,303,4.6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17369,306,285,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17369,307,59,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17369,320,15434,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17369,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17369,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17369,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17369,601,386,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17369,605,0.146,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17369,606,1.514,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17370,203,22.6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17370,204,11.34,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17370,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17370,207,1.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17370,208,192,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17370,255,66.59,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17370,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17370,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17370,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17370,303,1.27,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17370,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17370,307,34,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17370,320,8,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17370,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17370,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17370,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17370,601,71,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17370,605,0.38,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17370,606,4.378,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17371,203,20.33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17371,204,12.41,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17371,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17371,207,0.86,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17371,208,193,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17371,255,69.29,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17371,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17371,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17371,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17371,303,1.04,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17371,306,281,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17371,307,57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17371,320,8,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17371,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17371,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17371,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17371,601,63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17371,605,0.439,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17371,606,4.848,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17372,203,26.26,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17372,204,6.21,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17372,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17372,207,0.94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17372,208,161,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17372,255,66.65,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17372,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17372,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17372,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17372,303,4.94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17372,306,187,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17372,307,67,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17372,320,4,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17372,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17372,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17372,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (17372,601,186,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17372,605,0.162,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17372,606,2.001,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17373,203,18.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17373,204,3.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17373,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17373,207,1.13,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17373,208,105,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17373,255,77.84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17373,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17373,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17373,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17373,303,3.29,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17373,306,277,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17373,307,94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17373,320,5,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17373,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17373,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17373,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17373,601,119,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17373,605,0.078,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17373,606,0.995,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17374,203,21.13,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17374,204,6.61,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17374,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17374,207,2.58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17374,208,144,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17374,255,72.6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17374,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17374,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17374,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17374,303,1.06,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17374,306,354,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17374,307,52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17374,320,8,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17374,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17374,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17374,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (17374,601,462,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17374,605,0.172,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17374,606,2.342,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17375,203,11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17375,204,3.16,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17375,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17375,207,1.35,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17375,208,72,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17375,255,85.78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17375,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17375,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17375,301,2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17375,303,0.54,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17375,306,302,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17375,307,39,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17375,320,5,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17375,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17375,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17375,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17375,601,160,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17375,605,0.162,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17375,606,1.602,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17376,203,21.01,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17376,204,4.56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17376,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17376,207,1.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17376,208,125,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17376,255,73.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17376,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17376,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17376,301,8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17376,303,1.69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17376,306,265,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17376,307,118,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17376,320,22,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17376,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17376,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17376,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (17376,601,523,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17376,605,0.039,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17376,606,1.461,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17377,203,11.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17377,204,2.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17377,205,0.14,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17377,207,1.08,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17377,208,68,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17377,255,85.01,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17377,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17377,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17377,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17377,303,1.14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17377,306,265,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17377,307,119,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17377,320,10,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17377,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17377,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17377,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17377,601,393,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17377,605,0.025,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17377,606,0.793,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17378,203,17.51,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17378,204,22.04,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17378,205,0.86,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17378,207,0.84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17378,208,272,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17378,255,58.74,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17378,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17378,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17378,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17378,303,1.74,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17378,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17378,307,52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17378,320,1,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17378,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17378,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17378,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (17378,601,126,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17378,605,0.746,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17378,606,7.341,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17379,203,14.27,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17379,204,18.61,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17379,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17379,207,0.77,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17379,208,225,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17379,255,66.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17379,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17379,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17379,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17379,303,1.25,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17379,306,207,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17379,307,77,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17379,320,5,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17379,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17379,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17379,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17379,601,88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17379,605,0.658,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17379,606,5.896,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17380,203,25.29,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17380,204,6.44,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17380,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17380,207,1.17,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17380,208,159,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17380,255,68.14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17380,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17380,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17380,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17380,303,1.71,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17380,306,369,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17380,307,62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17380,320,2,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17380,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17380,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17380,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17380,601,79,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17380,605,0.179,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17380,606,2.035,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17381,203,20.93,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17381,204,4.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17381,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17381,207,1.14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17381,208,121,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17381,255,74.43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17381,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17381,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17381,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17381,303,1.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17381,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17381,307,60,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17381,320,3,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17381,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17381,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17381,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17381,601,64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17381,605,0.114,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17381,606,1.37,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17382,203,31.06,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17382,204,14.56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17382,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17382,207,1.18,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17382,208,255,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17382,255,55.36,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17382,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17382,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17382,301,40,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17382,303,1.89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17382,306,213,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17382,307,59,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17382,320,8,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17382,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17382,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17382,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17382,601,99,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17382,605,0.523,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17382,606,5.476,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17383,203,20.62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17383,204,9.08,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17383,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17383,207,1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17383,208,164,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17383,255,71.98,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17383,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17383,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17383,301,27,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17383,303,1.18,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17383,306,321,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17383,307,82,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17383,320,6,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17383,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17383,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17383,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17383,601,59,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17383,605,0.299,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17383,606,2.769,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17384,203,27.94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17384,204,4.81,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17384,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17384,207,1.44,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17384,208,155,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17384,255,66.43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17384,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17384,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17384,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17384,303,2.12,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17384,306,433,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17384,307,59,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17384,320,2,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17384,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17384,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17384,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17384,601,94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17384,605,0.166,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17384,606,1.799,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17385,203,20.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17385,204,3.81,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17385,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17385,207,1.35,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17385,208,116,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17385,255,74.35,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17385,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17385,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17385,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17385,303,1.63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17385,306,381,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17385,307,49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17385,320,1,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (17385,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17385,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17385,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17385,601,69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17385,605,0.191,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17385,606,1.26,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17386,203,25.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17386,204,6.7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17386,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17386,207,1.1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17386,208,162,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17386,255,68.3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17386,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17386,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17386,301,8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17386,303,1.6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17386,306,345,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17386,307,76,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17386,320,5,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17386,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17386,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17386,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17386,601,78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17386,605,0.25,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17386,606,2.514,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17387,203,20.86,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17387,204,5.32,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17387,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17387,207,1.04,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17387,208,131,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17387,255,73.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17387,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17387,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17387,301,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17387,303,1.54,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17387,306,356,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17387,307,75,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17387,320,4,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17387,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17387,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17387,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17387,601,66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17387,605,0.217,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17387,606,1.96,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17388,203,28.99,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17388,204,4.49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17388,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17388,207,1.3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17388,208,156,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17388,255,66.69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17388,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17388,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17388,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17388,303,2.05,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17388,306,355,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17388,307,57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17388,320,1,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17388,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17388,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17388,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17388,601,86,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17388,605,0.098,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17388,606,1.581,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17389,203,21.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17389,204,3.77,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17389,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17389,207,1.17,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17389,208,120,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17389,255,74.54,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17389,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17389,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17389,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17389,303,1.55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17389,306,368,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17389,307,60,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17389,320,2,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17389,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17389,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17389,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17389,601,66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17389,605,0.057,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17389,606,1.187,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17390,203,32.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17390,204,7.37,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17390,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17390,207,1.1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17390,208,196,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17390,255,60.93,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17390,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17390,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17390,301,8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17390,303,2.12,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17390,306,258,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17390,307,72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17390,320,2,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17390,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17390,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17390,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17390,601,115,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17390,605,0.217,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17390,606,2.361,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17391,203,20.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17391,204,3.35,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17391,205,0.73,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17391,207,1.02,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17391,208,115,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17391,255,74.49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17391,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17391,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17391,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17391,303,1.46,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17391,306,327,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17391,307,82,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17391,320,2,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17391,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17391,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17391,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17391,601,62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17391,605,0.089,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17391,606,1.05,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17392,203,19.84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17392,204,7.97,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17392,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17392,207,1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17392,208,151,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17392,255,72.43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17392,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17392,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17392,301,23,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17392,303,1.24,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17392,306,323,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17392,307,81,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17392,320,5,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17392,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17392,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17392,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17392,601,71,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17392,605,0.259,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17392,606,3.12,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17393,203,31.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17393,204,15.36,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17393,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17393,207,1.11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17393,208,264,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17393,255,54.64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17393,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17393,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17393,301,58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17393,303,2.28,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17393,306,289,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17393,307,97,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17393,320,8,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17393,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17393,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17393,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17393,601,121,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17393,605,0.544,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17393,606,6.085,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17394,203,25.14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17394,204,10.91,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17394,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17394,207,1.14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17394,208,199,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17394,255,64.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17394,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17394,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17394,301,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17394,303,1.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17394,306,337,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17394,307,65,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17394,320,6,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17394,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17394,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17394,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17394,601,79,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17394,605,0.257,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17394,606,3.262,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17395,203,20.2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17395,204,6.88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17395,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17395,207,0.98,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17395,208,143,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17395,255,72.9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17395,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17395,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17395,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17395,303,1.16,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17395,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17395,307,65,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17395,320,5,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17395,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17395,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17395,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17395,601,58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17395,605,0.132,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17395,606,2.125,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17396,203,24.39,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17396,204,8.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17396,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17396,207,1.13,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17396,208,173,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17396,255,66.7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17396,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17396,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17396,301,11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17396,303,1.76,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17396,306,330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17396,307,67,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17396,320,3,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17396,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17396,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17396,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17396,601,72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17396,605,0.313,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17396,606,3.196,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17397,203,20.61,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17397,204,7.12,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17397,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17397,207,0.97,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17397,208,147,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17397,255,71.67,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17397,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17397,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17397,301,8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17397,303,1.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17397,306,334,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17397,307,63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17397,320,5,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17397,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17397,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17397,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17397,601,62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17397,605,0.349,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17397,606,3.044,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17398,203,27.43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17398,204,10.7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17398,205,0.41,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17398,207,1.25,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17398,208,208,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17398,255,60.21,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17398,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17398,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17398,301,42,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17398,303,1.88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17398,306,367,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17398,307,84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17398,320,6,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17398,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17398,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17398,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17398,601,85,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17398,605,0.375,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17398,606,4.039,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17399,203,25.08,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17399,204,10.13,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17399,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17399,207,1.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17399,208,192,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17399,255,64.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17399,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17399,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17399,301,14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17399,303,1.47,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17399,306,334,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17399,307,80,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17399,320,1,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17399,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17399,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17399,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17399,601,71,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17399,605,0.415,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17399,606,3.503,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17400,203,26.31,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17400,204,6.35,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17400,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17400,207,1.26,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17400,208,162,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17400,255,67.56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17400,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17400,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17400,301,10,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17400,303,2.03,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17400,306,373,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17400,307,67,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17400,320,2,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17400,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17400,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17400,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17400,601,78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17400,605,0.185,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17400,606,1.901,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17401,203,20.48,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17401,204,32.63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17401,205,0.14,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17401,207,0.52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17401,208,376,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17401,255,47.82,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17401,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17401,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17401,301,8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17401,303,1.11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17401,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17401,307,51,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17401,320,24,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17401,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17401,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17401,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17401,601,76,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17401,605,1.686,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17401,606,13.534,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17402,203,16.17,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17402,204,30.14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17402,205,0.27,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17402,207,0.74,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17402,208,337,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17402,255,54.39,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17402,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17402,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17402,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17402,303,0.84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17402,306,240,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17402,307,69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17402,320,20,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17402,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17402,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17402,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17402,601,64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17402,605,1.482,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17402,606,12.704,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17403,203,29.59,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17403,204,14.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17403,205,0.04,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17403,207,1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17403,208,247,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17403,255,56.87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17403,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17403,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17403,301,8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17403,303,1.99,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17403,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17403,307,69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17403,320,8,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17403,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17403,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17403,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17403,601,111,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17403,605,0.654,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17403,606,5.405,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17404,203,18.39,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17404,204,12.12,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17404,205,0.73,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17404,207,0.93,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17404,208,186,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17404,255,67.84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17404,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17404,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17404,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17404,303,1.34,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17404,306,299,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17404,307,76,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17404,320,7,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17404,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17404,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17404,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17404,601,64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17404,605,0.577,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17404,606,4.861,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17405,203,24.26,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17405,204,12.76,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17405,205,0.04,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17405,207,1.15,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17405,208,212,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17405,255,63.15,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17405,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17405,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17405,301,10,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17405,303,1.93,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17405,306,353,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17405,307,65,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17405,320,7,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17405,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17405,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17405,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17405,601,78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17405,605,0.59,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17405,606,4.743,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17406,203,21.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17406,204,27.11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17406,205,0.41,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17406,207,0.95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17406,208,332,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17406,255,50.12,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17406,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17406,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17406,301,31,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17406,303,1.62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17406,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17406,307,73,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17406,320,19,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17406,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17406,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17406,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17406,601,81,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17406,605,1.437,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17406,606,11.272,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17407,203,21.13,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17407,204,20.98,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17407,205,0.1,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17407,207,0.89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17407,208,274,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17407,255,58.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17407,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17407,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17407,301,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17407,303,1.44,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17407,306,306,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17407,307,69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17407,320,16,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17407,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17407,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17407,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17407,601,76,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17407,605,1.146,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17407,606,8.762,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17408,203,16.56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17408,204,22.9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17408,205,0.2,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17408,207,0.83,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17408,208,273,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17408,255,60.04,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17408,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17408,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17408,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17408,303,1.29,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17408,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17408,307,63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17408,320,15,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17408,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17408,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17408,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17408,601,69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17408,605,1.205,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17408,606,9.639,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17409,203,28.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17409,204,4.57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17409,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17409,207,1.3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17409,208,157,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17409,255,66.64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17409,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17409,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17409,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17409,303,2.05,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17409,306,355,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17409,307,57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17409,320,1,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17409,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17409,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17409,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17409,601,86,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17409,605,0.103,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17409,606,1.614,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17410,203,21.44,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17410,204,3.99,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17410,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17410,207,1.17,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17410,208,122,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17410,255,74.37,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17410,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17410,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17410,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17410,303,1.55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17410,306,368,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17410,307,60,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17410,320,2,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17410,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17410,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17410,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17410,601,66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17410,605,0.071,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17410,606,1.289,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17411,203,28.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17411,204,21.43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17411,205,0.03,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17411,207,1.01,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17411,208,307,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17411,255,51.28,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17411,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17411,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17411,301,52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17411,303,2.14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17411,306,276,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17411,307,91,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17411,320,13,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17411,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17411,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17411,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17411,601,116,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17411,605,0.948,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17411,606,8.74,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17412,203,17.43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17412,204,17.9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17412,205,0.14,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17412,207,0.88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17412,208,231,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17412,255,64.7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17412,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17412,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17412,301,20,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17412,303,1.14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17412,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17412,307,73,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17412,320,11,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17412,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17412,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17412,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17412,601,72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17412,605,0.849,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17412,606,7.514,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17413,203,21.45,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17413,204,22.33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17413,205,0.05,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17413,207,0.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17413,208,287,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17413,255,56.45,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17413,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17413,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17413,301,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17413,303,1.33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17413,306,305,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17413,307,61,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17413,320,14,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17413,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17413,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17413,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17413,601,78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17413,605,1.014,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17413,606,8.431,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17414,203,16.9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17414,204,20.36,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17414,205,0.2,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17414,207,0.82,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17414,208,252,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17414,255,62.47,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17414,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17414,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17414,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17414,303,1.05,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17414,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17414,307,58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17414,320,13,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17414,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17414,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17414,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17414,601,61,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17414,605,0.951,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17414,606,8.211,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17415,203,26.79,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17415,204,23.86,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17415,205,0.05,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17415,207,1.02,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17415,208,322,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17415,255,50.14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17415,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17415,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17415,301,34,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17415,303,1.74,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17415,306,207,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17415,307,57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17415,320,15,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17415,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17415,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17415,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17415,601,95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17415,605,1.137,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17415,606,9.596,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17416,203,17.02,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17416,204,22.84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17416,205,0.23,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17416,207,0.83,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17416,208,275,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17416,255,61.18,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17416,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17416,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17416,301,22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17416,303,1.06,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17416,306,274,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17416,307,71,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17416,320,15,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17416,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17416,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17416,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17416,601,63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17416,605,1.139,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17416,606,9.099,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17417,203,20.88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17417,204,23.39,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17417,205,0.03,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17417,207,0.91,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17417,208,294,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17417,255,55.93,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17417,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17417,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17417,301,12,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17417,303,1.41,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17417,306,299,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17417,307,72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17417,320,11,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17417,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17417,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17417,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17417,601,72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17417,605,1.236,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17417,606,9.332,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17418,203,27.87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17418,204,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17418,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17418,207,1.44,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17418,208,157,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17418,255,66.31,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17418,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17418,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17418,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17418,303,2.11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17418,306,432,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17418,307,59,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17418,320,2,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17418,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17418,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17418,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17418,601,94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17418,605,0.177,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17418,606,1.882,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17419,203,23.56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17419,204,11.2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17419,205,0.01,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17419,207,1.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17419,208,195,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17419,255,64.76,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17419,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17419,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17419,301,11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17419,303,1.74,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17419,306,323,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17419,307,67,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17419,320,5,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17419,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17419,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17419,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17419,601,72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17419,605,0.487,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17419,606,4.41,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17420,203,19.88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17420,204,9.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17420,205,0.05,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17420,207,0.94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17420,208,169,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17420,255,69.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17420,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17420,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17420,301,8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17420,303,1.36,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17420,306,324,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17420,307,62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17420,320,7,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17420,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17420,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17420,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17420,601,62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17420,605,0.517,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17420,606,4.305,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17421,203,23.41,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17421,204,12.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17421,205,0.03,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17421,207,1.08,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17421,208,208,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17421,255,63.79,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17421,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17421,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17421,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17421,303,1.64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17421,306,349,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17421,307,61,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17421,320,7,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17421,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17421,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17421,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17421,601,79,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17421,605,0.573,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17421,606,4.788,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17422,203,20.93,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17422,204,4.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17422,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17422,207,1.14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17422,208,121,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17422,255,74.43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17422,269,NULL,'100g',NULL,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17422,291,NULL,'100g',NULL,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17422,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17422,303,1.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17422,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17422,307,60,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17422,320,3,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (17422,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17422,401,NULL,'100g',NULL,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17422,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17422,601,64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17422,605,0.114,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17422,606,1.37,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17423,203,20.43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17423,204,4.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17423,205,0.01,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17423,207,1.34,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17423,208,120,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17423,255,74.04,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17423,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17423,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17423,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17423,303,1.62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17423,306,379,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17423,307,49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17423,320,2,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (17423,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17423,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17423,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17423,601,69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17423,605,0.171,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17423,606,2.11,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17424,203,25.83,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17424,204,11.78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17424,205,1.51,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17424,207,1.02,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17424,208,215,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17424,255,59.87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17424,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17424,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17424,301,18,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17424,303,1.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17424,306,245,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17424,307,146,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17424,320,0,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (17424,328,1.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17424,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17424,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17424,601,77,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17424,605,0.448,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17424,606,4.368,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17425,203,31.89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17425,204,2.63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17425,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17425,207,1.45,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17425,208,151,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17425,255,65.32,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17425,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17425,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17425,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17425,303,1.39,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17425,306,323,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17425,307,88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17425,320,0,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (17425,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17425,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17425,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17425,601,72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17425,605,0.114,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17425,606,1.012,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17426,203,22.07,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17426,204,2.07,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17426,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17426,207,1.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17426,208,107,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17426,255,75.2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17426,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17426,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17426,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17426,303,0.81,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17426,306,273,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17426,307,86,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17426,320,0,'100g',2,1,'2024-12-12','2016-01-03');
INSERT INTO `cndb_nutval` VALUES (17426,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17426,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17426,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17426,601,56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17426,605,0.09,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17426,606,0.805,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17427,203,29.75,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17427,204,4.44,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17427,205,0.07,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17427,207,1.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17427,208,159,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17427,255,64.65,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17427,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17427,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17427,301,13,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17427,303,0.79,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17427,306,239,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17427,307,85,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17427,320,0,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (17427,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17427,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17427,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17427,601,78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17427,605,0.188,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17427,606,1.742,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17428,203,19.77,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17428,204,1.64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17428,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17428,207,0.98,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17428,208,94,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17428,255,77.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17428,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17428,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17428,301,11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17428,303,1.19,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17428,306,163,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17428,307,109,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17428,320,0,'100g',2,1,'2024-12-12','2016-01-03');
INSERT INTO `cndb_nutval` VALUES (17428,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17428,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17428,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17428,601,62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17428,605,0.074,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17428,606,0.639,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17429,203,29.12,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17429,204,4.51,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17429,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17429,207,0.97,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17429,208,157,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17429,255,63.28,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17429,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17429,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17429,301,21,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17429,303,2.06,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17429,306,205,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17429,307,90,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17429,320,0,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (17429,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17429,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17429,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17429,601,92,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17429,605,0.163,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17429,606,1.658,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17430,203,27.33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17430,204,5.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17430,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17430,207,0.95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17430,208,159,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17430,255,66.44,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17430,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17430,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17430,301,21,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17430,303,1.65,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17430,306,245,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17430,307,113,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17430,320,0,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (17430,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17430,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17430,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17430,601,77,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17430,605,0.221,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17430,606,2.092,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17431,203,8.85,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17431,204,51.6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17431,205,0.89,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17431,207,0.47,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17431,208,503,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17431,255,38.19,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17431,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17431,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17431,301,31,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17431,303,0.73,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17431,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17431,307,89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17431,320,0,'100g',2,1,'2024-12-12','2016-01-03');
INSERT INTO `cndb_nutval` VALUES (17431,328,5.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17431,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17431,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17431,601,86,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17431,605,2.243,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17431,606,19.082,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17432,203,15.28,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17432,204,53.23,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17432,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17432,207,0.6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17432,208,540,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17432,255,32.69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17432,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17432,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17432,301,58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17432,303,1.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17432,306,152,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17432,307,103,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17432,320,0,'100g',2,1,'2024-12-12','2016-01-03');
INSERT INTO `cndb_nutval` VALUES (17432,328,3.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17432,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17432,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17432,601,85,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17432,605,2.051,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17432,606,17.754,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17433,203,12.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17433,204,43.75,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17433,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17433,207,0.66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17433,208,444,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17433,255,44.47,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17433,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17433,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17433,301,30,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17433,303,0.87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17433,306,179,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17433,307,89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17433,320,0,'100g',2,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (17433,328,3.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17433,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17433,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17433,601,83,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17433,605,1.734,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17433,606,14.235,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17434,203,11.16,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17434,204,50.17,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17434,205,2.11,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17434,207,0.57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17434,208,505,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17434,255,35.99,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17434,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17434,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17434,301,43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17434,303,1.15,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17434,306,155,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17434,307,87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17434,320,0,'100g',2,1,'2024-12-12','2016-01-03');
INSERT INTO `cndb_nutval` VALUES (17434,328,4.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17434,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17434,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17434,601,82,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17434,605,1.671,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17434,606,16.316,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17435,203,19.28,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17435,204,3.3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17435,205,0,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17435,207,0.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17435,208,107,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17435,255,75.85,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17435,269,0,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17435,291,0,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17435,301,12,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17435,303,1.17,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17435,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17435,307,107,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17435,320,0,'100g',2,1,'2024-12-12','2016-01-03');
INSERT INTO `cndb_nutval` VALUES (17435,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17435,401,0,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17435,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17435,601,63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17435,605,0.139,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17435,606,1.176,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17436,203,27.94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17436,204,7.77,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17436,205,0.11,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17436,207,0.94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17436,208,182,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17436,255,61.3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17436,269,0,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17436,291,0,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17436,301,22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17436,303,2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17436,306,201,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17436,307,90,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17436,320,0,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (17436,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17436,401,0,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17436,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17436,601,92,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17436,605,0.276,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17436,606,2.712,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17437,203,28.04,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17437,204,9.48,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17437,205,0.16,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17437,207,1.03,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17437,208,198,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17437,255,61.41,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17437,269,0,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17437,291,0,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17437,301,17,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17437,303,0.82,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17437,306,229,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17437,307,86,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17437,320,0,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (17437,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17437,401,0,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17437,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17437,601,79,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17437,605,0.369,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17437,606,3.378,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17438,203,25.72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17438,204,10.57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17438,205,0.15,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17438,207,0.91,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17438,208,199,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17438,255,62.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17438,269,0,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17438,291,0,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17438,301,24,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17438,303,1.59,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17438,306,235,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17438,307,111,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17438,320,0,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (17438,328,1.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17438,401,0,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17438,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17438,601,78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (17438,605,0.396,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17438,606,3.715,'100g',3,1,'2015-01-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17439,203,28.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17439,204,8.35,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17439,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17439,207,1.17,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17439,208,190,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17439,255,63.87,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17439,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17439,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17439,301,2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17439,303,2.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17439,306,287,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17439,307,70,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17439,320,2,'100g',2,1,'2024-12-12','2014-01-10');
INSERT INTO `cndb_nutval` VALUES (17439,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17439,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17439,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17439,601,107,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17439,605,0.413,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17439,606,3.224,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17440,203,30.73,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17440,204,5.63,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17440,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17440,207,0.9,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17440,208,174,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17440,255,64.87,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17440,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17440,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17440,301,5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17440,303,2.02,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17440,306,192,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17440,307,86,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17440,320,2,'100g',2,1,'2024-12-12','2014-01-10');
INSERT INTO `cndb_nutval` VALUES (17440,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17440,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17440,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17440,601,111,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17440,605,0.366,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17440,606,2.241,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17441,203,22.49,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17441,204,3.53,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17441,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17441,207,0.96,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17441,208,122,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17441,255,74.83,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17441,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17441,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17441,301,4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17441,303,1.58,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17441,306,227,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17441,307,93,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17441,320,2,'100g',2,1,'2024-12-12','2014-01-10');
INSERT INTO `cndb_nutval` VALUES (17441,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17441,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17441,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17441,601,54,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17441,605,0.171,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17441,606,1.269,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17442,203,30.97,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17442,204,6.71,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17442,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17442,207,1.49,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17442,208,184,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17442,255,62.62,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17442,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17442,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17442,301,2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17442,303,2.52,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17442,306,231,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17442,307,61,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17442,320,2,'100g',2,1,'2024-12-12','2014-01-10');
INSERT INTO `cndb_nutval` VALUES (17442,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17442,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17442,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17442,601,111,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17442,605,0.229,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17442,606,2.084,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17443,203,23.42,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17443,204,4.73,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17443,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17443,207,1.09,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17443,208,136,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17443,255,72.45,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17443,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17443,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17443,301,2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17443,303,2.27,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17443,306,311,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17443,307,73,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17443,320,2,'100g',2,1,'2024-12-12','2014-01-10');
INSERT INTO `cndb_nutval` VALUES (17443,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17443,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17443,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17443,601,76,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17443,605,0.217,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17443,606,1.857,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17444,203,22.28,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17444,204,5.24,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17444,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17444,207,1.05,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17444,208,136,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17444,255,72.94,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17444,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17444,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17444,301,2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17444,303,1.88,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17444,306,231,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17444,307,83,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17444,320,3,'100g',2,1,'2024-12-12','2014-01-10');
INSERT INTO `cndb_nutval` VALUES (17444,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17444,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17444,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17444,601,61,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17444,605,0.307,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17444,606,2.277,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17445,203,32.08,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17445,204,9.59,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17445,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17445,207,1.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17445,208,215,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17445,255,58.24,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17445,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17445,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17445,301,4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17445,303,2.55,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17445,306,308,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17445,307,80,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17445,320,2,'100g',2,1,'2024-12-12','2014-01-10');
INSERT INTO `cndb_nutval` VALUES (17445,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17445,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17445,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17445,601,117,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17445,605,0.636,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17445,606,4.359,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17446,203,23.11,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17446,204,4.33,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17446,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17446,207,1.01,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17446,208,131,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17446,255,73.02,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17446,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17446,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17446,301,3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17446,303,2.25,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17446,306,238,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17446,307,77,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17446,320,3,'100g',2,1,'2024-12-12','2014-01-10');
INSERT INTO `cndb_nutval` VALUES (17446,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17446,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17446,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17446,601,76,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17446,605,0.2,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17446,606,1.774,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17447,203,26.52,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17447,204,7.63,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17447,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17447,207,1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17447,208,175,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17447,255,66.02,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17447,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17447,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17447,301,7,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17447,303,1.94,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17447,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17447,307,72,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17447,320,3,'100g',2,1,'2024-12-12','2014-01-10');
INSERT INTO `cndb_nutval` VALUES (17447,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17447,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17447,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17447,601,97,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17447,605,0.417,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17447,606,3.54,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17448,203,28.01,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17448,204,14.64,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17448,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17448,207,1.02,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17448,208,244,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17448,255,57.93,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17448,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17448,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17448,301,6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17448,303,2.63,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17448,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17448,307,67,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17448,320,4,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17448,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17448,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17448,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17448,601,96,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17448,605,0.899,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17448,606,6.802,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17449,203,16.9,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17449,204,52.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17449,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17449,207,0.75,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17449,208,538,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17449,255,27.09,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17449,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17449,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17449,301,12,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17449,303,1.98,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17449,306,207,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17449,307,58,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17449,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17449,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17449,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17449,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17449,601,81,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17449,605,4.063,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17449,606,26.8,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17450,203,12.59,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17450,204,48.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17450,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17450,207,0.56,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17450,208,487,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17450,255,38.41,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17450,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17450,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17450,301,10,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17450,303,1.08,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17450,306,149,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17450,307,69,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17450,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17450,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17450,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17450,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17450,601,71,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17450,605,3.564,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17450,606,23.892,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17451,203,13.81,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17451,204,54.72,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17451,205,1.55,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17451,207,0.67,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17451,208,554,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17451,255,29.25,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17451,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17451,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17451,301,8,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17451,303,1.39,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17451,306,164,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17451,307,53,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17451,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17451,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17451,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17451,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17451,601,110,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17451,605,4.438,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17451,606,28.619,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17452,203,15.65,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17452,204,44.01,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17452,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17452,207,0.66,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17452,208,459,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17452,255,40.32,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17452,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17452,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17452,301,6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17452,303,0.98,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17452,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17452,307,55,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17452,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (17452,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17452,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17452,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17452,601,90,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17452,605,3.235,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17452,606,21.397,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17453,203,27.54,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17453,204,12.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17453,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17453,207,1.13,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17453,208,219,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17453,255,60.91,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17453,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17453,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17453,301,3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17453,303,2.01,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17453,306,279,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17453,307,69,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17453,320,2,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17453,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17453,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17453,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17453,601,106,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17453,605,0.725,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17453,606,5.223,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17454,203,20.97,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17454,204,11.43,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17454,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17454,207,0.98,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17454,208,187,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17454,255,67.93,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17454,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17454,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17454,301,3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17454,303,1.76,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17454,306,218,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17454,307,80,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17454,320,2,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17454,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17454,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17454,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17454,601,63,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17454,605,0.773,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17454,606,5.361,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17455,203,29.52,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17455,204,9.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17455,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17455,207,0.89,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17455,208,204,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17455,255,61.85,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17455,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17455,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17455,301,6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17455,303,2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17455,306,192,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17455,307,84,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17455,320,2,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17455,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17455,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17455,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17455,601,110,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17455,605,0.678,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17455,606,4.293,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17456,203,20.58,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17456,204,12.68,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17456,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17456,207,0.88,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17456,208,196,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17456,255,67.33,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17456,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17456,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17456,301,5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17456,303,1.47,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17456,306,210,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17456,307,87,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17456,320,2,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17456,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17456,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17456,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17456,601,59,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17456,605,0.862,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17456,606,5.862,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17457,203,30.15,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17457,204,11.64,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17457,205,0.08,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17457,207,1.14,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17457,208,226,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17457,255,54.95,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17457,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17457,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17457,301,4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17457,303,2.41,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17457,306,291,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17457,307,77,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17457,320,2,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17457,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17457,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17457,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17457,601,113,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17457,605,0.813,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17457,606,5.483,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17458,203,21.95,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17458,204,9.73,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17458,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17458,207,0.96,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17458,208,175,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17458,255,68.68,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17458,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17458,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17458,301,3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17458,303,2.09,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17458,306,225,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17458,307,75,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17458,320,2,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17458,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17458,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17458,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17458,601,76,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17458,605,0.612,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17458,606,4.464,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17459,203,30.87,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17459,204,7.02,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17459,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17459,207,1.48,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17459,208,187,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17459,255,62.38,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17459,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17459,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17459,301,2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17459,303,2.52,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17459,306,231,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17459,307,61,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17459,320,2,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17459,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17459,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17459,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17459,601,110,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17459,605,0.255,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17459,606,2.251,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17460,203,23.23,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17460,204,5.52,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17460,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17460,207,1.08,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17460,208,143,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17460,255,71.83,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17460,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17460,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17460,301,2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17460,303,2.25,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17460,306,308,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17460,307,73,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17460,320,1,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17460,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17460,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17460,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17460,601,76,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17460,605,0.277,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17460,606,2.255,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17461,203,33.17,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17461,204,11.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17461,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17461,207,1.26,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17461,208,236,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17461,255,55.36,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17461,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17461,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17461,301,10,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17461,303,2.46,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17461,306,294,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17461,307,85,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17461,320,5,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17461,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17461,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17461,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17461,601,103,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17461,605,0.622,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17461,606,5.627,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17462,203,25.95,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17462,204,9.91,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17462,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17462,207,0.98,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17462,208,193,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17462,255,64.15,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17462,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17462,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17462,301,7,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17462,303,1.92,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17462,306,227,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17462,307,71,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17462,320,3,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17462,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17462,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17462,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17462,601,97,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17462,605,0.608,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17462,606,4.743,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17463,203,25.96,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17463,204,20.77,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17463,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17463,207,0.97,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17463,208,291,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17463,255,53.33,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17463,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17463,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17463,301,7,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17463,303,2.47,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17463,306,228,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17463,307,65,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17463,320,4,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17463,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17463,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17463,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17463,601,97,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17463,605,1.431,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17463,606,10.111,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17464,203,30.9,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17464,204,16.96,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17464,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17464,207,1.19,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17464,208,276,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17464,255,51.74,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17464,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17464,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17464,301,10,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17464,303,2.37,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17464,306,281,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17464,307,82,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17464,320,4,'100g',2,1,'2024-12-12','2014-01-11');
INSERT INTO `cndb_nutval` VALUES (17464,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (17464,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17464,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (17464,601,101,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17464,605,1.09,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (17464,606,8.484,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18001,203,10.56,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18001,204,1.32,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18001,205,52.38,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18001,207,1.93,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18001,208,264,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18001,255,33.81,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18001,269,8.43,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18001,291,1.6,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18001,301,219,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18001,303,3.57,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18001,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18001,307,422,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18001,320,0,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (18001,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18001,401,0,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18001,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18001,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18001,605,0.021,'100g',3,1,'2006-01-24','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18001,606,0.36,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18002,203,11.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18002,204,1.43,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18002,205,57.39,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18002,207,1.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18002,208,287,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18002,255,28.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18002,269,9.14,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18002,291,1.8,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18002,301,15,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18002,303,4.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18002,306,116,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18002,307,457,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18002,320,0,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (18002,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18002,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18002,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18002,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18002,605,0,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18002,606,0.229,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18003,203,10.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18003,204,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18003,205,53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18003,207,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18003,208,278,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18003,255,32.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18003,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18003,291,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18003,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18003,303,3.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18003,306,68,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18003,307,505,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18003,320,33,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18003,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18003,401,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18003,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18003,601,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18003,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18003,606,0.421,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18005,203,9.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18005,204,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18005,205,55.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18005,207,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18005,208,274,'100g',3,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (18005,255,32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18005,269,5.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18005,291,2.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18005,301,19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18005,303,3.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18005,306,148,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18005,307,407,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18005,320,21,'100g',2,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (18005,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18005,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18005,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18005,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18005,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18005,606,0.274,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18006,203,10.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18006,204,1.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18006,205,59.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18006,207,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18006,208,294,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18006,255,26.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18006,269,6.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18006,291,2.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18006,301,20,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18006,303,4.09,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18006,306,163,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18006,307,370,'100g',3,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (18006,320,23,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (18006,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18006,401,0.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18006,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18006,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18006,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18006,606,0.295,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18007,203,10.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18007,204,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18007,205,53.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18007,207,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18007,208,255,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18007,255,32.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18007,269,1.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18007,291,3.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18007,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18007,303,3.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18007,306,115,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18007,307,590,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18007,320,1,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18007,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18007,401,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18007,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18007,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18007,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18007,606,0.191,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18009,203,6.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18009,204,11.03,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18009,205,53.87,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18009,207,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18009,208,338,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18009,255,26.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18009,269,3.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18009,291,1.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18009,301,49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18009,303,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18009,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18009,307,942,'100g',6,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18009,320,0,'100g',2,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (18009,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18009,401,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18009,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18009,601,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18009,605,NULL,'100g',NULL,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18009,606,1.676,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18010,203,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18010,204,15.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18010,205,63.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18010,207,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18010,208,428,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18010,255,9.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18010,269,11.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18010,291,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18010,301,179,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18010,303,2.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18010,306,163,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18010,307,1276,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18010,320,2,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (18010,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18010,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18010,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18010,601,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18010,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18010,606,3.965,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18011,203,7.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18011,204,12.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18011,205,48.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18011,207,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18011,208,335,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18011,255,28.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18011,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18011,291,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18011,301,185,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18011,303,2.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18011,306,188,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18011,307,955,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18011,320,26,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18011,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18011,401,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18011,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18011,601,4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18011,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18011,606,2.789,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18012,203,6.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18012,204,7.83,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18012,205,43.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18012,207,4.02,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18012,208,270,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18012,255,37.76,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18012,269,7.18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18012,291,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18012,301,26,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18012,303,2.13,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18012,306,159,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18012,307,828,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18012,320,0,'100g',2,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (18012,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18012,401,0.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18012,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18012,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18012,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18012,606,3.14,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18013,203,7.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18013,204,9.1,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18013,205,51.6,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18013,207,3.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18013,208,319,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18013,255,27.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18013,269,8.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18013,291,2.3,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18013,301,19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18013,303,3.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18013,306,185,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18013,307,962,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18013,320,0,'100g',2,1,'2024-12-12','2006-01-02');
INSERT INTO `cndb_nutval` VALUES (18013,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18013,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18013,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18013,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18013,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18013,606,3.648,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18014,203,6.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18014,204,10.58,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18014,205,46.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18014,207,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18014,208,307,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18014,255,33.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18014,269,7.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18014,291,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18014,301,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18014,303,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18014,306,162,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18014,307,977,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18014,320,2,'100g',2,1,'2024-12-12','2005-01-11');
INSERT INTO `cndb_nutval` VALUES (18014,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18014,401,0.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18014,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18014,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18014,605,3.444,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18014,606,2.806,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18015,203,6.79,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18015,204,11.22,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18015,205,49.05,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18015,207,3.25,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18015,208,324,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18015,255,29.69,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18015,269,8.19,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18015,291,2.8,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18015,301,27,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18015,303,2.57,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18015,306,152,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18015,307,1002,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18015,320,0,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (18015,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18015,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18015,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18015,601,0,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18015,605,0.224,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18015,606,5.514,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18016,203,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18016,204,16.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18016,205,44.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18016,207,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18016,208,353,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18016,255,28.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18016,269,2.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18016,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18016,301,235,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18016,303,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18016,306,121,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18016,307,580,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18016,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18016,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18016,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18016,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18016,601,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18016,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18016,606,4.324,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18017,203,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18017,204,5.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18017,205,47.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18017,207,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18017,208,263,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18017,255,37.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18017,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18017,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18017,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18017,303,2.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18017,306,456,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18017,307,670,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18017,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18017,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18017,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18017,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18017,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18017,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18017,606,1.366,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18019,203,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18019,204,10.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18019,205,54.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18019,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18019,208,326,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18019,255,29.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18019,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18019,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18019,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18019,303,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18019,306,134,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18019,307,302,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18019,320,106,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (18019,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18019,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18019,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18019,601,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18019,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18019,606,2.237,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18021,203,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18021,204,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18021,205,43.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18021,207,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18021,208,195,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18021,255,47.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18021,269,2.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18021,291,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18021,301,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18021,303,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18021,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18021,307,631,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18021,320,25,'100g',2,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (18021,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18021,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18021,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18021,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18021,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18021,606,0.282,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18022,203,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18022,204,12.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18022,205,69.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18022,207,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18022,208,418,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18022,255,7.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18022,269,20.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18022,291,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18022,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18022,303,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18022,306,113,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18022,307,817,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18022,320,19,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18022,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18022,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18022,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18022,601,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18022,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18022,606,3.091,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18023,203,6.59,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18023,204,9.58,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18023,205,54.46,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18023,207,2.25,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18023,208,330,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18023,255,27.11,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18023,269,16.05,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18023,291,2.3,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18023,301,135,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18023,303,1.85,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18023,306,133,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18023,307,599,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18023,320,35,'100g',1,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (18023,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18023,401,0.1,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18023,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18023,601,57,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18023,605,0.224,'100g',3,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18023,606,3.732,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18024,203,6.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18024,204,7.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18024,205,43.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18024,207,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18024,208,266,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18024,255,39.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18024,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18024,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18024,301,249,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18024,303,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18024,306,147,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18024,307,658,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18024,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18024,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18024,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18024,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18024,601,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18024,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18024,606,1.555,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18025,203,8.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18025,204,3.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18025,205,49.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18025,207,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18025,208,260,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18025,255,35.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18025,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18025,291,5.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18025,301,43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18025,303,2.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18025,306,177,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18025,307,538,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18025,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18025,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18025,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18025,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18025,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18025,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18025,606,0.916,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18027,203,9.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18027,204,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18027,205,47.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18027,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18027,208,287,'100g',3,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (18027,255,34.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18027,269,1.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18027,291,2.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18027,301,93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18027,303,3.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18027,306,115,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18027,307,380,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18027,320,63,'100g',2,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (18027,328,0.4,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18027,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18027,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18027,601,51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18027,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18027,606,1.593,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18028,203,10.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18028,204,6.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18028,205,52.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18028,207,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18028,208,315,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18028,255,28.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18028,269,1.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18028,291,2.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18028,301,102,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18028,303,3.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18028,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18028,307,417,'100g',3,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (18028,320,69,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18028,328,0.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18028,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18028,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18028,601,56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18028,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18028,606,1.616,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18029,203,10.75,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18029,204,2.42,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18029,205,51.88,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18029,207,1.96,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18029,208,272,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18029,255,33,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18029,269,4.62,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18029,291,2.2,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18029,301,52,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18029,303,3.91,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18029,306,117,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18029,307,602,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18029,320,0,'100g',2,1,'2024-12-12','2005-01-11');
INSERT INTO `cndb_nutval` VALUES (18029,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18029,401,0,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18029,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18029,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18029,605,0.005,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18029,606,0.529,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18030,203,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18030,204,2.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18030,205,61.93,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18030,207,2.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18030,208,319,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18030,255,20.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18030,269,3.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18030,291,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18030,301,47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18030,303,3.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18030,306,140,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18030,307,720,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18030,320,0,'100g',2,1,'2024-12-12','2005-01-11');
INSERT INTO `cndb_nutval` VALUES (18030,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18030,401,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18030,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18030,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18030,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18030,606,0.502,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18032,203,6.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18032,204,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18032,205,56,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18032,207,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18032,208,290,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18032,255,30.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18032,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18032,291,2.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18032,301,81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18032,303,2.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18032,306,266,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18032,307,398,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18032,320,48,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18032,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18032,401,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18032,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18032,601,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18032,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18032,606,1.111,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18033,203,9.49,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18033,204,2.73,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18033,205,48.11,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18033,207,2.13,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18033,208,259,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18033,255,37.54,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18033,269,4.69,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18033,291,2.1,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18033,301,105,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18033,303,3.45,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18033,306,124,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18033,307,618,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18033,320,0,'100g',2,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (18033,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18033,401,0,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18033,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18033,601,0,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18033,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18033,606,0.544,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18036,203,14.52,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18036,204,4.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18036,205,47.11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18036,207,2.32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18036,208,288,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18036,255,31.46,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18036,269,6.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18036,291,8.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18036,301,111,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18036,303,2.72,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18036,306,250,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18036,307,414,'100g',3,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (18036,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (18036,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18036,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18036,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18036,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18036,605,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18036,606,0.948,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18037,203,10.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18037,204,4.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18037,205,39.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18037,207,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18037,208,236,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18037,255,44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18037,269,7.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18037,291,4.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18037,301,65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18037,303,3.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18037,306,147,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18037,307,353,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18037,320,2,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18037,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18037,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18037,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18037,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18037,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18037,606,0.697,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18038,203,11.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18038,204,4.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18038,205,43.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18038,207,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18038,208,259,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18038,255,38.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18038,269,8.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18038,291,4.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18038,301,71,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18038,303,3.43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18038,306,123,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18038,307,387,'100g',3,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (18038,320,2,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18038,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18038,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18038,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18038,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18038,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18038,606,0.766,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18039,203,8.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18039,204,4.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18039,205,48.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18039,207,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18039,208,269,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18039,255,36.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18039,269,8.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18039,291,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18039,301,66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18039,303,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18039,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18039,307,447,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18039,320,5,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18039,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18039,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18039,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18039,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18039,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18039,606,0.703,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18040,203,9.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18040,204,4.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18040,205,52.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18040,207,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18040,208,292,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18040,255,31.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18040,269,8.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18040,291,4.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18040,301,72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18040,303,2.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18040,306,154,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18040,307,486,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18040,320,5,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18040,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18040,401,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18040,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18040,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18040,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18040,606,0.764,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18041,203,9.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18041,204,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18041,205,55.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18041,207,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18041,208,275,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18041,255,32.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18041,269,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18041,291,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18041,301,86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18041,303,2.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18041,306,120,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18041,307,536,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18041,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18041,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18041,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18041,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18041,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18041,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18041,606,0.166,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18042,203,9.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18042,204,1.71,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18042,205,55.89,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18042,207,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18042,208,262,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18042,255,30.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18042,269,2.87,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18042,291,6.1,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18042,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18042,303,3.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18042,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18042,307,421,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18042,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18042,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18042,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18042,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18042,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18042,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18042,606,0.208,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18043,203,12.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18043,204,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18043,205,43.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18043,207,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18043,208,245,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18043,255,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18043,269,1.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18043,291,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18043,301,124,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18043,303,4.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18043,306,322,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18043,307,404,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18043,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18043,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18043,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18043,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18043,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18043,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18043,606,0.332,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18044,203,8.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18044,204,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18044,205,47.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18044,207,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18044,208,250,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18044,255,37.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18044,269,0.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18044,291,6.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18044,301,68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18044,303,2.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18044,306,208,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18044,307,596,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18044,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18044,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18044,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18044,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18044,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18044,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18044,606,0.437,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18047,203,7.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18047,204,4.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18047,205,52.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18047,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18047,208,274,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18047,255,33.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18047,269,5.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18047,291,4.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18047,301,66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18047,303,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18047,306,227,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18047,307,347,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18047,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18047,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18047,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18047,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18047,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18047,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18047,606,1.081,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18048,203,8.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18048,204,4.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18048,205,56.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18048,207,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18048,208,297,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18048,255,27.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18048,269,6.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18048,291,4.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18048,301,72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18048,303,3.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18048,306,246,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18048,307,377,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18048,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18048,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18048,401,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18048,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18048,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18048,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18048,606,1.175,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18049,203,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18049,204,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18049,205,41.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18049,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18049,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18049,255,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18049,269,3.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18049,291,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18049,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18049,303,3.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18049,306,102,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18049,307,459,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18049,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18049,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18049,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18049,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18049,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18049,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18049,606,0.445,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18050,203,9.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18050,204,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18050,205,49.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18050,207,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18050,208,239,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18050,255,35.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18050,269,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18050,291,14.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18050,301,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18050,303,3.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18050,306,122,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18050,307,547,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18050,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18050,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18050,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18050,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18050,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18050,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18050,606,0.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18051,203,7.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18051,204,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18051,205,43.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18051,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18051,208,210,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18051,255,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18051,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18051,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18051,301,115,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18051,303,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18051,306,124,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18051,307,388,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18051,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18051,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18051,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18051,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18051,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18051,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18051,606,0.599,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18053,203,9.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18053,204,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18053,205,40.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18053,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18053,208,203,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18053,255,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18053,269,2.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18053,291,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18053,301,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18053,303,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18053,306,98,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18053,307,513,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18053,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18053,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18053,401,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18053,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18053,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18053,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18053,606,0.368,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18055,203,13.32,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18055,204,2.92,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18055,205,42.47,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18055,207,1.68,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18055,208,217,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18055,255,39.6,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18055,269,3.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18055,291,11.1,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18055,301,163,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18055,303,2.91,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18055,306,150,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18055,307,332,'100g',1,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18055,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18055,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18055,401,0.1,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18055,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18055,601,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18055,605,0.046,'100g',NULL,1,'1996-09-30','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18055,606,0.84,'100g',3,1,'1996-09-30','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18057,203,8.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18057,204,2.5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18057,205,44.3,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18057,207,1.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18057,208,207,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18057,255,42.9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18057,269,4.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18057,291,9.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18057,301,94,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18057,303,3.19,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18057,306,76,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18057,307,479,'100g',6,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18057,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18057,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18057,401,0.5,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18057,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18057,601,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18057,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18057,606,0.549,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18059,203,8.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18059,204,4.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18059,205,43.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18059,207,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18059,208,243,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18059,255,41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18059,269,4.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18059,291,4.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18059,301,69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18059,303,3.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18059,306,215,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18059,307,269,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18059,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (18059,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18059,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18059,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18059,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18059,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18059,606,0.709,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18060,203,8.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18060,204,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18060,205,48.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18060,207,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18060,208,259,'100g',3,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (18060,255,37.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18060,269,3.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18060,291,5.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18060,301,73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18060,303,2.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18060,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18060,307,603,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18060,320,0,'100g',2,1,'2024-12-12','2006-01-02');
INSERT INTO `cndb_nutval` VALUES (18060,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18060,401,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18060,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18060,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18060,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18060,606,0.626,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18061,203,9.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18061,204,3.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18061,205,53.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18061,207,2.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18061,208,284,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18061,255,31,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18061,269,4.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18061,291,6.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18061,301,80,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18061,303,3.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18061,306,183,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18061,307,664,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18061,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18061,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18061,401,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18061,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18061,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18061,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18061,606,0.688,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18064,203,10.67,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18064,204,4.53,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18064,205,47.54,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18064,207,2.01,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18064,208,274,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18064,255,35.25,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18064,269,5.73,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18064,291,4,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18064,301,125,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18064,303,3.6,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18064,306,141,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18064,307,473,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18064,320,0,'100g',2,1,'2024-12-12','2005-01-11');
INSERT INTO `cndb_nutval` VALUES (18064,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18064,401,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18064,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18064,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18064,605,0.033,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18064,606,0.697,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18065,203,12.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18065,204,4.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18065,205,55.77,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18065,207,2.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18065,208,313,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18065,255,24.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18065,269,6.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18065,291,4.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18065,301,165,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18065,303,4.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18065,306,223,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18065,307,601,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18065,320,0,'100g',2,1,'2024-12-12','2005-01-11');
INSERT INTO `cndb_nutval` VALUES (18065,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18065,401,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18065,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18065,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18065,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18065,606,0.989,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18069,203,8.85,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18069,204,3.33,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18069,205,49.42,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18069,207,1.98,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18069,208,266,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18069,255,36.42,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18069,269,5.67,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18069,291,2.7,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18069,301,144,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18069,303,3.61,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18069,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18069,307,490,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18069,320,0,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (18069,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18069,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18069,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18069,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18069,605,0.027,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18069,606,0.698,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18070,203,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18070,204,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18070,205,54.5,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18070,207,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18070,208,290,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18070,255,30.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18070,269,6.2,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18070,291,2.9,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18070,301,119,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18070,303,3.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18070,306,131,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18070,307,537,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18070,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18070,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18070,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18070,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18070,601,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18070,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18070,606,0.764,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18071,203,7.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18071,204,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18071,205,53.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18071,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18071,208,274,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18071,255,34.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18071,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18071,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18071,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18071,303,3.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18071,306,111,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18071,307,336,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18071,320,12,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18071,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18071,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18071,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18071,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18071,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18071,606,0.391,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18073,203,7.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18073,204,5.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18073,205,49.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18073,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18073,208,285,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18073,255,35.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18073,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18073,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18073,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18073,303,2.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18073,306,146,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18073,307,359,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18073,320,22,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18073,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18073,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18073,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18073,601,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18073,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18073,606,1.178,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18075,203,12.45,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18075,204,3.5,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18075,205,42.71,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18075,207,2.32,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18075,208,252,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18075,255,39.01,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18075,269,4.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18075,291,6,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18075,301,161,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18075,303,2.47,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18075,306,254,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18075,307,455,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18075,320,0,'100g',2,1,'2024-12-12','2009-01-11');
INSERT INTO `cndb_nutval` VALUES (18075,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18075,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18075,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18075,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18075,605,0.02,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18075,606,0.722,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18076,203,16.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18076,204,4.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18076,205,51.16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18076,207,4.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18076,208,306,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18076,255,24.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18076,269,5.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18076,291,7.5,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18076,301,130,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18076,303,2.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18076,306,326,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18076,307,565,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18076,320,0,'100g',2,1,'2024-12-12','2005-01-11');
INSERT INTO `cndb_nutval` VALUES (18076,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18076,401,0,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18076,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18076,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18076,605,1.025,'100g',3,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18076,606,0.922,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18077,203,8.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18077,204,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18077,205,51.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18077,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18077,208,278,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18077,255,32.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18077,269,3.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18077,291,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18077,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18077,303,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18077,306,314,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18077,307,346,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18077,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18077,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18077,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18077,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18077,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18077,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18077,606,0.796,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18078,203,9.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18078,204,5.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18078,205,56.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18078,207,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18078,208,305,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18078,255,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18078,269,4.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18078,291,6.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18078,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18078,303,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18078,306,345,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18078,307,381,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18078,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18078,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18078,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18078,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18078,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18078,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18078,606,0.874,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18079,203,13.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18079,204,5.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18079,205,71.98,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18079,207,2.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18079,208,395,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18079,255,6.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18079,269,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18079,291,4.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18079,301,183,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18079,303,4.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18079,306,196,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18079,307,732,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18079,320,0,'100g',1,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (18079,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18079,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18079,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18079,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18079,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18079,606,1.203,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18080,203,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18080,204,9.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18080,205,68.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18080,207,3.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18080,208,412,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18080,255,6.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18080,269,1.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18080,291,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18080,301,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18080,303,4.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18080,306,124,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18080,307,713,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18080,320,0,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (18080,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18080,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18080,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18080,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18080,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18080,606,1.41,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18081,203,11,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18081,204,3.4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18081,205,76.2,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18081,207,5.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18081,208,386,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18081,255,4.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18081,269,8.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18081,291,3.2,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18081,301,97,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18081,303,3.81,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18081,306,246,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18081,307,1405,'100g',6,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18081,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18081,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18081,401,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18081,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18081,601,1,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18081,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18081,606,0.845,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18082,203,2.73,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18082,204,12.05,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18082,205,18.84,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18082,207,1.61,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18082,208,195,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18082,255,64.77,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18082,269,2.04,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18082,291,0.8,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18082,301,30,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18082,303,0.95,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18082,306,67,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18082,307,479,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18082,320,114,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18082,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18082,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18082,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18082,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18082,605,2.07,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18082,606,2.319,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18084,203,10,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18084,204,4.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18084,205,76.7,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18084,207,4.4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18084,208,389,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18084,255,4.6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18084,269,13.16,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18084,291,14.3,'100g',3,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18084,301,78,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18084,303,3.25,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18084,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18084,307,1429,'100g',3,1,'1994-11-14','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18084,320,8,'100g',1,1,'2024-12-12','2008-01-08');
INSERT INTO `cndb_nutval` VALUES (18084,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18084,401,3.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18084,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18084,601,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18084,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18084,606,0.922,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18085,203,2.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18085,204,8.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18085,205,21.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18085,207,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18085,208,179,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18085,255,64.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18085,269,0,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18085,291,2.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18085,301,26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18085,303,0.94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18085,306,62,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18085,307,526,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18085,320,78,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18085,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18085,401,0.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18085,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18085,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18085,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18085,606,1.755,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18086,203,5.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18086,204,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18086,205,57.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18086,207,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18086,208,258,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18086,255,33.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18086,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18086,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18086,301,140,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18086,303,0.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18086,306,93,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18086,307,749,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18086,320,0,'100g',1,1,'2024-12-12','2005-01-12');
INSERT INTO `cndb_nutval` VALUES (18086,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18086,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18086,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18086,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18086,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18086,606,0.121,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18088,203,6.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18088,204,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18088,205,58.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18088,207,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18088,208,257,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18088,255,32.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18088,269,30.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18088,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18088,301,84,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18088,303,0.23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18088,306,135,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18088,307,511,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18088,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18088,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18088,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18088,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18088,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18088,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18088,606,0.043,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18090,203,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18090,204,8.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18090,205,42.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18090,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18090,208,252,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18090,255,45.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18090,269,36.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18090,291,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18090,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18090,303,0.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18090,306,39,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18090,307,254,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18090,320,24,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18090,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18090,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18090,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18090,601,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18090,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18090,606,2.445,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18092,203,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18092,204,9.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18092,205,79.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18092,207,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18092,208,415,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18092,255,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18092,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18092,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18092,301,172,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18092,303,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18092,306,169,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18092,307,567,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18092,320,97,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18092,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18092,401,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18092,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18092,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18092,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18092,606,1.472,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18095,203,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18095,204,12.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18095,205,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18095,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18095,208,264,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18095,255,46.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18095,269,32.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18095,291,0.5,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18095,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18095,303,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18095,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18095,307,164,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18095,320,80,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18095,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18095,401,13.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18095,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18095,601,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18095,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18095,606,5.066,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18096,203,3.48,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18096,204,20.05,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18096,205,52.84,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18096,207,1.58,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18096,208,389,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18096,255,22.04,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18096,269,39.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18096,291,2.2,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18096,301,30,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18096,303,3.04,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18096,306,270,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18096,307,348,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18096,320,1,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (18096,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18096,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18096,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18096,601,22,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18096,605,1.318,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18096,606,5.917,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18097,203,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18097,204,8.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18097,205,80.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18097,207,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18097,208,391,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18097,255,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18097,269,39.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18097,291,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18097,301,133,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18097,303,2.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18097,306,337,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18097,307,866,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18097,320,1,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18097,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18097,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18097,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18097,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18097,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18097,606,3.5,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18101,203,5.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18101,204,15.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18101,205,53.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18101,207,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18101,208,371,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18101,255,24.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18101,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18101,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18101,301,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18101,303,1.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18101,306,140,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18101,307,315,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18101,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18101,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18101,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18101,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18101,601,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18101,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18101,606,5.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18102,203,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18102,204,10.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18102,205,63.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18102,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18102,208,356,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18102,255,20.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18102,269,57.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18102,291,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18102,301,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18102,303,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18102,306,99,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18102,307,284,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18102,320,12,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18102,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18102,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18102,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18102,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18102,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18102,606,3.897,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18103,203,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18103,204,15.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18103,205,44.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18103,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18103,208,339,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18103,255,32.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18103,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18103,291,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18103,301,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18103,303,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18103,306,289,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18103,307,339,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18103,320,86,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18103,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18103,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18103,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18103,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18103,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18103,606,5.391,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18104,203,6.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18104,204,23.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18104,205,46.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18104,207,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18104,208,418,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18104,255,21.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18104,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18104,291,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18104,301,54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18104,303,1.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18104,306,123,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18104,307,351,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18104,320,33,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18104,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18104,401,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18104,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18104,601,32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18104,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18104,606,5.797,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18105,203,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18105,204,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18105,205,53.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18105,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18105,208,331,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18105,255,29.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18105,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18105,291,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18105,301,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18105,303,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18105,306,78,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18105,307,323,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18105,320,37,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18105,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18105,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18105,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18105,601,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18105,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18105,606,2.833,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18106,203,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18106,204,10.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18106,205,51.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18106,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18106,208,311,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18106,255,31.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18106,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18106,291,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18106,301,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18106,303,2.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18106,306,90,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18106,307,385,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18106,320,7,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18106,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18106,401,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18106,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18106,601,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18106,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18106,606,2.495,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18108,203,5.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18108,204,9.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18108,205,52.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18108,207,1.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18108,208,318,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18108,255,30.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18108,269,29.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18108,291,1.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18108,301,136,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18108,303,1.43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18108,306,112,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18108,307,421,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18108,320,35,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (18108,328,0.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18108,401,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18108,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18108,601,49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18108,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18108,606,1.855,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18110,203,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18110,204,9.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18110,205,61.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18110,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18110,208,324,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18110,255,25.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18110,269,27.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18110,291,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18110,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18110,303,2.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18110,306,153,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18110,307,101,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18110,320,7,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18110,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18110,401,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18110,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18110,601,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18110,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18110,606,1.048,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18114,203,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18114,204,13.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18114,205,74.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18114,207,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18114,208,437,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18114,255,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18114,269,46.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18114,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18114,301,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18114,303,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18114,306,341,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18114,307,657,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18114,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18114,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18114,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18114,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18114,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18114,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18114,606,3.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18116,203,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18116,204,16.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18116,205,49.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18116,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18116,208,356,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18116,255,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18116,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18116,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18116,301,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18116,303,2.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18116,306,439,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18116,307,327,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18116,320,14,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18116,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18116,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18116,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18116,601,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18116,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18116,606,4.122,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18119,203,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18119,204,12.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18119,205,50.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18119,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18119,208,319,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18119,255,32.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18119,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18119,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18119,301,120,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18119,303,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18119,306,112,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18119,307,319,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18119,320,62,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18119,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18119,401,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18119,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18119,601,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18119,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18119,606,2.915,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18120,203,5,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18120,204,13.96,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18120,205,53.64,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18120,207,1.53,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18120,208,353,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18120,255,25.87,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18120,269,33.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18120,291,0.6,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18120,301,47,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18120,303,1.48,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18120,306,149,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18120,307,377,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18120,320,70,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (18120,328,0.8,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18120,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18120,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18120,601,66,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18120,605,0.192,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18120,606,4.811,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18121,203,5.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18121,204,17.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18121,205,52.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18121,207,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18121,208,389,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18121,255,23.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18121,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18121,291,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18121,301,64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18121,303,1.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18121,306,106,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18121,307,400,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18121,320,35,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18121,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18121,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18121,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18121,601,58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18121,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18121,606,4.647,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18126,203,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18126,204,14.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18126,205,48.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18126,207,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18126,208,346,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18126,255,28.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18126,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18126,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18126,301,205,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18126,303,2.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18126,306,106,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18126,307,506,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18126,320,18,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18126,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18126,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18126,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18126,601,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18126,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18126,606,3.772,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18127,203,3.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18127,204,15.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18127,205,60.31,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18127,207,1.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18127,208,399,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18127,255,18.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18127,269,37.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18127,291,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18127,301,116,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18127,303,3.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18127,306,176,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18127,307,332,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18127,320,1,'100g',2,1,'2024-12-12','2005-01-10');
INSERT INTO `cndb_nutval` VALUES (18127,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18127,401,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18127,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18127,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18127,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18127,606,4.884,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18128,203,3.47,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18128,204,11.54,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18128,205,64.03,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18128,207,1.36,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18128,208,374,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18128,255,19.6,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18128,269,37.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18128,291,1,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18128,301,24,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18128,303,1.36,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18128,306,71,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18128,307,470,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18128,320,5,'100g',2,1,'2024-12-12','2007-01-10');
INSERT INTO `cndb_nutval` VALUES (18128,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18128,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18128,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18128,601,41,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18128,605,1.621,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18128,606,4.139,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18131,203,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18131,204,8.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18131,205,79.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18131,207,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18131,208,397,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18131,255,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18131,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18131,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18131,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18131,303,1.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18131,306,149,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18131,307,260,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18131,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18131,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18131,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18131,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18131,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18131,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18131,606,1.251,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18133,203,5.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18133,204,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18133,205,61,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18133,207,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18133,208,290,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18133,255,29.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18133,269,36.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18133,291,0.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18133,301,70,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18133,303,2.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18133,306,99,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18133,307,623,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18133,320,44,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18133,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18133,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18133,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18133,601,102,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18133,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18133,606,0.802,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18134,203,7.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18134,204,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18134,205,57.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18134,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18134,208,297,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18134,255,29.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18134,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18134,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18134,301,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18134,303,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18134,306,141,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18134,307,228,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18134,320,77,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18134,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18134,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18134,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18134,601,170,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18134,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18134,606,1.301,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18135,203,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18135,204,9.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18135,205,80.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18135,207,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18135,208,423,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18135,255,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18135,269,48.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18135,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18135,301,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18135,303,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18135,306,72,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18135,307,665,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18135,320,0,'100g',2,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (18135,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18135,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18135,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18135,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18135,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18135,606,2.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18139,203,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18139,204,12.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18139,205,57.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18139,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18139,208,357,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18139,255,23.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18139,269,35.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18139,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18139,301,130,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18139,303,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18139,306,95,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18139,307,327,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18139,320,15,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18139,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18139,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18139,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18139,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18139,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18139,606,3.269,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18140,203,3.16,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18140,204,17.75,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18140,205,55.36,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18140,207,1.35,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18140,208,379,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18140,255,22.38,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18140,269,39.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18140,291,1.5,'100g',1,1,'2012-08-01','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18140,301,32,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18140,303,2.03,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18140,306,187,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18140,307,310,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18140,320,7,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (18140,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18140,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18140,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18140,601,16,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18140,605,1.313,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18140,606,5.793,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18141,203,2.99,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18141,204,17.91,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18141,205,56.2,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18141,207,0.81,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18141,208,391,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18141,255,22.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18141,269,41.79,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18141,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18141,301,62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18141,303,1.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18141,306,53,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18141,307,269,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18141,320,32,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (18141,328,0.4,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18141,401,0,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18141,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18141,601,75,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18141,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18141,606,2.936,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18142,203,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18142,204,9.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18142,205,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18142,207,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18142,208,423,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18142,255,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18142,269,44.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18142,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18142,301,115,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18142,303,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18142,306,63,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18142,307,860,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18142,320,0,'100g',2,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (18142,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18142,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18142,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18142,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18142,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18142,606,2.469,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18144,203,3.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18144,204,3.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18144,205,81.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18144,207,3.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18144,208,374,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18144,255,7.18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18144,269,43.29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18144,291,1.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18144,301,211,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18144,303,2.08,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18144,306,47,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18144,307,728,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18144,320,0,'100g',2,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (18144,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18144,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18144,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18144,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18144,605,0.231,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18144,606,1.62,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18146,203,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18146,204,14.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18146,205,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18146,207,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18146,208,361,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18146,255,25.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18146,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18146,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18146,301,146,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18146,303,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18146,306,91,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18146,307,343,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18146,320,40,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18146,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18146,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18146,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18146,601,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18146,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18146,606,3.924,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18147,203,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18147,204,22.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18147,205,25.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18147,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18147,208,321,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18147,255,45.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18147,269,21.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18147,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18147,301,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18147,303,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18147,306,90,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18147,307,438,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18147,320,159,'100g',2,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (18147,328,0.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18147,401,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18147,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18147,601,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18147,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18147,606,9.921,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18148,203,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18148,204,12.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18148,205,35.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18148,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18148,208,274,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18148,255,44.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18148,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18148,291,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18148,301,172,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18148,303,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18148,306,211,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18148,307,380,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18148,320,96,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18148,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18148,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18148,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18148,601,29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18148,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18148,606,6.691,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18151,203,4.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18151,204,16.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18151,205,63.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18151,207,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18151,208,405,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18151,255,13.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18151,269,36.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18151,291,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18151,301,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18151,303,2.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18151,306,149,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18151,307,286,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18151,320,20,'100g',2,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (18151,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18151,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18151,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18151,601,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18151,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18151,606,4.235,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18152,203,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18152,204,14.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18152,205,76.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18152,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18152,208,434,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18152,255,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18152,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18152,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18152,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18152,303,1.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18152,306,219,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18152,307,303,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18152,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18152,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18152,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18152,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18152,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18152,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18152,606,2.519,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18154,203,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18154,204,29.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18154,205,50.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18154,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18154,208,466,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18154,255,12.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18154,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18154,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18154,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18154,303,1.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18154,306,176,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18154,307,343,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18154,320,176,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (18154,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18154,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18154,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18154,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18154,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18154,606,7.319,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18155,203,6.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18155,204,18.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18155,205,68.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18155,207,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18155,208,467,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18155,255,4.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18155,269,20.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18155,291,0.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18155,301,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18155,303,2.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18155,306,111,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18155,307,282,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18155,320,165,'100g',2,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (18155,328,0.4,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18155,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18155,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18155,601,117,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18155,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18155,606,11.051,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18156,203,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18156,204,3.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18156,205,78.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18156,207,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18156,208,349,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18156,255,11.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18156,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18156,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18156,301,34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18156,303,2.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18156,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18156,307,192,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18156,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18156,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18156,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18156,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18156,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18156,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18156,606,1.112,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18157,203,6.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18157,204,14.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18157,205,72.7,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18157,207,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18157,208,433,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18157,255,4.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18157,269,37.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18157,291,3.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18157,301,31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18157,303,4.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18157,306,210,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18157,307,580,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18157,320,3,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18157,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18157,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18157,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18157,601,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18157,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18157,606,4.241,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18158,203,5.97,'100g',6,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18158,204,17.91,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18158,205,67.49,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18158,207,1.27,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18158,208,451,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18158,255,7.36,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18158,269,32.84,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18158,291,3,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18158,301,0,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18158,303,3.22,'100g',6,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18158,306,134,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18158,307,418,'100g',6,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18158,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18158,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18158,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18158,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18158,601,0,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18158,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18158,606,5.962,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18159,203,5.1,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18159,204,24.72,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18159,205,65.36,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18159,207,1.25,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18159,208,492,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18159,255,3.57,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18159,269,32.9,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18159,291,2,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18159,301,21,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18159,303,5.58,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18159,306,171,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18159,307,311,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18159,320,0,'100g',1,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (18159,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18159,401,0,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18159,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18159,601,0,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18159,605,0.684,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18159,606,8.091,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18160,203,3.63,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18160,204,19.77,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18160,205,65.75,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18160,207,0.97,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18160,208,444,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18160,255,9.88,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18160,269,37.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18160,291,1.8,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18160,301,17,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18160,303,4.07,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18160,306,130,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18160,307,276,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18160,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (18160,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18160,401,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (18160,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18160,601,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (18160,605,0.055,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18160,606,9.751,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18161,203,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18161,204,25.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18161,205,66.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18161,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18161,208,497,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18161,255,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18161,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18161,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18161,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18161,303,2.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18161,306,208,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18161,307,290,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18161,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18161,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18161,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18161,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18161,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18161,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18161,606,8.316,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18163,203,3.98,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18163,204,21.33,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18163,205,61.02,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18163,207,1.54,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18163,208,451,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18163,255,12.08,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18163,269,38.04,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18163,291,1.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18163,301,14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18163,303,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18163,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18163,307,321,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18163,320,4,'100g',2,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (18163,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18163,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18163,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18163,601,7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18163,605,2.47,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18163,606,8.39,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18164,203,4.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18164,204,22.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18164,205,68.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18164,207,1.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18164,208,492,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18164,255,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18164,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18164,291,1.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18164,301,28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18164,303,2.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18164,306,200,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18164,307,232,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18164,320,18,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18164,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18164,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18164,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18164,601,27,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18164,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18164,606,7.759,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18165,203,5.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18165,204,28.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18165,205,58.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18165,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18165,208,488,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18165,255,5.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18165,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18165,291,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18165,301,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18165,303,2.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18165,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18165,307,361,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18165,320,143,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (18165,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18165,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18165,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18165,601,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18165,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18165,606,8.074,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18166,203,5.21,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18166,204,19.14,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18166,205,71,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18166,207,1.54,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18166,208,464,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18166,255,3.11,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18166,269,40.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18166,291,2.9,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18166,301,21,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18166,303,12.14,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18166,306,234,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18166,307,388,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18166,320,1,'100g',2,1,'2024-12-12','2013-01-07');
INSERT INTO `cndb_nutval` VALUES (18166,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18166,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18166,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18166,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18166,605,0.112,'100g',3,1,'2006-01-24','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18166,606,5.649,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18167,203,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18167,204,26.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18167,205,66.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18167,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18167,208,481,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18167,255,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18167,269,49.58,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18167,291,5.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18167,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18167,303,3.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18167,306,240,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18167,307,326,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18167,320,2,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18167,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18167,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18167,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18167,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18167,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18167,606,7.426,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18168,203,4.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18168,204,24.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18168,205,68.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18168,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18168,208,497,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18168,255,1.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18168,269,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18168,291,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18168,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18168,303,7.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18168,306,137,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18168,307,351,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18168,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (18168,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18168,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18168,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18168,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18168,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18168,606,5.454,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18170,203,3.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18170,204,7.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18170,205,70.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18170,207,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18170,208,348,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18170,255,16.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18170,269,46.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18170,291,4.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18170,301,64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18170,303,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18170,306,207,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18170,307,350,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18170,320,9,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18170,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18170,401,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18170,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18170,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18170,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18170,606,1.123,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18171,203,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18171,204,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18171,205,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18171,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18171,208,378,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18171,255,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18171,269,45.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18171,291,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18171,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18171,303,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18171,306,41,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18171,307,31,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18171,320,1,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18171,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18171,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18171,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18171,601,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18171,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18171,606,0.669,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18172,203,5.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18172,204,9.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18172,205,76.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18172,207,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18172,208,416,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18172,255,5.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18172,269,19.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18172,291,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18172,301,77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18172,303,6.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18172,306,346,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18172,307,555,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18172,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18172,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18172,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18172,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18172,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18172,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18172,606,2.451,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18173,203,6.69,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18173,204,10.6,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18173,205,77.66,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18173,207,1.66,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18173,208,430,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18173,255,3.39,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18173,269,24.85,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18173,291,3.4,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18173,301,77,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18173,303,3.78,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18173,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18173,307,516,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18173,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18173,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18173,401,0,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18173,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18173,601,0,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18173,605,0.055,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18173,606,1.633,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18174,203,4,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18174,204,25.8,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18174,205,66.78,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18174,207,1.42,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18174,208,500,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18174,255,2,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18174,269,37.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18174,291,2.2,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18174,301,46,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18174,303,2,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18174,306,267,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18174,307,265,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18174,320,2,'100g',2,1,'2024-12-12','2013-01-10');
INSERT INTO `cndb_nutval` VALUES (18174,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18174,401,0.1,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18174,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18174,601,1,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18174,605,0.55,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18174,606,17.2,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18175,203,10.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18175,204,9.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18175,205,59.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18175,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18175,208,365,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18175,255,19.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18175,269,25.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18175,291,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18175,301,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18175,303,3.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18175,306,113,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18175,307,147,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18175,320,3,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18175,328,0.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18175,401,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18175,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18175,601,221,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18175,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18175,606,3.069,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18176,203,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18176,204,16.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18176,205,67.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18176,207,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18176,208,421,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18176,255,10.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18176,269,44.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18176,291,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18176,301,46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18176,303,2.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18176,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18176,307,188,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18176,320,1,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18176,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18176,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18176,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18176,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18176,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18176,606,4.722,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18177,203,5.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18177,204,12.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18177,205,73.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18177,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18177,208,430,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18177,255,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18177,269,17.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18177,291,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18177,301,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18177,303,6.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18177,306,346,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18177,307,459,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18177,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18177,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18177,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18177,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18177,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18177,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18177,606,3.212,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18178,203,6.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18178,204,18.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18178,205,68.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18178,207,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18178,208,450,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18178,255,5.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18178,269,24.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18178,291,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18178,301,37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18178,303,2.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18178,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18178,307,520,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18178,320,5,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18178,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18178,401,0.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18178,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18178,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18178,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18178,606,4.519,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18179,203,6.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18179,204,14.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18179,205,65.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18179,207,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18179,208,409,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18179,255,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18179,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18179,291,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18179,301,90,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18179,303,2.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18179,306,135,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18179,307,349,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18179,320,5,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18179,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18179,401,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18179,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18179,601,5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18179,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18179,606,3.63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18180,203,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18180,204,19.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18180,205,67.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18180,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18180,208,462,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18180,255,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18180,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18180,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18180,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18180,303,2.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18180,306,183,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18180,307,473,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18180,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18180,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18180,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18180,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18180,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18180,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18180,606,4.755,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18182,203,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18182,204,18.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18182,205,59.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18182,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18182,208,424,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18182,255,15.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18182,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18182,291,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18182,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18182,303,2.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18182,306,147,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18182,307,294,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18182,320,4,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18182,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18182,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18182,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18182,601,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18182,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18182,606,4.751,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18183,203,6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18183,204,21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18183,205,65.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18183,207,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18183,208,471,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18183,255,5.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18183,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18183,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18183,301,35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18183,303,2.38,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18183,306,163,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18183,307,327,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18183,320,4,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18183,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18183,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18183,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18183,601,26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18183,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18183,606,5.339,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18184,203,5.86,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18184,204,15.76,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18184,205,68.95,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18184,207,1.44,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18184,208,441,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18184,255,7.98,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18184,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18184,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18184,301,28,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18184,303,2.3,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18184,306,230,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18184,307,322,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18184,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18184,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18184,401,NULL,'100g',NULL,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18184,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18184,601,NULL,'100g',NULL,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18184,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18184,606,5.439,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18185,203,8.92,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18185,204,23.82,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18185,205,58.15,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18185,207,1.83,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18185,208,473,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18185,255,7.28,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18185,269,28.58,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18185,291,2.1,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18185,301,41,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18185,303,2.11,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18185,306,202,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18185,307,463,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18185,320,9,'100g',1,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (18185,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18185,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18185,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18185,601,27,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18185,605,1.25,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18185,606,6.751,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18186,203,5.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18186,204,24.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18186,205,57.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18186,207,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18186,208,457,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18186,255,11.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18186,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18186,291,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18186,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18186,303,0.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18186,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18186,307,336,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18186,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18186,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18186,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18186,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18186,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18186,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18186,606,6.149,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18187,203,8.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18187,204,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18187,205,52.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18187,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18187,208,458,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18187,255,12.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18187,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18187,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18187,301,101,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18187,303,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18187,306,308,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18187,307,397,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18187,320,14,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18187,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18187,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18187,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18187,601,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18187,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18187,606,5.791,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18188,203,9.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18188,204,27.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18188,205,57.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18188,207,2.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18188,208,503,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18188,255,4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18188,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18188,291,1.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18188,301,111,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18188,303,1.87,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18188,306,338,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18188,307,436,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18188,320,14,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18188,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18188,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18188,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18188,601,30,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18188,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18188,606,6.199,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18189,203,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18189,204,23.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18189,205,58.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18189,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18189,208,475,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18189,255,5.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18189,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18189,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18189,301,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18189,303,2.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18189,306,231,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18189,307,518,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18189,320,137,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (18189,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18189,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18189,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18189,601,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18189,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18189,606,4.438,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18190,203,8.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18190,204,21.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18190,205,65.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18190,207,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18190,208,478,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18190,255,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18190,269,35.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18190,291,1.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18190,301,53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18190,303,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18190,306,192,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18190,307,368,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18190,320,1,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18190,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18190,401,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18190,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18190,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18190,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18190,606,4.995,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18191,203,4.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18191,204,13.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18191,205,68,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18191,207,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18191,208,401,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18191,255,13.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18191,269,47.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18191,291,1.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18191,301,46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18191,303,2.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18191,306,140,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18191,307,418,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18191,320,2,'100g',2,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (18191,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18191,401,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18191,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18191,601,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18191,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18191,606,3.46,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18192,203,5.37,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18192,204,26.22,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18192,205,63.78,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18192,207,1.04,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18192,208,514,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18192,255,3.6,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18192,269,21.65,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18192,291,1.3,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18192,301,13,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18192,303,2.98,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18192,306,88,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18192,307,353,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18192,320,0,'100g',2,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (18192,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18192,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18192,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18192,601,0,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18192,605,0.714,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18192,606,8.105,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18193,203,4.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18193,204,32.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18193,205,58.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18193,207,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18193,208,542,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18193,255,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18193,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18193,291,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18193,301,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18193,303,2.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18193,306,73,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18193,307,281,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18193,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18193,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18193,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18193,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18193,601,33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18193,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18193,606,8.204,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18196,203,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18196,204,12.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18196,205,80.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18196,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18196,208,426,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18196,255,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18196,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18196,291,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18196,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18196,303,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18196,306,335,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18196,307,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18196,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18196,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18196,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18196,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18196,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18196,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18196,606,2.018,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18198,203,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18198,204,16.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18198,205,73.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18198,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18198,208,450,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18198,255,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18198,269,39.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18198,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18198,301,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18198,303,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18198,306,199,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18198,307,244,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18198,320,1,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18198,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18198,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18198,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18198,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18198,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18198,606,4.183,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18199,203,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18199,204,22.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18199,205,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18199,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18199,208,461,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18199,255,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18199,269,19.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18199,291,4.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18199,301,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18199,303,4.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18199,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18199,307,342,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18199,320,1,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18199,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18199,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18199,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18199,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18199,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18199,606,3.992,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18200,203,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18200,204,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18200,205,69.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18200,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18200,208,449,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18200,255,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18200,269,31.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18200,291,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18200,301,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18200,303,4.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18200,306,175,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18200,307,273,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18200,320,1,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18200,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18200,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18200,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18200,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18200,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18200,606,2.693,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18201,203,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18201,204,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18201,205,50.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18201,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18201,208,535,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18201,255,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18201,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18201,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18201,301,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18201,303,2.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18201,306,294,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18201,307,412,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18201,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18201,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18201,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18201,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18201,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18201,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18201,606,4.937,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18202,203,3.57,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18202,204,28.57,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18202,205,66.26,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18202,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18202,208,531,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18202,255,0.7,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18202,269,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18202,291,14.3,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18202,301,0,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18202,303,1.29,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18202,306,57,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18202,307,71,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18202,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (18202,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18202,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18202,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18202,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18202,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18202,606,4.257,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18204,203,5.35,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18204,204,19.55,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18204,205,67.34,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18204,207,1.47,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18204,208,464,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18204,255,6.29,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18204,269,27.31,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18204,291,1.3,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18204,301,35,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18204,303,2.24,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18204,306,87,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18204,307,385,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18204,320,7,'100g',2,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (18204,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18204,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18204,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18204,601,12,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18204,605,0.49,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18204,606,7.666,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18205,203,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18205,204,19.48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18205,205,61.22,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18205,207,1.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18205,208,436,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18205,255,14.08,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18205,269,36.51,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18205,291,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18205,301,8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18205,303,1.85,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18205,306,147,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18205,307,328,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18205,320,11,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18205,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18205,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18205,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18205,601,11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18205,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18205,606,4.955,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18206,203,4.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18206,204,23.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18206,205,65.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18206,207,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18206,208,489,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18206,255,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18206,269,40.36,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18206,291,0.9,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18206,301,90,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18206,303,1.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18206,306,163,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18206,307,362,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18206,320,12,'100g',4,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18206,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18206,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18206,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18206,601,32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18206,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18206,606,5.906,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18209,203,3.84,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18209,204,23.24,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18209,205,70.64,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18209,207,0.61,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18209,208,502,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18209,255,1.66,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18209,269,42.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18209,291,1.6,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18209,301,27,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18209,303,3.73,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18209,306,117,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18209,307,103,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18209,320,0,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (18209,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18209,401,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18209,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18209,601,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18209,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18209,606,11.899,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18210,203,4.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18210,204,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18210,205,72.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18210,207,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18210,208,483,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18210,255,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18210,269,39.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18210,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18210,301,27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18210,303,2.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18210,306,91,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18210,307,388,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18210,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18210,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18210,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18210,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18210,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18210,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18210,606,2.979,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18211,203,7.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18211,204,38.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18211,205,45.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18211,207,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18211,208,558,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18211,255,7.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18211,269,0.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18211,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18211,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18211,303,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18211,306,62,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18211,307,253,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18211,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18211,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18211,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18211,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18211,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18211,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18211,606,5.502,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18212,203,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18212,204,15.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18212,205,73.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18212,207,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18212,208,441,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18212,255,5.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18212,269,37.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18212,291,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18212,301,48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18212,303,2.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18212,306,97,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18212,307,388,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18212,320,8,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18212,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18212,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18212,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18212,601,51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18212,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18212,606,3.838,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18213,203,4.9,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18213,204,16.41,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18213,205,72.6,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18213,207,1.11,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18213,208,455,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18213,255,4.98,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18213,269,35.07,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18213,291,1.6,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18213,301,36,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18213,303,2.79,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18213,306,99,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18213,307,325,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18213,320,0,'100g',1,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (18213,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18213,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18213,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18213,601,9,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18213,605,0.6,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18213,606,4.245,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18214,203,10.93,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18214,204,22.74,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18214,205,59.42,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18214,207,3.36,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18214,208,489,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18214,255,3.55,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18214,269,4.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18214,291,2.3,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18214,301,136,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18214,303,4.88,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18214,306,156,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18214,307,973,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18214,320,17,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (18214,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18214,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18214,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18214,601,3,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18214,605,0.542,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18214,606,5.288,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18215,203,12.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18215,204,25.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18215,205,56.74,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18215,207,2.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18215,208,496,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18215,255,3.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18215,269,6.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18215,291,3.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18215,301,50,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18215,303,2.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18215,306,218,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18215,307,829,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18215,320,1,'100g',2,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (18215,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18215,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18215,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18215,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18215,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18215,606,4.406,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18216,203,7.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18216,204,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18216,205,82.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18216,207,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18216,208,366,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18216,255,6.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18216,269,1.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18216,291,16.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18216,301,31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18216,303,2.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18216,306,319,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18216,307,410,'100g',3,1,'1994-01-31','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (18216,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18216,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18216,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18216,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18216,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18216,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18216,606,0.145,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18217,203,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18217,204,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18217,205,83.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18217,207,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18217,208,395,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18217,255,4.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18217,269,0.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18217,291,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18217,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18217,303,3.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18217,306,112,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18217,307,0,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18217,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18217,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18217,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18217,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18217,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18217,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18217,606,0.226,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18218,203,12.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18218,204,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18218,205,78.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18218,207,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18218,208,391,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18218,255,6.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18218,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18218,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18218,301,40,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18218,303,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18218,306,150,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18218,307,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18218,320,13,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18218,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18218,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18218,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18218,601,83,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18218,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18218,606,0.548,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18219,203,13.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18219,204,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18219,205,78.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18219,207,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18219,208,351,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18219,255,4.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18219,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18219,291,11.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18219,301,23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18219,303,4.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18219,306,316,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18219,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18219,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18219,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18219,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18219,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18219,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18219,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18219,606,0.243,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18220,203,12.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18220,204,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18220,205,76.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18220,207,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18220,208,390,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18220,255,5.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18220,269,0.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18220,291,6.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18220,301,93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18220,303,3.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18220,306,202,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18220,307,598,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18220,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18220,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18220,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18220,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18220,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18220,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18220,606,0.445,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18221,203,11.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18221,204,3.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18221,205,77.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18221,207,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18221,208,389,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18221,255,4.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18221,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18221,291,8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18221,301,78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18221,303,3.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18221,306,193,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18221,307,899,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18221,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18221,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18221,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18221,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18221,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18221,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18221,606,0.453,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18222,203,12.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18222,204,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18222,205,76.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18222,207,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18222,208,374,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18222,255,5.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18222,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18222,291,7.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18222,301,43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18222,303,4.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18222,306,148,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18222,307,837,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18222,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18222,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18222,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18222,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18222,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18222,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18222,606,0.337,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18223,203,7.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18223,204,13.77,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18223,205,71.73,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18223,207,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18223,208,446,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18223,255,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18223,269,10.32,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18223,291,3.4,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18223,301,172,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18223,303,3.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18223,306,114,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18223,307,687,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18223,320,16,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18223,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18223,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18223,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18223,601,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18223,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18223,606,2.912,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18224,203,13.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18224,204,7.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18224,205,72.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18224,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18224,208,407,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18224,255,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18224,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18224,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18224,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18224,303,2.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18224,306,245,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18224,307,253,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18224,320,12,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18224,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18224,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18224,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18224,601,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18224,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18224,606,1.376,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18225,203,9.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18225,204,22.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18225,205,60.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18225,207,3.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18225,208,481,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18225,255,3.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18225,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18225,291,3.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18225,301,222,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18225,303,2.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18225,306,342,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18225,307,1044,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18225,320,24,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18225,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18225,401,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18225,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18225,601,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18225,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18225,606,5.987,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18226,203,9.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18226,204,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18226,205,80.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18226,207,4.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18226,208,334,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18226,255,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18226,269,1.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18226,291,22.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18226,301,40,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18226,303,5.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18226,306,495,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18226,307,557,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18226,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18226,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18226,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18226,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18226,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18226,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18226,606,0.108,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18227,203,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18227,204,9.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18227,205,73.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18227,207,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18227,208,381,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18227,255,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18227,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18227,291,20.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18227,301,44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18227,303,3.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18227,306,454,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18227,307,887,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18227,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18227,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18227,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18227,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18227,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18227,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18227,606,1.287,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18228,203,9.46,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18228,204,8.64,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18228,205,74.05,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18228,207,2.79,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18228,208,418,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18228,255,5.05,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18228,269,1.29,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18228,291,2.8,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18228,301,19,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18228,303,5.57,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18228,306,152,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18228,307,941,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18228,320,1,'100g',1,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (18228,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18228,401,0,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18228,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18228,601,0,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18228,605,0.167,'100g',3,1,'2006-01-24','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18228,606,1.653,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18229,203,6.64,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18229,204,26.43,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18229,205,61.3,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18229,207,2.49,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18229,208,510,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18229,255,3.14,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18229,269,8.18,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18229,291,2.3,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18229,301,120,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18229,303,4.03,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18229,306,118,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18229,307,726,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18229,320,0,'100g',1,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (18229,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18229,401,0,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18229,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18229,601,0,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18229,605,1.076,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18229,606,5.562,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18230,203,9.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18230,204,21.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18230,205,61.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18230,207,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18230,208,477,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18230,255,3.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18230,269,3.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18230,291,1.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18230,301,257,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18230,303,2.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18230,306,429,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18230,307,978,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18230,320,17,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18230,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18230,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18230,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18230,601,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18230,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18230,606,6.125,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18231,203,11.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18231,204,24.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18231,205,58.38,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18231,207,2.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18231,208,494,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18231,255,2.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18231,269,10.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18231,291,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18231,301,81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18231,303,2.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18231,306,215,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18231,307,801,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18231,320,1,'100g',2,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (18231,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18231,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18231,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18231,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18231,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18231,606,4.803,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18232,203,7.3,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18232,204,16.4,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18232,205,70.73,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18232,207,2.83,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18232,208,455,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18232,255,2.75,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18232,269,15.48,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18232,291,6.9,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18232,301,92,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18232,303,2.64,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18232,306,283,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18232,307,699,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18232,320,0,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (18232,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18232,401,0,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18232,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18232,601,0,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18232,605,0.034,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18232,606,3.21,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18233,203,9.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18233,204,25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18233,205,58.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18233,207,3.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18233,208,497,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18233,255,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18233,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18233,291,3.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18233,301,204,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18233,303,2.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18233,306,306,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18233,307,839,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18233,320,21,'100g',2,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (18233,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18233,401,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18233,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18233,601,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18233,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18233,606,4.129,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18234,203,13.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18234,204,26.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18234,205,53.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18234,207,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18234,208,495,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18234,255,3.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18234,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18234,291,4.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18234,301,170,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18234,303,2.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18234,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18234,307,807,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18234,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18234,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18234,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18234,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18234,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18234,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18234,606,4.602,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18235,203,10.58,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18235,204,14.13,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18235,205,69.55,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18235,207,2.8,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18235,208,427,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18235,255,2.94,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18235,269,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18235,291,10.3,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18235,301,36,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18235,303,3.34,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18235,306,345,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18235,307,800,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18235,320,0,'100g',2,1,'2024-12-12','2008-01-10');
INSERT INTO `cndb_nutval` VALUES (18235,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18235,401,0,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18235,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18235,601,0,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18235,605,0.199,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18235,606,2.063,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18236,203,9.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18236,204,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18236,205,80.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18236,207,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18236,208,383,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18236,255,7.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18236,269,0.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18236,291,2.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18236,301,23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18236,303,4.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18236,306,115,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18236,307,16,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18236,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (18236,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18236,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18236,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18236,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18236,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18236,606,0.271,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18237,203,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18237,204,25.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18237,205,22.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18237,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18237,208,360,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18237,255,40.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18237,269,0.25,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18237,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18237,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18237,303,2.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18237,306,97,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18237,307,483,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18237,320,288,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18237,328,1.4,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18237,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18237,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18237,601,171,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18237,605,NULL,'100g',NULL,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18237,606,5.599,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18239,203,8.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18239,204,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18239,205,45.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18239,207,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18239,208,406,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18239,255,23.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18239,269,11.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18239,291,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18239,301,37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18239,303,2.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18239,306,118,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18239,307,384,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18239,320,206,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18239,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18239,401,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18239,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18239,601,67,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18239,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18239,606,11.659,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18240,203,7.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18240,204,8.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18240,205,37.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18240,207,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18240,208,254,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18240,255,45.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18240,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18240,291,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18240,301,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18240,303,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18240,306,90,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18240,307,274,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18240,320,94,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18240,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18240,401,0.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18240,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18240,601,31,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18240,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18240,606,4.994,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18241,203,9.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18241,204,20.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18241,205,47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18241,207,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18241,208,414,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18241,255,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18241,269,11.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18241,291,2.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18241,301,53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18241,303,2.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18241,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18241,307,361,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18241,320,204,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (18241,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18241,401,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18241,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18241,601,57,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18241,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18241,606,10.628,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18242,203,11.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18242,204,6.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18242,205,73.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18242,207,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18242,208,407,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18242,255,5.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18242,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18242,291,5.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18242,301,76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18242,303,4.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18242,306,124,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18242,307,698,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18242,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18242,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18242,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18242,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18242,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18242,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18242,606,1.51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18243,203,10.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18243,204,18.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18243,205,63.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18243,207,3.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18243,208,465,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18243,255,3.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18243,269,4.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18243,291,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18243,301,96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18243,303,2.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18243,306,181,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18243,307,1333,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18243,320,7,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18243,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18243,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18243,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18243,601,7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18243,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18243,606,5.247,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18244,203,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18244,204,22.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18244,205,44.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18244,207,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18244,208,403,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18244,255,24.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18244,269,19.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18244,291,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18244,301,71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18244,303,1.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18244,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18244,307,414,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18244,320,6,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18244,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18244,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18244,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18244,601,21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18244,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18244,606,5.681,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18245,203,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18245,204,21.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18245,205,37.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18245,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18245,208,374,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18245,255,31.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18245,269,6.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18245,291,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18245,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18245,303,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18245,306,98,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18245,307,417,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18245,320,35,'100g',2,1,'2024-12-12','2009-01-01');
INSERT INTO `cndb_nutval` VALUES (18245,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18245,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18245,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18245,601,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18245,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18245,606,6.794,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18246,203,5.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18246,204,18.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18246,205,47.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18246,207,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18246,208,371,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18246,255,27.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18246,269,27.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18246,291,1.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18246,301,46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18246,303,1.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18246,306,83,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18246,307,445,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18246,320,15,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18246,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18246,401,3.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18246,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18246,601,114,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18246,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18246,606,4.86,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18248,203,5.31,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18248,204,24.93,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18248,205,47.06,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18248,207,1.87,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18248,208,434,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18248,255,20.82,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18248,269,18.15,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18248,291,1.7,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18248,301,40,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18248,303,2.53,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18248,306,134,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18248,307,477,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18248,320,4,'100g',2,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (18248,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18248,401,0,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18248,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18248,601,10,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18248,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (18248,606,11.105,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18249,203,4.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18249,204,25.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18249,205,51.33,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18249,207,1.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18249,208,452,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18249,255,16.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18249,269,26.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18249,291,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18249,301,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18249,303,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18249,306,201,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18249,307,326,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18249,320,4,'100g',2,1,'2024-12-12','2005-01-10');
INSERT INTO `cndb_nutval` VALUES (18249,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18249,401,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18249,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18249,601,19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18249,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (18249,606,13.47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18250,203,5.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18250,204,22.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18250,205,50.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18250,207,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18250,208,426,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18250,255,19.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18250,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18250,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18250,301,60,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18250,303,1.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18250,306,102,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18250,307,402,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18250,320,3,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18250,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18250,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18250,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18250,601,32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18250,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18250,606,5.926,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18251,203,4.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18251,204,19.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18251,205,57.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18251,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18251,208,417,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18251,255,16.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18251,269,31.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18251,291,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18251,301,213,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18251,303,2.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18251,306,106,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18251,307,215,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18251,320,12,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18251,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18251,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18251,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18251,601,57,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18251,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18251,606,5.132,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18253,203,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18253,204,18.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18253,205,59.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18253,207,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18253,208,412,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18253,255,17.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18253,269,35.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18253,291,1.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18253,301,26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18253,303,2.42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18253,306,78,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18253,307,345,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18253,320,2,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18253,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18253,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18253,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18253,601,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18253,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18253,606,4.667,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18254,203,6.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18254,204,24.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18254,205,30,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18254,207,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18254,208,361,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18254,255,38.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18254,269,14.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18254,291,0.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18254,301,25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18254,303,1.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18254,306,80,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18254,307,309,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18254,320,11,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18254,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18254,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18254,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18254,601,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18254,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18254,606,5.43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18255,203,6.14,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18255,204,22.7,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18255,205,47.93,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18255,207,1.22,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18255,208,421,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18255,255,22,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18255,269,22.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18255,291,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18255,301,101,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18255,303,2.38,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18255,306,102,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18255,307,316,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18255,320,5,'100g',2,1,'2024-12-12','2005-01-11');
INSERT INTO `cndb_nutval` VALUES (18255,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18255,401,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18255,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18255,601,30,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18255,605,0.455,'100g',3,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18255,606,9.453,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18256,203,5.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18256,204,18.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18256,205,39,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18256,207,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18256,208,340,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18256,255,35.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18256,269,21.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18256,291,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18256,301,25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18256,303,1.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18256,306,79,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18256,307,455,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18256,320,17,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18256,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18256,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18256,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18256,601,26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18256,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18256,606,4.843,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18258,203,8.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18258,204,1.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18258,205,44.17,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18258,207,1.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18258,208,227,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18258,255,43.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18258,269,3.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18258,291,3.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18258,301,163,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18258,303,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18258,306,109,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18258,307,425,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18258,320,0,'100g',3,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (18258,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18258,401,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18258,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18258,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18258,605,0,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18258,606,0.733,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18259,203,10.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18259,204,2.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18259,205,52.65,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18259,207,2.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18259,208,270,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18259,255,32.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18259,269,3.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18259,291,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18259,301,197,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18259,303,4.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18259,306,129,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18259,307,477,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18259,320,0,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (18259,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18259,401,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18259,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18259,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18259,605,0,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18259,606,0.533,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18260,203,9.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18260,204,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18260,205,46.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18260,207,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18260,208,235,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18260,255,40.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18260,269,0.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18260,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18260,301,196,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18260,303,3.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18260,306,156,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18260,307,298,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18260,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18260,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18260,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18260,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18260,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18260,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18260,606,0.23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18262,203,7.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18262,204,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18262,205,48.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18262,207,1.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18262,208,240,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18262,255,40.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18262,269,14.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18262,291,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18262,301,114,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18262,303,4.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18262,306,173,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18262,307,299,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18262,320,0,'100g',3,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (18262,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18262,401,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18262,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18262,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18262,605,0,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18262,606,0.54,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18263,203,8.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18263,204,2.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18263,205,55.04,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18263,207,1.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18263,208,276,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18263,255,32.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18263,269,13.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18263,291,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18263,301,139,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18263,303,4.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18263,306,194,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18263,307,342,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18263,320,0,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (18263,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18263,401,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18263,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18263,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18263,605,0,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18263,606,0.579,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18264,203,8.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18264,204,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18264,205,44.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18264,207,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18264,208,223,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18264,255,42.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18264,269,1.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18264,291,4.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18264,301,178,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18264,303,2.87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18264,306,186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18264,307,353,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18264,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18264,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18264,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18264,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18264,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18264,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18264,606,0.287,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18266,203,8.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18266,204,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18266,205,40.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18266,207,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18266,208,203,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18266,255,45.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18266,269,8.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18266,291,6.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18266,301,265,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18266,303,2.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18266,306,210,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18266,307,364,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18266,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18266,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18266,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18266,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18266,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18266,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18266,606,0.334,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18268,203,7.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18268,204,6.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18268,205,32.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18268,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18268,208,213,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18268,255,52.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18268,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18268,291,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18268,301,107,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18268,303,2.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18268,306,134,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18268,307,495,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18268,320,54,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18268,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18268,401,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18268,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18268,601,82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18268,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18268,606,1.533,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18269,203,7.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18269,204,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18269,205,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18269,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18269,208,229,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18269,255,54.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18269,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18269,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18269,301,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18269,303,1.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18269,306,134,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18269,307,479,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18269,320,124,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (18269,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18269,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18269,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18269,601,116,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18269,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18269,606,2.723,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18270,203,7.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18270,204,13.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18270,205,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18270,207,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18270,208,337,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18270,255,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18270,269,2.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18270,291,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18270,301,278,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18270,303,3.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18270,306,144,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18270,307,668,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18270,320,41,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18270,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18270,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18270,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18270,601,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18270,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18270,606,2.108,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18271,203,8.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18271,204,6.9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18271,205,79,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18271,207,0.7,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18271,208,417,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18271,255,5.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18271,269,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18271,291,3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18271,301,25,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18271,303,3.6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18271,306,112,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18271,307,256,'100g',6,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18271,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18271,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18271,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18271,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18271,601,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18271,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18271,606,1.222,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18272,203,7.9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18272,204,3.8,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18272,205,84.1,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18272,207,1.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18272,208,402,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18272,255,3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18272,269,25.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18272,291,1.7,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18272,301,44,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18272,303,4.43,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18272,306,145,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18272,307,298,'100g',6,1,'1994-11-14','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18272,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18272,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18272,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18272,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18272,601,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18272,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18272,606,0.573,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18273,203,6.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18273,204,11.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18273,205,41.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18273,207,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18273,208,296,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18273,255,37.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18273,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18273,291,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18273,301,200,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18273,303,2.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18273,306,121,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18273,307,467,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18273,320,40,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18273,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18273,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18273,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18273,601,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18273,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18273,606,2.156,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18274,203,4.49,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18274,204,16.07,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18274,205,53,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18274,207,1.46,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18274,208,375,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18274,255,24.96,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18274,269,31.47,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18274,291,1.1,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18274,301,44,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18274,303,1.3,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18274,306,121,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18274,307,336,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18274,320,21,'100g',2,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (18274,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18274,401,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18274,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18274,601,30,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18274,605,0.2,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18274,606,2.844,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18275,203,3.48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18275,204,3.25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18275,205,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18275,207,2.09,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18275,208,293,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18275,255,30.18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18275,269,32.73,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18275,291,1.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18275,301,18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18275,303,1.62,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18275,306,48,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18275,307,479,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18275,320,1,'100g',2,1,'2024-12-12','2008-01-08');
INSERT INTO `cndb_nutval` VALUES (18275,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18275,401,2.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18275,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18275,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18275,605,0.227,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18275,606,1.161,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18277,203,4.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18277,204,9.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18277,205,53.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18277,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18277,208,313,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18277,255,30.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18277,269,4.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18277,291,1.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18277,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18277,303,0.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18277,306,83,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18277,307,417,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18277,320,94,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18277,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18277,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18277,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18277,601,6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18277,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18277,606,1.398,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18278,203,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18278,204,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18278,205,40.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18278,207,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18278,208,285,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18278,255,39.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18278,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18278,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18278,301,189,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18278,303,2.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18278,306,123,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18278,307,441,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18278,320,38,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18278,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18278,401,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18278,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18278,601,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18278,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18278,606,2.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18279,203,5.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18279,204,8.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18279,205,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18279,207,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18279,208,305,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18279,255,32.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18279,269,17.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18279,291,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18279,301,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18279,303,2.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18279,306,69,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18279,307,385,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18279,320,52,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18279,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18279,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18279,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18279,601,26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18279,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18279,606,1.354,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18280,203,7.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18280,204,10.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18280,205,49.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18280,207,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18280,208,321,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18280,255,30.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18280,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18280,291,2.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18280,301,75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18280,303,1.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18280,306,131,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18280,307,795,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18280,320,41,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18280,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18280,401,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18280,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18280,601,62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18280,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18280,606,2.797,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18281,203,5.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18281,204,11.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18281,205,57.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18281,207,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18281,208,346,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18281,255,23.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18281,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18281,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18281,301,19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18281,303,1.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18281,306,92,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18281,307,430,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18281,320,18,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18281,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18281,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18281,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18281,601,13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18281,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18281,606,1.681,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18282,203,7.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18282,204,12.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18282,205,44.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18282,207,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18282,208,316,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18282,255,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18282,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18282,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18282,301,259,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18282,303,2.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18282,306,145,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18282,307,585,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18282,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18282,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18282,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18282,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18282,601,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18282,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18282,606,2.311,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18283,203,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18283,204,7.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18283,205,48.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18283,207,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18283,208,270,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18283,255,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18283,269,8.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18283,291,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18283,301,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18283,303,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18283,306,507,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18283,307,393,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18283,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18283,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18283,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18283,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18283,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18283,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18283,606,1.087,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18284,203,7.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18284,204,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18284,205,73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18284,207,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18284,208,396,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18284,255,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18284,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18284,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18284,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18284,303,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18284,306,200,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18284,307,700,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18284,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18284,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18284,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18284,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18284,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18284,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18284,606,2.939,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18288,203,5.23,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18288,204,6.83,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18288,205,37.75,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18288,207,1.82,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18288,208,233,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18288,255,48.37,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18288,269,8.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18288,291,1,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18288,301,78,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18288,303,5.67,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18288,306,90,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18288,307,461,'100g',1,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18288,320,453,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (18288,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18288,401,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18288,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18288,601,18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18288,605,0.03,'100g',3,1,'2006-02-23','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18288,606,1.162,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18289,203,9.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18289,204,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18289,205,73.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18289,207,4.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18289,208,368,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18289,255,9.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18289,269,16.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18289,291,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18289,301,344,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18289,303,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18289,306,191,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18289,307,1082,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18289,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18289,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18289,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18289,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18289,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18289,605,0.383,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18289,606,0.822,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18290,203,5.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18290,204,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18290,205,36.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18290,207,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18290,208,194,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18290,255,53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18290,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18290,291,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18290,301,126,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18290,303,1.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18290,306,175,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18290,307,628,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18290,320,10,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18290,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18290,401,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18290,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18290,601,12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18290,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18290,606,0.507,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18291,203,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18291,204,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18291,205,73.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18291,207,5.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18291,208,355,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18291,255,9.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18291,269,2.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18291,291,5.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18291,301,342,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18291,303,3.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18291,306,191,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18291,307,1148,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18291,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18291,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18291,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18291,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18291,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18291,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18291,606,0.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18292,203,7.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18292,204,7.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18292,205,28.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18292,207,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18292,208,218,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18292,255,52.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18292,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18292,291,1.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18292,301,215,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18292,303,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18292,306,199,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18292,307,505,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18292,320,71,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18292,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18292,401,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18292,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18292,601,71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18292,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18292,606,2.045,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18293,203,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18293,204,9.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18293,205,28.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18293,207,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18293,208,227,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18293,255,52.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18293,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18293,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18293,301,219,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18293,303,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18293,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18293,307,439,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18293,320,54,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18293,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18293,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18293,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18293,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18293,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18293,606,2.122,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18294,203,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18294,204,9.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18294,205,29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18294,207,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18294,208,222,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18294,255,53.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18294,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18294,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18294,301,206,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18294,303,1.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18294,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18294,307,412,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18294,320,50,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18294,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18294,401,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18294,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18294,601,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18294,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18294,606,1.986,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18295,203,10.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18295,204,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18295,205,71.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18295,207,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18295,208,340,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18295,255,9.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18295,269,7.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18295,291,8.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18295,301,476,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18295,303,4.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18295,306,316,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18295,307,684,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18295,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18295,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18295,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18295,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18295,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18295,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18295,606,0.439,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18297,203,8.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18297,204,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18297,205,73.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18297,207,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18297,208,349,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18297,255,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18297,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18297,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18297,301,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18297,303,3.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18297,306,676,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18297,307,456,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18297,320,6,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18297,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18297,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18297,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18297,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18297,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18297,606,0.202,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18299,203,12.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18299,204,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18299,205,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18299,207,5.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18299,208,344,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18299,255,8.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18299,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18299,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18299,301,449,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18299,303,7.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18299,306,445,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18299,307,1419,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18299,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18299,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18299,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18299,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18299,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18299,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18299,606,0.244,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18300,203,8.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18300,204,6.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18300,205,29.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18300,207,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18300,208,208,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18300,255,52.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18300,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18300,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18300,301,250,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18300,303,3.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18300,306,279,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18300,307,572,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18300,320,64,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18300,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18300,401,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18300,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18300,601,61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18300,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18300,606,1.749,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18301,203,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18301,204,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18301,205,34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18301,207,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18301,208,237,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18301,255,52.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18301,269,15.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18301,291,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18301,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18301,303,0.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18301,306,65,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18301,307,201,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18301,320,32,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (18301,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18301,401,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18301,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18301,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18301,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18301,606,3.797,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18302,203,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18302,204,12.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18302,205,37.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18302,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18302,208,265,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18302,255,47.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18302,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18302,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18302,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18302,303,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18302,306,79,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18302,307,211,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18302,320,11,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18302,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18302,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18302,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18302,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18302,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18302,606,3.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18303,203,3.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18303,204,12.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18303,205,31.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18303,207,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18303,208,251,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18303,255,50.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18303,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18303,291,0.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18303,301,73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18303,303,0.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18303,306,113,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18303,307,290,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18303,320,95,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18303,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18303,401,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18303,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18303,601,29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18303,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18303,606,6.904,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18304,203,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18304,204,13.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18304,205,32.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18304,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18304,208,269,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18304,255,47.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18304,269,12.06,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18304,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18304,301,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18304,303,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18304,306,165,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18304,307,240,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18304,320,61,'100g',2,1,'2024-12-12','2003-01-06');
INSERT INTO `cndb_nutval` VALUES (18304,328,0.8,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18304,401,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18304,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18304,601,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18304,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18304,606,3.758,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18305,203,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18305,204,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18305,205,34.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18305,207,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18305,208,232,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18305,255,52.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18305,269,9.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18305,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18305,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18305,303,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18305,306,50,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18305,307,287,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18305,320,44,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18305,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18305,401,2.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18305,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18305,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18305,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18305,606,1.679,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18306,203,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18306,204,11.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18306,205,33.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18306,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18306,208,245,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18306,255,51.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18306,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18306,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18306,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18306,303,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18306,306,50,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18306,307,185,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18306,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18306,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18306,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18306,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18306,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18306,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18306,606,2.911,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18308,203,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18308,204,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18308,205,39.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18308,207,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18308,208,260,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18308,255,46.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18308,269,14.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18308,291,0.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18308,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18308,303,0.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18308,306,81,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18308,307,246,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18308,320,52,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18308,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18308,401,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18308,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18308,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18308,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18308,606,2.562,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18309,203,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18309,204,12.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18309,205,38.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18309,207,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18309,208,270,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18309,255,45.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18309,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18309,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18309,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18309,303,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18309,306,77,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18309,307,191,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18309,320,29,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18309,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18309,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18309,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18309,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18309,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18309,606,2.985,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18310,203,4.15,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18310,204,22.41,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18310,205,38.44,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18310,207,1.08,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18310,208,353,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18310,255,33.92,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18310,269,27.39,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18310,291,0.8,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18310,301,66,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18310,303,1.49,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18310,306,161,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18310,307,266,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18310,320,46,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (18310,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18310,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18310,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18310,601,12,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (18310,605,2.49,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18310,606,12.449,'100g',6,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18312,203,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18312,204,15.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18312,205,29.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18312,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18312,208,260,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18312,255,49.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18312,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18312,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18312,301,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18312,303,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18312,306,285,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18312,307,460,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18312,320,124,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18312,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18312,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18312,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18312,601,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18312,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18312,606,8.195,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18313,203,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18313,204,16.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18313,205,37.3,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18313,207,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18313,208,298,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18313,255,43.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18313,269,18.52,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18313,291,1.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18313,301,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18313,303,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18313,306,65,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18313,307,204,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18313,320,27,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18313,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18313,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18313,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18313,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18313,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18313,606,6.976,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18314,203,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18314,204,17.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18314,205,28.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18314,207,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18314,208,276,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18314,255,49.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18314,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18314,291,0.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18314,301,72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18314,303,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18314,306,141,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18314,307,329,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18314,320,95,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18314,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18314,401,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18314,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18314,601,23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18314,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18314,606,8.934,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18316,203,5.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18316,204,13.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18316,205,30.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18316,207,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18316,208,260,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18316,255,49.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18316,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18316,291,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18316,301,81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18316,303,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18316,306,175,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18316,307,335,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18316,320,26,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18316,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18316,401,0.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18316,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18316,601,35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18316,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18316,606,5.854,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18317,203,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18317,204,11.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18317,205,20.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18317,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18317,208,210,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18317,255,60.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18317,269,11.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18317,291,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18317,301,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18317,303,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18317,306,106,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18317,307,275,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18317,320,57,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18317,328,0.8,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18317,401,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18317,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18317,601,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18317,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18317,606,2.349,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18319,203,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18319,204,16.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18319,205,42.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18319,207,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18319,208,316,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18319,255,37.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18319,269,21.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18319,291,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18319,301,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18319,303,1.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18319,306,65,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18319,307,333,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18319,320,5,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18319,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18319,401,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18319,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18319,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18319,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18319,606,2.457,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18320,203,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18320,204,8.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18320,205,47.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18320,207,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18320,208,268,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18320,255,41.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18320,269,23.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18320,291,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18320,301,56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18320,303,0.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18320,306,89,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18320,307,172,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18320,320,51,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18320,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18320,401,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18320,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18320,601,45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18320,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18320,606,1.766,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18321,203,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18321,204,12.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18321,205,39.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18321,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18321,208,285,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18321,255,43.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18321,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18321,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18321,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18321,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18321,306,65,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18321,307,242,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18321,320,43,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18321,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18321,401,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18321,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18321,601,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18321,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18321,606,3.185,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18322,203,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18322,204,10.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18322,205,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18322,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18322,208,289,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18322,255,37.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18322,269,28.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18322,291,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18322,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18322,303,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18322,306,203,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18322,307,254,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18322,320,1,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18322,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18322,401,5.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18322,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18322,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18322,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18322,606,2.682,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18323,203,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18323,204,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18323,205,32.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18323,207,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18323,208,224,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18323,255,54.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18323,269,16.23,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18323,291,0.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18323,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18323,303,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18323,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18323,307,217,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18323,320,10,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18323,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18323,401,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18323,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18323,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18323,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18323,606,1.508,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18324,203,4.5,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18324,204,16.69,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18324,205,59.61,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18324,207,0.95,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18324,208,407,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18324,255,18.25,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18324,269,25.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18324,291,2.1,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18324,301,22,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18324,303,0.93,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18324,306,99,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18324,307,275,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18324,320,51,'100g',2,1,'2024-12-12','2007-01-10');
INSERT INTO `cndb_nutval` VALUES (18324,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18324,401,0,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18324,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18324,601,42,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18324,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18324,606,2.654,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18325,203,4.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18325,204,22.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18325,205,52.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18325,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18325,208,412,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18325,255,19.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18325,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18325,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18325,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18325,303,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18325,306,133,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18325,307,262,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18325,320,82,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (18325,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18325,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18325,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18325,601,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18325,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18325,606,3.989,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18326,203,3.9,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18326,204,9.75,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18326,205,34.83,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18326,207,1.14,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18326,208,243,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18326,255,50.39,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18326,269,18.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18326,291,1.8,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18326,301,64,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18326,303,0.9,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18326,306,167,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18326,307,239,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18326,320,448,'100g',2,1,'2024-12-12','2007-01-11');
INSERT INTO `cndb_nutval` VALUES (18326,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18326,401,0,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18326,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18326,601,26,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18326,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18326,606,1.988,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18327,203,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18327,204,9.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18327,205,26.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18327,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18327,208,204,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18327,255,58.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18327,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18327,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18327,301,94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18327,303,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18327,306,186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18327,307,225,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18327,320,426,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18327,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18327,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18327,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18327,601,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18327,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18327,606,3.171,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18328,203,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18328,204,14.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18328,205,32.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18328,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18328,208,278,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18328,255,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18328,269,12.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18328,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18328,301,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18328,303,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18328,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18328,307,260,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18328,320,83,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18328,328,1.2,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18328,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18328,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18328,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18328,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18328,606,4.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18332,203,6.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18332,204,31.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18332,205,52.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18332,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18332,208,518,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18332,255,7.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18332,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18332,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18332,301,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18332,303,2.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18332,306,64,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18332,307,753,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18332,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18332,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18332,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18332,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18332,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18332,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18332,606,7.974,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18333,203,6.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18333,204,30.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18333,205,50.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18333,207,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18333,208,501,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18333,255,10.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18333,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18333,291,1.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18333,301,60,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18333,303,2.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18333,306,62,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18333,307,729,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18333,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18333,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18333,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18333,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18333,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18333,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18333,606,7.711,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18334,203,6.16,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18334,204,26.07,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18334,205,48.62,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18334,207,1.33,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18334,208,457,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18334,255,17.82,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18334,269,3.72,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18334,291,2.5,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18334,301,19,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18334,303,2.6,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18334,306,97,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18334,307,409,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18334,320,0,'100g',2,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (18334,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18334,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18334,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18334,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18334,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18334,606,8.159,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18335,203,6.5,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18335,204,28.59,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18335,205,56.24,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18335,207,1.49,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18335,208,508,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18335,255,7.18,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18335,269,4.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18335,291,3.3,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18335,301,21,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18335,303,2.8,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18335,306,114,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18335,307,467,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18335,320,0,'100g',2,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (18335,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18335,401,0,'100g',4,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18335,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18335,601,0,'100g',4,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18335,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18335,606,9.277,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18336,203,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18336,204,34.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18336,205,47.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18336,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18336,208,527,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18336,255,9.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18336,269,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18336,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18336,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18336,303,2.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18336,306,67,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18336,307,542,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18336,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18336,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18336,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18336,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18336,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18336,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18336,606,8.622,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18337,203,7.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18337,204,38.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18337,205,45.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18337,207,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18337,208,551,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18337,255,8.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18337,269,0.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18337,291,1.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18337,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18337,303,2.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18337,306,61,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18337,307,249,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18337,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18337,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18337,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18337,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18337,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18337,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18337,606,9.643,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18338,203,7.1,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18338,204,6,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18338,205,52.6,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18338,207,1.6,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18338,208,299,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18338,255,32.6,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18338,269,0.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18338,291,1.9,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18338,301,11,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18338,303,3.21,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18338,306,74,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18338,307,483,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18338,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18338,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18338,401,0,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18338,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18338,601,0,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18338,605,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18338,606,1.47,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18339,203,10.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18339,204,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18339,205,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18339,207,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18339,208,371,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18339,255,11.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18339,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18339,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18339,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18339,303,2.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18339,306,100,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18339,307,906,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18339,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18339,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18339,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18339,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18339,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18339,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18339,606,0.983,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18342,203,10.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18342,204,6.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18342,205,52.04,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18342,207,2.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18342,208,310,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18342,255,28.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18342,269,5.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18342,291,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18342,301,178,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18342,303,3.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18342,306,139,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18342,307,467,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18342,320,1,'100g',2,1,'2024-12-12','2005-01-10');
INSERT INTO `cndb_nutval` VALUES (18342,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18342,401,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18342,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18342,601,4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18342,605,0,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18342,606,1.375,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18344,203,9.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18344,204,6.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18344,205,52,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18344,207,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18344,208,307,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18344,255,30.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18344,269,4.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18344,291,3.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18344,301,59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18344,303,3.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18344,306,104,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18344,307,566,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18344,320,5,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18344,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18344,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18344,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18344,601,50,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18344,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18344,606,1.577,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18345,203,9.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18345,204,4.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18345,205,40.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18345,207,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18345,208,236,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18345,255,44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18345,269,6.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18345,291,4.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18345,301,85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18345,303,4.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18345,306,121,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18345,307,413,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18345,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18345,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18345,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18345,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18345,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18345,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18345,606,0.619,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18346,203,10.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18346,204,3.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18346,205,53.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18346,207,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18346,208,286,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18346,255,30.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18346,269,1.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18346,291,4.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18346,301,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18346,303,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18346,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18346,307,650,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18346,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18346,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18346,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18346,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18346,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18346,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18346,606,0.605,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18347,203,8.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18347,204,6.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18347,205,46,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18347,207,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18347,208,273,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18347,255,37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18347,269,1.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18347,291,3.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18347,301,176,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18347,303,3.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18347,306,115,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18347,307,524,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18347,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18347,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18347,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18347,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18347,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18347,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18347,606,1.497,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18348,203,8.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18348,204,4.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18348,205,51.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18348,207,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18348,208,266,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18348,255,33.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18348,269,8.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18348,291,7.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18348,301,106,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18348,303,2.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18348,306,272,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18348,307,521,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18348,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18348,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18348,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18348,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18348,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18348,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18348,606,0.836,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18349,203,8.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18349,204,4.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18349,205,50.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18349,207,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18349,208,277,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18349,255,34.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18349,269,0.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18349,291,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18349,301,91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18349,303,2.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18349,306,114,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18349,307,574,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18349,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18349,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18349,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18349,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18349,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18349,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18349,606,0.962,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18350,203,9.77,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18350,204,3.91,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18350,205,50.12,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18350,207,1.85,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18350,208,279,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18350,255,34.34,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18350,269,7.28,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18350,291,1.8,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18350,301,144,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18350,303,3.43,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18350,306,122,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18350,307,494,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18350,320,29,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (18350,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18350,401,1.3,'100g',1,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18350,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18350,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18350,605,0.027,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18350,606,0.842,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18351,203,9.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18351,204,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18351,205,44.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18351,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18351,208,263,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18351,255,38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18351,269,6.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18351,291,3.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18351,301,95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18351,303,3.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18351,306,160,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18351,307,458,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18351,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18351,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18351,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18351,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18351,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18351,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18351,606,1.39,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18353,203,9.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18353,204,4.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18353,205,52.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18353,207,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18353,208,293,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18353,255,31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18353,269,1.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18353,291,2.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18353,301,95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18353,303,3.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18353,306,108,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18353,307,544,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18353,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18353,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18353,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18353,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18353,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18353,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18353,606,0.606,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18354,203,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18354,204,11.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18354,205,41.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18354,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18354,208,274,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18354,255,43.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18354,269,25.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18354,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18354,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18354,303,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18354,306,149,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18354,307,135,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18354,320,6,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18354,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18354,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18354,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18354,601,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18354,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18354,606,2.044,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18355,203,7.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18355,204,18.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18355,205,43.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18355,207,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18355,208,360,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18355,255,29.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18355,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18355,291,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18355,301,118,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18355,303,0.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18355,306,137,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18355,307,357,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18355,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18355,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18355,401,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18355,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18355,601,76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18355,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18355,606,6.059,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18356,203,6.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18356,204,16.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18356,205,50.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18356,207,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18356,208,372,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18356,255,24.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18356,269,31.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18356,291,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18356,301,72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18356,303,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18356,306,111,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18356,307,304,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18356,320,62,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18356,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18356,401,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18356,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18356,601,66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18356,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18356,606,3.079,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18357,203,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18357,204,12.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18357,205,51.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18357,207,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18357,208,333,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18357,255,28.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18357,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18357,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18357,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18357,303,2.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18357,306,58,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18357,307,765,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18357,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18357,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18357,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18357,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18357,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18357,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18357,606,3.081,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18358,203,5.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18358,204,13.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18358,205,56.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18358,207,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18358,208,362,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18358,255,22.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18358,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18358,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18358,301,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18358,303,2.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18358,306,63,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18358,307,832,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18358,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18358,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18358,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18358,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18358,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18358,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18358,606,3.348,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18360,203,6.41,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18360,204,21.79,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18360,205,63.49,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18360,207,1.9,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18360,208,476,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18360,255,6.4,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18360,269,1.5,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18360,291,6.7,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18360,301,100,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18360,303,1.64,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18360,306,231,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18360,307,324,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18360,320,1,'100g',2,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (18360,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18360,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18360,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18360,601,0,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18360,605,0.172,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18360,606,7.105,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18362,203,4.2,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18362,204,9.95,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18362,205,70.32,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18362,207,1.2,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18362,208,388,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18362,255,14.33,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18362,269,26.13,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18362,291,1,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18362,301,16,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18362,303,5.51,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18362,306,102,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18362,307,334,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18362,320,202,'100g',2,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (18362,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18362,401,0,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18362,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18362,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18362,605,0.028,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18362,606,3.615,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18363,203,5.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18363,204,2.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18363,205,44.64,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18363,207,0.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18363,208,218,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18363,255,45.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18363,269,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18363,291,6.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18363,301,81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18363,303,1.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18363,306,186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18363,307,45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18363,320,0,'100g',2,1,'2024-12-12','2004-01-02');
INSERT INTO `cndb_nutval` VALUES (18363,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18363,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18363,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18363,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18363,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18363,606,0.453,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18364,203,8.2,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18364,204,7.99,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18364,205,49.38,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18364,207,2.45,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18364,208,306,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18364,255,31.98,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18364,269,3.71,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18364,291,3.5,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18364,301,146,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18364,303,3.63,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18364,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18364,307,736,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18364,320,0,'100g',2,1,'2024-12-12','2004-01-03');
INSERT INTO `cndb_nutval` VALUES (18364,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18364,401,0,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18364,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18364,601,0,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18364,605,0.052,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18364,606,2.924,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18365,203,6.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18365,204,9.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18365,205,42.98,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18365,207,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18365,208,285,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18365,255,37.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18365,269,4.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18365,291,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18365,301,308,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18365,303,5.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18365,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18365,307,638,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18365,320,381,'100g',2,1,'2024-12-12','2004-01-10');
INSERT INTO `cndb_nutval` VALUES (18365,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18365,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18365,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18365,601,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18365,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18365,606,1.531,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18367,203,7.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18367,204,14.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18367,205,32.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18367,207,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18367,208,291,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18367,255,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18367,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18367,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18367,301,255,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18367,303,2.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18367,306,159,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18367,307,511,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18367,320,65,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18367,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18367,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18367,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18367,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18367,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18367,606,2.866,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18368,203,9.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18368,204,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18368,205,57.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18368,207,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18368,208,291,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18368,255,28.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18368,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18368,291,1.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18368,301,47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18368,303,3.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18368,306,82,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18368,307,572,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18368,320,4,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18368,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18368,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18368,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18368,601,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18368,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18368,606,0.263,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18369,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18369,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18369,205,27.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18369,207,67.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18369,208,53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18369,255,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18369,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18369,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18369,301,5876,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18369,303,11.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18369,306,20,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18369,307,10600,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18369,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18369,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18369,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18369,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (18369,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18369,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18369,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18370,203,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18370,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18370,205,24.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18370,207,71.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18370,208,51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18370,255,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18370,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18370,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18370,301,7364,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18370,303,11.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18370,306,5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18370,307,7893,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18370,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18370,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18370,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18370,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (18370,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18370,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18370,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18371,203,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18371,204,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18371,205,46.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18371,207,46.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18371,208,97,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18371,255,6.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18371,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18371,291,2.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18371,301,4332,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18371,303,8.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18371,306,10100,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18371,307,90,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18371,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18371,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18371,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18371,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (18371,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18371,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18371,606,0.073,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18372,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18372,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18372,205,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18372,207,36.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18372,208,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18372,255,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18372,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18372,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18372,301,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18372,303,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18372,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18372,307,27360,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18372,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18372,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18372,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18372,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (18372,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18372,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18372,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18373,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18373,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18373,205,61.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18373,207,36.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18373,208,258,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18373,255,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18373,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18373,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18373,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18373,303,3.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18373,306,16500,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18373,307,52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18373,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18373,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18373,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18373,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (18373,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18373,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18373,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18374,203,8.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18374,204,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18374,205,18.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18374,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18374,208,105,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18374,255,69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18374,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18374,291,8.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18374,301,19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18374,303,3.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18374,306,601,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18374,307,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18374,320,0,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (18374,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18374,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18374,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (18374,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18374,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18374,606,0.243,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18375,203,40.44,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18375,204,7.61,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18375,205,41.22,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18375,207,5.65,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18375,208,325,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18375,255,5.08,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18375,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18375,291,26.9,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18375,301,30,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18375,303,2.17,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18375,306,955,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18375,307,51,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18375,320,0,'100g',1,1,'2024-12-12','2009-01-01');
INSERT INTO `cndb_nutval` VALUES (18375,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18375,401,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18375,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (18375,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18375,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18375,606,1.001,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18376,203,14.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18376,204,5.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18376,205,68.49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18376,207,5.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18376,208,383,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18376,255,6.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18376,269,5.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18376,291,4.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18376,301,182,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18376,303,4.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18376,306,231,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18376,307,2100,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18376,320,10,'100g',2,1,'2024-12-12','2017-01-07');
INSERT INTO `cndb_nutval` VALUES (18376,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18376,401,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18376,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18376,601,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18376,605,NULL,'100g',NULL,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (18376,606,1.391,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18377,203,6.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18377,204,17.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18377,205,66.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18377,207,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18377,208,447,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18377,255,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18377,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18377,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18377,301,105,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18377,303,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18377,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18377,307,598,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18377,320,160,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (18377,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18377,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18377,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18377,601,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18377,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18377,606,3.581,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18378,203,5.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18378,204,28.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18378,205,58.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18378,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18378,208,488,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18378,255,5.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18378,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18378,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18378,301,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18378,303,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18378,306,221,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18378,307,341,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18378,320,139,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18378,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18378,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18378,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18378,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18378,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18378,606,14.071,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18383,203,13.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18383,204,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18383,205,48.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18383,207,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18383,208,270,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18383,255,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18383,269,1.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18383,291,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18383,301,136,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18383,303,4.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18383,306,346,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18383,307,444,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18383,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18383,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18383,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18383,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18383,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18383,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18383,606,0.364,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18384,203,9.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18384,204,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18384,205,47.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18384,207,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18384,208,264,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18384,255,35.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18384,269,5.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18384,291,5.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18384,301,75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18384,303,3.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18384,306,212,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18384,307,292,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18384,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18384,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18384,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18384,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18384,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18384,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18384,606,0.771,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18386,203,4.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18386,204,10.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18386,205,56.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18386,207,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18386,208,333,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18386,255,26.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18386,269,12.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18386,291,1.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18386,301,14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18386,303,0.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18386,306,88,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18386,307,444,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18386,320,101,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18386,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18386,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18386,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18386,601,5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18386,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18386,606,1.551,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18388,203,5.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18388,204,9.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18388,205,55.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18388,207,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18388,208,313,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18388,255,27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18388,269,23.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18388,291,8.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18388,301,39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18388,303,2.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18388,306,177,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18388,307,527,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18388,320,56,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18388,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18388,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18388,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18388,601,9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18388,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18388,606,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18390,203,6.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18390,204,9.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18390,205,28.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18390,207,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18390,208,227,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18390,255,52.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18390,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18390,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18390,301,157,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18390,303,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18390,306,145,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18390,307,522,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18390,320,30,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18390,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18390,401,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18390,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18390,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18390,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18390,606,1.832,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18396,203,8.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18396,204,7.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18396,205,53.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18396,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18396,208,316,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18396,255,29.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18396,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18396,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18396,301,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18396,303,2.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18396,306,152,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18396,307,415,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18396,320,87,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18396,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18396,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18396,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18396,601,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18396,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18396,606,1.795,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18399,203,4.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18399,204,24.4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18399,205,63.9,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18399,207,1.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18399,208,484,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18399,255,6.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18399,269,37.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18399,291,1.5,'100g',3,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18399,301,20,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18399,303,2.12,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18399,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18399,307,560,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18399,320,191,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18399,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18399,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18399,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18399,601,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18399,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18399,606,5.092,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18400,203,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18400,204,3.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18400,205,77.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18400,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18400,208,391,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18400,255,7.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18400,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18400,291,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18400,301,36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18400,303,4.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18400,306,83,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18400,307,285,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18400,320,7,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18400,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18400,401,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18400,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18400,601,45,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18400,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18400,606,0.936,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18401,203,3.7,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18401,204,36.2,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18401,205,50.2,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18401,207,1.4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18401,208,531,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18401,255,8.5,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18401,269,7.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18401,291,0.1,'100g',3,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18401,301,42,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18401,303,1.63,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18401,306,79,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18401,307,515,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18401,320,269,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18401,328,0.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18401,401,0.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18401,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18401,601,39,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18401,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18401,606,7.434,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18402,203,5.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18402,204,30.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18402,205,42.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18402,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18402,208,469,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18402,255,19.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18402,269,0.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18402,291,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18402,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18402,303,2.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18402,306,59,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18402,307,482,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18402,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18402,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18402,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18402,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18402,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18402,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18402,606,7.674,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18403,203,7.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18403,204,9.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18403,205,49.29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18403,207,3.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18403,208,312,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18403,255,30.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18403,269,5.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18403,291,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18403,301,307,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18403,303,6.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18403,306,144,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18403,307,467,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18403,320,398,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (18403,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18403,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18403,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18403,601,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18403,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18403,606,1.638,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18406,203,10.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18406,204,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18406,205,53.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18406,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18406,208,275,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18406,255,32.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18406,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18406,291,2.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18406,301,18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18406,303,3.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18406,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18406,307,534,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18406,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18406,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18406,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18406,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18406,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18406,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18406,606,0.22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18407,203,10.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18407,204,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18407,205,53.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18407,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18407,208,275,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18407,255,32.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18407,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18407,291,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18407,301,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18407,303,1.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18407,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18407,307,534,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18407,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18407,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18407,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18407,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18407,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18407,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18407,606,0.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18408,203,10.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18408,204,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18408,205,53.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18408,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18408,208,275,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18408,255,32.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18408,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18408,291,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18408,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18408,303,1.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18408,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18408,307,534,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18408,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18408,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18408,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18408,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18408,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18408,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18408,606,0.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18412,203,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18412,204,12.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18412,205,69.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18412,207,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18412,208,418,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18412,255,7.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18412,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18412,291,6.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18412,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18412,303,0.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18412,306,113,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18412,307,1111,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18412,320,6,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18412,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18412,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18412,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18412,601,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18412,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18412,606,3.091,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18413,203,9.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18413,204,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18413,205,55.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18413,207,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18413,208,275,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18413,255,32.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18413,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18413,291,2.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18413,301,86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18413,303,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18413,306,120,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18413,307,536,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18413,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18413,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18413,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18413,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18413,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18413,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18413,606,0.166,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18414,203,7.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18414,204,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18414,205,52.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18414,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18414,208,274,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18414,255,33.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18414,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18414,291,4.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18414,301,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18414,303,1.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18414,306,227,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18414,307,390,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18414,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18414,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18414,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18414,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18414,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18414,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18414,606,1.081,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18416,203,8.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18416,204,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18416,205,49.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18416,207,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18416,208,267,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18416,255,36.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18416,269,4.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18416,291,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18416,301,108,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18416,303,3.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18416,306,119,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18416,307,298,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18416,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18416,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18416,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18416,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18416,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18416,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18416,606,0.811,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18417,203,6.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18417,204,23.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18417,205,46.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18417,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18417,208,418,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18417,255,21.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18417,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18417,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18417,301,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18417,303,0.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18417,306,123,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18417,307,351,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18417,320,33,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18417,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18417,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18417,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18417,601,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18417,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18417,606,5.797,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18418,203,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18418,204,17.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18418,205,52.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18418,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18418,208,389,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18418,255,23.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18418,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18418,291,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18418,301,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18418,303,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18418,306,106,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18418,307,400,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18418,320,35,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18418,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18418,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18418,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18418,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18418,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18418,606,4.647,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18419,203,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18419,204,9.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18419,205,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18419,207,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18419,208,423,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18419,255,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18419,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18419,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18419,301,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18419,303,0.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18419,306,72,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18419,307,665,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18419,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18419,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18419,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18419,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18419,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18419,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18419,606,2.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18420,203,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18420,204,11.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18420,205,78.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18420,207,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18420,208,432,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18420,255,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18420,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18420,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18420,301,135,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18420,303,0.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18420,306,82,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18420,307,657,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18420,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18420,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18420,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18420,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18420,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18420,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18420,606,1.738,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18421,203,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18421,204,18.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18421,205,68.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18421,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18421,208,467,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18421,255,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18421,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18421,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18421,301,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18421,303,0.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18421,306,111,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18421,307,351,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18421,320,160,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18421,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18421,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18421,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18421,601,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18421,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18421,606,11.051,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18422,203,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18422,204,22.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18422,205,66.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18422,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18422,208,481,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18422,255,4.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18422,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18422,291,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18422,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18422,303,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18422,306,135,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18422,307,315,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18422,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18422,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18422,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18422,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18422,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18422,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18422,606,7.476,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18423,203,10.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18423,204,9.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18423,205,59.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18423,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18423,208,363,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18423,255,19.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18423,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18423,291,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18423,301,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18423,303,3.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18423,306,113,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18423,307,147,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18423,320,167,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18423,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18423,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18423,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18423,601,221,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18423,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18423,606,3.022,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18424,203,12.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18424,204,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18424,205,76.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18424,207,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18424,208,390,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18424,255,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18424,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18424,291,6.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18424,301,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18424,303,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18424,306,202,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18424,307,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18424,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18424,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18424,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18424,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18424,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18424,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18424,606,0.445,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18425,203,9.5,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18425,204,8.85,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18425,205,74.34,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18425,207,3.28,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18425,208,421,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18425,255,4.03,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18425,269,2.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18425,291,2.9,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18425,301,119,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18425,303,5.13,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18425,306,724,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18425,307,198,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18425,320,0,'100g',2,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (18425,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18425,401,0,'100g',4,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18425,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18425,601,0,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18425,605,0.443,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18425,606,2.001,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (18426,203,9.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18426,204,11.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18426,205,71.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18426,207,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18426,208,434,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18426,255,4.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18426,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18426,291,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18426,301,119,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18426,303,5.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18426,306,128,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18426,307,766,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18426,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18426,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18426,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18426,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18426,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18426,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18426,606,2.932,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18427,203,7.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18427,204,25.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18427,205,61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18427,207,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18427,208,502,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18427,255,3.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18427,269,1.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18427,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18427,301,120,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18427,303,3.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18427,306,355,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18427,307,216,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18427,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18427,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18427,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18427,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18427,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18427,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18427,606,3.776,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18428,203,8.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18428,204,20.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18428,205,64.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18428,207,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18428,208,473,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18428,255,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18428,269,13.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18428,291,4.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18428,301,49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18428,303,4.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18428,306,203,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18428,307,190,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18428,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18428,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18428,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18428,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18428,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18428,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18428,606,5.178,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18429,203,8.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18429,204,17.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18429,205,68.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18429,207,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18429,208,443,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18429,255,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18429,269,0.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18429,291,10.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18429,301,50,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18429,303,3.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18429,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18429,307,186,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18429,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18429,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18429,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18429,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18429,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18429,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18429,606,3.393,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18430,203,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18430,204,22.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18430,205,44.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18430,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18430,208,403,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18430,255,24.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18430,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18430,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18430,301,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18430,303,0.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18430,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18430,307,371,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18430,320,4,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18430,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18430,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18430,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18430,601,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18430,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18430,606,5.681,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18431,203,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18431,204,18.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18431,205,47.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18431,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18431,208,371,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18431,255,27.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18431,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18431,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18431,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18431,303,0.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18431,306,83,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18431,307,354,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18431,320,22,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18431,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18431,401,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18431,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18431,601,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18431,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18431,606,2.826,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18432,203,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18432,204,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18432,205,54.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18432,207,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18432,208,293,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18432,255,30.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18432,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18432,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18432,301,119,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18432,303,3.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18432,306,131,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18432,307,376,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18432,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18432,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18432,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18432,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18432,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18432,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18432,606,0.892,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18433,203,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18433,204,18.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18433,205,47.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18433,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18433,208,371,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18433,255,27.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18433,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18433,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18433,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18433,303,0.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18433,306,83,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18433,307,354,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18433,320,53,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18433,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18433,401,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18433,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18433,601,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18433,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18433,606,2.826,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18434,203,10.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18434,204,25.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18434,205,58.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18434,207,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18434,208,503,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18434,255,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18434,269,0.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18434,291,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18434,301,151,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18434,303,4.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18434,306,106,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18434,307,458,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18434,320,17,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18434,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18434,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18434,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18434,601,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18434,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18434,606,9.638,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18435,203,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18435,204,18.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18435,205,47.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18435,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18435,208,371,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18435,255,27.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18435,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18435,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18435,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18435,303,0.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18435,306,83,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18435,307,354,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18435,320,60,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18435,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18435,401,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18435,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18435,601,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18435,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18435,606,2.826,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18436,203,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18436,204,22.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18436,205,44.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18436,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18436,208,403,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18436,255,25.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18436,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18436,291,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18436,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18436,303,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18436,306,108,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18436,307,342,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18436,320,4,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18436,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18436,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18436,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18436,601,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18436,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18436,606,5.813,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18437,203,7.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18437,204,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18437,205,46,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18437,207,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18437,208,235,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18437,255,42.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18437,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18437,291,2.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18437,301,52,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18437,303,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18437,306,131,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18437,307,464,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18437,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18437,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18437,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18437,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18437,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18437,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18437,606,0.259,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18438,203,7.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18438,204,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18438,205,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18438,207,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18438,208,235,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18438,255,42.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18438,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18438,291,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18438,301,174,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18438,303,0.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18438,306,131,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18438,307,464,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18438,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18438,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18438,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18438,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18438,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18438,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18438,606,0.259,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18439,203,7.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18439,204,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18439,205,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18439,207,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18439,208,235,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18439,255,42.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18439,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18439,291,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18439,301,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18439,303,0.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18439,306,131,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18439,307,464,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18439,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18439,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18439,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18439,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18439,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18439,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18439,606,0.259,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18443,203,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18443,204,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18443,205,34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18443,207,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18443,208,237,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18443,255,52.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18443,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18443,291,1.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18443,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18443,303,1.21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18443,306,65,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18443,307,266,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18443,320,29,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18443,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18443,401,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18443,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18443,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18443,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18443,606,3.797,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18444,203,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18444,204,16.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18444,205,42.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18444,207,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18444,208,316,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18444,255,37.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18444,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18444,291,2.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18444,301,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18444,303,1.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18444,306,65,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18444,307,374,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18444,320,9,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18444,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18444,401,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18444,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18444,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18444,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18444,606,2.457,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18445,203,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18445,204,16.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18445,205,42.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18445,207,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18445,208,316,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18445,255,37.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18445,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18445,291,2.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18445,301,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18445,303,1.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18445,306,65,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18445,307,374,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18445,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18445,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18445,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18445,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18445,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18445,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18445,606,2.457,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18446,203,3.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18446,204,29.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18446,205,44.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18446,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18446,208,457,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18446,255,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18446,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18446,291,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18446,301,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18446,303,0.38,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18446,306,98,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18446,307,576,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18446,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18446,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18446,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18446,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18446,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18446,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18446,606,4.357,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18447,203,10.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18447,204,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18447,205,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18447,207,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18447,208,371,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18447,255,11.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18447,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18447,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18447,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18447,303,0.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18447,306,100,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18447,307,906,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18447,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18447,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18447,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18447,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18447,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18447,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18447,606,0.983,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18448,203,7.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18448,204,22.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18448,205,62.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18448,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18448,208,468,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18448,255,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18448,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18448,291,7.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18448,301,160,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18448,303,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18448,306,179,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18448,307,15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18448,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18448,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18448,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18448,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18448,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18448,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18448,606,3.245,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18449,203,5.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18449,204,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18449,205,46.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18449,207,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18449,208,222,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18449,255,44.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18449,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18449,291,5.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18449,301,175,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18449,303,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18449,306,154,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18449,307,11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18449,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18449,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18449,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18449,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18449,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18449,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18449,606,0.334,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18450,203,8.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18450,204,7.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18450,205,55.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18450,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18450,208,325,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18450,255,26.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18450,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18450,291,3.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18450,301,39,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18450,303,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18450,306,131,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18450,307,478,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18450,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18450,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18450,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18450,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18450,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18450,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18450,606,1.745,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18451,203,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18451,204,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18451,205,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18451,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18451,208,283,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18451,255,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18451,269,34.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18451,291,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18451,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18451,303,2.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18451,306,110,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18451,307,341,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18451,320,29,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18451,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18451,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18451,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18451,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18451,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18451,606,0.259,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18453,203,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18453,204,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18453,205,84.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18453,207,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18453,208,404,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18453,255,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18453,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18453,291,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18453,301,155,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18453,303,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18453,306,65,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18453,307,604,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18453,320,4,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (18453,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18453,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18453,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18453,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18453,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18453,606,1.367,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18457,203,10.5,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18457,204,1.6,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18457,205,82.3,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18457,207,2.2,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18457,208,393,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18457,255,3.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18457,269,0.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18457,291,2.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18457,301,22,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18457,303,7.72,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18457,306,115,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18457,307,849,'100g',6,1,'1996-09-30','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18457,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18457,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18457,401,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18457,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18457,601,0,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18457,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18457,606,0.244,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18459,203,3.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18459,204,5.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18459,205,76.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18459,207,1.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18459,208,372,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18459,255,12.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18459,269,4.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18459,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18459,301,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18459,303,3.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18459,306,66,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18459,307,361,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18459,320,285,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (18459,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18459,401,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18459,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18459,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18459,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18459,606,1.393,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18566,203,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18566,204,8.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18566,205,77.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18566,207,2.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18566,208,407,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18566,255,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18566,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18566,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18566,301,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18566,303,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18566,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18566,307,760,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18566,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18566,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18566,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18566,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18566,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18566,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18566,606,1.865,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18927,203,8.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18927,204,24.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18927,205,58.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18927,207,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18927,208,490,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18927,255,4.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18927,269,12.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18927,291,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18927,301,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18927,303,2.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18927,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18927,307,878,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18927,320,11,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (18927,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18927,401,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18927,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18927,601,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18927,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18927,606,4.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18932,203,6.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18932,204,9.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18932,205,41.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18932,207,2.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18932,208,273,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18932,255,40.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18932,269,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18932,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18932,301,279,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18932,303,6.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18932,306,126,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18932,307,621,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18932,320,401,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (18932,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18932,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18932,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18932,601,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18932,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18932,606,1.898,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18933,203,7.42,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18933,204,9.49,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18933,205,48.39,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18933,207,3.13,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18933,208,309,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18933,255,31.57,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18933,269,4.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18933,291,2.6,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18933,301,299,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18933,303,6.59,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18933,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18933,307,710,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18933,320,438,'100g',2,1,'2024-12-12','2017-01-07');
INSERT INTO `cndb_nutval` VALUES (18933,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18933,401,0,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18933,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18933,601,13,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18933,605,NULL,'100g',NULL,1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18933,606,2.275,'100g',3,1,'2006-02-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (18934,203,6.92,'100g',1,1,'2006-05-02','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18934,204,9.4,'100g',1,1,'2006-05-02','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18934,205,44.16,'100g',3,1,'2006-05-02','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18934,207,3.04,'100g',1,1,'2006-05-02','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18934,208,289,'100g',3,1,'2006-05-02','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18934,255,36.48,'100g',1,1,'2006-05-02','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18934,269,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18934,291,2.4,'100g',1,1,'2006-05-02','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18934,301,125,'100g',1,1,'2006-05-02','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18934,303,6.53,'100g',1,1,'2006-05-02','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18934,306,110,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18934,307,663,'100g',1,1,'2006-05-02','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18934,320,429,'100g',1,1,'2024-12-12','2004-01-11');
INSERT INTO `cndb_nutval` VALUES (18934,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18934,401,0,'100g',1,1,'2006-05-02','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18934,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18934,601,16,'100g',1,1,'2006-05-02','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18934,605,NULL,'100g',NULL,1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (18934,606,2.057,'100g',3,1,'2006-05-02','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (18935,203,6.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18935,204,9.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18935,205,45.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18935,207,3.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18935,208,298,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18935,255,34.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18935,269,5.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18935,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18935,301,197,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18935,303,5.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18935,306,148,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18935,307,682,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18935,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18935,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18935,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18935,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18935,601,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18935,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18935,606,1.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18936,203,5.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18936,204,4.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18936,205,43.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18936,207,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18936,208,239,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18936,255,43.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18936,269,7.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18936,291,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18936,301,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18936,303,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18936,306,122,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18936,307,566,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18936,320,216,'100g',1,1,'2024-12-12','2004-01-12');
INSERT INTO `cndb_nutval` VALUES (18936,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18936,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18936,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18936,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18936,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18936,606,0.855,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18938,203,4.01,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18938,204,9.02,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18938,205,71.83,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18938,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18938,208,385,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18938,255,14.04,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18938,269,31,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18938,291,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18938,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18938,303,4.35,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18938,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18938,307,311,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18938,320,202,'100g',1,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (18938,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18938,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18938,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18938,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18938,605,0.034,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18938,606,3.091,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18939,203,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18939,204,11.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18939,205,72.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18939,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18939,208,409,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18939,255,10.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18939,269,28.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18939,291,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18939,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18939,303,3.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18939,306,81,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18939,307,354,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18939,320,467,'100g',1,1,'2024-12-12','2006-01-01');
INSERT INTO `cndb_nutval` VALUES (18939,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18939,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18939,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18939,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18939,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18939,606,2.637,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18940,203,4.23,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (18940,204,4.22,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (18940,205,50.05,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (18940,207,1.56,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (18940,208,255,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (18940,255,39.94,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (18940,269,27.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18940,291,4.2,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (18940,301,35,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (18940,303,2,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (18940,306,96,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18940,307,413,'100g',6,1,'2007-12-03','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18940,320,10,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (18940,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18940,401,0.9,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (18940,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18940,601,28,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (18940,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (18940,606,1.549,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (18942,203,5.1,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18942,204,24.83,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18942,205,64.3,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18942,207,1.39,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18942,208,501,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18942,255,4.37,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18942,269,18.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18942,291,1.9,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18942,301,29,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18942,303,2.6,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18942,306,113,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18942,307,471,'100g',6,1,'2009-01-25','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18942,320,0,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (18942,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18942,401,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18942,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18942,601,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18942,605,NULL,'100g',NULL,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18942,606,4.999,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18943,203,6.08,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18943,204,22.42,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18943,205,64.48,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18943,207,2.03,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18943,208,484,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18943,255,4.99,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18943,269,26.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18943,291,2.7,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18943,301,32,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18943,303,4.3,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18943,306,187,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18943,307,503,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18943,320,0,'100g',2,1,'2024-12-12','2007-01-09');
INSERT INTO `cndb_nutval` VALUES (18943,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18943,401,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18943,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18943,601,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18943,605,0,'100g',NULL,1,'2009-01-25','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (18943,606,4.725,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18944,203,2.17,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18944,204,11.5,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18944,205,44.54,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18944,207,0.7,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18944,208,290,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18944,255,41.09,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18944,269,22.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18944,291,1.6,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18944,301,14,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18944,303,0.91,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18944,306,76,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18944,307,200,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18944,320,18,'100g',2,1,'2024-12-12','2007-01-11');
INSERT INTO `cndb_nutval` VALUES (18944,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18944,401,5.7,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18944,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18944,601,0,'100g',6,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18944,605,NULL,'100g',NULL,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18944,606,2.313,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (18945,203,5.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18945,204,28.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18945,205,46.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18945,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18945,208,468,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18945,255,17.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18945,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18945,291,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18945,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18945,303,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18945,306,91,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18945,307,353,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18945,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18945,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18945,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18945,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18945,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18945,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18945,606,8.129,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18946,203,3.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18946,204,28.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18946,205,58.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18946,207,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18946,208,506,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18946,255,7.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18946,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18946,291,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18946,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18946,303,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18946,306,83,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18946,307,472,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18946,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18946,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18946,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18946,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18946,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18946,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18946,606,11.087,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18947,203,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18947,204,31.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18947,205,52.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18947,207,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18947,208,521,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18947,255,8.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18947,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18947,291,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18947,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18947,303,2.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18947,306,103,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18947,307,393,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18947,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18947,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18947,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18947,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18947,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18947,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18947,606,8.862,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18948,203,2.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18948,204,25.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18948,205,51.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18948,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18948,208,445,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18948,255,19.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18948,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18948,291,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18948,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18948,303,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18948,306,73,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18948,307,409,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18948,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18948,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18948,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18948,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18948,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18948,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18948,606,9.596,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18949,203,11.34,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18949,204,7.59,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18949,205,75.52,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18949,207,2.96,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18949,208,416,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18949,255,2.59,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18949,269,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18949,291,10.9,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18949,301,39,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18949,303,3.56,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18949,306,373,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18949,307,745,'100g',6,1,'2010-01-04','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (18949,320,0,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (18949,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18949,401,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18949,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18949,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18949,605,0.096,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18949,606,1.067,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18950,203,9.34,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18950,204,13.37,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18950,205,71.52,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18950,207,3.04,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18950,208,444,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18950,255,2.73,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18950,269,15.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18950,291,3.4,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18950,301,80,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18950,303,5.02,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18950,306,210,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18950,307,776,'100g',6,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18950,320,0,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (18950,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18950,401,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18950,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18950,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18950,605,0.201,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18950,606,2.112,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18951,203,5.8,'100g',6,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18951,204,10.1,'100g',6,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18951,205,45.68,'100g',3,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18951,207,2.8,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18951,208,297,'100g',3,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18951,255,35.62,'100g',6,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18951,269,13.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18951,291,1.5,'100g',6,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18951,301,357,'100g',6,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18951,303,6.4,'100g',6,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18951,306,74,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18951,307,529,'100g',6,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18951,320,429,'100g',2,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (18951,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18951,401,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18951,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18951,601,21,'100g',6,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18951,605,0.2,'100g',6,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18951,606,3.567,'100g',3,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18952,203,6.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18952,204,23.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18952,205,64.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18952,207,2.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18952,208,474,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18952,255,3.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18952,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18952,291,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18952,301,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18952,303,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18952,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18952,307,657,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18952,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18952,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18952,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18952,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18952,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18952,605,0.163,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18952,606,7.011,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18953,203,7.12,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18953,204,17.12,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18953,205,47.84,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18953,207,2.44,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18953,208,374,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18953,255,25.48,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18953,269,24.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18953,291,0.7,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18953,301,73,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18953,303,0.98,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18953,306,350,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18953,307,510,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18953,320,141,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (18953,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18953,401,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18953,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18953,601,59,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18953,605,2.027,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18953,606,4.612,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (18954,203,7.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18954,204,17.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18954,205,51.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18954,207,1.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18954,208,390,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18954,255,22.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18954,269,18.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18954,291,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18954,301,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18954,303,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18954,306,210,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18954,307,390,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18954,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18954,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18954,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18954,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18954,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18954,605,0.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18954,606,3.042,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18955,203,9.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18955,204,11.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18955,205,56.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18955,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18955,208,367,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18955,255,21.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18955,269,12.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18955,291,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18955,301,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18955,303,2.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18955,306,103,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18955,307,228,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18955,320,5,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (18955,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18955,401,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18955,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18955,601,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18955,605,1.103,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18955,606,2.183,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18959,203,5.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18959,204,18.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18959,205,47.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18959,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18959,208,379,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18959,255,27.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18959,269,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18959,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18959,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18959,303,2.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18959,306,103,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18959,307,231,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18959,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (18959,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18959,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18959,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18959,601,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18959,605,2.853,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18959,606,5.535,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18963,203,8.36,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18963,204,16.61,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18963,205,41.72,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18963,207,1.54,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18963,208,350,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18963,255,31.78,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18963,269,3.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18963,291,2.5,'100g',1,1,'2012-03-02','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (18963,301,27,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18963,303,3.05,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18963,306,103,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18963,307,544,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18963,320,13,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (18963,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18963,401,0.2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18963,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18963,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18963,605,0.24,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18963,606,5.281,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18964,203,4.45,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18964,204,26.61,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18964,205,48.6,'100g',3,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18964,207,1.36,'100g',1,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18964,208,452,'100g',3,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18964,255,18.98,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18964,269,25.7,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18964,291,1.2,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18964,301,183,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18964,303,1.37,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18964,306,102,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18964,307,305,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18964,320,0,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (18964,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18964,401,0.3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18964,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18964,601,5,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18964,605,0.295,'100g',3,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18964,606,12.649,'100g',3,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (18965,203,10,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18965,204,11.67,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18965,205,68.19,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18965,207,2.84,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18965,208,418,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18965,255,7.3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18965,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18965,291,3.3,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18965,301,67,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18965,303,4.8,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18965,306,141,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18965,307,1167,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18965,320,9,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (18965,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18965,401,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18965,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18965,601,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18965,605,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18965,606,3.333,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18966,203,7.14,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18966,204,10.71,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18966,205,68.25,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18966,207,4.04,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18966,208,398,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18966,255,9.85,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18966,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18966,291,6.7,'100g',3,1,'2012-03-02','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (18966,301,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18966,303,5.14,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18966,306,221,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18966,307,1214,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18966,320,0,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (18966,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18966,401,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18966,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18966,601,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18966,605,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18966,606,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18967,203,10.66,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18967,204,2.15,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18967,205,43.91,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18967,207,3.69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18967,208,238,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18967,255,39.6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18967,269,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18967,291,9.2,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18967,301,684,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18967,303,4.89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18967,306,127,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18967,307,478,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18967,320,0,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (18967,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18967,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18967,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18967,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18967,605,0.031,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18967,606,0.63,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18968,203,10.2,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18968,204,1.53,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18968,205,48.89,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18968,207,1.82,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18968,208,250,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18968,255,37.55,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18968,269,6.12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18968,291,4.1,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18968,301,20,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18968,303,2.76,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18968,306,165,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18968,307,439,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18968,320,0,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (18968,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18968,401,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18968,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18968,601,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18968,605,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18968,606,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18969,203,4.41,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18969,204,18.52,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18969,205,37.43,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18969,207,1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18969,208,334,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18969,255,38.64,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18969,269,22.05,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18969,291,0.9,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18969,301,35,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18969,303,0.95,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18969,306,68,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18969,307,265,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18969,320,23,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (18969,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18969,401,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18969,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18969,601,66,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18969,605,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18969,606,7.055,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18970,203,8.01,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18970,204,7.58,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18970,205,49.27,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18970,207,2.71,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18970,208,297,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18970,255,32.43,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18970,269,2.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18970,291,2.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18970,301,163,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18970,303,3.32,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18970,306,133,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18970,307,742,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18970,320,0,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (18970,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18970,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18970,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18970,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18970,605,0.014,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18970,606,1.225,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18971,203,12.5,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18971,204,3.13,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18971,205,47.07,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18971,207,3.76,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18971,208,266,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18971,255,33.55,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18971,269,9.38,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (18971,291,6.3,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18971,301,188,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18971,303,2.25,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18971,306,718,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18971,307,375,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18971,320,24,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (18971,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18971,401,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18971,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18971,601,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18971,605,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18971,606,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18972,203,10.42,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18972,204,20.83,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18972,205,44.83,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18972,207,2.79,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18972,208,408,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18972,255,21.13,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18972,269,2.08,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18972,291,2.1,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18972,301,90,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18972,303,2.49,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18972,306,84,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18972,307,750,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18972,320,24,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (18972,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18972,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18972,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18972,601,10,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18972,605,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18972,606,6.25,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18973,203,8.77,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18973,204,7.89,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18973,205,35.82,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18973,207,1.6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18973,208,249,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18973,255,45.91,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18973,269,1.75,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (18973,291,1.8,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18973,301,35,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18973,303,3.16,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18973,306,114,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18973,307,561,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18973,320,0,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (18973,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (18973,401,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18973,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (18973,601,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18973,605,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (18973,606,0.877,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19002,203,33.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19002,204,25.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19002,205,11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19002,207,6.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19002,208,410,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19002,255,23.36,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19002,269,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19002,291,1.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19002,301,20,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19002,303,5.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19002,306,597,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19002,307,1785,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19002,320,0,'100g',1,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (19002,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19002,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19002,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19002,601,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19002,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19002,606,10.85,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19003,203,6.17,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19003,204,33.36,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19003,205,57.27,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19003,207,2.13,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19003,208,539,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19003,255,1.07,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19003,269,0.27,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19003,291,4,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19003,301,138,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19003,303,1.2,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19003,306,144,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19003,307,514,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19003,320,3,'100g',2,1,'2024-12-12','2017-01-07');
INSERT INTO `cndb_nutval` VALUES (19003,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19003,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19003,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19003,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19003,605,0.088,'100g',3,1,'2006-01-24','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19003,606,4.331,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19004,203,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19004,204,32.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19004,205,56.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19004,207,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19004,208,523,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19004,255,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19004,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19004,291,5.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19004,301,131,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19004,303,1.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19004,306,236,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19004,307,763,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19004,320,31,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19004,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19004,401,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19004,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19004,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19004,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19004,606,4.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19005,203,5.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19005,204,26.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19005,205,62.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19005,207,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19005,208,510,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19005,255,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19005,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19005,291,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19005,301,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19005,303,2.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19005,306,81,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19005,307,1022,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19005,320,16,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19005,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19005,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19005,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19005,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19005,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19005,606,22.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19007,203,7.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19007,204,22.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19007,205,65.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19007,207,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19007,208,499,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19007,255,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19007,269,4.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19007,291,3.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19007,301,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19007,303,3.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19007,306,143,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19007,307,950,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19007,320,8,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (19007,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19007,401,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19007,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19007,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19007,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19007,606,4.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19008,203,5.46,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19008,204,36.54,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19008,205,54.54,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19008,207,2.9,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19008,208,567,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19008,255,0.56,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19008,269,3.57,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19008,291,0.8,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19008,301,53,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19008,303,1.69,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19008,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19008,307,928,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19008,320,13,'100g',1,1,'2024-12-12','2016-01-02');
INSERT INTO `cndb_nutval` VALUES (19008,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19008,401,0.1,'100g',1,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19008,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19008,601,7,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (19008,605,0.272,'100g',3,1,'2006-01-24','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19008,606,3.749,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19010,203,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19010,204,13.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19010,205,73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19010,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19010,208,404,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19010,255,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19010,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19010,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19010,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19010,303,6.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19010,306,168,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19010,307,278,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19010,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (19010,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19010,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19010,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19010,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19010,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19010,606,5.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19013,203,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19013,204,2.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19013,205,82.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19013,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19013,208,359,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19013,255,12.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19013,269,57.58,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19013,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19013,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19013,303,0.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19013,306,164,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19013,307,199,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19013,320,3,'100g',2,1,'2024-12-12','2017-01-07');
INSERT INTO `cndb_nutval` VALUES (19013,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19013,401,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19013,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19013,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19013,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19013,606,0.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19014,203,0.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19014,204,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19014,205,85.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19014,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19014,208,371,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19014,255,10.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19014,269,49.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19014,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19014,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19014,303,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19014,306,294,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19014,307,317,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19014,320,6,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (19014,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19014,401,120,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19014,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19014,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19014,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19014,606,0.672,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19015,203,10.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19015,204,19.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19015,205,64.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19015,207,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19015,208,471,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19015,255,3.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19015,269,28.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19015,291,5.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19015,301,61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19015,303,2.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19015,306,336,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19015,307,294,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19015,320,2,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (19015,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19015,401,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19015,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19015,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19015,605,NULL,'100g',NULL,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (19015,606,2.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19016,203,7.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19016,204,25.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19016,205,62,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19016,207,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19016,208,495,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19016,255,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19016,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19016,291,4.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19016,301,32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19016,303,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19016,306,273,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19016,307,256,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19016,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19016,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19016,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19016,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19016,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19016,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19016,606,12.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19017,203,7.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19017,204,16.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19017,205,72.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19017,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19017,208,438,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19017,255,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19017,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19017,291,4.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19017,301,77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19017,303,3.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19017,306,251,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19017,307,344,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19017,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19017,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19017,401,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19017,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19017,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19017,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19017,606,11.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19018,203,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19018,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19018,205,85.13,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19018,207,0.13,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19018,208,341,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19018,255,14.74,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19018,269,53,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19018,291,0.1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19018,301,8,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19018,303,0.04,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19018,306,7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19018,307,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19018,320,0,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (19018,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19018,401,1.6,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19018,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19018,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19018,605,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19018,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19020,203,7.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19020,204,17.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19020,205,67.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19020,207,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19020,208,443,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19020,255,6.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19020,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19020,291,4.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19020,301,105,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19020,303,2.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19020,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19020,307,278,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19020,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19020,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19020,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19020,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19020,601,0,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19020,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19020,606,7.25,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19021,203,10.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19021,204,15.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19021,205,64.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19021,207,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19021,208,426,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19021,255,7.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19021,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19021,291,4.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19021,301,91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19021,303,2.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19021,306,291,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19021,307,409,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19021,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19021,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19021,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19021,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19021,601,0,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19021,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19021,606,3.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19022,203,7.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19022,204,17.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19022,205,66.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19022,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19022,208,448,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19022,255,6.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19022,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19022,291,4.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19022,301,101,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19022,303,2.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19022,306,362,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19022,307,282,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19022,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19022,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19022,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19022,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19022,601,0,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19022,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19022,606,9.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19024,203,5.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19024,204,24.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19024,205,63.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19024,207,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19024,208,466,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19024,255,3.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19024,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19024,291,3.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19024,301,103,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19024,303,2.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19024,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19024,307,200,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19024,320,7,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19024,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19024,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19024,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19024,601,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19024,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19024,606,14.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19025,203,8.72,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19025,204,20.18,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19025,205,67.41,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19025,207,1.16,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19025,208,473,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19025,255,2.54,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19025,269,62.68,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19025,291,1.9,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19025,301,21,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19025,303,0.71,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19025,306,220,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19025,307,174,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19025,320,0,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (19025,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19025,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19025,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19025,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19025,605,0.029,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19025,606,5.735,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19026,203,10.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19026,204,31.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19026,205,53.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19026,207,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19026,208,508,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (19026,255,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19026,269,23.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19026,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19026,301,108,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19026,303,1.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19026,306,339,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19026,307,193,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19026,320,5,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (19026,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19026,401,0.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19026,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19026,601,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19026,605,NULL,'100g',NULL,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (19026,606,17.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19027,203,9.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19027,204,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19027,205,62.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19027,207,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19027,208,432,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19027,255,5.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19027,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19027,291,4.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19027,301,80,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19027,303,1.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19027,306,377,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19027,307,328,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19027,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19027,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19027,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19027,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19027,601,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19027,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19027,606,5.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19030,203,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19030,204,0.02,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19030,205,65.1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19030,207,0.06,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19030,208,261,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19030,255,34.82,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19030,269,65,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19030,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19030,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19030,303,0.03,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19030,306,1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19030,307,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19030,320,0,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19030,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19030,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19030,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19030,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19030,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (19030,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19031,203,17.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19031,204,25.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19031,205,51.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19031,207,2.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19031,208,506,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19031,255,2.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19031,269,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19031,291,13.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19031,301,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19031,303,2.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19031,306,328,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19031,307,413,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19031,320,0,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19031,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19031,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19031,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19031,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19031,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19031,606,3.785,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19034,203,12.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19034,204,4.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19034,205,77.78,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19034,207,1.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19034,208,387,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19034,255,3.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19034,269,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19034,291,14.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19034,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19034,303,3.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19034,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19034,307,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19034,320,10,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (19034,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19034,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19034,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19034,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19034,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19034,606,0.637,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19035,203,7.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19035,204,43.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19035,205,45.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19035,207,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19035,208,583,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19035,255,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19035,269,0.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19035,291,8.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19035,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19035,303,1.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19035,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19035,307,909,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19035,320,8,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (19035,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19035,401,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19035,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19035,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19035,605,NULL,'100g',NULL,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19035,606,6.82,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19036,203,9.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19036,204,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19036,205,80.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19036,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19036,208,384,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19036,255,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19036,269,0.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19036,291,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19036,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19036,303,1.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19036,306,327,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19036,307,288,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19036,320,4,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19036,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19036,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19036,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19036,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19036,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19036,606,0.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19038,203,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19038,204,7.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19038,205,80.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19038,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19038,208,400,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19038,255,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19038,269,45.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19038,291,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19038,301,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19038,303,3.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19038,306,355,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19038,307,177,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19038,320,4,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (19038,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19038,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19038,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19038,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19038,605,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19038,606,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19039,203,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19039,204,12.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19039,205,79.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19039,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19039,208,431,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19039,255,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19039,269,53.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19039,291,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19039,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19039,303,1.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19039,306,109,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19039,307,206,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19039,320,2,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (19039,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19039,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19039,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19039,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19039,605,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19039,606,3.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19040,203,9.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19040,204,33.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19040,205,51.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19040,207,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19040,208,526,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19040,255,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19040,269,0.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19040,291,9.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19040,301,113,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19040,303,2.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19040,306,261,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19040,307,889,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19040,320,8,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (19040,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19040,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19040,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19040,601,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19040,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19040,606,6.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19041,203,61.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19041,204,31.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19041,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19041,207,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19041,208,544,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19041,255,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19041,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19041,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19041,301,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19041,303,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19041,306,127,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19041,307,1818,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19041,320,12,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19041,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19041,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19041,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19041,601,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19041,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19041,606,11.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19042,203,6.51,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19042,204,31.06,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19042,205,55.92,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19042,207,4.03,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19042,208,487,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19042,255,2.48,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19042,269,5.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19042,291,3.8,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19042,301,32,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19042,303,1.36,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19042,306,1186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19042,307,545,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19042,320,20,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (19042,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19042,401,62.4,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19042,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19042,601,0,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19042,605,0.124,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19042,606,4.002,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19043,203,8.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19043,204,33.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19043,205,51.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19043,207,4.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19043,208,531,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19043,255,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19043,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19043,291,5.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19043,301,72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19043,303,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19043,306,1331,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19043,307,549,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (19043,320,14,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (19043,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19043,401,37.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19043,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19043,601,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19043,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19043,606,8.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19045,203,4.56,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19045,204,26.14,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19045,205,64.76,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19045,207,2.31,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19045,208,502,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19045,255,2.22,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19045,269,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19045,291,3.2,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19045,301,29,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19045,303,1.11,'100g',1,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19045,306,760,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19045,307,450,'100g',6,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19045,320,0,'100g',2,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (19045,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19045,401,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19045,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19045,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19045,605,0.139,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19045,606,6.759,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19046,203,6.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19046,204,37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19046,205,51.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19046,207,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19046,208,547,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19046,255,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19046,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19046,291,1.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19046,301,64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19046,303,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19046,306,496,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19046,307,541,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (19046,320,323,'100g',2,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (19046,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19046,401,9.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19046,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19046,601,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19046,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19046,606,9.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19047,203,10.04,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19047,204,2.93,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19047,205,80.39,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19047,207,3.51,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19047,208,384,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19047,255,3.13,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19047,269,2.21,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19047,291,3.4,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19047,301,27,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19047,303,4.58,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19047,306,223,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19047,307,1240,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19047,320,0,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (19047,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19047,401,2.1,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19047,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19047,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19047,605,0.004,'100g',3,1,'2006-01-24','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19047,606,0.391,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19048,203,7.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19048,204,16.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19048,205,70.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19048,207,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19048,208,457,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19048,255,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19048,269,38.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19048,291,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19048,301,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19048,303,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19048,306,225,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19048,307,569,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19048,320,0,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (19048,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19048,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19048,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19048,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19048,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19048,606,7.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19050,203,11.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19050,204,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19050,205,81.3,'100g',3,1,'1994-01-31','2012-09-01');
INSERT INTO `cndb_nutval` VALUES (19050,207,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19050,208,362,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19050,255,3.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19050,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19050,291,7.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19050,301,28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19050,303,2.69,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19050,306,430,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19050,307,203,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19050,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19050,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19050,401,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19050,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19050,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19050,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19050,606,0.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19051,203,8.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19051,204,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19051,205,81.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19051,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19051,208,387,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19051,255,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19051,269,0.89,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19051,291,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19051,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19051,303,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19051,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19051,307,166,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19051,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19051,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19051,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19051,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19051,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19051,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19051,606,0.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19052,203,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19052,204,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19052,205,80.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19052,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19052,208,380,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19052,255,5.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19052,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19052,291,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19052,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19052,303,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19052,306,299,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19052,307,116,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19052,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19052,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19052,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19052,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19052,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19052,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19052,606,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19053,203,7.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19053,204,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19053,205,81.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19053,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19053,208,392,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19053,255,5.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19053,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19053,291,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19053,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19053,303,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19053,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19053,307,227,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19053,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19053,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19053,401,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19053,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19053,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19053,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19053,606,0.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19056,203,7.1,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19056,204,20.68,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19056,205,67.78,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19056,207,1.79,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19056,208,472,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19056,255,2.64,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19056,269,0.78,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19056,291,5.4,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19056,301,106,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19056,303,1.52,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19056,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19056,307,328,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19056,320,0,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (19056,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19056,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19056,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19056,601,0,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19056,605,0.812,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19056,606,2.811,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19057,203,7.36,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19057,204,27.42,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19057,205,60.81,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19057,207,2.75,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19057,208,519,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19057,255,1.66,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19057,269,2.59,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19057,291,5.1,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19057,301,137,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19057,303,1.16,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19057,306,223,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19057,307,691,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19057,320,6,'100g',1,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (19057,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19057,401,0.4,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19057,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19057,601,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19057,605,0.185,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19057,606,3.876,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19058,203,7.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19058,204,24.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19058,205,62.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19058,207,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19058,208,501,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19058,255,3.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19058,269,3.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19058,291,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19058,301,134,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19058,303,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19058,306,259,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19058,307,519,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19058,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (19058,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19058,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19058,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19058,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19058,605,0.345,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19058,606,3.539,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19059,203,13.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19059,204,29.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19059,205,44.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19059,207,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19059,208,462,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19059,255,9.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19059,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19059,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19059,301,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19059,303,3.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19059,306,685,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19059,307,229,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19059,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19059,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19059,401,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19059,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19059,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19059,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19059,606,5.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19061,203,6.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19061,204,17.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19061,205,65.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19061,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19061,208,442,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19061,255,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19061,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19061,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19061,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19061,303,2.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19061,306,709,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19061,307,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19061,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19061,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19061,401,7.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19061,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19061,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19061,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19061,606,8.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19062,203,14.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19062,204,31.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19062,205,44.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19062,207,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19062,208,484,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19062,255,6.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19062,269,23.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19062,291,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19062,301,109,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19062,303,3.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19062,306,648,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19062,307,121,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19062,320,0,'100g',2,1,'2024-12-12','2013-01-07');
INSERT INTO `cndb_nutval` VALUES (19062,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19062,401,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19062,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19062,601,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19062,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19062,606,6.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19063,203,7.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19063,204,24.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19063,205,63.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19063,207,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19063,208,480,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19063,255,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19063,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19063,291,5.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19063,301,155,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19063,303,2.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19063,306,217,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19063,307,787,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19063,320,45,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19063,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19063,401,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19063,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19063,601,0,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19063,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19063,606,4.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19070,203,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19070,204,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19070,205,90.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19070,207,1.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19070,208,391,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19070,255,5.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19070,269,80.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19070,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19070,301,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19070,303,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19070,306,3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19070,307,391,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19070,320,28,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (19070,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19070,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19070,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19070,601,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19070,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19070,606,2.065,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19071,203,8.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19071,204,31.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19071,205,56.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19071,207,2.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19071,208,540,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19071,255,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19071,269,34.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19071,291,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19071,301,303,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19071,303,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19071,306,633,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19071,307,107,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19071,320,1,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (19071,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19071,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19071,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19071,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19071,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19071,606,29.018,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19074,203,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19074,204,8.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19074,205,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19074,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19074,208,382,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19074,255,8.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19074,269,65.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19074,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19074,301,138,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19074,303,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19074,306,214,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19074,307,245,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19074,320,12,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (19074,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19074,401,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19074,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19074,601,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19074,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19074,606,2.476,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19076,203,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19076,204,3.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19076,205,87.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19076,207,0.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19076,208,387,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19076,255,6.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19076,269,56.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19076,291,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19076,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19076,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19076,306,116,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19076,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19076,320,0,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (19076,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19076,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19076,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19076,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19076,605,0.963,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19076,606,0.967,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19077,203,12.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19077,204,47.7,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19077,205,36.2,'100g',3,1,'1994-11-14','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19077,207,3.1,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19077,208,472,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19077,255,0.9,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19077,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19077,291,18.1,'100g',3,1,'1994-11-22','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19077,301,54,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19077,303,4.15,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19077,306,1166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19077,307,12,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19077,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19077,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19077,401,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19077,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19077,601,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19077,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19077,606,25.29,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19078,203,14.32,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19078,204,52.31,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19078,205,28.42,'100g',3,1,'1994-11-14','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19078,207,3.6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19078,208,642,'100g',3,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19078,255,1.34,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19078,269,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19078,291,16.6,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19078,301,101,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19078,303,17.4,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19078,306,830,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19078,307,24,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19078,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19078,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19078,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19078,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19078,601,2,'100g',1,1,'1994-11-14','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19078,605,0,'100g',NULL,1,'1994-09-20','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19078,606,32.277,'100g',3,1,'1994-11-14','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19079,203,5.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19079,204,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19079,205,63.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19079,207,1.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19079,208,522,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19079,255,1.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19079,269,62.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19079,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19079,301,205,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19079,303,0.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19079,306,290,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19079,307,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19079,320,1,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (19079,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19079,401,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19079,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19079,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19079,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19079,606,24.104,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19080,203,4.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19080,204,30,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19080,205,63.9,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19080,207,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19080,208,480,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19080,255,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19080,269,54.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19080,291,5.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19080,301,32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19080,303,3.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19080,306,365,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19080,307,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19080,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19080,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19080,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19080,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19080,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19080,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19080,606,17.75,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19081,203,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19081,204,34.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19081,205,60.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19081,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19081,208,507,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19081,255,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19081,269,51.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19081,291,5.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19081,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19081,303,2.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19081,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19081,307,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19081,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19081,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19081,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19081,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19081,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19081,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19081,606,20.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19083,203,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19083,204,9.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19083,205,80.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19083,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19083,208,366,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19083,255,7.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19083,269,71.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19083,291,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19083,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19083,303,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19083,306,168,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19083,307,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19083,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19083,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19083,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19083,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19083,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19083,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19083,606,5.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19085,203,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19085,204,29.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19085,205,67.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19085,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19085,208,539,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19085,255,0.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19085,269,67.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19085,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19085,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19085,303,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19085,306,64,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19085,307,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19085,320,0,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (19085,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19085,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19085,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19085,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19085,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19085,606,24.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19086,203,18.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19086,204,29.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19086,205,46.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19086,207,2.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19086,208,529,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19086,255,2.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19086,269,38.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19086,291,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19086,301,110,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19086,303,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19086,306,505,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19086,307,250,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19086,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (19086,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19086,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19086,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19086,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19086,605,1.763,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19086,606,13.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19087,203,5.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19087,204,32.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19087,205,59.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19087,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19087,208,539,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19087,255,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19087,269,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19087,291,0.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19087,301,199,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19087,303,0.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19087,306,286,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19087,307,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19087,320,9,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (19087,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19087,401,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19087,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19087,601,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19087,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19087,606,19.412,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19088,203,4.78,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19088,204,4.83,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19088,205,29.46,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19088,207,1.07,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19088,208,180,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19088,255,59.85,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19088,269,22.12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19088,291,0.3,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19088,301,161,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19088,303,0.19,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19088,306,208,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19088,307,74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19088,320,128,'100g',2,1,'2024-12-12','2005-01-06');
INSERT INTO `cndb_nutval` VALUES (19088,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19088,401,1.2,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19088,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19088,601,27,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19088,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19088,606,2.927,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19089,203,3.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19089,204,16.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19089,205,22.29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19089,207,0.81,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19089,208,249,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19089,255,57.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19089,269,20.65,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19089,291,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19089,301,117,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19089,303,0.34,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19089,306,157,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19089,307,61,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19089,320,182,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19089,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19089,401,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19089,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19089,601,92,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19089,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19089,606,10.329,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19090,203,4.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19090,204,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19090,205,22.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19090,207,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19090,208,222,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19090,255,59.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19090,269,21.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19090,291,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19090,301,131,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19090,303,0.21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19090,306,177,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19090,307,61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19090,320,162,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19090,328,0.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19090,401,0.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19090,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19090,601,91,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19090,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19090,606,7.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19094,203,4.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19094,204,4.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19094,205,22.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19094,207,0.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19094,208,145,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19094,255,68.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19094,269,22.78,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19094,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19094,301,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19094,303,0.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19094,306,118,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19094,307,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19094,320,46,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (19094,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19094,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19094,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19094,601,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19094,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19094,606,1.799,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19095,203,3.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19095,204,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19095,205,23.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19095,207,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19095,208,207,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19095,255,61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19095,269,21.22,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19095,291,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19095,301,128,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19095,303,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19095,306,199,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19095,307,80,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19095,320,118,'100g',2,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (19095,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19095,401,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19095,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19095,601,44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19095,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19095,606,6.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19096,203,4.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19096,204,2.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19096,205,21.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19096,207,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19096,208,126,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19096,255,69.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19096,269,18.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19096,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19096,301,157,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19096,303,0.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19096,306,221,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19096,307,70,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19096,320,29,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19096,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19096,401,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19096,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19096,601,12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19096,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19096,606,1.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19097,203,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19097,204,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19097,205,30.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19097,207,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19097,208,144,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19097,255,66.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19097,269,24.32,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19097,291,1.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19097,301,54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19097,303,0.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19097,306,96,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19097,307,46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19097,320,12,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (19097,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19097,401,2.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19097,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19097,601,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19097,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19097,606,1.16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19099,203,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19099,204,0.02,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19099,205,93.18,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19099,207,0.06,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19099,208,373,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19099,255,6.74,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19099,269,88.9,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19099,291,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19099,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19099,303,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19099,306,4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19099,307,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19099,320,0,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (19099,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19099,401,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19099,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19099,601,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19099,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19099,606,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19100,203,2.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19100,204,10.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19100,205,76.7,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19100,207,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19100,208,410,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19100,255,9.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19100,269,73.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19100,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19100,301,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19100,303,1.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19100,306,134,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19100,307,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19100,320,44,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (19100,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19100,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19100,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19100,601,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19100,605,0.165,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19100,606,6.448,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19101,203,4.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19101,204,18.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19101,205,68.15,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19101,207,0.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19101,208,460,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19101,255,7.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19101,269,63.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19101,291,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19101,301,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19101,303,1.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19101,306,183,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19101,307,39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19101,320,38,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (19101,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19101,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19101,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19101,601,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19101,605,0.142,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19101,606,6.489,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19102,203,3.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19102,204,6.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19102,205,77.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19102,207,0.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19102,208,387,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19102,255,10.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19102,269,73.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19102,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19102,301,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19102,303,0.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19102,306,119,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19102,307,118,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19102,320,9,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (19102,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19102,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19102,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19102,601,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19102,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19102,606,1.721,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19103,203,1.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19103,204,5.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19103,205,82.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19103,207,0.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19103,208,383,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19103,255,10.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19103,269,79.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19103,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19103,301,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19103,303,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19103,306,49,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19103,307,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19103,320,46,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (19103,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19103,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19103,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19103,601,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19103,605,0.179,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19103,606,3.382,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19104,203,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19104,204,13.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19104,205,74.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19104,207,0.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19104,208,435,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19104,255,7.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19104,269,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19104,291,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19104,301,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19104,303,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19104,306,103,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19104,307,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19104,320,41,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (19104,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19104,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19104,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19104,601,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19104,605,0.158,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19104,606,3.828,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19106,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19106,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19106,205,98.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19106,207,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19106,208,396,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19106,255,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19106,269,58.97,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19106,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19106,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19106,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19106,306,5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19106,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19106,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19106,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19106,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19106,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19106,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19106,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19106,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19107,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19107,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19107,205,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19107,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19107,208,394,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19107,255,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19107,269,62.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19107,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19107,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19107,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19107,306,5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19107,307,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19107,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19107,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19107,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19107,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19107,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19107,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19107,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19108,203,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19108,204,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19108,205,93.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19108,207,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19108,208,375,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19108,255,6.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19108,269,70,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19108,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19108,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19108,303,0.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19108,306,37,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19108,307,50,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19108,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19108,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19108,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19108,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19108,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19108,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19108,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19113,203,0,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19113,204,0.09,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19113,205,72.43,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19113,207,0.76,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19113,208,291,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19113,255,26.72,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19113,269,72.25,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19113,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19113,301,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19113,303,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19113,306,3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19113,307,287,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19113,320,0,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (19113,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19113,401,0,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19113,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19113,601,0,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19113,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19113,606,0,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19114,203,5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19114,204,7.19,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19114,205,25.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19114,207,0.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19114,208,187,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19114,255,61.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19114,269,24.71,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19114,291,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19114,301,159,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19114,303,0.69,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19114,306,170,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19114,307,71,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19114,320,71,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (19114,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19114,401,1.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19114,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19114,601,28,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19114,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19114,606,4.38,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19116,203,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19116,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19116,205,81.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19116,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19116,208,318,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19116,255,16.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19116,269,57.56,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19116,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19116,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19116,303,0.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19116,306,5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19116,307,80,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19116,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19116,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19116,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19116,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19116,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19116,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19116,606,0.056,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19117,203,12.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19117,204,21.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19117,205,60.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19117,207,1.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19117,208,469,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19117,255,3.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19117,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19117,291,4.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19117,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19117,303,4.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19117,306,187,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19117,307,195,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19117,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19117,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19117,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19117,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19117,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19117,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19117,606,4.127,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19120,203,7.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19120,204,29.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19120,205,59.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19120,207,1.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19120,208,535,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19120,255,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19120,269,51.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19120,291,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19120,301,189,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19120,303,2.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19120,306,372,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19120,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19120,320,59,'100g',2,1,'2024-12-12','2008-01-08');
INSERT INTO `cndb_nutval` VALUES (19120,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19120,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19120,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19120,601,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19120,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19120,606,18.509,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19121,203,2.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19121,204,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19121,205,19.74,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19121,207,1.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19121,208,105,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19121,255,74.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19121,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19121,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19121,301,102,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19121,303,0.06,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19121,306,131,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19121,307,296,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19121,320,46,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19121,328,0.8,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19121,401,0.8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19121,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19121,601,6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19121,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19121,606,0.971,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19122,203,2.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19122,204,1.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19122,205,18.43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19122,207,1.03,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19122,208,101,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19122,255,75.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19122,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19122,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19122,301,109,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19122,303,0.05,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19122,306,137,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19122,307,164,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19122,320,50,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19122,328,0.9,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19122,401,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19122,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19122,601,7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19122,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19122,606,1.015,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19123,203,3.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19123,204,1.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19123,205,18.89,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19123,207,1.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19123,208,105,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19123,255,74.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19123,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19123,291,0.4,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19123,301,104,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19123,303,0.4,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19123,306,168,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19123,307,284,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19123,320,46,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19123,328,0.8,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19123,401,0.8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19123,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19123,601,6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19123,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19123,606,1.064,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19124,203,3.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19124,204,15.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19124,205,77.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19124,207,1.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19124,208,426,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19124,255,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19124,269,69.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19124,291,4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19124,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19124,303,2.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19124,306,397,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19124,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19124,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19124,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19124,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19124,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19124,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19124,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19124,606,8.606,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19125,203,5.41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19125,204,29.73,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19125,205,62.36,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19125,207,1.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19125,208,539,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19125,255,1.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19125,269,54.05,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19125,291,5.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19125,301,108,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19125,303,4.38,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19125,306,407,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19125,307,41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19125,320,1,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (19125,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19125,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19125,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19125,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19125,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19125,606,28.423,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19126,203,13.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19126,204,33.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19126,205,49.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19126,207,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19126,208,519,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19126,255,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19126,269,37.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19126,291,4.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19126,301,104,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19126,303,1.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19126,306,502,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19126,307,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19126,320,41,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (19126,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19126,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19126,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19126,601,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19126,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19126,606,14.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19127,203,4.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19127,204,14.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19127,205,68.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19127,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19127,208,390,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19127,255,11.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19127,269,62.22,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19127,291,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19127,301,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19127,303,1.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19127,306,514,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19127,307,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19127,320,29,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (19127,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19127,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19127,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19127,601,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19127,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19127,606,10.272,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19128,203,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19128,204,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19128,205,44.55,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19128,207,0.55,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19128,208,165,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19128,255,54.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19128,269,32.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19128,291,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19128,301,10,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19128,303,0.03,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19128,306,3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19128,307,178,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19128,320,0,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (19128,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19128,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19128,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19128,601,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19128,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19128,606,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19129,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19129,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19129,205,61.47,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19129,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19129,208,234,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19129,255,37.98,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19129,269,21.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19129,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19129,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19129,303,0.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19129,306,15,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19129,307,82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19129,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19129,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19129,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19129,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19129,601,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19129,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19129,606,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19132,203,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19132,204,34.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19132,205,53.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19132,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19132,208,526,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19132,255,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19132,269,43.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19132,291,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19132,301,224,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19132,303,1.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19132,306,444,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19132,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19132,320,52,'100g',2,1,'2024-12-12','2008-01-01');
INSERT INTO `cndb_nutval` VALUES (19132,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19132,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19132,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19132,601,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19132,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19132,606,17.701,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19134,203,7.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19134,204,29.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19134,205,59.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19134,207,1.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19134,208,511,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19134,255,1.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19134,269,51.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19134,291,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19134,301,187,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19134,303,2.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19134,306,370,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19134,307,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19134,320,65,'100g',2,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (19134,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19134,401,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19134,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19134,601,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19134,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19134,606,15.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19137,203,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19137,204,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19137,205,66.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19137,207,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19137,208,254,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19137,255,33,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19137,269,27.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19137,291,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19137,301,6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19137,303,0.28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19137,306,51,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19137,307,21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19137,320,1,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19137,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19137,401,13.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19137,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19137,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19137,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19137,606,0.005,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19138,203,6.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19138,204,33.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19138,205,44.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19138,207,1.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19138,208,510,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19138,255,13.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19138,269,38.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19138,291,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19138,301,157,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19138,303,1.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19138,306,297,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19138,307,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19138,320,144,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (19138,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19138,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19138,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19138,601,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19138,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19138,606,18.488,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19147,203,15.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19147,204,33.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19147,205,47.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19147,207,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19147,208,522,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19147,255,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19147,269,42.22,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19147,291,4.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19147,301,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19147,303,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19147,306,407,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19147,307,156,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19147,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19147,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19147,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19147,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19147,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19147,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19147,606,4.678,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19148,203,7.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19148,204,18.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19148,205,71.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19148,207,1.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19148,208,486,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19148,255,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19148,269,51.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19148,291,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19148,301,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19148,303,1.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19148,306,168,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19148,307,445,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19148,320,39,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19148,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19148,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19148,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19148,601,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19148,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19148,606,4.144,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19154,203,11.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19154,204,33.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19154,205,50.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19154,207,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19154,208,516,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19154,255,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19154,269,31.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19154,291,7.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19154,301,639,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19154,303,4.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19154,306,307,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19154,307,167,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19154,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (19154,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19154,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19154,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19154,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19154,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19154,606,4.662,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19163,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19163,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19163,205,96.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19163,207,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19163,208,360,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19163,255,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19163,269,66.08,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19163,291,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19163,301,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19163,303,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19163,306,2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19163,307,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19163,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (19163,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19163,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19163,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19163,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19163,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19163,606,0.042,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19165,203,19.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19165,204,13.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19165,205,57.9,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19165,207,5.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19165,208,228,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19165,255,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19165,269,1.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19165,291,37,'100g',6,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19165,301,128,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19165,303,13.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19165,306,1524,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19165,307,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19165,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19165,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19165,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19165,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19165,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19165,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19165,606,8.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19166,203,18.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19166,204,13.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19166,205,58.3,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19166,207,7.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19166,208,220,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19166,255,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19166,269,1.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19166,291,29.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19166,301,111,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19166,303,15.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19166,306,2509,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19166,307,19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19166,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19166,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19166,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19166,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19166,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19166,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19166,606,7.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19168,203,5.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19168,204,4.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19168,205,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19168,207,0.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19168,208,104,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19168,255,78.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19168,269,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19168,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19168,301,107,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19168,303,0.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19168,306,148,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19168,307,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19168,320,49,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (19168,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19168,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19168,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19168,601,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19168,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19168,606,2.164,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19169,203,6.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19169,204,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19169,205,82.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19169,207,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19169,208,410,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19169,255,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19169,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19169,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19169,301,228,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19169,303,1.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19169,306,540,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19169,307,281,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19169,320,63,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (19169,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19169,401,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19169,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19169,601,258,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19169,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19169,606,2.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19170,203,3.99,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19170,204,4,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19170,205,17.6,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19170,207,0.97,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19170,208,122,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19170,255,73.45,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19170,269,4.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19170,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19170,301,139,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19170,303,0.34,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19170,306,207,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19170,307,84,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19170,320,52,'100g',2,1,'2024-12-12','2009-01-08');
INSERT INTO `cndb_nutval` VALUES (19170,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19170,401,0.1,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19170,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19170,601,51,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19170,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19170,606,2.032,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19172,203,7.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19172,204,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19172,205,90.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19172,207,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19172,208,381,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19172,255,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19172,269,86.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19172,291,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19172,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19172,303,0.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19172,306,7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19172,307,466,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19172,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19172,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19172,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19172,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19172,601,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19172,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19172,606,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19173,203,1.22,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19173,204,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19173,205,14.19,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19173,207,0.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19173,208,60,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19173,255,84.39,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19173,269,13.49,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19173,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19173,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19173,303,0.02,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19173,306,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19173,307,75,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19173,320,0,'100g',2,1,'2024-12-12','2017-01-01');
INSERT INTO `cndb_nutval` VALUES (19173,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19173,401,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19173,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19173,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19173,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19173,606,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19175,203,15.67,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19175,204,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19175,205,80.21,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19175,207,2.18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19175,208,198,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19175,255,1.93,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19175,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19175,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19175,301,8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19175,303,0.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19175,306,14,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19175,307,862,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19175,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19175,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19175,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19175,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19175,601,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19175,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19175,606,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19176,203,0.83,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19176,204,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19176,205,4.22,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19176,207,0.21,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19176,208,20,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19176,255,94.74,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19176,269,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19176,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19176,301,3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19176,303,0.01,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19176,306,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19176,307,48,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19176,320,0,'100g',2,1,'2024-12-12','2017-01-01');
INSERT INTO `cndb_nutval` VALUES (19176,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19176,401,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19176,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19176,601,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19176,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19176,606,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19177,203,85.6,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19177,204,0.1,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19177,205,0,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19177,207,1.3,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19177,208,335,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19177,255,13,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19177,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19177,291,0,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19177,301,55,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19177,303,1.11,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19177,306,16,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19177,307,196,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19177,320,0,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (19177,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19177,401,0,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19177,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19177,601,0,'100g',3,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19177,605,NULL,'100g',NULL,1,'1994-03-16','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19177,606,0.07,'100g',1,1,'1994-03-16','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19182,203,4.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19182,204,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19182,205,16.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19182,207,0.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19182,208,225,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19182,255,62.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19182,269,14.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19182,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19182,301,96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19182,303,0.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19182,306,143,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19182,307,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19182,320,140,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (19182,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19182,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19182,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19182,601,140,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19182,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19182,606,9.151,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19183,203,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19183,204,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19183,205,23.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19183,207,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19183,208,142,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19183,255,69.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19183,269,17.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19183,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19183,301,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19183,303,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19183,306,184,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19183,307,152,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19183,320,14,'100g',2,1,'2024-12-12','2006-01-10');
INSERT INTO `cndb_nutval` VALUES (19183,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19183,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19183,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19183,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19183,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19183,606,1.263,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19184,203,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19184,204,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19184,205,87.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19184,207,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19184,208,378,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19184,255,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19184,269,67.86,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19184,291,3.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19184,301,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19184,303,1.29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19184,306,236,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19184,307,1771,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19184,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19184,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19184,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19184,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19184,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19184,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19184,606,0.825,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19185,203,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19185,204,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19185,205,18.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19185,207,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19185,208,111,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19185,255,73.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19185,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19185,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19185,301,102,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19185,303,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19185,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19185,307,284,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19185,320,26,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19185,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19185,401,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19185,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19185,601,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19185,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19185,606,1.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19186,203,1.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19186,204,3.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19186,205,30.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19186,207,1.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19186,208,161,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19186,255,62.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19186,269,19.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19186,291,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19186,301,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19186,303,0.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19186,306,78,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19186,307,351,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19186,320,29,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (19186,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19186,401,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19186,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19186,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19186,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19186,606,0.685,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19188,203,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19188,204,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19188,205,89.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19188,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19188,208,362,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19188,255,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19188,269,42.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19188,291,4.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19188,301,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19188,303,1.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19188,306,209,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19188,307,479,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19188,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (19188,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19188,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19188,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19188,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19188,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19188,606,1.234,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19189,203,3.16,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19189,204,3.15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19189,205,19.64,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19189,207,0.92,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19189,208,120,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19189,255,73.13,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19189,269,11.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19189,291,0.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19189,301,106,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19189,303,0.34,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19189,306,150,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19189,307,98,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19189,320,39,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (19189,328,1.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19189,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19189,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19189,601,9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19189,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19189,606,1.81,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19190,203,3.28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19190,204,2.06,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19190,205,19.76,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19190,207,0.96,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19190,208,111,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19190,255,73.94,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19190,269,11.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19190,291,0.8,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19190,301,112,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19190,303,0.34,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19190,306,156,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19190,307,102,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19190,320,47,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (19190,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19190,401,0.1,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19190,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19190,601,7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19190,605,0.073,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19190,606,1.289,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19191,203,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19191,204,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19191,205,19.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19191,207,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19191,208,107,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19191,255,74.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19191,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19191,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19191,301,102,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19191,303,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19191,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19191,307,246,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19191,320,45,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19191,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19191,401,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19191,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19191,601,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19191,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19191,606,1.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19193,203,3.23,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19193,204,2.15,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19193,205,18.39,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19193,207,0.78,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19193,208,108,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19193,255,75.15,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19193,269,11.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19193,291,0.3,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19193,301,95,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19193,303,0.11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19193,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19193,307,97,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19193,320,19,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (19193,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19193,401,1.3,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19193,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19193,601,12,'100g',1,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19193,605,0.054,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19193,606,1.208,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19195,203,3.25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19195,204,2.82,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19195,205,20.68,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19195,207,0.81,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19195,208,121,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19195,255,72.42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19195,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19195,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19195,301,103,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19195,303,0.37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19195,306,128,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19195,307,108,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19195,320,29,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19195,328,0.8,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19195,401,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19195,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19195,601,11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19195,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19195,606,1.682,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19199,203,2.84,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19199,204,2.89,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19199,205,19.43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19199,207,0.85,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19199,208,115,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19199,255,73.97,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19199,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19199,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19199,301,103,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19199,303,0.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19199,306,131,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19199,307,120,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19199,320,25,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19199,328,0.9,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19199,401,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19199,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19199,601,12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19199,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19199,606,1.724,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19201,203,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19201,204,3.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19201,205,22.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19201,207,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19201,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19201,255,71.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19201,269,16.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19201,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19201,301,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19201,303,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19201,306,65,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19201,307,172,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19201,320,2,'100g',2,1,'2024-12-12','2006-01-10');
INSERT INTO `cndb_nutval` VALUES (19201,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19201,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19201,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19201,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19201,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19201,606,1.016,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19202,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19202,204,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19202,205,92.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19202,207,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19202,208,377,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19202,255,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19202,269,92.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19202,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19202,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19202,303,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19202,306,12,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19202,307,1400,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19202,320,1,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19202,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19202,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19202,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19202,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19202,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19202,606,0.432,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19203,203,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19203,204,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19203,205,19.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19203,207,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19203,208,114,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19203,255,73.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19203,269,18.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19203,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19203,301,101,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19203,303,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19203,306,128,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19203,307,286,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19203,320,25,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19203,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19203,401,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19203,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19203,601,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19203,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19203,606,1.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19204,203,2.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19204,204,1.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19204,205,20.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19204,207,1.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19204,208,107,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19204,255,74.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19204,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19204,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19204,301,101,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19204,303,0.06,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19204,306,130,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19204,307,268,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19204,320,46,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19204,328,0.8,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19204,401,0.8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19204,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19204,601,6,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19204,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19204,606,0.974,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19205,203,4.13,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19205,204,2.83,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19205,205,17.61,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19205,207,1,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19205,208,112,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19205,255,74.44,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19205,269,4.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19205,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19205,301,146,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19205,303,0.33,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19205,306,214,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19205,307,87,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19205,320,61,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (19205,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19205,401,0.2,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19205,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19205,601,49,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19205,605,0.078,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19205,606,1.475,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19206,203,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19206,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19206,205,93.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19206,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19206,208,379,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19206,255,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19206,269,79.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19206,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19206,301,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19206,303,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19206,306,20,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19206,307,613,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19206,320,0,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (19206,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19206,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19206,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19206,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19206,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19206,606,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19207,203,2.8,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19207,204,2.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19207,205,18.92,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19207,207,0.9,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19207,208,113,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19207,255,74.49,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19207,269,17.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19207,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19207,301,99,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19207,303,0.04,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19207,306,119,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19207,307,156,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19207,320,40,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (19207,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19207,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19207,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19207,601,9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19207,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19207,606,1.643,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19208,203,3.29,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19208,204,1.63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19208,205,20.81,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19208,207,0.82,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19208,208,111,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19208,255,73.43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19208,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19208,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19208,301,105,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19208,303,0.37,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19208,306,130,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19208,307,109,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19208,320,46,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19208,328,0.8,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19208,401,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19208,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19208,601,6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19208,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19208,606,0.967,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19209,203,2.88,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19209,204,1.67,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19209,205,19.56,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19209,207,0.87,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19209,208,105,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19209,255,75.01,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19209,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19209,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19209,301,105,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19209,303,0.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19209,306,133,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19209,307,121,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19209,320,47,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19209,328,0.9,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19209,401,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19209,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19209,601,6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19209,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19209,606,0.991,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19212,203,2.94,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19212,204,1.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19212,205,18.53,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19212,207,0.95,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19212,208,101,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19212,255,75.86,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19212,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19212,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19212,301,108,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19212,303,0.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19212,306,137,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19212,307,159,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19212,320,48,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19212,328,0.9,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19212,401,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19212,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19212,601,7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19212,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19212,606,1.017,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19213,203,3.24,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19213,204,2.06,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19213,205,13.47,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19213,207,0.81,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19213,208,85,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19213,255,80.39,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19213,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19213,291,0.5,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19213,301,126,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19213,303,0.3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19213,306,182,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19213,307,52,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19213,320,50,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19213,328,0.9,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19213,401,0.9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19213,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19213,601,7,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19213,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19213,606,1.231,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19214,203,3.06,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19214,204,1.77,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19214,205,12.34,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19214,207,0.73,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19214,208,77,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19214,255,82.11,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19214,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19214,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19214,301,121,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19214,303,0.05,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19214,306,142,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19214,307,46,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19214,320,51,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (19214,328,0.9,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19214,401,0.9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19214,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19214,601,7,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19214,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19214,606,1.061,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19216,203,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19216,204,25.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19216,205,59.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19216,207,0.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19216,208,485,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19216,255,10.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19216,269,55.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19216,291,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19216,301,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19216,303,1.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19216,306,217,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19216,307,48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19216,320,1,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (19216,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19216,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19216,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19216,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19216,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19216,606,2.224,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19217,203,0.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19217,204,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19217,205,6.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19217,207,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19217,208,24,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19217,255,93.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19217,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19217,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19217,301,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19217,303,0.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19217,306,26,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19217,307,5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19217,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19217,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19217,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19217,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19217,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19217,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19217,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19218,203,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19218,204,3.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19218,205,21.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19218,207,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19218,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19218,255,71.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19218,269,14.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19218,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19218,301,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19218,303,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19218,306,92,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19218,307,145,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19218,320,0,'100g',1,1,'2024-12-12','2006-01-10');
INSERT INTO `cndb_nutval` VALUES (19218,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19218,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19218,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19218,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19218,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19218,606,0.962,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19219,203,3.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19219,204,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19219,205,17.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19219,207,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19219,208,104,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19219,255,75.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19219,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19219,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19219,301,113,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19219,303,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19219,306,159,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19219,307,163,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19219,320,49,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19219,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19219,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19219,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19219,601,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19219,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19219,606,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19220,203,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19220,204,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19220,205,91.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19220,207,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19220,208,363,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19220,255,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19220,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19220,291,5.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19220,301,166,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19220,303,2.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19220,306,430,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19220,307,187,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19220,320,0,'100g',1,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (19220,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19220,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19220,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19220,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19220,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19220,606,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19221,203,3.2,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19221,204,3.34,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19221,205,13.34,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19221,207,0.79,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19221,208,96,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19221,255,79.29,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19221,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19221,291,0.5,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19221,301,124,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19221,303,0.3,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19221,306,179,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19221,307,51,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19221,320,27,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19221,328,0.9,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19221,401,0.8,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19221,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19221,601,12,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19221,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19221,606,1.999,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19223,203,3.03,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19223,204,3.07,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19223,205,12.21,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19223,207,0.71,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19223,208,89,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19223,255,80.98,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19223,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19223,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19223,301,119,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19223,303,0.05,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19223,306,140,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19223,307,46,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19223,320,27,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19223,328,0.9,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19223,401,0.9,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19223,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19223,601,13,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19223,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19223,606,1.846,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19225,203,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19225,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19225,205,19.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19225,207,72.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19225,208,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19225,255,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19225,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19225,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19225,301,3733,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19225,303,7.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19225,306,292,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19225,307,26050,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19225,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19225,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19225,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19225,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19225,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19225,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19225,606,0.041,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19226,203,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19226,204,17.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19226,205,63.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19226,207,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19226,208,397,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19226,255,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19226,269,57.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19226,291,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19226,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19226,303,1.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19226,306,196,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19226,307,183,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19226,320,0,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (19226,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19226,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19226,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19226,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19226,605,NULL,'100g',NULL,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (19226,606,5.526,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19227,203,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19227,204,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19227,205,52.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19227,207,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19227,208,433,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19227,255,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19227,269,40,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19227,291,2.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19227,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19227,303,0.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19227,306,186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19227,307,160,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19227,320,0,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (19227,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19227,401,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19227,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19227,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19227,605,3.748,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19227,606,8.631,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19228,203,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19228,204,17.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19228,205,67.32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19228,207,0.23,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19228,208,415,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19228,255,15.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19228,269,63.54,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19228,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19228,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19228,303,0.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19228,306,35,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19228,307,191,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19228,320,0,'100g',1,1,'2024-12-12','2008-01-06');
INSERT INTO `cndb_nutval` VALUES (19228,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19228,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19228,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19228,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19228,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19228,606,4.545,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19230,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19230,204,16.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19230,205,67.89,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19230,207,0.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19230,208,418,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19230,255,15.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19230,269,63.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19230,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19230,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19230,303,0.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19230,306,34,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19230,307,184,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19230,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19230,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19230,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19230,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19230,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19230,605,0,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19230,606,2.974,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19231,203,2.99,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19231,204,1.72,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19231,205,18.82,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19231,207,0.76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19231,208,103,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19231,255,75.71,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19231,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19231,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19231,301,113,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19231,303,0.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19231,306,163,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19231,307,113,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19231,320,52,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19231,328,0.9,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19231,401,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19231,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19231,601,7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19231,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19231,606,1.035,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19232,203,2.95,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19232,204,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19232,205,18.68,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19232,207,0.74,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19232,208,113,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19232,255,74.63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19232,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19232,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19232,301,111,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19232,303,0.06,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19232,306,160,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19232,307,112,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19232,320,29,'100g',2,1,'2024-12-12','2002-01-05');
INSERT INTO `cndb_nutval` VALUES (19232,328,0.9,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19232,401,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19232,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19232,601,12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19232,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19232,606,1.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19233,203,2.02,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19233,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19233,205,20.16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19233,207,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19233,208,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19233,255,76.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19233,269,15.12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19233,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19233,301,40,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19233,303,0.36,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19233,306,108,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19233,307,191,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19233,320,1,'100g',2,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (19233,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19233,401,1.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19233,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19233,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19233,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19233,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19234,203,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19234,204,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19234,205,21.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19234,207,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19234,208,94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19234,255,76.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19234,269,14.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19234,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19234,301,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19234,303,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19234,306,70,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19234,307,187,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19234,320,0,'100g',2,1,'2024-12-12','2006-01-10');
INSERT INTO `cndb_nutval` VALUES (19234,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19234,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19234,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19234,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19234,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19234,606,0.122,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19235,203,1.93,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19235,204,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19235,205,20.87,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19235,207,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19235,208,93,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19235,255,76.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19235,269,15.75,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19235,291,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19235,301,39,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19235,303,1.69,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19235,306,208,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19235,307,154,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19235,320,0,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (19235,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19235,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19235,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19235,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19235,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19235,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19241,203,1.11,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19241,204,13.06,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19241,205,71.8,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19241,207,0.71,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19241,208,408,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19241,255,13.33,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19241,269,0.01,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19241,291,1.9,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19241,301,12,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19241,303,0.93,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19241,306,143,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19241,307,124,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19241,320,76,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (19241,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19241,401,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19241,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19241,601,24,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19241,605,0.534,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19241,606,8.369,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19247,203,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19247,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19247,205,62.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19247,207,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19247,208,244,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19247,255,35.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19247,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19247,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19247,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19247,303,0.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19247,306,77,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19247,307,156,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19247,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19247,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19247,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19247,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19247,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19247,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19247,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19260,203,3.97,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19260,204,7.45,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19260,205,21.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19260,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19260,208,169,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19260,255,65.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19260,269,6.46,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19260,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19260,301,136,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19260,303,0.19,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19260,306,196,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19260,307,96,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19260,320,86,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (19260,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19260,401,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19260,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19260,601,27,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19260,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19260,606,4.048,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19263,203,1.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19263,204,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19263,205,20.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19263,207,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19263,208,87,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19263,255,78.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19263,269,17.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19263,291,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19263,301,5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19263,303,0.19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19263,306,53,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19263,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19263,320,1,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19263,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19263,401,9.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19263,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19263,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19263,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19263,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19265,203,3.54,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19265,204,5.74,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19265,205,26.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19265,207,0.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19265,208,173,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19265,255,62.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19265,269,5.65,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19265,291,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19265,301,121,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19265,303,0.48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19265,306,196,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19265,307,75,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19265,320,75,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (19265,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19265,401,0.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19265,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19265,601,16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19265,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19265,606,3.61,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19268,203,7.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19268,204,30,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19268,205,59.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19268,207,1.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19268,208,540,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19268,255,1.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19268,269,42.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19268,291,7.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19268,301,100,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19268,303,2.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19268,306,342,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19268,307,25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19268,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19268,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19268,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19268,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19268,601,13,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19268,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19268,606,15,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19270,203,3.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19270,204,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19270,205,28.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19270,207,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19270,208,216,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19270,255,55.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19270,269,25.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19270,291,1.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19270,301,109,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19270,303,0.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19270,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19270,307,76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19270,320,118,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19270,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19270,401,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19270,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19270,601,34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19270,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19270,606,6.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19271,203,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19271,204,8.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19271,205,27.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19271,207,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19271,208,192,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19271,255,60,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19271,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19271,291,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19271,301,120,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19271,303,0.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19271,306,188,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19271,307,60,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19271,320,96,'100g',2,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (19271,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19271,401,7.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19271,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19271,601,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19271,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19271,606,5.19,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19274,203,0.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19274,204,3.5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19274,205,85.2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19274,207,1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19274,208,373,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19274,255,10.2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19274,269,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19274,291,3.5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19274,301,18,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19274,303,0.75,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19274,306,164,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19274,307,317,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19274,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (19274,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19274,401,120,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19274,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19274,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19274,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19274,606,0.99,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19279,203,7.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19279,204,33.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19279,205,55.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19279,207,1.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19279,208,549,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19279,255,2.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19279,269,50.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19279,291,5.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19279,301,169,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19279,303,2.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19279,306,413,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19279,307,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19279,320,51,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (19279,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19279,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19279,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19279,601,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19279,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19279,606,18.138,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19280,203,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19280,204,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19280,205,32.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19280,207,0.03,'100g',3,1,'1994-01-31','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (19280,208,128,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19280,255,66.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19280,269,32.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19280,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19280,301,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19280,303,0.16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19280,306,3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19280,307,22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19280,320,0,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (19280,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19280,401,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19280,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19280,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19280,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19280,606,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19283,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19283,204,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19283,205,19.23,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19283,207,0.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19283,208,79,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19283,255,80.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19283,269,13.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19283,291,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19283,301,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19283,303,0.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19283,306,15,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19283,307,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19283,320,0,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (19283,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19283,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19283,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19283,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19283,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19283,606,0.013,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19293,203,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19293,204,5.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19293,205,24.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19293,207,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19293,208,159,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19293,255,65.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19293,269,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19293,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19293,301,143,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19293,303,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19293,306,211,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19293,307,87,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19293,320,59,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19293,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19293,401,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19293,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19293,601,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19293,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19293,606,3.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19294,203,0.39,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19294,204,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19294,205,42.47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19294,207,0.39,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19294,208,173,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19294,255,56.45,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19294,269,35.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19294,291,1.5,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19294,301,14,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19294,303,0.31,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19294,306,91,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19294,307,15,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19294,320,1,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (19294,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19294,401,0.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19294,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19294,601,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19294,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19294,606,0.053,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19296,203,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19296,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19296,205,82.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19296,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19296,208,304,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19296,255,17.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19296,269,82.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19296,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19296,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19296,303,0.42,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19296,306,52,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19296,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19296,320,0,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (19296,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19296,401,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19296,539,82.12,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19296,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19296,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19296,606,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19297,203,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19297,204,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19297,205,68.86,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19297,207,0.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19297,208,278,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19297,255,30.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19297,269,48.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19297,291,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19297,301,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19297,303,0.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19297,306,77,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19297,307,32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19297,320,0,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (19297,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19297,401,8.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19297,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19297,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19297,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19297,606,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19300,203,0.15,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19300,204,0.02,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19300,205,69.95,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19300,207,0.12,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19300,208,266,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19300,255,29.77,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19300,269,51.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19300,291,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19300,301,7,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19300,303,0.19,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19300,306,54,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19300,307,30,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19300,320,0,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (19300,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19300,401,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19300,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19300,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19300,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19300,606,0.005,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19301,203,3.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19301,204,21.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19301,205,67.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19301,207,0.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19301,208,474,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19301,255,7.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19301,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19301,291,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19301,301,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19301,303,1.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19301,306,170,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19301,307,79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19301,320,68,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (19301,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19301,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19301,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19301,601,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19301,605,0.297,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19301,606,10.378,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19303,203,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19303,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19303,205,66.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19303,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19303,208,246,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19303,255,33.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19303,269,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19303,291,0.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19303,301,38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19303,303,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19303,306,37,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19303,307,56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19303,320,3,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19303,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19303,401,4.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19303,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19303,601,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19303,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19303,606,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19304,203,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19304,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19304,205,74.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19304,207,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19304,208,290,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19304,255,21.87,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19304,269,74.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19304,291,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19304,301,205,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19304,303,4.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19304,306,1464,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19304,307,37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19304,320,0,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (19304,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19304,401,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19304,539,74.72,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19304,601,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19304,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19304,606,0.018,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19310,203,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19310,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19310,205,90.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19310,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19310,208,325,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19310,255,8.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19310,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19310,291,8.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19310,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19310,303,2.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19310,306,7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19310,307,200,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19310,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19310,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19310,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19310,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19310,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19310,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19310,606,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19312,203,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19312,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19312,205,26.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19312,207,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19312,208,100,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19312,255,73.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19312,269,13.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19312,291,1,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19312,301,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19312,303,0.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19312,306,45,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19312,307,47,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19312,320,2,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (19312,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19312,401,1.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19312,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19312,601,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19312,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19312,606,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19314,203,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19314,204,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19314,205,28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19314,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19314,208,115,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19314,255,71.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19314,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19314,291,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19314,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19314,303,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19314,306,105,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19314,307,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19314,320,10,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19314,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19314,401,3.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19314,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19314,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19314,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19314,606,0.018,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19318,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19318,204,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19318,205,92.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19318,207,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19318,208,367,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19318,255,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19318,269,76.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19318,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19318,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19318,303,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19318,306,15,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19318,307,1499,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19318,320,0,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (19318,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19318,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19318,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19318,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19318,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19318,606,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19319,203,2.62,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19319,204,2.8,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19319,205,19.76,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19319,207,1.2,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19319,208,115,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19319,255,73.62,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19319,269,17.38,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19319,291,0,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19319,301,94,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19319,303,0.05,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19319,306,112,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19319,307,290,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19319,320,38,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (19319,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19319,401,0,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19319,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19319,601,9,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19319,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19319,606,1.562,'100g',7,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19320,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19320,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19320,205,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19320,207,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19320,208,366,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19320,255,4.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19320,269,74.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19320,291,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19320,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19320,303,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19320,306,17,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19320,307,788,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19320,320,0,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (19320,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19320,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19320,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19320,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19320,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19320,606,0.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19321,203,2.74,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19321,204,2.89,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19321,205,18.44,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19321,207,0.97,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19321,208,111,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19321,255,74.96,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19321,269,15.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19321,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19321,301,101,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19321,303,0.04,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19321,306,118,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19321,307,158,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19321,320,40,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (19321,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19321,401,0,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19321,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19321,601,9,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19321,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19321,606,1.634,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19322,203,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19322,204,10,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19322,205,83.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19322,207,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19322,208,415,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19322,255,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19322,269,64,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19322,291,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19322,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19322,303,0.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19322,306,96,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19322,307,1040,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19322,320,0,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (19322,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19322,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19322,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19322,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19322,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19322,606,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19323,203,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19323,204,3.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19323,205,19.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19323,207,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19323,208,117,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19323,255,73.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19323,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19323,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19323,301,100,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19323,303,0.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19323,306,129,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19323,307,246,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19323,320,24,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19323,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19323,401,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19323,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19323,601,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19323,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19323,606,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19324,203,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19324,204,11.36,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19324,205,81.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19324,207,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19324,208,434,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19324,255,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19324,269,80.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19324,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19324,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19324,303,0.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19324,306,133,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19324,307,682,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19324,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19324,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19324,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19324,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19324,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19324,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19324,606,11.364,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19325,203,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19325,204,3.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19325,205,17.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19325,207,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19325,208,114,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19325,255,74.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19325,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19325,291,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19325,301,111,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19325,303,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19325,306,157,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19325,307,162,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19325,320,26,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19325,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19325,401,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19325,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19325,601,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19325,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19325,606,2.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19330,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19330,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19330,205,95.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19330,207,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19330,208,378,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19330,255,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19330,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19330,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19330,301,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19330,303,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19330,306,8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19330,307,1332,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19330,320,0,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (19330,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19330,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19330,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19330,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19330,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19330,606,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19331,203,2.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19331,204,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19331,205,20.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19331,207,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19331,208,115,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19331,255,73.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19331,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19331,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19331,301,99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19331,303,0.06,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19331,306,127,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19331,307,267,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19331,320,24,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19331,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19331,401,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19331,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19331,601,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19331,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19331,606,1.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19333,203,0.65,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19333,204,1.12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19333,205,24.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19333,207,0.42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19333,208,109,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19333,255,73.62,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19333,269,13.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19333,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19333,301,8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19333,303,0.13,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19333,306,6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19333,307,63,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19333,320,15,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (19333,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19333,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19333,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19333,601,49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19333,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19333,606,0.382,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19334,203,0.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19334,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19334,205,98.09,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19334,207,0.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19334,208,380,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19334,255,1.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19334,269,97.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19334,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19334,301,83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19334,303,0.71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19334,306,133,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19334,307,28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19334,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (19334,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19334,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19334,539,97.02,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19334,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19334,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19334,606,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19335,203,0,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19335,204,0,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19335,205,99.98,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19335,207,0.01,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19335,208,387,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19335,255,0.02,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19335,269,99.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19335,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19335,301,1,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19335,303,0.05,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19335,306,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19335,307,1,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19335,320,0,'100g',1,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (19335,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19335,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19335,539,99.8,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19335,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19335,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19335,606,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19336,203,0,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19336,204,0,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19336,205,99.77,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19336,207,0.01,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19336,208,389,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19336,255,0.23,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19336,269,97.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19336,291,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19336,301,1,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19336,303,0.06,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19336,306,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19336,307,2,'100g',1,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19336,320,0,'100g',2,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (19336,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19336,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19336,539,97.81,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19336,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19336,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19336,606,0,'100g',3,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19340,203,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19340,204,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19340,205,90.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19340,207,0.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19340,208,354,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19340,255,8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19340,269,84.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19340,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19340,301,90,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19340,303,1.61,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19340,306,274,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19340,307,11,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19340,320,0,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (19340,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19340,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19340,539,84.87,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19340,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19340,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19340,606,0.036,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19348,203,4.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19348,204,8.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19348,205,62.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19348,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19348,208,350,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19348,255,21.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19348,269,34.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19348,291,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19348,301,49,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19348,303,1.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19348,306,284,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19348,307,346,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19348,320,1,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (19348,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19348,401,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19348,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19348,601,1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19348,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19348,606,3.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19349,203,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19349,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19349,205,77.59,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19349,207,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19349,208,286,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19349,255,22.01,'100g',7,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19349,269,77.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19349,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19349,301,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19349,303,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19349,306,44,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19349,307,155,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19349,320,0,'100g',2,1,'2024-12-12','2003-01-07');
INSERT INTO `cndb_nutval` VALUES (19349,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19349,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19349,539,77.59,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19349,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19349,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19349,606,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19350,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19350,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19350,205,76.79,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19350,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19350,208,283,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19350,255,22.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19350,269,76.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19350,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19350,301,13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19350,303,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19350,306,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19350,307,62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19350,320,0,'100g',2,1,'2024-12-12','2007-01-09');
INSERT INTO `cndb_nutval` VALUES (19350,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19350,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19350,539,76.77,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19350,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19350,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19350,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19351,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19351,204,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19351,205,76,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19351,207,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19351,208,281,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19351,255,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19351,269,75.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19351,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19351,301,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19351,303,0.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19351,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19351,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19351,320,0,'100g',2,1,'2024-12-12','2004-01-12');
INSERT INTO `cndb_nutval` VALUES (19351,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19351,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19351,539,75.65,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19351,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19351,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19351,606,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19352,203,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19352,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19352,205,71.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19352,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19352,208,318,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19352,255,21.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19352,269,71.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19352,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19352,301,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19352,303,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19352,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19352,307,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19352,320,0,'100g',1,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (19352,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19352,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19352,539,71.3,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19352,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19352,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19352,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19353,203,0.04,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19353,204,0.06,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19353,205,67.04,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19353,207,0.47,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19353,208,260,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19353,255,32.39,'100g',7,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19353,269,60.46,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19353,291,0,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19353,301,102,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19353,303,0.11,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19353,306,212,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19353,307,12,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19353,320,0,'100g',2,1,'2024-12-12','2010-01-03');
INSERT INTO `cndb_nutval` VALUES (19353,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19353,401,0,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19353,539,60.46,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19353,601,0,'100g',6,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19353,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19353,606,0.007,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19355,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19355,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19355,205,74.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19355,207,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19355,208,290,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19355,255,22.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19355,269,74.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19355,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19355,301,150,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19355,303,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19355,306,1000,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19355,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19355,320,0,'100g',1,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (19355,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19355,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19355,539,74.9,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19355,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19355,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19355,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19360,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19360,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19360,205,69.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19360,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19360,208,265,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19360,255,30.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19360,269,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19360,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19360,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19360,303,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19360,306,6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19360,307,61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19360,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19360,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19360,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19360,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19360,601,0,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19360,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19360,606,0.018,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19362,203,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19362,204,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19362,205,83.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19362,207,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19362,208,319,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19362,255,15.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19362,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19362,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19362,301,23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19362,303,0.74,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19362,306,63,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19362,307,71,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19362,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19362,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19362,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19362,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19362,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19362,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19362,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19364,203,1.21,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19364,204,0,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19364,205,57.01,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19364,207,1.15,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19364,208,216,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19364,255,40.63,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19364,269,57,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19364,291,0,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19364,301,49,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19364,303,0,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19364,306,66,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19364,307,341,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19364,320,19,'100g',2,1,'2024-12-12','2017-01-04');
INSERT INTO `cndb_nutval` VALUES (19364,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19364,401,0.5,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19364,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19364,601,0,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19364,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19364,606,0,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19365,203,0.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19365,204,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19365,205,79,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19365,207,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19365,208,322,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19365,255,19.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19365,269,46.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19365,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19365,301,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19365,303,0.22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19365,306,5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19365,307,80,'100g',6,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19365,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19365,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19365,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19365,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19365,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19365,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19365,606,0.056,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19366,203,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19366,204,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19366,205,66.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19366,207,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19366,208,253,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19366,255,33,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19366,269,21.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19366,291,0.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19366,301,6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19366,303,0.12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19366,306,43,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19366,307,42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19366,320,1,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19366,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19366,401,3.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19366,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19366,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19366,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19366,606,0.018,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19367,203,4.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19367,204,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19367,205,58.08,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19367,207,0.73,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19367,208,448,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19367,255,14.69,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19367,269,36.72,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19367,291,2.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19367,301,35,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19367,303,1.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19367,306,151,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19367,307,42,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19367,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (19367,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19367,401,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19367,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19367,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19367,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19367,606,1.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19371,203,0.34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19371,204,12.74,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19371,205,74.28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19371,207,0.47,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19371,208,413,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19371,255,12.18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19371,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19371,291,0.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19371,301,6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19371,303,0.01,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19371,306,10,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19371,307,114,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19371,320,80,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19371,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19371,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19371,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19371,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19371,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19371,606,1.74,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19372,203,1.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19372,204,12.87,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19372,205,71.02,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19372,207,0.69,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19372,208,404,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19372,255,14.07,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19372,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19372,291,1.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19372,301,12,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19372,303,0.93,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19372,306,143,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19372,307,163,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19372,320,80,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19372,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19372,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19372,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19372,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19372,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19372,606,1.74,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19375,203,0.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19375,204,0.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19375,205,83.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19375,207,0.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19375,208,341,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19375,255,15.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19375,269,80.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19375,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19375,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19375,303,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19375,306,30,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19375,307,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19375,320,4,'100g',2,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (19375,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19375,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19375,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19375,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19375,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19375,606,0.271,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19379,203,2.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19379,204,17.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19379,205,71.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19379,207,0.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19379,208,453,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19379,255,7.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19379,269,64.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19379,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19379,301,45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19379,303,0.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19379,306,147,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19379,307,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19379,320,75,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (19379,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19379,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19379,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19379,601,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19379,605,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19379,606,10.669,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19382,203,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19382,204,3.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19382,205,91.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19382,207,0.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19382,208,397,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19382,255,4.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19382,269,68.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19382,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19382,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19382,303,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19382,306,3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19382,307,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19382,320,27,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (19382,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19382,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19382,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19382,601,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19382,605,0.131,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19382,606,2.049,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19383,203,1.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19383,204,32.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19383,205,64.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19383,207,0.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19383,208,560,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19383,255,0.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19383,269,63.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19383,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19383,301,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19383,303,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19383,306,51,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19383,307,135,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19383,320,319,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (19383,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19383,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19383,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19383,601,104,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19383,605,0.674,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19383,606,20.565,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19384,203,1.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19384,204,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19384,205,89.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19384,207,0.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19384,208,364,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19384,255,9.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19384,269,78.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19384,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19384,301,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19384,303,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19384,306,23,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19384,307,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19384,320,0,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (19384,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19384,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19384,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19384,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19384,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19384,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19387,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19387,204,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19387,205,23.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19387,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19387,208,113,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19387,255,73.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19387,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19387,291,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19387,301,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19387,303,3.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19387,306,17,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19387,307,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19387,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19387,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19387,401,13.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19387,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19387,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19387,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19387,606,2.304,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19393,203,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19393,204,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19393,205,24.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19393,207,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19393,208,160,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19393,255,63.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19393,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19393,291,2.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19393,301,147,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19393,303,1.25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19393,306,261,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19393,307,98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19393,320,44,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19393,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19393,401,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19393,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19393,601,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19393,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19393,606,3.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19400,203,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19400,204,33.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19400,205,58.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19400,207,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19400,208,519,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19400,255,4.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19400,269,35.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19400,291,7.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19400,301,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19400,303,1.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19400,306,536,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19400,307,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19400,320,4,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19400,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19400,401,6.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19400,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19400,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19400,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19400,606,28.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19401,203,9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19401,204,14.3,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19401,205,71.7,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19401,207,3.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19401,208,436,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19401,255,1.6,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19401,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19401,291,8.4,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19401,301,17,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19401,303,1.7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19401,306,286,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19401,307,600,'100g',6,1,'1996-09-30','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (19401,320,17,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19401,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19401,401,0.4,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19401,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19401,601,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19401,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19401,606,2.58,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19403,203,7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19403,204,20.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19403,205,64.6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19403,207,1.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19403,208,458,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19403,255,6.7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19403,269,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19403,291,3.6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19403,301,74,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19403,303,6.35,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19403,306,229,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19403,307,234,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19403,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (19403,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19403,401,11.5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19403,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19403,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19403,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19403,606,3.77,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (19404,203,5.65,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19404,204,16.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19404,205,70.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19404,207,1.14,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19404,208,418,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19404,255,6.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19404,269,28.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19404,291,3.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19404,301,41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19404,303,2.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19404,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19404,307,291,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19404,320,0,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (19404,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19404,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19404,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19404,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19404,605,NULL,'100g',NULL,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (19404,606,6.061,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19405,203,6.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19405,204,15.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19405,205,70.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19405,207,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19405,208,427,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19405,255,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19405,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19405,291,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19405,301,89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19405,303,2.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19405,306,275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19405,307,316,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19405,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19405,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19405,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19405,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19405,601,0,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19405,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19405,606,9.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19406,203,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19406,204,20.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19406,205,63.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19406,207,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19406,208,454,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19406,255,6.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19406,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19406,291,5.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19406,301,84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19406,303,2.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19406,306,392,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19406,307,254,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19406,320,2,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19406,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19406,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19406,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19406,601,0,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19406,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19406,606,9.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19407,203,21.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19407,204,49.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19407,205,5.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19407,207,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19407,208,550,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19407,255,19.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19407,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19407,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19407,301,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19407,303,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19407,306,257,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19407,307,1531,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19407,320,13,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (19407,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19407,401,6.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19407,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19407,601,133,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19407,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19407,606,20.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19408,203,57.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19408,204,31.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19408,205,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19408,207,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19408,208,538,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19408,255,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19408,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19408,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19408,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19408,303,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19408,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19408,307,2667,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19408,320,65,'100g',2,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (19408,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19408,401,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19408,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19408,601,115,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19408,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19408,606,11.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19410,203,4.62,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19410,204,35.28,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19410,205,55.38,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19410,207,2.34,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19410,208,545,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19410,255,2.37,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19410,269,0.76,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19410,291,2.9,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19410,301,17,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19410,303,0.8,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19410,306,637,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19410,307,529,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19410,320,0,'100g',2,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (19410,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19410,401,1.2,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19410,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19410,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19410,605,0.227,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19410,606,8.643,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19411,203,6.39,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19411,204,33.98,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19411,205,53.83,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19411,207,3.94,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19411,208,532,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19411,255,1.86,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19411,269,0.33,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19411,291,3.1,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19411,301,21,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19411,303,1.28,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19411,306,1196,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19411,307,527,'100g',1,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19411,320,0,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (19411,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19411,401,21.6,'100g',6,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19411,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19411,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19411,605,0.084,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (19411,606,3.4,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19412,203,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19412,204,37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19412,205,50.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19412,207,3.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19412,208,551,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19412,255,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19412,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19412,291,3.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19412,301,110,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19412,303,1.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19412,306,381,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19412,307,600,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (19412,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19412,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19412,401,8.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19412,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19412,601,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19412,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19412,606,9.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19413,203,8.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19413,204,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19413,205,81.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19413,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19413,208,385,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19413,255,5.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19413,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19413,291,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19413,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19413,303,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19413,306,275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19413,307,167,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19413,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19413,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19413,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19413,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19413,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19413,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19413,606,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19414,203,8.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19414,204,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19414,205,80.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19414,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19414,208,387,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19414,255,6.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19414,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19414,291,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19414,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19414,303,1.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19414,306,294,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19414,307,252,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19414,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19414,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19414,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19414,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19414,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19414,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19414,606,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19415,203,6.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19415,204,34.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19415,205,53.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19415,207,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19415,208,522,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19415,255,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19415,269,0.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19415,291,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19415,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19415,303,2.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19415,306,1237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19415,307,633,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19415,320,0,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19415,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19415,401,47.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19415,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19415,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19415,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19415,606,8.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19416,203,8.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19416,204,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19416,205,79.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19416,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19416,208,386,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19416,255,6.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19416,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19416,291,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19416,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19416,303,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19416,306,311,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19416,307,110,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19416,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19416,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19416,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19416,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19416,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19416,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19416,606,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19418,203,10.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19418,204,36.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19418,205,46.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19418,207,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19418,208,541,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19418,255,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19418,269,0.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19418,291,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19418,301,170,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19418,303,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19418,306,177,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19418,307,1488,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19418,320,0,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (19418,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19418,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19418,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19418,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19418,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19418,606,6.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19419,203,8.1,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19419,204,2.4,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19419,205,83.4,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19419,207,1.5,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19419,208,387,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19419,255,4.6,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19419,269,23.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19419,291,1.9,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19419,301,19,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19419,303,1.4,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19419,306,157,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19419,307,488,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19419,320,70,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (19419,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19419,401,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19419,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19419,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19419,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19419,606,0.42,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19420,203,9.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19420,204,23.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19420,205,62.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19420,207,1.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19420,208,483,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19420,255,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19420,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19420,291,2.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19420,301,41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19420,303,2.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19420,306,291,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19420,307,283,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19420,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19420,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19420,401,0.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19420,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19420,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19420,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19420,606,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19421,203,8.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19421,204,27.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19421,205,57.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19421,207,4.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19421,208,496,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19421,255,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19421,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19421,291,5.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19421,301,72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19421,303,1.84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19421,306,1528,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19421,307,458,'100g',3,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (19421,320,10,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19421,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19421,401,54.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19421,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19421,601,4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19421,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19421,606,8.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19422,203,7.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19422,204,20.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19422,205,66.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19422,207,4.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19422,208,471,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19422,255,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19422,269,0.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19422,291,5.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19422,301,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19422,303,1.35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19422,306,1744,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19422,307,571,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19422,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19422,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19422,401,25.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19422,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19422,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19422,605,NULL,'100g',NULL,1,'1994-01-31','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (19422,606,4.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19423,203,7.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19423,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19423,205,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19423,207,4.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19423,208,274,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19423,255,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19423,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19423,291,6.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19423,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19423,303,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19423,306,1160,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19423,307,554,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19423,320,0,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (19423,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19423,401,28.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19423,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19423,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19423,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19423,606,0.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19424,203,8.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19424,204,15.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19424,205,71.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19424,207,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19424,208,445,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19424,255,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19424,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19424,291,4.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19424,301,159,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19424,303,1.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19424,306,272,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19424,307,1003,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19424,320,24,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19424,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19424,401,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19424,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19424,601,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19424,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19424,606,2.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19433,203,11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19433,204,5.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19433,205,80.2,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19433,207,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19433,208,448,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19433,255,1.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19433,269,0.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19433,291,5.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19433,301,159,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19433,303,1.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19433,306,272,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19433,307,517,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19433,320,5,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19433,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19433,401,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19433,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19433,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19433,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19433,606,0.85,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19434,203,8.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19434,204,12.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19434,205,72.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19434,207,4.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19434,208,432,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19434,255,3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19434,269,7.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19434,291,3.6,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19434,301,357,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19434,303,1.28,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19434,306,286,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19434,307,842,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19434,320,44,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (19434,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19434,401,21.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19434,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19434,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19434,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19434,606,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19435,203,5.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19435,204,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19435,205,77.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19435,207,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19435,208,342,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19435,255,13.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19435,269,45.24,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19435,291,7.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19435,301,3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19435,303,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19435,306,220,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19435,307,16,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19435,320,1,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (19435,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19435,401,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19435,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19435,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19435,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19435,606,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19436,203,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19436,204,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19436,205,90.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19436,207,0.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19436,208,381,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19436,255,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19436,269,64.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19436,291,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19436,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19436,303,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19436,306,110,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19436,307,286,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19436,320,2,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (19436,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19436,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19436,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19436,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19436,605,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19436,606,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19437,203,9.64,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19437,204,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19437,205,83.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19437,207,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19437,208,379,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19437,255,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19437,269,3.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19437,291,7.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19437,301,35,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19437,303,3.57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19437,306,1628,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19437,307,643,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19437,320,1,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (19437,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19437,401,9.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19437,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19437,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19437,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19437,606,0.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19444,203,8.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19444,204,3.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19444,205,65.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19444,207,3.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19444,208,318,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19444,255,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19444,269,2.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19444,291,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19444,301,128,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19444,303,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19444,306,396,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19444,307,705,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19444,320,9,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (19444,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19444,401,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19444,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19444,601,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19444,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19444,606,1.054,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19445,203,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19445,204,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19445,205,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19445,207,2.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19445,208,253,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19445,255,2.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19445,269,0.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19445,291,7.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19445,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19445,303,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19445,306,931,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19445,307,429,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19445,320,0,'100g',1,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (19445,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19445,401,108.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19445,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19445,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19445,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19445,606,0.355,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19524,203,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19524,204,24.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19524,205,68.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19524,207,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19524,208,498,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19524,255,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19524,269,3.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19524,291,7.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19524,301,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19524,303,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19524,306,755,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19524,307,342,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19524,320,7,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19524,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19524,401,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19524,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19524,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19524,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19524,606,6.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19701,203,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19701,204,29.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19701,205,63.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19701,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19701,208,477,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19701,255,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19701,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19701,291,5.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19701,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19701,303,3.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19701,306,365,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19701,307,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19701,320,3,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19701,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19701,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19701,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19701,601,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19701,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19701,606,17.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19702,203,7.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19702,204,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19702,205,90.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19702,207,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19702,208,381,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19702,255,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19702,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19702,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19702,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19702,303,0.15,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19702,306,7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19702,307,491,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19702,320,0,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (19702,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19702,401,62.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19702,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19702,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19702,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19702,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19703,203,55.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19703,204,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19703,205,33.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19703,207,4.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19703,208,345,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19703,255,6.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19703,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19703,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19703,301,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19703,303,0.02,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19703,306,1985,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19703,307,2751,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19703,320,0,'100g',1,1,'2024-12-12','2002-01-04');
INSERT INTO `cndb_nutval` VALUES (19703,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19703,401,490,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19703,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19703,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19703,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19703,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19704,203,55.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19704,204,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19704,205,33.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19704,207,4.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19704,208,345,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19704,255,6.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19704,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19704,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19704,301,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19704,303,0.02,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19704,306,14,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19704,307,158,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19704,320,0,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (19704,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19704,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19704,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19704,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19704,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19704,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19705,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19705,204,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19705,205,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19705,207,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19705,208,386,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19705,255,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19705,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19705,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19705,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19705,303,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19705,306,15,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19705,307,1499,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19705,320,0,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (19705,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19705,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19705,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19705,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19705,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19705,606,0.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19706,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19706,204,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19706,205,88.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19706,207,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19706,208,387,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19706,255,4.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19706,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19706,291,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19706,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19706,303,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19706,306,17,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19706,307,788,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19706,320,0,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (19706,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19706,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19706,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19706,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19706,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19706,606,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19708,203,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19708,204,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19708,205,90.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19708,207,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19708,208,366,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19708,255,5.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19708,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19708,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19708,301,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19708,303,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19708,306,257,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19708,307,849,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19708,320,0,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (19708,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19708,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19708,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19708,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19708,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19708,606,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19710,203,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19710,204,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19710,205,92.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19710,207,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19710,208,369,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19710,255,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19710,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19710,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19710,301,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19710,303,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19710,306,20,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19710,307,754,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19710,320,0,'100g',1,1,'2024-12-12','2002-01-03');
INSERT INTO `cndb_nutval` VALUES (19710,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19710,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19710,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19710,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19710,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19710,606,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19719,203,0.7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19719,204,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19719,205,64.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19719,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19719,208,242,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19719,255,34.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19719,269,43.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19719,291,0.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19719,301,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19719,303,0.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19719,306,77,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19719,307,40,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19719,320,10,'100g',2,1,'2024-12-12','2013-01-07');
INSERT INTO `cndb_nutval` VALUES (19719,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19719,401,8.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19719,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19719,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19719,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19719,606,0.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19720,203,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19720,204,0.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19720,205,69.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19720,207,0.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19720,208,265,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19720,255,30.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19720,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19720,291,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19720,301,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19720,303,0.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19720,306,22,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19720,307,61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19720,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19720,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19720,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19720,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19720,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19720,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19720,606,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19800,203,8.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19800,204,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19800,205,83.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19800,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19800,208,387,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19800,255,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19800,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19800,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19800,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19800,303,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19800,306,157,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19800,307,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19800,320,12,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19800,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19800,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19800,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19800,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19800,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19800,606,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19802,203,5.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19802,204,35.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19802,205,54.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19802,207,2.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19802,208,558,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19802,255,1.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19802,269,2.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19802,291,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19802,301,58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19802,303,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19802,306,197,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19802,307,896,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19802,320,0,'100g',1,1,'2024-12-12','2006-01-07');
INSERT INTO `cndb_nutval` VALUES (19802,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19802,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19802,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19802,601,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19802,605,0.806,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19802,606,5.512,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19804,203,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19804,204,32.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19804,205,56.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19804,207,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19804,208,523,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19804,255,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19804,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19804,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19804,301,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19804,303,4.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19804,306,236,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19804,307,763,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19804,320,31,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19804,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19804,401,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19804,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19804,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19804,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19804,606,4.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19806,203,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19806,204,4.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19806,205,77.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19806,207,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19806,208,382,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19806,255,4.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19806,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19806,291,15.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19806,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19806,303,2.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19806,306,301,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19806,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19806,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19806,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19806,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19806,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19806,601,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19806,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19806,606,0.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19807,203,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19807,204,28.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19807,205,57.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19807,207,2.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19807,208,500,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19807,255,2.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19807,269,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19807,291,10,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19807,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19807,303,2.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19807,306,225,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19807,307,884,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19807,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19807,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19807,401,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19807,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19807,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19807,605,NULL,'100g',NULL,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19807,606,4.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19809,203,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19809,204,34.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19809,205,52.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19809,207,3.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19809,208,536,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19809,255,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19809,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19809,291,4.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19809,301,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19809,303,1.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19809,306,1275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19809,307,594,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19809,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19809,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19809,401,31.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19809,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19809,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19809,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19809,606,5.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19810,203,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19810,204,34.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19810,205,52.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19810,207,3.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19810,208,536,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19810,255,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19810,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19810,291,4.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19810,301,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19810,303,1.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19810,306,1275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19810,307,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19810,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19810,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19810,401,31.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19810,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19810,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19810,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19810,606,5.43,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19811,203,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19811,204,34.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19811,205,52.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19811,207,3.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19811,208,536,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19811,255,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19811,269,0.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19811,291,4.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19811,301,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19811,303,1.63,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19811,306,1275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19811,307,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19811,320,0,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19811,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19811,401,31.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19811,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19811,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19811,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19811,606,10.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19812,203,9.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19812,204,3.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19812,205,79.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19812,207,4.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19812,208,381,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19812,255,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19812,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19812,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19812,301,36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19812,303,1.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19812,306,146,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19812,307,1715,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19812,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19812,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19812,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19812,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19812,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19812,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19812,606,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19813,203,9.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19813,204,3.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19813,205,79.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19813,207,4.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19813,208,381,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19813,255,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19813,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19813,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19813,301,36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19813,303,1.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19813,306,146,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19813,307,289,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19813,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19813,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19813,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19813,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19813,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19813,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19813,606,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19814,203,9.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19814,204,3.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19814,205,79.2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19814,207,4.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19814,208,381,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19814,255,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19814,269,2.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19814,291,2.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19814,301,36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19814,303,4.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19814,306,146,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19814,307,250,'100g',6,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (19814,320,0,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19814,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19814,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19814,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19814,601,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19814,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (19814,606,0.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (19816,203,8.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19816,204,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19816,205,81.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19816,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19816,208,387,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19816,255,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19816,269,0.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19816,291,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19816,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19816,303,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19816,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19816,307,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19816,320,0,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19816,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19816,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19816,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19816,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19816,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19816,606,0.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19817,203,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19817,204,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19817,205,80.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19817,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19817,208,380,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19817,255,5.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19817,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19817,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19817,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19817,303,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19817,306,299,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19817,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19817,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19817,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19817,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19817,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19817,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19817,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19817,606,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19818,203,8.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19818,204,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19818,205,80.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19818,207,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19818,208,387,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19818,255,6.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19818,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19818,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19818,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19818,303,1.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19818,306,294,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19818,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19818,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19818,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19818,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19818,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19818,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19818,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19818,606,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19819,203,7.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19819,204,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19819,205,81.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19819,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19819,208,392,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19819,255,5.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19819,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19819,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19819,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19819,303,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19819,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19819,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19819,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19819,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19819,401,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19819,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19819,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19819,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19819,606,0.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19820,203,10.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19820,204,36.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19820,205,46.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19820,207,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19820,208,541,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19820,255,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19820,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19820,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19820,301,170,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19820,303,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19820,306,177,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19820,307,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19820,320,4,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19820,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19820,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19820,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19820,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19820,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19820,606,6.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19821,203,13.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19821,204,29.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19821,205,44.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19821,207,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19821,208,462,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19821,255,9.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19821,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19821,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19821,301,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19821,303,3.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19821,306,685,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19821,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19821,320,1,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19821,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19821,401,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19821,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19821,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19821,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19821,606,5.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19822,203,14.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19822,204,31.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19822,205,44.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19822,207,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19822,208,484,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19822,255,6.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19822,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19822,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19822,301,109,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19822,303,3.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19822,306,648,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19822,307,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19822,320,13,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (19822,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19822,401,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19822,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19822,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19822,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19822,606,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19823,203,7.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19823,204,20.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19823,205,67.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19823,207,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19823,208,487,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19823,255,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19823,269,0.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19823,291,6.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19823,301,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19823,303,1.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19823,306,1744,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19823,307,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19823,320,0,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (19823,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19823,401,25.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19823,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19823,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19823,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19823,606,4.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19833,203,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19833,204,5.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19833,205,80.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19833,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19833,208,416,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19833,255,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19833,269,0.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19833,291,5.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19833,301,159,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19833,303,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19833,306,272,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19833,307,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19833,320,4,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (19833,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19833,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19833,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19833,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19833,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19833,606,0.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19857,203,7.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19857,204,25.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19857,205,62.3,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19857,207,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19857,208,511,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19857,255,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19857,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19857,291,5.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19857,301,147,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19857,303,3.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19857,306,216,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19857,307,708,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19857,320,24,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (19857,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19857,401,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19857,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19857,601,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19857,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19857,606,4.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19858,203,10,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19858,204,17.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19858,205,68.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19858,207,1.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19858,208,465,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19858,255,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19858,269,62.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19858,291,2.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19858,301,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19858,303,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19858,306,255,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19858,307,13,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19858,320,0,'100g',2,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (19858,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19858,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19858,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19858,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19858,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19858,606,1.948,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19860,203,16.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19860,204,23.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19860,205,49.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19860,207,6.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19860,208,479,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19860,255,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19860,269,1.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19860,291,33.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19860,301,122,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19860,303,14.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19860,306,2509,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19860,307,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19860,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19860,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19860,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19860,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19860,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19860,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19860,606,12.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19866,203,2.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19866,204,9.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19866,205,73.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19866,207,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19866,208,390,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19866,255,13.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19866,269,45.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19866,291,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19866,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19866,303,0.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19866,306,82,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19866,307,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19866,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19866,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19866,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19866,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19866,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19866,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19866,606,0.898,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19867,203,4.48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19867,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19867,205,30.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19867,207,1.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19867,208,138,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19867,255,64.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19867,269,6.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19867,291,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19867,301,149,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19867,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19867,306,302,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19867,307,97,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19867,320,200,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (19867,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19867,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19867,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19867,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19867,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19867,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19898,203,3.17,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19898,204,12.7,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19898,205,22.23,'100g',3,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19898,207,0.9,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19898,208,216,'100g',3,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19898,255,61,'100g',1,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19898,269,6.35,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19898,291,4.8,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19898,301,128,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19898,303,0.09,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19898,306,199,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19898,307,48,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19898,320,118,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (19898,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19898,401,0.6,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19898,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19898,601,32,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19898,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19898,606,6.79,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19899,203,3.8,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19899,204,12.7,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19899,205,26.8,'100g',3,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19899,207,1,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19899,208,237,'100g',3,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19899,255,55.7,'100g',1,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19899,269,6.35,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19899,291,4.8,'100g',6,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19899,301,109,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19899,303,0.93,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19899,306,249,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19899,307,76,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19899,320,118,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (19899,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19899,401,0.7,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19899,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19899,601,34,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19899,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (19899,606,6.8,'100g',1,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (19902,203,4.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19902,204,31.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19902,205,61.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19902,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19902,208,546,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19902,255,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19902,269,47.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19902,291,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19902,301,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19902,303,8.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19902,306,559,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19902,307,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19902,320,2,'100g',1,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (19902,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19902,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19902,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19902,601,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19902,605,0.112,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19902,606,18.519,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19903,203,6.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19903,204,38.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19903,205,52.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19903,207,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19903,208,579,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19903,255,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19903,269,36.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19903,291,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19903,301,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19903,303,6.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19903,306,567,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19903,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19903,320,3,'100g',1,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (19903,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19903,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19903,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19903,601,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19903,605,0.079,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19903,606,22.031,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19904,203,7.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19904,204,42.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19904,205,45.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19904,207,2.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19904,208,598,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19904,255,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19904,269,23.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19904,291,10.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19904,301,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19904,303,11.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19904,306,715,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19904,307,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19904,320,2,'100g',1,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (19904,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19904,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19904,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19904,601,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19904,605,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19904,606,24.489,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19905,203,5.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19905,204,32.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19905,205,59.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19905,207,1.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19905,208,550,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19905,255,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19905,269,46.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19905,291,7.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19905,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19905,303,8.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19905,306,568,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19905,307,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19905,320,2,'100g',1,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (19905,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19905,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19905,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19905,601,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19905,605,0.106,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (19905,606,18.993,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19910,203,9.53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19910,204,31.34,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19910,205,55.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19910,207,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19910,208,542,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19910,255,1.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19910,269,40.33,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19910,291,3.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19910,301,70,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19910,303,1.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19910,306,295,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19910,307,264,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19910,320,15,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (19910,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19910,401,0.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19910,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19910,601,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19910,605,0.02,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19910,606,12.959,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (19912,203,0.09,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19912,204,0.45,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19912,205,76.37,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19912,207,0.14,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19912,208,310,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19912,255,22.94,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19912,269,68.03,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19912,291,0.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19912,301,1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19912,303,0.09,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19912,306,4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19912,307,4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19912,320,8,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (19912,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19912,401,17,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19912,539,68.03,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19912,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19912,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (19912,606,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19918,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19918,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19918,205,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19918,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19918,208,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19918,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19918,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19918,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19918,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19918,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19918,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19918,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19918,320,0,'100g',2,1,'2024-12-12','2013-01-06');
INSERT INTO `cndb_nutval` VALUES (19918,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19918,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19918,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (19918,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19918,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19918,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19919,203,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19919,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19919,205,87.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19919,207,0.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19919,208,352,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19919,255,11.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19919,269,68.18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19919,291,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19919,301,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19919,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19919,306,8,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19919,307,23,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19919,320,0,'100g',2,1,'2024-12-12','2013-01-07');
INSERT INTO `cndb_nutval` VALUES (19919,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19919,401,136.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19919,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19919,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19919,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19919,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (19920,203,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19920,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19920,205,52.93,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19920,207,0.23,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19920,208,212,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19920,255,46.84,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19920,269,42,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19920,291,0.9,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19920,301,11,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19920,303,0.34,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19920,306,65,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19920,307,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19920,320,1,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (19920,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19920,401,18.1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19920,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19920,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19920,605,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19920,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19921,203,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19921,204,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19921,205,91.96,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19921,207,5.52,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19921,208,331,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (19921,255,2.52,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19921,269,78.57,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19921,291,2.5,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19921,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19921,303,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19921,306,309,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19921,307,1643,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19921,320,1,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (19921,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19921,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19921,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19921,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19921,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (19921,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19922,203,2.13,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19922,204,27.65,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19922,205,55.87,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19922,207,1.1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19922,208,481,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19922,255,13.26,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19922,269,36.16,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19922,291,6.4,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19922,301,43,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19922,303,0.77,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19922,306,294,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19922,307,128,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19922,320,0,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (19922,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (19922,401,2.7,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19922,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (19922,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (19922,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (19922,606,25.54,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20001,203,13.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20001,204,7.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20001,205,65.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20001,207,2.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20001,208,371,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20001,255,11.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20001,269,1.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20001,291,6.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20001,301,159,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20001,303,7.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20001,306,508,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20001,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20001,320,0,'100g',1,1,'2024-12-12','2008-01-05');
INSERT INTO `cndb_nutval` VALUES (20001,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20001,401,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20001,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20001,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20001,605,NULL,'100g',NULL,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20001,606,1.459,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20003,203,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20003,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20003,205,88.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20003,207,0.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20003,208,357,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20003,255,11.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20003,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20003,291,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20003,301,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20003,303,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20003,306,11,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20003,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20003,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20003,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20003,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20003,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20003,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20003,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20003,606,0.019,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20004,203,12.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20004,204,2.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20004,205,73.48,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20004,207,2.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20004,208,354,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20004,255,9.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20004,269,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20004,291,17.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20004,301,33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20004,303,3.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20004,306,452,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20004,307,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20004,320,1,'100g',2,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (20004,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20004,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20004,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20004,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20004,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20004,606,0.482,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20005,203,9.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20005,204,1.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20005,205,77.72,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20005,207,1.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20005,208,352,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20005,255,10.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20005,269,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20005,291,15.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20005,301,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20005,303,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20005,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20005,307,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20005,320,1,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (20005,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20005,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20005,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20005,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20005,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20005,606,0.244,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20006,203,2.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20006,204,0.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20006,205,28.22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20006,207,0.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20006,208,123,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20006,255,68.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20006,269,0.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20006,291,3.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20006,301,11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20006,303,1.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20006,306,93,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20006,307,3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20006,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (20006,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20006,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20006,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20006,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20006,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20006,606,0.093,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20008,203,13.25,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20008,204,3.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20008,205,71.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20008,207,2.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20008,208,343,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20008,255,9.75,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20008,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20008,291,10,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20008,301,18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20008,303,2.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20008,306,460,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20008,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20008,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20008,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20008,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20008,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20008,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20008,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20008,606,0.741,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20009,203,11.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20009,204,2.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20009,205,74.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20009,207,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20009,208,346,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20009,255,8.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20009,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20009,291,10.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20009,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20009,303,2.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20009,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20009,307,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20009,320,0,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (20009,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20009,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20009,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20009,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20009,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20009,606,0.591,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20010,203,3.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20010,204,0.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20010,205,19.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20010,207,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20010,208,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20010,255,75.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20010,269,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20010,291,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20010,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20010,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20010,306,88,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20010,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20010,320,0,'100g',2,1,'2024-12-12','2006-01-11');
INSERT INTO `cndb_nutval` VALUES (20010,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20010,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20010,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20010,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20010,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20010,606,0.134,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20011,203,12.62,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20011,204,3.1,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20011,205,70.59,'100g',3,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20011,207,2.54,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20011,208,335,'100g',3,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20011,255,11.15,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20011,269,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20011,291,10,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20011,301,41,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20011,303,4.06,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20011,306,577,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20011,307,11,'100g',3,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20011,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (20011,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20011,401,0,'100g',3,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20011,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20011,601,0,'100g',4,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20011,605,NULL,'100g',NULL,1,'2005-12-28','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20011,606,0.677,'100g',1,1,'2005-12-28','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20012,203,12.29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20012,204,1.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20012,205,75.87,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20012,207,1.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20012,208,342,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20012,255,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20012,269,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20012,291,12.5,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20012,301,35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20012,303,2.46,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20012,306,410,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20012,307,17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20012,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (20012,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20012,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20012,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20012,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20012,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20012,606,0.232,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20013,203,3.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20013,204,0.24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20013,205,18.58,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20013,207,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20013,208,83,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20013,255,77.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20013,269,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20013,291,4.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20013,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20013,303,0.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20013,306,68,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20013,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20013,320,0,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (20013,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20013,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20013,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20013,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20013,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20013,606,0.042,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20014,203,9.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20014,204,4.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20014,205,74.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20014,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20014,208,365,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20014,255,10.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20014,269,0.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20014,291,7.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20014,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20014,303,2.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20014,306,287,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20014,307,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20014,320,11,'100g',2,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (20014,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20014,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20014,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20014,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20014,605,NULL,'100g',NULL,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20014,606,0.667,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20015,203,8.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20015,204,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20015,205,85.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20015,207,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20015,208,224,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20015,255,4.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20015,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20015,291,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20015,301,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20015,303,2.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20015,306,44,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20015,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20015,320,4,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (20015,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20015,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20015,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20015,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20015,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20015,606,0.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20016,203,6.93,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20016,204,3.86,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20016,205,76.85,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20016,207,1.45,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20016,208,361,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20016,255,10.91,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20016,269,0.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20016,291,7.3,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20016,301,7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20016,303,2.38,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20016,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20016,307,5,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20016,320,11,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (20016,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20016,401,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20016,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20016,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20016,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20016,606,0.543,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20017,203,8.46,'100g',1,1,'1995-06-26','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20017,204,3.69,'100g',1,1,'1995-06-26','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20017,205,76.59,'100g',3,1,'1995-06-26','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20017,207,1.48,'100g',1,1,'1995-06-26','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20017,208,363,'100g',3,1,'1995-06-26','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20017,255,9.79,'100g',1,1,'1995-06-26','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20017,269,1.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20017,291,6.4,'100g',1,1,'1995-06-26','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20017,301,138,'100g',1,1,'1995-06-26','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20017,303,8.5,'100g',1,1,'1995-06-26','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20017,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20017,307,5,'100g',1,1,'1995-06-26','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20017,320,0,'100g',1,1,'2024-12-12','2009-01-12');
INSERT INTO `cndb_nutval` VALUES (20017,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20017,401,0,'100g',3,1,'1995-06-26','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20017,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20017,601,0,'100g',4,1,'1995-06-26','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20017,605,NULL,'100g',NULL,1,'1995-06-23','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (20017,606,0.532,'100g',1,1,'1995-06-26','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20018,203,5.59,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20018,204,1.39,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20018,205,82.75,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20018,207,0.46,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20018,208,375,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20018,255,9.81,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20018,269,0.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20018,291,1.9,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20018,301,2,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20018,303,0.91,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20018,306,90,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20018,307,1,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20018,320,11,'100g',2,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (20018,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20018,401,0,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20018,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20018,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20018,605,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20018,606,0.171,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20019,203,8.46,'100g',1,1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20019,204,3.69,'100g',1,1,'2011-01-18','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20019,205,76.59,'100g',3,1,'2011-01-18','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20019,207,1.48,'100g',1,1,'2011-01-18','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20019,208,363,'100g',3,1,'2011-01-18','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20019,255,9.79,'100g',1,1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20019,269,1.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20019,291,6.4,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20019,301,138,'100g',1,1,'2011-01-18','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20019,303,1.47,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20019,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20019,307,5,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20019,320,0,'100g',1,1,'2024-12-12','2009-01-12');
INSERT INTO `cndb_nutval` VALUES (20019,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20019,401,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20019,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20019,601,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20019,605,NULL,'100g',NULL,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20019,606,0.532,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20020,203,8.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20020,204,3.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20020,205,76.89,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20020,207,1.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20020,208,362,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20020,255,10.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20020,269,0.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20020,291,7.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20020,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20020,303,3.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20020,306,287,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20020,307,35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20020,320,11,'100g',2,1,'2024-12-12','2007-01-01');
INSERT INTO `cndb_nutval` VALUES (20020,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20020,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20020,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20020,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20020,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20020,606,0.505,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20022,203,7.11,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20022,204,1.75,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20022,205,79.45,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20022,207,0.51,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20022,208,370,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20022,255,11.18,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20022,269,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20022,291,3.9,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20022,301,3,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20022,303,4.36,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20022,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20022,307,7,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20022,320,11,'100g',1,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (20022,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20022,401,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20022,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20022,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20022,605,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20022,606,0.22,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (20023,203,8.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20023,204,3.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20023,205,70.28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20023,207,5.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20023,208,334,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20023,255,12.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20023,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20023,291,6.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20023,301,361,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20023,303,5.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20023,306,255,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20023,307,1247,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20023,320,23,'100g',2,1,'2024-12-12','2008-01-08');
INSERT INTO `cndb_nutval` VALUES (20023,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20023,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20023,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20023,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20023,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20023,606,0.478,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20024,203,8.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20024,204,2.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20024,205,73.43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20024,207,4.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20024,208,348,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20024,255,10.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20024,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20024,291,6.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20024,301,299,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20024,303,4.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20024,306,207,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20024,307,1319,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20024,320,14,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (20024,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20024,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20024,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20024,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20024,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20024,606,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20025,203,8.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20025,204,1.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20025,205,74.79,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20025,207,4.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20025,208,355,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20025,255,10.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20025,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20025,291,7.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20025,301,350,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20025,303,4.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20025,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20025,307,1348,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20025,320,11,'100g',2,1,'2024-12-12','2008-01-06');
INSERT INTO `cndb_nutval` VALUES (20025,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20025,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20025,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20025,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20025,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20025,606,0.234,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20027,203,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20027,204,0.05,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20027,205,91.27,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20027,207,0.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20027,208,381,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20027,255,8.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20027,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20027,291,0.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20027,301,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20027,303,0.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20027,306,3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20027,307,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20027,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (20027,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20027,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20027,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20027,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20027,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20027,606,0.009,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20028,203,12.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20028,204,0.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20028,205,77.43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20028,207,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20028,208,376,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20028,255,8.56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20028,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20028,291,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20028,301,24,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20028,303,1.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20028,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20028,307,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20028,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20028,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20028,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20028,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20028,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20028,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20028,606,0.117,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20029,203,3.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20029,204,0.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20029,205,23.22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20029,207,0.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20029,208,112,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20029,255,72.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20029,269,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20029,291,1.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20029,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20029,303,0.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20029,306,58,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20029,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20029,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (20029,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20029,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20029,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20029,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20029,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20029,606,0.029,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20030,203,1.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20030,204,0.88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20030,205,14.26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20030,207,0.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20030,208,72,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20030,255,82.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20030,269,1.51,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20030,291,2.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20030,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20030,303,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20030,306,9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20030,307,267,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20030,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (20030,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20030,401,0.3,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20030,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20030,601,0,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20030,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20030,606,0.123,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20031,203,11.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20031,204,4.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20031,205,72.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20031,207,3.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20031,208,378,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20031,255,8.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20031,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20031,291,8.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20031,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20031,303,3.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20031,306,195,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20031,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20031,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20031,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20031,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20031,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20031,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20031,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20031,606,0.723,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20032,203,3.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20032,204,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20032,205,23.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20032,207,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20032,208,119,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20032,255,71.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20032,269,0.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20032,291,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20032,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20032,303,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20032,306,62,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20032,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20032,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (20032,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20032,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20032,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20032,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20032,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20032,606,0.172,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20033,203,17.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20033,204,7.03,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20033,205,66.22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20033,207,2.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20033,208,246,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20033,255,6.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20033,269,1.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20033,291,15.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20033,301,58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20033,303,5.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20033,306,566,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20033,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20033,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (20033,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20033,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20033,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20033,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20033,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20033,606,1.328,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20034,203,3.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20034,204,0.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20034,205,11.44,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20034,207,0.49,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20034,208,40,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20034,255,84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20034,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20034,291,2.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20034,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20034,303,0.88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20034,306,92,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20034,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20034,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20034,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20034,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20034,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20034,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20034,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20034,606,0.163,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20035,203,14.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20035,204,6.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20035,205,64.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20035,207,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20035,208,368,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20035,255,13.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20035,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20035,291,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20035,301,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20035,303,4.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20035,306,563,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20035,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20035,320,1,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (20035,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20035,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20035,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20035,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20035,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20035,606,0.706,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20036,203,7.54,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20036,204,3.2,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20036,205,76.25,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20036,207,1.21,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20036,208,367,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20036,255,11.8,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20036,269,0.66,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20036,291,3.6,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20036,301,9,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20036,303,1.29,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20036,306,250,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20036,307,5,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20036,320,0,'100g',1,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (20036,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20036,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20036,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20036,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20036,605,0.001,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20036,606,0.591,'100g',3,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20037,203,2.74,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20037,204,0.97,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20037,205,25.58,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20037,207,0.44,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20037,208,123,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20037,255,70.27,'100g',1,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20037,269,0.24,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20037,291,1.6,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20037,301,3,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20037,303,0.56,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20037,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20037,307,4,'100g',1,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20037,320,0,'100g',1,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (20037,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20037,401,0,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20037,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20037,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20037,605,0,'100g',NULL,1,'1994-01-31','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20037,606,0.26,'100g',3,1,'1994-01-31','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20038,203,16.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20038,204,6.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20038,205,66.27,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20038,207,1.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20038,208,389,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20038,255,8.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20038,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20038,291,10.6,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20038,301,54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20038,303,4.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20038,306,429,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20038,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20038,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20038,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20038,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20038,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20038,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20038,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20038,606,1.217,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20040,203,7.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20040,204,2.68,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20040,205,76.17,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20040,207,1.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20040,208,362,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20040,255,12.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20040,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20040,291,3.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20040,301,33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20040,303,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20040,306,268,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20040,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20040,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20040,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20040,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20040,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20040,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20040,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20040,606,0.536,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20041,203,2.32,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20041,204,0.83,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20041,205,23.51,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20041,207,0.39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20041,208,112,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20041,255,72.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20041,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20041,291,1.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20041,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20041,303,0.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20041,306,79,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20041,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20041,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20041,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20041,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20041,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20041,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20041,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20041,606,0.165,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20044,203,7.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20044,204,0.66,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20044,205,79.95,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20044,207,0.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20044,208,365,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20044,255,11.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20044,269,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20044,291,1.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20044,301,28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20044,303,4.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20044,306,115,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20044,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20044,320,0,'100g',1,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (20044,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20044,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20044,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20044,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20044,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20044,606,0.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20045,203,2.69,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20045,204,0.28,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20045,205,28.17,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20045,207,0.41,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20045,208,130,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20045,255,68.44,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20045,269,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20045,291,0.4,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20045,301,10,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20045,303,1.2,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20045,306,35,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20045,307,1,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20045,320,0,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (20045,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20045,401,0,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20045,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20045,601,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20045,605,NULL,'100g',NULL,1,'2004-07-15','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (20045,606,0.077,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20046,203,7.51,'100g',1,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20046,204,1.03,'100g',1,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20046,205,80.89,'100g',3,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20046,207,0.71,'100g',1,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20046,208,374,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20046,255,9.86,'100g',1,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20046,269,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20046,291,1.8,'100g',1,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20046,301,71,'100g',1,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20046,303,3.33,'100g',1,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20046,306,174,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20046,307,2,'100g',1,1,'1994-11-14','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20046,320,0,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (20046,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20046,401,0,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20046,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20046,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20046,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20046,606,0.294,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20047,203,2.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20047,204,0.37,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20047,205,26.05,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20047,207,0.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20047,208,123,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20047,255,70.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20047,269,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20047,291,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20047,301,19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20047,303,1.81,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20047,306,56,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20047,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20047,320,0,'100g',1,1,'2024-12-12','2009-01-12');
INSERT INTO `cndb_nutval` VALUES (20047,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20047,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20047,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20047,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20047,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20047,606,0.074,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20048,203,7.82,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20048,204,0.94,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20048,205,82.32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20048,207,0.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20048,208,380,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20048,255,8.38,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20048,269,0.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20048,291,1.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20048,301,22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20048,303,6.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20048,306,27,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20048,307,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20048,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (20048,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20048,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20048,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20048,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20048,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20048,606,0.152,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20049,203,2.18,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20049,204,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20049,205,26.76,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20049,207,0.22,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20049,208,124,'100g',3,1,'1994-01-31','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20049,255,70.34,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20049,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20049,291,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20049,301,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20049,303,1.77,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20049,306,9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20049,307,4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20049,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (20049,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20049,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20049,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20049,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20049,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20049,606,0.017,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20050,203,6.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20050,204,0.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20050,205,79.34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20050,207,0.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20050,208,360,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20050,255,12.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20050,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20050,291,1.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20050,301,9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20050,303,4.36,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20050,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20050,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20050,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20050,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20050,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20050,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20050,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20050,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20050,606,0.158,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20051,203,2.38,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20051,204,0.21,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20051,205,28.59,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20051,207,0.21,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20051,208,130,'100g',3,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20051,255,68.61,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20051,269,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20051,291,0.3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20051,301,3,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20051,303,1.49,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20051,306,29,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20051,307,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20051,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20051,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20051,401,0,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20051,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20051,601,0,'100g',4,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20051,605,NULL,'100g',NULL,1,'1994-09-20','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20051,606,0.057,'100g',1,1,'1994-11-14','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20052,203,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20052,204,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20052,205,79.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20052,207,0.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20052,208,358,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20052,255,13.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20052,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20052,291,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20052,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20052,303,4.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20052,306,76,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20052,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20052,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20052,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20052,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20052,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20052,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20052,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20052,606,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20053,203,2.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20053,204,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20053,205,28.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20053,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20053,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20053,255,68.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20053,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20053,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20053,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20053,303,1.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20053,306,26,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20053,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20053,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20053,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20053,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20053,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20053,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20053,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20053,606,0.051,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20054,203,6.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20054,204,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20054,205,81.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20054,207,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20054,208,370,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20054,255,10.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20054,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20054,291,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20054,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20054,303,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20054,306,77,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20054,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20054,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20054,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20054,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20054,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20054,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20054,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20054,606,0.111,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20055,203,2.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20055,204,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20055,205,21.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20055,207,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20055,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20055,255,76.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20055,269,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20055,291,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20055,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20055,303,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20055,306,10,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20055,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20055,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (20055,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20055,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20055,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20055,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20055,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20055,606,0.039,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20060,203,13.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20060,204,20.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20060,205,49.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20060,207,9.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20060,208,316,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20060,255,6.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20060,269,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20060,291,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20060,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20060,303,18.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20060,306,1485,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20060,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20060,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (20060,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20060,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20060,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20060,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20060,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20060,606,4.171,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20061,203,5.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20061,204,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20061,205,80.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20061,207,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20061,208,366,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20061,255,11.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20061,269,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20061,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20061,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20061,303,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20061,306,76,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20061,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20061,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (20061,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20061,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20061,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20061,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20061,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20061,606,0.386,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20062,203,10.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20062,204,1.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20062,205,75.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20062,207,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20062,208,338,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20062,255,10.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20062,269,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20062,291,15.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20062,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20062,303,2.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20062,306,510,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20062,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20062,320,1,'100g',2,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (20062,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20062,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20062,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20062,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20062,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20062,606,0.197,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20063,203,15.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20063,204,2.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20063,205,68.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20063,207,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20063,208,325,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20063,255,10.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20063,269,2.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20063,291,23.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20063,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20063,303,4.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20063,306,717,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20063,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20063,320,1,'100g',1,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (20063,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20063,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20063,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20063,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20063,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20063,606,0.269,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20064,203,10.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20064,204,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20064,205,75.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20064,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20064,208,349,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20064,255,10.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20064,269,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20064,291,11.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20064,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20064,303,2.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20064,306,374,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20064,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20064,320,0,'100g',1,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (20064,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20064,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20064,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20064,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20064,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20064,606,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20065,203,9.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20065,204,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20065,205,76.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20065,207,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20065,208,357,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20065,255,11.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20065,269,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20065,291,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20065,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20065,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20065,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20065,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20065,320,0,'100g',1,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (20065,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20065,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20065,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20065,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20065,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20065,606,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20066,203,12.68,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20066,204,1.05,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20066,205,72.83,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20066,207,0.77,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20066,208,360,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20066,255,12.67,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20066,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20066,291,3.9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20066,301,17,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20066,303,4.36,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20066,306,186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20066,307,1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20066,320,0,'100g',2,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (20066,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20066,401,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20066,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20066,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20066,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20066,606,0.15,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20067,203,10.62,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20067,204,3.46,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20067,205,72.09,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20067,207,1.43,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20067,208,329,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20067,255,12.4,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20067,269,2.53,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20067,291,6.7,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20067,301,13,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20067,303,3.36,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20067,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20067,307,2,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20067,320,0,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (20067,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20067,401,0,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20067,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20067,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20067,605,0.005,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20067,606,0.61,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20068,203,0.19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20068,204,0.02,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20068,205,88.69,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20068,207,0.11,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20068,208,358,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20068,255,10.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20068,269,3.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20068,291,0.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20068,301,20,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20068,303,1.58,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20068,306,11,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20068,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20068,320,0,'100g',1,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (20068,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20068,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20068,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20068,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20068,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20068,606,0.005,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20069,203,13.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20069,204,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20069,205,72.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20069,207,2.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20069,208,336,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20069,255,10.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20069,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20069,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20069,301,37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20069,303,2.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20069,306,332,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20069,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20069,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20069,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20069,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20069,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20069,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20069,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20069,606,0.366,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20070,203,13.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20070,204,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20070,205,73.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20070,207,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20070,208,338,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20070,255,10.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20070,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20070,291,14.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20070,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20070,303,2.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20070,306,466,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20070,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20070,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20070,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20070,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20070,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20070,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20070,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20070,606,0.318,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20071,203,15.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20071,204,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20071,205,68.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20071,207,1.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20071,208,329,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20071,255,12.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20071,269,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20071,291,12.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20071,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20071,303,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20071,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20071,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20071,320,0,'100g',2,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (20071,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20071,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20071,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20071,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20071,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20071,606,0.314,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20072,203,12.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20072,204,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20072,205,71.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20072,207,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20072,208,327,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20072,255,13.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20072,269,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20072,291,12.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20072,301,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20072,303,3.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20072,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20072,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20072,320,0,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (20072,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20072,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20072,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20072,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20072,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20072,606,0.269,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20073,203,10.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20073,204,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20073,205,74.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20073,207,1.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20073,208,331,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20073,255,12.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20073,269,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20073,291,12.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20073,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20073,303,3.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20073,306,397,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20073,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20073,320,0,'100g',1,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (20073,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20073,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20073,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20073,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20073,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20073,606,0.289,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20074,203,11.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20074,204,1.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20074,205,75.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20074,207,1.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20074,208,342,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20074,255,9.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20074,269,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20074,291,12.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20074,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20074,303,4.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20074,306,432,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20074,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20074,320,0,'100g',2,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (20074,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20074,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20074,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20074,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20074,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20074,606,0.277,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20075,203,10.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20075,204,1.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20075,205,75.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20075,207,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20075,208,340,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20075,255,10.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20075,269,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20075,291,12.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20075,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20075,303,5.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20075,306,435,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20075,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20075,320,0,'100g',2,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (20075,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20075,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20075,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20075,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20075,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20075,606,0.368,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20076,203,13.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20076,204,2.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20076,205,71.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20076,207,1.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20076,208,339,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20076,255,10.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20076,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20076,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20076,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20076,303,3.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20076,306,431,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20076,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20076,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20076,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20076,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20076,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20076,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20076,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20076,606,0.454,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20077,203,15.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20077,204,4.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20077,205,64.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20077,207,5.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20077,208,216,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20077,255,9.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20077,269,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20077,291,42.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20077,301,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20077,303,10.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20077,306,1182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20077,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20077,320,0,'100g',1,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (20077,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20077,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20077,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20077,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20077,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20077,606,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20078,203,23.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20078,204,9.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20078,205,51.8,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20078,207,4.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20078,208,360,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20078,255,11.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20078,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20078,291,13.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20078,301,39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20078,303,6.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20078,306,892,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20078,307,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20078,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20078,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20078,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20078,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20078,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20078,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20078,606,1.665,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20080,203,13.21,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20080,204,2.5,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20080,205,71.97,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20080,207,1.58,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20080,208,340,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20080,255,10.74,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20080,269,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20080,291,10.7,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20080,301,34,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20080,303,3.6,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20080,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20080,307,2,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20080,320,0,'100g',1,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (20080,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20080,401,0,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20080,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20080,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20080,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (20080,606,0.43,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20081,203,10.33,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20081,204,0.98,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20081,205,76.31,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20081,207,0.47,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20081,208,364,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20081,255,11.92,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20081,269,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20081,291,2.7,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20081,301,15,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20081,303,4.64,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20081,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20081,307,2,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20081,320,0,'100g',1,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (20081,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20081,401,0,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20081,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20081,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20081,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (20081,606,0.155,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20082,203,9.89,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20082,204,0.97,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20082,205,74.22,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20082,207,4.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20082,208,354,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20082,255,10.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20082,269,0.22,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20082,291,2.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20082,301,338,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20082,303,4.67,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20082,306,124,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20082,307,1193,'100g',6,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (20082,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (20082,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20082,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20082,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20082,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20082,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20082,606,0.154,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20083,203,11.98,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20083,204,1.66,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20083,205,72.53,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20083,207,0.47,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20083,208,361,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20083,255,13.36,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20083,269,0.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20083,291,2.4,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20083,301,15,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20083,303,4.41,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20083,306,100,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20083,307,2,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20083,320,0,'100g',1,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (20083,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20083,401,0,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20083,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20083,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20083,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (20083,606,0.244,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20084,203,8.2,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20084,204,0.86,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20084,205,78.03,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20084,207,0.39,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20084,208,362,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20084,255,12.51,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20084,269,0.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20084,291,1.7,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20084,301,14,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20084,303,7.32,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20084,306,105,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20084,307,2,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20084,320,0,'100g',1,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (20084,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20084,401,0,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20084,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20084,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20084,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (20084,606,0.127,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20086,203,9.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20086,204,10.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20086,205,67.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20086,207,2.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20086,208,405,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20086,255,10.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20086,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20086,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20086,301,205,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20086,303,7.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20086,306,100,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20086,307,677,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20086,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20086,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20086,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20086,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20086,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20086,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20086,606,4.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20087,203,7.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20087,204,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20087,205,42.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20087,207,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20087,208,198,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20087,255,47.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20087,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20087,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20087,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20087,303,2.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20087,306,169,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20087,307,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20087,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20087,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20087,401,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20087,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20087,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20087,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20087,606,0.206,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20088,203,14.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20088,204,1.08,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20088,205,74.9,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20088,207,1.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20088,208,357,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20088,255,7.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20088,269,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20088,291,6.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20088,301,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20088,303,1.96,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20088,306,427,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20088,307,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20088,320,1,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (20088,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20088,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20088,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20088,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20088,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20088,606,0.156,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20089,203,3.99,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20089,204,0.34,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20089,205,21.34,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20089,207,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20089,208,101,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20089,255,73.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20089,269,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20089,291,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20089,301,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20089,303,0.6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20089,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20089,307,3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20089,320,0,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (20089,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20089,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20089,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20089,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20089,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20089,606,0.049,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20090,203,7.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20090,204,2.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20090,205,76.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20090,207,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20090,208,363,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20090,255,11.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20090,269,0.66,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20090,291,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20090,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20090,303,1.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20090,306,289,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20090,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20090,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20090,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20090,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20090,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20090,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20090,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20090,606,0.557,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20091,203,7.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20091,204,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20091,205,79.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20091,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20091,208,357,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20091,255,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20091,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20091,291,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20091,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20091,303,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20091,306,294,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20091,307,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20091,320,9,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20091,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20091,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20091,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20091,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20091,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20091,606,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20092,203,2.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20092,204,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20092,205,27.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20092,207,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20092,208,126,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20092,255,68.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20092,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20092,291,4.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20092,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20092,303,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20092,306,31,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20092,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20092,320,3,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20092,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20092,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20092,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20092,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20092,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20092,606,0.102,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20093,203,11.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20093,204,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20093,205,54.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20093,207,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20093,208,288,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20093,255,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20093,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20093,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20093,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20093,303,3.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20093,306,179,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20093,307,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20093,320,14,'100g',2,1,'2024-12-12','2002-01-07');
INSERT INTO `cndb_nutval` VALUES (20093,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20093,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20093,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20093,601,73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20093,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20093,606,0.328,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20094,203,5.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20094,204,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20094,205,24.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20094,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20094,208,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20094,255,68.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20094,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20094,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20094,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20094,303,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20094,306,24,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20094,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20094,320,6,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20094,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20094,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20094,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20094,601,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20094,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20094,606,0.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20095,203,11.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20095,204,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20095,205,55.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20095,207,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20095,208,289,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20095,255,30.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20095,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20095,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20095,301,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20095,303,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20095,306,272,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20095,307,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20095,320,25,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20095,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20095,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20095,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20095,601,73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20095,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20095,606,0.483,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20096,203,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20096,204,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20096,205,25.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20096,207,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20096,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20096,255,68.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20096,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20096,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20096,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20096,303,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20096,306,37,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20096,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20096,320,10,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20096,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20096,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20096,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20096,601,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20096,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20096,606,0.217,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20097,203,5.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20097,204,1.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20097,205,23.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20097,207,0.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20097,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20097,255,68.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20097,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20097,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20097,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20097,303,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20097,306,21,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20097,307,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20097,320,17,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20097,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20097,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20097,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20097,601,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20097,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20097,606,0.408,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20098,203,4.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20098,204,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20098,205,25.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20098,207,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20098,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20098,255,68.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20098,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20098,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20098,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20098,303,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20098,306,19,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20098,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20098,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20098,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20098,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20098,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20098,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20098,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20098,606,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20105,203,13.14,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20105,204,1.04,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20105,205,74.88,'100g',3,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20105,207,1.05,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20105,208,367,'100g',3,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20105,255,9.89,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20105,269,NULL,'100g',NULL,1,'1998-03-27','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20105,291,4.3,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20105,301,34,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20105,303,4.28,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20105,306,285,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20105,307,43,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20105,320,8,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (20105,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20105,401,0,'100g',3,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20105,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20105,601,0,'100g',4,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20105,605,NULL,'100g',NULL,1,'1998-03-27','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20105,606,0.15,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20106,203,4.53,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20106,204,0.11,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20106,205,26.61,'100g',3,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20106,207,0.38,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20106,208,128,'100g',3,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20106,255,68.37,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20106,269,1.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20106,291,4.3,'100g',3,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20106,301,11,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20106,303,0.49,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20106,306,31,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20106,307,6,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20106,320,5,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (20106,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20106,401,0,'100g',3,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20106,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20106,601,0,'100g',4,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20106,605,NULL,'100g',NULL,1,'1998-03-27','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20106,606,0.016,'100g',1,1,'1998-03-27','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20109,203,14.16,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20109,204,4.44,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20109,205,71.27,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20109,207,1.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20109,208,384,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20109,255,9.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20109,269,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20109,291,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20109,301,35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20109,303,4.01,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20109,306,244,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20109,307,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20109,320,17,'100g',2,1,'2024-12-12','2004-01-11');
INSERT INTO `cndb_nutval` VALUES (20109,328,0.3,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20109,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20109,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20109,601,84,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20109,605,0.061,'100g',6,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20109,606,1.18,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20110,203,4.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20110,204,2.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20110,205,25.16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20110,207,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20110,208,138,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20110,255,67.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20110,269,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20110,291,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20110,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20110,303,1.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20110,306,38,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20110,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20110,320,6,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (20110,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20110,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20110,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20110,601,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20110,605,0.029,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20110,606,0.419,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20111,203,14.61,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20111,204,4.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20111,205,70.32,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20111,207,1.79,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20111,208,382,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20111,255,8.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20111,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20111,291,6.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20111,301,56,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20111,303,4.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20111,306,355,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20111,307,72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20111,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20111,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20111,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20111,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20111,601,95,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20111,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20111,606,1.047,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20112,203,5.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20112,204,1.57,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20112,205,24.25,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20112,207,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20112,208,132,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20112,255,68.52,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20112,269,0.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20112,291,2.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20112,301,19,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20112,303,1.09,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20112,306,37,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20112,307,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20112,320,10,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (20112,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20112,401,0,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20112,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20112,601,33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20112,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20112,606,0.361,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20113,203,10.88,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20113,204,21.24,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20113,205,63.64,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20113,207,2.66,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20113,208,471,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20113,255,1.58,'100g',3,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20113,269,0,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20113,291,6.7,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20113,301,0,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20113,303,6.43,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20113,306,103,'100g',3,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20113,307,866,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20113,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (20113,328,0,'100g',3,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20113,401,0,'100g',6,1,'1994-01-31','2012-09-01');
INSERT INTO `cndb_nutval` VALUES (20113,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20113,601,0,'100g',6,1,'1994-01-31','2012-09-01');
INSERT INTO `cndb_nutval` VALUES (20113,605,0,'100g',6,1,'2006-02-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20113,606,6.738,'100g',6,1,'1994-01-31','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (20114,203,14.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20114,204,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20114,205,74.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20114,207,3.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20114,208,336,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20114,255,6.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20114,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20114,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20114,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20114,303,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20114,306,252,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20114,307,792,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20114,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20114,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20114,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20114,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20114,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20114,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20114,606,0.136,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20115,203,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20115,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20115,205,21.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20115,207,0.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20115,208,99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20115,255,73.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20115,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20115,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20115,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20115,303,0.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20115,306,35,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20115,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20115,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20115,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20115,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20115,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20115,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20115,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20115,606,0.019,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20116,203,11.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20116,204,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20116,205,74.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20116,207,4.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20116,208,356,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20116,255,9.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20116,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20116,291,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20116,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20116,303,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20116,306,164,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20116,307,1840,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20116,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20116,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20116,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20116,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20116,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20116,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20116,606,0.115,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20117,203,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20117,204,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20117,205,27.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20117,207,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20117,208,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20117,255,67.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20117,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20117,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20117,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20117,303,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20117,306,29,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20117,307,161,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20117,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20117,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20117,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20117,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20117,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20117,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20117,606,0.025,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20118,203,10.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20118,204,31.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20118,205,51.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20118,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20118,208,521,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20118,255,4.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20118,269,0.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20118,291,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20118,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20118,303,1.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20118,306,89,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20118,307,378,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20118,320,0,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (20118,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20118,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20118,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20118,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20118,605,0.136,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20118,606,4.931,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20120,203,13.04,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20120,204,1.51,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20120,205,74.67,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20120,207,0.88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20120,208,371,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20120,255,9.9,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20120,269,2.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20120,291,3.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20120,301,21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20120,303,3.3,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20120,306,223,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20120,307,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20120,320,0,'100g',2,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (20120,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20120,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20120,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20120,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20120,605,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20120,606,0.277,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20121,203,5.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20121,204,0.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20121,205,30.86,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20121,207,0.27,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20121,208,158,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20121,255,62.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20121,269,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20121,291,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20121,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20121,303,1.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20121,306,44,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20121,307,1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20121,320,0,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (20121,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20121,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20121,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20121,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20121,605,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20121,606,0.176,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20124,203,13.87,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20124,204,2.93,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20124,205,73.37,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20124,207,1.62,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20124,208,352,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20124,255,8.21,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20124,269,2.74,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20124,291,9.2,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20124,301,29,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20124,303,3.62,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20124,306,434,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20124,307,6,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20124,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20124,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20124,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20124,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20124,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20124,605,0.002,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20124,606,0.428,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20125,203,5.99,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20125,204,1.71,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20125,205,30.07,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20125,207,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20125,208,149,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20125,255,61.8,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20125,269,0.75,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20125,291,3.9,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20125,301,13,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20125,303,1.72,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20125,306,96,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20125,307,4,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20125,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (20125,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20125,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20125,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20125,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20125,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (20125,606,0.243,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20126,203,13.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20126,204,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20126,205,74.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20126,207,1.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20126,208,372,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20126,255,8.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20126,269,2.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20126,291,10.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20126,301,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20126,303,2.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20126,306,376,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20126,307,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20126,320,23,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (20126,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20126,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20126,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20126,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20126,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20126,606,0.226,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20127,203,4.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20127,204,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20127,205,26.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20127,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20127,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20127,255,68.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20127,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20127,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20127,301,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20127,303,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20127,306,58,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20127,307,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20127,320,8,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20127,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20127,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20127,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20127,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20127,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20127,606,0.091,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20129,203,11.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20129,204,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20129,205,72.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20129,207,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20129,208,361,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20129,255,13.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20129,269,0.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20129,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20129,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20129,303,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20129,306,100,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20129,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20129,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (20129,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20129,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20129,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20129,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20129,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20129,606,0.244,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20130,203,10.5,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20130,204,1.6,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20130,205,74.52,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20130,207,1.28,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20130,208,345,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20130,255,12.11,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20130,269,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20130,291,10.1,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20130,301,32,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20130,303,2.68,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20130,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20130,307,4,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20130,320,0,'100g',1,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (20130,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20130,401,0,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20130,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20130,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20130,605,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20130,606,0.335,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20131,203,10.28,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20131,204,1.84,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20131,205,78.3,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20131,207,1.37,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20131,208,361,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20131,255,8.21,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20131,269,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20131,291,7.1,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20131,301,37,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20131,303,4.71,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20131,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20131,307,11,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20131,320,1,'100g',1,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (20131,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20131,401,0.6,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20131,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20131,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20131,605,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20131,606,0.386,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20132,203,14.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20132,204,9.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20132,205,65.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20132,207,1.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20132,208,404,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20132,255,8.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20132,269,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20132,291,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20132,301,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20132,303,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20132,306,371,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20132,307,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20132,320,0,'100g',1,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (20132,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20132,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20132,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20132,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20132,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20132,606,1.607,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20133,203,5.95,'100g',3,1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (20133,204,0.56,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20133,205,80.18,'100g',3,1,'1997-08-29','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20133,207,0.85,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20133,208,364,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20133,255,11.91,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20133,269,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20133,291,1.6,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20133,301,18,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20133,303,0.7,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20133,306,30,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20133,307,182,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20133,320,0,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (20133,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20133,401,0,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20133,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20133,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20133,605,NULL,'100g',NULL,1,'1997-08-29','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20133,606,0.153,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20134,203,1.79,'100g',3,1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (20134,204,0.2,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20134,205,24.01,'100g',3,1,'1997-08-29','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20134,207,0.18,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20134,208,108,'100g',3,1,'1997-08-29','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20134,255,73.82,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20134,269,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20134,291,1,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20134,301,4,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20134,303,0.14,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20134,306,4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20134,307,19,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20134,320,0,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (20134,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20134,401,0,'100g',1,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20134,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20134,601,0,'100g',4,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20134,605,NULL,'100g',NULL,1,'1997-08-29','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (20134,606,0.023,'100g',3,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20135,203,13.51,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20135,204,2.68,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20135,205,73.1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20135,207,1.87,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20135,208,362,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20135,255,8.85,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20135,269,2.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20135,291,10.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20135,301,27,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20135,303,3.33,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20135,306,366,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20135,307,11,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20135,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20135,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20135,401,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (20135,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20135,601,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (20135,605,0.002,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20135,606,0.351,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20136,203,5.82,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20136,204,1.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20136,205,31.51,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20136,207,0.45,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20136,208,159,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20136,255,60.72,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20136,269,0.85,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20136,291,4.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20136,301,12,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20136,303,1.65,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20136,306,77,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20136,307,6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20136,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20136,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20136,401,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (20136,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20136,601,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (20136,605,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20136,606,0.239,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20137,203,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20137,204,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20137,205,21.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20137,207,0.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20137,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20137,255,71.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20137,269,0.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20137,291,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20137,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20137,303,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20137,306,172,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20137,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20137,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (20137,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20137,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20137,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20137,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20137,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20137,606,0.231,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20140,203,14.57,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (20140,204,2.43,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (20140,205,70.19,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (20140,207,1.78,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (20140,208,338,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (20140,255,11.02,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (20140,269,6.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20140,291,10.7,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (20140,301,27,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (20140,303,4.44,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (20140,306,388,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20140,307,8,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (20140,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (20140,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20140,401,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (20140,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20140,601,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (20140,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (20140,606,0.406,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (20142,203,13.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20142,204,2.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20142,205,73.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20142,207,2.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20142,208,367,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20142,255,8.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20142,269,1.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20142,291,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20142,301,180,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20142,303,7.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20142,306,427,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20142,307,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20142,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (20142,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20142,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20142,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20142,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20142,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20142,606,0.449,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20310,203,4.54,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20310,204,2.07,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20310,205,25.16,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20310,207,0.5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20310,208,138,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20310,255,67.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20310,269,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20310,291,1.2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20310,301,12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20310,303,1.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20310,306,38,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20310,307,165,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20310,320,6,'100g',2,1,'2024-12-12','2004-01-11');
INSERT INTO `cndb_nutval` VALUES (20310,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20310,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20310,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20310,601,29,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20310,605,0.029,'100g',3,1,'2006-01-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20310,606,0.419,'100g',3,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20314,203,9.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20314,204,4.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20314,205,74.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20314,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20314,208,365,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20314,255,10.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20314,269,NULL,'100g',NULL,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20314,291,NULL,'100g',NULL,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20314,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20314,303,2.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20314,306,287,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20314,307,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20314,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20314,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20314,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20314,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20314,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20314,605,NULL,'100g',NULL,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20314,606,0.667,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20316,203,6.93,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20316,204,3.86,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20316,205,76.85,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20316,207,1.45,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20316,208,361,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20316,255,10.91,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20316,269,0.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20316,291,7.3,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20316,301,7,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20316,303,2.38,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20316,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20316,307,5,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20316,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (20316,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20316,401,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20316,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20316,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20316,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20316,606,0.543,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20317,203,8.46,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20317,204,3.69,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20317,205,76.59,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20317,207,1.48,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20317,208,363,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20317,255,9.79,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20317,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20317,291,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20317,301,138,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20317,303,8.5,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20317,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20317,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20317,320,11,'100g',2,1,'2024-12-12','2009-01-12');
INSERT INTO `cndb_nutval` VALUES (20317,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20317,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20317,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20317,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20317,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20317,606,0.532,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20320,203,8.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20320,204,3.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20320,205,76.89,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20320,207,1.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20320,208,362,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20320,255,10.26,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20320,269,0.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20320,291,7.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20320,301,6,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20320,303,3.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20320,306,287,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20320,307,35,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20320,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (20320,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20320,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20320,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20320,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20320,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20320,606,0.505,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20321,203,5.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20321,204,0.93,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20321,205,30.59,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20321,207,0.55,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20321,208,157,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20321,255,62.13,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20321,269,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20321,291,1.8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20321,301,7,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20321,303,1.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20321,306,44,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20321,307,131,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20321,320,0,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (20321,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20321,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20321,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20321,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20321,605,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20321,606,0.176,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20322,203,7.11,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20322,204,1.75,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20322,205,79.45,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20322,207,0.51,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20322,208,370,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20322,255,11.18,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20322,269,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20322,291,3.9,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20322,301,3,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20322,303,4.36,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20322,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20322,307,7,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20322,320,0,'100g',1,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (20322,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20322,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20322,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20322,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20322,605,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20322,606,0.22,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (20323,203,8.28,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20323,204,3.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20323,205,70.28,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20323,207,5.45,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20323,208,334,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20323,255,12.59,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20323,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20323,291,6.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20323,301,361,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20323,303,5.76,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20323,306,255,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20323,307,1247,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20323,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (20323,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20323,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20323,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20323,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20323,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20323,606,0.478,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20324,203,8.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20324,204,2.85,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20324,205,73.43,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20324,207,4.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20324,208,348,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20324,255,10.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20324,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20324,291,6.3,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20324,301,299,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20324,303,4.95,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20324,306,207,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20324,307,1319,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20324,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (20324,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20324,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20324,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20324,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20324,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20324,606,0.4,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20325,203,8.41,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20325,204,1.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20325,205,74.79,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20325,207,4.91,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20325,208,355,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20325,255,10.17,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20325,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20325,291,7.1,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20325,301,350,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20325,303,4.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20325,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20325,307,1348,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20325,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (20325,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20325,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20325,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20325,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20325,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20325,606,0.234,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20330,203,1.48,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20330,204,0.88,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20330,205,14.26,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20330,207,0.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20330,208,72,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20330,255,82.53,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20330,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20330,291,2.5,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20330,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20330,303,0.62,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20330,306,9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20330,307,345,'100g',3,1,'1994-01-31','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (20330,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20330,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20330,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20330,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20330,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20330,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20330,606,0.123,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20345,203,2.69,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20345,204,0.28,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20345,205,28.17,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20345,207,0.41,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20345,208,130,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20345,255,68.44,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20345,269,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20345,291,0.4,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20345,301,10,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20345,303,1.2,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20345,306,35,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20345,307,382,'100g',1,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20345,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (20345,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20345,401,0,'100g',3,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20345,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20345,601,0,'100g',4,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20345,605,NULL,'100g',NULL,1,'1994-01-31','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (20345,606,0.077,'100g',1,1,'1994-01-31','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20381,203,10.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20381,204,0.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20381,205,76.31,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20381,207,0.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20381,208,364,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20381,255,11.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20381,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20381,291,2.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20381,301,252,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20381,303,4.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20381,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20381,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20381,320,0,'100g',1,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (20381,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20381,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20381,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20381,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20381,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20381,606,0.155,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20409,203,14.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20409,204,4.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20409,205,71.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20409,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20409,208,384,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20409,255,9.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20409,269,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20409,291,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20409,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20409,303,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20409,306,244,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20409,307,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20409,320,17,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (20409,328,0.3,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20409,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20409,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20409,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20409,605,0.061,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20409,606,1.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20410,203,4.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20410,204,2.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20410,205,25.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20410,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20410,208,138,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20410,255,67.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20410,269,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20410,291,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20410,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20410,303,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20410,306,38,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20410,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20410,320,6,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (20410,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20410,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20410,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20410,601,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20410,605,0.029,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20410,606,0.419,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20420,203,13.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20420,204,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20420,205,74.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20420,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20420,208,371,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20420,255,9.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20420,269,2.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20420,291,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20420,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20420,303,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20420,306,223,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20420,307,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20420,320,0,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (20420,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20420,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20420,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20420,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20420,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20420,606,0.277,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20421,203,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20421,204,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20421,205,30.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20421,207,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20421,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20421,255,62.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20421,269,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20421,291,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20421,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20421,303,0.5,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20421,306,44,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20421,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20421,320,0,'100g',2,1,'2024-12-12','2015-01-09');
INSERT INTO `cndb_nutval` VALUES (20421,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20421,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20421,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20421,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20421,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20421,606,0.176,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20422,203,7.11,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20422,204,1.75,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20422,205,79.45,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20422,207,0.51,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20422,208,370,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20422,255,11.18,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20422,269,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20422,291,3.9,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20422,301,3,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20422,303,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20422,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20422,307,7,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20422,320,11,'100g',1,1,'2024-12-12','2006-01-06');
INSERT INTO `cndb_nutval` VALUES (20422,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20422,401,0,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20422,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20422,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20422,605,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20422,606,0.22,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (20444,203,7.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20444,204,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20444,205,79.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20444,207,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20444,208,365,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20444,255,11.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20444,269,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20444,291,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20444,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20444,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20444,306,115,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20444,307,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20444,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (20444,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20444,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20444,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20444,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20444,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20444,606,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20445,203,2.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20445,204,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20445,205,28.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20445,207,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20445,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20445,255,68.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20445,269,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20445,291,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20445,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20445,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20445,306,35,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20445,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20445,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (20445,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20445,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20445,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20445,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20445,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20445,606,0.077,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20446,203,7.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20446,204,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20446,205,80.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20446,207,0.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20446,208,374,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20446,255,9.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20446,269,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20446,291,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20446,301,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20446,303,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20446,306,174,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20446,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20446,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20446,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20446,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20446,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20446,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20446,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20446,606,0.294,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20447,203,2.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20447,204,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20447,205,26.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20447,207,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20447,208,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20447,255,70.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20447,269,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20447,291,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20447,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20447,303,0.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20447,306,56,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20447,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20447,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20447,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20447,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20447,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20447,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20447,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20447,606,0.074,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20450,203,6.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20450,204,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20450,205,79.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20450,207,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20450,208,360,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20450,255,12.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20450,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20450,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20450,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20450,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20450,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20450,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20450,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20450,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20450,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20450,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20450,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20450,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20450,606,0.158,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20451,203,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20451,204,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20451,205,28.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20451,207,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20451,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20451,255,68.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20451,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20451,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20451,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20451,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20451,306,29,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20451,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20451,320,0,'100g',1,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20451,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20451,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20451,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20451,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20451,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20451,606,0.057,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20452,203,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20452,204,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20452,205,79.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20452,207,0.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20452,208,358,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20452,255,13.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20452,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20452,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20452,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20452,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20452,306,76,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20452,307,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20452,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20452,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20452,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20452,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20452,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20452,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20452,606,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20453,203,2.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20453,204,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20453,205,28.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20453,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20453,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20453,255,68.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20453,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20453,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20453,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20453,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20453,306,26,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20453,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20453,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20453,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20453,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20453,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20453,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20453,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20453,606,0.051,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20466,203,12.68,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20466,204,1.05,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20466,205,72.83,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20466,207,0.77,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20466,208,360,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20466,255,12.67,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20466,269,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20466,291,3.9,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20466,301,17,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20466,303,1.23,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20466,306,186,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20466,307,1,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20466,320,0,'100g',3,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20466,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20466,401,0,'100g',3,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20466,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20466,601,0,'100g',4,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20466,605,NULL,'100g',NULL,1,'1996-09-30','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20466,606,0.15,'100g',1,1,'1996-09-30','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20481,203,10.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20481,204,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20481,205,76.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20481,207,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20481,208,364,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20481,255,11.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20481,269,0.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20481,291,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20481,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20481,303,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20481,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20481,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20481,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (20481,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20481,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20481,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20481,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20481,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20481,606,0.155,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20510,203,4.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20510,204,2.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20510,205,25.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20510,207,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20510,208,138,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20510,255,67.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20510,269,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20510,291,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20510,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20510,303,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20510,306,38,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20510,307,165,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20510,320,6,'100g',2,1,'2024-12-12','2004-01-11');
INSERT INTO `cndb_nutval` VALUES (20510,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20510,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20510,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20510,601,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20510,605,0.029,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20510,606,0.419,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20521,203,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20521,204,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20521,205,30.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20521,207,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20521,208,157,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20521,255,62.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20521,269,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20521,291,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20521,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20521,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20521,306,44,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20521,307,131,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20521,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20521,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20521,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20521,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20521,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20521,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20521,606,0.176,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20522,203,7.11,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20522,204,1.75,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20522,205,79.45,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20522,207,0.51,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20522,208,370,'100g',3,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20522,255,11.18,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20522,269,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20522,291,3.9,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20522,301,3,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20522,303,1.1,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20522,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20522,307,7,'100g',1,1,'1994-01-31','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (20522,320,0,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (20522,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20522,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20522,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20522,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20522,605,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20522,606,0.22,'100g',3,1,'1994-01-31','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (20523,203,8.86,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20523,204,0.21,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20523,205,30.88,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20523,207,0.31,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20523,208,164,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20523,255,59.73,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20523,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20523,291,2,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20523,301,10,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20523,303,0.72,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20523,306,42,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20523,307,5,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20523,320,0,'100g',2,1,'2024-12-12','2002-01-06');
INSERT INTO `cndb_nutval` VALUES (20523,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20523,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20523,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20523,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20523,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20523,606,0.032,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20545,203,2.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20545,204,0.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20545,205,28.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20545,207,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20545,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20545,255,68.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20545,269,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20545,291,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20545,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20545,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20545,306,35,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20545,307,382,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20545,320,0,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (20545,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20545,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20545,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20545,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20545,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20545,606,0.077,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20581,203,10.33,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20581,204,0.98,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20581,205,76.31,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20581,207,0.47,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20581,208,364,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20581,255,11.92,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20581,269,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20581,291,2.7,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20581,301,15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20581,303,4.64,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20581,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20581,307,2,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20581,320,0,'100g',1,1,'2024-12-12','2002-01-10');
INSERT INTO `cndb_nutval` VALUES (20581,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20581,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20581,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20581,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20581,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20581,606,0.155,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20622,203,21.78,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20622,204,2.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20622,205,65.65,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20622,207,1.12,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20622,208,374,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20622,255,9.23,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20622,269,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20622,291,2.4,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20622,301,39,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20622,303,4.15,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20622,306,201,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20622,307,8,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20622,320,0,'100g',2,1,'2024-12-12','2003-01-05');
INSERT INTO `cndb_nutval` VALUES (20622,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20622,401,0,'100g',3,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20622,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20622,601,0,'100g',4,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20622,605,NULL,'100g',NULL,1,'1994-01-31','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (20622,606,0.328,'100g',1,1,'1994-01-31','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (20623,203,8.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20623,204,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20623,205,77.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20623,207,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20623,208,367,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20623,255,11.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20623,269,0.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20623,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20623,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20623,303,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20623,306,131,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20623,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20623,320,0,'100g',2,1,'2024-12-12','2004-01-09');
INSERT INTO `cndb_nutval` VALUES (20623,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20623,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20623,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20623,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20623,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20623,606,0.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20624,203,8.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20624,204,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20624,205,77.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20624,207,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20624,208,367,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20624,255,11.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20624,269,0.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20624,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20624,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20624,303,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20624,306,131,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20624,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20624,320,0,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (20624,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20624,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20624,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20624,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20624,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20624,606,0.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20628,203,9.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20628,204,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20628,205,76.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20628,207,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20628,208,366,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20628,255,12.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20628,269,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20628,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20628,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20628,303,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20628,306,149,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20628,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20628,320,0,'100g',2,1,'2024-12-12','2004-01-09');
INSERT INTO `cndb_nutval` VALUES (20628,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20628,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20628,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20628,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20628,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20628,606,0.302,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20629,203,9.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20629,204,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20629,205,76.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20629,207,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20629,208,366,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20629,255,12.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20629,269,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20629,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20629,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20629,303,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20629,306,149,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20629,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20629,320,0,'100g',2,1,'2024-12-12','2004-01-09');
INSERT INTO `cndb_nutval` VALUES (20629,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20629,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20629,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20629,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20629,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20629,606,0.302,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20630,203,9.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20630,204,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20630,205,76.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20630,207,0.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20630,208,366,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20630,255,12.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20630,269,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20630,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20630,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20630,303,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20630,306,149,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20630,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20630,320,0,'100g',2,1,'2024-12-12','2004-01-10');
INSERT INTO `cndb_nutval` VALUES (20630,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20630,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20630,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20630,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20630,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20630,606,0.302,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20634,203,11.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20634,204,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20634,205,73.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20634,207,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20634,208,363,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20634,255,12.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20634,269,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20634,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20634,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20634,303,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20634,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20634,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20634,320,0,'100g',2,1,'2024-12-12','2004-01-09');
INSERT INTO `cndb_nutval` VALUES (20634,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20634,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20634,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20634,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20634,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20634,606,0.268,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20635,203,11.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20635,204,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20635,205,73.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20635,207,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20635,208,363,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20635,255,12.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20635,269,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20635,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20635,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20635,303,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20635,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20635,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20635,320,0,'100g',2,1,'2024-12-12','2004-01-09');
INSERT INTO `cndb_nutval` VALUES (20635,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20635,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20635,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20635,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20635,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20635,606,0.268,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20636,203,11.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20636,204,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20636,205,73.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20636,207,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20636,208,363,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20636,255,12.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20636,269,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20636,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20636,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20636,303,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20636,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20636,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20636,320,0,'100g',2,1,'2024-12-12','2004-01-10');
INSERT INTO `cndb_nutval` VALUES (20636,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20636,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20636,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20636,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20636,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20636,606,0.268,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20640,203,13.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20640,204,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20640,205,72.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20640,207,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20640,208,362,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20640,255,12.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20640,269,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20640,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20640,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20640,303,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20640,306,128,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20640,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20640,320,0,'100g',2,1,'2024-12-12','2004-01-09');
INSERT INTO `cndb_nutval` VALUES (20640,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20640,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20640,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20640,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20640,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20640,606,0.189,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20641,203,13.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20641,204,1.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20641,205,72.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20641,207,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20641,208,362,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20641,255,12.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20641,269,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20641,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20641,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20641,303,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20641,306,128,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20641,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20641,320,0,'100g',2,1,'2024-12-12','2004-01-09');
INSERT INTO `cndb_nutval` VALUES (20641,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20641,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20641,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20641,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20641,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20641,606,0.189,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20645,203,15.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20645,204,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20645,205,69.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20645,207,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20645,208,362,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20645,255,12.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20645,269,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20645,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20645,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20645,303,5.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20645,306,120,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20645,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20645,320,0,'100g',2,1,'2024-12-12','2004-01-09');
INSERT INTO `cndb_nutval` VALUES (20645,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20645,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20645,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20645,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20645,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20645,606,0.272,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20646,203,15.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20646,204,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20646,205,69.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20646,207,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20646,208,362,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20646,255,12.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20646,269,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20646,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20646,301,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20646,303,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20646,306,120,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20646,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20646,320,0,'100g',2,1,'2024-12-12','2004-01-09');
INSERT INTO `cndb_nutval` VALUES (20646,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20646,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20646,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20646,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20646,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20646,606,0.272,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20647,203,10.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20647,204,4.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20647,205,75.12,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20647,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20647,208,382,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20647,255,8.67,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20647,269,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20647,291,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20647,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20647,303,3.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20647,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20647,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20647,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20647,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20647,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20647,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20647,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20647,605,0.002,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20647,606,0.536,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20648,203,8.43,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20648,204,3.34,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20648,205,76.64,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20648,207,1.32,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20648,208,359,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20648,255,10.26,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20648,269,1.94,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20648,291,6.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20648,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20648,303,3.14,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (20648,306,324,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20648,307,3,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20648,320,0,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (20648,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20648,401,0.8,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20648,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20648,601,NULL,'100g',NULL,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20648,605,0.004,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20648,606,0.528,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (20649,203,9.61,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (20649,204,1.95,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (20649,205,74.48,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (20649,207,1.53,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (20649,208,332,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (20649,255,12.42,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (20649,269,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (20649,291,13.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (20649,301,33,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (20649,303,3.71,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (20649,306,394,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20649,307,3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (20649,320,0,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (20649,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20649,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (20649,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20649,601,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (20649,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (20649,606,0.43,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (20650,203,9.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (20650,204,1.24,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (20650,205,76.85,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (20650,207,0.47,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (20650,208,357,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (20650,255,11.92,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (20650,269,NULL,'100g',NULL,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (20650,291,1.9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (20650,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (20650,303,0.97,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (20650,306,145,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20650,307,1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (20650,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20650,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20650,401,0.6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (20650,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (20650,601,NULL,'100g',NULL,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (20650,605,0.001,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (20650,606,0.303,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (20653,203,13.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20653,204,2.55,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20653,205,73.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20653,207,1.73,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20653,208,361,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20653,255,9.23,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20653,269,2.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20653,291,11.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20653,301,25,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20653,303,3.41,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20653,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20653,307,12,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20653,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (20653,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (20653,401,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (20653,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (20653,601,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (20653,605,0.002,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (20653,606,0.324,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (21224,203,10.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21224,204,12.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21224,205,29.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21224,207,2.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21224,208,268,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21224,255,46.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21224,269,3.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21224,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21224,301,179,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21224,303,2.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21224,306,152,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21224,307,447,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21224,320,66,'100g',2,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (21224,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21224,401,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21224,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (21224,601,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21224,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21224,606,4.272,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (21225,203,12.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21225,204,8.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21225,205,32.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21225,207,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21225,208,260,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21225,255,43.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21225,269,5.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21225,291,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21225,301,177,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21225,303,1.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21225,306,175,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21225,307,556,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21225,320,69,'100g',2,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (21225,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21225,401,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21225,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (21225,601,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21225,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21225,606,3.825,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (21226,203,11.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21226,204,14.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21226,205,25.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21226,207,2.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21226,208,276,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21226,255,46.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21226,269,4.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21226,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21226,301,152,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21226,303,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21226,306,209,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21226,307,555,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21226,320,65,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (21226,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21226,401,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21226,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (21226,601,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21226,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21226,606,5.083,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (21227,203,12.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21227,204,11.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21227,205,28.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21227,207,2.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21227,208,271,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21227,255,44.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21227,269,7.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21227,291,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21227,301,155,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21227,303,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21227,306,189,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21227,307,640,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21227,320,68,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (21227,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21227,401,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21227,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (21227,601,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21227,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21227,606,4.586,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (21412,203,4.02,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21412,204,6.46,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21412,205,26.82,'100g',7,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21412,207,0.96,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21412,208,182,'100g',7,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21412,255,61.74,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21412,269,24.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21412,291,0.2,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21412,301,135,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21412,303,0.27,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21412,306,208,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21412,307,54,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21412,320,31,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (21412,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21412,401,0.9,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21412,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (21412,601,16,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21412,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21412,606,3.633,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21413,203,3.97,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21413,204,5.66,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21413,205,25.55,'100g',7,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21413,207,0.92,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21413,208,169,'100g',7,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21413,255,63.9,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21413,269,21.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21413,291,0.1,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21413,301,129,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21413,303,0.61,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21413,306,198,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21413,307,75,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21413,320,26,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (21413,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21413,401,0.8,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21413,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (21413,601,15,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21413,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21413,606,2.754,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (21463,203,3.36,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (21463,204,1.01,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (21463,205,15.86,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (21463,207,0.8,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (21463,208,84,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (21463,255,78.98,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (21463,269,11.68,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21463,291,1.1,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (21463,301,105,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (21463,303,0.49,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (21463,306,189,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21463,307,49,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (21463,320,30,'100g',4,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (21463,328,0.1,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21463,401,14.3,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (21463,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (21463,601,3,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (21463,605,0,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (21463,606,0.525,'100g',7,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (21505,203,11.91,'100g',1,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (21505,204,11.07,'100g',1,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (21505,205,28.8,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (21505,207,2.21,'100g',1,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (21505,208,263,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (21505,255,46.01,'100g',1,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (21505,269,3.71,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (21505,291,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21505,301,228,'100g',1,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (21505,303,2.14,'100g',1,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (21505,306,201,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21505,307,471,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (21505,320,72,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (21505,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (21505,401,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21505,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (21505,601,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (21505,605,0.277,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (21505,606,5.698,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22247,203,3.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22247,204,2.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22247,205,11.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22247,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22247,208,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22247,255,81.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22247,269,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22247,291,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22247,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22247,303,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22247,306,84,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22247,307,302,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22247,320,17,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (22247,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22247,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22247,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22247,601,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22247,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22247,606,0.881,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22401,203,5.05,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (22401,204,1.01,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (22401,205,15.24,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (22401,207,0.88,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (22401,208,90,'100g',6,1,'1997-08-29','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (22401,255,77.82,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (22401,269,2.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22401,291,1.8,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (22401,301,18,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (22401,303,1.25,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (22401,306,144,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22401,307,238,'100g',6,1,'1997-08-29','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (22401,320,9,'100g',2,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (22401,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22401,401,5.4,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (22401,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22401,601,6,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (22401,605,NULL,'100g',NULL,1,'1997-08-29','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22401,606,0.35,'100g',6,1,'1997-08-29','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (22402,203,5.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22402,204,1.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22402,205,17.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22402,207,1.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22402,208,113,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22402,255,73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22402,269,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22402,291,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22402,301,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22402,303,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22402,306,202,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22402,307,178,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22402,320,8,'100g',2,1,'2024-12-12','2013-01-07');
INSERT INTO `cndb_nutval` VALUES (22402,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22402,401,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22402,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22402,601,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22402,605,0.025,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22402,606,0.443,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22522,203,4.37,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22522,204,2.38,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22522,205,12.7,'100g',6,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (22522,207,2.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22522,208,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22522,255,78.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22522,269,3.17,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22522,291,1.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22522,301,60,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22522,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22522,306,191,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22522,307,287,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22522,320,13,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (22522,328,0.4,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22522,401,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22522,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22522,601,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22522,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22522,606,0.791,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22528,203,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22528,204,8.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22528,205,17.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22528,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22528,208,176,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22528,255,65.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22528,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22528,291,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22528,301,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22528,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22528,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22528,307,350,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22528,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (22528,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22528,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22528,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22528,601,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22528,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22528,606,2.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22529,203,7.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22529,204,11.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22529,205,22.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22529,207,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22529,208,220,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22529,255,58.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22529,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22529,291,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22529,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22529,303,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22529,306,115,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22529,307,365,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22529,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (22529,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22529,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22529,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22529,601,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22529,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22529,606,4.149,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22899,203,2.48,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22899,204,1.45,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22899,205,13.64,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22899,207,1.52,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22899,208,77,'100g',3,1,'2012-03-02','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (22899,255,80.91,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22899,269,3.72,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22899,291,1.3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22899,301,33,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22899,303,0.74,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22899,306,232,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22899,307,306,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22899,320,10,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (22899,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22899,401,0,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22899,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22899,601,3,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22899,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22899,606,0.723,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22900,203,3.24,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22900,204,3.41,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22900,205,13.26,'100g',3,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22900,207,0.97,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22900,208,97,'100g',3,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22900,255,79.12,'100g',1,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22900,269,1.97,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22900,291,1.5,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22900,301,12,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22900,303,1.09,'100g',1,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22900,306,178,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22900,307,283,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22900,320,14,'100g',2,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (22900,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22900,401,0,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22900,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22900,601,5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22900,605,0.192,'100g',3,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22900,606,1.46,'100g',3,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22901,203,13.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22901,204,7.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22901,205,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22901,207,1.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22901,208,307,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22901,255,30.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22901,269,0.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22901,291,1.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22901,301,152,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22901,303,1.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22901,306,89,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22901,307,406,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22901,320,38,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (22901,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22901,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22901,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22901,601,42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22901,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22901,606,3.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22902,203,11.76,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22902,204,11.52,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22902,205,30.76,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22902,207,2.69,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22902,208,274,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22902,255,43.27,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22902,269,3.88,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22902,291,2.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22902,301,150,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22902,303,1.7,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22902,306,201,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22902,307,690,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22902,320,49,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (22902,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22902,401,1.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22902,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22902,601,21,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22902,605,0.194,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22902,606,4.283,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22903,203,14.38,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22903,204,13.13,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22903,205,24.69,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22903,207,2.39,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22903,208,274,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22903,255,45.41,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22903,269,3.39,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (22903,291,2,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22903,301,168,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22903,303,2.43,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (22903,306,239,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22903,307,590,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (22903,320,69,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (22903,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22903,401,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22903,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22903,601,27,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22903,605,0.21,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (22903,606,4.827,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (22904,203,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22904,204,3.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22904,205,13.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22904,207,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22904,208,107,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22904,255,75.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22904,269,1.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22904,291,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22904,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22904,303,1.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22904,306,264,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22904,307,449,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22904,320,23,'100g',1,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (22904,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22904,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22904,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22904,601,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22904,605,0.166,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22904,606,1.253,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22905,203,4.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22905,204,5.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22905,205,7.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22905,207,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22905,208,99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22905,255,80.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22905,269,1.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22905,291,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22905,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22905,303,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22905,306,163,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22905,307,388,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22905,320,11,'100g',1,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (22905,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22905,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22905,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22905,601,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22905,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22905,606,2.185,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22906,203,5.11,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22906,204,11.85,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22906,205,19.21,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22906,207,1.25,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22906,208,204,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22906,255,62.58,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22906,269,2.26,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22906,291,1.1,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22906,301,20,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22906,303,0.76,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22906,306,110,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22906,307,393,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22906,320,34,'100g',1,1,'2024-12-12','2012-01-06');
INSERT INTO `cndb_nutval` VALUES (22906,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22906,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22906,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22906,601,15,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22906,605,0.085,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22906,606,4.365,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22910,203,6.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22910,204,5.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22910,205,13.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22910,207,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22910,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22910,255,72.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22910,269,4.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22910,291,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22910,301,111,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22910,303,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22910,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22910,307,284,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22910,320,46,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (22910,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22910,401,17.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22910,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22910,601,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22910,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22910,606,2.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22911,203,7.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22911,204,7.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22911,205,6.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22911,207,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22911,208,118,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22911,255,77.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22911,269,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22911,291,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22911,301,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22911,303,2.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22911,306,185,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22911,307,411,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22911,320,14,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (22911,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22911,401,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22911,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22911,601,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22911,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22911,606,2.255,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22912,203,4.37,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22912,204,4.11,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22912,205,11.45,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22912,207,1.26,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22912,208,100,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22912,255,78.8,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22912,269,2.91,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22912,291,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22912,301,29,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22912,303,1.03,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22912,306,217,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22912,307,280,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22912,320,17,'100g',1,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (22912,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22912,401,1.9,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22912,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22912,601,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22912,605,0.113,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22912,606,1.459,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22914,203,2.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22914,204,0.71,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22914,205,13.94,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22914,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22914,208,71,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22914,255,82.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22914,269,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22914,291,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22914,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22914,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22914,306,192,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22914,307,381,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22914,320,36,'100g',2,1,'2024-12-12','2017-01-07');
INSERT INTO `cndb_nutval` VALUES (22914,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22914,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22914,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22914,601,6,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22914,605,0.007,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22914,606,0.167,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22915,203,6.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22915,204,2.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22915,205,13.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22915,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22915,208,101,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22915,255,76.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22915,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22915,291,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22915,301,108,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22915,303,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22915,306,150,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22915,307,181,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22915,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (22915,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22915,401,17.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22915,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22915,601,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22915,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22915,606,0.967,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22916,203,6.63,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22916,204,4.42,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22916,205,14.39,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22916,207,1.46,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22916,208,124,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22916,255,73.1,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22916,269,2.96,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22916,291,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22916,301,73,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22916,303,0.65,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22916,306,184,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22916,307,347,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22916,320,37,'100g',1,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (22916,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22916,401,4.1,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22916,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22916,601,14,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22916,605,0.18,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22916,606,2.067,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22917,203,7.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22917,204,9.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22917,205,30.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22917,207,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22917,208,239,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22917,255,50.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22917,269,0.7,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22917,291,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22917,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22917,303,2.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22917,306,221,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22917,307,587,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22917,320,11,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (22917,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22917,401,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22917,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22917,601,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22917,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22917,606,2.949,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22918,203,7.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22918,204,6.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22918,205,34.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22918,207,1.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22918,208,221,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22918,255,50.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22918,269,3.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22918,291,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22918,301,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22918,303,2.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22918,306,210,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22918,307,351,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22918,320,8,'100g',1,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (22918,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22918,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22918,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22918,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22918,605,0.041,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22918,606,1.343,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22919,203,5.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22919,204,5.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22919,205,13.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22919,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22919,208,134,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22919,255,72.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22919,269,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22919,291,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22919,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22919,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22919,306,72,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22919,307,335,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22919,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (22919,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22919,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22919,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22919,601,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22919,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22919,606,3.665,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22928,203,8.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22928,204,11.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22928,205,38.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22928,207,2.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22928,208,298,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22928,255,38.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22928,269,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22928,291,6.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22928,301,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22928,303,3.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22928,306,271,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22928,307,659,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22928,320,13,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (22928,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22928,401,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22928,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22928,601,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22928,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22928,606,4.072,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22953,203,9.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22953,204,8.18,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22953,205,28.49,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22953,207,2.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22953,208,227,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22953,255,51.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22953,269,1.67,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22953,291,0,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22953,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22953,303,1.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22953,306,212,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22953,307,407,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22953,320,390,'100g',2,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (22953,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22953,401,29.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22953,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22953,601,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22953,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22953,606,1.65,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22954,203,10.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22954,204,4.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22954,205,28.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22954,207,2.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22954,208,197,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22954,255,54.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22954,269,5.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22954,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22954,301,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22954,303,1.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22954,306,281,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22954,307,478,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22954,320,55,'100g',2,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (22954,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22954,401,11.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22954,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22954,601,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22954,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22954,606,0.964,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22955,203,5.95,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22955,204,6.97,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22955,205,31.77,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22955,207,1.94,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22955,208,214,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22955,255,53.37,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22955,269,5.96,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22955,291,2.4,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22955,301,50,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22955,303,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22955,306,222,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22955,307,490,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22955,320,49,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (22955,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22955,401,6.7,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22955,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22955,601,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22955,605,0.05,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (22955,606,1.138,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22956,203,6.87,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (22956,204,6.04,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (22956,205,14.18,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (22956,207,1.66,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (22956,208,139,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (22956,255,71.24,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (22956,269,2.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22956,291,1.9,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (22956,301,150,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (22956,303,0.55,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (22956,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22956,307,445,'100g',6,1,'2007-12-03','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (22956,320,68,'100g',2,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (22956,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22956,401,1.1,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (22956,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22956,601,14,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (22956,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (22956,606,2.866,'100g',3,1,'2007-12-03','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (22957,203,6.97,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22957,204,3.89,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22957,205,16.32,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22957,207,1.66,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22957,208,128,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22957,255,71.16,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22957,269,4.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22957,291,1.3,'100g',7,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22957,301,27,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22957,303,0.79,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22957,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22957,307,326,'100g',3,1,'2009-01-25','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (22957,320,44,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (22957,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22957,401,0.8,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22957,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22957,601,14,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22957,605,NULL,'100g',NULL,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22957,606,0.877,'100g',3,1,'2009-01-25','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (22958,203,5.65,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22958,204,1.56,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22958,205,22.46,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22958,207,1.25,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22958,208,126,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22958,255,69.09,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22958,269,4.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22958,291,0.7,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22958,301,13,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22958,303,0.35,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22958,306,123,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22958,307,333,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22958,320,32,'100g',2,1,'2024-12-12','2007-01-12');
INSERT INTO `cndb_nutval` VALUES (22958,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22958,401,3,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22958,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22958,601,16,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22958,605,NULL,'100g',NULL,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22958,606,0.327,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (22959,203,13.86,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22959,204,4.82,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22959,205,70.12,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22959,207,3.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22959,208,379,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22959,255,8.05,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22959,269,9.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22959,291,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22959,301,146,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22959,303,2.75,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22959,306,347,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22959,307,680,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22959,320,18,'100g',2,1,'2024-12-12','2008-01-12');
INSERT INTO `cndb_nutval` VALUES (22959,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22959,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22959,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22959,601,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22959,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (22959,606,1.151,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22960,203,4.89,'100g',1,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (22960,204,8.28,'100g',1,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (22960,205,23.93,'100g',3,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (22960,207,1.3,'100g',1,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (22960,208,190,'100g',3,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (22960,255,61.6,'100g',1,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (22960,269,4.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22960,291,1.2,'100g',1,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (22960,301,63,'100g',1,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (22960,303,0.99,'100g',1,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (22960,306,129,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22960,307,338,'100g',1,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (22960,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (22960,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22960,401,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (22960,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22960,601,3,'100g',1,1,'2010-01-04','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (22960,605,1.244,'100g',3,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22960,606,1.816,'100g',3,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22969,203,5.85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22969,204,3.68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22969,205,10.88,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22969,207,1.7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22969,208,100,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22969,255,77.89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22969,269,1.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22969,291,2.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22969,301,34,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22969,303,1.13,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22969,306,245,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22969,307,385,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22969,320,23,'100g',1,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (22969,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22969,401,0.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22969,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22969,601,10,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22969,605,0.195,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22969,606,1.372,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22970,203,5.6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22970,204,6.41,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22970,205,17.28,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22970,207,1.31,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22970,208,149,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22970,255,69.39,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22970,269,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22970,291,1.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22970,301,114,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22970,303,0.57,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22970,306,95,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22970,307,290,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22970,320,47,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (22970,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22970,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22970,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22970,601,10,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22970,605,0.153,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22970,606,2.608,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22971,203,1.96,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22971,204,9.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22971,205,16.18,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22971,207,1.47,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22971,208,157,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22971,255,70.99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22971,269,4.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22971,291,1.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22971,301,15,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22971,303,0.5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22971,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22971,307,329,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22971,320,19,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (22971,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22971,401,0.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22971,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22971,601,17,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22971,605,0.025,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22971,606,1.437,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22972,203,13.19,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22972,204,4.42,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22972,205,18.74,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22972,207,2.65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22972,208,168,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22972,255,60.99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22972,269,15.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22972,291,1.2,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22972,301,44,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22972,303,1.24,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22972,306,305,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22972,307,666,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22972,320,13,'100g',1,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (22972,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22972,401,0.2,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22972,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22972,601,35,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22972,605,0.019,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22972,606,1.416,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22973,203,8.57,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22973,204,12.02,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22973,205,26.96,'100g',3,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22973,207,2.13,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22973,208,250,'100g',3,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22973,255,50.32,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22973,269,7.54,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22973,291,1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22973,301,72,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22973,303,1.9,'100g',1,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22973,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22973,307,668,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22973,320,48,'100g',2,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (22973,328,0.4,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22973,401,0.5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22973,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22973,601,44,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22973,605,0.17,'100g',3,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22973,606,3.466,'100g',3,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22974,203,12.02,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22974,204,17.31,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22974,205,16.09,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22974,207,2.23,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22974,208,268,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22974,255,52.36,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22974,269,0.72,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22974,291,1.6,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22974,301,47,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22974,303,0.95,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22974,306,206,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22974,307,540,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22974,320,16,'100g',1,1,'2024-12-12','2016-01-04');
INSERT INTO `cndb_nutval` VALUES (22974,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22974,401,0.4,'100g',1,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22974,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22974,601,32,'100g',1,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22974,605,0.069,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22974,606,3.598,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (22975,203,14.36,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22975,204,15.42,'100g',1,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22975,205,16.24,'100g',3,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22975,207,2.09,'100g',1,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22975,208,261,'100g',3,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22975,255,51.9,'100g',1,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22975,269,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22975,291,0.7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22975,301,38,'100g',1,1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (22975,303,1.43,'100g',1,1,'2012-03-02','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (22975,306,281,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22975,307,538,'100g',1,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22975,320,16,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (22975,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22975,401,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22975,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22975,601,34,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22975,605,0.082,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22975,606,3.366,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22976,203,4.52,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22976,204,2.61,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22976,205,17.31,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22976,207,1.23,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22976,208,111,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22976,255,74.33,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22976,269,4.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22976,291,1.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22976,301,79,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22976,303,0.93,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22976,306,233,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22976,307,280,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22976,320,35,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (22976,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22976,401,2.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22976,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22976,601,11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22976,605,0.074,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22976,606,1.191,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (22977,203,7.28,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22977,204,4.92,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22977,205,15.36,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22977,207,1.57,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22977,208,135,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22977,255,70.87,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22977,269,3.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22977,291,1.7,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22977,301,88,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22977,303,0.71,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22977,306,196,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22977,307,373,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22977,320,41,'100g',1,1,'2024-12-12','2012-01-06');
INSERT INTO `cndb_nutval` VALUES (22977,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22977,401,2.5,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22977,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22977,601,17,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22977,605,0.196,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22977,606,2.348,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22978,203,14.62,'100g',1,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22978,204,13.58,'100g',1,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22978,205,14.86,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22978,207,2.11,'100g',1,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22978,208,240,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22978,255,54.83,'100g',1,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22978,269,0.57,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22978,291,1.7,'100g',1,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22978,301,39,'100g',1,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22978,303,0.84,'100g',1,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22978,306,281,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22978,307,527,'100g',1,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22978,320,7,'100g',1,1,'2024-12-12','2014-01-07');
INSERT INTO `cndb_nutval` VALUES (22978,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22978,401,0.5,'100g',1,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22978,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22978,601,36,'100g',1,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22978,605,0.055,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (22978,606,2.437,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22999,203,2.65,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22999,204,3.45,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22999,205,23.54,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22999,207,1.03,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22999,208,136,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22999,255,69.33,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22999,269,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (22999,291,0.7,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22999,301,7,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22999,303,0.95,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22999,306,58,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22999,307,377,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (22999,320,42,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (22999,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (22999,401,NULL,'100g',NULL,1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (22999,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (22999,601,NULL,'100g',NULL,1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (22999,605,0.485,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (22999,606,0.746,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23000,203,21.39,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23000,204,4.97,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23000,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23000,207,1.13,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23000,208,130,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23000,255,72.58,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23000,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23000,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23000,301,12,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23000,303,2.62,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23000,306,395,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23000,307,72,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23000,320,3,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23000,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23000,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23000,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23000,601,66,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23000,605,0.256,'100g',3,1,'2011-01-18','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23000,606,2.033,'100g',3,1,'2011-01-18','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23001,203,20.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23001,204,14.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23001,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23001,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23001,208,214,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23001,255,64.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23001,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23001,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23001,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23001,303,1.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23001,306,243,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23001,307,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23001,320,4,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23001,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23001,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23001,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23001,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23001,605,0.849,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23001,606,5.981,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23002,203,25.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23002,204,18.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23002,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23002,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23002,208,276,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23002,255,55.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23002,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23002,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23002,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23002,303,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23002,306,257,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23002,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23002,320,7,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23002,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23002,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23002,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23002,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23002,605,1.117,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23002,606,7.481,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23003,203,20.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23003,204,13.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23003,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23003,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23003,208,208,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23003,255,65.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23003,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23003,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23003,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23003,303,2.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23003,306,235,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23003,307,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23003,320,4,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23003,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23003,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23003,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23003,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23003,605,0.829,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23003,606,5.696,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23004,203,26.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23004,204,16.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23004,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23004,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23004,208,263,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23004,255,56.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23004,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23004,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23004,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23004,303,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23004,306,259,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23004,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23004,320,8,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23004,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23004,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23004,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23004,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23004,605,1.049,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23004,606,6.843,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23005,203,20.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23005,204,15.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23005,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23005,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23005,208,223,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23005,255,64.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23005,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23005,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23005,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23005,303,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23005,306,232,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23005,307,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23005,320,4,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23005,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23005,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23005,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23005,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23005,605,0.903,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23005,606,6.495,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23006,203,24.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23006,204,20.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23006,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23006,207,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23006,208,289,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23006,255,54.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23006,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23006,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23006,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23006,303,3.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23006,306,248,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23006,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23006,320,8,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23006,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23006,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23006,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23006,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23006,605,1.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23006,606,8.356,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23007,203,20.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23007,204,14.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23007,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23007,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23007,208,215,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23007,255,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23007,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23007,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23007,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23007,303,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23007,306,246,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23007,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23007,320,4,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23007,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23007,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23007,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23007,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23007,605,0.892,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23007,606,6.211,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23008,203,25.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23008,204,19.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23008,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23008,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23008,208,281,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23008,255,55.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23008,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23008,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23008,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23008,303,3.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23008,306,261,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23008,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23008,320,8,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23008,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23008,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23008,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23008,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23008,605,1.228,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23008,606,7.806,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23030,203,21.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23030,204,4.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23030,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23030,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23030,208,133,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23030,255,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23030,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23030,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23030,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23030,303,2.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23030,306,378,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23030,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23030,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23030,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23030,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23030,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23030,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23030,605,0.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23030,606,1.755,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23031,203,28.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23031,204,5.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23031,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23031,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23031,208,174,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23031,255,65.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23031,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23031,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23031,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23031,303,2.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23031,306,365,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23031,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23031,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23031,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23031,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23031,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23031,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23031,605,0.195,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23031,606,2.218,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23032,203,21.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23032,204,3.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23032,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23032,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23032,208,123,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23032,255,73.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23032,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23032,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23032,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23032,303,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23032,306,386,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23032,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23032,320,0,'100g',1,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (23032,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23032,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23032,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23032,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23032,605,0.117,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23032,606,1.225,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23033,203,29.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23033,204,3.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23033,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23033,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23033,208,160,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23033,255,66.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23033,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23033,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23033,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23033,303,2.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23033,306,365,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23033,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23033,320,0,'100g',1,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (23033,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23033,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23033,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23033,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23033,605,0.114,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23033,606,1.267,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23034,203,20.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23034,204,6.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23034,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23034,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23034,208,145,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23034,255,72.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23034,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23034,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23034,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23034,303,2.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23034,306,339,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23034,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23034,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23034,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23034,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23034,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23034,601,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23034,605,0.219,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23034,606,2.328,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23035,203,26.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23035,204,7.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23035,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23035,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23035,208,181,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23035,255,65.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23035,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23035,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23035,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23035,303,2.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23035,306,361,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23035,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23035,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23035,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23035,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23035,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23035,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23035,605,0.251,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23035,606,2.737,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23036,203,20.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23036,204,5.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23036,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23036,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23036,208,142,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23036,255,72.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23036,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23036,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23036,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23036,303,2.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23036,306,366,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23036,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23036,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23036,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23036,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23036,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23036,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23036,605,0.214,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23036,606,1.988,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23037,203,20.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23037,204,6.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23037,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23037,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23037,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23037,255,72.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23037,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23037,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23037,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23037,303,2.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23037,306,347,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23037,307,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23037,320,0,'100g',1,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (23037,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23037,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23037,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23037,601,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23037,605,0.199,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23037,606,2.083,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23038,203,26.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23038,204,8.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23038,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23038,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23038,208,184,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23038,255,65.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23038,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23038,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23038,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23038,303,2.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23038,306,342,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23038,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23038,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23038,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23038,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23038,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23038,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23038,605,0.291,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23038,606,3.031,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23039,203,21.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23039,204,5.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23039,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23039,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23039,208,140,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23039,255,72.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23039,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23039,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23039,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23039,303,2.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23039,306,370,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23039,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23039,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23039,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23039,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23039,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23039,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23039,605,0.188,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23039,606,1.791,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23040,203,26.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23040,204,6.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23040,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23040,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23040,208,176,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23040,255,64.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23040,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23040,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23040,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23040,303,3.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23040,306,401,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23040,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23040,320,0,'100g',1,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (23040,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23040,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23040,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23040,601,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23040,605,0.242,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23040,606,2.235,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23041,203,18.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23041,204,11.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23041,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23041,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23041,208,182,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23041,255,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23041,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23041,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23041,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23041,303,2.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23041,306,302,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23041,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23041,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23041,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23041,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23041,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23041,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23041,605,0.389,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23041,606,4.186,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23042,203,24.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23042,204,13.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23042,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23042,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23042,208,228,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23042,255,61.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23042,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23042,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23042,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23042,303,2.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23042,306,317,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23042,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23042,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23042,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23042,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23042,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23042,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23042,605,0.524,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23042,606,5.432,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23043,203,19.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23043,204,9.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23043,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23043,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23043,208,166,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23043,255,71.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23043,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23043,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23043,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23043,303,2.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23043,306,324,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23043,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23043,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23043,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23043,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23043,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23043,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23043,605,0.335,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23043,606,3.464,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23044,203,25.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23044,204,11.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23044,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23044,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23044,208,212,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23044,255,62.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23044,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23044,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23044,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23044,303,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23044,306,333,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23044,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23044,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23044,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23044,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23044,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23044,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23044,605,0.487,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23044,606,4.423,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23045,203,20.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23045,204,6.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23045,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23045,207,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23045,208,150,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23045,255,72.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23045,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23045,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23045,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23045,303,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23045,306,365,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23045,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23045,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23045,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23045,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23045,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23045,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23045,605,0.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23045,606,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23046,203,26.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23046,204,8.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23046,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23046,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23046,208,188,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23046,255,64.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23046,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23046,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23046,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23046,303,2.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23046,306,373,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23046,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23046,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23046,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23046,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23046,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23046,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23046,605,0.246,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23046,606,2.759,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23047,203,20.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23047,204,5.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23047,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23047,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23047,208,137,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23047,255,72.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23047,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23047,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23047,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23047,303,2.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23047,306,360,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23047,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23047,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23047,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23047,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23047,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23047,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23047,605,0.206,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23047,606,1.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23048,203,26.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23048,204,5.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23048,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23048,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23048,208,162,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23048,255,67.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23048,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23048,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23048,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23048,303,2.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23048,306,386,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23048,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23048,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23048,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23048,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23048,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23048,601,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23048,605,0.212,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23048,606,2.063,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23049,203,21.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23049,204,6.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23049,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23049,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23049,208,150,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23049,255,71.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23049,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23049,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23049,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23049,303,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23049,306,338,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23049,307,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23049,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23049,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23049,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23049,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23049,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23049,605,0.185,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23049,606,2.301,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23050,203,27.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23050,204,8.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23050,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23050,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23050,208,191,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23050,255,63.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23050,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23050,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23050,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23050,303,2.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23050,306,361,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23050,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23050,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23050,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23050,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23050,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23050,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23050,605,0.239,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23050,606,2.954,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23051,203,22.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23051,204,3.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23051,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23051,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23051,208,129,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23051,255,73.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23051,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23051,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23051,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23051,303,2.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23051,306,360,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23051,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23051,320,0,'100g',1,1,'2024-12-12','2005-01-01');
INSERT INTO `cndb_nutval` VALUES (23051,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23051,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23051,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23051,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23051,605,0.136,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23051,606,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23052,203,28.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23052,204,5.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23052,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23052,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23052,208,166,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23052,255,65.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23052,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23052,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23052,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23052,303,3.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23052,306,368,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23052,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23052,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23052,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23052,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23052,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23052,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23052,605,0.154,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23052,606,1.716,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23053,203,20.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23053,204,6.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23053,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23053,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23053,208,144,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23053,255,72.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23053,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23053,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23053,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23053,303,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23053,306,327,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23053,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23053,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23053,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23053,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23053,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23053,601,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23053,605,0.215,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23053,606,2.088,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23054,203,26.22,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23054,204,7.2,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23054,205,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23054,207,1.02,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23054,208,177,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23054,255,65.65,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23054,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23054,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23054,301,5,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23054,303,2.59,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23054,306,356,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23054,307,59,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23054,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23054,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23054,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23054,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23054,601,78,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23054,605,0.273,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23054,606,2.833,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23055,203,21.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23055,204,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23055,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23055,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23055,208,129,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23055,255,73.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23055,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23055,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23055,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23055,303,2.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23055,306,381,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23055,307,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23055,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23055,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23055,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23055,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23055,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23055,605,0.139,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23055,606,1.578,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23056,203,29.08,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23056,204,4.84,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23056,205,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23056,207,1.16,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23056,208,168,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23056,255,65.68,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23056,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23056,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23056,301,5,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23056,303,2.77,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23056,306,365,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23056,307,54,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23056,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23056,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23056,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23056,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23056,601,80,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23056,605,0.168,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23056,606,1.901,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23057,203,20.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23057,204,5.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23057,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23057,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23057,208,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23057,255,72.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23057,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23057,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23057,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23057,303,2.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23057,306,355,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23057,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23057,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23057,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23057,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23057,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23057,601,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23057,605,0.196,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23057,606,1.985,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23058,203,26.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23058,204,7.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23058,205,0.12,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23058,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23058,208,182,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23058,255,64.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23058,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23058,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23058,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23058,303,2.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23058,306,361,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23058,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23058,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23058,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23058,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23058,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23058,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23058,605,0.275,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23058,606,2.765,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23059,203,18.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23059,204,10.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23059,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23059,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23059,208,176,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23059,255,70.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23059,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23059,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23059,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23059,303,2.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23059,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23059,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23059,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23059,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23059,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23059,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23059,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23059,605,0.371,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23059,606,3.945,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23060,203,24.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23060,204,12.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23060,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23060,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23060,208,222,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23060,255,62.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23060,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23060,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23060,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23060,303,2.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23060,306,322,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23060,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23060,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23060,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23060,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23060,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23060,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23060,605,0.512,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23060,606,5.095,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23061,203,20.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23061,204,5.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23061,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23061,207,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23061,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23061,255,72.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23061,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23061,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23061,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23061,303,1.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23061,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23061,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23061,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23061,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23061,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23061,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23061,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23061,605,0.209,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23061,606,2.163,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23062,203,27.12,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23062,204,6.78,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23062,205,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23062,207,1,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23062,208,177,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23062,255,65.46,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23062,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23062,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23062,301,5,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23062,303,2.51,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23062,306,377,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23062,307,52,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23062,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23062,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23062,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23062,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23062,601,77,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23062,605,0.235,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23062,606,2.527,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23063,203,21.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23063,204,5.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23063,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23063,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23063,208,142,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23063,255,72.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23063,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23063,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23063,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23063,303,2.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23063,306,345,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23063,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23063,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23063,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23063,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23063,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23063,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23063,605,0.169,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23063,606,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23064,203,27.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23064,204,7.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23064,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23064,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23064,208,182,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23064,255,64.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23064,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23064,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23064,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23064,303,2.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23064,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23064,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23064,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23064,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23064,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23064,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23064,601,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23064,605,0.211,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23064,606,2.541,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23065,203,26.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23065,204,6.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23065,205,0.33,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23065,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23065,208,172,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23065,255,65.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23065,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23065,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23065,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23065,303,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23065,306,348,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23065,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23065,320,0,'100g',1,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (23065,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23065,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23065,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23065,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23065,605,0.177,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23065,606,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23066,203,19.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23066,204,10.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23066,205,0.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23066,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23066,208,175,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23066,255,68.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23066,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23066,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23066,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23066,303,2.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23066,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23066,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23066,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23066,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23066,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23066,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23066,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23066,605,0.489,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23066,606,4.55,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23067,203,20.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23067,204,8.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23067,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23067,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23067,208,161,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23067,255,70.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23067,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23067,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23067,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23067,303,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23067,306,303,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23067,307,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23067,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23067,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23067,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23067,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23067,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23067,605,0.721,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23067,606,3.94,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23068,203,19.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23068,204,10.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23068,205,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23068,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23068,208,169,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23068,255,69.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23068,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23068,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23068,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23068,303,2.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23068,306,307,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23068,307,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23068,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23068,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23068,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23068,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23068,601,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23068,605,0.598,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23068,606,4.312,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23069,203,30.95,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23069,204,12.22,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23069,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23069,207,1.06,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23069,208,234,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23069,255,56.64,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23069,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23069,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23069,301,17,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23069,303,2.97,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23069,306,279,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23069,307,69,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23069,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23069,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23069,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23069,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23069,601,100,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23069,605,0.629,'100g',3,1,'2011-01-18','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23069,606,5.38,'100g',3,1,'2011-01-18','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23070,203,32.1,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23070,204,10.24,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23070,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23070,207,1.12,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23070,208,221,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23070,255,57.54,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23070,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23070,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23070,301,16,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23070,303,2.86,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23070,306,292,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23070,307,70,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23070,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23070,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23070,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23070,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23070,601,99,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23070,605,0.746,'100g',3,1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23070,606,3,'100g',3,1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23071,203,31.41,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23071,204,11.43,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23071,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23071,207,1.08,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23071,208,228,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23071,255,57,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23071,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23071,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23071,301,17,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23071,303,2.93,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23071,306,286,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23071,307,69,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23071,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23071,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23071,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23071,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23071,601,99,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23071,605,0.614,'100g',3,1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23071,606,4.99,'100g',3,1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23072,203,20.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23072,204,7.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23072,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23072,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23072,208,152,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23072,255,70.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23072,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23072,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23072,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23072,303,2.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23072,306,330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23072,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23072,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23072,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23072,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23072,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23072,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23072,605,0.384,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23072,606,3.419,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23073,203,21.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23073,204,5.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23073,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23073,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23073,208,137,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23073,255,72.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23073,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23073,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23073,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23073,303,2.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23073,306,293,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23073,307,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23073,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23073,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23073,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23073,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23073,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23073,605,0.372,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23073,606,2.57,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23074,203,20.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23074,204,6.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23074,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23074,207,0.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23074,208,146,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23074,255,71.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23074,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23074,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23074,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23074,303,2.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23074,306,317,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23074,307,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23074,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23074,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23074,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23074,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23074,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23074,605,0.373,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23074,606,3.03,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23075,203,27.97,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23075,204,11.47,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23075,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23075,207,1.03,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23075,208,215,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23075,255,60.35,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23075,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23075,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23075,301,16,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23075,303,2.88,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23075,306,391,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23075,307,75,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23075,320,1,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23075,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23075,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23075,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23075,601,86,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23075,605,0.622,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23075,606,4.895,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23076,203,27.88,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23076,204,9.77,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23076,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23076,207,1.03,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23076,208,199,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23076,255,61.45,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23076,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23076,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23076,301,19,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23076,303,2.81,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23076,306,356,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23076,307,74,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23076,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23076,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23076,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23076,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23076,601,91,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23076,605,0.71,'100g',3,1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23076,606,2.9,'100g',3,1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23077,203,27.94,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23077,204,10.79,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23077,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23077,207,1.03,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23077,208,209,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23077,255,60.79,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23077,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23077,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23077,301,17,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23077,303,2.87,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23077,306,380,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23077,307,75,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23077,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23077,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23077,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23077,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23077,601,88,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23077,605,0.618,'100g',3,1,'2011-01-18','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23077,606,4.83,'100g',3,1,'2011-01-18','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23078,203,21.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23078,204,8.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23078,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23078,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23078,208,160,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23078,255,69.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23078,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23078,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23078,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23078,303,2.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23078,306,371,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23078,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23078,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23078,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23078,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23078,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23078,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23078,605,0.433,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23078,606,3.605,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23079,203,21.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23079,204,6.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23079,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23079,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23079,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23079,255,71.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23079,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23079,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23079,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23079,303,2.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23079,306,388,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23079,307,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23079,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23079,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23079,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23079,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23079,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23079,605,0.386,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23079,606,2.759,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23080,203,21.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23080,204,7.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23080,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23080,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23080,208,153,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23080,255,70.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23080,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23080,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23080,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23080,303,2.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23080,306,371,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23080,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23080,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23080,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23080,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23080,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23080,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23080,605,0.414,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23080,606,3.267,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23081,203,31.32,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23081,204,8.3,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23081,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23081,207,1.42,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23081,208,200,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23081,255,60.05,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23081,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23081,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23081,301,13,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23081,303,3.76,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23081,306,358,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23081,307,60,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23081,320,1,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23081,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23081,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23081,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23081,601,97,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23081,605,0.307,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23081,606,2.835,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23082,203,31.71,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23082,204,7.02,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23082,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23082,207,1.38,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23082,208,190,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23082,255,60.96,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23082,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23082,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23082,301,13,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23082,303,3.36,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23082,306,360,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23082,307,63,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23082,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23082,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23082,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23082,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23082,601,99,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23082,605,0.285,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23082,606,2.239,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23083,203,31.48,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23083,204,7.78,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23083,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23083,207,1.4,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23083,208,196,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23083,255,60.41,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23083,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23083,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23083,301,13,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23083,303,3.6,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23083,306,359,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23083,307,61,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23083,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23083,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23083,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23083,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23083,601,98,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23083,605,0.298,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23083,606,2.596,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23084,203,33.55,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23084,204,6.94,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23084,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23084,207,1.62,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23084,208,197,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23084,255,59.17,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23084,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23084,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23084,301,15,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23084,303,3.53,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23084,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23084,307,67,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23084,320,1,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23084,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23084,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23084,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23084,601,113,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23084,605,0.282,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23084,606,2.708,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23085,203,32.96,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23085,204,5.44,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23085,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23085,207,1.69,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23085,208,181,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23085,255,60.8,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23085,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23085,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23085,301,15,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23085,303,3.32,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23085,306,298,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23085,307,70,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23085,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23085,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23085,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23085,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23085,601,117,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23085,605,0.282,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23085,606,2.238,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23086,203,33.31,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23086,204,6.34,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23086,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23086,207,1.65,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23086,208,190,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23086,255,59.82,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23086,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23086,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23086,301,15,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23086,303,3.42,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23086,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23086,307,68,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23086,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23086,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23086,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23086,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23086,601,115,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23086,605,0.282,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23086,606,2.52,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23087,203,21.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23087,204,4.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23087,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23087,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23087,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23087,255,73.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23087,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23087,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23087,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23087,303,2.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23087,306,349,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23087,307,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23087,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23087,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23087,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23087,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23087,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23087,605,0.183,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23087,606,1.884,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23088,203,21.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23088,204,3.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23088,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23088,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23088,208,117,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23088,255,74.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23088,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23088,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23088,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23088,303,2.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23088,306,344,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23088,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23088,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23088,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23088,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23088,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23088,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23088,605,0.164,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23088,606,1.47,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23089,203,21.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23089,204,4.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23089,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23089,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23089,208,123,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23089,255,73.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23089,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23089,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23089,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23089,303,2.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23089,306,346,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23089,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23089,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23089,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23089,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23089,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23089,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23089,605,0.185,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23089,606,1.7,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23090,203,32.41,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23090,204,6.82,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23090,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23090,207,1.26,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23090,208,191,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23090,255,60.08,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23090,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23090,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23090,301,16,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23090,303,2.96,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23090,306,319,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23090,307,67,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23090,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23090,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23090,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23090,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23090,601,99,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23090,605,0.366,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23090,606,2.8,'100g',3,1,'2011-01-18','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23091,203,32.29,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23091,204,6.34,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23091,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23091,207,1.18,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23091,208,186,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23091,255,60.97,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23091,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23091,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23091,301,15,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23091,303,2.84,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23091,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23091,307,68,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23091,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23091,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23091,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23091,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23091,601,102,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23091,605,0.31,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23091,606,2.514,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23092,203,32.49,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23092,204,7.14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23092,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23092,207,1.31,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23092,208,194,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23092,255,59.49,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23092,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23092,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23092,301,17,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23092,303,3.06,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23092,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23092,307,65,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23092,320,1,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23092,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23092,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23092,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23092,601,96,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23092,605,0.405,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23092,606,2.87,'100g',3,1,'2011-01-18','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23093,203,21.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23093,204,4.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23093,205,0.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23093,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23093,208,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23093,255,72.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23093,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23093,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23093,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23093,303,2.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23093,306,367,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23093,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23093,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23093,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23093,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23093,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23093,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23093,605,0.231,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23093,606,1.86,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23094,203,21.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23094,204,3.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23094,205,0.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23094,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23094,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23094,255,72.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23094,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23094,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23094,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23094,303,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23094,306,359,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23094,307,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23094,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23094,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23094,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23094,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23094,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23094,605,0.213,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23094,606,1.748,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23095,203,21.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23095,204,4.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23095,205,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23095,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23095,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23095,255,72.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23095,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23095,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23095,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23095,303,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23095,306,373,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23095,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23095,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23095,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23095,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23095,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23095,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23095,605,0.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23095,606,1.988,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23096,203,30.91,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23096,204,10.91,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23096,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23096,207,1.56,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23096,208,222,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23096,255,57.56,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23096,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23096,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23096,301,14,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23096,303,3.25,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23096,306,312,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23096,307,65,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23096,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23096,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23096,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23096,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23096,601,106,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23096,605,0.427,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23096,606,4.253,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23097,203,32.01,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23097,204,9.66,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23097,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23097,207,1.2,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23097,208,215,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23097,255,58.92,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23097,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23097,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23097,301,14,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23097,303,3.15,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23097,306,303,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23097,307,66,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23097,320,2,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (23097,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23097,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23097,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23097,601,108,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23097,605,0.427,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23097,606,3.567,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23098,203,31.35,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23098,204,10.41,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23098,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23098,207,1.42,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23098,208,219,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23098,255,58.11,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23098,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23098,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23098,301,14,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23098,303,3.21,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23098,306,308,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23098,307,65,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23098,320,2,'100g',2,1,'2024-12-12','2010-01-06');
INSERT INTO `cndb_nutval` VALUES (23098,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23098,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23098,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23098,601,107,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23098,605,0.427,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23098,606,3.981,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23099,203,26.7,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23099,204,20.49,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23099,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23099,207,1.22,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23099,208,291,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23099,255,52.51,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23099,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23099,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23099,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23099,303,2.68,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23099,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23099,307,62,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23099,320,8,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23099,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23099,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23099,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23099,601,99,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23099,605,1.187,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23099,606,8.261,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23100,203,27.97,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23100,204,10.57,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23100,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23100,207,1.02,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23100,208,207,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23100,255,61.36,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23100,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23100,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23100,301,7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23100,303,2.53,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23100,306,296,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23100,307,59,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23100,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23100,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23100,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23100,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23100,601,79,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23100,605,0.517,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23100,606,4.2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23101,203,27.18,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23101,204,14.55,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23101,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23101,207,1.02,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23101,208,240,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23101,255,57.57,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23101,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23101,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23101,301,11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23101,303,2.37,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23101,306,296,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23101,307,68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23101,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23101,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23101,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23101,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23101,601,83,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23101,605,0.666,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23101,606,5.606,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23102,203,19.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23102,204,13.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23102,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23102,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23102,208,196,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23102,255,66.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23102,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23102,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23102,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23102,303,2.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23102,306,336,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23102,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23102,320,4,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23102,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23102,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23102,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23102,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23102,605,0.831,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23102,606,5.726,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23103,203,19.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23103,204,13.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23103,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23103,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23103,208,202,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23103,255,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23103,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23103,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23103,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23103,303,2.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23103,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23103,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23103,320,4,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23103,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23103,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23103,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23103,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23103,605,0.846,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23103,606,5.896,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23104,203,19.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23104,204,12.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23104,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23104,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23104,208,187,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23104,255,67.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23104,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23104,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23104,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23104,303,2.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23104,306,347,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23104,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23104,320,4,'100g',1,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23104,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23104,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23104,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23104,601,67,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23104,605,0.807,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23104,606,5.473,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23105,203,26.18,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23105,204,13.54,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23105,205,0.21,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23105,207,0.99,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23105,208,227,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23105,255,59.08,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23105,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23105,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23105,301,13,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23105,303,3.26,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23105,306,310,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23105,307,73,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23105,320,7,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23105,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23105,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23105,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23105,601,93,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23105,605,0.868,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23105,606,5.692,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23106,203,26.1,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23106,204,14.41,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23106,205,0.4,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23106,207,0.98,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23106,208,236,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23106,255,58.12,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23106,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23106,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23106,301,12,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23106,303,3.27,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23106,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23106,307,73,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23106,320,7,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23106,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23106,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23106,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23106,601,89,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23106,605,0.882,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23106,606,5.963,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23107,203,26.3,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23107,204,12.25,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23107,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23107,207,1.01,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23107,208,215,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23107,255,60.52,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23107,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23107,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23107,301,16,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23107,303,3.31,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23107,306,301,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23107,307,73,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23107,320,7,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23107,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23107,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23107,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23107,601,98,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23107,605,0.846,'100g',3,1,'2011-01-18','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23107,606,5.285,'100g',3,1,'2011-01-18','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23108,203,18.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23108,204,11.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23108,205,0.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23108,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23108,208,182,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23108,255,68.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23108,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23108,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23108,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23108,303,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23108,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23108,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23108,320,4,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23108,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23108,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23108,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23108,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23108,605,0.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23108,606,4.831,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23109,203,18.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23109,204,12.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23109,205,0.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23109,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23109,208,189,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23109,255,67.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23109,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23109,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23109,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23109,303,2.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23109,306,312,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23109,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23109,320,4,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23109,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23109,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23109,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23109,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23109,605,0.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23109,606,5.137,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23110,203,19.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23110,204,10.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23110,205,0.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23110,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23110,208,172,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23110,255,69.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23110,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23110,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23110,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23110,303,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23110,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23110,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23110,320,4,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23110,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23110,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23110,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23110,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23110,605,0.669,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23110,606,4.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23111,203,21.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23111,204,5.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23111,205,0.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23111,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23111,208,133,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23111,255,72.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23111,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23111,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23111,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23111,303,2.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23111,306,403,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23111,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23111,320,3,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23111,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23111,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23111,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23111,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23111,605,0.247,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23111,606,2.124,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23112,203,21.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23112,204,4.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23112,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23112,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23112,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23112,255,73.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23112,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23112,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23112,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23112,303,2.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23112,306,383,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23112,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23112,320,3,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23112,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23112,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23112,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23112,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23112,605,0.269,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23112,606,1.897,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23113,203,24.63,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23113,204,15.29,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23113,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23113,207,0.94,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23113,208,236,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23113,255,60.3,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23113,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23113,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23113,301,18,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23113,303,2.22,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23113,306,308,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23113,307,76,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23113,320,7,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23113,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23113,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23113,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23113,601,83,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23113,605,0.888,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23113,606,6.354,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23114,203,24.47,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23114,204,15.87,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23114,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23114,207,0.94,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23114,208,241,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23114,255,59.63,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23114,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23114,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23114,301,18,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23114,303,2.28,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23114,306,307,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23114,307,75,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23114,320,6,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23114,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23114,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23114,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23114,601,84,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23114,605,0.882,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23114,606,6.462,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23115,203,24.86,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23115,204,14.41,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23115,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23115,207,0.94,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23115,208,229,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23115,255,61.29,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23115,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23115,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23115,301,19,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23115,303,2.16,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23115,306,312,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23115,307,76,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23115,320,7,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23115,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23115,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23115,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23115,601,81,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23115,605,0.896,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23115,606,6.192,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23116,203,28.23,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23116,204,18,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23116,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23116,207,1.3,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23116,208,275,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23116,255,53.8,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23116,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23116,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23116,301,14,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23116,303,2.8,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23116,306,273,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23116,307,65,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23116,320,8,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23116,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23116,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23116,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23116,601,96,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23116,605,1.043,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23116,606,7.256,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23117,203,27.6,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23117,204,19.3,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23117,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23117,207,1.4,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23117,208,284,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23117,255,52.71,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23117,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23117,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23117,301,14,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23117,303,2.82,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23117,306,275,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23117,307,64,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23117,320,8,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23117,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23117,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23117,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23117,601,98,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23117,605,1.072,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23117,606,7.666,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23118,203,29.18,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23118,204,16.05,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23118,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23118,207,1.15,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23118,208,261,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23118,255,55.43,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23118,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23118,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23118,301,14,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23118,303,2.76,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23118,306,270,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23118,307,66,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23118,320,8,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23118,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23118,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23118,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23118,601,94,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23118,605,0.994,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23118,606,6.629,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23119,203,32.07,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23119,204,10.18,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23119,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23119,207,1.62,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23119,208,220,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23119,255,57.29,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23119,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23119,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23119,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23119,303,3.29,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23119,306,298,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23119,307,67,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23119,320,7,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23119,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23119,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23119,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23119,601,113,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23119,605,0.475,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23119,606,3.638,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23120,203,32.21,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23120,204,10.74,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23120,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23120,207,1.55,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23120,208,225,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23120,255,56.78,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23120,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23120,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23120,301,15,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23120,303,3.38,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23120,306,303,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23120,307,66,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23120,320,7,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23120,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23120,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23120,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23120,601,112,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23120,605,0.488,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23120,606,3.888,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23121,203,31.86,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23121,204,9.34,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23121,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23121,207,1.71,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23121,208,211,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23121,255,58.05,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23121,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23121,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23121,301,15,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23121,303,3.21,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23121,306,288,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23121,307,69,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23121,320,7,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23121,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23121,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23121,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23121,601,115,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23121,605,0.457,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23121,606,3.263,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23122,203,21.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23122,204,4.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23122,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23122,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23122,208,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23122,255,73.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23122,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23122,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23122,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23122,303,2.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23122,306,343,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23122,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23122,320,3,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23122,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23122,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23122,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23122,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23122,605,0.229,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23122,606,2.059,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23123,203,21.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23123,204,5.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23123,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23123,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23123,208,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23123,255,72.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23123,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23123,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23123,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23123,303,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23123,306,347,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23123,307,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23123,320,3,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23123,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23123,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23123,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23123,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23123,605,0.222,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23123,606,2.114,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23124,203,21.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23124,204,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23124,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23124,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23124,208,122,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23124,255,74.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23124,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23124,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23124,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23124,303,2.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23124,306,341,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23124,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23124,320,3,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23124,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23124,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23124,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23124,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23124,605,0.239,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23124,606,1.976,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23125,203,25.48,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23125,204,22.58,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23125,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23125,207,0.83,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23125,208,305,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23125,255,52.01,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23125,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23125,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23125,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23125,303,2.7,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23125,306,239,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23125,307,70,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23125,320,8,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23125,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23125,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23125,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23125,601,100,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23125,605,1.431,'100g',3,1,'2011-01-18','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23125,606,10.04,'100g',3,1,'2011-01-18','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23126,203,25.26,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23126,204,24.05,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23126,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23126,207,0.82,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23126,208,317,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23126,255,50.69,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23126,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23126,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23126,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23126,303,2.67,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23126,306,228,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23126,307,70,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23126,320,8,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23126,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23126,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23126,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23126,601,98,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23126,605,1.52,'100g',3,1,'2011-01-18','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23126,606,10.638,'100g',3,1,'2011-01-18','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23127,203,25.81,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23127,204,20.38,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23127,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23127,207,0.84,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23127,208,287,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23127,255,53.99,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23127,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23127,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23127,301,14,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23127,303,2.76,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23127,306,269,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23127,307,71,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23127,320,8,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23127,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23127,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23127,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23127,601,104,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23127,605,1.297,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23127,606,9.144,'100g',3,1,'2011-01-18','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23128,203,17.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23128,204,18.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23128,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23128,207,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23128,208,235,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23128,255,63.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23128,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23128,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23128,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23128,303,2.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23128,306,277,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23128,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23128,320,4,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23128,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23128,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23128,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23128,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23128,605,1.207,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23128,606,7.979,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23129,203,17.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23129,204,19.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23129,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23129,207,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23129,208,240,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23129,255,63.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23129,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23129,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23129,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23129,303,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23129,306,282,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23129,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23129,320,4,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23129,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23129,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23129,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23129,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23129,605,1.118,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23129,606,8.141,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23130,203,17.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23130,204,17.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23130,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23130,207,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23130,208,227,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23130,255,64.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23130,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23130,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23130,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23130,303,2.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23130,306,273,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23130,307,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23130,320,5,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23130,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23130,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23130,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23130,601,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23130,605,1.341,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23130,606,7.738,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23131,203,31.03,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23131,204,8.92,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23131,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23131,207,1.38,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23131,208,204,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23131,255,59.76,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23131,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23131,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23131,301,13,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23131,303,3.53,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23131,306,352,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23131,307,61,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23131,320,7,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23131,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23131,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23131,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23131,601,98,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23131,605,0.387,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23131,606,3.112,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23132,203,30.93,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23132,204,9.25,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23132,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23132,207,1.4,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23132,208,207,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23132,255,59.49,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23132,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23132,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23132,301,13,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23132,303,3.7,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23132,306,353,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23132,307,60,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23132,320,6,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23132,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23132,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23132,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23132,601,98,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23132,605,0.382,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23132,606,3.264,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23133,203,31.18,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23133,204,8.41,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23133,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23133,207,1.35,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23133,208,200,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23133,255,60.15,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23133,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23133,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23133,301,13,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23133,303,3.29,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23133,306,352,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23133,307,62,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23133,320,7,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23133,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23133,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23133,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23133,601,98,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23133,605,0.394,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23133,606,2.884,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23134,203,27.69,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23134,204,20.55,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23134,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23134,207,0.96,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23134,208,296,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23134,255,51.91,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23134,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23134,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23134,301,16,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23134,303,2.49,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23134,306,247,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23134,307,65,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23134,320,8,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (23134,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23134,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23134,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23134,601,96,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23134,605,1.316,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23134,606,9.009,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23135,203,27.16,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23135,204,21.56,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23135,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23135,207,0.94,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23135,208,303,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23135,255,51.36,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23135,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23135,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23135,301,16,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23135,303,2.51,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23135,306,241,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23135,307,65,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23135,320,8,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (23135,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23135,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23135,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23135,601,96,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23135,605,1.333,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23135,606,9.268,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23136,203,28.47,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23136,204,19.03,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23136,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23136,207,0.99,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23136,208,285,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23136,255,52.74,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23136,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23136,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23136,301,15,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23136,303,2.46,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23136,306,255,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23136,307,66,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23136,320,8,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (23136,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23136,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23136,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23136,601,95,'100g',1,1,'2011-01-18','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23136,605,1.291,'100g',3,1,'2011-01-18','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23136,606,8.621,'100g',3,1,'2011-01-18','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23137,203,18.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23137,204,14.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23137,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23137,207,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23137,208,205,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23137,255,66.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23137,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23137,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23137,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23137,303,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23137,306,291,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23137,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23137,320,4,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (23137,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23137,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23137,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23137,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23137,605,0.909,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23137,606,6.154,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23138,203,18.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23138,204,14.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23138,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23138,207,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23138,208,210,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23138,255,65.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23138,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23138,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23138,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23138,303,2.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23138,306,302,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23138,307,76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23138,320,4,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (23138,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23138,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23138,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23138,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23138,605,0.906,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23138,606,6.387,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23139,203,19.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23139,204,13.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23139,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23139,207,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23139,208,196,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23139,255,67.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23139,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23139,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23139,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23139,303,1.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23139,306,271,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23139,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23139,320,4,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (23139,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23139,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23139,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23139,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23139,605,0.915,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23139,606,5.805,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23140,203,24.98,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23140,204,19.64,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23140,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23140,207,0.94,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23140,208,277,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23140,255,55.22,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23140,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23140,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23140,301,16,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23140,303,2.45,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23140,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23140,307,71,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23140,320,7,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (23140,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23140,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23140,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23140,601,87,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23140,605,1.287,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23140,606,8.66,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23141,203,24.95,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23141,204,20.35,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23141,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23141,207,0.94,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23141,208,283,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23141,255,54.74,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23141,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23141,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23141,301,15,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23141,303,2.46,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23141,306,333,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23141,307,71,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23141,320,7,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (23141,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23141,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23141,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23141,601,86,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23141,605,1.289,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23141,606,8.677,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23142,203,25.03,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23142,204,18.57,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23142,205,0,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23142,207,0.94,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23142,208,267,'100g',3,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23142,255,55.93,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23142,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23142,291,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23142,301,17,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23142,303,2.42,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23142,306,307,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23142,307,70,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23142,320,8,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (23142,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23142,401,0,'100g',4,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23142,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23142,601,89,'100g',1,1,'2011-01-18','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23142,605,1.284,'100g',3,1,'2011-01-18','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23142,606,8.633,'100g',3,1,'2011-01-18','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23143,203,18.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23143,204,16.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23143,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23143,207,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23143,208,223,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23143,255,64.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23143,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23143,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23143,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23143,303,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23143,306,329,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23143,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23143,320,4,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (23143,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23143,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23143,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23143,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23143,605,1.052,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23143,606,6.963,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23144,203,18.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23144,204,16.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23144,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23144,207,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23144,208,227,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23144,255,63.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23144,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23144,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23144,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23144,303,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23144,306,330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23144,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23144,320,4,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (23144,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23144,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23144,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23144,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23144,605,1.056,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23144,606,7.176,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23145,203,18.86,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23145,204,15.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23145,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23145,207,0.89,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23145,208,216,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23145,255,65.24,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23145,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23145,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23145,301,14,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23145,303,2.14,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23145,306,342,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23145,307,68,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23145,320,4,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (23145,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23145,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23145,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23145,601,68,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23145,605,1.045,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23145,606,6.644,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23146,203,27.12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23146,204,13.64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23146,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23146,207,1.05,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23146,208,231,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23146,255,58.66,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23146,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23146,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23146,301,11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23146,303,2.36,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23146,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23146,307,69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23146,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23146,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23146,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23146,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23146,601,80,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23146,605,0.639,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23146,606,5.258,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23147,203,27.03,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23147,204,12.29,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23147,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23147,207,1.11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23147,208,219,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23147,255,60.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23147,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23147,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23147,301,11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23147,303,2.35,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23147,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23147,307,70,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23147,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23147,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23147,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23147,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23147,601,77,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23147,605,0.597,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23147,606,4.736,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23148,203,27.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23148,204,11.97,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23148,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23148,207,1.01,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23148,208,217,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23148,255,60.57,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23148,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23148,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23148,301,8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23148,303,2.65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23148,306,282,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23148,307,60,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23148,320,1,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23148,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23148,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23148,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23148,601,80,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23148,605,0.572,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23148,606,4.645,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23149,203,28.98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23149,204,8.48,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23149,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23149,207,1.05,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23149,208,192,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23149,255,62.56,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23149,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23149,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23149,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23149,303,2.34,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23149,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23149,307,59,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23149,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23149,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23149,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23149,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23149,601,77,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23149,605,0.434,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23149,606,3.534,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23150,203,21.22,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23150,204,9.04,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23150,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23150,207,0.97,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23150,208,166,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23150,255,69.24,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23150,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23150,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23150,301,9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23150,303,1.96,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23150,306,275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23150,307,64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23150,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23150,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23150,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23150,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23150,601,64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23150,605,0.447,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23150,606,3.544,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23151,203,20.93,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23151,204,9.97,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23151,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23151,207,0.95,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23151,208,173,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23151,255,68.58,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23151,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23151,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23151,301,9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23151,303,1.95,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23151,306,270,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23151,307,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23151,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23151,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23151,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23151,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23151,601,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23151,605,0.486,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23151,606,3.88,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23152,203,21.65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23152,204,7.64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23152,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23152,207,1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23152,208,155,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23152,255,70.21,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23152,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23152,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23152,301,10,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23152,303,1.99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23152,306,281,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23152,307,63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23152,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23152,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23152,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23152,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23152,601,62,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23152,605,0.388,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23152,606,3.039,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23153,203,21.99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23153,204,7.54,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23153,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23153,207,1.01,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23153,208,156,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23153,255,70.14,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23153,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23153,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23153,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23153,303,1.94,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23153,306,276,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23153,307,56,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23153,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23153,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23153,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23153,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23153,601,66,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23153,605,0.313,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23153,606,2.759,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23154,203,21.62,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23154,204,8.29,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23154,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23154,207,0.99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23154,208,161,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23154,255,69.65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23154,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23154,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23154,301,7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23154,303,2.04,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23154,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23154,307,56,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23154,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23154,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23154,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23154,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23154,601,63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23154,605,0.362,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23154,606,3.057,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23155,203,22.55,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23155,204,6.41,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23155,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23155,207,1.03,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23155,208,148,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23155,255,70.89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23155,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23155,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23155,301,5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23155,303,1.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23155,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23155,307,55,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23155,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23155,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23155,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23155,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23155,601,70,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23155,605,0.241,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23155,606,2.313,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23156,203,27.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23156,204,12.43,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23156,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23156,207,1.09,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23156,208,221,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23156,255,59.69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23156,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23156,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23156,301,22,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23156,303,2.62,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23156,306,279,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23156,307,67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23156,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23156,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23156,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23156,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23156,601,80,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23156,605,0.602,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23156,606,4.794,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23157,203,27.03,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23157,204,13.44,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23157,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23157,207,1.04,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23157,208,229,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23157,255,59.13,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23157,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23157,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23157,301,22,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23157,303,2.61,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23157,306,276,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23157,307,67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23157,320,1,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23157,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23157,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23157,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23157,601,82,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23157,605,0.612,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23157,606,4.897,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23158,203,27.96,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23158,204,10.91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23158,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23158,207,1.15,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23158,208,210,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23158,255,60.51,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23158,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23158,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23158,301,22,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23158,303,2.63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23158,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23158,307,67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23158,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23158,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23158,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23158,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23158,601,78,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23158,605,0.587,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23158,606,4.639,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23159,203,28.21,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23159,204,11.68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23159,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23159,207,1.05,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23159,208,218,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23159,255,59.55,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23159,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23159,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23159,301,8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23159,303,2.13,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23159,306,326,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23159,307,56,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23159,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23159,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23159,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23159,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23159,601,80,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23159,605,0.583,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23159,606,4.535,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23160,203,27.87,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23160,204,13.01,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23160,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23160,207,1.01,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23160,208,229,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23160,255,58.26,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23160,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23160,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23160,301,8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23160,303,2.2,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23160,306,319,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23160,307,54,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23160,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23160,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23160,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23160,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23160,601,81,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23160,605,0.667,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23160,606,5.187,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23161,203,28.72,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23161,204,9.68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23161,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23161,207,1.11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23161,208,202,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23161,255,61.49,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23161,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23161,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23161,301,8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23161,303,2.02,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23161,306,335,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23161,307,59,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23161,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23161,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23161,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23161,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23161,601,79,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23161,605,0.459,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23161,606,3.556,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23162,203,29.99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23162,204,12.69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23162,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23162,207,1.05,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23162,208,234,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23162,255,57,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23162,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23162,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23162,301,7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23162,303,2.47,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23162,306,303,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23162,307,63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23162,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23162,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23162,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23162,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23162,601,92,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23162,605,0.525,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23162,606,4.315,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23163,203,21.17,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23163,204,8.82,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23163,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23163,207,0.95,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23163,208,164,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23163,255,69.5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23163,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23163,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23163,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23163,303,1.75,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23163,306,272,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23163,307,66,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23163,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23163,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23163,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23163,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23163,601,64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23163,605,0.403,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23163,606,3.233,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23164,203,29.56,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23164,204,13.72,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23164,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23164,207,1.03,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23164,208,242,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23164,255,56.33,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23164,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23164,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23164,301,7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23164,303,2.51,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23164,306,298,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23164,307,64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23164,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23164,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23164,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23164,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23164,601,93,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23164,605,0.582,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23164,606,4.76,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23165,203,20.89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23165,204,9.76,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23165,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23165,207,0.94,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23165,208,171,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23165,255,68.91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23165,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23165,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23165,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23165,303,1.74,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23165,306,264,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23165,307,67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23165,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23165,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23165,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23165,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23165,601,64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23165,605,0.443,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23165,606,3.546,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23166,203,30.64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23166,204,11.16,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23166,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23166,207,1.09,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23166,208,223,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23166,255,58.01,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23166,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23166,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23166,301,7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23166,303,2.36,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23166,306,312,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23166,307,62,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23166,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23166,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23166,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23166,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23166,601,91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23166,605,0.44,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23166,606,3.647,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23167,203,21.61,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23167,204,7.41,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23167,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23167,207,0.97,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23167,208,153,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23167,255,70.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23167,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23167,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23167,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23167,303,1.76,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23167,306,292,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23167,307,66,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23167,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23167,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23167,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23167,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23167,601,63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23167,605,0.343,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23167,606,2.765,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23168,203,27.68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23168,204,19.01,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23168,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23168,207,1.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23168,208,282,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23168,255,52.29,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23168,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23168,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23168,301,7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23168,303,5.21,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23168,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23168,307,71,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23168,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23168,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23168,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23168,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23168,601,102,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23168,605,0.819,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23168,606,6.674,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23169,203,18.74,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23169,204,14.53,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23169,205,0.19,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23169,207,0.94,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23169,208,206,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23169,255,65.6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23169,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23169,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23169,301,5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23169,303,3.6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23169,306,253,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23169,307,67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23169,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23169,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23169,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23169,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23169,601,69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23169,605,0.744,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23169,606,5.618,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23170,203,27.03,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23170,204,20.28,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23170,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23170,207,1.28,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23170,208,291,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23170,255,51.62,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23170,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23170,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23170,301,7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23170,303,5.06,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23170,306,286,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23170,307,71,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23170,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23170,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23170,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23170,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23170,601,105,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23170,605,0.872,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23170,606,7.035,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23171,203,18.47,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23171,204,15.26,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23171,205,0.17,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23171,207,0.92,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23171,208,212,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23171,255,65.19,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23171,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23171,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23171,301,5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23171,303,3.53,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23171,306,251,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23171,307,68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23171,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23171,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23171,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23171,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23171,601,70,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23171,605,0.769,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23171,606,5.798,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23172,203,28.65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23172,204,17.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23172,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23172,207,1.33,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23172,208,268,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23172,255,53.31,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23172,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23172,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23172,301,8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23172,303,5.46,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23172,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23172,307,70,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23172,320,3,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23172,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23172,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23172,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23172,601,99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23172,605,0.74,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23172,606,6.132,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23173,203,19.14,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23173,204,13.44,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23173,205,0.23,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23173,207,0.97,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23173,208,198,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23173,255,66.22,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23173,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23173,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23173,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23173,303,3.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23173,306,260,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23173,307,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23173,320,3,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23173,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23173,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23173,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23173,601,69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23173,605,0.706,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23173,606,5.349,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23174,203,28.11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23174,204,10.37,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23174,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23174,207,1.09,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23174,208,206,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23174,255,60.91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23174,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23174,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23174,301,7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23174,303,2.53,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23174,306,296,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23174,307,59,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23174,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23174,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23174,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23174,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23174,601,79,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23174,605,0.517,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23174,606,4.2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23175,203,21.85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23175,204,7.41,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23175,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23175,207,0.98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23175,208,154,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23175,255,69.93,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23175,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23175,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23175,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23175,303,1.94,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23175,306,276,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23175,307,56,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23175,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23175,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23175,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23175,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23175,601,66,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23175,605,0.313,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23175,606,2.759,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23176,203,27.39,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23176,204,11.75,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23176,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23176,207,1.06,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23176,208,215,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23176,255,60.09,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23176,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23176,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23176,301,8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23176,303,2.65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23176,306,282,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23176,307,60,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23176,320,1,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23176,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23176,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23176,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23176,601,80,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23176,605,0.572,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23176,606,4.645,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23177,203,21.44,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23177,204,8.5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23177,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23177,207,0.97,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23177,208,162,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23177,255,69.22,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23177,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23177,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23177,301,7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23177,303,2.04,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23177,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23177,307,56,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23177,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23177,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23177,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23177,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23177,601,63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23177,605,0.362,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23177,606,3.057,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23178,203,29.18,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23178,204,8.31,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23178,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23178,207,1.15,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23178,208,191,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23178,255,62.15,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23178,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23178,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23178,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23178,303,2.34,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23178,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23178,307,59,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23178,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23178,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23178,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23178,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23178,601,77,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23178,605,0.434,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23178,606,3.534,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23179,203,22.46,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23179,204,5.78,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23179,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23179,207,1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23179,208,142,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23179,255,71,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23179,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23179,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23179,301,5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23179,303,1.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23179,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23179,307,55,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23179,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23179,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23179,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23179,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23179,601,70,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23179,605,0.241,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23179,606,2.313,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23180,203,28.36,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23180,204,20.57,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23180,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23180,207,0.64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23180,208,299,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23180,255,51.12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23180,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23180,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23180,301,22,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23180,303,2.66,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23180,306,284,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23180,307,68,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23180,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23180,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23180,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23180,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23180,601,90,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23180,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23180,606,8.103,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23181,203,19.11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23181,204,17.91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23181,205,0.46,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23181,207,0.82,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23181,208,239,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23181,255,61.7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23181,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23181,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23181,301,9,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23181,303,1.84,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23181,306,258,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23181,307,60,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23181,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (23181,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23181,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23181,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23181,601,70,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23181,605,0.973,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23181,606,7.055,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23182,203,27.75,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23182,204,21.72,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23182,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23182,207,0.6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23182,208,306,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23182,255,50.5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23182,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23182,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23182,301,22,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23182,303,2.64,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23182,306,280,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23182,307,68,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23182,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23182,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23182,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23182,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23182,601,91,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23182,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23182,606,8.763,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23183,203,18.72,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23183,204,19.36,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23183,205,0.64,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23183,207,0.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23183,208,252,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23183,255,60.48,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23183,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23183,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23183,301,8,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23183,303,1.83,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23183,306,254,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23183,307,61,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23183,320,2,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23183,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23183,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23183,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23183,601,72,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23183,605,1.045,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23183,606,7.812,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23184,203,29.28,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23184,204,18.84,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23184,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23184,207,0.7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23184,208,287,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23184,255,52.05,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23184,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23184,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23184,301,22,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23184,303,2.68,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23184,306,289,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23184,307,68,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23184,320,3,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23184,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23184,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23184,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23184,601,89,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23184,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23184,606,7.091,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23185,203,19.71,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23185,204,15.73,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23185,205,0.2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23185,207,0.84,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23185,208,221,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23185,255,63.52,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23185,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23185,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23185,301,9,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23185,303,1.86,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23185,306,264,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23185,307,59,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23185,320,3,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23185,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23185,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23185,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23185,601,67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23185,605,0.865,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23185,606,5.92,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23186,203,22.71,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23186,204,24.7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23186,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23186,207,0.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23186,208,313,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23186,255,52.36,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23186,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23186,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23186,301,22,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23186,303,2.29,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23186,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23186,307,60,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23186,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23186,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23186,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23186,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23186,601,83,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23186,605,1.613,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23186,606,10.566,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23187,203,23.19,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23187,204,23.47,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23187,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23187,207,0.98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23187,208,304,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23187,255,53.01,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23187,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23187,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23187,301,22,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23187,303,2.29,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23187,306,246,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23187,307,59,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23187,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23187,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23187,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23187,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23187,601,80,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23187,605,1.654,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23187,606,10.723,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23188,203,22.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23188,204,24.2,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23188,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23188,207,0.93,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23188,208,309,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23188,255,52.62,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23188,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23188,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23188,301,22,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23188,303,2.29,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23188,306,243,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23188,307,60,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23188,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23188,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23188,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23188,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23188,601,82,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23188,605,1.629,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23188,606,10.629,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23189,203,23.53,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23189,204,23.61,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23189,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23189,207,0.91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23189,208,307,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23189,255,52.38,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23189,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23189,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23189,301,13,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23189,303,2.15,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23189,306,264,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23189,307,62,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23189,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23189,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23189,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23189,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23189,601,83,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23189,605,1.481,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23189,606,10.097,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23190,203,23.36,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23190,204,21.85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23190,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23190,207,0.99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23190,208,290,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23190,255,54.66,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23190,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23190,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23190,301,14,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23190,303,2.13,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23190,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23190,307,64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23190,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23190,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23190,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23190,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23190,601,79,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23190,605,1.462,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23190,606,9.562,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23191,203,23.47,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23191,204,22.91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23191,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23191,207,0.94,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23191,208,300,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23191,255,53.29,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23191,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23191,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23191,301,13,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23191,303,2.14,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23191,306,263,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23191,307,63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23191,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23191,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23191,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23191,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23191,601,82,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23191,605,1.473,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23191,606,9.883,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23192,203,18.13,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23192,204,20.31,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23192,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23192,207,0.85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23192,208,255,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23192,255,60.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23192,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23192,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23192,301,10,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23192,303,1.74,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23192,306,233,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23192,307,56,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23192,320,5,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23192,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23192,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23192,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23192,601,69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23192,605,1.309,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23192,606,9.097,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23193,203,17.92,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23193,204,20.96,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23193,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23193,207,0.84,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23193,208,260,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23193,255,60.35,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23193,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23193,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23193,301,10,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23193,303,1.73,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23193,306,231,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23193,307,57,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23193,320,5,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23193,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23193,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23193,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23193,601,70,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23193,605,1.324,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23193,606,9.265,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23194,203,18.44,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23194,204,19.34,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23194,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23194,207,0.88,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23194,208,248,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23194,255,61.47,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23194,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23194,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23194,301,11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23194,303,1.76,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23194,306,237,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23194,307,55,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23194,320,5,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23194,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23194,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23194,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23194,601,68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23194,605,1.287,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23194,606,8.844,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23195,203,22.92,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23195,204,23.52,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23195,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23195,207,0.88,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23195,208,303,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23195,255,53.5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23195,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23195,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23195,301,12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23195,303,2.33,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23195,306,247,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23195,307,54,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23195,320,7,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23195,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23195,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23195,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23195,601,81,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23195,605,1.571,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23195,606,10.307,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23196,203,24.83,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23196,204,19.25,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23196,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23196,207,0.93,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23196,208,273,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23196,255,55.98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23196,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23196,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23196,301,10,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23196,303,2.12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23196,306,279,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23196,307,54,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23196,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23196,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23196,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23196,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23196,601,79,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23196,605,1.338,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23196,606,8.749,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23197,203,23.69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23197,204,21.81,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23197,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23197,207,0.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23197,208,291,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23197,255,54.49,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23197,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23197,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23197,301,11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23197,303,2.24,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23197,306,260,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23197,307,54,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23197,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23197,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23197,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23197,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23197,601,80,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23197,605,1.478,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23197,606,9.684,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23198,203,24.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23198,204,21.66,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23198,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23198,207,0.93,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23198,208,292,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23198,255,53.79,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23198,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23198,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23198,301,11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23198,303,1.95,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23198,306,286,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23198,307,52,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23198,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23198,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23198,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23198,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23198,601,81,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23198,605,1.438,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23198,606,9.419,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23199,203,23.92,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23199,204,22.98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23199,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23199,207,0.89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23199,208,303,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23199,255,52.62,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23199,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23199,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23199,301,11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23199,303,2,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23199,306,281,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23199,307,51,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23199,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23199,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23199,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23199,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23199,601,82,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23199,605,1.52,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23199,606,10.044,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23200,203,24.85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23200,204,19.68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23200,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23200,207,0.98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23200,208,277,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23200,255,55.56,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23200,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23200,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23200,301,11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23200,303,1.87,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23200,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23200,307,54,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23200,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23200,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23200,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23200,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23200,601,80,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23200,605,1.314,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23200,606,8.482,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23201,203,18.85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23201,204,18.73,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23201,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23201,207,0.89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23201,208,244,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23201,255,61.77,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23201,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23201,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23201,301,8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23201,303,1.74,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23201,306,236,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23201,307,50,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23201,320,5,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23201,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23201,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23201,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23201,601,70,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23201,605,1.168,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23201,606,8.251,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23202,203,18.39,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23202,204,19.95,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23202,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23202,207,0.87,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23202,208,253,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23202,255,60.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23202,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23202,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23202,301,8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23202,303,1.81,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23202,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23202,307,50,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23202,320,5,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23202,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23202,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23202,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23202,601,68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23202,605,1.244,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23202,606,8.741,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23213,203,19.55,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23213,204,16.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23213,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23213,207,0.91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23213,208,230,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23213,255,63.08,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23213,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23213,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23213,301,7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23213,303,1.64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23213,306,256,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23213,307,50,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23213,320,5,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23213,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23213,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23213,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23213,601,74,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23213,605,1.054,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23213,606,7.515,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23214,203,29.36,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23214,204,14.2,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23214,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23214,207,1.04,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23214,208,245,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23214,255,56.07,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23214,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23214,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23214,301,7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23214,303,2.44,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23214,306,298,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23214,307,63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23214,320,7,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23214,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23214,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23214,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23214,601,92,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23214,605,0.657,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23214,606,5.057,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23215,203,28.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23215,204,15.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23215,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23215,207,1.01,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23215,208,253,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23215,255,55.35,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23215,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23215,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23215,301,7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23215,303,2.48,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23215,306,293,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23215,307,63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23215,320,7,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23215,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23215,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23215,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23215,601,93,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23215,605,0.724,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23215,606,5.554,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23216,203,30.06,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23216,204,12.54,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23216,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23216,207,1.08,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23216,208,233,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23216,255,57.16,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23216,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23216,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23216,301,7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23216,303,2.34,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23216,306,307,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23216,307,61,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23216,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23216,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23216,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23216,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23216,601,91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23216,605,0.557,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23216,606,4.311,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23217,203,20.38,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23217,204,11.71,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23217,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23217,207,0.92,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23217,208,187,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23217,255,67.25,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23217,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23217,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23217,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23217,303,1.71,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23217,306,262,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23217,307,64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23217,320,4,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23217,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23217,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23217,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23217,601,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23217,605,0.628,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23217,606,4.626,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23218,203,20.06,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23218,204,12.78,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23218,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23218,207,0.91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23218,208,195,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23218,255,66.55,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23218,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23218,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23218,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23218,303,1.7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23218,306,254,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23218,307,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23218,320,4,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23218,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23218,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23218,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23218,601,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23218,605,0.685,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23218,606,5.034,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23219,203,20.87,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23219,204,10.11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23219,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23219,207,0.94,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23219,208,174,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23219,255,68.31,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23219,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23219,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23219,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23219,303,1.73,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23219,306,283,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23219,307,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23219,320,4,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23219,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23219,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23219,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23219,601,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23219,605,0.543,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23219,606,4.014,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23220,203,25.07,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23220,204,14.53,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23220,205,0.62,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23220,207,1.09,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23220,208,240,'100g',3,1,'2012-03-02','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23220,255,58.69,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23220,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23220,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23220,301,25,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23220,303,2.67,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23220,306,353,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23220,307,85,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23220,320,7,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23220,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23220,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23220,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23220,601,84,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23220,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23220,606,5.6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23221,203,27.06,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23221,204,20.47,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23221,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23221,207,1.28,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23221,208,292,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23221,255,51.41,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23221,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23221,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23221,301,8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23221,303,5.09,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23221,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23221,307,70,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23221,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23221,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23221,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23221,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23221,601,102,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23221,605,0.951,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23221,606,7.405,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23222,203,26.46,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23222,204,21.62,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23222,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23222,207,1.26,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23222,208,300,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23222,255,50.82,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23222,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23222,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23222,301,8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23222,303,4.95,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23222,306,282,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23222,307,70,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23222,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23222,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23222,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23222,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23222,601,104,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23222,605,1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23222,606,7.733,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23223,203,27.95,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23223,204,18.75,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23223,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23223,207,1.31,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23223,208,281,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23223,255,52.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23223,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23223,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23223,301,8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23223,303,5.33,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23223,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23223,307,69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23223,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23223,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23223,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23223,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23223,601,98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23223,605,0.877,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23223,606,6.911,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23224,203,17.98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23224,204,17.59,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23224,205,0.35,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23224,207,0.91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23224,208,232,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23224,255,63.17,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23224,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23224,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23224,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23224,303,3.42,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23224,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23224,307,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23224,320,4,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23224,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23224,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23224,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23224,601,71,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23224,605,0.987,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23224,606,7.138,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23225,203,17.69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23225,204,18.44,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23225,205,0.35,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23225,207,0.88,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23225,208,238,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23225,255,62.64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23225,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23225,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23225,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23225,303,3.35,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23225,306,240,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23225,307,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23225,320,4,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23225,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23225,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23225,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23225,601,71,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23225,605,1.028,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23225,606,7.426,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23226,203,18.43,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23226,204,16.31,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23226,205,0.36,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23226,207,0.94,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23226,208,222,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23226,255,63.96,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23226,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23226,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23226,301,6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23226,303,3.63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23226,306,251,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23226,307,63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23226,320,5,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23226,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23226,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23226,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23226,601,70,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23226,605,0.924,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23226,606,6.705,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23227,203,24.85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23227,204,19.02,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23227,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23227,207,0.99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23227,208,271,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23227,255,55.59,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23227,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23227,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23227,301,12,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23227,303,2.4,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23227,306,279,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23227,307,58,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23227,320,7,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23227,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23227,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23227,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23227,601,78,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23227,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23227,606,8.443,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23228,203,23.89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23228,204,21.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23228,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23228,207,0.95,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23228,208,285,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23228,255,54.37,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23228,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23228,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23228,301,12,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23228,303,2.49,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23228,306,264,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23228,307,58,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23228,320,7,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23228,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23228,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23228,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23228,601,80,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23228,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23228,606,9.244,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23229,203,26.29,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23229,204,15.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23229,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23229,207,1.05,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23229,208,248,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23229,255,57.42,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23229,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23229,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23229,301,10,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23229,303,2.28,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23229,306,301,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23229,307,58,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23229,320,8,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23229,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23229,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23229,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23229,601,77,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23229,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23229,606,7.226,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23230,203,19.26,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23230,204,16.71,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23230,205,0.12,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23230,207,0.88,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23230,208,228,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23230,255,63.02,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23230,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23230,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23230,301,8,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23230,303,1.81,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23230,306,246,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23230,307,52,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23230,320,4,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23230,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23230,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23230,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23230,601,68,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23230,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23230,606,7.363,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23231,203,18.69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23231,204,18.43,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23231,205,0.2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23231,207,0.87,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23231,208,241,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23231,255,61.82,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23231,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23231,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23231,301,8,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23231,303,1.86,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23231,306,231,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23231,307,51,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23231,320,4,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23231,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23231,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23231,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23231,601,66,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23231,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23231,606,8.074,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23232,203,20.12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23232,204,14.14,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23232,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23232,207,0.91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23232,208,208,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23232,255,64.83,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23232,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23232,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23232,301,7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23232,303,1.72,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23232,306,268,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23232,307,52,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23232,320,5,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23232,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23232,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23232,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23232,601,61,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23232,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23232,606,6.29,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23233,203,24.23,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23233,204,29.21,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23233,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23233,207,0.62,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23233,208,360,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23233,255,46.49,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23233,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23233,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23233,301,23,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23233,303,2.4,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23233,306,255,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23233,307,63,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23233,320,9,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23233,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23233,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23233,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23233,601,87,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23233,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23233,606,12.99,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23234,203,23.34,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23234,204,30.95,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23234,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23234,207,0.59,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23234,208,372,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23234,255,45.56,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23234,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23234,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23234,301,23,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23234,303,2.34,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23234,306,248,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23234,307,61,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23234,320,9,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23234,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23234,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23234,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23234,601,88,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23234,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23234,606,13.77,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23235,203,25.56,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23235,204,26.59,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23235,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23235,207,0.67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23235,208,341,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23235,255,47.88,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23235,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23235,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23235,301,24,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23235,303,2.49,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23235,306,267,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23235,307,64,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23235,320,9,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23235,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23235,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23235,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23235,601,85,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23235,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23235,606,11.822,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23236,203,16.15,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23236,204,28.42,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23236,205,0.78,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23236,207,0.73,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23236,208,324,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23236,255,53.91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23236,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23236,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23236,301,10,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23236,303,1.63,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23236,306,218,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23236,307,53,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23236,320,6,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23236,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23236,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23236,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23236,601,75,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23236,605,1.881,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23236,606,12.643,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23237,203,15.75,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23237,204,29.89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23237,205,0.9,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23237,207,0.72,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23237,208,336,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23237,255,52.74,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23237,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23237,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23237,301,9,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23237,303,1.61,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23237,306,214,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23237,307,53,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23237,320,6,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23237,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23237,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23237,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23237,601,76,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23237,605,1.949,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23237,606,13.296,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23238,203,16.75,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23238,204,26.23,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23238,205,0.6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23238,207,0.75,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23238,208,305,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23238,255,55.67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23238,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23238,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23238,301,10,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23238,303,1.66,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23238,306,224,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23238,307,52,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23238,320,6,'100g',2,1,'2024-12-12','2011-01-06');
INSERT INTO `cndb_nutval` VALUES (23238,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23238,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23238,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23238,601,73,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23238,605,1.779,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23238,606,11.663,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23239,203,28.97,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23239,204,6.37,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23239,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23239,207,1.11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23239,208,173,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23239,255,63.64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23239,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23239,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23239,301,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23239,303,2.77,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23239,306,379,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23239,307,57,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23239,320,1,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23239,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23239,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23239,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23239,601,88,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23239,605,0.32,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23239,606,1.994,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23240,203,23.03,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23240,204,4.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23240,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23240,207,1.04,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23240,208,132,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23240,255,72.28,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23240,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23240,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23240,301,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23240,303,2.23,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23240,306,395,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23240,307,65,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23240,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23240,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23240,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23240,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23240,601,68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23240,605,0.189,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23240,606,1.392,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23241,203,28.26,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23241,204,7.23,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23241,205,0.73,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23241,207,1.17,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23241,208,181,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23241,255,62.62,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23241,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23241,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23241,301,17,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23241,303,2.02,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23241,306,371,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23241,307,62,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23241,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23241,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23241,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23241,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23241,601,84,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23241,605,0.348,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23241,606,2.653,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23242,203,28.19,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23242,204,7.96,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23242,205,1.07,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23242,207,1.14,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23242,208,189,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23242,255,61.65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23242,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23242,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23242,301,17,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23242,303,2.04,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23242,306,374,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23242,307,62,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23242,320,1,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23242,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23242,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23242,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23242,601,83,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23242,605,0.4,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23242,606,2.905,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23243,203,28.36,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23243,204,6.14,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23243,205,0.22,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23243,207,1.21,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23243,208,170,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23243,255,64.07,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23243,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23243,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23243,301,21,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23243,303,1.82,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23243,306,389,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23243,307,63,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23243,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23243,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23243,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23243,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23243,601,85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23243,605,0.27,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23243,606,2.275,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23244,203,21.38,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23244,204,5.36,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23244,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23244,207,0.98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23244,208,134,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23244,255,72.93,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23244,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23244,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23244,301,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23244,303,2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23244,306,375,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23244,307,55,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23244,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23244,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23244,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23244,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23244,601,67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23244,605,0.253,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23244,606,1.875,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23245,203,21.34,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23245,204,5.82,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23245,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23245,207,0.99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23245,208,138,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23245,255,72.52,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23245,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23245,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23245,301,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23245,303,2.08,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23245,306,367,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23245,307,60,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23245,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23245,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23245,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23245,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23245,601,67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23245,605,0.257,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23245,606,2.08,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23246,203,21.44,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23246,204,4.68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23246,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23246,207,0.98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23246,208,128,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23246,255,73.56,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23246,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23246,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23246,301,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23246,303,1.98,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23246,306,355,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23246,307,52,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23246,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23246,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23246,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23246,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23246,601,67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23246,605,0.248,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23246,606,1.568,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23247,203,29.33,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23247,204,8.54,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23247,205,0.3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23247,207,1.16,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23247,208,195,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23247,255,60.67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23247,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23247,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23247,301,17,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23247,303,2.06,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23247,306,377,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23247,307,63,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23247,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23247,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23247,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23247,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23247,601,86,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23247,605,0.34,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23247,606,2.987,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23248,203,28.99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23248,204,9.48,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23248,205,0.36,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23248,207,1.17,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23248,208,203,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23248,255,60,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23248,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23248,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23248,301,17,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23248,303,2.04,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23248,306,374,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23248,307,62,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23248,320,1,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23248,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23248,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23248,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23248,601,85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23248,605,0.363,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23248,606,3.361,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23249,203,29.85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23249,204,7.12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23249,205,0.2,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23249,207,1.15,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23249,208,184,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23249,255,61.68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23249,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23249,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23249,301,22,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23249,303,1.91,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23249,306,407,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23249,307,65,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23249,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23249,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23249,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23249,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23249,601,87,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23249,605,0.307,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23249,606,2.425,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23250,203,28.33,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23250,204,8.76,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23250,205,0.82,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23250,207,1.17,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23250,208,195,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23250,255,60.91,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23250,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23250,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23250,301,17,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23250,303,2.02,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23250,306,371,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23250,307,62,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23250,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23250,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23250,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23250,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23250,601,81,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23250,605,0.444,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23250,606,3.014,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23251,203,28.24,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23251,204,9.97,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23251,205,0.88,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23251,207,1.18,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23251,208,206,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23251,255,59.74,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23251,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23251,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23251,301,17,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23251,303,2.02,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23251,306,371,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23251,307,62,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23251,320,1,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23251,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23251,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23251,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23251,601,79,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23251,605,0.502,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23251,606,3.498,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23252,203,28.48,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23252,204,6.95,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23252,205,0.74,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23252,207,1.15,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23252,208,179,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23252,255,62.67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23252,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23252,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23252,301,22,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23252,303,1.85,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23252,306,396,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23252,307,64,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23252,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23252,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23252,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23252,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23252,601,85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23252,605,0.356,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23252,606,2.29,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23253,203,22.61,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23253,204,5.84,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23253,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23253,207,1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23253,208,143,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23253,255,70.59,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23253,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23253,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23253,301,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23253,303,2.17,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23253,306,407,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23253,307,60,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23253,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23253,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23253,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23253,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23253,601,69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23253,605,0.213,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23253,606,2.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23254,203,22.5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23254,204,6.48,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23254,205,0.23,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23254,207,1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23254,208,149,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23254,255,69.79,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23254,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23254,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23254,301,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23254,303,2.27,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23254,306,402,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23254,307,66,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23254,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23254,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23254,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23254,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23254,601,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23254,605,0.256,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23254,606,2.419,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23255,203,22.77,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23255,204,4.88,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23255,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23255,207,1.01,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23255,208,135,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23255,255,71.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23255,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23255,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23255,301,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23255,303,2.39,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23255,306,387,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23255,307,57,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23255,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23255,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23255,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23255,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23255,601,76,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23255,605,0.149,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23255,606,1.621,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23256,203,30.58,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23256,204,5.37,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23256,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23256,207,1.31,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23256,208,171,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23256,255,62.92,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23256,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23256,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23256,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23256,303,2.9,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23256,306,397,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23256,307,59,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23256,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23256,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23256,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23256,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23256,601,79,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23256,605,0.282,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23256,606,1.803,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23257,203,30.45,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23257,204,5.83,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23257,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23257,207,1.32,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23257,208,174,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23257,255,62.57,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23257,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23257,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23257,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23257,303,2.89,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23257,306,395,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23257,307,59,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23257,320,1,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23257,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23257,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23257,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23257,601,81,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23257,605,0.288,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23257,606,1.978,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23258,203,30.78,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23258,204,4.68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23258,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23258,207,1.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23258,208,165,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23258,255,63.44,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23258,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23258,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23258,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23258,303,3.19,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23258,306,390,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23258,307,56,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23258,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23258,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23258,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23258,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23258,601,74,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23258,605,0.272,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23258,606,1.541,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23259,203,29.12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23259,204,5.92,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23259,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23259,207,1.12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23259,208,170,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23259,255,63.93,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23259,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23259,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23259,301,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23259,303,2.75,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23259,306,377,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23259,307,57,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23259,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23259,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23259,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23259,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23259,601,86,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23259,605,0.275,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23259,606,1.742,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23260,203,29.35,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23260,204,5.25,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23260,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23260,207,1.12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23260,208,165,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23260,255,64.36,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23260,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23260,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23260,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23260,303,2.75,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23260,306,426,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23260,307,58,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23260,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23260,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23260,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23260,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23260,601,84,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23260,605,0.206,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23260,606,1.364,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23261,203,23.04,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23261,204,3.98,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23261,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23261,207,1.06,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23261,208,128,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23261,255,72.67,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23261,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23261,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23261,301,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23261,303,2.24,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23261,306,395,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23261,307,65,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23261,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23261,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23261,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23261,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23261,601,69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23261,605,0.176,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23261,606,1.285,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23262,203,23.05,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23262,204,3.35,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23262,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23262,207,1.07,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23262,208,122,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23262,255,73.27,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23262,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23262,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23262,301,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23262,303,2.39,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23262,306,388,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23262,307,58,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23262,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23262,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23262,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23262,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23262,601,69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23262,605,0.157,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23262,606,1.125,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23263,203,22.66,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23263,204,4.66,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23263,205,0.04,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23263,207,1.06,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23263,208,133,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23263,255,71.57,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23263,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23263,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23263,301,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23263,303,2.28,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23263,306,402,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23263,307,66,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23263,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23263,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23263,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23263,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23263,601,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23263,605,0.215,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23263,606,1.683,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23264,203,22.52,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23264,204,5.29,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23264,205,0.18,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23264,207,1.03,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23264,208,138,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23264,255,70.99,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23264,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23264,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23264,301,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23264,303,2.27,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23264,306,401,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23264,307,66,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23264,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23264,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23264,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23264,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23264,601,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23264,605,0.233,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23264,606,1.962,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23265,203,22.89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23265,204,3.72,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23265,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23265,207,1.11,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23265,208,125,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23265,255,72.46,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23265,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23265,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23265,301,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23265,303,2.17,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23265,306,389,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23265,307,57,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23265,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23265,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23265,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23265,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23265,601,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23265,605,0.188,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23265,606,1.265,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23266,203,24.66,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23266,204,15.7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23266,205,1.53,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23266,207,0.94,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23266,208,246,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23266,255,57.18,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23266,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23266,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23266,301,7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23266,303,3.07,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23266,306,351,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23266,307,86,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23266,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23266,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23266,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23266,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23266,601,76,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23266,605,0.582,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23266,606,5.566,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23267,203,24.24,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23267,204,17.21,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23267,205,1.81,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23267,207,0.95,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23267,208,259,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23267,255,55.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23267,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23267,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23267,301,7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23267,303,3.06,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23267,306,349,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23267,307,86,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23267,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23267,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23267,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23267,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23267,601,78,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23267,605,0.622,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23267,606,5.961,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23268,203,25.28,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23268,204,13.43,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23268,205,1.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23268,207,0.93,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23268,208,226,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23268,255,59.26,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23268,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23268,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23268,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23268,303,3.22,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23268,306,346,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23268,307,79,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23268,320,2,'100g',2,1,'2024-12-12','2011-01-10');
INSERT INTO `cndb_nutval` VALUES (23268,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23268,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23268,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23268,601,73,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23268,605,0.522,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23268,606,4.974,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23269,203,19.7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23269,204,10.6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23269,205,1.51,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23269,207,0.89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23269,208,180,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23269,255,67.31,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23269,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23269,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23269,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23269,303,2.64,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23269,306,357,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23269,307,88,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23269,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23269,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23269,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23269,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23269,601,64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23269,605,0.45,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23269,606,4.066,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23270,203,19.46,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23270,204,11.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23270,205,1.75,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23270,207,0.89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23270,208,187,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23270,255,66.5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23270,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23270,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23270,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23270,303,2.64,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23270,306,357,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23270,307,88,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23270,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23270,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23270,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23270,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23270,601,64,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23270,605,0.48,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23270,606,4.359,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23271,203,20.05,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23271,204,9.39,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23271,205,1.15,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23271,207,0.88,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23271,208,169,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23271,255,68.53,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23271,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23271,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23271,301,7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23271,303,2.95,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23271,306,365,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23271,307,84,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23271,320,2,'100g',2,1,'2024-12-12','2011-01-10');
INSERT INTO `cndb_nutval` VALUES (23271,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23271,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23271,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23271,601,63,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23271,605,0.405,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23271,606,3.626,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23272,203,28.77,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23272,204,9.2,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23272,205,0.17,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23272,207,1.12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23272,208,199,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23272,255,60.74,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23272,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23272,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23272,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23272,303,2.77,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23272,306,410,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23272,307,56,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23272,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23272,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23272,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23272,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23272,601,82,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23272,605,0.398,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23272,606,3.205,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23273,203,28.35,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23273,204,10.26,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23273,205,0.51,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23273,207,1.12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23273,208,208,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23273,255,59.75,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23273,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23273,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23273,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23273,303,2.76,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23273,306,409,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23273,307,56,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23273,320,1,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23273,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23273,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23273,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23273,601,82,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23273,605,0.466,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23273,606,3.616,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23274,203,29.39,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23274,204,7.61,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23274,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23274,207,1.12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23274,208,186,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23274,255,62.22,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23274,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23274,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23274,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23274,303,3.56,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23274,306,383,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23274,307,87,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23274,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23274,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23274,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23274,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23274,601,82,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23274,605,0.295,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23274,606,2.588,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23275,203,28.15,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23275,204,7.31,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23275,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23275,207,1.09,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23275,208,178,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23275,255,63.52,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23275,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23275,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23275,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23275,303,2.68,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23275,306,398,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23275,307,55,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23275,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23275,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23275,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23275,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23275,601,85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23275,605,0.338,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23275,606,2.587,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23276,203,28,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23276,204,8.42,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23276,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23276,207,1.07,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23276,208,188,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23276,255,62.52,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23276,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23276,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23276,301,5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23276,303,2.65,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23276,306,363,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23276,307,54,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23276,320,1,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23276,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23276,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23276,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23276,601,83,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23276,605,0.375,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23276,606,3.053,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23277,203,28.37,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23277,204,5.65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23277,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23277,207,1.12,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23277,208,164,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23277,255,65.02,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23277,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23277,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23277,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23277,303,3.46,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23277,306,372,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23277,307,84,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23277,320,2,'100g',2,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23277,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23277,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23277,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23277,601,89,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23277,605,0.281,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23277,606,1.887,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23278,203,26,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23278,204,15,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23278,205,0.8,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23278,207,1.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23278,208,242,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23278,255,57.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23278,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23278,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23278,301,7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23278,303,3.16,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23278,306,361,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23278,307,89,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23278,320,7,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (23278,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23278,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23278,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23278,601,84,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23278,605,0.704,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23278,606,5.35,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23279,203,26.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23279,204,14.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23279,205,1.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23279,207,1.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23279,208,238,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23279,255,57.2,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23279,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23279,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23279,301,7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23279,303,3.23,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23279,306,368,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23279,307,91,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23279,320,7,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (23279,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23279,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23279,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23279,601,83,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23279,605,0.685,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23279,606,5.092,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23280,203,25.5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23280,204,16.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23280,205,0.4,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23280,207,1.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23280,208,249,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23280,255,56.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23280,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23280,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23280,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23280,303,3.19,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23280,306,342,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23280,307,78,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23280,320,8,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (23280,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23280,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23280,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23280,601,85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23280,605,0.731,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23280,606,5.737,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23281,203,19.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23281,204,12.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23281,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23281,207,0.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23281,208,191,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23281,255,67.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23281,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23281,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23281,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23281,303,2.41,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23281,306,326,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23281,307,80,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23281,320,4,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (23281,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23281,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23281,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23281,601,68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23281,605,0.755,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23281,606,4.619,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23282,203,19.7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23282,204,13.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23282,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23282,207,0.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23282,208,199,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23282,255,66.5,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23282,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23282,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23282,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23282,303,2.4,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23282,306,325,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23282,307,80,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23282,320,4,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (23282,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23282,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23282,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23282,601,68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23282,605,0.809,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23282,606,5.079,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23283,203,20.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23283,204,10.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23283,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23283,207,0.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23283,208,179,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23283,255,68.6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23283,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23283,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23283,301,7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23283,303,2.74,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23283,306,339,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23283,307,78,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23283,320,4,'100g',2,1,'2024-12-12','2011-01-10');
INSERT INTO `cndb_nutval` VALUES (23283,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23283,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23283,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23283,601,68,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23283,605,0.673,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23283,606,3.93,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23284,203,27.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23284,204,14.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23284,205,0.6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23284,207,1.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23284,208,239,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23284,255,56.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23284,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23284,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23284,301,7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23284,303,3.3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23284,306,376,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23284,307,93,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23284,320,7,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (23284,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23284,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23284,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23284,601,86,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23284,605,0.698,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23284,606,4.817,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23285,203,26.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23285,204,15.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23285,205,0.6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23285,207,1.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23285,208,253,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23285,255,55.6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23285,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23285,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23285,301,7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23285,303,3.23,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23285,306,368,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23285,307,91,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23285,320,7,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (23285,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23285,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23285,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23285,601,85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23285,605,0.776,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23285,606,5.454,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23286,203,28.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23286,204,11.6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23286,205,0.4,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23286,207,1.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23286,208,219,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23286,255,58.6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23286,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23286,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23286,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23286,303,3.52,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23286,306,378,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23286,307,86,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23286,320,7,'100g',2,1,'2024-12-12','2011-01-10');
INSERT INTO `cndb_nutval` VALUES (23286,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23286,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23286,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23286,601,87,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23286,605,0.581,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23286,606,3.862,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23287,203,27,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23287,204,12.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23287,205,1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23287,207,1.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23287,208,228,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23287,255,58,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23287,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23287,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23287,301,7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23287,303,3.3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23287,306,376,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23287,307,93,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23287,320,7,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (23287,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23287,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23287,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23287,601,82,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23287,605,0.7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23287,606,4.361,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23288,203,26.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23288,204,14.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23288,205,1.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23288,207,1.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23288,208,239,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23288,255,56.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23288,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23288,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23288,301,7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23288,303,3.29,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23288,306,375,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23288,307,92,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23288,320,7,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (23288,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23288,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23288,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23288,601,80,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23288,605,0.757,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23288,606,4.824,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23289,203,27.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23289,204,11.2,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23289,205,0.9,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23289,207,1.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23289,208,213,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23289,255,59.7,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23289,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23289,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23289,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23289,303,3.43,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23289,306,369,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23289,307,84,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23289,320,7,'100g',2,1,'2024-12-12','2011-01-10');
INSERT INTO `cndb_nutval` VALUES (23289,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23289,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23289,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23289,601,85,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23289,605,0.614,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23289,606,3.666,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23290,203,21.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23290,204,11.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23290,205,0.3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23290,207,0.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23290,208,187,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23290,255,66.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23290,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23290,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23290,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23290,303,2.66,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23290,306,360,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23290,307,89,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23290,320,4,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (23290,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23290,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23290,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23290,601,69,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23290,605,0.602,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23290,606,3.547,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23291,203,20.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23291,204,12.6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23291,205,0.6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23291,207,0.9,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23291,208,199,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23291,255,65.1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23291,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23291,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23291,301,6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23291,303,2.66,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23291,306,360,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23291,307,89,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23291,320,4,'100g',2,1,'2024-12-12','2011-01-08');
INSERT INTO `cndb_nutval` VALUES (23291,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23291,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23291,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23291,601,65,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23291,605,0.697,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23291,606,4.043,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23292,203,21.6,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23292,204,9.3,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23292,205,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23292,207,1,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23292,208,170,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23292,255,68.4,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23292,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23292,291,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23292,301,7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23292,303,2.98,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23292,306,369,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23292,307,85,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23292,320,4,'100g',2,1,'2024-12-12','2011-01-10');
INSERT INTO `cndb_nutval` VALUES (23292,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23292,401,0,'100g',4,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23292,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23292,601,76,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23292,605,0.461,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23292,606,2.803,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (23293,203,17.72,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23293,204,18.12,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23293,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23293,207,0.82,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23293,208,239,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23293,255,63.56,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23293,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23293,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23293,301,6,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23293,303,1.79,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23293,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23293,307,62,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23293,320,0,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23293,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23293,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23293,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23293,601,66,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23293,605,0.906,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23293,606,7.938,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23294,203,20.85,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23294,204,6.11,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23294,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23294,207,1.08,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23294,208,138,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23294,255,72.42,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23294,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23294,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23294,301,4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23294,303,2.25,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23294,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23294,307,63,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23294,320,0,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23294,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23294,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23294,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23294,601,49,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23294,605,0.264,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23294,606,2.725,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23295,203,20.19,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23295,204,12.3,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23295,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23295,207,1.04,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23295,208,191,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23295,255,66.47,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23295,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23295,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23295,301,4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23295,303,2.24,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23295,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23295,307,64,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23295,320,0,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23295,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23295,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23295,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23295,601,59,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23295,605,0.464,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23295,606,5.507,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23296,203,11.32,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23296,204,51.36,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23296,205,0.39,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23296,207,0.42,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23296,208,509,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23296,255,36.51,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23296,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23296,291,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23296,301,6,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23296,303,0.95,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23296,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23296,307,36,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23296,320,36,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23296,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23296,401,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23296,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23296,601,66,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23296,605,2.763,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23296,606,22.65,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23297,203,9.58,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23297,204,57.73,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23297,205,1.06,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23297,207,0.44,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23297,208,562,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23297,255,31.2,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23297,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23297,291,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23297,301,3,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23297,303,0.89,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23297,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23297,307,34,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23297,320,36,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23297,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23297,401,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23297,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23297,601,65,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23297,605,3.209,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23297,606,26.584,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23298,203,6.54,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23298,204,63.27,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23298,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23298,207,0.4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23298,208,596,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23298,255,30.25,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23298,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23298,291,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23298,301,2,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23298,303,1,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23298,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23298,307,37,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23298,320,22,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23298,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23298,401,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23298,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23298,601,73,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23298,605,3.304,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23298,606,22.504,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23299,203,6,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23299,204,63.3,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23299,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23299,207,0.32,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23299,208,594,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23299,255,30.44,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23299,269,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23299,291,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23299,301,2,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23299,303,0.97,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23299,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23299,307,32,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23299,320,22,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23299,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23299,401,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23299,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23299,601,95,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23299,605,3.398,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23299,606,23.155,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23300,203,5.54,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23300,204,68.07,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23300,205,0.97,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23300,207,0.25,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23300,208,639,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23300,255,25.17,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23300,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23300,291,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23300,301,4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23300,303,0.81,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23300,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23300,307,43,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23300,320,22,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23300,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23300,401,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23300,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23300,601,95,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23300,605,2.842,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23300,606,22.395,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23301,203,5.16,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23301,204,67.33,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23301,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23301,207,0.22,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23301,208,627,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23301,255,28.13,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23301,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23301,291,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23301,301,2,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23301,303,0.91,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23301,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23301,307,27,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23301,320,22,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23301,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23301,401,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23301,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23301,601,96,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23301,605,3.028,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23301,606,22.467,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23302,203,20.53,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23302,204,7.63,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23302,205,0.01,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23302,207,1.06,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23302,208,151,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23302,255,71.21,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23302,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23302,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23302,301,4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23302,303,2.21,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23302,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23302,307,62,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23302,320,1,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23302,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23302,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23302,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23302,601,50,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23302,605,0.347,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23302,606,3.393,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23303,203,21.79,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23303,204,4.87,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23303,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23303,207,1.01,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23303,208,131,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23303,255,72.95,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23303,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23303,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23303,301,5,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23303,303,1.57,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23303,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23303,307,66,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23303,320,0,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23303,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23303,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23303,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23303,601,41,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23303,605,0.164,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23303,606,2.09,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23304,203,19.71,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23304,204,14.09,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23304,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23304,207,1.02,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23304,208,206,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23304,255,65.2,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23304,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23304,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23304,301,4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23304,303,2.2,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23304,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23304,307,63,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23304,320,1,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23304,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23304,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23304,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23304,601,60,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23304,605,0.564,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23304,606,6.105,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23305,203,19.9,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23305,204,13.17,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23305,205,0.11,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23305,207,0.91,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23305,208,199,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23305,255,66.42,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23305,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23305,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23305,301,5,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23305,303,1.46,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23305,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23305,307,60,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23305,320,6,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23305,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23305,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23305,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23305,601,46,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23305,605,0.634,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23305,606,5.837,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23306,203,21.9,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23306,204,3.87,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23306,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23306,207,1.11,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23306,208,122,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23306,255,74.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23306,269,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23306,291,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23306,301,5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23306,303,2.53,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23306,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23306,307,60,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23306,320,0,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23306,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23306,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23306,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23306,601,54,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23306,605,0.126,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23306,606,1.601,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23307,203,21.47,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23307,204,8.2,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23307,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23307,207,0.96,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23307,208,160,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23307,255,70.09,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23307,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23307,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23307,301,5,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23307,303,1.88,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23307,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23307,307,65,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23307,320,0,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23307,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23307,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23307,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23307,601,50,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23307,605,0.292,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23307,606,3.596,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23308,203,21.4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23308,204,4.93,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23308,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23308,207,1.06,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23308,208,130,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23308,255,73.31,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23308,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23308,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23308,301,4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23308,303,2.11,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23308,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23308,307,71,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23308,320,0,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23308,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23308,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23308,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23308,601,54,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23308,605,0.179,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23308,606,1.959,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23309,203,22.41,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23309,204,4.43,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23309,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23309,207,1.09,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23309,208,129,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23309,255,73.05,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23309,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23309,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23309,301,5,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23309,303,2.3,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23309,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23309,307,60,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23309,320,0,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23309,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23309,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23309,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23309,601,48,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23309,605,0.141,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23309,606,1.783,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23310,203,18.87,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23310,204,17.73,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23310,205,0.57,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23310,207,0.93,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23310,208,237,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23310,255,61.91,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23310,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23310,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23310,301,4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23310,303,2.41,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23310,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23310,307,62,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23310,320,0,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23310,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23310,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23310,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23310,601,74,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23310,605,0.645,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23310,606,7.377,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23311,203,20.15,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23311,204,15.69,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23311,205,0.2,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23311,207,0.89,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23311,208,223,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23311,255,63.07,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23311,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23311,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23311,301,4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23311,303,1.85,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23311,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23311,307,61,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23311,320,0,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23311,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23311,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23311,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23311,601,58,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23311,605,0.524,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23311,606,5.909,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23312,203,16.92,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23312,204,29.15,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23312,205,0.13,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23312,207,0.71,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23312,208,331,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23312,255,53.09,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23312,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23312,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23312,301,4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23312,303,1.71,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23312,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23312,307,68,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23312,320,0,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23312,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23312,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23312,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23312,601,61,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23312,605,0.891,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23312,606,10.309,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23313,203,20.35,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23313,204,16.93,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23313,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23313,207,0.91,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23313,208,234,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23313,255,61.92,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23313,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23313,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23313,301,4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23313,303,1.89,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23313,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23313,307,58,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23313,320,0,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23313,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23313,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23313,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23313,601,72,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23313,605,0.758,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23313,606,6.536,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23314,203,17.61,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23314,204,28.61,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23314,205,0.46,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23314,207,0.73,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23314,208,330,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23314,255,52.58,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23314,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23314,291,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23314,301,4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23314,303,2.14,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23314,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23314,307,65,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23314,320,0,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23314,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23314,401,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23314,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23314,601,77,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23314,605,0.911,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23314,606,11.123,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23315,203,21.77,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23315,204,4.45,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23315,205,0.01,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23315,207,1.1,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23315,208,127,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23315,255,73.65,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23315,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23315,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23315,301,5,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23315,303,2.51,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23315,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23315,307,59,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23315,320,0,'100g',1,1,'2024-12-12','2012-01-10');
INSERT INTO `cndb_nutval` VALUES (23315,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23315,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23315,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23315,601,55,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23315,605,0.158,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23315,606,1.859,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23316,203,19.8,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23316,204,15.21,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23316,205,0.11,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23316,207,0.88,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23316,208,217,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23316,255,64.6,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23316,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23316,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23316,301,5,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23316,303,1.74,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23316,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23316,307,60,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23316,320,5,'100g',2,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23316,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23316,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23316,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23316,601,52,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23316,605,0.7,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23316,606,6.782,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23317,203,21.13,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23317,204,6.16,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23317,205,0.01,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23317,207,1.04,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23317,208,140,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23317,255,72.33,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23317,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23317,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23317,301,5,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23317,303,2.08,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23317,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23317,307,70,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23317,320,1,'100g',2,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23317,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23317,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23317,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23317,601,55,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23317,605,0.248,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23317,606,2.51,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23318,203,22.24,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23318,204,4.4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23318,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23318,207,1.09,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23318,208,129,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23318,255,72.52,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23318,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23318,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23318,301,5,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23318,303,2.28,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23318,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23318,307,59,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23318,320,0,'100g',2,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23318,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23318,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23318,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23318,601,47,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23318,605,0.14,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23318,606,1.77,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23319,203,17.67,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23319,204,24.2,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23319,205,0.12,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23319,207,0.8,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23319,208,289,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23319,255,57.21,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23319,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23319,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23319,301,4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23319,303,1.69,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23319,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23319,307,56,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23319,320,4,'100g',2,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23319,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23319,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23319,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23319,601,63,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23319,605,1.028,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23319,606,8.928,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23320,203,14.58,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23320,204,36.98,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23320,205,0.14,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23320,207,0.61,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23320,208,392,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23320,255,47.68,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23320,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23320,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23320,301,4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23320,303,1.54,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23320,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23320,307,61,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23320,320,4,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23320,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23320,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23320,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23320,601,68,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23320,605,1.302,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23320,606,12.765,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23321,203,17.07,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23321,204,27.64,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23321,205,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23321,207,0.78,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23321,208,317,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23321,255,54.63,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23321,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23321,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23321,301,4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23321,303,1.68,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23321,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23321,307,52,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23321,320,5,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23321,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23321,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23321,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23321,601,76,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23321,605,1.361,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23321,606,10.329,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23322,203,14.54,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23322,204,38.3,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23322,205,0.28,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23322,207,0.61,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23322,208,404,'100g',3,1,'2013-02-22','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23322,255,46.27,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23322,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23322,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23322,301,3,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23322,303,1.82,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23322,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23322,307,57,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23322,320,6,'100g',1,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23322,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23322,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23322,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23322,601,82,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23322,605,1.423,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23322,606,13.942,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23323,203,18.5,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23323,204,19.11,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23323,205,0.58,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23323,207,0.91,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23323,208,248,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23323,255,60.9,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23323,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23323,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23323,301,4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23323,303,2.37,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23323,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23323,307,61,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23323,320,1,'100g',2,1,'2024-12-12','2012-01-04');
INSERT INTO `cndb_nutval` VALUES (23323,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23323,401,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23323,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23323,601,74,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (23323,605,0.705,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23323,606,7.788,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23324,203,23.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23324,204,3.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23324,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23324,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23324,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23324,255,72.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23324,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23324,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23324,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23324,303,2.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23324,306,312,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23324,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23324,320,3,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23324,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23324,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23324,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23324,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23324,605,0.163,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23324,606,1.287,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23325,203,23.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23325,204,3.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23325,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23325,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23325,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23325,255,72.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23325,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23325,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23325,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23325,303,2.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23325,306,307,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23325,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23325,320,3,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23325,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23325,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23325,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23325,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23325,605,0.171,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23325,606,1.424,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23326,203,23.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23326,204,2.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23326,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23326,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23326,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23326,255,73.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23326,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23326,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23326,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23326,303,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23326,306,314,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23326,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23326,320,3,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23326,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23326,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23326,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23326,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23326,605,0.152,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23326,606,1.082,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23327,203,23.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23327,204,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23327,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23327,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23327,208,125,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23327,255,72.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23327,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23327,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23327,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23327,303,2.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23327,306,311,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23327,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23327,320,3,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23327,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23327,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23327,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23327,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23327,605,0.173,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23327,606,1.353,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23328,203,23.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23328,204,3.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23328,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23328,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23328,208,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23328,255,72.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23328,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23328,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23328,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23328,303,2.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23328,306,306,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23328,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23328,320,3,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23328,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23328,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23328,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23328,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23328,605,0.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23328,606,1.488,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23329,203,23.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23329,204,3.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23329,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23329,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23329,208,121,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23329,255,72.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23329,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23329,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23329,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23329,303,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23329,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23329,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23329,320,3,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23329,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23329,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23329,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23329,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23329,605,0.163,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23329,606,1.151,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23330,203,23.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23330,204,3.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23330,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23330,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23330,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23330,255,73.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23330,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23330,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23330,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23330,303,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23330,306,317,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23330,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23330,320,3,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23330,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23330,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23330,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23330,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23330,605,0.169,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23330,606,1.276,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23331,203,23.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23331,204,3.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23331,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23331,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23331,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23331,255,72.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23331,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23331,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23331,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23331,303,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23331,306,323,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23331,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23331,320,3,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23331,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23331,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23331,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23331,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23331,605,0.169,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23331,606,1.308,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23332,203,23.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23332,204,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23332,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23332,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23332,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23332,255,73.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23332,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23332,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23332,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23332,303,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23332,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23332,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23332,320,5,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23332,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23332,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23332,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23332,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23332,605,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23332,606,1.229,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23333,203,23.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23333,204,3.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23333,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23333,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23333,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23333,255,73.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23333,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23333,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23333,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23333,303,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23333,306,317,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23333,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23333,320,3,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23333,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23333,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23333,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23333,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23333,605,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23333,606,1.285,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23334,203,23.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23334,204,3.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23334,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23334,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23334,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23334,255,72.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23334,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23334,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23334,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23334,303,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23334,306,322,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23334,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23334,320,3,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23334,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23334,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23334,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23334,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23334,605,0.174,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23334,606,1.343,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23335,203,23.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23335,204,2.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23335,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23335,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23335,208,120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23335,255,73.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23335,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23335,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23335,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23335,303,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23335,306,310,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23335,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23335,320,5,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23335,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23335,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23335,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23335,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23335,605,0.165,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23335,606,1.199,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23336,203,21.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23336,204,6.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23336,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23336,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23336,208,149,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23336,255,71.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23336,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23336,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23336,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23336,303,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23336,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23336,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23336,320,5,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23336,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23336,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23336,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23336,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23336,605,0.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23336,606,2.479,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23337,203,21.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23337,204,7.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23337,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23337,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23337,208,153,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23337,255,71.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23337,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23337,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23337,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23337,303,2.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23337,306,279,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23337,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23337,320,3,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23337,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23337,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23337,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23337,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23337,605,0.378,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23337,606,2.687,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23338,203,21.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23338,204,6.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23338,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23338,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23338,208,144,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23338,255,72.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23338,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23338,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23338,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23338,303,2.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23338,306,294,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23338,307,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23338,320,4,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23338,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23338,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23338,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23338,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23338,605,0.309,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23338,606,2.166,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23339,203,22.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23339,204,8.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23339,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23339,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23339,208,163,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23339,255,68.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23339,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23339,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23339,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23339,303,1.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23339,306,273,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23339,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23339,320,4,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23339,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23339,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23339,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23339,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23339,605,0.473,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23339,606,3.478,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23340,203,22.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23340,204,9.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23340,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23340,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23340,208,171,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23340,255,67.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23340,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23340,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23340,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23340,303,1.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23340,306,271,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23340,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23340,320,4,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23340,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23340,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23340,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23340,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23340,605,0.503,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23340,606,3.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23341,203,22.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23341,204,6.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23341,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23341,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23341,208,151,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23341,255,70.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23341,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23341,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23341,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23341,303,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23341,306,279,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23341,307,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23341,320,4,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23341,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23341,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23341,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23341,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23341,605,0.412,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23341,606,2.91,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23342,203,21.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23342,204,6.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23342,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23342,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23342,208,147,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23342,255,71.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23342,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23342,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23342,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23342,303,2.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23342,306,285,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23342,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23342,320,3,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23342,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23342,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23342,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23342,601,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23342,605,0.333,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23342,606,2.363,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23343,203,21.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23343,204,7.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23343,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23343,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23343,208,150,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23343,255,71.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23343,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23343,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23343,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23343,303,2.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23343,306,280,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23343,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23343,320,3,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23343,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23343,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23343,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23343,601,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23343,605,0.357,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23343,606,2.548,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23344,203,21.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23344,204,6.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23344,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23344,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23344,208,142,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23344,255,72.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23344,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23344,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23344,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23344,303,2.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23344,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23344,307,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23344,320,4,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (23344,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23344,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23344,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23344,601,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23344,605,0.297,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23344,606,2.087,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23345,203,27.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23345,204,8.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23345,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23345,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23345,208,183,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23345,255,64.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23345,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23345,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23345,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23345,303,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23345,306,346,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23345,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23345,320,6,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23345,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23345,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23345,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23345,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23345,605,0.446,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23345,606,3.245,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23346,203,27.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23346,204,8.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23346,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23346,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23346,208,188,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23346,255,63.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23346,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23346,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23346,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23346,303,3.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23346,306,347,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23346,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23346,320,6,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23346,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23346,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23346,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23346,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23346,605,0.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23346,606,3.533,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23347,203,27.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23347,204,7.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23347,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23347,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23347,208,174,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23347,255,65.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23347,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23347,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23347,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23347,303,3.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23347,306,349,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23347,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23347,320,8,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23347,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23347,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23347,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23347,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23347,605,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23347,606,2.812,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23348,203,29.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23348,204,4.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23348,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23348,207,1.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23348,208,160,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23348,255,64.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23348,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23348,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23348,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23348,303,2.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23348,306,384,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23348,307,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23348,320,4,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23348,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23348,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23348,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23348,601,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23348,605,0.214,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23348,606,1.671,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23349,203,30.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23349,204,4.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23349,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23349,207,1.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23349,208,163,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23349,255,63.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23349,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23349,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23349,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23349,303,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23349,306,378,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23349,307,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23349,320,4,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23349,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23349,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23349,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23349,601,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23349,605,0.222,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23349,606,1.837,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23350,203,30.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23350,204,3.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23350,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23350,207,1.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23350,208,157,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23350,255,65.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23350,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23350,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23350,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23350,303,2.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23350,306,387,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23350,307,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23350,320,4,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23350,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23350,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23350,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23350,601,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23350,605,0.201,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23350,606,1.421,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23351,203,29.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23351,204,4.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23351,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23351,207,1.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23351,208,159,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23351,255,65.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23351,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23351,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23351,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23351,303,1.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23351,306,411,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23351,307,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23351,320,4,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23351,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23351,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23351,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23351,601,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23351,605,0.221,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23351,606,1.669,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23352,203,29.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23352,204,4.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23352,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23352,207,1.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23352,208,163,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23352,255,64.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23352,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23352,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23352,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23352,303,1.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23352,306,419,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23352,307,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23352,320,4,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (23352,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23352,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23352,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23352,601,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23352,605,0.225,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23352,606,1.744,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23353,203,29.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23353,204,3.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23353,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23353,207,1.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23353,208,154,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23353,255,65.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23353,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23353,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23353,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23353,303,1.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23353,306,402,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23353,307,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23353,320,7,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23353,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23353,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23353,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23353,601,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23353,605,0.215,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23353,606,1.557,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23354,203,23.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23354,204,2.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23354,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23354,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23354,208,121,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23354,255,72.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23354,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23354,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23354,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23354,303,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23354,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23354,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23354,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23354,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23354,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23354,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23354,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23354,605,0.138,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23354,606,1.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23355,203,23.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23355,204,3.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23355,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23355,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23355,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23355,255,72.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23355,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23355,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23355,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23355,303,2.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23355,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23355,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23355,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23355,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23355,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23355,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23355,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23355,605,0.144,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23355,606,1.253,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23356,203,23.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23356,204,2.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23356,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23356,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23356,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23356,255,73.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23356,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23356,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23356,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23356,303,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23356,306,316,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23356,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23356,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23356,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23356,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23356,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23356,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23356,605,0.128,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23356,606,0.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23357,203,23.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23357,204,2.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23357,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23357,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23357,208,121,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23357,255,72.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23357,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23357,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23357,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23357,303,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23357,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23357,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23357,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23357,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23357,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23357,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23357,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23357,605,0.138,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23357,606,1.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23358,203,23.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23358,204,3.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23358,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23358,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23358,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23358,255,72.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23358,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23358,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23358,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23358,303,2.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23358,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23358,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23358,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23358,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23358,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23358,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23358,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23358,605,0.144,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23358,606,1.253,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23359,203,23.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23359,204,2.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23359,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23359,207,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23359,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23359,255,73.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23359,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23359,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23359,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23359,303,2.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23359,306,316,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23359,307,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23359,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23359,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23359,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23359,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23359,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23359,605,0.128,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23359,606,0.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23360,203,23.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23360,204,3.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23360,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23360,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23360,208,121,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23360,255,73.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23360,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23360,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23360,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23360,303,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23360,306,319,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23360,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23360,320,1,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23360,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23360,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23360,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23360,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23360,605,0.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23360,606,1.086,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23361,203,23.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23361,204,3.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23361,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23361,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23361,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23361,255,73.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23361,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23361,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23361,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23361,303,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23361,306,324,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23361,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23361,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23361,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23361,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23361,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23361,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23361,605,0.142,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23361,606,1.137,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23362,203,23.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23362,204,2.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23362,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23362,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23362,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23362,255,73.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23362,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23362,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23362,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23362,303,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23362,306,312,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23362,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23362,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23362,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23362,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23362,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23362,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23362,605,0.137,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23362,606,1.011,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23363,203,23.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23363,204,3.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23363,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23363,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23363,208,121,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23363,255,73.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23363,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23363,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23363,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23363,303,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23363,306,319,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23363,307,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23363,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23363,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23363,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23363,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23363,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23363,605,0.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23363,606,1.086,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23364,203,23.35,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23364,204,3.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23364,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23364,207,1.1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23364,208,124,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23364,255,73.18,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23364,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23364,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23364,301,13,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23364,303,1.47,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23364,306,324,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23364,307,52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23364,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23364,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23364,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23364,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23364,601,58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23364,605,0.142,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23364,606,1.137,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23365,203,23.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23365,204,2.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23365,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23365,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23365,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23365,255,73.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23365,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23365,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23365,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23365,303,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23365,306,312,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23365,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23365,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23365,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23365,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23365,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23365,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23365,605,0.137,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23365,606,1.011,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23366,203,21.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23366,204,5.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23366,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23366,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23366,208,139,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23366,255,72.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23366,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23366,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23366,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23366,303,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23366,306,289,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23366,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23366,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23366,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23366,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23366,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23366,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23366,605,0.271,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23366,606,1.956,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23367,203,21.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23367,204,6.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23367,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23367,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23367,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23367,255,72.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23367,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23367,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23367,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23367,303,2.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23367,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23367,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23367,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23367,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23367,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23367,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23367,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23367,605,0.292,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23367,606,2.123,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23368,203,22.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23368,204,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23368,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23368,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23368,208,135,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23368,255,73.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23368,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23368,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23368,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23368,303,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23368,306,298,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23368,307,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23368,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23368,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23368,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23368,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23368,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23368,605,0.239,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23368,606,1.706,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23369,203,23.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23369,204,5.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23369,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23369,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23369,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23369,255,70.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23369,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23369,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23369,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23369,303,1.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23369,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23369,307,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23369,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23369,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23369,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23369,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23369,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23369,605,0.299,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23369,606,2.345,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23370,203,22.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23370,204,6.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23370,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23370,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23370,208,149,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23370,255,69.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23370,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23370,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23370,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23370,303,1.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23370,306,283,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23370,307,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23370,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23370,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23370,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23370,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23370,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23370,605,0.307,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23370,606,2.515,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23371,203,23.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23371,204,4.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23371,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23371,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23371,208,135,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23371,255,71.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23371,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23371,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23371,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23371,303,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23371,306,288,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23371,307,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23371,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23371,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23371,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23371,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23371,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23371,605,0.25,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23371,606,1.824,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23372,203,21.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23372,204,5.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23372,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23372,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23372,208,139,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23372,255,72.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23372,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23372,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23372,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23372,303,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23372,306,289,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23372,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23372,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23372,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23372,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23372,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23372,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23372,605,0.271,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23372,606,1.956,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23373,203,21.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23373,204,6.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23373,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23373,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23373,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23373,255,72.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23373,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23373,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23373,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23373,303,2.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23373,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23373,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23373,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (23373,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23373,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23373,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23373,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23373,605,0.292,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23373,606,2.123,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23374,203,22.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23374,204,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23374,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23374,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23374,208,135,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23374,255,73.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23374,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23374,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23374,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23374,303,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23374,306,298,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23374,307,42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23374,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23374,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23374,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23374,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23374,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23374,605,0.239,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23374,606,1.706,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23375,203,27.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23375,204,7.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23375,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23375,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23375,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23375,255,64.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23375,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23375,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23375,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23375,303,3.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23375,306,350,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23375,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23375,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23375,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23375,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23375,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23375,601,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23375,605,0.404,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23375,606,2.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23376,203,27.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23376,204,8.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23376,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23376,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23376,208,183,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23376,255,64.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23376,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23376,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23376,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23376,303,3.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23376,306,350,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23376,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23376,320,1,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23376,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23376,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23376,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23376,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23376,605,0.423,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23376,606,3.252,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23377,203,27.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23377,204,6.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23377,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23377,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23377,208,169,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23377,255,65.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23377,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23377,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23377,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23377,303,3.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23377,306,352,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23377,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23377,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23377,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23377,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23377,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23377,601,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23377,605,0.375,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23377,606,2.595,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23378,203,30.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23378,204,3.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23378,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23378,207,1.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23378,208,162,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23378,255,64.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23378,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23378,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23378,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23378,303,2.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23378,306,387,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23378,307,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23378,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23378,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23378,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23378,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23378,601,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23378,605,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23378,606,1.383,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23379,203,30.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23379,204,4.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23379,205,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23379,207,1.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23379,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23379,255,64.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23379,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23379,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23379,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23379,303,2.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23379,306,381,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23379,307,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23379,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23379,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23379,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23379,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23379,601,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23379,605,0.178,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23379,606,1.547,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23380,203,29.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23380,204,3.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23380,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23380,207,1.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23380,208,150,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23380,255,65.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23380,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23380,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23380,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23380,303,2.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23380,306,390,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23380,307,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23380,320,3,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23380,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23380,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23380,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23380,601,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23380,605,0.158,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23380,606,1.136,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23381,203,29.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23381,204,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23381,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23381,207,1.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23381,208,155,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23381,255,65.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23381,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23381,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23381,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23381,303,1.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23381,306,414,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23381,307,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23381,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23381,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23381,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23381,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23381,601,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23381,605,0.182,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23381,606,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23382,203,29.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23382,204,4.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23382,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23382,207,1.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23382,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23382,255,64.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23382,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23382,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23382,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23382,303,1.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23382,306,421,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23382,307,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23382,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23382,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23382,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23382,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23382,601,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23382,605,0.185,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23382,606,1.476,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23383,203,29.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23383,204,3.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23383,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23383,207,1.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23383,208,149,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23383,255,66.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23383,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23383,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23383,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23383,303,1.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23383,306,405,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23383,307,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23383,320,3,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (23383,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23383,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23383,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23383,601,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23383,605,0.178,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23383,606,1.313,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23384,203,23.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23384,204,4.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23384,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23384,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23384,208,135,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23384,255,71.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23384,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23384,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23384,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23384,303,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23384,306,288,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23384,307,47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23384,320,2,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (23384,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23384,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23384,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23384,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23384,605,0.287,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23384,606,2.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23385,203,22.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23385,204,6.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23385,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23385,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23385,208,149,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23385,255,69.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23385,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23385,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23385,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23385,303,1.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23385,306,283,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23385,307,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23385,320,2,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (23385,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23385,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23385,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23385,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23385,605,0.307,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23385,606,2.515,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23386,203,23.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23386,204,5.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23386,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23386,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23386,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23386,255,70.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23386,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23386,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23386,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23386,303,1.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23386,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23386,307,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23386,320,2,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (23386,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23386,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23386,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23386,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23386,605,0.299,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23386,606,2.345,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23387,203,21.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23387,204,11.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23387,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23387,207,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23387,208,191,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23387,255,66.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23387,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23387,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23387,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23387,303,1.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23387,306,258,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23387,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23387,320,4,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (23387,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23387,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23387,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23387,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23387,605,0.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23387,606,5.202,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23388,203,21.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23388,204,12.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23388,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23388,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23388,208,199,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23388,255,65.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23388,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23388,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23388,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23388,303,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23388,306,254,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23388,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23388,320,4,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (23388,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23388,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23388,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23388,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23388,605,0.782,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23388,606,5.491,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23389,203,25.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23389,204,19.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23389,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23389,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23389,208,275,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23389,255,54.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23389,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23389,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23389,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23389,303,2.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23389,306,259,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23389,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23389,320,7,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (23389,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23389,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23389,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23389,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23389,605,1.112,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23389,606,7.505,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23390,203,26.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23390,204,15.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23390,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23390,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23390,208,247,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23390,255,57.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23390,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23390,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23390,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23390,303,2.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23390,306,282,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23390,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23390,320,8,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (23390,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23390,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23390,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23390,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23390,605,0.931,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23390,606,6.056,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23391,203,26.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23391,204,17.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23391,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23391,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23391,208,264,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23391,255,55.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23391,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23391,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23391,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23391,303,2.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23391,306,265,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23391,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23391,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (23391,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23391,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23391,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23391,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23391,605,1.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23391,606,6.925,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23392,203,28.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23392,204,10.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23392,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23392,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23392,208,208,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23392,255,60.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23392,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23392,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23392,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23392,303,2.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23392,306,293,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23392,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23392,320,1,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (23392,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23392,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23392,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23392,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23392,605,0.504,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23392,606,3.917,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23393,203,29.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23393,204,7.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23393,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23393,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23393,208,184,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23393,255,62.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23393,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23393,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23393,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23393,303,2.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23393,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23393,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23393,320,2,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (23393,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23393,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23393,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23393,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23393,605,0.375,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23393,606,2.713,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23394,203,29.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23394,204,9.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23394,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23394,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23394,208,198,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23394,255,61.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23394,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23394,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23394,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23394,303,2.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23394,306,299,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23394,307,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23394,320,2,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (23394,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23394,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23394,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23394,601,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23394,605,0.453,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23394,606,3.435,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23395,203,21.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23395,204,13.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23395,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23395,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23395,208,205,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23395,255,64.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23395,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23395,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23395,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23395,303,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23395,306,253,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23395,307,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23395,320,4,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (23395,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23395,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23395,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23395,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23395,605,0.796,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23395,606,5.685,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23397,203,33.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23397,204,6.57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23397,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23397,207,1.15,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23397,208,193,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23397,255,60.46,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23397,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23397,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23397,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23397,303,2.7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23397,306,181,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23397,307,33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23397,320,13,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23397,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23397,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23397,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23397,601,91,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23397,605,0.069,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23397,606,1.881,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23398,203,22.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23398,204,4.49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23398,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23398,207,0.98,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23398,208,129,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23398,255,73.11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23398,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23398,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23398,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23398,303,2.06,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23398,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23398,307,55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23398,320,6,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23398,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23398,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23398,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23398,601,56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23398,605,0.048,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23398,606,1.347,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23399,203,29.35,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23399,204,16.37,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23399,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23399,207,0.93,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23399,208,265,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23399,255,54.88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23399,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23399,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23399,301,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23399,303,1.84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23399,306,142,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23399,307,39,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23399,320,16,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23399,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23399,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23399,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23399,601,79,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23399,605,0.285,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23399,606,5.527,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23401,203,19.74,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23401,204,12.75,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23401,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23401,207,0.84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23401,208,194,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23401,255,67.95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23401,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23401,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23401,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23401,303,1.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23401,306,277,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23401,307,66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23401,320,13,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23401,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23401,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23401,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23401,601,53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23401,605,0.24,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23401,606,4.351,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23402,203,34.51,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23402,204,7.05,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23402,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23402,207,0.83,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23402,208,202,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23402,255,58.64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23402,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23402,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23402,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23402,303,2.78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23402,306,178,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23402,307,30,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23402,320,12,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23402,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23402,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23402,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23402,601,95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23402,605,0.099,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23402,606,2.22,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23403,203,20.92,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23403,204,4.62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23403,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23403,207,0.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23403,208,125,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23403,255,73.75,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23403,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23403,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23403,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23403,303,2.06,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23403,306,321,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23403,307,51,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23403,320,9,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23403,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23403,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23403,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23403,601,54,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23403,605,0.074,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23403,606,1.648,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23404,203,20.46,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23404,204,5.41,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23404,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23404,207,0.95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23404,208,131,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23404,255,73.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23404,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23404,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23404,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23404,303,2.04,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23404,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23404,307,56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23404,320,9,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23404,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23404,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23404,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23404,601,61,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23404,605,0.072,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23404,606,1.756,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23405,203,32.08,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23405,204,8.89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23405,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23405,207,0.78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23405,208,208,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23405,255,59.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23405,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23405,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23405,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23405,303,2.71,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23405,306,189,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23405,307,38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23405,320,12,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23405,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23405,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23405,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23405,601,98,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23405,605,0.117,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23405,606,2.894,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23406,203,30.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23406,204,13.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23406,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23406,207,1.07,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23406,208,239,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23406,255,56.8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23406,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23406,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23406,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23406,303,2.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23406,306,361,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23406,307,52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23406,320,12,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23406,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23406,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23406,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23406,601,94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23406,605,0.242,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23406,606,4.523,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23407,203,19.77,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23407,204,8.51,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23407,205,1.38,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23407,207,0.91,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23407,208,161,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23407,255,69.43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23407,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23407,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23407,301,3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23407,303,2.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23407,306,319,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23407,307,45,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23407,320,17,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23407,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23407,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23407,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23407,601,59,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23407,605,0.207,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23407,606,3.689,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23408,203,29.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23408,204,4.98,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23408,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23408,207,1.15,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23408,208,164,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23408,255,65.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23408,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23408,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23408,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23408,303,1.89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23408,306,374,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23408,307,43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23408,320,7,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23408,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23408,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23408,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23408,601,67,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23408,605,0.089,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23408,606,1.623,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23409,203,20.15,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23409,204,3.35,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23409,205,1.35,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23409,207,1.02,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23409,208,116,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23409,255,74.14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23409,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23409,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23409,301,3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23409,303,1.39,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23409,306,352,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23409,307,40,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23409,320,7,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23409,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23409,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23409,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23409,601,47,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23409,605,0.044,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23409,606,0.875,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23410,203,30.75,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23410,204,7.92,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23410,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23410,207,0.67,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23410,208,194,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23410,255,61.51,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23410,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23410,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23410,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23410,303,2.41,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23410,306,192,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23410,307,28,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23410,320,11,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23410,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23410,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23410,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23410,601,78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23410,605,0.117,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23410,606,2.862,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23411,203,20.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23411,204,6.67,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23411,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23411,207,0.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23411,208,142,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23411,255,73.62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23411,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23411,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23411,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23411,303,1.57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23411,306,331,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23411,307,47,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23411,320,8,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23411,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23411,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23411,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23411,601,49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23411,605,0.097,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23411,606,2.299,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23412,203,33.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23412,204,10.3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23412,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23412,207,1.06,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23412,208,226,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23412,255,56.39,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23412,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23412,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23412,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23412,303,3.23,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23412,306,172,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23412,307,30,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23412,320,15,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23412,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23412,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23412,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23412,601,94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23412,605,0.174,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23412,606,3.117,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23413,203,21.3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23413,204,7.69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23413,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23413,207,0.92,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23413,208,154,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23413,255,70.81,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23413,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23413,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23413,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23413,303,1.9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23413,306,291,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23413,307,50,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23413,320,11,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23413,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23413,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23413,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23413,601,55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23413,605,0.147,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23413,606,2.525,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23414,203,31.29,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23414,204,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23414,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23414,207,1.04,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23414,208,179,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23414,255,62.27,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23414,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23414,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23414,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23414,303,6.81,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23414,306,184,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23414,307,59,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23414,320,14,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23414,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23414,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23414,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23414,601,201,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23414,605,0.124,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23414,606,1.825,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23415,203,18.52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23415,204,3.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23415,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23415,207,1.02,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23415,208,105,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23415,255,78.07,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23415,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23415,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23415,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23415,303,4.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23415,306,275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23415,307,86,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23415,320,10,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23415,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23415,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23415,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23415,601,124,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23415,605,0.055,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23415,606,0.857,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23416,203,31.23,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23416,204,4.64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23416,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23416,207,1.62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23416,208,167,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23416,255,64.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23416,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23416,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23416,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23416,303,2.72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23416,306,217,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23416,307,44,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23416,320,8,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23416,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23416,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23416,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23416,601,89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23416,605,0.054,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23416,606,1.369,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23417,203,21.46,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23417,204,3.12,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23417,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23417,207,0.99,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23417,208,114,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23417,255,74.57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23417,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23417,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23417,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23417,303,2.04,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23417,306,326,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23417,307,63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23417,320,6,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23417,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23417,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23417,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23417,601,56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23417,605,0.022,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23417,606,0.881,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23418,203,22.16,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23418,204,4.36,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23418,205,0.1,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23418,207,1.03,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23418,208,128,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23418,255,72.35,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23418,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23418,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23418,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23418,303,2.27,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23418,306,338,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23418,307,40,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23418,320,8,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23418,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23418,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23418,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23418,601,55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23418,605,0.082,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23418,606,1.528,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23419,203,7.9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23419,204,57.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23419,205,3.39,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23419,207,0.33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23419,208,560,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23419,255,31.16,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23419,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23419,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23419,301,16,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23419,303,1.18,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23419,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23419,307,25,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23419,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (23419,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23419,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23419,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23419,601,87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23419,605,2.052,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23419,606,25.25,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23420,203,6.97,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23420,204,63.78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23420,205,0.01,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23420,207,0.2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23420,208,602,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23420,255,29.04,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23420,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23420,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23420,301,11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23420,303,0.76,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23420,306,143,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23420,307,32,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23420,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (23420,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23420,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23420,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23420,601,104,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23420,605,2.133,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23420,606,28.5,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23421,203,27.28,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23421,204,5.27,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23421,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23421,207,1.55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23421,208,157,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23421,255,66.44,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23421,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23421,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23421,301,14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23421,303,5.7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23421,306,144,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23421,307,123,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23421,320,104,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23421,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23421,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23421,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23421,601,1002,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23421,605,0.055,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23421,606,1.173,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23422,203,27.51,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23422,204,7.58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23422,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23422,207,1.25,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23422,208,178,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23422,255,64.7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23422,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23422,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23422,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23422,303,2.25,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23422,306,405,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23422,307,49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23422,320,13,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23422,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23422,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23422,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23422,601,76,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23422,605,0.128,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23422,606,2.299,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23423,203,15.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23423,204,2.64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23423,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23423,207,1.15,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23423,208,87,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23423,255,80.52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23423,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23423,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23423,301,9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23423,303,3.83,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23423,306,225,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23423,307,175,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23423,320,89,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23423,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23423,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23423,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23423,601,404,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23423,605,0.034,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23423,606,0.616,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23424,203,23.3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23424,204,4.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23424,205,3.78,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23424,207,1.8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23424,208,150,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23424,255,66.44,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23424,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23424,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23424,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23424,303,7.17,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23424,306,336,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23424,307,55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23424,320,21014,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23424,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23424,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23424,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23424,601,243,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23424,605,0.09,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23424,606,1.392,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23425,203,20.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23425,204,4.05,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23425,205,3.6,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23425,207,1.46,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23425,208,133,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23425,255,70.39,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23425,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23425,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23425,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23425,303,8.44,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23425,306,327,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23425,307,53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23425,320,28319,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23425,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23425,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23425,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23425,601,254,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23425,605,0.077,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23425,606,1.185,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23426,203,24.21,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23426,204,3.26,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23426,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23426,207,0.63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23426,208,126,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23426,255,73.1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23426,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23426,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23426,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23426,303,1.78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23426,306,193,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23426,307,32,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23426,320,8,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23426,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23426,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23426,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23426,601,67,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23426,605,0.078,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23426,606,1.154,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23427,203,21.23,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23427,204,3.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23427,205,0.23,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23427,207,1.02,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23427,208,119,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23427,255,73.84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23427,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23427,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23427,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23427,303,1.95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23427,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23427,307,55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23427,320,10,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23427,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23427,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23427,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23427,601,49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23427,605,0.114,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23427,606,1.65,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23428,203,29.87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23428,204,8.46,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23428,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23428,207,0.63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23428,208,196,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23428,255,62.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23428,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23428,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23428,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23428,303,2.78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23428,306,151,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23428,307,25,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23428,320,11,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23428,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23428,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23428,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23428,601,87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23428,605,0.117,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23428,606,2.925,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23429,203,21.83,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23429,204,7.56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23429,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23429,207,0.9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23429,208,155,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23429,255,71.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23429,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23429,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23429,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23429,303,1.95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23429,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23429,307,59,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23429,320,12,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23429,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23429,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23429,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23429,601,56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23429,605,0.079,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23429,606,2.589,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23430,203,27.23,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23430,204,9.74,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23430,205,0.09,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23430,207,1.12,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23430,208,197,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23430,255,61.82,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23430,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23430,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23430,301,18,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23430,303,2.21,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23430,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23430,307,58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23430,320,9,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23430,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23430,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23430,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23430,601,69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23430,605,0.183,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23430,606,3.585,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23431,203,21.31,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23431,204,6.78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23431,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23431,207,0.94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23431,208,146,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23431,255,71.32,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23431,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23431,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23431,301,15,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23431,303,1.82,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23431,306,337,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23431,307,54,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23431,320,8,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23431,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23431,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23431,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23431,601,57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23431,605,0.123,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23431,606,2.453,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23432,203,30.17,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23432,204,7.48,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23432,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23432,207,1.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23432,208,188,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23432,255,61.77,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23432,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23432,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23432,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23432,303,2.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23432,306,427,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23432,307,55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23432,320,12,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23432,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23432,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23432,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23432,601,78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23432,605,0.156,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23432,606,2.609,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23433,203,28.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23433,204,11.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23433,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23433,207,1.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23433,208,217,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23433,255,59.61,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23433,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23433,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23433,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23433,303,1.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23433,306,364,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23433,307,55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23433,320,19,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23433,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23433,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23433,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23433,601,70,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23433,605,0.205,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23433,606,3.918,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23434,203,20.93,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23434,204,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23434,205,0.74,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23434,207,0.91,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23434,208,150,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23434,255,70.41,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23434,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23434,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23434,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23434,303,1.61,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23434,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23434,307,47,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23434,320,12,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23434,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23434,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23434,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23434,601,54,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23434,605,0.125,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23434,606,2.488,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23435,203,6.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23435,204,78.3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23435,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23435,207,0.28,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23435,208,731,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23435,255,15.41,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23435,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23435,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23435,301,17,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23435,303,0.47,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23435,306,129,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23435,307,25,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23435,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (23435,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23435,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23435,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23435,601,63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23435,605,2.698,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23435,606,30.256,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23436,203,8.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23436,204,72.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23436,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23436,207,0.1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23436,208,685,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23436,255,19.91,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23436,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23436,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23436,301,20,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23436,303,0.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23436,306,93,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23436,307,26,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23436,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (23436,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23436,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23436,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23436,601,64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23436,605,2.712,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23436,606,31.514,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23437,203,12.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23437,204,29.79,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23437,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23437,207,1.91,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23437,208,318,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23437,255,56.26,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23437,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23437,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23437,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23437,303,1.12,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23437,306,258,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23437,307,52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23437,320,19,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23437,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23437,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23437,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23437,601,249,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23437,605,0.586,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23437,606,12.473,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23438,203,11.51,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23438,204,28.6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23438,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23438,207,2.36,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23438,208,303,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23438,255,57.67,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23438,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23438,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23438,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23438,303,1.15,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23438,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23438,307,64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23438,320,19,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23438,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23438,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23438,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23438,601,217,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23438,605,0.595,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23438,606,12.294,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23439,203,29.37,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23439,204,9.01,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23439,205,0.27,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23439,207,1.66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23439,208,200,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23439,255,59.69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23439,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23439,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23439,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23439,303,3.01,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23439,306,427,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23439,307,45,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23439,320,13,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23439,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23439,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23439,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23439,601,81,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23439,605,0.175,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23439,606,3.596,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23440,203,21.27,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23440,204,10.31,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23440,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23440,207,0.87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23440,208,178,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23440,255,69.48,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23440,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23440,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23440,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23440,303,1.89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23440,306,288,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23440,307,57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23440,320,12,'100g',1,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (23440,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23440,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23440,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23440,601,56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23440,605,0.19,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23440,606,3.815,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23441,203,21.19,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23441,204,6.1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23441,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23441,207,1.05,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23441,208,140,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23441,255,71.79,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23441,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23441,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23441,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23441,303,2.21,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23441,306,362,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23441,307,39,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23441,320,9,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23441,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23441,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23441,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23441,601,58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23441,605,0.121,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23441,606,2.446,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23442,203,18.31,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23442,204,20.34,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23442,205,3.68,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23442,207,0.72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23442,208,271,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23442,255,56.95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23442,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23442,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23442,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23442,303,2.52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23442,306,189,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23442,307,57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23442,320,12,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23442,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23442,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23442,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23442,601,105,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23442,605,0.358,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23442,606,7.019,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23443,203,17.77,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23443,204,19.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23443,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23443,207,0.8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23443,208,243,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23443,255,65.24,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23443,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23443,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23443,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23443,303,1.81,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23443,306,252,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23443,307,73,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23443,320,12,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23443,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23443,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23443,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23443,601,81,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23443,605,0.785,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23443,606,6.689,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23444,203,19,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23444,204,2.98,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23444,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23444,207,0.89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23444,208,103,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23444,255,77.71,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23444,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23444,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23444,301,158,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23444,303,3.72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23444,306,102,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23444,307,40,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23444,320,6,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23444,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23444,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23444,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23444,601,199,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23444,605,0.07,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23444,606,0.922,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23445,203,14.86,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23445,204,1.98,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23445,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23445,207,1.1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23445,208,77,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23445,255,82.19,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23445,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23445,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23445,301,112,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23445,303,4.44,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23445,306,217,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23445,307,81,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23445,320,6,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23445,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23445,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23445,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23445,601,117,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23445,605,0.101,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23445,606,1.02,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23446,203,31.3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23446,204,11.37,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23446,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23446,207,1.07,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23446,208,228,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23446,255,57.82,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23446,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23446,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23446,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23446,303,2.54,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23446,306,177,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23446,307,33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23446,320,12,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23446,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23446,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23446,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23446,601,92,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23446,605,0.242,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23446,606,4.117,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23447,203,21.29,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23447,204,8.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23447,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23447,207,0.93,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23447,208,159,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23447,255,70.23,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23447,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23447,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23447,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23447,303,1.97,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23447,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23447,307,54,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23447,320,6,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23447,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23447,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23447,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23447,601,57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23447,605,0.19,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23447,606,3.017,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23448,203,20.14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23448,204,41.33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23448,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23448,207,0.66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23448,208,453,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23448,255,38.97,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23448,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23448,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23448,301,11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23448,303,1.29,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23448,306,137,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23448,307,33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23448,320,10,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23448,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23448,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23448,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23448,601,72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23448,605,1.258,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23448,606,15.494,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23449,203,15.81,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23449,204,31.27,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23449,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23449,207,0.61,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23449,208,345,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23449,255,53.33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23449,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23449,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23449,301,9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23449,303,1.11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23449,306,223,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23449,307,54,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23449,320,9,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23449,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23449,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23449,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23449,601,62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23449,605,0.977,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23449,606,12.915,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23450,203,31.94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23450,204,13.6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23450,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23450,207,0.78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23450,208,250,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23450,255,54.66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23450,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23450,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23450,301,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23450,303,2.57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23450,306,173,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23450,307,29,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23450,320,11,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23450,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23450,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23450,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23450,601,92,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23450,605,0.338,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23450,606,4.796,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23451,203,20.05,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23451,204,9.23,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23451,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23451,207,0.9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23451,208,163,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23451,255,70.11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23451,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23451,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23451,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23451,303,1.94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23451,306,306,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23451,307,49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23451,320,8,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23451,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23451,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23451,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23451,601,55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23451,605,0.251,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23451,606,3.685,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23452,203,29.92,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23452,204,14.74,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23452,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23452,207,0.74,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23452,208,252,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23452,255,55.95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23452,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23452,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23452,301,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23452,303,2.52,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23452,306,183,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23452,307,37,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23452,320,11,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23452,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23452,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23452,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23452,601,95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23452,605,0.335,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23452,606,5.199,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23453,203,19.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23453,204,11.45,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23453,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23453,207,0.87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23453,208,181,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23453,255,68.67,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23453,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23453,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23453,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23453,303,1.89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23453,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23453,307,53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23453,320,8,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23453,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23453,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23453,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23453,601,61,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23453,605,0.31,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23453,606,4.437,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23454,203,27.79,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23454,204,19.45,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23454,205,0.03,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23454,207,1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23454,208,286,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23454,255,52.86,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23454,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23454,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23454,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23454,303,2.2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23454,306,338,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23454,307,49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23454,320,11,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23454,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23454,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23454,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23454,601,91,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23454,605,0.478,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23454,606,7.012,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23455,203,18.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23455,204,16.31,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23455,205,1.26,'100g',3,1,'2015-01-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23455,207,0.83,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23455,208,225,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23455,255,63.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23455,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23455,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23455,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23455,303,1.91,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23455,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23455,307,43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23455,320,15,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23455,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23455,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23455,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23455,601,60,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23455,605,0.488,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23455,606,6.734,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23456,203,29.49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23456,204,5.57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23456,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23456,207,1.14,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23456,208,168,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23456,255,64.99,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23456,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23456,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23456,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23456,303,1.88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23456,306,372,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23456,307,43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23456,320,7,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23456,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23456,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23456,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23456,601,67,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23456,605,0.109,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23456,606,1.85,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23457,203,19.88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23457,204,4.92,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23457,205,1.32,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23457,207,1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23457,208,129,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23457,255,72.9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23457,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23457,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23457,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23457,303,1.37,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23457,306,346,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23457,307,39,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23457,320,7,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23457,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23457,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23457,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23457,601,48,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23457,605,0.105,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23457,606,1.573,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23458,203,30.13,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23458,204,9.73,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23458,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23458,207,0.66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23458,208,208,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23458,255,60.32,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23458,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23458,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23458,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23458,303,2.36,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23458,306,190,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23458,307,28,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23458,320,11,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23458,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23458,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23458,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23458,601,78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23458,605,0.183,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23458,606,3.566,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23459,203,20.12,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23459,204,8.9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23459,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23459,207,0.93,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23459,208,161,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23459,255,71.79,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23459,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23459,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23459,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23459,303,1.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23459,306,323,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23459,307,46,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23459,320,8,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23459,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23459,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23459,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23459,601,49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23459,605,0.186,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23459,606,3.292,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23460,203,31.86,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23460,204,13.79,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23460,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23460,207,1.02,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23460,208,252,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23460,255,54.29,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23460,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23460,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23460,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23460,303,3.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23460,306,170,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23460,307,30,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23460,320,14,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23460,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23460,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23460,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23460,601,92,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23460,605,0.303,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23460,606,4.507,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23461,203,20.57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23461,204,10.55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23461,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23461,207,0.89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23461,208,177,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23461,255,68.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23461,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23461,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23461,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23461,303,1.84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23461,306,283,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23461,307,49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23461,320,10,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23461,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23461,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23461,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23461,601,58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23461,605,0.248,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23461,606,3.847,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23462,203,29.82,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23462,204,8.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23462,205,0.07,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23462,207,1.54,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23462,208,196,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23462,255,61.87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23462,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23462,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23462,301,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23462,303,2.6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23462,306,211,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23462,307,43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23462,320,8,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23462,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23462,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23462,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23462,601,88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23462,605,0.195,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23462,606,2.948,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23463,203,20.61,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23463,204,7.2,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23463,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23463,207,0.94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23463,208,147,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23463,255,71.41,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23463,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23463,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23463,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23463,303,1.95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23463,306,313,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23463,307,61,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23463,320,6,'100g',1,1,'2024-12-12','2014-01-03');
INSERT INTO `cndb_nutval` VALUES (23463,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23463,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23463,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23463,601,57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23463,605,0.173,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23463,606,2.711,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23464,203,29.79,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23464,204,8.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23464,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23464,207,0.63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23464,208,197,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23464,255,62.23,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23464,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23464,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23464,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23464,303,2.77,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23464,306,151,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23464,307,25,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23464,320,10,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (23464,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23464,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23464,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23464,601,87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23464,605,0.125,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23464,606,3.013,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23465,203,30.01,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23465,204,7.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23465,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23465,207,1.37,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23465,208,192,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23465,255,61.45,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23465,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23465,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23465,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23465,303,2.95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23465,306,425,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23465,307,55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23465,320,12,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (23465,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23465,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23465,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23465,601,78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23465,605,0.173,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23465,606,2.795,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23466,203,21.74,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23466,204,6.05,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23466,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23466,207,0.97,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23466,208,141,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23466,255,72.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23466,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23466,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23466,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23466,303,2.3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23466,306,343,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23466,307,49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23466,320,7,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (23466,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23466,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23466,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23466,601,55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23466,605,0.133,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23466,606,1.999,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23467,203,21.65,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23467,204,6.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23467,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23467,207,0.97,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23467,208,145,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23467,255,71.87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23467,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23467,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23467,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23467,303,2.29,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23467,306,341,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23467,307,49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23467,320,7,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (23467,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23467,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23467,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23467,601,55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23467,605,0.15,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23467,606,2.2,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23468,203,24.89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23468,204,22.33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23468,205,0.02,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23468,207,0.95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23468,208,301,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23468,255,52.4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23468,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23468,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23468,301,8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23468,303,1.72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23468,306,325,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23468,307,50,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23468,320,16,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (23468,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23468,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23468,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23468,601,69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23468,605,0.613,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23468,606,8.244,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23469,203,18.49,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23469,204,19.53,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23469,205,0.6,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23469,207,0.76,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23469,208,252,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23469,255,60.78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23469,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23469,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23469,301,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23469,303,1.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23469,306,268,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23469,307,43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23469,320,10,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (23469,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23469,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23469,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23469,601,57,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23469,605,0.616,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23469,606,8.064,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23470,203,29.26,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23470,204,9.35,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23470,205,0.27,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23470,207,1.66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23470,208,202,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23470,255,59.47,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23470,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23470,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23470,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23470,303,2.99,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23470,306,425,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23470,307,45,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23470,320,13,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (23470,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23470,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23470,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23470,601,81,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23470,605,0.188,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23470,606,3.729,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23471,203,21.04,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23471,204,6.88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23471,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23471,207,1.04,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23471,208,146,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23471,255,71.18,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23471,269,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23471,291,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23471,301,4,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23471,303,2.18,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23471,306,359,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23471,307,39,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23471,320,9,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (23471,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23471,401,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23471,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23471,601,58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23471,605,0.151,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23471,606,2.788,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23472,203,20.85,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23472,204,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23472,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23472,207,1.02,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23472,208,152,'100g',3,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23472,255,71.72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23472,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23472,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23472,301,10,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23472,303,2.33,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23472,306,336,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23472,307,66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23472,320,4,'100g',1,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23472,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23472,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23472,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23472,601,63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23472,605,0.348,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23472,606,2.878,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23473,203,26.22,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23473,204,8.94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23473,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23473,207,1.05,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23473,208,193,'100g',3,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23473,255,63.81,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23473,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23473,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23473,301,9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23473,303,2.78,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23473,306,342,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23473,307,66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23473,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23473,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23473,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23473,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23473,601,88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23473,605,0.254,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23473,606,3.684,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23474,203,25.56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23474,204,8.01,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23474,205,0.06,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23474,207,1.08,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23474,208,182,'100g',3,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23474,255,65.29,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23474,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23474,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23474,301,11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23474,303,2.82,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23474,306,371,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23474,307,72,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23474,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23474,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23474,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23474,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23474,601,84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23474,605,0.266,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23474,606,3.286,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23475,203,27.03,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23475,204,8.43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23475,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23475,207,0.94,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23475,208,192,'100g',3,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23475,255,63.26,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23475,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23475,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23475,301,10,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23475,303,2.99,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23475,306,309,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23475,307,59,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23475,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23475,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23475,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23475,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23475,601,88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23475,605,0.253,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23475,606,3.48,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23476,203,28.88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23476,204,9.51,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23476,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23476,207,1.32,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23476,208,209,'100g',3,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23476,255,60.82,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23476,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23476,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23476,301,12,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23476,303,3.17,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23476,306,449,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23476,307,86,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23476,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23476,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23476,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23476,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23476,601,89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23476,605,0.241,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23476,606,3.897,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23477,203,21.98,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23477,204,3,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23477,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23477,207,1.07,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23477,208,121,'100g',3,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23477,255,74.75,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23477,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23477,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23477,301,8,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23477,303,2.44,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23477,306,357,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23477,307,66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23477,320,4,'100g',1,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23477,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23477,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23477,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23477,601,60,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23477,605,0.092,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23477,606,1.48,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23478,203,26.36,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23478,204,4.46,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23478,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23478,207,1.06,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23478,208,153,'100g',3,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23478,255,67.96,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23478,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23478,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23478,301,5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23478,303,2.88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23478,306,353,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23478,307,64,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23478,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23478,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23478,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23478,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23478,601,88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23478,605,0.094,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23478,606,2.207,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23479,203,26.03,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23479,204,3.65,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23479,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23479,207,1.09,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23479,208,144,'100g',3,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23479,255,68.68,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23479,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23479,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23479,301,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23479,303,2.89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23479,306,382,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23479,307,69,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23479,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23479,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23479,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23479,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23479,601,84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23479,605,0.092,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23479,606,1.797,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23480,203,27.58,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23480,204,4.06,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23480,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23480,207,0.95,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23480,208,154,'100g',3,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23480,255,66.43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23480,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23480,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23480,301,6,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23480,303,3.11,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23480,306,321,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23480,307,56,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23480,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23480,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23480,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23480,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23480,601,88,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23480,605,0.093,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23480,606,2.011,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23481,203,29.46,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23481,204,5.46,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23481,205,0,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23481,207,1.36,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23481,208,175,'100g',3,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23481,255,64.55,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23481,269,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23481,291,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23481,301,7,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23481,303,3.29,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23481,306,470,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23481,307,84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23481,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23481,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23481,401,0,'100g',4,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23481,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23481,601,89,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23481,605,0.084,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23481,606,2.686,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23482,203,20.95,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23482,204,9.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23482,205,0,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23482,207,1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23482,208,167,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23482,255,69.03,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23482,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23482,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23482,301,13,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23482,303,2.04,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23482,306,310,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23482,307,61,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23482,320,3,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23482,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23482,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23482,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23482,601,65,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23482,605,0.381,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23482,606,3.845,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23483,203,22.15,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23483,204,5.38,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23483,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23483,207,1.06,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23483,208,140,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23483,255,71.78,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23483,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23483,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23483,301,17,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23483,303,1.84,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23483,306,316,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23483,307,56,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23483,320,1,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23483,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23483,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23483,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23483,601,62,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23483,605,0.136,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23483,606,1.974,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23484,203,28.95,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23484,204,8.15,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23484,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23484,207,1.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23484,208,194,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23484,255,62.48,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23484,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23484,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23484,301,12,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23484,303,2.4,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23484,306,303,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23484,307,54,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23484,320,1,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (23484,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23484,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23484,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23484,601,80,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23484,605,0.251,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23484,606,3.108,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23485,203,22.15,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23485,204,5.54,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23485,205,0,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23485,207,1.05,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23485,208,138,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23485,255,71.58,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23485,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23485,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23485,301,13,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23485,303,2.08,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23485,306,322,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23485,307,60,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23485,320,1,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23485,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23485,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23485,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23485,601,63,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23485,605,0.233,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23485,606,2.151,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23490,203,22.01,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23490,204,6.05,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23490,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23490,207,1.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23490,208,142,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23490,255,71.22,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23490,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23490,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23490,301,18,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23490,303,1.91,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23490,306,308,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23490,307,55,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23490,320,1,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23490,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23490,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23490,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23490,601,62,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23490,605,0.152,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23490,606,2.222,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23491,203,28.73,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23491,204,9.16,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23491,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23491,207,1.08,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23491,208,203,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23491,255,61.51,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23491,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23491,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23491,301,11,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23491,303,2.49,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23491,306,298,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23491,307,53,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23491,320,1,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23491,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23491,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23491,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23491,601,82,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23491,605,0.279,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23491,606,3.536,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23494,203,21.34,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23494,204,10.08,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23494,205,0,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23494,207,1.01,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23494,208,176,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23494,255,68,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23494,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23494,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23494,301,13,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23494,303,2.07,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23494,306,306,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23494,307,61,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23494,320,3,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23494,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23494,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23494,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23494,601,66,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23494,605,0.403,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23494,606,4.122,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23495,203,21.55,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23495,204,7.24,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23495,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23495,207,1.01,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23495,208,151,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23495,255,70.24,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23495,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23495,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23495,301,14,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23495,303,2.16,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23495,306,335,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23495,307,66,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23495,320,1,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23495,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23495,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23495,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23495,601,66,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23495,605,0.274,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23495,606,2.755,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23496,203,22.03,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23496,204,4.99,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23496,205,0,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23496,207,1.05,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23496,208,133,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23496,255,72.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23496,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23496,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23496,301,12,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23496,303,2.14,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23496,306,330,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23496,307,63,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23496,320,2,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23496,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23496,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23496,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23496,601,64,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23496,605,0.228,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23496,606,1.973,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23497,203,21.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23497,204,8,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23497,205,0,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (23497,207,1.02,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23497,208,157,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23497,255,70.16,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23497,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23497,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23497,301,13,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23497,303,2.06,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23497,306,315,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23497,307,61,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23497,320,3,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23497,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23497,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23497,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23497,601,64,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23497,605,0.354,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23497,606,3.351,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23498,203,27.51,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23498,204,6.37,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23498,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23498,207,1.07,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23498,208,167,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23498,255,60,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23498,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23498,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23498,301,11,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23498,303,2.17,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23498,306,294,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23498,307,51,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23498,320,1,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23498,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23498,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23498,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23498,601,74,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23498,605,0.181,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23498,606,2.354,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23499,203,22.37,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23499,204,4.55,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23499,205,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23499,207,1.07,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23499,208,130,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23499,255,72.47,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23499,269,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23499,291,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23499,301,17,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23499,303,1.81,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23499,306,328,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23499,307,58,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23499,320,1,'100g',2,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23499,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23499,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23499,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23499,601,62,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23499,605,0.111,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23499,606,1.664,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23509,203,25.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23509,204,5.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23509,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23509,207,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23509,208,159,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23509,255,66.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23509,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23509,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23509,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23509,303,2.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23509,306,293,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23509,307,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23509,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (23509,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23509,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23509,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23509,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23509,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23509,606,1.828,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23511,203,26.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23511,204,10.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23511,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23511,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23511,208,203,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23511,255,62.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23511,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23511,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23511,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23511,303,2.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23511,306,304,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23511,307,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23511,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (23511,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23511,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23511,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23511,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23511,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23511,606,3.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23513,203,19.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23513,204,5.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23513,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23513,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23513,208,129,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23513,255,73.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23513,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23513,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23513,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23513,303,2.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23513,306,354,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23513,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23513,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (23513,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23513,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23513,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23513,601,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23513,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23513,606,1.414,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23514,203,26.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23514,204,6.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23514,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23514,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23514,208,172,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23514,255,64.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23514,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23514,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23514,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23514,303,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23514,306,385,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23514,307,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23514,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (23514,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23514,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23514,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23514,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23514,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23514,606,2.037,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23515,203,26.36,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23515,204,6.75,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23515,205,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23515,207,1.17,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23515,208,173,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23515,255,64.92,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23515,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23515,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23515,301,7,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23515,303,3.09,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23515,306,372,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23515,307,71,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23515,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (23515,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23515,401,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23515,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23515,601,71,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23515,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23515,606,2.144,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23516,203,28.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23516,204,5.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23516,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23516,207,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23516,208,175,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23516,255,64.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23516,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23516,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23516,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23516,303,2.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23516,306,372,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23516,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23516,320,2,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23516,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23516,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23516,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23516,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23516,605,0.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23516,606,2.43,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23517,203,29.34,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23517,204,7.04,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23517,205,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23517,207,1.17,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23517,208,189,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23517,255,60.02,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23517,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23517,291,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23517,301,8,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23517,303,3.79,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23517,306,287,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23517,307,60,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23517,320,0,'100g',1,1,'2024-12-12','2002-01-01');
INSERT INTO `cndb_nutval` VALUES (23517,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23517,401,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23517,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23517,601,94,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23517,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23517,606,2.271,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (23519,203,25.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23519,204,5.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23519,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23519,207,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23519,208,161,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23519,255,65.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23519,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23519,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23519,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23519,303,3.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23519,306,293,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23519,307,73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23519,320,0,'100g',1,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23519,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23519,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23519,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23519,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23519,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23519,606,1.721,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23521,203,26.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23521,204,5.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23521,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23521,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23521,208,159,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23521,255,67.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23521,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23521,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23521,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23521,303,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23521,306,293,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23521,307,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23521,320,0,'100g',1,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23521,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23521,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23521,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23521,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23521,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23521,606,2.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23523,203,25.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23523,204,12.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23523,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23523,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23523,208,227,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23523,255,60.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23523,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23523,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23523,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23523,303,2.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23523,306,300,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23523,307,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23523,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (23523,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23523,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23523,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23523,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23523,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23523,606,4.162,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23525,203,25.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23525,204,9.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23525,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23525,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23525,208,200,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23525,255,62.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23525,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23525,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23525,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23525,303,2.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23525,306,298,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23525,307,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23525,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (23525,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23525,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23525,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23525,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23525,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23525,606,3.533,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23528,203,24.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23528,204,12.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23528,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23528,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23528,208,216,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23528,255,60.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23528,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23528,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23528,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23528,303,3.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23528,306,363,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23528,307,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23528,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (23528,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23528,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23528,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23528,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23528,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23528,606,4.285,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23531,203,27.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23531,204,8.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23531,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23531,207,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23531,208,196,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23531,255,62.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23531,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23531,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23531,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23531,303,3.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23531,306,372,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23531,307,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23531,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (23531,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23531,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23531,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23531,601,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23531,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23531,606,3.349,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23533,203,28.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23533,204,7.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23533,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23533,207,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23533,208,186,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23533,255,63.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23533,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23533,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23533,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23533,303,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23533,306,367,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23533,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23533,320,6,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23533,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23533,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23533,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23533,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23533,605,0.368,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23533,606,3.09,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23536,203,28.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23536,204,6.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23536,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23536,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23536,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23536,255,64.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23536,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23536,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23536,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23536,303,2.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23536,306,366,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23536,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23536,320,6,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23536,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23536,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23536,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23536,601,83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23536,605,0.424,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23536,606,2.642,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23540,203,26.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23540,204,12.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23540,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23540,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23540,208,220,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23540,255,60.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23540,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23540,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23540,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23540,303,2.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23540,306,289,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23540,307,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23540,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (23540,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23540,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23540,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23540,601,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23540,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23540,606,4.666,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23541,203,23.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23541,204,17.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23541,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23541,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23541,208,255,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23541,255,57.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23541,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23541,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23541,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23541,303,2.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23541,306,379,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23541,307,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23541,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (23541,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23541,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23541,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23541,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23541,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23541,606,7.083,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23545,203,29.97,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23545,204,15.18,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23545,205,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23545,207,1.45,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23545,208,265,'100g',3,1,'2006-02-23','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (23545,255,50.5,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23545,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23545,291,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23545,301,12,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23545,303,3.64,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23545,306,437,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23545,307,72,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23545,320,0,'100g',1,1,'2024-12-12','2008-01-04');
INSERT INTO `cndb_nutval` VALUES (23545,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23545,401,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23545,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23545,601,68,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23545,605,NULL,'100g',NULL,1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (23545,606,5.707,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23547,203,25.87,'100g',1,1,'2006-02-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23547,204,5.52,'100g',1,1,'2006-02-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23547,205,0,'100g',3,1,'2006-02-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23547,207,1.36,'100g',1,1,'2006-02-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23547,208,160,'100g',3,1,'2006-02-24','2012-09-01');
INSERT INTO `cndb_nutval` VALUES (23547,255,66.19,'100g',1,1,'2006-02-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23547,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23547,291,0,'100g',3,1,'2006-02-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23547,301,8,'100g',3,1,'2006-02-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23547,303,2.93,'100g',3,1,'2006-02-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23547,306,293,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23547,307,71,'100g',3,1,'2006-02-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23547,320,0,'100g',1,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23547,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23547,401,0,'100g',3,1,'2006-02-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23547,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23547,601,63,'100g',1,1,'2006-02-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23547,605,NULL,'100g',NULL,1,'2006-02-24','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (23547,606,1.871,'100g',3,1,'2006-02-24','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23549,203,25.73,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23549,204,11.73,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23549,205,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23549,207,1.09,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23549,208,216,'100g',3,1,'2006-02-23','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (23549,255,61.57,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23549,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23549,291,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23549,301,7,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23549,303,2.76,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23549,306,299,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23549,307,67,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23549,320,0,'100g',1,1,'2024-12-12','2001-01-12');
INSERT INTO `cndb_nutval` VALUES (23549,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23549,401,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23549,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23549,601,61,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23549,605,NULL,'100g',NULL,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23549,606,3.906,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23552,203,25.7,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23552,204,10.84,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23552,205,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23552,207,1.15,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23552,208,207,'100g',3,1,'2006-02-23','2012-08-01');
INSERT INTO `cndb_nutval` VALUES (23552,255,61.09,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23552,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23552,291,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23552,301,7,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23552,303,3.05,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23552,306,367,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23552,307,71,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23552,320,0,'100g',1,1,'2024-12-12','2011-01-07');
INSERT INTO `cndb_nutval` VALUES (23552,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23552,401,0,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23552,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23552,601,69,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23552,605,NULL,'100g',NULL,1,'2006-02-23','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (23552,606,3.904,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23554,203,28.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23554,204,6.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23554,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23554,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23554,208,182,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23554,255,64.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23554,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23554,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23554,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23554,303,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23554,306,366,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23554,307,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23554,320,6,'100g',2,1,'2024-12-12','2010-01-07');
INSERT INTO `cndb_nutval` VALUES (23554,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23554,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23554,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23554,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23554,605,0.39,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (23554,606,2.911,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23557,203,21.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23557,204,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23557,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23557,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23557,208,137,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23557,255,73.24,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23557,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23557,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23557,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23557,303,2.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23557,306,346,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23557,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23557,320,4,'100g',1,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23557,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23557,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23557,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23557,601,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23557,605,0.22,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23557,606,2.182,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23558,203,26.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23558,204,6.8,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23558,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23558,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23558,208,174,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23558,255,65.78,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23558,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23558,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23558,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23558,303,2.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23558,306,347,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23558,307,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23558,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23558,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23558,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23558,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23558,601,88,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23558,605,0.174,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23558,606,2.976,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23559,203,25.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23559,204,5.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23559,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23559,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23559,208,164,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23559,255,66.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23559,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23559,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23559,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23559,303,2.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23559,306,376,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23559,307,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23559,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23559,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23559,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23559,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23559,601,84,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23559,605,0.179,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23559,606,2.589,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23560,203,29.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23560,204,7.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23560,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23560,207,1.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23560,208,193,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23560,255,62.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23560,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23560,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23560,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23560,303,3.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23560,306,459,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23560,307,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23560,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23560,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23560,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23560,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23560,601,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23560,605,0.162,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23560,606,3.298,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23561,203,27.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23561,204,6.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23561,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23561,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23561,208,174,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23561,255,64.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23561,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23561,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23561,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23561,303,3.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23561,306,315,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23561,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23561,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23561,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23561,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23561,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (23561,601,88,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23561,605,0.173,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23561,606,2.788,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23562,203,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23562,204,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23562,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23562,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23562,208,176,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23562,255,69.45,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23562,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23562,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23562,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23562,303,2.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23562,306,321,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23562,307,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23562,320,4,'100g',1,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23562,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23562,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23562,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23562,601,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23562,605,0.54,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23562,606,3.927,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23563,203,26.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23563,204,11.75,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23563,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23563,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23563,208,217,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23563,255,61.24,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23563,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23563,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23563,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23563,303,2.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23563,306,333,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23563,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23563,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23563,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23563,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23563,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23563,601,88,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23563,605,0.373,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23563,606,4.628,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23564,203,25.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23564,204,10.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23564,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23564,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23564,208,204,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23564,255,63.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23564,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23564,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23564,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23564,303,2.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23564,306,363,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23564,307,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23564,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23564,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23564,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23564,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23564,601,84,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23564,605,0.397,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23564,606,4.189,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23565,203,28.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23565,204,12.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23565,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23565,207,1.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23565,208,230,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23565,255,58.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23565,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23565,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23565,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23565,303,3.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23565,306,433,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23565,307,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23565,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23565,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23565,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23565,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23565,601,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23565,605,0.359,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23565,606,4.712,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23566,203,26.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23566,204,11.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23566,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23566,207,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23566,208,214,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23566,255,61.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23566,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23566,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23566,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23566,303,2.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23566,306,300,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23566,307,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23566,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23566,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23566,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23566,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (23566,601,88,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23566,605,0.373,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23566,606,4.375,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23567,203,18.59,'100g',1,1,'2002-09-06','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23567,204,15,'100g',1,1,'2002-09-06','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23567,205,0,'100g',3,1,'2002-09-06','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23567,207,0.91,'100g',1,1,'2002-09-06','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23567,208,215,'100g',3,1,'2002-09-06','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23567,255,65.66,'100g',1,1,'2002-09-06','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23567,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23567,291,0,'100g',4,1,'2002-09-06','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23567,301,15,'100g',1,1,'2002-09-06','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23567,303,2.09,'100g',1,1,'2002-09-06','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23567,306,295,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23567,307,66,'100g',1,1,'2002-09-06','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23567,320,4,'100g',1,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23567,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23567,401,0,'100g',4,1,'2002-09-06','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23567,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23567,601,68,'100g',1,1,'2002-09-06','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23567,605,0.86,'100g',3,1,'2006-01-24','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23567,606,5.715,'100g',3,1,'2002-09-06','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23568,203,25.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23568,204,15.41,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23568,205,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23568,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23568,208,250,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23568,255,57.98,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23568,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23568,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23568,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23568,303,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23568,306,318,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23568,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23568,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23568,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23568,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23568,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23568,601,88,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23568,605,0.572,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23568,606,5.895,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23569,203,24.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23569,204,14.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23569,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23569,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23569,208,232,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23569,255,60.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23569,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23569,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23569,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23569,303,2.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23569,306,349,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23569,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23569,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23569,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23569,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23569,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23569,601,84,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23569,605,0.615,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23569,606,5.331,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23570,203,27.73,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23570,204,15.3,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23570,205,0,'100g',3,1,'2004-07-15','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23570,207,1.22,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23570,208,256,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23570,255,55.9,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23570,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23570,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23570,301,22,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23570,303,2.93,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23570,306,407,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23570,307,89,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23570,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23570,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23570,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23570,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23570,601,89,'100g',1,1,'2004-07-15','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23570,605,0.556,'100g',3,1,'2006-01-24','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23570,606,5.806,'100g',3,1,'2004-07-15','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23571,203,25.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23571,204,14.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23571,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23571,207,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23571,208,240,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (23571,255,58.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23571,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23571,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23571,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23571,303,2.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23571,306,286,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23571,307,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23571,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23571,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23571,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23571,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (23571,601,88,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23571,605,0.573,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23571,606,5.497,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23572,203,17.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23572,204,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23572,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23572,207,0.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23572,208,254,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23572,255,61.87,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23572,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23572,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23572,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23572,303,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23572,306,270,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23572,307,66,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23572,320,4,'100g',1,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23572,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23572,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23572,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23572,601,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23572,605,1.18,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23572,606,7.581,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23573,203,25.75,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23573,204,17.78,'100g',1,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23573,205,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23573,207,1,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23573,208,270,'100g',3,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23573,255,55.99,'100g',1,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23573,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23573,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23573,301,24,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23573,303,2.48,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23573,306,304,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23573,307,75,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23573,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23573,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23573,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23573,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23573,601,88,'100g',1,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23573,605,0.771,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23573,606,6.764,'100g',3,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23574,203,24.04,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23574,204,15.94,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23574,205,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23574,207,1.06,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23574,208,246,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23574,255,59.11,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23574,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23574,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23574,301,26,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23574,303,2.59,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23574,306,335,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23574,307,83,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23574,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23574,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23574,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23574,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23574,601,84,'100g',1,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23574,605,0.833,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23574,606,6.029,'100g',3,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23575,203,27,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23575,204,17.36,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23575,205,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23575,207,1.16,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23575,208,272,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23575,255,54.54,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23575,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23575,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23575,301,28,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23575,303,2.78,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23575,306,380,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23575,307,91,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23575,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23575,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23575,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23575,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23575,601,89,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23575,605,0.753,'100g',3,1,'2006-01-24','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23575,606,6.546,'100g',3,1,'2004-07-15','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23576,203,25.25,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23576,204,16.17,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23576,205,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23576,207,0.9,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23576,208,254,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23576,255,57.7,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23576,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23576,291,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23576,301,23,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23576,303,2.58,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23576,306,271,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23576,307,67,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23576,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23576,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23576,401,0,'100g',4,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23576,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (23576,601,88,'100g',1,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23576,605,0.773,'100g',3,1,'2006-02-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23576,606,6.159,'100g',3,1,'2006-02-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23577,203,15.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23577,204,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23577,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23577,207,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23577,208,293,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23577,255,58.09,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23577,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23577,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23577,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23577,303,1.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23577,306,244,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23577,307,66,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23577,320,4,'100g',1,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23577,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23577,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23577,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23577,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23577,605,1.5,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23577,606,9.568,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23578,203,25.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23578,204,18.87,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23578,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23578,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23578,208,279,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23578,255,55.28,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23578,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23578,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23578,301,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23578,303,2.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23578,306,289,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23578,307,78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23578,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23578,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23578,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23578,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23578,601,88,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23578,605,0.969,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23578,606,7.248,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23579,203,23.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23579,204,16.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23579,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23579,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23579,208,248,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23579,255,58.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23579,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23579,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23579,301,32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23579,303,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23579,306,322,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23579,307,87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23579,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23579,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23579,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23579,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23579,601,84,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23579,605,1.052,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23579,606,6.281,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23580,203,26.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23580,204,18.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23580,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23580,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23580,208,277,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23580,255,54.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23580,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23580,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23580,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23580,303,2.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23580,306,354,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23580,307,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23580,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23580,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23580,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23580,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23580,601,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23580,605,0.95,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23580,606,6.926,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23581,203,24.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23581,204,16.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23581,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23581,207,0.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23581,208,254,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23581,255,57.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23581,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23581,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23581,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23581,303,2.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23581,306,256,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23581,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23581,320,3,'100g',2,1,'2024-12-12','2014-01-06');
INSERT INTO `cndb_nutval` VALUES (23581,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23581,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23581,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (23581,601,88,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23581,605,0.973,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23581,606,6.356,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23582,203,22.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23582,204,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23582,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23582,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23582,208,134,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23582,255,72.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23582,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23582,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23582,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23582,303,1.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23582,306,353,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23582,307,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23582,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23582,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23582,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23582,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23582,601,73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23582,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23582,606,1.553,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23583,203,22.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23583,204,5.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23583,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23583,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23583,208,148,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23583,255,71.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23583,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23583,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23583,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23583,303,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23583,306,354,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23583,307,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23583,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23583,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23583,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23583,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23583,601,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23583,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23583,606,2.191,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23584,203,22.27,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23584,204,3.54,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23584,205,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23584,207,1.19,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23584,208,127,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23584,255,73.31,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23584,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23584,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23584,301,22,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23584,303,1.61,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23584,306,357,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23584,307,56,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23584,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23584,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23584,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23584,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23584,601,59,'100g',3,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23584,605,NULL,'100g',NULL,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23584,606,1.307,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23585,203,23.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23585,204,3.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23585,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23585,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23585,208,133,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23585,255,72.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23585,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23585,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23585,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23585,303,1.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23585,306,361,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23585,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23585,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23585,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23585,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23585,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23585,601,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23585,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23585,606,1.432,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23586,203,30.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23586,204,6.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23586,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23586,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23586,208,188,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23586,255,62.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23586,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23586,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23586,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23586,303,1.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23586,306,409,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23586,307,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23586,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23586,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23586,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23586,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23586,601,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23586,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23586,606,2.369,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23587,203,29.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23587,204,7.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23587,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23587,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23587,208,194,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23587,255,62.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23587,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23587,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23587,301,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23587,303,1.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23587,306,386,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23587,307,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23587,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23587,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23587,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23587,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23587,601,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23587,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23587,606,2.953,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23588,203,29.34,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23588,204,4.96,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23588,205,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23588,207,1.2,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23588,208,170,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23588,255,65.47,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23588,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23588,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23588,301,21,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23588,303,1.81,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23588,306,386,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23588,307,62,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23588,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23588,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23588,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23588,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23588,601,77,'100g',3,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23588,605,NULL,'100g',NULL,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23588,606,1.889,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23589,203,29.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23589,204,5.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23589,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23589,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23589,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23589,255,64.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23589,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23589,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23589,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23589,303,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23589,306,386,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23589,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23589,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23589,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23589,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23589,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23589,601,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23589,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23589,606,2.183,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23590,203,28.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23590,204,4.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23590,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23590,207,1.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23590,208,164,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23590,255,66.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23590,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23590,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23590,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23590,303,2.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23590,306,238,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23590,307,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23590,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23590,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23590,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23590,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23590,601,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23590,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23590,606,1.608,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23591,203,29.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23591,204,4.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23591,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23591,207,1.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23591,208,163,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23591,255,66.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23591,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23591,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23591,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23591,303,2.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23591,306,245,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23591,307,39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23591,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23591,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23591,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23591,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23591,601,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23591,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23591,606,1.416,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23592,203,31.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23592,204,4.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23592,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23592,207,1.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23592,208,177,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23592,255,62.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23592,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23592,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23592,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23592,303,2.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23592,306,270,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23592,307,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23592,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23592,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23592,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23592,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23592,601,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23592,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23592,606,1.602,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23593,203,34.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23593,204,6.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23593,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23593,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23593,208,205,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23593,255,58.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23593,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23593,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23593,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23593,303,2.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23593,306,289,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23593,307,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23593,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23593,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23593,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23593,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23593,601,92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23593,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23593,606,2.216,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23594,203,22.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23594,204,4.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23594,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23594,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23594,208,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23594,255,72.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23594,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23594,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23594,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23594,303,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23594,306,350,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23594,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23594,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23594,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23594,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23594,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23594,601,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23594,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23594,606,1.476,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23595,203,33.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23595,204,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23595,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23595,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23595,208,196,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23595,255,60.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23595,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23595,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23595,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23595,303,2.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23595,306,266,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23595,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23595,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23595,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23595,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23595,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23595,601,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23595,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23595,606,2.274,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23596,203,21.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23596,204,3.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23596,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23596,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23596,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23596,255,73.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23596,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23596,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23596,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23596,303,1.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23596,306,336,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23596,307,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23596,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23596,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23596,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23596,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23596,601,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23596,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23596,606,1.425,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23597,203,22.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23597,204,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23597,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23597,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23597,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23597,255,73.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23597,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23597,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23597,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23597,303,1.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23597,306,357,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23597,307,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23597,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23597,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23597,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23597,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23597,601,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23597,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23597,606,1.027,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23598,203,29.73,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23598,204,4.71,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23598,205,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23598,207,1.15,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23598,208,169,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23598,255,65.52,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23598,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23598,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23598,301,6,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23598,303,2.46,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23598,306,241,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23598,307,38,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23598,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23598,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23598,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23598,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23598,601,76,'100g',3,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23598,605,NULL,'100g',NULL,1,'2004-07-15','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23598,606,1.624,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23599,203,22.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23599,204,5.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23599,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23599,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23599,208,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23599,255,69.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23599,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23599,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23599,301,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23599,303,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23599,306,347,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23599,307,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23599,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23599,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23599,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23599,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23599,601,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23599,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23599,606,1.864,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23600,203,29.04,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23600,204,8.39,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23600,205,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23600,207,1.13,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23600,208,200,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23600,255,62.93,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23600,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23600,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23600,301,19,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23600,303,1.84,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23600,306,370,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23600,307,60,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23600,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23600,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23600,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23600,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23600,601,82,'100g',3,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23600,605,NULL,'100g',NULL,1,'2004-07-15','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (23600,606,3.195,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23601,203,22.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23601,204,6.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23601,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23601,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23601,208,153,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23601,255,70.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23601,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23601,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23601,301,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23601,303,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23601,306,347,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23601,307,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23601,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23601,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23601,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23601,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23601,601,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23601,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23601,606,2.412,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23602,203,34.66,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23602,204,7.36,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23602,205,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23602,207,1.02,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23602,208,214,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23602,255,57.84,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23602,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23602,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23602,301,16,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23602,303,2.93,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23602,306,277,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23602,307,56,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23602,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23602,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23602,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23602,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23602,601,104,'100g',3,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23602,605,NULL,'100g',NULL,1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (23602,606,2.788,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23603,203,22.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23603,204,4.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23603,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23603,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23603,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23603,255,73.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23603,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23603,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23603,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23603,303,1.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23603,306,337,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23603,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23603,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23603,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23603,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23603,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23603,601,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23603,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23603,606,1.553,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23604,203,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23604,204,5.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23604,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23604,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23604,208,163,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23604,255,65.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23604,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23604,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23604,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23604,303,2.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23604,306,230,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23604,307,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23604,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23604,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23604,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23604,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23604,601,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23604,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23604,606,1.972,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23605,203,34.34,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23605,204,7.73,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23605,205,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23605,207,1.02,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23605,208,216,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23605,255,57.54,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23605,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23605,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23605,301,7,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23605,303,2.87,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23605,306,282,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23605,307,45,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23605,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23605,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23605,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23605,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23605,601,94,'100g',3,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23605,605,NULL,'100g',NULL,1,'2004-07-15','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (23605,606,2.663,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23606,203,29.3,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23606,204,7.09,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23606,205,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23606,207,1.14,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23606,208,189,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23606,255,63.32,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23606,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23606,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23606,301,19,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23606,303,1.85,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23606,306,372,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23606,307,61,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23606,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23606,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23606,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23606,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23606,601,81,'100g',3,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23606,605,NULL,'100g',NULL,1,'2004-07-15','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (23606,606,2.7,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23607,203,22.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23607,204,5.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23607,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23607,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23607,208,138,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23607,255,71.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23607,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23607,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23607,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23607,303,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23607,306,354,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23607,307,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23607,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23607,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23607,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23607,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23607,601,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23607,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23607,606,1.905,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23608,203,31.82,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23608,204,5.45,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23608,205,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23608,207,1.2,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23608,208,185,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23608,255,61.96,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23608,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23608,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23608,301,7,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23608,303,2.7,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23608,306,264,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23608,307,42,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23608,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23608,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23608,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23608,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23608,601,84,'100g',3,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23608,605,NULL,'100g',NULL,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23608,606,1.878,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23609,203,22.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23609,204,4.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23609,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23609,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23609,208,135,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23609,255,75.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23609,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23609,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23609,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23609,303,1.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23609,306,362,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23609,307,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23609,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23609,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23609,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23609,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23609,601,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23609,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23609,606,1.399,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23610,203,29.42,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23610,204,5.84,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23610,205,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23610,207,1.2,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23610,208,178,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23610,255,64.29,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23610,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23610,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23610,301,19,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23610,303,1.87,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23610,306,376,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23610,307,61,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23610,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23610,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23610,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23610,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23610,601,79,'100g',3,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23610,605,NULL,'100g',NULL,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23610,606,2.224,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23611,203,22.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23611,204,4.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23611,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23611,207,1.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23611,208,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23611,255,72.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23611,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23611,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23611,301,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23611,303,1.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23611,306,349,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23611,307,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23611,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23611,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23611,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23611,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23611,601,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23611,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23611,606,1.508,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23612,203,21.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23612,204,5.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23612,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23612,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23612,208,139,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23612,255,72.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23612,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23612,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23612,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23612,303,2.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23612,306,332,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23612,307,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23612,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23612,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23612,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23612,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23612,601,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23612,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23612,606,1.875,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23613,203,21.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23613,204,4.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23613,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23613,207,1.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23613,208,129,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23613,255,73.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23613,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23613,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23613,301,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23613,303,2.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23613,306,335,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23613,307,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23613,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23613,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23613,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23613,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23613,601,65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23613,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23613,606,1.508,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23614,203,34.72,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23614,204,8.37,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23614,205,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23614,207,1.03,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23614,208,224,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23614,255,56.39,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23614,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23614,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23614,301,15,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23614,303,3.04,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23614,306,275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23614,307,56,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23614,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23614,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23614,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23614,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23614,601,106,'100g',3,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23614,605,NULL,'100g',NULL,1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (23614,606,3.17,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23615,203,33.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23615,204,6.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23615,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23615,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23615,208,203,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23615,255,59.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23615,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23615,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23615,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23615,303,2.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23615,306,261,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23615,307,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23615,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23615,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23615,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23615,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23615,601,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23615,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23615,606,2.572,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23616,203,22.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23616,204,3.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23616,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23616,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23616,208,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23616,255,72.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23616,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23616,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23616,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23616,303,2.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23616,306,351,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23616,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23616,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23616,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23616,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23616,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23616,601,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23616,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23616,606,1.158,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23617,203,22.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23617,204,4.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23617,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23617,207,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23617,208,140,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23617,255,71.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23617,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23617,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23617,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23617,303,2.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23617,306,352,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23617,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23617,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23617,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23617,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23617,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23617,601,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23617,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23617,606,1.637,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23618,203,22.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23618,204,4.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23618,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23618,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23618,208,140,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23618,255,71.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23618,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23618,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23618,301,19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23618,303,2.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23618,306,341,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23618,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23618,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23618,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23618,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23618,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23618,601,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23618,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23618,606,1.699,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23619,203,27.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23619,204,6.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23619,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23619,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23619,208,179,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23619,255,65.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23619,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23619,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23619,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23619,303,2.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23619,306,225,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23619,307,36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23619,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23619,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23619,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23619,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23619,601,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23619,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23619,606,2.334,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23620,203,29.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23620,204,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23620,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23620,207,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23620,208,175,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23620,255,64.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23620,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23620,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23620,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23620,303,2.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23620,306,241,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23620,307,39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23620,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23620,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23620,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23620,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23620,601,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23620,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23620,606,1.828,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23621,203,32.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23621,204,6.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23621,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23621,207,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23621,208,193,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23621,255,61.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23621,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23621,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23621,301,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23621,303,2.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23621,306,263,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23621,307,42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23621,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23621,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23621,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23621,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23621,601,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23621,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23621,606,2.154,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23622,203,34.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23622,204,9.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23622,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23622,207,0.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23622,208,228,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23622,255,56.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23622,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23622,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23622,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23622,303,3.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23622,306,278,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23622,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23622,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23622,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23622,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23622,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23622,601,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23622,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23622,606,3.109,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23623,203,22.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23623,204,5.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23623,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23623,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23623,208,148,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23623,255,71.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23623,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23623,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23623,301,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23623,303,1.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23623,306,341,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23623,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23623,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23623,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23623,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23623,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23623,601,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23623,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23623,606,2.183,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23624,203,22.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23624,204,7.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23624,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23624,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23624,208,158,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23624,255,70.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23624,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23624,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23624,301,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23624,303,1.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23624,306,340,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23624,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23624,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23624,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23624,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23624,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23624,601,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23624,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23624,606,2.612,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23625,203,21.91,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23625,204,4.62,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23625,205,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23625,207,1.09,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23625,208,135,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23625,255,72.51,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23625,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23625,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23625,301,28,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23625,303,1.63,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23625,306,342,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23625,307,57,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23625,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23625,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23625,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23625,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23625,601,61,'100g',3,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23625,605,NULL,'100g',NULL,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23625,606,1.709,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23626,203,28.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23626,204,9.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23626,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23626,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23626,208,202,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23626,255,62.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23626,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23626,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23626,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23626,303,1.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23626,306,352,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23626,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23626,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23626,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23626,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23626,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23626,601,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23626,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23626,606,3.445,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23627,203,22.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23627,204,6.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23627,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23627,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23627,208,155,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23627,255,70.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23627,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23627,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23627,301,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23627,303,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23627,306,348,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23627,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23627,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23627,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23627,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23627,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23627,601,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23627,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23627,606,2.378,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23628,203,29.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23628,204,9.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23628,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23628,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23628,208,206,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23628,255,61.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23628,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23628,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23628,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23628,303,1.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23628,306,358,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23628,307,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23628,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23628,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23628,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23628,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23628,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23628,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23628,606,3.465,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23629,203,29.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23629,204,6.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23629,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23629,207,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23629,208,187,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23629,255,63.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23629,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23629,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23629,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23629,303,2.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23629,306,369,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23629,307,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23629,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23629,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23629,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23629,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23629,601,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23629,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23629,606,2.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23630,203,29.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23630,204,8.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23630,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23630,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23630,208,201,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23630,255,61.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23630,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23630,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23630,301,16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23630,303,1.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23630,306,362,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23630,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23630,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23630,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23630,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23630,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23630,601,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23630,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23630,606,3.217,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23631,203,22.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23631,204,3.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23631,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23631,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23631,208,125,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23631,255,74.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23631,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23631,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23631,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23631,303,1.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23631,306,339,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23631,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23631,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23631,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23631,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23631,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23631,601,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23631,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23631,606,1.232,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23632,203,21.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23632,204,3.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23632,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23632,207,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23632,208,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23632,255,74.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23632,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23632,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23632,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23632,303,1.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23632,306,333,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23632,307,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23632,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23632,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23632,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23632,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23632,601,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23632,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23632,606,1.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23633,203,34.6,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23633,204,6.35,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23633,205,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23633,207,1.02,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23633,208,205,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23633,255,59.29,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23633,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23633,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23633,301,17,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23633,303,2.89,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23633,306,281,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23633,307,57,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23633,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23633,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23633,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23633,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23633,601,103,'100g',3,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23633,605,NULL,'100g',NULL,1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (23633,606,2.406,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23634,203,33.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23634,204,5.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23634,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23634,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23634,208,189,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23634,255,61.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23634,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23634,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23634,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23634,303,2.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23634,306,273,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23634,307,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23634,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23634,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23634,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23634,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23634,601,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23634,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23634,606,1.973,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23635,203,22.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23635,204,2.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23635,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23635,207,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23635,208,119,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23635,255,73.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23635,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23635,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23635,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23635,303,1.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23635,306,364,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23635,307,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23635,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23635,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23635,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23635,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23635,601,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23635,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23635,606,0.898,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23636,203,23.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23636,204,3.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23636,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23636,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23636,208,129,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23636,255,72.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23636,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23636,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23636,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23636,303,1.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23636,306,373,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23636,307,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23636,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23636,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23636,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23636,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23636,601,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23636,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23636,606,1.154,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23637,203,22.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23637,204,3.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23637,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23637,207,1.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23637,208,128,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23637,255,73.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23637,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23637,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23637,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23637,303,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23637,306,361,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23637,307,62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23637,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23637,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23637,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23637,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23637,601,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23637,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23637,606,1.253,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23638,203,29.58,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23638,204,7.63,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23638,205,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23638,207,1.15,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23638,208,195,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23638,255,64.27,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23638,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23638,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23638,301,19,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23638,303,1.88,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23638,306,378,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23638,307,62,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23638,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23638,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23638,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23638,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23638,601,87,'100g',3,1,'2004-07-15','2011-01-18');
INSERT INTO `cndb_nutval` VALUES (23638,605,NULL,'100g',NULL,1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (23638,606,2.907,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (23640,203,11.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23640,204,4.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23640,205,1.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23640,207,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23640,208,94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23640,255,81.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23640,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23640,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23640,301,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23640,303,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23640,306,42,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23640,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23640,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (23640,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23640,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23640,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23640,601,157,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23640,605,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23640,606,1.357,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23646,203,21.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23646,204,5.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23646,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23646,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23646,208,142,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23646,255,72.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23646,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23646,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23646,301,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23646,303,1.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23646,306,333,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23646,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23646,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (23646,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23646,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23646,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23646,601,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23646,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23646,606,1.729,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23647,203,26.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23647,204,9.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23647,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23647,207,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23647,208,193,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23647,255,63.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23647,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23647,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23647,301,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23647,303,1.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23647,306,324,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23647,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23647,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (23647,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23647,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23647,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23647,601,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23647,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23647,606,3.527,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23648,203,21.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23648,204,7.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23648,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23648,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23648,208,154,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23648,255,71.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23648,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23648,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23648,301,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23648,303,1.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23648,306,323,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23648,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23648,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (23648,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23648,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23648,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23648,601,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23648,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23648,606,2.132,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23649,203,27.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23649,204,6.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23649,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23649,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23649,208,179,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23649,255,65.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23649,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23649,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23649,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23649,303,1.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23649,306,359,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23649,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23649,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (23649,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23649,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23649,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23649,601,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23649,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23649,606,2.517,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23650,203,21.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23650,204,4.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23650,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23650,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23650,208,129,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23650,255,73.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23650,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23650,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23650,301,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23650,303,1.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23650,306,344,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23650,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23650,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (23650,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23650,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23650,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23650,601,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23650,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23650,606,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23651,203,21.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23651,204,3.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23651,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23651,207,1.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23651,208,126,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23651,255,74.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23651,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23651,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23651,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23651,303,1.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23651,306,323,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23651,307,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23651,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (23651,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23651,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23651,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23651,601,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23651,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23651,606,1.376,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23652,203,20.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23652,204,4.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23652,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23652,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23652,208,130,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23652,255,73.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23652,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23652,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23652,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23652,303,1.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23652,306,318,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23652,307,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23652,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (23652,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23652,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23652,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23652,601,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23652,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23652,606,1.556,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23653,203,21.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23653,204,3.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23653,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23653,207,1.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23653,208,122,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23653,255,74.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23653,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23653,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23653,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23653,303,1.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23653,306,337,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23653,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23653,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (23653,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23653,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23653,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23653,601,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23653,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23653,606,1.147,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23654,203,27.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23654,204,7.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23654,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23654,207,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23654,208,186,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23654,255,64.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23654,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23654,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23654,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23654,303,1.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23654,306,350,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23654,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23654,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (23654,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23654,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23654,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23654,601,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23654,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23654,606,3.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23655,203,27.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23655,204,6.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23655,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23655,207,1.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23655,208,178,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23655,255,65.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23655,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23655,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23655,301,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23655,303,1.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23655,306,365,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23655,307,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23655,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (23655,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23655,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23655,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23655,601,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23655,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23655,606,2.688,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23656,203,21.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23656,204,5.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23656,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23656,207,1.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23656,208,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23656,255,72.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23656,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23656,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23656,301,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23656,303,1.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23656,306,340,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23656,307,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23656,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (23656,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23656,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23656,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23656,601,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23656,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23656,606,2.058,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23657,203,21.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23657,204,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23657,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23657,207,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23657,208,137,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23657,255,72.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23657,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23657,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23657,301,21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23657,303,1.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23657,306,341,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23657,307,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23657,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (23657,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23657,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23657,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23657,601,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23657,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23657,606,2.074,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23658,203,18.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23658,204,22.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23658,205,0.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23658,207,0.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23658,208,278,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23658,255,58.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23658,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23658,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23658,301,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23658,303,1.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23658,306,281,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23658,307,61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23658,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (23658,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23658,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23658,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23658,601,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23658,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23658,606,8.939,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23659,203,17.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23659,204,22.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23659,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23659,207,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23659,208,276,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23659,255,59.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23659,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23659,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23659,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23659,303,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23659,306,271,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23659,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23659,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (23659,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23659,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23659,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23659,601,94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23659,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23659,606,8.963,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (23660,203,28.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23660,204,19.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23660,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23660,207,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23660,208,298,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23660,255,51.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23660,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23660,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23660,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23660,303,2.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23660,306,227,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23660,307,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23660,320,0,'100g',1,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (23660,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (23660,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23660,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (23660,601,107,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23660,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (23660,606,8.219,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25000,203,10.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25000,204,6.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25000,205,76.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25000,207,2.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25000,208,402,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25000,255,4.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25000,269,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25000,291,13.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25000,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25000,303,2.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25000,306,284,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25000,307,571,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25000,320,13,'100g',1,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (25000,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25000,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25000,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25000,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25000,605,0.885,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25000,606,1.184,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25001,203,12.6,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25001,204,9.5,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25001,205,72,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25001,207,3.1,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25001,208,424,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25001,255,2.8,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25001,269,0.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25001,291,14.2,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25001,301,11,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25001,303,2.28,'100g',1,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25001,306,241,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25001,307,629,'100g',6,1,'2007-12-03','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (25001,320,12,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (25001,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25001,401,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25001,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25001,601,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25001,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25001,606,1.415,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25003,203,0.46,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25003,204,6.53,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25003,205,74.64,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25003,207,0.77,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25003,208,359,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25003,255,17.59,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25003,269,39.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25003,291,3.3,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25003,301,430,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25003,303,0.56,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25003,306,100,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25003,307,8,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25003,320,0,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (25003,328,0,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (25003,401,260.8,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25003,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25003,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25003,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25003,606,5.096,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25012,203,2.94,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25012,204,32.35,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25012,205,56.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25012,207,3.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25012,208,532,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25012,255,4.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25012,269,8.82,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25012,291,8.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25012,301,59,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25012,303,2.12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25012,306,925,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25012,307,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25012,320,1184,'100g',2,1,'2024-12-12','2011-01-02');
INSERT INTO `cndb_nutval` VALUES (25012,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25012,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25012,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25012,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25012,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25012,606,2.941,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25014,203,7.5,'100g',1,1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (25014,204,34.02,'100g',1,1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (25014,205,55.16,'100g',3,1,'2007-12-03','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25014,207,2.98,'100g',1,1,'2007-12-03','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25014,208,557,'100g',3,1,'2007-12-03','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (25014,255,0.34,'100g',1,1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (25014,269,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25014,291,10,'100g',1,1,'2009-02-13','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25014,301,20,'100g',1,1,'2007-12-03','2009-01-27');
INSERT INTO `cndb_nutval` VALUES (25014,303,1.85,'100g',1,1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (25014,306,240,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25014,307,764,'100g',1,1,'2007-12-03','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25014,320,22,'100g',2,1,'2024-12-12','2013-01-07');
INSERT INTO `cndb_nutval` VALUES (25014,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25014,401,0.1,'100g',3,1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (25014,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25014,601,0,'100g',3,1,'2007-12-03','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (25014,605,9.802,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25014,606,7.216,'100g',3,1,'2007-12-03','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25024,203,8.2,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25024,204,3.1,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25024,205,71.04,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25024,207,2.66,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25024,208,345,'100g',3,1,'2007-12-03','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25024,255,15,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25024,269,0.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25024,291,1.7,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25024,301,23,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25024,303,3.92,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25024,306,88,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25024,307,252,'100g',6,1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (25024,320,0,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (25024,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25024,401,0,'100g',4,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25024,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25024,601,0,'100g',3,1,'2007-12-03','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (25024,605,NULL,'100g',NULL,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25024,606,0.695,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25025,203,26.5,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25025,204,7.35,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25025,205,53.15,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25025,207,4.5,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25025,208,385,'100g',3,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25025,255,8.5,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25025,269,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25025,291,3.5,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25025,301,171,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25025,303,5.2,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25025,306,7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25025,307,842,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25025,320,0,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (25025,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25025,401,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25025,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25025,601,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25025,605,0,'100g',3,1,'2007-12-03','2007-12-03');
INSERT INTO `cndb_nutval` VALUES (25025,606,1.102,'100g',3,1,'2007-12-03','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25026,203,8.38,'100g',1,1,'2009-01-25','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25026,204,30.22,'100g',1,1,'2009-01-25','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25026,205,57.26,'100g',3,1,'2009-01-25','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25026,207,3.23,'100g',1,1,'2009-01-25','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25026,208,535,'100g',3,1,'2009-01-25','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25026,255,0.9,'100g',1,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (25026,269,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25026,291,10,'100g',1,1,'2009-01-25','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25026,301,23,'100g',1,1,'2009-01-25','2012-09-01');
INSERT INTO `cndb_nutval` VALUES (25026,303,2.06,'100g',1,1,'2009-01-25','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25026,306,393,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25026,307,763,'100g',1,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (25026,320,9,'100g',2,1,'2024-12-12','2016-01-07');
INSERT INTO `cndb_nutval` VALUES (25026,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25026,401,0,'100g',1,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (25026,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25026,601,0,'100g',3,1,'2009-01-25','2009-01-25');
INSERT INTO `cndb_nutval` VALUES (25026,605,0.853,'100g',3,1,'2009-01-27','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (25026,606,14.598,'100g',3,1,'2009-01-25','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (25027,203,2.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25027,204,29.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25027,205,63.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25027,207,2.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25027,208,531,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25027,255,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25027,269,0.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25027,291,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25027,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25027,303,0.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25027,306,786,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25027,307,202,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25027,320,69,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (25027,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25027,401,32.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25027,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25027,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25027,605,0.185,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25027,606,8.337,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25028,203,6.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25028,204,22.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25028,205,67.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25028,207,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25028,208,497,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25028,255,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25028,269,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25028,291,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25028,301,104,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25028,303,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25028,306,206,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25028,307,310,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25028,320,8,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (25028,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25028,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25028,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25028,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25028,605,0.066,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (25028,606,2.776,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25035,203,5.55,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25035,204,12.5,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25035,205,69.4,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25035,207,0.9,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25035,208,412,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25035,255,11.65,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25035,269,20.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25035,291,3.1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25035,301,417,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25035,303,2.03,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25035,306,199,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25035,307,312,'100g',6,1,'2010-01-04','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (25035,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (25035,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25035,401,0.1,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25035,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25035,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25035,605,0,'100g',6,1,'2010-01-04','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (25035,606,5.008,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25036,203,7.17,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25036,204,17.5,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25036,205,66.27,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25036,207,1.12,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25036,208,451,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25036,255,7.88,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25036,269,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25036,291,5.7,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25036,301,41,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25036,303,1.56,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25036,306,285,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25036,307,167,'100g',3,1,'2010-01-04','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (25036,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (25036,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25036,401,0.2,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25036,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25036,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25036,605,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25036,606,9.888,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25037,203,11.79,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25037,204,15.2,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25037,205,68.26,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25037,207,2.75,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25037,208,457,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25037,255,2,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25037,269,4.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25037,291,3.8,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25037,301,17,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25037,303,4.59,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25037,306,129,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25037,307,854,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25037,320,0,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (25037,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25037,401,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25037,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25037,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25037,605,0.038,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25037,606,1.342,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25038,203,8.6,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25038,204,20,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25038,205,60.13,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25038,207,2.53,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25038,208,455,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25038,255,8.74,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25038,269,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25038,291,4.3,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25038,301,136,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25038,303,1.49,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25038,306,320,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25038,307,486,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25038,320,5,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (25038,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25038,401,0.2,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25038,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25038,601,0,'100g',3,1,'2010-01-04','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (25038,605,0.005,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25038,606,5.668,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25040,203,5.32,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25040,204,23.3,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25040,205,60.43,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25040,207,4.64,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25040,208,473,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25040,255,6.31,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25040,269,4.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25040,291,4.7,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25040,301,52,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25040,303,1.55,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25040,306,838,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25040,307,412,'100g',3,1,'2010-01-04','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (25040,320,9,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (25040,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25040,401,4.9,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25040,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25040,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25040,605,0.091,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25040,606,1.762,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25043,203,0,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25043,204,7.5,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25043,205,86.9,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25043,207,1.87,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25043,208,415,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25043,255,3.73,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25043,269,65,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25043,291,0.2,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25043,301,500,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25043,303,0.19,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25043,306,338,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25043,307,75,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25043,320,1,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (25043,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25043,401,180,'100g',6,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25043,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25043,601,3,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25043,605,NULL,'100g',NULL,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25043,606,1.389,'100g',3,1,'2010-01-04','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25045,203,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25045,204,10,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25045,205,69.82,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (25045,207,3.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25045,208,389,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (25045,255,12.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25045,269,25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25045,291,22.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25045,301,250,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25045,303,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25045,306,447,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25045,307,237,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (25045,320,0,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (25045,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25045,401,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25045,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25045,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25045,605,0.007,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25045,606,3.397,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25046,203,12.34,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25046,204,15.14,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25046,205,66.36,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25046,207,1.1,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25046,208,451,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25046,255,5.05,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25046,269,6.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25046,291,4.1,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25046,301,24,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25046,303,5.05,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25046,306,140,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25046,307,233,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25046,320,0,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (25046,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25046,401,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25046,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25046,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25046,605,0.057,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25046,606,6.835,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (25050,203,1.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25050,204,25.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25050,205,69.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25050,207,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25050,208,515,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25050,255,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25050,269,3.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25050,291,3.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25050,301,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25050,303,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25050,306,868,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25050,307,296,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25050,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (25050,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25050,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25050,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25050,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25050,605,0.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25050,606,8.689,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25059,203,8.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25059,204,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25059,205,81.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25059,207,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25059,208,384,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25059,255,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25059,269,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25059,291,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25059,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25059,303,1.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25059,306,290,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25059,307,326,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25059,320,0,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (25059,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25059,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25059,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25059,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25059,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25059,606,0.642,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25060,203,7.05,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25060,204,17.64,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25060,205,70.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25060,207,2.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25060,208,467,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25060,255,3.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25060,269,38.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25060,291,3.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25060,301,141,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25060,303,2.54,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25060,306,199,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25060,307,494,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25060,320,25,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (25060,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25060,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25060,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25060,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25060,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25060,606,8.611,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25062,203,13.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25062,204,10.53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25062,205,58.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25062,207,1.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25062,208,383,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25062,255,15.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25062,269,26.32,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25062,291,7.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25062,301,105,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25062,303,1.89,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25062,306,446,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25062,307,447,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25062,320,27,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (25062,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25062,401,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25062,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25062,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25062,605,0.001,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25062,606,3.846,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25063,203,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25063,204,24.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25063,205,65.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25063,207,2.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25063,208,505,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25063,255,2.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25063,269,4.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25063,291,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25063,301,26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25063,303,0.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25063,306,330,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25063,307,544,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25063,320,0,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (25063,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25063,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25063,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25063,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25063,605,0.149,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (25063,606,6.307,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25064,203,6.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25064,204,35.39,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25064,205,53.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25064,207,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25064,208,560,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25064,255,1.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25064,269,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25064,291,4.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25064,301,24,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25064,303,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25064,306,1304,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25064,307,187,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25064,320,0,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (25064,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25064,401,27.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25064,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25064,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25064,605,0.215,'100g',7,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (25064,606,5.49,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (25065,203,3.52,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25065,204,6.67,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25065,205,78.62,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25065,207,4.28,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25065,208,389,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25065,255,6.91,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25065,269,4.22,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25065,291,3.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25065,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25065,303,0.46,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25065,306,69,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25065,307,1567,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25065,320,0,'100g',2,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (25065,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25065,401,0.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25065,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25065,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25065,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (25065,606,3.307,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25066,203,14.11,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25066,204,14.11,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25066,205,62.2,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25066,207,2.65,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25066,208,432,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25066,255,6.93,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25066,269,14.11,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25066,291,3.8,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25066,301,123,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25066,303,3.8,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25066,306,732,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25066,307,300,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25066,320,77,'100g',2,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (25066,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25066,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25066,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25066,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25066,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (25066,606,5.29,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25070,203,7.14,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25070,204,17.86,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25070,205,59.09,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25070,207,2.31,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25070,208,426,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25070,255,13.6,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25070,269,21.43,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25070,291,5.6,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25070,301,20,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25070,303,1.91,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25070,306,193,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25070,307,571,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25070,320,0,'100g',2,1,'2024-12-12','2015-01-08');
INSERT INTO `cndb_nutval` VALUES (25070,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25070,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25070,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25070,601,2,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25070,605,0.066,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25070,606,5.357,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25071,203,10,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25071,204,5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25071,205,82.64,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25071,207,2.24,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25071,208,416,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25071,255,0.11,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25071,269,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25071,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25071,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25071,303,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25071,306,243,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25071,307,233,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25071,320,0,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (25071,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (25071,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25071,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (25071,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25071,605,0.002,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (25071,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27035,203,10.89,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (27035,204,2.5,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (27035,205,70.95,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (27035,207,3.59,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (27035,208,350,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (27035,255,12.08,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (27035,269,0.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27035,291,2.7,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (27035,301,22,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (27035,303,4.52,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (27035,306,128,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27035,307,1200,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (27035,320,0,'100g',2,1,'2024-12-12','2009-01-04');
INSERT INTO `cndb_nutval` VALUES (27035,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27035,401,1.2,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (27035,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27035,601,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (27035,605,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (27035,606,0,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (27043,203,2.33,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27043,204,4.23,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27043,205,5.68,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27043,207,1.23,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27043,208,70,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27043,255,86.53,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27043,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27043,291,0.8,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27043,301,14,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27043,303,0.56,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27043,306,337,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27043,307,194,'100g',1,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27043,320,8,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (27043,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27043,401,3.3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27043,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27043,601,3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27043,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27043,606,0.701,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27044,203,3.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27044,204,1.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27044,205,3.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27044,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27044,208,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27044,255,90.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27044,269,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27044,291,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27044,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27044,303,0.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27044,306,285,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27044,307,186,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27044,320,49,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (27044,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27044,401,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27044,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27044,601,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27044,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27044,606,0.394,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (27046,203,0.36,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27046,204,0.13,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27046,205,60.66,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (27046,207,1.4,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27046,208,245,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27046,255,37.44,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27046,269,30.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27046,291,0.6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27046,301,11,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27046,303,0.39,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27046,306,87,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27046,307,712,'100g',6,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (27046,320,8,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (27046,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27046,401,0.9,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27046,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27046,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27046,605,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27046,606,0.051,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27047,203,1.13,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27047,204,0.89,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27047,205,6.36,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27047,207,2.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27047,208,38,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27047,255,89.52,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27047,269,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27047,291,1.9,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27047,301,9,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27047,303,0.65,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27047,306,259,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27047,307,906,'100g',6,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (27047,320,11,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (27047,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27047,401,12.3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27047,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27047,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27047,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27047,606,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27048,203,1.25,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27048,204,0.23,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27048,205,22.04,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27048,207,5.08,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27048,208,95,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27048,255,71,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27048,269,9.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27048,291,1.5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27048,301,19,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27048,303,1.37,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27048,306,312,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27048,307,1647,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27048,320,15,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (27048,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27048,401,6.8,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27048,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27048,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27048,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27048,606,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27049,203,1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27049,204,16.7,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27049,205,13.3,'100g',6,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27049,207,1.96,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27049,208,211,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27049,255,67,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27049,269,4.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27049,291,0.5,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27049,301,26,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27049,303,0.25,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27049,306,68,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27049,307,667,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27049,320,11,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (27049,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27049,401,2.3,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27049,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27049,601,7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27049,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27049,606,3.333,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27050,203,0.27,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27050,204,0.02,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27050,205,38.22,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27050,207,1.22,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27050,208,154,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (27050,255,60.27,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27050,269,18.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27050,291,0.1,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27050,301,10,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27050,303,0.21,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27050,306,99,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27050,307,539,'100g',6,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (27050,320,1,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (27050,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27050,401,8.7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27050,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27050,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27050,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27050,606,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27051,203,1.36,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27051,204,1.05,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27051,205,28.22,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27051,207,3.7,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27051,208,128,'100g',3,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (27051,255,65.67,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27051,269,11.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27051,291,1.8,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27051,301,26,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27051,303,0.83,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27051,306,309,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27051,307,1262,'100g',6,1,'2012-03-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (27051,320,18,'100g',2,1,'2024-12-12','2011-01-04');
INSERT INTO `cndb_nutval` VALUES (27051,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27051,401,11.6,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27051,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27051,601,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27051,605,NULL,'100g',NULL,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27051,606,0,'100g',3,1,'2012-03-02',NULL);
INSERT INTO `cndb_nutval` VALUES (27052,203,3.14,'100g',1,1,'2012-03-02','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (27052,204,9.51,'100g',1,1,'2012-03-02','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (27052,205,11.14,'100g',3,1,'2012-03-02','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (27052,207,2.49,'100g',1,1,'2012-03-02','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (27052,208,143,'100g',3,1,'2012-03-02','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (27052,255,73.72,'100g',1,1,'2012-03-02','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (27052,269,1.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27052,291,0.7,'100g',1,1,'2012-03-02','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (27052,301,98,'100g',1,1,'2012-03-02','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (27052,303,0.14,'100g',1,1,'2012-03-02','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (27052,306,105,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27052,307,796,'100g',1,1,'2012-03-02','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (27052,320,33,'100g',1,1,'2024-12-12','2012-01-07');
INSERT INTO `cndb_nutval` VALUES (27052,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27052,401,0.4,'100g',1,1,'2012-03-02','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (27052,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27052,601,9,'100g',1,1,'2012-03-02','2012-07-01');
INSERT INTO `cndb_nutval` VALUES (27052,605,0.097,'100g',3,1,'2012-03-02','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (27052,606,2.491,'100g',3,1,'2012-03-02','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (27059,203,6.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27059,204,16.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27059,205,22.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27059,207,4.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27059,208,257,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27059,255,51.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27059,269,17.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27059,291,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27059,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27059,303,0.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27059,306,235,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27059,307,1338,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27059,320,0,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (27059,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27059,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27059,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27059,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (27059,605,0.035,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (27059,606,2.907,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (27060,203,1.16,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27060,204,0.51,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27060,205,10.28,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27060,207,1.14,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27060,208,50,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27060,255,86.91,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27060,269,2.78,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27060,291,1.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27060,301,25,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27060,303,0.4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27060,306,349,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27060,307,138,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27060,320,58,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (27060,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27060,401,0.7,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27060,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27060,601,1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27060,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (27060,606,0.217,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27062,203,2.81,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27062,204,0.96,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27062,205,7.94,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27062,207,0.94,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27062,208,52,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27062,255,87.35,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27062,269,1.22,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27062,291,0.9,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27062,301,11,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27062,303,0.45,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27062,306,121,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27062,307,297,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27062,320,14,'100g',1,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (27062,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27062,401,0.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27062,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27062,601,4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27062,605,0.034,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27062,606,0.329,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27063,203,0.62,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27063,204,0.91,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27063,205,4.87,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27063,207,1.82,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27063,208,30,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27063,255,91.78,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27063,269,1.83,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27063,291,0.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27063,301,7,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27063,303,0.67,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27063,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27063,307,547,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27063,320,36,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (27063,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27063,401,0.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27063,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27063,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27063,605,0.003,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27063,606,0.111,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27064,203,2.23,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27064,204,10.9,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27064,205,46.13,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27064,207,9.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27064,208,292,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27064,255,31.7,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27064,269,13.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27064,291,6.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27064,301,41,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27064,303,0.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27064,306,182,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27064,307,3390,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27064,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (27064,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27064,401,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27064,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27064,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27064,605,0.037,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27064,606,2.031,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27065,203,5.44,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27065,204,3.7,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27065,205,15.89,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27065,207,2.02,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27065,208,119,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27065,255,72.95,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27065,269,0.99,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27065,291,4.9,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27065,301,26,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27065,303,1.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27065,306,368,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27065,307,443,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27065,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (27065,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27065,401,0.6,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27065,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27065,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27065,605,0.008,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27065,606,0.529,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27066,203,1.09,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27066,204,50.89,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27066,205,10.05,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27066,207,2.14,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27066,208,503,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27066,255,35.83,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27066,269,8.98,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27066,291,1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27066,301,12,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27066,303,0.23,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27066,306,44,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27066,307,730,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27066,320,17,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (27066,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (27066,401,0.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27066,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (27066,601,50,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27066,605,0.179,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (27066,606,8.233,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28285,203,7.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28285,204,9.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28285,205,46.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28285,207,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28285,208,299,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28285,255,35.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28285,269,2.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28285,291,9.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28285,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28285,303,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28285,306,196,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28285,307,298,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28285,320,0,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (28285,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28285,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28285,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28285,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28285,605,0.029,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (28285,606,3.311,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28286,203,6.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28286,204,13.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28286,205,45.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28286,207,1.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28286,208,326,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28286,255,33.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28286,269,4.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28286,291,9.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28286,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28286,303,1.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28286,306,139,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28286,307,452,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28286,320,2,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (28286,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28286,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28286,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28286,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28286,605,0.034,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (28286,606,5.826,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28287,203,10.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28287,204,6.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28287,205,46.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28287,207,1.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28287,208,286,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28287,255,34.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28287,269,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28287,291,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28287,301,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28287,303,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28287,306,185,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28287,307,467,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28287,320,2,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (28287,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28287,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28287,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28287,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28287,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28287,606,2.907,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28288,203,10.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28288,204,5.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28288,205,55.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28288,207,1.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28288,208,318,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28288,255,26.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28288,269,3.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28288,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28288,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28288,303,3.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28288,306,131,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28288,307,506,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28288,320,1,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (28288,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28288,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28288,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28288,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28288,605,0.869,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28288,606,1.401,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28289,203,3.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28289,204,25.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28289,205,64.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28289,207,0.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28289,208,489,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28289,255,5.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28289,269,35.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28289,291,4.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28289,301,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28289,303,3.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28289,306,195,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28289,307,182,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28289,320,6,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (28289,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28289,401,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28289,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28289,601,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28289,605,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28289,606,17.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28290,203,8.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28290,204,35.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28290,205,52.9,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (28290,207,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28290,208,562,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (28290,255,1.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28290,269,30.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28290,291,3.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28290,301,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28290,303,2.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28290,306,217,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28290,307,371,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28290,320,0,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (28290,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28290,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28290,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28290,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28290,605,0.27,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28290,606,19.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28291,203,3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28291,204,24.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28291,205,70.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28291,207,0.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28291,208,509,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28291,255,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28291,269,41.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28291,291,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28291,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28291,303,1.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28291,306,96,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28291,307,257,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28291,320,0,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (28291,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28291,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28291,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28291,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28291,605,0.515,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28291,606,16.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28292,203,7.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28292,204,20.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28292,205,67.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28292,207,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28292,208,482,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28292,255,2.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28292,269,12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28292,291,3.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28292,301,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28292,303,2.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28292,306,171,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28292,307,883,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28292,320,0,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (28292,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28292,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28292,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28292,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28292,605,0.19,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28292,606,3.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28293,203,4.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28293,204,23.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28293,205,68.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28293,207,1.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28293,208,503,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28293,255,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28293,269,33.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28293,291,1.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28293,301,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28293,303,2.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28293,306,234,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28293,307,301,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (28293,320,0,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (28293,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28293,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28293,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28293,601,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28293,605,0.49,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28293,606,14.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28294,203,4.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28294,204,24.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28294,205,67.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28294,207,1.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28294,208,507,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28294,255,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28294,269,32,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28294,291,2.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28294,301,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28294,303,3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28294,306,95,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28294,307,380,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28294,320,0,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (28294,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28294,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28294,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28294,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28294,605,0.37,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28294,606,16.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28295,203,9.76,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28295,204,9.76,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28295,205,45.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28295,207,4.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28295,208,310,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28295,255,30.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28295,269,2.44,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28295,291,9.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28295,301,244,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28295,303,2.63,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28295,306,262,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28295,307,617,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (28295,320,0,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (28295,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28295,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28295,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28295,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28295,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28295,606,4.878,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28296,203,3.71,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28296,204,13,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28296,205,69.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28296,207,2.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28296,208,409,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28296,255,11.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28296,269,33.42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28296,291,14.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28296,301,149,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28296,303,4.01,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28296,306,193,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28296,307,483,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28296,320,1,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (28296,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28296,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28296,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28296,601,93,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28296,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28296,606,5.57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28297,203,3.71,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28297,204,11.14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28297,205,74.3,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (28297,207,1.19,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28297,208,412,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (28297,255,9.66,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28297,269,29.71,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28297,291,14.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28297,301,223,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28297,303,1.34,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28297,306,73,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28297,307,316,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28297,320,5,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (28297,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28297,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28297,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28297,601,93,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28297,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28297,606,3.713,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28298,203,2.77,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28298,204,9.68,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28298,205,61.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28298,207,1.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28298,208,345,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28298,255,24.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28298,269,38.73,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28298,291,11.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28298,301,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28298,303,1.99,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28298,306,143,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28298,307,290,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28298,320,0,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (28298,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28298,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28298,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28298,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28298,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28298,606,2.766,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28299,203,2.94,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28299,204,13.24,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28299,205,76.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28299,207,1.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28299,208,436,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28299,255,6.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28299,269,41.18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28299,291,2.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28299,301,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28299,303,3.18,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28299,306,176,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28299,307,471,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28299,320,0,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (28299,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28299,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28299,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28299,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28299,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28299,606,2.941,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28300,203,2.61,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28300,204,18.29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28300,205,55.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28300,207,1.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28300,208,398,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28300,255,22.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28300,269,31.36,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28300,291,2.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28300,301,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28300,303,1.88,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28300,306,136,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28300,307,500,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (28300,320,1,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (28300,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28300,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28300,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28300,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28300,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28300,606,5.226,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28301,203,10.34,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28301,204,31.03,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28301,205,50.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28301,207,1.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28301,208,523,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28301,255,6.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28301,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28301,291,3.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28301,301,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28301,303,2.48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28301,306,202,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28301,307,448,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28301,320,0,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (28301,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28301,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28301,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28301,601,17,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28301,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28301,606,8.621,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28302,203,5.71,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28302,204,5.71,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28302,205,77.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28302,207,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28302,208,386,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28302,255,8.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28302,269,22.86,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28302,291,5.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28302,301,429,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28302,303,3.09,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28302,306,171,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28302,307,629,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28302,320,0,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (28302,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28302,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28302,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28302,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28302,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28302,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28303,203,9.62,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28303,204,16.03,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28303,205,57.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28303,207,2.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28303,208,412,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28303,255,14.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28303,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28303,291,6.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28303,301,128,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28303,303,3.46,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28303,306,212,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28303,307,706,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (28303,320,12,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (28303,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28303,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28303,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28303,601,16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28303,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28303,606,3.206,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28304,203,7.14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28304,204,3.57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28304,205,49.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28304,207,1.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28304,208,257,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28304,255,38.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28304,269,4.29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28304,291,4.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28304,301,143,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28304,303,6.43,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28304,306,164,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28304,307,557,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28304,320,155,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (28304,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28304,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28304,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28304,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28304,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28304,606,0.714,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28305,203,5.71,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28305,204,1.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28305,205,57.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28305,207,1.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28305,208,269,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28305,255,33.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28305,269,8.57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28305,291,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28305,301,57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28305,303,1.71,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28305,306,97,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28305,307,429,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28305,320,7,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (28305,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28305,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28305,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28305,601,24,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28305,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28305,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28306,203,11.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28306,204,7.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28306,205,46.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28306,207,1.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28306,208,297,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28306,255,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28306,269,2.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28306,291,4.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28306,301,93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28306,303,3.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28306,306,266,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28306,307,409,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28306,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (28306,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28306,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28306,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28306,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28306,605,0.034,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (28306,606,1.953,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28307,203,9.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28307,204,5.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28307,205,50.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28307,207,1.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28307,208,291,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28307,255,32.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28307,269,3.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28307,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28307,301,84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28307,303,3.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28307,306,125,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28307,307,465,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28307,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (28307,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28307,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28307,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28307,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (28307,605,0.042,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28307,606,1.393,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (28308,203,7.29,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28308,204,17.84,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28308,205,68.37,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28308,207,3.77,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28308,208,463,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28308,255,2.73,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28308,269,10.43,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28308,291,4.9,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28308,301,167,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28308,303,3.65,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28308,306,209,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28308,307,748,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28308,320,0,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (28308,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28308,401,0,'100g',NULL,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (28308,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28308,601,0,'100g',NULL,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (28308,605,0.607,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28308,606,4.345,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28309,203,3.02,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28309,204,22.55,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28309,205,61.22,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28309,207,1.71,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28309,208,460,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28309,255,11.5,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28309,269,45.16,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28309,291,5.1,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28309,301,5,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28309,303,0.82,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28309,306,123,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28309,307,241,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28309,320,0,'100g',2,1,'2024-12-12','2014-01-05');
INSERT INTO `cndb_nutval` VALUES (28309,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28309,401,0,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28309,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28309,601,0,'100g',6,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28309,605,NULL,'100g',NULL,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28309,606,20.099,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28310,203,5.37,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28310,204,14,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28310,205,75.99,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28310,207,1.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28310,208,451,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28310,255,3.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28310,269,21.65,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28310,291,1.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28310,301,13,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28310,303,2.98,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28310,306,88,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28310,307,571,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28310,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28310,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28310,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28310,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28310,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28310,605,0.47,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28310,606,4.694,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28311,203,3.45,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28311,204,27.59,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28311,205,65.99,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28311,207,1.24,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28311,208,526,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28311,255,1.73,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28311,269,51.72,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28311,291,3.4,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28311,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28311,303,1.24,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28311,306,311,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28311,307,138,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28311,320,1,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28311,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28311,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28311,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28311,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28311,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28311,606,17.241,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28312,203,11.69,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28312,204,3.61,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28312,205,47.31,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28312,207,2.16,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28312,208,269,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28312,255,35.23,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28312,269,6.9,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28312,291,4.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28312,301,196,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28312,303,2.92,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28312,306,181,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28312,307,463,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28312,320,27,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28312,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28312,401,1.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28312,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28312,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28312,605,0.018,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28312,606,0.746,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28313,203,12.38,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28313,204,4.38,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28313,205,44.93,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28313,207,2.39,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28313,208,269,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28313,255,35.92,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28313,269,5.92,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28313,291,6.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28313,301,198,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28313,303,2.42,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28313,306,242,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28313,307,477,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (28313,320,33,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28313,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28313,401,1.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28313,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28313,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28313,605,0.022,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28313,606,0.921,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28314,203,8.33,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28314,204,16.67,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28314,205,63.49,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28314,207,2.18,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28314,208,437,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28314,255,9.33,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28314,269,11.11,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28314,291,2.8,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28314,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28314,303,3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28314,306,122,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28314,307,639,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28314,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28314,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28314,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28314,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28314,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28314,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28314,606,2.778,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28315,203,7.05,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28315,204,5.29,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28315,205,44.38,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28315,207,1.34,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28315,208,253,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28315,255,41.93,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28315,269,14.11,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28315,291,3.5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28315,301,71,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28315,303,2.54,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28315,306,74,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28315,307,388,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28315,320,0,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (28315,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28315,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28315,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28315,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28315,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28315,606,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28316,203,13.16,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28316,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28316,205,33.88,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28316,207,2.08,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28316,208,188,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28316,255,50.88,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28316,269,2.63,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28316,291,5.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28316,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28316,303,1.89,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28316,306,198,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28316,307,474,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28316,320,0,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (28316,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28316,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28316,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28316,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28316,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28316,606,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28317,203,14.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28317,204,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28317,205,36.82,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28317,207,2.26,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28317,208,205,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28317,255,46.61,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28317,269,2.86,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28317,291,5.7,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28317,301,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28317,303,2.06,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28317,306,215,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28317,307,515,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28317,320,0,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (28317,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28317,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28317,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28317,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28317,605,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28317,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28318,203,8.33,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28318,204,1.04,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28318,205,49.1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28318,207,1.72,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28318,208,239,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28318,255,39.81,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28318,269,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28318,291,4.2,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28318,301,42,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28318,303,0.75,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28318,306,163,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28318,307,375,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28318,320,0,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (28318,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28318,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28318,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28318,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28318,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28318,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28319,203,9.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28319,204,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28319,205,54.52,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28319,207,1.65,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28319,208,255,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28319,255,34.52,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28319,269,9.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28319,291,4.7,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28319,301,93,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28319,303,4.19,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28319,306,176,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28319,307,372,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28319,320,0,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (28319,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28319,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28319,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28319,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28319,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28319,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28320,203,7.02,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28320,204,1.75,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28320,205,50.17,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28320,207,1.59,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28320,208,245,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28320,255,39.48,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28320,269,1.75,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28320,291,3.5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28320,301,140,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28320,303,2.53,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28320,306,130,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28320,307,386,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28320,320,0,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (28320,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28320,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28320,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28320,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28320,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28320,606,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28321,203,9.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28321,204,3.49,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28321,205,46.5,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28321,207,2.05,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28321,208,255,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28321,255,38.67,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28321,269,9.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28321,291,2.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28321,301,233,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28321,303,2.59,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28321,306,190,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28321,307,512,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28321,320,0,'100g',2,1,'2024-12-12','2015-01-05');
INSERT INTO `cndb_nutval` VALUES (28321,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28321,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28321,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28321,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28321,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28321,606,1.163,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28322,203,9.9,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28322,204,1.24,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28322,205,47.47,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28322,207,1.99,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28322,208,241,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28322,255,39.4,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28322,269,8.66,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28322,291,6.2,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28322,301,124,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28322,303,2.23,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28322,306,204,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28322,307,359,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28322,320,0,'100g',2,1,'2024-12-12','2015-01-05');
INSERT INTO `cndb_nutval` VALUES (28322,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28322,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28322,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28322,601,6,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28322,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28322,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28324,203,10.53,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28324,204,1.32,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28324,205,74.11,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28324,207,3.55,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28324,208,350,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28324,255,10.5,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28324,269,10.53,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28324,291,7.9,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28324,301,158,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28324,303,7.11,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28324,306,368,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28324,307,1632,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28324,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28324,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28324,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28324,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28324,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28324,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28324,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28325,203,6.45,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28325,204,16.13,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28325,205,67.66,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28325,207,1.63,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28325,208,442,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28325,255,8.12,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28325,269,12.9,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28325,291,9.7,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28325,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28325,303,3.48,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28325,306,306,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28325,307,177,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28325,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28325,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28325,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28325,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28325,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28325,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28325,606,3.226,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28326,203,14.12,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28326,204,21.18,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28326,205,54.59,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28326,207,2.79,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28326,208,465,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28326,255,7.32,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28326,269,9.41,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28326,291,9.4,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28326,301,33,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28326,303,3.07,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28326,306,330,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28326,307,635,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28326,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28326,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28326,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28326,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28326,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28326,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28326,606,4.525,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28327,203,7.14,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28327,204,7.14,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28327,205,72.81,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28327,207,1.9,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28327,208,384,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28327,255,11,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28327,269,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28327,291,7.1,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28327,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28327,303,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28327,306,99,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28327,307,571,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28327,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28327,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28327,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28327,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28327,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28327,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28327,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28328,203,2.94,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28328,204,17.65,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28328,205,63.52,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28328,207,0.95,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28328,208,425,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28328,255,14.95,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28328,269,38.24,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28328,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28328,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28328,303,1.06,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28328,306,94,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28328,307,279,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28328,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28328,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28328,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28328,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28328,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28328,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28328,606,5.882,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28329,203,3.23,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28329,204,19.35,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28329,205,63.26,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28329,207,1.14,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28329,208,440,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28329,255,13.02,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28329,269,40.32,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28329,291,1.6,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28329,301,32,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28329,303,2.49,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28329,306,227,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28329,307,210,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28329,320,0,'100g',3,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28329,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28329,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28329,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28329,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28329,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28329,606,11.29,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28330,203,4.55,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28330,204,18.18,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28330,205,63.26,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28330,207,1.74,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28330,208,435,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28330,255,12.27,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28330,269,40.91,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28330,291,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28330,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28330,303,1.64,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28330,306,227,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28330,307,341,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28330,320,43,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28330,328,0.9,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28330,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28330,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28330,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28330,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28330,606,11.364,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28331,203,10.16,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28331,204,17.71,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28331,205,65.67,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28331,207,3.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28331,208,463,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28331,255,3.42,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28331,269,1.18,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28331,291,3.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28331,301,83,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28331,303,4.58,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28331,306,224,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28331,307,970,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28331,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (28331,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28331,401,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28331,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28331,601,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28331,605,0.059,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28331,606,2.059,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28332,203,2.19,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28332,204,17.89,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28332,205,76.03,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28332,207,1.06,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28332,208,474,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28332,255,2.84,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28332,269,49,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28332,291,2.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28332,301,19,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28332,303,2.81,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28332,306,157,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28332,307,275,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28332,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28332,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28332,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28332,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28332,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28332,605,0.099,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28332,606,7.905,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28333,203,4.06,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28333,204,30.42,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28333,205,62.82,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28333,207,1.33,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28333,208,541,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28333,255,1.37,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28333,269,40.99,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28333,291,1.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28333,301,109,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28333,303,3.67,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28333,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28333,307,122,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28333,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (28333,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28333,401,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28333,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28333,601,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28333,605,0.102,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28333,606,15.299,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28334,203,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28334,204,24.18,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28334,205,74.39,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28334,207,0.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28334,208,515,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28334,255,1.12,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28334,269,42.31,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28334,291,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28334,301,9,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28334,303,0.18,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28334,306,36,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28334,307,111,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28334,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (28334,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28334,401,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28334,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28334,601,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28334,605,0.043,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28334,606,10.501,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28335,203,2.66,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28335,204,20.47,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28335,205,74.61,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28335,207,0.59,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28335,208,493,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28335,255,1.67,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28335,269,46.68,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28335,291,0.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28335,301,14,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28335,303,0.34,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28335,306,105,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28335,307,201,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28335,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (28335,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28335,401,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28335,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28335,601,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28335,605,0.057,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28335,606,7.006,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28336,203,3.13,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28336,204,10.7,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28336,205,52.83,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28336,207,1.68,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28336,208,320,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28336,255,31.67,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28336,269,8.36,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28336,291,3.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28336,301,24,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28336,303,0.76,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28336,306,92,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28336,307,528,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28336,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (28336,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28336,401,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28336,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28336,601,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28336,605,0.019,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28336,606,0.339,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28337,203,4.31,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28337,204,5.24,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28337,205,45.78,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28337,207,1.68,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28337,208,248,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28337,255,42.99,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28337,269,3.53,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28337,291,4.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28337,301,138,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28337,303,2.63,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28337,306,75,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28337,307,447,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28337,320,0,'100g',3,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28337,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28337,401,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28337,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28337,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28337,605,0.01,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28337,606,0.977,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28338,203,5.4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28338,204,8.02,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28338,205,51.15,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28338,207,1.75,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28338,208,298,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28338,255,33.69,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28338,269,11.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28338,291,5.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28338,301,59,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28338,303,0.53,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28338,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28338,307,515,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28338,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (28338,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28338,401,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28338,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28338,601,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28338,605,0.023,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28338,606,0.629,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28339,203,7.25,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28339,204,9.34,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28339,205,49.09,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28339,207,1.96,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28339,208,309,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28339,255,32.36,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28339,269,9.81,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28339,291,4.9,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28339,301,60,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28339,303,0.76,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28339,306,123,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28339,307,510,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28339,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (28339,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28339,401,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28339,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28339,601,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28339,605,0.019,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28339,606,0.266,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28341,203,3.34,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28341,204,2.65,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28341,205,50.47,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28341,207,1.54,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28341,208,239,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28341,255,42,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28341,269,6.87,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28341,291,5.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28341,301,180,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28341,303,3.57,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28341,306,76,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28341,307,593,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28341,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28341,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28341,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28341,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28341,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28341,605,0.008,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28341,606,0.215,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28343,203,11.8,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28343,204,11.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28343,205,44.29,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28343,207,2.41,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28343,208,329,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28343,255,29.9,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28343,269,4.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28343,291,11.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28343,301,118,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28343,303,1.64,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28343,306,273,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28343,307,507,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28343,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (28343,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28343,401,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28343,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28343,601,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28343,605,0.034,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28343,606,1.381,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28344,203,2.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28344,204,15.41,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28344,205,76.94,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28344,207,2.67,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28344,208,456,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28344,255,2.48,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28344,269,3.9,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28344,291,3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28344,301,28,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28344,303,0.56,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28344,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28344,307,890,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28344,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (28344,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28344,401,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28344,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28344,601,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28344,605,0.048,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28344,606,5.711,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28345,203,11.25,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28345,204,15.84,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28345,205,66.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28345,207,3.02,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28345,208,453,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28345,255,3.59,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28345,269,0.86,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28345,291,10.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28345,301,238,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28345,303,2.83,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28345,306,381,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28345,307,438,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28345,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28345,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28345,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28345,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28345,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28345,605,0.018,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28345,606,2.069,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28346,203,2.72,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28346,204,8.84,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28346,205,43.05,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28346,207,2.02,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28346,208,263,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28346,255,43.37,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28346,269,1.73,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28346,291,1.4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28346,301,40,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28346,303,0.63,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28346,306,124,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28346,307,505,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28346,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28346,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28346,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28346,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28346,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28346,605,0.01,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28346,606,0.781,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28347,203,3.31,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28347,204,4.55,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28347,205,40.32,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28347,207,1.58,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28347,208,215,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28347,255,50.24,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28347,269,4.06,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28347,291,1.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28347,301,39,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28347,303,0.7,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28347,306,127,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28347,307,331,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28347,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28347,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28347,401,0.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28347,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28347,601,12,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28347,605,0.013,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28347,606,0.48,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28348,203,10.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28348,204,7.37,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28348,205,53.58,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28348,207,1.18,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28348,208,321,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28348,255,27.83,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28348,269,15.38,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28348,291,3.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28348,301,62,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28348,303,2.74,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28348,306,149,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28348,307,253,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28348,320,40,'100g',2,1,'2024-12-12','2017-01-07');
INSERT INTO `cndb_nutval` VALUES (28348,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28348,401,0.2,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28348,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28348,601,55,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28348,605,0.168,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28348,606,3.516,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28349,203,4.02,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28349,204,10.04,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28349,205,64.62,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28349,207,1.86,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28349,208,365,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28349,255,19.46,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28349,269,32.14,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28349,291,16.1,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28349,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28349,303,1.45,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28349,306,274,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28349,307,562,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28349,320,92,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28349,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28349,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28349,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28349,601,20,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28349,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28349,606,4.09,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28350,203,10,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28350,204,22.5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28350,205,51.08,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28350,207,1.32,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28350,208,447,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28350,255,15.09,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28350,269,25,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28350,291,5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28350,301,50,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28350,303,0.9,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28350,306,181,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28350,307,213,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28350,320,1,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28350,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28350,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28350,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28350,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28350,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28350,606,12.584,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28351,203,7.05,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28351,204,10.58,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28351,205,70.54,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28351,207,2.03,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28351,208,406,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28351,255,9.79,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28351,269,21.16,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28351,291,3.5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28351,301,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28351,303,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28351,306,307,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28351,307,370,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28351,320,1,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28351,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28351,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28351,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28351,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28351,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28351,606,5.291,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28352,203,4.17,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28352,204,10.42,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28352,205,78.16,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28352,207,1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28352,208,423,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28352,255,6.25,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28352,269,37.5,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28352,291,2.1,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28352,301,42,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28352,303,2.25,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28352,306,104,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28352,307,354,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28352,320,0,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (28352,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28352,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28352,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28352,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28352,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28352,606,3.175,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28397,203,13.36,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28397,204,4.23,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28397,205,43.34,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28397,207,2.13,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28397,208,265,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28397,255,36.94,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28397,269,6.39,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28397,291,7.4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28397,301,103,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28397,303,2.5,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28397,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28397,307,381,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28397,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (28397,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28397,401,0.1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28397,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28397,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28397,605,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28397,606,0.872,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28399,203,6.9,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28399,204,13.8,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28399,205,74.1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28399,207,1.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28399,208,446,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28399,255,3.9,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28399,269,23.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28399,291,1.1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28399,301,43,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28399,303,2.75,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28399,306,100,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28399,307,335,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (28399,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (28399,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (28399,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28399,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (28399,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (28399,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (28399,606,3.463,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31022,203,3.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31022,204,10.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31022,205,33.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31022,207,1.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31022,208,242,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31022,255,50.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31022,269,1.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31022,291,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31022,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31022,303,0.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31022,306,704,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31022,307,77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31022,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (31022,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31022,401,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31022,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (31022,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31022,605,0.032,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (31022,606,0.805,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (31023,203,2.16,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31023,204,8.92,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31023,205,35.58,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31023,207,1.38,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31023,208,182,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31023,255,51.97,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31023,269,12.9,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31023,291,5.7,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31023,301,52,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31023,303,0.77,'100g',1,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (31023,306,409,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31023,307,146,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31023,320,434,'100g',1,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (31023,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31023,401,7.5,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31023,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (31023,601,0,'100g',4,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31023,605,0.042,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31023,606,1.157,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31024,203,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31024,204,11.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31024,205,25.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31024,207,1.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31024,208,209,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31024,255,60.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31024,269,6.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31024,291,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31024,301,39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31024,303,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31024,306,244,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31024,307,214,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31024,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (31024,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31024,401,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31024,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (31024,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31024,605,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31024,606,0.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31025,203,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31025,204,3.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31025,205,30.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31025,207,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31025,208,161,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31025,255,63.02,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31025,269,7.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31025,291,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31025,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31025,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31025,306,248,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31025,307,250,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31025,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (31025,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31025,401,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31025,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (31025,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31025,605,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31025,606,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31026,203,1.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31026,204,1.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31026,205,23.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31026,207,1.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31026,208,119,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31026,255,70.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31026,269,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31026,291,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31026,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31026,303,0.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31026,306,444,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31026,307,338,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31026,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (31026,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31026,401,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31026,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (31026,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31026,605,0.023,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (31026,606,0.153,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (31027,203,2.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31027,204,5.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31027,205,25.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31027,207,1.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31027,208,162,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31027,255,65.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31027,269,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31027,291,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31027,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31027,303,0.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31027,306,447,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31027,307,300,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31027,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (31027,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31027,401,10.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31027,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (31027,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31027,605,0.107,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (31027,606,1.427,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (31028,203,2.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31028,204,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31028,205,17.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31028,207,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31028,208,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31028,255,78.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31028,269,0.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31028,291,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31028,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31028,303,0.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31028,306,398,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31028,307,330,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31028,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (31028,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31028,401,7.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31028,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (31028,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31028,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31028,606,0.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31029,203,2.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31029,204,7.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31029,205,22.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31029,207,1.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31029,208,162,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (31029,255,66.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31029,269,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31029,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31029,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31029,303,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31029,306,381,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31029,307,380,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31029,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (31029,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31029,401,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31029,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (31029,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31029,605,0.147,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (31029,606,1.843,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (31030,203,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31030,204,3.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31030,205,24.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31030,207,0.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31030,208,134,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (31030,255,69.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31030,269,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31030,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31030,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31030,303,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31030,306,360,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31030,307,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31030,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (31030,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31030,401,6.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31030,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (31030,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31030,605,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31030,606,0.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31031,203,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31031,204,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31031,205,22.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31031,207,1.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31031,208,187,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (31031,255,62.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31031,269,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31031,291,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31031,301,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31031,303,0.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31031,306,310,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31031,307,393,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31031,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (31031,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31031,401,5.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31031,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (31031,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31031,605,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31031,606,2.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (31033,203,0.33,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31033,204,0.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31033,205,4.83,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31033,207,2.44,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31033,208,20,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31033,255,92.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31033,269,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31033,291,2.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31033,301,74,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31033,303,0.28,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31033,306,36,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31033,307,906,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31033,320,0,'100g',1,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (31033,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31033,401,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31033,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (31033,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31033,605,0.029,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31033,606,0.037,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31034,203,0.8,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31034,204,0.4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31034,205,4.56,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31034,207,4.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31034,208,22,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31034,255,90.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31034,269,1.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31034,291,2.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31034,301,61,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31034,303,0.32,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31034,306,113,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31034,307,1430,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31034,320,43,'100g',1,1,'2024-12-12','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (31034,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31034,401,12.3,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31034,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (31034,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31034,605,0.001,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31034,606,0.061,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31036,203,1.97,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31036,204,5.01,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31036,205,13.29,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31036,207,1.46,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31036,208,106,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31036,255,78.27,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31036,269,1.76,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31036,291,1.9,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31036,301,34,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31036,303,0.27,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31036,306,274,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (31036,307,298,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31036,320,53,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (31036,328,0.1,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (31036,401,0.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31036,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (31036,601,13,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31036,605,0.128,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (31036,606,2.632,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32000,203,10.84,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32000,204,1.27,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32000,205,76.02,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32000,207,3.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32000,208,359,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32000,255,8.27,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32000,269,4.27,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32000,291,1.6,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32000,301,32,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32000,303,2.82,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32000,306,169,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32000,307,1337,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32000,320,70,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (32000,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32000,401,1.9,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32000,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32000,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32000,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (32000,606,0.31,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32001,203,2.82,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32001,204,3.2,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32001,205,22.03,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32001,207,1.01,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32001,208,129,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32001,255,70.93,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32001,269,NULL,'100g',NULL,1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (32001,291,0.6,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32001,301,10,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32001,303,0.88,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32001,306,48,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32001,307,364,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32001,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (32001,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32001,401,NULL,'100g',NULL,1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (32001,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32001,601,NULL,'100g',NULL,1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (32001,605,0.384,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (32001,606,0.682,'100g',3,1,'2013-02-22','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (32002,203,10.42,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32002,204,1.37,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32002,205,76.31,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32002,207,3.87,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32002,208,359,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32002,255,8.04,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32002,269,1.53,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32002,291,1.2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32002,301,83,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32002,303,2.44,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32002,306,188,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32002,307,1303,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32002,320,4,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (32002,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32002,401,4.1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32002,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32002,601,1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32002,605,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32002,606,0.307,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32003,203,2.94,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32003,204,3.7,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32003,205,25.67,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32003,207,1.23,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32003,208,148,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32003,255,66.47,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32003,269,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32003,291,0.6,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32003,301,29,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32003,303,0.85,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32003,306,69,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32003,307,430,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32003,320,39,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (32003,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32003,401,NULL,'100g',NULL,1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (32003,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32003,601,NULL,'100g',NULL,1,'2013-02-22','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (32003,605,0.521,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32003,606,0.744,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32004,203,12.73,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32004,204,10.67,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32004,205,46.66,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32004,207,3.06,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32004,208,334,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32004,255,26.88,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32004,269,6.43,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32004,291,1.8,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32004,301,145,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32004,303,2.07,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32004,306,197,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32004,307,766,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32004,320,6,'100g',2,1,'2024-12-12','2013-01-01');
INSERT INTO `cndb_nutval` VALUES (32004,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32004,401,0.6,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32004,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32004,601,3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32004,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (32004,606,1.184,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32005,203,6.68,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32005,204,4.99,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32005,205,23.1,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32005,207,1.64,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32005,208,164,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32005,255,63.59,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32005,269,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32005,291,1.2,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32005,301,85,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32005,303,1.17,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32005,306,80,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32005,307,460,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32005,320,22,'100g',1,1,'2024-12-12','2012-01-08');
INSERT INTO `cndb_nutval` VALUES (32005,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32005,401,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32005,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32005,601,8,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (32005,605,0.092,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32005,606,1.636,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32006,203,9.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32006,204,12.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32006,205,33.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32006,207,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32006,208,284,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32006,255,42.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32006,269,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32006,291,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32006,301,104,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32006,303,2.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32006,306,155,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32006,307,453,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32006,320,30,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (32006,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32006,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32006,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32006,601,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32006,605,0.071,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32006,606,2.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32007,203,9.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32007,204,12.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32007,205,33.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32007,207,1.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32007,208,287,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32007,255,42.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32007,269,1.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32007,291,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32007,301,97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32007,303,2.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32007,306,174,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32007,307,456,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32007,320,35,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (32007,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32007,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32007,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32007,601,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32007,605,0.147,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32007,606,2.621,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32008,203,11.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32008,204,1.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32008,205,71.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32008,207,5.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32008,208,349,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32008,255,9.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32008,269,4.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32008,291,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32008,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32008,303,2.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32008,306,204,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32008,307,2152,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32008,320,25,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (32008,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32008,401,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32008,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32008,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32008,605,0.054,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (32008,606,0.368,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32009,203,12.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32009,204,1.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32009,205,72.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32009,207,5.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32009,208,354,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32009,255,8.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32009,269,4.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32009,291,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32009,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32009,303,2.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32009,306,342,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32009,307,1537,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32009,320,0,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (32009,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32009,401,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32009,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32009,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32009,605,0.106,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (32009,606,0.439,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32010,203,10.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32010,204,1.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32010,205,73.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32010,207,5.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32010,208,356,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32010,255,7.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32010,269,11.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32010,291,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32010,301,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32010,303,2.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32010,306,277,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32010,307,1850,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32010,320,10,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (32010,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32010,401,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32010,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32010,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32010,605,0.089,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (32010,606,0.443,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32011,203,7.02,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32011,204,1.75,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32011,205,74.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32011,207,5.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32011,208,343,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32011,255,10.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32011,269,1.75,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32011,291,1.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32011,301,35,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32011,303,2.53,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32011,306,801,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32011,307,1316,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32011,320,9,'100g',2,1,'2024-12-12','2013-01-02');
INSERT INTO `cndb_nutval` VALUES (32011,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32011,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32011,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32011,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32011,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32011,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32012,203,8.73,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32012,204,9.98,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32012,205,50.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32012,207,2.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32012,208,328,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32012,255,27.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32012,269,3.74,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32012,291,1.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32012,301,125,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32012,303,1.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32012,306,301,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32012,307,599,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32012,320,67,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (32012,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32012,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32012,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32012,601,6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32012,605,1.2,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (32012,606,2.494,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32013,203,8.28,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32013,204,5.52,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32013,205,13.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32013,207,1.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32013,208,136,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32013,255,70.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32013,269,2.76,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32013,291,1.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32013,301,28,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32013,303,0.74,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32013,306,284,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32013,307,441,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32013,320,5,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (32013,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32013,401,8.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32013,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32013,601,17,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32013,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32013,606,1.724,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32014,203,13.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32014,204,4.03,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32014,205,52.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32014,207,3.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32014,208,297,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32014,255,27.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32014,269,5.04,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32014,291,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32014,301,202,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32014,303,1.81,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32014,306,203,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32014,307,867,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32014,320,30,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (32014,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32014,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32014,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32014,601,15,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32014,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32014,606,0.409,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32015,203,10.24,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32015,204,9.45,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32015,205,27.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32015,207,2.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32015,208,235,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32015,255,50.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32015,269,7.87,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32015,291,1.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32015,301,276,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32015,303,1.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32015,306,179,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32015,307,598,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32015,320,52,'100g',2,1,'2024-12-12','2013-01-03');
INSERT INTO `cndb_nutval` VALUES (32015,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32015,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32015,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32015,601,20,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32015,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32015,606,4.724,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32016,203,11.48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32016,204,6.56,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32016,205,70.75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32016,207,3.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32016,208,388,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32016,255,8.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32016,269,8.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32016,291,1.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32016,301,328,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32016,303,2.36,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32016,306,348,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32016,307,902,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32016,320,99,'100g',2,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (32016,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32016,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32016,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32016,601,8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32016,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32016,606,2.814,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32017,203,12.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32017,204,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32017,205,70.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32017,207,6.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32017,208,355,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32017,255,8.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32017,269,6.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32017,291,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32017,301,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32017,303,3.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32017,306,271,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32017,307,2093,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32017,320,38,'100g',1,1,'2024-12-12','2013-01-04');
INSERT INTO `cndb_nutval` VALUES (32017,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32017,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32017,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32017,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32017,605,0.099,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (32017,606,0.697,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (32018,203,10.62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32018,204,1.62,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32018,205,76.45,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32018,207,4.04,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32018,208,363,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32018,255,7.27,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32018,269,3.83,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32018,291,3.1,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32018,301,29,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32018,303,3.32,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32018,306,445,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32018,307,1085,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32018,320,23,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (32018,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32018,401,NULL,'100g',NULL,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32018,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32018,601,NULL,'100g',NULL,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32018,605,0.022,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32018,606,0.395,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32019,203,5.06,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32019,204,4.22,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32019,205,21.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32019,207,1.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32019,208,145,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32019,255,67.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32019,269,3.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32019,291,1.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32019,301,84,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32019,303,0.76,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32019,306,159,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32019,307,312,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32019,320,23,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (32019,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32019,401,1.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32019,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32019,601,11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32019,605,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32019,606,2.11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (32020,203,18.66,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32020,204,22.45,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32020,205,14.23,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32020,207,3.03,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32020,208,334,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32020,255,41.63,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32020,269,0,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32020,291,0.1,'100g',NULL,1,'2015-01-06','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (32020,301,75,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32020,303,1.26,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32020,306,279,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32020,307,813,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32020,320,37,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (32020,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32020,401,NULL,'100g',NULL,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32020,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32020,601,87,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32020,605,1.263,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32020,606,5.207,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32021,203,3.27,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32021,204,2.38,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32021,205,22.74,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32021,207,1.35,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32021,208,125,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32021,255,70.26,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32021,269,1.79,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32021,291,1.5,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32021,301,18,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32021,303,1.02,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32021,306,185,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32021,307,349,'100g',1,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32021,320,10,'100g',1,1,'2024-12-12','2014-01-04');
INSERT INTO `cndb_nutval` VALUES (32021,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32021,401,NULL,'100g',NULL,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32021,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32021,601,NULL,'100g',NULL,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32021,605,0.104,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32021,606,0.387,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32024,203,8.77,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32024,204,3.51,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32024,205,73.88,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32024,207,5.1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32024,208,362,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32024,255,8.74,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32024,269,5.26,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32024,291,1.8,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32024,301,140,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32024,303,4.74,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32024,306,351,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32024,307,1193,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32024,320,6,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (32024,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32024,401,2.1,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32024,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32024,601,9,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32024,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32024,606,1.754,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32025,203,5.26,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32025,204,6.14,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32025,205,29.64,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32025,207,1.7,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32025,208,195,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32025,255,57.25,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32025,269,1.75,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32025,291,0.9,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32025,301,35,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32025,303,1.26,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32025,306,107,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32025,307,474,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32025,320,3,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (32025,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32025,401,5.3,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32025,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32025,601,4,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32025,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32025,606,1.316,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32026,203,7.87,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32026,204,5.51,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32026,205,21.74,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32026,207,1.56,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32026,208,168,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32026,255,63.32,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32026,269,3.94,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32026,291,3.1,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32026,301,157,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32026,303,2.13,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32026,306,167,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32026,307,276,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32026,320,40,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (32026,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32026,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32026,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32026,601,16,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32026,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32026,606,2.756,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32027,203,9.45,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32027,204,5.51,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32027,205,31.89,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32027,207,1.92,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32027,208,215,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32027,255,51.23,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32027,269,3.94,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32027,291,0.8,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32027,301,197,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32027,303,2.13,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32027,306,117,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32027,307,378,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32027,320,37,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (32027,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32027,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32027,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32027,601,20,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32027,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32027,606,2.756,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32028,203,7.87,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32028,204,12.6,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32028,205,20.67,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32028,207,1.65,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32028,208,228,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32028,255,57.21,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32028,269,7.87,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32028,291,0.8,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32028,301,79,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32028,303,2.13,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32028,306,177,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32028,307,378,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32028,320,39,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (32028,328,0.4,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32028,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32028,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32028,601,31,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32028,605,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32028,606,5.512,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32029,203,3.49,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (32029,204,2.57,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (32029,205,26.28,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (32029,207,1.46,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (32029,208,142,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (32029,255,66.21,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (32029,269,0.4,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (32029,291,0.8,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (32029,301,35,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (32029,303,1.45,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (32029,306,113,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (32029,307,443,'100g',1,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (32029,320,4,'100g',2,1,'2024-12-12','2015-01-04');
INSERT INTO `cndb_nutval` VALUES (32029,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32029,401,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32029,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32029,601,0,'100g',6,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32029,605,NULL,'100g',NULL,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (32029,606,1.071,'100g',3,1,'2016-02-06','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (32031,203,6.98,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32031,204,10.47,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32031,205,6.78,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32031,207,1.58,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32031,208,149,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32031,255,74.19,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32031,269,0.26,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32031,291,1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32031,301,47,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32031,303,0.95,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32031,306,144,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32031,307,509,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32031,320,2,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32031,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32031,401,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32031,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32031,601,33,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32031,605,0.284,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32031,606,3.982,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32032,203,9.54,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32032,204,22.13,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32032,205,21.57,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32032,207,2.64,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32032,208,324,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32032,255,44.12,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32032,269,3.1,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32032,291,2,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32032,301,136,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32032,303,1.85,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32032,306,269,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32032,307,591,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32032,320,176,'100g',2,1,'2024-12-12','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (32032,328,0.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (32032,401,0.1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32032,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (32032,601,78,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32032,605,0.177,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (32032,606,8.595,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (35001,203,3.4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35001,204,31.8,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35001,205,13.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35001,207,4.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35001,208,353,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35001,255,47.3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35001,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35001,291,0.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35001,301,8,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35001,303,0.3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35001,306,70,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35001,307,21,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35001,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35001,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35001,401,2.9,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35001,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35001,601,10,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35001,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35001,606,7.7,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35003,203,21.7,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35003,204,18.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35003,205,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35003,207,3.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35003,208,258,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35003,255,55.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35003,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35003,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35003,301,16,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35003,303,4.55,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35003,306,228,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35003,307,95,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35003,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35003,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35003,401,2.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35003,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35003,601,89,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35003,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35003,606,5.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35004,203,3.8,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35004,204,0.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35004,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35004,207,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35004,208,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35004,255,90.4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35004,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35004,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35004,301,47,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35004,303,3.3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35004,306,102,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35004,307,656,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35004,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35004,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35004,401,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35004,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35004,601,7,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35004,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35004,606,0.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35009,203,69.86,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35009,204,5.34,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35009,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35009,207,2.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35009,208,327,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35009,255,22.39,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35009,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35009,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35009,301,22,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35009,303,72.35,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35009,306,800,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35009,307,220,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35009,320,0,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (35009,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35009,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35009,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35009,601,122,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35009,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35009,606,1.204,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35011,203,26.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35011,204,0.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35011,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35011,207,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35011,208,111,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35011,255,72.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35011,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35011,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35011,301,7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35011,303,25.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35011,306,283,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35011,307,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35011,320,102,'100g',2,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (35011,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35011,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35011,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35011,601,80,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35011,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35011,606,0.092,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35014,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35014,204,100,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35014,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35014,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35014,208,900,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35014,255,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35014,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35014,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35014,301,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35014,303,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35014,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35014,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35014,320,694,'100g',2,1,'2024-12-12','2006-01-07');
INSERT INTO `cndb_nutval` VALUES (35014,328,5.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35014,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35014,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35014,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35014,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35014,606,14.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35024,203,3.8,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35024,204,0.7,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35024,205,4.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35024,207,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35024,208,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35024,255,90,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35024,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35024,291,0.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35024,301,7,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35024,303,0.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35024,306,84,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35024,307,72,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35024,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35024,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35024,401,1.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35024,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35024,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35024,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35024,606,0.01,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35041,203,9.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35041,204,1.93,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35041,205,4.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35041,207,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35041,208,74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35041,255,81.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35041,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35041,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35041,301,19,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35041,303,2.7,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35041,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35041,307,61,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35041,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35041,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35041,401,0.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35041,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35041,601,40,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35041,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35041,606,0.43,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35048,203,6.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35048,204,0.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35048,205,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35048,207,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35048,208,55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35048,255,86.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35048,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35048,291,0.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35048,301,12,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35048,303,1.52,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35048,306,100,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35048,307,222,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35048,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35048,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35048,401,1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35048,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35048,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35048,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35048,606,0.01,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35049,203,22.3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35049,204,1.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35049,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35049,207,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35049,208,103,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35049,255,74.79,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35049,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35049,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35049,301,5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35049,303,3.28,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35049,306,317,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35049,307,65,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35049,320,0,'100g',2,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (35049,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35049,401,4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35049,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35049,601,54,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35049,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35049,606,0.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35057,203,0.56,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35057,204,99.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35057,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35057,207,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35057,208,899,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35057,255,0.02,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35057,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35057,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35057,301,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35057,303,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35057,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35057,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35057,320,10,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (35057,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35057,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35057,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35057,601,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35057,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35057,606,10.926,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35067,203,39.9,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35067,204,30,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35067,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35067,207,3.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35067,208,430,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35067,255,23.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35067,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35067,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35067,301,23,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35067,303,4.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35067,306,700,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35067,307,693,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35067,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35067,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35067,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35067,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35067,601,107,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35067,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35067,606,6.97,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35071,203,28.4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35071,204,3.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35071,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35071,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35071,208,142,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35071,255,67.4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35071,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35071,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35071,301,5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35071,303,19.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35071,306,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35071,307,110,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35071,320,116,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (35071,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35071,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35071,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35071,601,90,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35071,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35071,606,0.82,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35073,203,7.4,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35073,204,2.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35073,205,5.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35073,207,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35073,208,72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35073,255,84,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35073,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35073,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35073,301,35,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35073,303,0.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35073,306,128,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35073,307,30,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35073,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35073,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35073,401,0.3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35073,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35073,601,12,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35073,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35073,606,0.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35078,203,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35078,204,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35078,205,0.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35078,207,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35078,208,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35078,255,99.7,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35078,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35078,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35078,301,2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35078,303,0.08,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35078,306,9,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35078,307,132,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35078,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35078,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35078,401,0.3,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35078,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35078,601,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35078,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35078,606,0,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35089,203,18.9,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35089,204,6.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35089,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35089,207,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35089,208,131,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35089,255,72.8,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35089,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35089,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35089,301,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35089,303,0.29,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35089,306,317,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35089,307,51,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35089,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35089,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35089,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35089,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35089,601,55,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35089,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35089,606,1.37,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35130,203,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35130,204,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35130,205,11.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35130,207,0.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35130,208,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35130,255,86.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35130,269,0.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35130,291,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35130,301,96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35130,303,2.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35130,306,58,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35130,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35130,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35130,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35130,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35130,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35130,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35130,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35130,606,0.074,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (35131,203,10.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35131,204,5.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35131,205,76.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35131,207,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35131,208,398,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35131,255,5.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35131,269,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35131,291,8.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35131,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35131,303,2.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35131,306,393,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35131,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35131,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35131,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35131,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35131,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35131,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35131,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35131,606,0.886,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35133,203,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35133,204,0.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35133,205,8.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35133,207,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35133,208,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35133,255,89.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35133,269,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35133,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35133,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35133,303,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35133,306,28,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35133,307,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35133,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35133,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35133,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35133,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35133,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35133,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35133,606,0.075,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (35134,203,9.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35134,204,5.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35134,205,74.93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35134,207,1.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35134,208,386,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35134,255,8.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35134,269,5.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35134,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35134,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35134,303,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35134,306,511,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35134,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35134,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35134,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35134,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35134,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35134,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35134,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35134,606,0.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35135,203,9.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35135,204,5.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35135,205,75.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35135,207,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35135,208,386,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35135,255,8.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35135,269,6.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35135,291,16.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35135,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35135,303,2.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35135,306,532,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35135,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35135,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35135,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35135,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35135,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35135,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35135,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35135,606,0.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35136,203,10.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35136,204,5.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35136,205,77.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35136,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35136,208,398,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35136,255,5.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35136,269,1.46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35136,291,10.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35136,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35136,303,3.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35136,306,443,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35136,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35136,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35136,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35136,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35136,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35136,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35136,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35136,606,0.853,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35137,203,9.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35137,204,5.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35137,205,72.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35137,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35137,208,384,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35137,255,10.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35137,269,1.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35137,291,9.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35137,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35137,303,2.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35137,306,322,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35137,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35137,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35137,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35137,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35137,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35137,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35137,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35137,606,1.043,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35140,203,4.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35140,204,2.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35140,205,39.47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35140,207,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35140,208,195,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35140,255,52.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35140,269,3.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35140,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35140,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35140,303,1.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35140,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35140,307,126,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35140,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35140,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35140,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35140,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35140,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35140,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35140,606,0.353,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35141,203,33.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35141,204,11.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35141,205,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35141,207,1.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35141,208,234,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35141,255,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35141,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35141,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35141,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35141,303,4.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35141,306,409,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35141,307,135,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35141,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35141,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35141,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35141,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35141,601,109,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35141,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35141,606,5.142,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35142,203,6.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35142,204,12.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35142,205,48.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35142,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35142,208,330,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35142,255,31.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35142,269,2.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35142,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35142,301,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35142,303,4.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35142,306,77,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35142,307,329,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35142,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35142,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35142,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35142,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35142,601,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35142,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35142,606,4.621,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35143,203,7.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35143,204,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35143,205,49.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35143,207,1.87,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35143,208,237,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35143,255,39.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35143,269,2.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35143,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35143,301,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35143,303,3.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35143,306,105,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35143,307,482,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35143,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35143,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35143,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35143,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35143,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35143,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35143,606,0.296,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35144,203,8.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35144,204,3.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35144,205,8.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35144,207,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35144,208,101,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35144,255,79.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35144,269,0.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35144,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35144,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35144,303,1.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35144,306,82,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35144,307,46,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35144,320,0,'100g',1,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (35144,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35144,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35144,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35144,601,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35144,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35144,606,1.709,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35145,203,6.71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35145,204,2.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35145,205,9.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35145,207,0.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35145,208,83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35145,255,81.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35145,269,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35145,291,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35145,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35145,303,0.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35145,306,118,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35145,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35145,320,0,'100g',1,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (35145,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35145,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35145,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35145,601,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35145,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35145,606,0.733,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35146,203,8.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35146,204,4.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35146,205,7.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35146,207,3.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35146,208,103,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35146,255,76.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35146,269,0.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35146,291,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35146,301,38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35146,303,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35146,306,199,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35146,307,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35146,320,0,'100g',1,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (35146,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35146,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35146,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35146,601,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35146,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35146,606,1.735,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35147,203,6.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35147,204,6.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35147,205,18.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35147,207,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35147,208,153,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35147,255,68.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35147,269,0.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35147,291,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35147,301,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35147,303,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35147,306,131,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35147,307,427,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35147,320,0,'100g',1,1,'2024-12-12','2004-01-04');
INSERT INTO `cndb_nutval` VALUES (35147,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35147,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35147,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35147,601,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35147,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35147,606,2.396,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35148,203,8.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35148,204,3.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35148,205,10.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35148,207,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35148,208,112,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35148,255,76.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35148,269,0.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35148,291,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35148,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35148,303,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35148,306,177,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35148,307,104,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35148,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35148,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35148,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35148,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35148,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35148,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35148,606,1.603,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35149,203,20.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35149,204,2.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35149,205,1.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35149,207,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35149,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35149,255,73.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35149,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35149,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35149,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35149,303,0.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35149,306,449,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35149,307,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35149,320,47,'100g',2,1,'2024-12-12','2008-01-08');
INSERT INTO `cndb_nutval` VALUES (35149,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35149,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35149,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35149,601,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35149,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35149,606,0.726,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35150,203,22.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35150,204,5.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35150,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35150,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35150,208,140,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35150,255,69.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35150,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35150,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35150,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35150,303,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35150,306,380,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35150,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35150,320,30,'100g',2,1,'2024-12-12','2008-01-08');
INSERT INTO `cndb_nutval` VALUES (35150,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35150,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35150,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35150,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35150,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35150,606,0.904,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35151,203,21.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35151,204,7.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35151,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35151,207,1.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35151,208,153,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35151,255,69.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35151,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35151,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35151,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35151,303,0.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35151,306,360,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35151,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35151,320,58,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (35151,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35151,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35151,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35151,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35151,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35151,606,1.007,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35152,203,20.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35152,204,3.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35152,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35152,207,1.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35152,208,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35152,255,72.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35152,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35152,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35152,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35152,303,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35152,306,370,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35152,307,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35152,320,32,'100g',2,1,'2024-12-12','2009-01-05');
INSERT INTO `cndb_nutval` VALUES (35152,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35152,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35152,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35152,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35152,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35152,606,0.547,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35153,203,20.25,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35153,204,11.73,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35153,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35153,207,1.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35153,208,187,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35153,255,65.96,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35153,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35153,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35153,301,42,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35153,303,0.79,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35153,306,370,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35153,307,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35153,320,136,'100g',2,1,'2024-12-12','2008-01-08');
INSERT INTO `cndb_nutval` VALUES (35153,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35153,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35153,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35153,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35153,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35153,606,1.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35156,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35156,204,99.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35156,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35156,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35156,208,894,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35156,255,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35156,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35156,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35156,301,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35156,303,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35156,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35156,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35156,320,1044,'100g',1,1,'2024-12-12','2008-01-08');
INSERT INTO `cndb_nutval` VALUES (35156,328,0.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35156,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35156,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35156,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35156,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35156,606,14.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35157,203,27.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35157,204,5.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35157,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35157,207,1.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35157,208,161,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35157,255,65.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35157,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35157,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35157,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35157,303,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35157,306,370,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35157,307,390,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35157,320,65,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (35157,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35157,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35157,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35157,601,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35157,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35157,606,0.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35158,203,14.66,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35158,204,2.88,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35158,205,4.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35158,207,1.33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35158,208,104,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35158,255,76.24,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35158,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35158,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35158,301,46,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35158,303,5.95,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35158,306,190,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35158,307,160,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35158,320,91,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (35158,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35158,401,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35158,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35158,601,439,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35158,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35158,606,0.496,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35160,203,52.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35160,204,5.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35160,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35160,207,3.15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35160,208,255,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35160,255,38.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35160,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35160,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35160,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35160,303,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35160,306,710,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35160,307,390,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35160,320,52,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (35160,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35160,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35160,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35160,601,141,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35160,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35160,606,1.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35161,203,59.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35161,204,3.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35161,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35161,207,4.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35161,208,271,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35161,255,33.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35161,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35161,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35161,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35161,303,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35161,306,810,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35161,307,950,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35161,320,11,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (35161,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35161,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35161,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35161,601,164,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35161,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35161,606,1.586,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35162,203,22.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35162,204,3.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35162,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35162,207,1.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35162,208,122,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35162,255,72.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35162,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35162,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35162,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35162,303,4.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35162,306,320,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35162,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35162,320,94,'100g',1,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (35162,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35162,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35162,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35162,601,81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35162,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35162,606,1.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35164,203,35.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35164,204,25.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35164,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35164,207,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35164,208,367,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35164,255,35.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35164,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35164,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35164,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35164,303,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35164,306,400,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35164,307,120,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35164,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35164,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35164,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35164,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35164,601,64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35164,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35164,606,3.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35165,203,62.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35165,204,13.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35165,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35165,207,5.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35165,208,371,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35165,255,20.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35165,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35165,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35165,301,810,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35165,303,4.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35165,306,1080,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35165,307,200,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35165,320,39,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (35165,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35165,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35165,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35165,601,266,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35165,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35165,606,2.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35166,203,35.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35166,204,7.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35166,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35166,207,2.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35166,208,206,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35166,255,56.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35166,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35166,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35166,301,69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35166,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35166,306,470,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35166,307,600,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35166,320,19,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (35166,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35166,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35166,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35166,601,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35166,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35166,606,1.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35167,203,24.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35167,204,4.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35167,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35167,207,2.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35167,208,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35167,255,69.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35167,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35167,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35167,301,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35167,303,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35167,306,400,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35167,307,460,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35167,320,15,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (35167,328,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35167,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35167,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35167,601,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35167,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35167,606,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35168,203,23.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35168,204,12.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35168,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35168,207,3.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35168,208,209,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35168,255,61.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35168,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35168,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35168,301,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35168,303,0.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35168,306,390,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35168,307,870,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35168,320,12,'100g',2,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (35168,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35168,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35168,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35168,601,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35168,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35168,606,2.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35169,203,22.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35169,204,2.84,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35169,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35169,207,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35169,208,115,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35169,255,74.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35169,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35169,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35169,301,140,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35169,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35169,306,390,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35169,307,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35169,320,0,'100g',1,1,'2024-12-12','2007-01-06');
INSERT INTO `cndb_nutval` VALUES (35169,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35169,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35169,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35169,601,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35169,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35169,606,0.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35171,203,62.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35171,204,14.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35171,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35171,207,3.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35171,208,378,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35171,255,22.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35171,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35171,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35171,301,155,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35171,303,2.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35171,306,910,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35171,307,190,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35171,320,16,'100g',1,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (35171,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35171,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35171,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35171,601,214,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35171,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35171,606,2.395,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35172,203,29.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35172,204,2.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35172,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35172,207,0.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35172,208,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35172,255,67.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35172,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35172,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35172,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35172,303,9.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35172,306,379,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35172,307,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35172,320,0,'100g',1,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (35172,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35172,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35172,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35172,601,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35172,605,0.065,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (35172,606,1.138,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35173,203,20.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35173,204,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35173,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35173,207,0.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35173,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35173,255,75.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35173,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35173,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35173,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35173,303,7.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35173,306,328,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35173,307,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35173,320,0,'100g',1,1,'2024-12-12','2008-01-08');
INSERT INTO `cndb_nutval` VALUES (35173,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35173,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35173,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35173,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35173,605,0.039,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (35173,606,0.706,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35174,203,21.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35174,204,1.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35174,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35174,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35174,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35174,255,75.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35174,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35174,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35174,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35174,303,2.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35174,306,355,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35174,307,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35174,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35174,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35174,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35174,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35174,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35174,605,0.065,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (35174,606,0.418,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35176,203,32.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35176,204,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35176,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35176,207,1.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35176,208,146,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35176,255,64.28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35176,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35176,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35176,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35176,303,3.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35176,306,376,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35176,307,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35176,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35176,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35176,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35176,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35176,601,82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35176,605,0.088,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (35176,606,0.595,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35177,203,19.74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35177,204,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35177,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35177,207,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35177,208,98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35177,255,76.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35177,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35177,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35177,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35177,303,2.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35177,306,367,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35177,307,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35177,320,0,'100g',1,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (35177,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35177,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35177,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35177,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35177,605,0.032,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (35177,606,0.828,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35178,203,30.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35178,204,2.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35178,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35178,207,1.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35178,208,148,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35178,255,64.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35178,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35178,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35178,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35178,303,2.68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35178,306,369,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35178,307,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35178,320,0,'100g',1,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (35178,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35178,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35178,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35178,601,63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35178,605,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35178,606,1.125,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35180,203,77.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35180,204,8.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35180,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35180,207,10.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35180,208,382,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35180,255,6.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35180,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35180,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35180,301,85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35180,303,2.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35180,306,1720,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35180,307,2850,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35180,320,64,'100g',2,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (35180,328,15.7,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35180,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35180,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35180,601,227,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35180,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35180,606,0.829,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35181,203,21.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35181,204,8.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35181,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35181,207,1.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35181,208,159,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35181,255,70.59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35181,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35181,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35181,301,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35181,303,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35181,306,365,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35181,307,118,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35181,320,20,'100g',2,1,'2024-12-12','2006-01-05');
INSERT INTO `cndb_nutval` VALUES (35181,328,15.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35181,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35181,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35181,601,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35181,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35181,606,1.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35182,203,6.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35182,204,3.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35182,205,9.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35182,207,0.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35182,208,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35182,255,79.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35182,269,0.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35182,291,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35182,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35182,303,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35182,306,110,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35182,307,130,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35182,320,0,'100g',2,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (35182,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35182,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35182,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35182,601,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35182,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35182,606,1.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35183,203,14.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35183,204,10.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35183,205,66.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35183,207,2.24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35183,208,419,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35183,255,6.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35183,269,21.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35183,291,20.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35183,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35183,303,2.61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35183,306,775,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35183,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35183,320,13,'100g',1,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (35183,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35183,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35183,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35183,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35183,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35183,606,1.974,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35184,203,56.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35184,204,17.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35184,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35184,207,8.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35184,208,386,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35184,255,16.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35184,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35184,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35184,301,1600,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35184,303,5.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35184,306,1000,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35184,307,420,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35184,320,139,'100g',1,1,'2024-12-12','2008-01-08');
INSERT INTO `cndb_nutval` VALUES (35184,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35184,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35184,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35184,601,249,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35184,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35184,606,3.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35185,203,8.38,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35185,204,10.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35185,205,46.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35185,207,2.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35185,208,309,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35185,255,33.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35185,269,1.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35185,291,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35185,301,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35185,303,3.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35185,306,75,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35185,307,671,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35185,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35185,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35185,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35185,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35185,601,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35185,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35185,606,3.631,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35186,203,7.91,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35186,204,8.31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35186,205,29.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35186,207,1.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35186,208,224,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35186,255,52.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35186,269,1.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35186,291,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35186,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35186,303,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35186,306,275,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35186,307,511,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35186,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35186,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35186,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35186,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35186,601,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35186,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35186,606,3.366,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35187,203,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35187,204,1.05,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35187,205,53.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35187,207,2.92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35187,208,258,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35187,255,33.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35187,269,3.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35187,291,2.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35187,301,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35187,303,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35187,306,100,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35187,307,810,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35187,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35187,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35187,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35187,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35187,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35187,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35187,606,0.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35188,203,22.13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35188,204,2.73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35188,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35188,207,1.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35188,208,113,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35188,255,72.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35188,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35188,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35188,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35188,303,0.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35188,306,501,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35188,307,86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35188,320,48,'100g',2,1,'2024-12-12','2006-01-04');
INSERT INTO `cndb_nutval` VALUES (35188,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35188,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35188,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35188,601,75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35188,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35188,606,0.498,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35190,203,60.62,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35190,204,11.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35190,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35190,207,6.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35190,208,345,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35190,255,23.93,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35190,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35190,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35190,301,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35190,303,1.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35190,306,960,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35190,307,51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35190,320,31,'100g',1,1,'2024-12-12','2007-01-07');
INSERT INTO `cndb_nutval` VALUES (35190,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35190,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35190,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35190,601,155,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35190,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35190,606,2.593,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35207,203,7.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35207,204,34.08,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35207,205,51.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35207,207,2.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35207,208,541,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35207,255,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35207,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35207,291,43.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35207,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35207,303,3.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35207,306,458,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35207,307,310,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35207,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35207,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35207,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35207,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35207,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35207,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35207,606,3.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35211,203,28.81,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35211,204,4.82,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35211,205,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35211,207,1.05,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35211,208,159,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35211,255,65.47,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35211,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35211,291,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35211,301,5,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35211,303,4.8,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35211,306,245,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35211,307,45,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35211,320,94,'100g',1,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (35211,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35211,401,0,'100g',4,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35211,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35211,601,107,'100g',1,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35211,605,NULL,'100g',NULL,1,'2010-01-04','2011-03-28');
INSERT INTO `cndb_nutval` VALUES (35211,606,1.88,'100g',3,1,'2010-01-04','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35225,203,9,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35225,204,43.5,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35225,205,10.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35225,207,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35225,208,470,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35225,255,34,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35225,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35225,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35225,301,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35225,303,0.2,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35225,306,206,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35225,307,24,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35225,320,34,'100g',2,1,'2024-12-12','2012-01-09');
INSERT INTO `cndb_nutval` VALUES (35225,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35225,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35225,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35225,601,26,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35225,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35225,606,8.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35226,203,22.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35226,204,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35226,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35226,207,0.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35226,208,137,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35226,255,71.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35226,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35226,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35226,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35226,303,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35226,306,291,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35226,307,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35226,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35226,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35226,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35226,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35226,601,359,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35226,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35226,606,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35227,203,18.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35227,204,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35227,205,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35227,207,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35227,208,93,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35227,255,77.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35227,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35227,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35227,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35227,303,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35227,306,253,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35227,307,231,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35227,320,0,'100g',2,1,'2024-12-12','2009-01-07');
INSERT INTO `cndb_nutval` VALUES (35227,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35227,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35227,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35227,601,390,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35227,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35227,606,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35230,203,22.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35230,204,14.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35230,205,5.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35230,207,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35230,208,242,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35230,255,56.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35230,269,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35230,291,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35230,301,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35230,303,9.55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35230,306,346,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35230,307,80,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35230,320,89,'100g',1,1,'2024-12-12','2008-01-07');
INSERT INTO `cndb_nutval` VALUES (35230,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35230,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35230,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35230,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35230,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35230,606,2.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35232,203,7.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35232,204,1.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35232,205,80.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35232,207,1.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35232,208,361,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35232,255,9.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35232,269,0.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35232,291,19.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35232,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35232,303,1.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35232,306,553,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35232,307,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35232,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35232,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35232,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35232,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35232,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35232,605,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35232,606,0.147,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35234,203,9.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35234,204,7.16,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35234,205,72.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35234,207,2.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35234,208,390,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35234,255,8.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35234,269,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35234,291,9.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35234,301,184,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35234,303,6.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35234,306,604,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35234,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35234,320,0,'100g',1,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (35234,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35234,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35234,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35234,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35234,605,0.006,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35234,606,0.819,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35235,203,0.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35235,204,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35235,205,7.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35235,207,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35235,208,34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35235,255,91.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35235,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35235,291,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35235,301,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35235,303,1.21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35235,306,187,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35235,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35235,320,NULL,'100g',NULL,1,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (35235,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35235,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35235,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (35235,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35235,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35235,606,0.041,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35236,203,1.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35236,204,0.54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35236,205,5.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35236,207,0.41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35236,208,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35236,255,92.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35236,269,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35236,291,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35236,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35236,303,0.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35236,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35236,307,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35236,320,0,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35236,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35236,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35236,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35236,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35236,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35236,606,0.085,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (35237,203,13.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35237,204,4.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35237,205,18.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35237,207,1.45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35237,208,168,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35237,255,62.39,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35237,269,1.57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35237,291,3.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35237,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35237,303,0.66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35237,306,250,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35237,307,298,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35237,320,81,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35237,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35237,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35237,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35237,601,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35237,605,0.012,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (35237,606,1.383,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35239,203,7.83,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35239,204,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35239,205,58.12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35239,207,2.76,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35239,208,276,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35239,255,29.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35239,269,2.97,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35239,291,3.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35239,301,174,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35239,303,2.89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35239,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35239,307,663,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35239,320,0,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35239,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35239,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35239,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35239,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35239,605,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35239,606,0.287,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (35240,203,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35240,204,1.53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35240,205,39.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35240,207,0.52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35240,208,186,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35240,255,55.01,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35240,269,12.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35240,291,3.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35240,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35240,303,1.58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35240,306,114,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35240,307,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35240,320,0,'100g',1,1,'2024-12-12','2010-01-04');
INSERT INTO `cndb_nutval` VALUES (35240,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (35240,401,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35240,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (35240,601,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35240,605,0.008,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (35240,606,0.289,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42040,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42040,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42040,205,66.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42040,207,0.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42040,208,268,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42040,255,32.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42040,269,46.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42040,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42040,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42040,303,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42040,306,28,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42040,307,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42040,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (42040,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42040,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42040,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42040,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42040,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42040,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42055,203,0.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42055,204,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42055,205,87.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42055,207,10.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42055,208,218,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42055,255,1.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42055,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42055,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42055,301,1047,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42055,303,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42055,306,498,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42055,307,404,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42055,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (42055,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42055,401,560,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42055,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42055,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42055,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (42055,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42063,203,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42063,204,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42063,205,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42063,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42063,208,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42063,255,96.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42063,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42063,291,2.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42063,301,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42063,303,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42063,306,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42063,307,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42063,320,0,'100g',1,1,'2024-12-12','2002-01-07');
INSERT INTO `cndb_nutval` VALUES (42063,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42063,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42063,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (42063,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42063,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42063,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42074,203,6.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42074,204,10.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42074,205,26.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42074,207,1.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42074,208,221,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42074,255,56.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42074,269,8.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42074,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42074,301,222,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42074,303,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42074,306,305,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42074,307,104,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42074,320,19,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (42074,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42074,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42074,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42074,601,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42074,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42074,606,5.528,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42116,203,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42116,204,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42116,205,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42116,207,3.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42116,208,160,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42116,255,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42116,269,5.65,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42116,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42116,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42116,303,0.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42116,306,36,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42116,307,833,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42116,320,11,'100g',2,1,'2024-12-12','2013-01-06');
INSERT INTO `cndb_nutval` VALUES (42116,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42116,401,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42116,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42116,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42116,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42116,606,2.115,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42117,203,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42117,204,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42117,205,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42117,207,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42117,208,390,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42117,255,38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42117,269,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42117,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42117,301,705,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42117,303,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42117,306,55,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42117,307,670,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42117,320,115,'100g',2,1,'2024-12-12','2007-01-08');
INSERT INTO `cndb_nutval` VALUES (42117,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42117,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42117,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42117,601,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42117,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42117,606,5.815,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42119,203,2.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42119,204,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42119,205,17.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42119,207,0.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42119,208,86,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42119,255,78.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42119,269,13.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42119,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42119,301,79,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42119,303,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42119,306,160,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42119,307,37,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42119,320,6,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (42119,328,0,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42119,401,33.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42119,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42119,601,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42119,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42119,606,0.517,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42120,203,2.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42120,204,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42120,205,14.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42120,207,0.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42120,208,74,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42120,255,81.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42120,269,10.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42120,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42120,301,81,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42120,303,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42120,306,137,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42120,307,36,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42120,320,5,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (42120,328,0,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42120,401,33.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42120,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42120,601,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42120,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42120,606,0.517,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42128,203,19.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42128,204,5.8,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42128,205,0.93,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42128,207,1.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42128,208,134,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42128,255,72,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42128,269,0.5,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42128,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42128,301,5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42128,303,1.35,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42128,306,299,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42128,307,1038,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42128,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (42128,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42128,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42128,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42128,601,67,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42128,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42128,606,0.5,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42129,203,11.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42129,204,19.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42129,205,2.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42129,207,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42129,208,230,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42129,255,63.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42129,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42129,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42129,301,11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42129,303,0.66,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42129,306,156,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42129,307,1108,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42129,320,0,'100g',1,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (42129,328,0.5,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42129,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42129,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42129,601,39,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42129,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42129,606,7.308,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42131,203,4.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42131,204,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42131,205,37.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42131,207,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42131,208,167,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42131,255,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42131,269,37.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42131,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42131,301,154,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42131,303,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42131,306,333,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42131,307,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42131,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (42131,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42131,401,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42131,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42131,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42131,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42131,606,0.597,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42135,203,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42135,204,13.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42135,205,23.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42135,207,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42135,208,224,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42135,255,59.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42135,269,23.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42135,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42135,301,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42135,303,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42135,306,101,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42135,307,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42135,320,4,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (42135,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42135,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42135,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42135,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42135,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42135,606,11.273,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42136,203,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42136,204,15.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42136,205,73.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42136,207,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42136,208,431,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42136,255,6.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42136,269,73.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42136,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42136,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42136,303,0.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42136,306,902,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42136,307,229,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42136,320,1,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (42136,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42136,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42136,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42136,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42136,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42136,606,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42137,203,1.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42137,204,61.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42137,205,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42137,207,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42137,208,564,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42137,255,31.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42137,269,2.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42137,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42137,301,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42137,303,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42137,306,176,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42137,307,1103,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42137,320,10,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (42137,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42137,401,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42137,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42137,601,49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42137,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42137,606,10.527,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42138,203,0.9,'100g',1,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (42138,204,33.3,'100g',1,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (42138,205,6.7,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (42138,207,3.1,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (42138,208,333,'100g',1,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (42138,255,56,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (42138,269,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42138,291,0,'100g',4,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (42138,301,0,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (42138,303,0,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (42138,306,67,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42138,307,733,'100g',1,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (42138,320,0,'100g',1,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (42138,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42138,401,0,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (42138,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (42138,601,0,'100g',4,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (42138,605,NULL,'100g',NULL,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (42138,606,4.618,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (42139,203,9.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42139,204,31.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42139,205,54.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42139,207,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42139,208,536,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42139,255,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42139,269,23.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42139,291,3.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42139,301,108,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42139,303,1.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42139,306,339,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42139,307,193,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42139,320,8,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (42139,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42139,401,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42139,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42139,601,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42139,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42139,606,17.065,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42140,203,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42140,204,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42140,205,6.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42140,207,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42140,208,200,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42140,255,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42140,269,1.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42140,291,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42140,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42140,303,0.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42140,306,33,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42140,307,1074,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42140,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (42140,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42140,401,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42140,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42140,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42140,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42140,606,2.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42141,203,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42141,204,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42141,205,9.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42141,207,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42141,208,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42141,255,86.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42141,269,9.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42141,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42141,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42141,303,0.56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42141,306,177,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42141,307,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42141,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (42141,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42141,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42141,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42141,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42141,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42141,606,0.896,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42150,203,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42150,204,1.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42150,205,19.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42150,207,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42150,208,93,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42150,255,77.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42150,269,12.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42150,291,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42150,301,6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42150,303,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42150,306,70,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42150,307,20,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42150,320,3,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (42150,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42150,401,35.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42150,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42150,601,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42150,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42150,606,1.034,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42151,203,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42151,204,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42151,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42151,207,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42151,208,465,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42151,255,44.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42151,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42151,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42151,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42151,303,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42151,306,6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42151,307,581,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42151,320,819,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (42151,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42151,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42151,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (42151,601,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42151,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42151,606,17.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42153,203,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42153,204,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42153,205,13.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42153,207,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42153,208,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42153,255,77.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42153,269,3.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42153,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42153,301,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42153,303,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42153,306,51,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42153,307,939,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42153,320,67,'100g',2,1,'2024-12-12','2004-01-07');
INSERT INTO `cndb_nutval` VALUES (42153,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42153,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42153,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42153,601,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42153,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42153,606,0.628,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42155,203,28.2,'100g',6,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (42155,204,21.6,'100g',6,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (42155,205,0.7,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (42155,207,3.5,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (42155,208,313,'100g',6,1,'2004-07-15','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42155,255,46,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (42155,269,0.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42155,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (42155,301,705,'100g',6,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (42155,303,0.72,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (42155,306,81,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42155,307,781,'100g',3,1,'2004-07-15','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (42155,320,142,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (42155,328,0.4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42155,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (42155,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (42155,601,65,'100g',6,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (42155,605,NULL,'100g',NULL,1,'2004-07-15','2006-11-30');
INSERT INTO `cndb_nutval` VALUES (42155,606,14.04,'100g',6,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (42157,203,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42157,204,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42157,205,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42157,207,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42157,208,107,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42157,255,74.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42157,269,5.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42157,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42157,301,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42157,303,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42157,306,133,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42157,307,897,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42157,320,1,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (42157,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42157,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42157,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42157,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42157,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42157,606,0.494,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42158,203,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42158,204,8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42158,205,16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42158,207,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42158,208,140,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42158,255,73,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42158,269,3.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42158,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42158,301,36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42158,303,0.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42158,306,49,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42158,307,932,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42158,320,18,'100g',2,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (42158,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42158,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42158,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42158,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42158,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42158,606,1.355,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42161,203,11.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42161,204,14.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42161,205,5.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42161,207,3.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42161,208,204,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42161,255,65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42161,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42161,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42161,301,9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42161,303,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42161,306,147,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42161,307,821,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42161,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (42161,328,0.4,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42161,401,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42161,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42161,601,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42161,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42161,606,5.464,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42171,203,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42171,204,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42171,205,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42171,207,2.4,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (42171,208,227,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (42171,255,59,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42171,269,25.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42171,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42171,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42171,303,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42171,306,79,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42171,307,804,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (42171,320,10,'100g',2,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (42171,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42171,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42171,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42171,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42171,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42171,606,1.872,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42173,203,22.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42173,204,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42173,205,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42173,207,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42173,208,307,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42173,255,50.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42173,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42173,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42173,301,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42173,303,1.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42173,306,337,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42173,307,878,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42173,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (42173,328,2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42173,401,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42173,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42173,601,84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42173,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42173,606,7.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42178,203,5.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42178,204,31.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42178,205,3.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42178,207,2.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42178,208,322,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42178,255,56.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42178,269,0.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42178,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42178,301,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42178,303,0.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42178,306,66,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42178,307,773,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42178,320,2,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (42178,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42178,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42178,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42178,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42178,605,0.153,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42178,606,2.921,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42179,203,12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42179,204,9.5,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (42179,205,1.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42179,207,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42179,208,140,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42179,255,63.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42179,269,0.85,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (42179,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42179,301,8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42179,303,1.15,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42179,306,129,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42179,307,744,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (42179,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (42179,328,0.6,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42179,401,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42179,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42179,601,40,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42179,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42179,606,1.526,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (42185,203,4.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42185,204,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42185,205,19.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42185,207,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42185,208,107,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42185,255,73.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42185,269,12.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42185,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42185,301,159,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42185,303,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42185,306,339,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42185,307,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42185,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (42185,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42185,401,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42185,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42185,601,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42185,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42185,606,0.505,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42186,203,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42186,204,3.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42186,205,21.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42186,207,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42186,208,131,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42186,255,71.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42186,269,19.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42186,291,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42186,301,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42186,303,0.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42186,306,234,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42186,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42186,320,39,'100g',2,1,'2024-12-12','2009-01-06');
INSERT INTO `cndb_nutval` VALUES (42186,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42186,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42186,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42186,601,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42186,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42186,606,2.272,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42187,203,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42187,204,3.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42187,205,21.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42187,207,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42187,208,127,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42187,255,71.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42187,269,19.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42187,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42187,301,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42187,303,0.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42187,306,156,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42187,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42187,320,49,'100g',2,1,'2024-12-12','2006-01-03');
INSERT INTO `cndb_nutval` VALUES (42187,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42187,401,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42187,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42187,601,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42187,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42187,606,2.326,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42189,203,4.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42189,204,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42189,205,5.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42189,207,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42189,208,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42189,255,87.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42189,269,5.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42189,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42189,301,143,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42189,303,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42189,306,180,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42189,307,105,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42189,320,16,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (42189,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42189,401,1.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42189,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (42189,601,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42189,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42189,606,1.242,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42190,203,13.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42190,204,37.63,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42190,205,2.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42190,207,2.22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42190,208,407,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42190,255,44.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42190,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42190,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42190,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42190,303,1.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42190,306,212,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42190,307,689,'100g',1,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (42190,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (42190,328,0.9,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42190,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42190,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42190,601,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42190,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42190,606,12.825,'100g',1,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42192,203,1.52,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42192,204,1.01,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42192,205,25.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42192,207,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42192,208,115,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42192,255,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42192,269,7.44,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42192,291,1.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42192,301,51,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42192,303,0.12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42192,306,194,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42192,307,814,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42192,320,5,'100g',2,1,'2024-12-12','2008-01-01');
INSERT INTO `cndb_nutval` VALUES (42192,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42192,401,0.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42192,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42192,601,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42192,605,0.096,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (42192,606,0.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42193,203,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42193,204,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42193,205,15.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42193,207,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42193,208,84,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42193,255,78.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42193,269,10.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42193,291,1.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42193,301,6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42193,303,0.12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42193,306,49,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42193,307,788,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42193,320,0,'100g',3,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (42193,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42193,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42193,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42193,601,9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42193,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42193,606,0.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42200,203,25.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42200,204,3.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42200,205,59.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42200,207,7.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42200,208,371,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42200,255,3.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42200,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42200,291,18.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42200,301,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42200,303,7.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42200,306,1000,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42200,307,1745,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42200,320,13,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (42200,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42200,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42200,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42200,601,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42200,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42200,606,1.084,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42204,203,7.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42204,204,4.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42204,205,81.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42204,207,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42204,208,392,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42204,255,5.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42204,269,0.88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42204,291,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42204,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42204,303,1.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42204,306,428,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42204,307,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42204,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (42204,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42204,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42204,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42204,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42204,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42204,606,0.875,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42230,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42230,204,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42230,205,40,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42230,207,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42230,208,329,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42230,255,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42230,269,38.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42230,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42230,301,36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42230,303,0.26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42230,306,50,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42230,307,1600,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42230,320,0,'100g',2,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (42230,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42230,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42230,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42230,601,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42230,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42230,606,2.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42231,203,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42231,204,99.98,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42231,205,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42231,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42231,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42231,255,0.12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42231,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42231,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42231,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42231,303,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42231,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42231,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42231,320,0,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (42231,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42231,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42231,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (42231,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42231,605,0.094,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42231,606,8.976,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42235,203,12.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42235,204,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42235,205,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42235,207,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42235,208,74,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42235,255,82.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42235,269,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42235,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42235,301,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42235,303,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42235,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42235,307,220,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42235,320,11,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (42235,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42235,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42235,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (42235,601,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42235,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42235,606,0.64,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42236,203,7.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42236,204,3.33,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (42236,205,84.7,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42236,207,2.27,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (42236,208,400,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42236,255,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42236,269,36.13,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (42236,291,4.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42236,301,333,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (42236,303,15,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (42236,306,207,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42236,307,533,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42236,320,500,'100g',2,1,'2024-12-12','2014-01-02');
INSERT INTO `cndb_nutval` VALUES (42236,328,3.6,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42236,401,20,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (42236,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42236,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42236,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (42236,606,0.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42256,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42256,204,52,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42256,205,16.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42256,207,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42256,208,534,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42256,255,30,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42256,269,16.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42256,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42256,301,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42256,303,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42256,306,30,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42256,307,542,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42256,320,819,'100g',2,1,'2024-12-12','2002-01-11');
INSERT INTO `cndb_nutval` VALUES (42256,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42256,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42256,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (42256,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42256,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42256,606,8.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42259,203,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42259,204,28.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42259,205,58.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42259,207,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42259,208,500,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42259,255,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42259,269,0.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42259,291,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42259,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42259,303,2.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42259,306,225,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42259,307,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42259,320,8,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (42259,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42259,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42259,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (42259,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42259,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42259,606,5.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42266,203,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42266,204,0.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42266,205,11.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42266,207,0.29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42266,208,47,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42266,255,87.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42266,269,9.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42266,291,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42266,301,15,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42266,303,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42266,306,137,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42266,307,5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42266,320,154,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (42266,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42266,401,34.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42266,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42266,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42266,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42266,606,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42267,203,0.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42267,204,0.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42267,205,9.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42267,207,0.25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42267,208,43,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42267,255,89.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42267,269,8.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42267,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42267,301,16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42267,303,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42267,306,174,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42267,307,10,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42267,320,94,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (42267,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42267,401,34.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42267,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42267,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42267,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42267,606,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42270,203,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42270,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42270,205,13.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42270,207,0.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42270,208,54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42270,255,86.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42270,269,9.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42270,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42270,301,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42270,303,0.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42270,306,42,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42270,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42270,320,2,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (42270,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42270,401,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42270,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42270,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42270,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (42270,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42272,203,5.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42272,204,32.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42272,205,55.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42272,207,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42272,208,531,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42272,255,6.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42272,269,34.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42272,291,6.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42272,301,42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42272,303,1.75,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42272,306,254,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42272,307,152,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42272,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (42272,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42272,401,0.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42272,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42272,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42272,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42272,606,22.72,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42278,203,1.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42278,204,1.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42278,205,12.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42278,207,0.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42278,208,69,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42278,255,84.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42278,269,2.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42278,291,1.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42278,301,14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42278,303,0.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42278,306,135,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42278,307,14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42278,320,8,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (42278,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42278,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42278,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42278,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42278,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42278,606,0.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42279,203,3.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42279,204,0.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42279,205,11.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42279,207,0.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42279,208,64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42279,255,84.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42279,269,2.89,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (42279,291,2.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42279,301,14,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42279,303,1.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42279,306,93,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42279,307,6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42279,320,19,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (42279,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42279,401,3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42279,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42279,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42279,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (42279,606,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42280,203,15.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42280,204,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42280,205,8.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42280,207,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42280,208,121,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42280,255,69.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42280,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42280,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42280,301,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42280,303,0.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42280,306,261,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42280,307,983,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42280,320,1,'100g',2,1,'2024-12-12','2002-01-09');
INSERT INTO `cndb_nutval` VALUES (42280,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42280,401,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42280,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42280,601,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42280,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42280,606,0.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42281,203,4.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42281,204,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42281,205,77.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42281,207,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42281,208,332,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42281,255,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42281,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42281,291,77.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42281,301,294,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42281,303,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42281,306,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42281,307,125,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42281,320,0,'100g',1,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (42281,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42281,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42281,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42281,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42281,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42281,606,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42283,203,5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42283,204,18.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42283,205,71.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42283,207,3.98,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42283,208,469,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42283,255,1.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42283,269,5.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42283,291,4.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42283,301,125,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42283,303,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42283,306,721,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42283,307,536,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42283,320,0,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (42283,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42283,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42283,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42283,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42283,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42283,606,2.631,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42284,203,6.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42284,204,9.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42284,205,76.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42284,207,3.32,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42284,208,421,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42284,255,3.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42284,269,28,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42284,291,2.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42284,301,400,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42284,303,22.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42284,306,114,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42284,307,0,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42284,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (42284,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42284,401,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42284,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42284,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42284,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42284,606,1.646,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42285,203,8.7,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (42285,204,3,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (42285,205,85.98,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (42285,207,1.32,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (42285,208,406,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (42285,255,1,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (42285,269,0.72,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (42285,291,6.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42285,301,55,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (42285,303,47.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42285,306,386,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42285,307,12,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (42285,320,0,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (42285,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42285,401,0,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (42285,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42285,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42285,605,0.001,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (42285,606,0.61,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (42286,203,4.1,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (42286,204,1.5,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (42286,205,5.35,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (42286,207,1.55,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (42286,208,51,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (42286,255,87.5,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (42286,269,1.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42286,291,1.4,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (42286,301,31,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (42286,303,0.7,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (42286,306,188,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42286,307,11,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (42286,320,31,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (42286,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42286,401,2.2,'100g',6,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (42286,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42286,601,11,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (42286,605,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (42286,606,0.5,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (42289,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42289,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42289,205,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42289,207,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42289,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42289,255,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42289,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42289,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42289,301,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42289,303,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42289,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42289,307,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42289,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (42289,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42289,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42289,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (42289,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42289,605,0.334,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42289,606,8.026,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42290,203,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42290,204,0.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42290,205,4.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42290,207,0.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42290,208,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42290,255,90.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42290,269,4.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42290,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42290,301,204,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42290,303,0.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42290,306,166,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42290,307,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42290,320,137,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (42290,328,1.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42290,401,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42290,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (42290,601,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42290,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42290,606,0.117,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (42291,203,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42291,204,49.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42291,205,21.83,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42291,207,3.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42291,208,590,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42291,255,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42291,269,9.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42291,291,6.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42291,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42291,303,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42291,306,747,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42291,307,203,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42291,320,0,'100g',2,1,'2024-12-12','2010-01-02');
INSERT INTO `cndb_nutval` VALUES (42291,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42291,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42291,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42291,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42291,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42291,606,7.716,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42303,203,24.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42303,204,17.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42303,205,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42303,207,3.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42303,208,271,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42303,255,50.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42303,269,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42303,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42303,301,529,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42303,303,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42303,306,134,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42303,307,600,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42303,320,175,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (42303,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42303,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42303,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (42303,601,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42303,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42303,606,10.95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42304,203,31.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42304,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42304,205,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42304,207,4.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42304,208,141,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42304,255,60.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42304,269,1.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42304,291,1.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42304,301,961,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42304,303,0.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42304,306,106,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42304,307,743,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42304,320,127,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (42304,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42304,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42304,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (42304,601,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42304,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42304,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42307,203,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42307,204,80.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42307,205,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42307,207,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42307,208,718,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42307,255,15.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42307,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42307,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42307,301,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42307,303,0.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42307,306,37,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42307,307,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42307,320,819,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (42307,328,0.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42307,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42307,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (42307,601,88,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42307,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42307,606,26.904,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42309,203,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42309,204,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42309,205,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42309,207,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42309,208,450,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42309,255,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42309,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42309,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42309,301,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42309,303,0.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42309,306,37,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42309,307,607,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42309,320,819,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (42309,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42309,401,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42309,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (42309,601,71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42309,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42309,606,16.669,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (42316,203,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42316,204,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42316,205,5.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42316,207,0.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42316,208,21,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (42316,255,93.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42316,269,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42316,291,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42316,301,19,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42316,303,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42316,306,129,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42316,307,48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42316,320,736,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (42316,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (42316,401,0.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42316,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (42316,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42316,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (42316,606,0.052,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43004,203,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43004,204,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43004,205,14.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43004,207,0.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43004,208,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43004,255,83.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43004,269,10.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43004,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43004,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43004,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43004,306,90,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43004,307,54,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43004,320,1,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (43004,328,0.1,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43004,401,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43004,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43004,601,29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43004,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43004,606,0.264,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43006,203,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43006,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43006,205,15.48,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43006,207,0.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43006,208,66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43006,255,83.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43006,269,9.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43006,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43006,301,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43006,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43006,306,46,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43006,307,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43006,320,7,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (43006,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43006,401,12.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43006,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43006,601,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43006,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43006,606,0.087,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43007,203,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43007,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43007,205,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43007,207,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43007,208,69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43007,255,82.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43007,269,9.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43007,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43007,301,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43007,303,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43007,306,47,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43007,307,17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43007,320,10,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (43007,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43007,401,7.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43007,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43007,601,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43007,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43007,606,0.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43008,203,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43008,204,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43008,205,9.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43008,207,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43008,208,51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43008,255,88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43008,269,0.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43008,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43008,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43008,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43008,306,60,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43008,307,25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43008,320,58,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (43008,328,0,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43008,401,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43008,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43008,601,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43008,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43008,606,0.211,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43015,203,2.17,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43015,204,57.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43015,205,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43015,207,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43015,208,542,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43015,255,34.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43015,269,2.81,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43015,291,0.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43015,301,48,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43015,303,1.08,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43015,306,29,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43015,307,1209,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43015,320,9,'100g',2,1,'2024-12-12','2007-01-12');
INSERT INTO `cndb_nutval` VALUES (43015,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43015,401,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43015,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43015,601,39,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43015,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43015,606,8.789,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43016,203,0.85,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43016,204,34.53,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43016,205,22.4,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43016,207,2.37,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43016,208,404,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43016,255,39.85,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43016,269,21.23,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43016,291,0,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43016,301,9,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43016,303,0.33,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43016,306,35,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43016,307,850,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43016,320,17,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (43016,328,0,'100g',3,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43016,401,0.6,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43016,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43016,601,41,'100g',1,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43016,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43016,606,5.343,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43017,203,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43017,204,43.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43017,205,7.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43017,207,2.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43017,208,427,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43017,255,45.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43017,269,6.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43017,291,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43017,301,34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43017,303,0.35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43017,306,58,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43017,307,867,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43017,320,10,'100g',2,1,'2024-12-12','2005-01-07');
INSERT INTO `cndb_nutval` VALUES (43017,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43017,401,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43017,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43017,601,40,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43017,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43017,606,5.978,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43019,203,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43019,204,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43019,205,3.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43019,207,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43019,208,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43019,255,95.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43019,269,3.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43019,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43019,301,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43019,303,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43019,306,33,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43019,307,208,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43019,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (43019,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43019,401,8.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43019,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43019,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43019,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43019,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43020,203,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43020,204,7.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43020,205,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43020,207,5.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43020,208,99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43020,255,79.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43020,269,2.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43020,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43020,301,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43020,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43020,306,5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43020,307,939,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43020,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (43020,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43020,401,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43020,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43020,601,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43020,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43020,606,2.575,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43021,203,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43021,204,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43021,205,18.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43021,207,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43021,208,110,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43021,255,73.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43021,269,16.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43021,291,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43021,301,24,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43021,303,0.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43021,306,29,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43021,307,1148,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43021,320,1,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (43021,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43021,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43021,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43021,601,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43021,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43021,606,0.703,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43026,203,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43026,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43026,205,11.99,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43026,207,0.21,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43026,208,51,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43026,255,87,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43026,269,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43026,291,0.7,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43026,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43026,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43026,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43026,307,210,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43026,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (43026,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43026,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43026,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43026,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43026,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43026,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43027,203,0.55,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43027,204,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43027,205,29.6,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43027,207,0.32,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43027,208,121,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43027,255,69.53,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43027,269,3.39,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43027,291,2.2,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43027,301,31,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43027,303,0.15,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43027,306,96,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43027,307,3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43027,320,35,'100g',2,1,'2024-12-12','2015-01-03');
INSERT INTO `cndb_nutval` VALUES (43027,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43027,401,0,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43027,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43027,601,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43027,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (43027,606,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43028,203,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43028,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43028,205,53.42,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43028,207,0.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43028,208,132,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43028,255,45.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43028,269,37.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43028,291,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43028,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43028,303,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43028,306,69,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43028,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43028,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43028,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43028,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43028,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43028,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43028,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43028,606,0.016,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43031,203,9.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43031,204,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43031,205,60.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43031,207,2.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43031,208,470,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43031,255,6.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43031,269,41.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43031,291,4.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43031,301,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43031,303,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43031,306,445,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43031,307,156,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43031,320,42,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43031,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43031,401,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43031,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43031,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43031,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43031,606,4.657,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43046,203,3.33,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43046,204,1.67,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43046,205,92.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43046,207,0.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43046,208,398,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43046,255,2.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43046,269,44.97,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43046,291,3.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43046,301,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43046,303,0.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43046,306,105,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43046,307,33,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43046,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43046,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43046,401,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43046,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43046,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43046,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43046,606,1.667,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43057,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43057,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43057,205,88.1,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43057,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43057,208,354,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43057,255,11.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43057,269,70,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43057,291,0,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43057,301,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43057,303,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43057,306,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43057,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43057,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43057,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43057,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43057,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43057,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43057,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43057,606,0.034,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43058,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43058,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43058,205,98.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43058,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43058,208,394,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43058,255,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43058,269,0,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43058,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43058,301,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43058,303,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43058,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43058,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43058,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43058,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43058,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43058,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43058,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43058,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43058,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43059,203,12.39,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43059,204,43.27,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43059,205,37.68,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43059,207,2.67,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43059,208,590,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43059,255,4,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43059,269,14.63,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43059,291,3.5,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43059,301,285,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43059,303,1.45,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43059,306,606,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43059,307,111,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43059,320,55,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43059,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43059,401,1.4,'100g',1,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43059,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43059,601,22,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43059,605,0.121,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43059,606,21.723,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43060,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43060,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43060,205,94.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43060,207,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43060,208,268,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43060,255,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43060,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43060,291,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43060,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43060,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43060,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43060,307,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43060,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (43060,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43060,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43060,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43060,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43060,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43060,606,0.058,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43075,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43075,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43075,205,2.45,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43075,207,0.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43075,208,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43075,255,96.44,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43075,269,2.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43075,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43075,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43075,303,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43075,306,77,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43075,307,101,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43075,320,0,'100g',1,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43075,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43075,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43075,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43075,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43075,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43075,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43098,203,0.82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43098,204,0.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43098,205,11.98,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43098,207,0.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43098,208,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43098,255,86.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43098,269,9.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43098,291,1.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43098,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43098,303,0.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43098,306,118,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43098,307,12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43098,320,10,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (43098,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43098,401,2.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43098,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43098,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43098,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43098,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43100,203,9.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43100,204,17.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43100,205,66.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43100,207,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43100,208,464,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43100,255,4.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43100,269,27.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43100,291,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43100,301,60,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43100,303,3.18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43100,306,326,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43100,307,251,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43100,320,8,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43100,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43100,401,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43100,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43100,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43100,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43100,606,12.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43109,203,8.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43109,204,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43109,205,69.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43109,207,4.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43109,208,338,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43109,255,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43109,269,0.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43109,291,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43109,301,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43109,303,3.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43109,306,88,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43109,307,203,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43109,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43109,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43109,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43109,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43109,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43109,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43109,606,0.695,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43112,203,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43112,204,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43112,205,16.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43112,207,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43112,208,97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43112,255,75.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43112,269,5.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43112,291,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43112,301,31,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43112,303,1.86,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43112,306,450,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43112,307,725,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43112,320,1,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (43112,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43112,401,1.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43112,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43112,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43112,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43112,606,0.145,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43114,203,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43114,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43114,205,82.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43114,207,5.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43114,208,331,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43114,255,11.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43114,269,17.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43114,291,3.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43114,301,55,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43114,303,1.81,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43114,306,3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43114,307,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43114,320,2,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (43114,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43114,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43114,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43114,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43114,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43114,606,0.014,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43125,203,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43125,204,3.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43125,205,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43125,207,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43125,208,47,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43125,255,91.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43125,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43125,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43125,301,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43125,303,1.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43125,306,408,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43125,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43125,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (43125,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43125,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43125,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43125,601,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43125,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43125,606,1.174,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43128,203,23.64,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43128,204,12.73,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43128,205,3.64,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43128,207,1.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43128,208,224,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43128,255,58.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43128,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43128,291,3.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43128,301,35,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43128,303,3.27,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43128,306,54,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43128,307,709,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43128,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (43128,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43128,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43128,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43128,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43128,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43128,606,1.534,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43130,203,19.61,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43130,204,13.73,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43130,205,7.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43130,207,0.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43130,208,233,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43130,255,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43130,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43130,291,3.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43130,301,33,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43130,303,1.41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43130,306,98,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43130,307,471,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43130,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (43130,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43130,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43130,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43130,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43130,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43130,606,1.653,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43131,203,17.78,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43131,204,11.11,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43131,205,4.44,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43131,207,1.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43131,208,189,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43131,255,65.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43131,269,2.22,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43131,291,1.1,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43131,301,41,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43131,303,1.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43131,306,200,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43131,307,711,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43131,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (43131,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43131,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43131,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43131,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43131,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43131,606,1.338,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43132,203,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43132,204,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43132,205,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43132,207,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43132,208,197,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43132,255,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43132,269,1.25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43132,291,4.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43132,301,25,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43132,303,2.16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43132,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43132,307,550,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43132,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (43132,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43132,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43132,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43132,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43132,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43132,606,1.425,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43134,203,23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43134,204,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43134,205,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43134,207,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43134,208,290,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43134,255,45,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43134,269,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43134,291,6.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43134,301,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43134,303,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43134,306,600,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43134,307,490,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43134,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (43134,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43134,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43134,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43134,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43134,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43134,606,2.849,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43135,203,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43135,204,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43135,205,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43135,207,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43135,208,149,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43135,255,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43135,269,1.9,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43135,291,3.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43135,301,44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43135,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43135,306,340,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43135,307,630,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43135,320,0,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (43135,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43135,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43135,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43135,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43135,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43135,606,1.425,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43137,203,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43137,204,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43137,205,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43137,207,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43137,208,197,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43137,255,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43137,269,1.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43137,291,4.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43137,301,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43137,303,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43137,306,180,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43137,307,550,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43137,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (43137,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43137,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43137,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43137,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43137,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43137,606,1.425,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43142,203,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43142,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43142,205,5.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43142,207,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43142,208,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43142,255,91.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43142,269,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43142,291,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43142,301,28,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43142,303,0.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43142,306,333,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43142,307,789,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43142,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (43142,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43142,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43142,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43142,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43142,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43142,606,0.092,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43143,203,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43143,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43143,205,5.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43143,207,1.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43143,208,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43143,255,91.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43143,269,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43143,291,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43143,301,48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43143,303,0.49,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43143,306,853,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43143,307,277,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43143,320,9,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (43143,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43143,401,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43143,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43143,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43143,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43143,606,0.013,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43144,203,1.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43144,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43144,205,5.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43144,207,1.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43144,208,28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43144,255,92.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43144,269,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43144,291,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43144,301,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43144,303,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43144,306,246,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43144,307,717,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43144,320,49,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (43144,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43144,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43144,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43144,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43144,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43144,606,0.013,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43146,203,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43146,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43146,205,9.77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43146,207,1.73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43146,208,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43146,255,86.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43146,269,4.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43146,291,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43146,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43146,303,0.77,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43146,306,12,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43146,307,1674,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43146,320,3,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (43146,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43146,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43146,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43146,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43146,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43146,606,0.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43154,203,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43154,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43154,205,6.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43154,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43154,208,50,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43154,255,88.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43154,269,1.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43154,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43154,301,9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43154,303,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43154,306,88,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43154,307,626,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43154,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (43154,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43154,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43154,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43154,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43154,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43154,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43158,203,0.94,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43158,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43158,205,89.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43158,207,1.19,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43158,208,360,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43158,255,8.75,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43158,269,85.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43158,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43158,301,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43158,303,0.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43158,306,4,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43158,307,428,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43158,320,0,'100g',2,1,'2024-12-12','2005-01-02');
INSERT INTO `cndb_nutval` VALUES (43158,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43158,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43158,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43158,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43158,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43158,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43205,203,19.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43205,204,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43205,205,66.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43205,207,5.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43205,208,353,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43205,255,7.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43205,269,65.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43205,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43205,301,285,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43205,303,12.82,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43205,306,947,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43205,307,385,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43205,320,625,'100g',2,1,'2024-12-12','2013-01-10');
INSERT INTO `cndb_nutval` VALUES (43205,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43205,401,76.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43205,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43205,601,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43205,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43205,606,0.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43212,203,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43212,204,25.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43212,205,28.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43212,207,5.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43212,208,476,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43212,255,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43212,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43212,291,10.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43212,301,101,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43212,303,0.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43212,306,145,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43212,307,1770,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43212,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (43212,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43212,401,1.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43212,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43212,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43212,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43212,606,4.055,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43214,203,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43214,204,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43214,205,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43214,207,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43214,208,373,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43214,255,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43214,269,5.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43214,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43214,301,23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43214,303,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43214,306,2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43214,307,1200,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43214,320,0,'100g',3,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43214,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43214,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43214,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43214,601,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43214,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43214,606,0.589,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43215,203,1.25,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43215,204,12.42,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43215,205,21.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43215,207,2.96,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43215,208,202,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43215,255,62.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43215,269,3.77,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43215,291,1.1,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43215,301,40,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43215,303,0.69,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43215,306,132,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43215,307,1120,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43215,320,18,'100g',2,1,'2024-12-12','2007-01-12');
INSERT INTO `cndb_nutval` VALUES (43215,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43215,401,0.6,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43215,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43215,601,16,'100g',7,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43215,605,0.059,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43215,606,1.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43216,203,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43216,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43216,205,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43216,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43216,208,368,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43216,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43216,269,92.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43216,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43216,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43216,303,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43216,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43216,307,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43216,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (43216,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43216,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43216,539,92.7,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43216,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43216,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43216,606,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43217,203,1.2,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43217,204,0.3,'100g',7,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43217,205,5.31,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43217,207,1.92,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43217,208,24,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43217,255,91.28,'100g',7,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43217,269,3.56,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43217,291,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43217,301,14,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43217,303,0.96,'100g',1,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43217,306,297,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43217,307,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43217,320,22,'100g',2,1,'2024-12-12','2011-01-05');
INSERT INTO `cndb_nutval` VALUES (43217,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43217,401,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43217,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43217,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43217,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43217,606,0.041,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43245,203,7.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43245,204,5.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43245,205,76.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43245,207,2.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43245,208,385,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43245,255,8.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43245,269,23.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43245,291,9.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43245,301,43,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43245,303,9.82,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43245,306,382,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43245,307,245,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43245,320,410,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (43245,328,1.8,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43245,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43245,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43245,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43245,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43245,606,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43260,203,35.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43260,204,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43260,205,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43260,207,10.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43260,208,358,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43260,255,7.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43260,269,39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43260,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43260,301,500,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43260,303,2.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43260,306,1705,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43260,307,717,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43260,320,2686,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43260,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43260,401,138,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43260,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43260,601,44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43260,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43260,606,2.162,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43261,203,4.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43261,204,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43261,205,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43261,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43261,208,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43261,255,75.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43261,269,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43261,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43261,301,152,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43261,303,0.07,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43261,306,194,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43261,307,58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43261,320,2,'100g',2,1,'2024-12-12','2006-01-12');
INSERT INTO `cndb_nutval` VALUES (43261,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43261,401,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43261,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43261,601,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43261,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43261,606,0.119,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43268,203,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43268,204,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43268,205,10.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43268,207,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43268,208,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43268,255,82.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43268,269,10.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43268,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43268,301,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43268,303,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43268,306,26,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43268,307,106,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43268,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (43268,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43268,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43268,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43268,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43268,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43268,606,3.186,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43269,203,4.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43269,204,6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43269,205,29.64,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43269,207,0.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43269,208,190,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43269,255,59.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43269,269,20.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43269,291,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43269,301,120,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43269,303,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43269,306,211,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43269,307,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43269,320,131,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (43269,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43269,401,1.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43269,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43269,601,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43269,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43269,606,3.09,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43273,203,10.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43273,204,4.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43273,205,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43273,207,1.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43273,208,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43273,255,80.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43273,269,0.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43273,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43273,301,56,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43273,303,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43273,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43273,307,403,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43273,320,53,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (43273,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43273,401,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43273,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43273,601,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43273,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43273,606,2.646,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43274,203,7.85,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43274,204,16.67,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43274,205,6.73,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43274,207,2.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43274,208,208,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43274,255,66.72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43274,269,3.3,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43274,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43274,301,148,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43274,303,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43274,306,247,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43274,307,317,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43274,320,161,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43274,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43274,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43274,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43274,601,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43274,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43274,606,10,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43275,203,24.6,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43275,204,7,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43275,205,3.5,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43275,207,6,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43275,208,180,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43275,255,58.9,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43275,269,0.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43275,291,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43275,301,684,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43275,303,0.43,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43275,306,180,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43275,307,1789,'100g',3,1,'2004-07-15','2013-12-26');
INSERT INTO `cndb_nutval` VALUES (43275,320,57,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43275,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43275,401,0,'100g',4,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43275,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43275,601,35,'100g',1,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43275,605,NULL,'100g',NULL,1,'2004-07-15','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (43275,606,4.41,'100g',3,1,'2004-07-15','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43276,203,7.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43276,204,28.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43276,205,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43276,207,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43276,208,295,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43276,255,58.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43276,269,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43276,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43276,301,71,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43276,303,1.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43276,306,112,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43276,307,436,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43276,320,302,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43276,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43276,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43276,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43276,601,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43276,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43276,606,18.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43278,203,16.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43278,204,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43278,205,11.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43278,207,4.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43278,208,239,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43278,255,53.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43278,269,7.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43278,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43278,301,562,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43278,303,0.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43278,306,242,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43278,307,1345,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43278,320,114,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (43278,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43278,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43278,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43278,601,36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43278,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43278,606,8.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43282,203,25.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43282,204,14.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43282,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43282,207,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43282,208,227,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43282,255,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43282,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43282,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43282,301,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43282,303,4.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43282,306,216,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43282,307,52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43282,320,70,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (43282,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43282,401,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43282,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43282,601,86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43282,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43282,606,3.955,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43283,203,32.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43283,204,12.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43283,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43283,207,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43283,208,239,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43283,255,54.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43283,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43283,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43283,301,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43283,303,1.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43283,306,271,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43283,307,43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43283,320,57,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (43283,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43283,401,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43283,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43283,601,89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43283,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43283,606,3.908,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43285,203,13.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43285,204,5.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43285,205,7.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43285,207,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43285,208,131,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43285,255,72.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43285,269,7.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43285,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43285,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43285,303,0.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43285,306,147,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43285,307,162,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43285,320,21,'100g',2,1,'2024-12-12','2010-01-09');
INSERT INTO `cndb_nutval` VALUES (43285,328,1.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43285,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43285,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43285,601,277,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43285,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43285,606,1.052,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43287,203,23.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43287,204,13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43287,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43287,207,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43287,208,213,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43287,255,62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43287,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43287,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43287,301,17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43287,303,5.91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43287,306,256,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43287,307,57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43287,320,28,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (43287,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43287,401,2.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43287,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43287,601,116,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43287,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43287,606,3.739,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43297,203,11.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43297,204,62.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43297,205,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43297,207,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43297,208,615,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43297,255,21.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43297,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43297,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43297,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43297,303,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43297,306,139,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43297,307,685,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43297,320,0,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (43297,328,NULL,'100g',NULL,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43297,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43297,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43297,601,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43297,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43297,606,23.056,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43299,203,12.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43299,204,8.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43299,205,6.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43299,207,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43299,208,151,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43299,255,70.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43299,269,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43299,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43299,301,188,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43299,303,5.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43299,306,199,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43299,307,20,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43299,320,2,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (43299,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43299,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43299,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43299,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43299,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43299,606,1.172,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43311,203,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43311,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43311,205,13.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43311,207,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43311,208,60,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43311,255,84.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43311,269,0.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43311,291,2.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43311,301,5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43311,303,1.26,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43311,306,229,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43311,307,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43311,320,0,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (43311,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43311,401,5.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43311,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43311,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43311,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43311,606,0.051,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43312,203,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43312,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43312,205,7.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43312,207,0.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43312,208,37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43312,255,90.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43312,269,2.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43312,291,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43312,301,21,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43312,303,0.65,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43312,306,138,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43312,307,26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43312,320,583,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (43312,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43312,401,3.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43312,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43312,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43312,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43312,606,0.039,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43325,203,22,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43325,204,7.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43325,205,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43325,207,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43325,208,165,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43325,255,65.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43325,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43325,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43325,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43325,303,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43325,306,362,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43325,307,969,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43325,320,0,'100g',1,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (43325,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43325,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43325,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43325,601,57,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43325,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43325,606,2.624,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43326,203,22.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43326,204,8.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43326,205,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43326,207,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43326,208,172,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43326,255,65.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43326,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43326,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43326,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43326,303,1.37,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43326,306,386,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43326,307,969,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43326,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (43326,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43326,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43326,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43326,601,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43326,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43326,606,2.781,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43327,203,20.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43327,204,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43327,205,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43327,207,4.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43327,208,145,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43327,255,67.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43327,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43327,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43327,301,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43327,303,1.48,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43327,306,287,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43327,307,969,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43327,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (43327,328,0.8,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43327,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43327,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43327,601,53,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43327,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43327,606,1.801,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43329,203,0.9,'100g',NULL,1,'2011-03-28','2011-03-28');
INSERT INTO `cndb_nutval` VALUES (43329,204,19,'100g',NULL,1,'2011-03-28','2011-03-28');
INSERT INTO `cndb_nutval` VALUES (43329,205,23.9,'100g',NULL,1,'2011-03-28','2011-03-28');
INSERT INTO `cndb_nutval` VALUES (43329,207,2,'100g',NULL,1,'2011-03-28','2011-03-28');
INSERT INTO `cndb_nutval` VALUES (43329,208,263,'100g',NULL,1,'2011-03-28','2011-03-28');
INSERT INTO `cndb_nutval` VALUES (43329,255,54.3,'100g',NULL,1,'2011-03-28','2011-03-28');
INSERT INTO `cndb_nutval` VALUES (43329,269,4.34,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43329,291,0,'100g',NULL,1,'2011-03-28','2011-03-28');
INSERT INTO `cndb_nutval` VALUES (43329,301,14,'100g',NULL,1,'2011-03-28','2011-03-28');
INSERT INTO `cndb_nutval` VALUES (43329,303,0.26,'100g',NULL,1,'2011-03-28','2011-03-28');
INSERT INTO `cndb_nutval` VALUES (43329,306,24,'100g',7,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43329,307,837,'100g',NULL,1,'2011-03-28','2011-03-28');
INSERT INTO `cndb_nutval` VALUES (43329,320,21,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43329,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43329,401,0,'100g',NULL,1,'2011-03-28','2011-03-28');
INSERT INTO `cndb_nutval` VALUES (43329,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43329,601,26,'100g',NULL,1,'2011-03-28','2011-03-28');
INSERT INTO `cndb_nutval` VALUES (43329,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (43329,606,2.962,'100g',NULL,1,'2011-03-28','2011-03-28');
INSERT INTO `cndb_nutval` VALUES (43331,203,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43331,204,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43331,205,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43331,207,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43331,208,326,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43331,255,58.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43331,269,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43331,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43331,301,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43331,303,0.27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43331,306,108,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43331,307,905,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43331,320,11,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43331,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43331,401,8.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43331,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43331,601,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43331,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43331,606,5.435,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43340,203,41.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43340,204,29.99,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43340,205,3.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43340,207,2.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43340,208,451,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43340,255,22.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43340,269,0.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43340,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43340,301,800,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43340,303,0.95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43340,306,107,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43340,307,63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43340,320,125,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43340,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43340,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43340,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43340,601,79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43340,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43340,606,19.051,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43344,203,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43344,204,0.1,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43344,205,37.6,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43344,207,0.3,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43344,208,151,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43344,255,62,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43344,269,29.41,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43344,291,1.5,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43344,301,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43344,303,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43344,306,59,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43344,307,0,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43344,320,0,'100g',2,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (43344,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43344,401,15,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43344,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43344,601,0,'100g',4,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43344,605,NULL,'100g',NULL,1,'2016-03-11','2016-03-11');
INSERT INTO `cndb_nutval` VALUES (43344,606,0.005,'100g',3,1,'2016-02-06','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43345,203,0.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43345,204,0.16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43345,205,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43345,207,7.27,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43345,208,227,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43345,255,1.32,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43345,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43345,291,2.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43345,301,800,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43345,303,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43345,306,2518,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43345,307,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43345,320,5997,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (43345,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43345,401,2400,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43345,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43345,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43345,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43345,606,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43346,203,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43346,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43346,205,23.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43346,207,0.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43346,208,95,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43346,255,76.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43346,269,19.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43346,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43346,301,9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43346,303,0.47,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43346,306,100,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43346,307,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43346,320,1,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (43346,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43346,401,25.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43346,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43346,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43346,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43346,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43352,203,12.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43352,204,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43352,205,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43352,207,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43352,208,72,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43352,255,83.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43352,269,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43352,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43352,301,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43352,303,0.14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43352,306,86,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43352,307,13,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43352,320,11,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (43352,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43352,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43352,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43352,601,4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43352,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43352,606,0.632,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43355,203,0.3,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (43355,204,19.2,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (43355,205,16,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (43355,207,1.8,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (43355,208,231,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (43355,255,62.7,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (43355,269,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43355,291,0,'100g',4,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (43355,301,0,'100g',4,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (43355,303,0,'100g',4,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (43355,306,10,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43355,307,110,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (43355,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43355,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43355,401,0,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (43355,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43355,601,24,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (43355,605,NULL,'100g',NULL,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (43355,606,3.3,'100g',3,1,'2011-03-09','2011-03-09');
INSERT INTO `cndb_nutval` VALUES (43364,203,7.79,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43364,204,23.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43364,205,65.32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43364,207,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43364,208,503,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43364,255,2.09,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43364,269,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43364,291,5.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43364,301,174,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43364,303,2.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43364,306,215,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43364,307,15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43364,320,4,'100g',2,1,'2024-12-12','2005-01-05');
INSERT INTO `cndb_nutval` VALUES (43364,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43364,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43364,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43364,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43364,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43364,606,2.458,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43365,203,0.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43365,204,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43365,205,4.59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43365,207,1.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43365,208,22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43365,255,93.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43365,269,3.28,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43365,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43365,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43365,303,0.42,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43365,306,193,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43365,307,58,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43365,320,78,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (43365,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43365,401,27.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43365,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43365,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43365,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43365,606,0.014,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43366,203,27.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43366,204,12.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43366,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43366,207,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43366,208,221,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43366,255,59.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43366,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43366,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43366,301,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43366,303,1.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43366,306,266,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43366,307,996,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43366,320,0,'100g',1,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (43366,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43366,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43366,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43366,601,81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43366,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43366,606,3.383,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43367,203,27.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43367,204,9.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43367,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43367,207,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43367,208,200,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43367,255,61.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43367,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43367,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43367,301,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43367,303,2.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43367,306,280,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43367,307,996,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43367,320,0,'100g',1,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (43367,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43367,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43367,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43367,601,85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43367,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43367,606,3.054,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43369,203,0.64,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43369,204,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43369,205,10.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43369,207,0.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43369,208,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43369,255,87.63,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43369,269,8.68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43369,291,0.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43369,301,100,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43369,303,0.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43369,306,79,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43369,307,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43369,320,60,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (43369,328,1.3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43369,401,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43369,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43369,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43369,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43369,606,0.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43378,203,37.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43378,204,41.78,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43378,205,1.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43378,207,7.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43378,208,541,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43378,255,12.32,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43378,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43378,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43378,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43378,303,1.44,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43378,306,565,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43378,307,1030,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43378,320,11,'100g',1,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (43378,328,1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43378,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43378,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43378,601,110,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43378,605,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43378,606,13.739,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43382,203,0.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43382,204,0.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43382,205,12.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43382,207,0.15,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43382,208,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43382,255,87.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43382,269,12.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43382,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43382,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43382,303,0.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43382,306,77,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43382,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43382,320,2,'100g',2,1,'2024-12-12','2007-01-02');
INSERT INTO `cndb_nutval` VALUES (43382,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43382,401,9.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43382,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43382,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43382,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43382,606,0.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43384,203,11.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43384,204,28.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43384,205,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43384,207,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43384,208,310,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43384,255,54.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43384,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43384,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43384,301,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43384,303,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43384,306,155,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43384,307,682,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43384,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43384,328,0.7,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43384,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43384,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43384,601,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43384,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43384,606,11.676,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43387,203,1.36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43387,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43387,205,2.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43387,207,0.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43387,208,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43387,255,94.69,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43387,269,0.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43387,291,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43387,301,118,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43387,303,1.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43387,306,141,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43387,307,29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43387,320,298,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (43387,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43387,401,15.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43387,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43387,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43387,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43387,606,0.07,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43390,203,28.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43390,204,9.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43390,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43390,207,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43390,208,208,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43390,255,61.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43390,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43390,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43390,301,26,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43390,303,1.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43390,306,280,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43390,307,996,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43390,320,0,'100g',1,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (43390,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43390,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43390,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43390,601,82,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43390,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43390,606,2.831,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43391,203,29.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43391,204,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43391,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43391,207,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43391,208,162,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43391,255,64.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43391,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43391,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43391,301,25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43391,303,1.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43391,306,298,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43391,307,996,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43391,320,0,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (43391,328,0.1,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43391,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43391,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43391,601,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43391,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43391,606,1.368,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43392,203,2.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43392,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43392,205,25.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43392,207,1.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43392,208,115,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43392,255,69.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43392,269,17.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43392,291,1.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43392,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43392,303,1.69,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43392,306,1806,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43392,307,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43392,320,3,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (43392,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43392,401,8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43392,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43392,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43392,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43392,606,0.046,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43396,203,10.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43396,204,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43396,205,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43396,207,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43396,208,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43396,255,83.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43396,269,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43396,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43396,301,56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43396,303,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43396,306,86,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43396,307,403,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43396,320,13,'100g',2,1,'2024-12-12','2003-01-01');
INSERT INTO `cndb_nutval` VALUES (43396,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43396,401,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43396,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43396,601,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43396,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43396,606,0.619,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43398,203,22.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43398,204,31.19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43398,205,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43398,207,2.21,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43398,208,376,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43398,255,42.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43398,269,0.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43398,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43398,301,616,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43398,303,0.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43398,306,162,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43398,307,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43398,320,254,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43398,328,0.6,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43398,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43398,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43398,601,94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43398,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43398,606,19.651,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43401,203,1.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43401,204,29.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43401,205,59.94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43401,207,2.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43401,208,509,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43401,255,6.16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43401,269,59,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43401,291,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43401,301,18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43401,303,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43401,306,909,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43401,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43401,320,1,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (43401,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43401,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43401,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43401,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43401,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43401,606,25.128,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43404,203,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43404,204,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43404,205,4.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43404,207,0.12,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43404,208,19,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43404,255,95.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43404,269,4.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43404,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43404,301,10,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43404,303,0.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43404,306,45,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43404,307,5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43404,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (43404,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43404,401,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43404,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43404,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43404,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43404,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43405,203,28.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43405,204,27.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43405,205,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43405,207,3.01,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43405,208,374,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43405,255,37.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43405,269,1.31,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43405,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43405,301,961,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43405,303,0.17,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43405,306,111,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43405,307,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43405,320,216,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43405,328,0.5,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43405,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43405,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43405,601,92,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43405,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43405,606,17.744,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43406,203,23.88,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43406,204,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43406,205,20.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43406,207,13.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43406,208,185,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43406,255,40.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43406,269,1.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43406,291,6.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43406,301,67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43406,303,4.04,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43406,306,2100,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43406,307,3380,'100g',6,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43406,320,0,'100g',1,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (43406,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43406,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43406,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43406,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43406,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43406,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43408,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43408,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43408,205,11.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43408,207,0.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43408,208,43,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43408,255,87.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43408,269,7.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43408,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43408,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43408,303,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43408,306,130,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43408,307,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43408,320,0,'100g',1,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (43408,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43408,401,33.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43408,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43408,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43408,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43408,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43410,203,21.28,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43410,204,12.77,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43410,205,8.51,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43410,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43410,208,234,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43410,255,56.44,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43410,269,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43410,291,4.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43410,301,42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43410,303,3.83,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43410,306,300,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43410,307,400,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43410,320,0,'100g',1,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (43410,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43410,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43410,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43410,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43410,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43410,606,1.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43417,203,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43417,204,2.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43417,205,8.72,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43417,207,0.46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43417,208,69,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43417,255,85.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43417,269,1.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43417,291,1.8,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43417,301,11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43417,303,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43417,306,168,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43417,307,26,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43417,320,57,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (43417,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43417,401,2.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43417,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43417,601,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43417,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43417,606,0.847,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43432,203,4.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43432,204,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43432,205,11.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43432,207,0.43,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43432,208,82,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43432,255,81.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43432,269,0.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43432,291,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43432,301,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43432,303,0.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43432,306,148,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43432,307,35,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43432,320,3,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (43432,328,0,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43432,401,1.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43432,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43432,601,7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43432,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43432,606,0.705,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43441,203,10.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43441,204,2.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43441,205,51.87,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43441,207,2.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43441,208,276,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43441,255,32,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43441,269,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43441,291,5.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43441,301,67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43441,303,2.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43441,306,208,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43441,307,492,'100g',3,1,'2013-12-23','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (43441,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (43441,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43441,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43441,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43441,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43441,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43441,606,0.495,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43447,203,6.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43447,204,33.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43447,205,57.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43447,207,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43447,208,557,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43447,255,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43447,269,1.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43447,291,4.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43447,301,124,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43447,303,1.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43447,306,185,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43447,307,15,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43447,320,4,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43447,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43447,401,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43447,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43447,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43447,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43447,606,4.344,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43449,203,4.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43449,204,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43449,205,20.49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43449,207,1.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43449,208,105,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43449,255,72.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43449,269,7.78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43449,291,5.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43449,301,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43449,303,0.29,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43449,306,296,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43449,307,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43449,320,5,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (43449,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43449,401,3.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43449,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43449,601,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43449,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43449,606,0.103,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43450,203,1.41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43450,204,1.41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43450,205,24.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43450,207,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43450,208,115,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43450,255,72.57,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43450,269,20.61,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43450,291,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43450,301,141,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43450,303,0.28,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43450,306,120,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43450,307,42,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43450,320,19,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (43450,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43450,401,21.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43450,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43450,601,7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43450,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43450,606,0.705,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43476,203,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43476,204,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43476,205,15.96,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43476,207,1.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43476,208,94,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43476,255,77.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43476,269,1.24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43476,291,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43476,301,118,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43476,303,1.06,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43476,306,47,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43476,307,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43476,320,2,'100g',2,1,'2024-12-12','2007-01-04');
INSERT INTO `cndb_nutval` VALUES (43476,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43476,401,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43476,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43476,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43476,605,0,'100g',NULL,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43476,606,0.259,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43483,203,13,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43483,204,3.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43483,205,80,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43483,207,1.56,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43483,208,354,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43483,255,2.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43483,269,0.55,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43483,291,2.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43483,301,8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43483,303,2.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43483,306,40,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43483,307,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43483,320,0,'100g',2,1,'2024-12-12','2007-01-03');
INSERT INTO `cndb_nutval` VALUES (43483,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43483,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43483,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43483,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43483,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43483,606,0.67,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43497,203,5.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43497,204,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43497,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43497,207,25.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43497,208,36,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43497,255,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43497,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43497,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43497,301,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43497,303,2.27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43497,306,3,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43497,307,9690,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43497,320,2,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (43497,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43497,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43497,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43497,601,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43497,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43497,606,0.273,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43506,203,4.4,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43506,204,20.2,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43506,205,30.9,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43506,207,1.19,'100g',NULL,1,'2006-02-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43506,208,323,'100g',3,1,'2006-02-23','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (43506,255,43.1,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43506,269,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43506,291,0.6,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43506,301,252,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43506,303,0.72,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43506,306,238,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43506,307,92,'100g',1,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43506,320,48,'100g',2,1,'2024-12-12','2011-01-03');
INSERT INTO `cndb_nutval` VALUES (43506,328,0.2,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43506,401,0.7,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43506,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43506,601,1,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43506,605,NULL,'100g',NULL,1,'2006-02-23','2012-03-02');
INSERT INTO `cndb_nutval` VALUES (43506,606,12.658,'100g',3,1,'2006-02-23','2007-11-27');
INSERT INTO `cndb_nutval` VALUES (43507,203,12,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43507,204,28.51,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43507,205,1.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43507,207,0.99,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43507,208,312,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43507,255,56.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43507,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43507,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43507,301,20,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43507,303,1.43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43507,306,166,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43507,307,311,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43507,320,0,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43507,328,0.9,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43507,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43507,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43507,601,61,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43507,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43507,606,12.038,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43514,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43514,204,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43514,205,5.92,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43514,207,0.06,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43514,208,24,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43514,255,94.03,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43514,269,1.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43514,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43514,301,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43514,303,0.67,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43514,306,11,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43514,307,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43514,320,0,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (43514,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43514,401,10.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43514,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43514,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43514,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43514,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43523,203,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43523,204,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43523,205,16.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43523,207,0.37,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43523,208,75,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43523,255,81.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43523,269,11.74,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43523,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43523,301,28,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43523,303,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43523,306,62,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43523,307,16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43523,320,5,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43523,328,0,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43523,401,11.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43523,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43523,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43523,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43523,606,0.517,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43529,203,6.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43529,204,2.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43529,205,86.89,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43529,207,0.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43529,208,396,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43529,255,3.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43529,269,3.22,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43529,291,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43529,301,850,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43529,303,37,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43529,306,410,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43529,307,16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43529,320,0,'100g',2,1,'2024-12-12','2007-01-05');
INSERT INTO `cndb_nutval` VALUES (43529,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43529,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43529,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43529,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43529,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43529,606,0.503,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43535,203,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43535,204,0.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43535,205,11.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43535,207,0.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43535,208,47,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43535,255,88.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43535,269,10.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43535,291,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43535,301,7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43535,303,0.35,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43535,306,110,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43535,307,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43535,320,1,'100g',2,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (43535,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43535,401,32.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43535,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43535,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43535,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43535,606,0.02,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43536,203,0.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43536,204,0.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43536,205,17.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43536,207,0.45,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43536,208,77,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43536,255,80.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43536,269,11.11,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43536,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43536,301,27,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43536,303,0.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43536,306,102,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43536,307,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43536,320,1,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43536,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43536,401,11.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43536,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43536,601,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43536,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43536,606,0.117,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43537,203,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43537,204,0.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43537,205,17.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43537,207,0.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43537,208,77,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43537,255,81.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43537,269,13.62,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43537,291,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43537,301,25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43537,303,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43537,306,62,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43537,307,14,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43537,320,3,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43537,328,0,'100g',1,1,'2017-05-02','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43537,401,12.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43537,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43537,601,4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43537,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43537,606,0.452,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43539,203,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43539,204,0.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43539,205,17.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43539,207,0.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43539,208,78,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43539,255,80.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43539,269,12.2,'100g',6,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43539,291,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43539,301,30,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43539,303,0.14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43539,306,100,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43539,307,14,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43539,320,3,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43539,328,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43539,401,13.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43539,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43539,601,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43539,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43539,606,0.37,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43541,203,4.72,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43541,204,16.98,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43541,205,19.78,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43541,207,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43541,208,251,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43541,255,57.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43541,269,17.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43541,291,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43541,301,142,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43541,303,1.02,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43541,306,238,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43541,307,57,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43541,320,201,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (43541,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43541,401,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43541,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43541,601,60,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43541,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43541,606,10.377,'100g',6,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43543,203,1.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43543,204,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43543,205,5.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43543,207,1.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43543,208,46,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43543,255,90,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43543,269,5.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43543,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43543,301,82,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43543,303,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43543,306,150,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43543,307,55,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43543,320,61,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43543,328,1.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43543,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43543,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43543,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43543,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43543,606,0.254,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43544,203,6.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43544,204,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43544,205,88.5,'100g',3,1,'2013-12-23','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (43544,207,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43544,208,389,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43544,255,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43544,269,1.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43544,291,2.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43544,301,38,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43544,303,9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43544,306,414,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43544,307,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43544,320,0,'100g',2,1,'2024-12-12','2013-01-05');
INSERT INTO `cndb_nutval` VALUES (43544,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43544,401,250,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43544,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43544,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43544,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43544,606,0.185,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43546,203,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43546,204,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43546,205,21.34,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43546,207,0.76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43546,208,91,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43546,255,76.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43546,269,11.36,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43546,291,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43546,301,4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43546,303,0.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43546,306,290,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43546,307,2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43546,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43546,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43546,401,21.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43546,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43546,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43546,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43546,606,0.072,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43550,203,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43550,204,0.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43550,205,16.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43550,207,0.29,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43550,208,68,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43550,255,83.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43550,269,14.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43550,291,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43550,301,3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43550,303,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43550,306,71,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43550,307,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43550,320,2,'100g',2,1,'2024-12-12','2003-01-04');
INSERT INTO `cndb_nutval` VALUES (43550,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43550,401,12.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43550,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43550,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43550,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43550,606,0.058,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (43566,203,8.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43566,204,15.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43566,205,73.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43566,207,1.85,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43566,208,465,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43566,255,1.3,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43566,269,0.53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43566,291,5.7,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43566,301,159,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43566,303,1.63,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43566,306,272,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43566,307,400,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43566,320,4,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43566,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43566,401,0.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43566,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43566,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43566,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43566,606,2.837,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43572,203,12.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43572,204,9.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43572,205,73.39,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43572,207,1.71,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43572,208,429,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43572,255,2.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43572,269,0.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43572,291,14.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43572,301,11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43572,303,2.28,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43572,306,241,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43572,307,490,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43572,320,7,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43572,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43572,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43572,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43572,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43572,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43572,606,1.415,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43585,203,0.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43585,204,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43585,205,17.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43585,207,0.52,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43585,208,73,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43585,255,81.6,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43585,269,14.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43585,291,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43585,301,6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43585,303,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43585,306,129,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43585,307,1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43585,320,3,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (43585,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43585,401,12.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43585,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43585,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43585,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43585,606,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43589,203,28.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43589,204,5.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43589,205,3.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43589,207,3.5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43589,208,179,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43589,255,59.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43589,269,1.33,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43589,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43589,301,961,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43589,303,0.17,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43589,306,111,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43589,307,199,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43589,320,40,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43589,328,0.1,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43589,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43589,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43589,601,35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43589,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43589,606,3.304,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43595,203,4.4,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43595,204,7.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43595,205,72.8,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43595,207,0.8,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43595,208,376,'100g',3,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43595,255,14.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43595,269,35.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43595,291,2.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43595,301,41,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43595,303,4.86,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43595,306,197,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43595,307,337,'100g',6,1,'2013-12-23','2019-02-13');
INSERT INTO `cndb_nutval` VALUES (43595,320,608,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (43595,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43595,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43595,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (43595,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43595,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43595,606,1.5,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43597,203,27.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43597,204,17.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43597,205,3.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43597,207,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43597,208,280,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43597,255,49.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43597,269,1.23,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43597,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43597,301,731,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43597,303,0.25,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43597,306,95,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43597,307,16,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43597,320,137,'100g',2,1,'2024-12-12','2009-01-02');
INSERT INTO `cndb_nutval` VALUES (43597,328,0.3,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43597,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43597,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43597,601,54,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43597,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43597,606,10.867,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (43598,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43598,204,77.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43598,205,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43598,207,0.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43598,208,688,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43598,255,21.7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43598,269,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43598,291,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43598,301,7,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43598,303,0.23,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43598,306,14,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43598,307,486,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43598,320,0,'100g',1,1,'2024-12-12','2005-01-03');
INSERT INTO `cndb_nutval` VALUES (43598,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (43598,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43598,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (43598,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43598,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (43598,606,10.784,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (44005,203,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44005,204,100,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44005,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44005,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44005,208,884,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44005,255,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44005,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44005,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44005,301,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44005,303,0.13,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44005,306,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44005,307,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44005,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (44005,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44005,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44005,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (44005,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44005,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44005,606,14.367,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (44018,203,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44018,204,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44018,205,76.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44018,207,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44018,208,279,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44018,255,23.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44018,269,76,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44018,291,0.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44018,301,1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44018,303,0.11,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44018,306,0,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44018,307,2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44018,320,0,'100g',2,1,'2024-12-12','2004-01-09');
INSERT INTO `cndb_nutval` VALUES (44018,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44018,401,0,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44018,539,76,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (44018,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44018,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44018,606,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44061,203,5.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44061,204,2.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44061,205,78.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44061,207,9.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44061,208,356,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44061,255,4.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44061,269,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44061,291,6.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44061,301,126,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44061,303,3.11,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44061,306,1279,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44061,307,2838,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44061,320,0,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (44061,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44061,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44061,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (44061,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44061,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44061,606,0.984,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (44074,203,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (44074,204,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (44074,205,15.38,'100g',3,1,'2015-01-06','2015-01-06');
INSERT INTO `cndb_nutval` VALUES (44074,207,0.22,'100g',NULL,1,'2013-02-22','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (44074,208,62,'100g',3,1,'2013-02-22','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (44074,255,84.4,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (44074,269,15.3,'100g',NULL,1,'2013-02-22','2016-03-09');
INSERT INTO `cndb_nutval` VALUES (44074,291,0,'100g',3,1,'2013-02-22','2016-02-06');
INSERT INTO `cndb_nutval` VALUES (44074,301,12,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (44074,303,0.3,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (44074,306,90,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44074,307,10,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (44074,320,4,'100g',2,1,'2024-12-12','2015-01-02');
INSERT INTO `cndb_nutval` VALUES (44074,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44074,401,33.8,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (44074,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (44074,601,0,'100g',4,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (44074,605,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (44074,606,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (44110,203,0.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44110,204,0.03,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44110,205,46.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44110,207,0.08,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44110,208,179,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44110,255,53,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44110,269,45.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44110,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44110,301,5,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44110,303,0.18,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44110,306,71,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44110,307,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44110,320,0,'100g',2,1,'2024-12-12','2003-01-02');
INSERT INTO `cndb_nutval` VALUES (44110,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44110,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44110,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (44110,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44110,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44110,606,0.009,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44158,203,0.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44158,204,0.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44158,205,44.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44158,207,0.35,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44158,208,181,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44158,255,54.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44158,269,37.75,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44158,291,2.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44158,301,27,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44158,303,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44158,306,115,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44158,307,12,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44158,320,1,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (44158,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44158,401,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44158,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (44158,601,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44158,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44158,606,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44258,203,10.08,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44258,204,3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44258,205,74.42,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44258,207,5.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44258,208,365,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44258,255,6.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44258,269,0.7,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44258,291,10.1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44258,301,50,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44258,303,3.87,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44258,306,570,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44258,307,3326,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44258,320,0,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (44258,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44258,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44258,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (44258,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44258,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44258,606,1.578,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (44259,203,1.6,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44259,204,0.1,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44259,205,86.04,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44259,207,1.86,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44259,208,351,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44259,255,10.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44259,269,2.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44259,291,0.9,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44259,301,49,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44259,303,0.05,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44259,306,18,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44259,307,1765,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44259,320,0,'100g',2,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (44259,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44259,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44259,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (44259,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44259,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44259,606,0.018,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (44260,203,0.81,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44260,204,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44260,205,84.66,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44260,207,6.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44260,208,350,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44260,255,6.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44260,269,0.9,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44260,291,0.8,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44260,301,143,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44260,303,0.38,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44260,306,30,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44260,307,3750,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44260,320,0,'100g',2,1,'2024-12-12','2005-01-04');
INSERT INTO `cndb_nutval` VALUES (44260,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (44260,401,0,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44260,539,NULL,'100g',NULL,1,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (44260,601,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44260,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (44260,606,0.099,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (48052,203,75.16,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (48052,204,1.85,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (48052,205,13.79,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (48052,207,1,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (48052,208,370,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (48052,255,8.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (48052,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (48052,291,0.6,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (48052,301,142,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (48052,303,5.2,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (48052,306,100,'100g',6,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (48052,307,29,'100g',6,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (48052,320,0,'100g',3,1,'2024-12-12','2003-01-03');
INSERT INTO `cndb_nutval` VALUES (48052,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (48052,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (48052,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (48052,601,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (48052,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (48052,606,0.272,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (51385,203,11.07,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51385,204,3.27,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51385,205,26.39,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51385,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51385,208,177.76,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51385,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51385,269,2.85,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51385,291,3.28,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51385,301,136.91,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51385,303,1.38,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51385,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51385,307,248.03,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51385,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51385,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51385,401,10.23,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51385,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51385,601,15.37,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51385,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51385,606,1.28,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51386,203,3.74,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51386,204,3.25,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51386,205,16.36,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51386,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51386,208,109.53,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51386,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51386,269,3.65,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51386,291,1.52,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51386,301,20.68,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51386,303,0.64,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51386,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51386,307,109.75,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51386,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51386,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51386,401,8.02,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51386,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51386,601,6.59,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51386,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51386,606,0.68,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51387,203,4.7,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51387,204,5.75,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51387,205,39.31,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51387,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51387,208,218.58,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51387,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51387,269,16.62,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51387,291,4.08,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51387,301,32.55,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51387,303,1.73,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51387,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51387,307,42.89,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51387,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51387,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51387,401,11.17,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51387,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51387,601,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51387,605,0.01,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51387,606,0.67,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51388,203,12.15,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51388,204,3.34,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51388,205,16.71,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51388,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51388,208,141.07,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51388,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51388,269,1.86,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51388,291,1.09,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51388,301,71.15,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51388,303,0.96,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51388,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51388,307,233.75,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51388,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51388,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51388,401,0.16,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51388,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51388,601,28.09,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51388,605,0.01,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51388,606,1.47,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51389,203,6.63,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51389,204,2.99,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51389,205,12.22,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51389,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51389,208,101.96,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51389,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51389,269,1.48,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51389,291,1.3,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51389,301,30.07,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51389,303,0.66,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51389,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51389,307,260.9,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51389,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51389,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51389,401,1.18,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51389,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51389,601,23.46,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51389,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51389,606,0.62,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51390,203,3.14,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51390,204,1.12,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51390,205,4.13,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51390,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51390,208,37.36,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51390,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51390,269,0.77,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51390,291,1.01,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51390,301,13.82,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51390,303,0.5,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51390,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51390,307,193.61,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51390,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51390,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51390,401,1.68,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51390,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51390,601,6.96,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51390,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51390,606,0.16,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51391,203,12.29,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51391,204,3.3,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51391,205,21.45,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51391,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51391,208,159.08,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51391,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51391,269,6.61,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51391,291,2.82,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51391,301,42.87,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51391,303,2.27,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51391,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51391,307,211.1,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51391,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51391,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51391,401,14.14,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51391,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51391,601,27.51,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51391,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51391,606,0.84,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51392,203,4.3,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51392,204,2.76,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51392,205,15.62,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51392,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51392,208,99.88,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51392,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51392,269,2.38,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51392,291,2.9,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51392,301,83.69,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51392,303,0.86,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51392,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51392,307,140.5,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51392,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51392,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51392,401,9.88,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51392,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51392,601,3.32,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51392,605,0.01,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51392,606,1.05,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51393,203,3.21,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51393,204,1.51,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51393,205,19.21,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51393,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51393,208,97.08,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51393,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51393,269,3.69,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51393,291,3.45,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51393,301,44.27,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51393,303,0.87,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51393,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51393,307,156.53,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51393,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51393,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51393,401,5.75,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51393,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51393,601,0.37,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51393,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51393,606,0.19,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51394,203,5.72,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51394,204,4.23,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51394,205,22.47,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51394,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51394,208,146.39,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51394,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51394,269,1.77,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51394,291,4.3,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51394,301,51.42,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51394,303,1.71,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51394,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51394,307,288.8,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51394,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51394,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51394,401,9.99,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51394,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51394,601,1.59,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51394,605,0.05,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51394,606,0.53,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51395,203,1.01,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51395,204,2.64,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51395,205,13.59,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51395,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51395,208,77.87,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51395,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51395,269,6.84,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51395,291,2.63,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51395,301,31.83,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51395,303,1.31,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51395,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51395,307,86.3,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51395,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51395,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51395,401,9.2,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51395,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51395,601,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51395,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51395,606,0.36,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51396,203,3.96,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51396,204,1.12,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51396,205,9.07,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51396,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51396,208,61.65,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51396,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51396,269,1.36,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51396,291,2.51,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51396,301,25.03,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51396,303,0.94,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51396,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51396,307,28.59,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51396,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51396,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51396,401,4.4,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51396,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51396,601,6.55,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51396,605,0.01,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51396,606,0.13,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51397,203,4.25,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51397,204,0.86,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51397,205,10.22,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51397,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51397,208,64,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51397,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51397,269,1.31,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51397,291,3.88,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51397,301,14.18,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51397,303,1.72,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51397,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51397,307,132.21,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51397,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51397,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51397,401,2.61,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51397,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51397,601,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51397,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51397,606,0.1,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51398,203,4.53,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51398,204,3.82,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51398,205,15.4,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51398,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51398,208,112.73,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51398,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51398,269,1.77,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51398,291,1.81,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51398,301,28.75,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51398,303,1.26,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51398,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51398,307,189,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51398,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51398,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51398,401,8.41,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51398,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51398,601,2.06,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51398,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51398,606,0.82,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51399,203,2.95,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51399,204,1.36,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51399,205,14.77,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51399,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51399,208,79.79,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51399,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51399,269,0.97,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51399,291,1.81,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51399,301,16.95,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51399,303,1.83,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51399,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51399,307,109.89,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51399,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51399,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51399,401,5.03,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51399,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51399,601,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51399,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51399,606,0.19,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51400,203,7.23,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51400,204,4.36,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51400,205,32.4,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51400,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51400,208,197.89,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51400,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51400,269,3.73,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51400,291,3.87,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51400,301,39.07,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51400,303,2.62,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51400,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51400,307,105.43,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51400,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51400,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51400,401,10.8,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51400,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51400,601,0.32,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51400,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51400,606,0.56,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51401,203,13.17,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51401,204,7.46,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51401,205,20.57,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51401,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51401,208,199.02,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51401,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51401,269,5.89,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51401,291,2.53,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51401,301,52.2,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51401,303,1.66,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51401,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51401,307,294.55,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51401,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51401,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51401,401,1.26,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51401,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51401,601,68.72,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51401,605,0.06,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51401,606,1.79,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51402,203,4.01,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51402,204,5.01,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51402,205,19.94,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51402,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51402,208,144.31,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51402,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51402,269,1.5,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51402,291,4.4,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51402,301,28.38,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51402,303,1.3,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51402,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51402,307,223.13,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51402,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51402,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51402,401,12.39,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51402,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51402,601,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51402,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51402,606,0.4,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51403,203,13.12,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51403,204,2.45,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51403,205,16.63,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51403,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51403,208,137.13,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51403,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51403,269,1.05,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51403,291,2.66,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51403,301,16.83,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51403,303,2.04,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51403,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51403,307,94.11,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51403,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51403,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51403,401,22.09,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51403,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51403,601,32.72,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51403,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51403,606,0.6,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51404,203,9.67,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51404,204,3.39,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51404,205,12.3,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51404,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51404,208,114.58,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51404,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51404,269,1.69,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51404,291,1.93,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51404,301,23.29,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51404,303,0.86,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51404,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51404,307,181.29,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51404,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51404,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51404,401,15.71,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51404,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51404,601,16.91,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51404,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51404,606,0.5,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51405,203,2.58,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51405,204,0.57,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51405,205,12.97,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51405,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51405,208,63.52,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51405,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51405,269,2.93,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51405,291,2.63,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51405,301,21.73,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51405,303,1.03,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51405,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51405,307,88.55,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51405,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51405,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51405,401,13.43,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51405,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51405,601,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51405,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51405,606,0.06,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51406,203,3.08,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51406,204,3.12,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51406,205,14.98,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51406,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51406,208,95.21,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51406,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51406,269,6.33,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51406,291,2.22,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51406,301,36.88,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51406,303,0.88,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51406,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51406,307,61.65,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51406,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51406,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51406,401,2.58,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51406,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51406,601,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51406,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51406,606,0.43,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51407,203,4.12,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51407,204,2.02,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51407,205,15.77,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51407,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51407,208,95.24,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51407,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51407,269,2.1,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51407,291,2.68,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51407,301,81,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51407,303,0.62,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51407,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51407,307,45.2,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51407,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51407,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51407,401,9.88,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51407,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51407,601,4.15,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51407,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51407,606,0.86,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51408,203,4.46,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51408,204,3.61,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51408,205,17.8,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51408,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51408,208,121.37,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51408,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51408,269,0.49,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51408,291,1.65,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51408,301,27.21,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51408,303,0.68,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51408,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51408,307,159.14,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51408,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51408,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51408,401,0.42,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51408,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51408,601,37.51,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51408,605,0.09,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51408,606,0.69,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51409,203,4.72,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51409,204,2.42,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51409,205,14.24,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51409,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51409,208,95.9,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51409,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51409,269,1.36,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51409,291,1.71,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51409,301,14.03,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51409,303,0.57,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51409,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51409,307,138.99,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51409,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51409,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51409,401,10.69,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51409,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51409,601,15.08,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51409,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51409,606,0.41,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51410,203,2.84,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51410,204,1.22,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51410,205,11.93,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51410,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51410,208,61.03,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51410,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51410,269,2.19,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51410,291,3.36,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51410,301,28.27,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51410,303,1.08,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51410,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51410,307,158.7,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51410,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51410,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51410,401,7.06,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51410,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51410,601,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51410,605,0.03,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51410,606,0.09,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51411,203,3.22,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51411,204,3.31,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51411,205,21.29,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51411,207,NULL,'100g',NULL,2,'2013-04-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51411,208,125.22,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51411,255,NULL,'100g',NULL,2,'2013-04-30','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51411,269,3.56,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51411,291,3.73,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51411,301,37.09,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51411,303,1.02,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51411,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51411,307,256.23,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51411,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51411,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51411,401,12.51,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51411,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51411,601,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51411,605,0.07,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51411,606,0.28,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51412,203,5.34,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51412,204,1.04,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51412,205,5.02,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51412,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51412,208,49.56,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51412,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51412,269,0.69,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51412,291,1.35,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51412,301,22.7,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51412,303,0.84,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51412,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51412,307,193.28,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51412,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51412,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51412,401,2.58,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51412,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51412,601,7.62,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51412,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51412,606,0.25,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51413,203,4.51,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51413,204,2.61,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51413,205,12.86,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51413,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51413,208,87.54,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51413,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51413,269,1.92,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51413,291,3.13,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51413,301,73.18,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51413,303,1.07,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51413,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51413,307,98.97,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51413,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51413,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51413,401,8.77,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51413,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51413,601,2.66,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51413,605,0.01,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51413,606,0.72,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51414,203,1.66,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51414,204,1.57,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51414,205,16.56,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51414,207,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51414,208,79.62,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51414,255,NULL,'100g',NULL,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51414,269,16.62,'100g',2,2,'2014-01-17','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (51414,291,2.98,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51414,301,35.94,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51414,303,0.83,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51414,306,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51414,307,93.63,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51414,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51414,328,NULL,'100g',NULL,2,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (51414,401,15.17,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51414,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51414,601,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51414,605,0,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51414,606,0.26,'100g',2,2,'2013-04-30','2013-04-30');
INSERT INTO `cndb_nutval` VALUES (51566,203,2.212,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,204,0.807,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,205,16.779,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,208,70.482,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,255,52.389,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,269,0.271,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,291,1.614,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,301,16.762,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,303,1.382,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,306,41.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,307,75.126,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51566,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,401,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51566,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51566,606,0.056,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,203,8.395,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,204,3.82,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,205,37.4,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,208,210.305,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,255,48.351,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,269,2.83,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,291,4.85,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,301,97.032,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,303,0.605,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,306,269.7,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,307,275.57,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51567,328,0.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,401,0.412,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51567,601,12.888,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,605,0.096,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51567,606,1.91,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,203,5.439,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,204,7.471,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,205,44.954,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,208,252.407,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,255,40.424,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,269,21.006,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,291,3.655,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,301,37.518,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,303,0.553,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,306,231.4,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,307,241.583,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51568,328,0.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,401,2.372,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51568,601,26.534,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51568,606,1.837,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,203,6.497,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,204,6.848,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,205,39.618,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,208,235.711,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,255,44.952,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,269,9.46,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,291,3.446,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,301,86.896,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,303,1.075,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,306,199.7,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,307,379.456,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51570,328,0.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,401,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51570,601,30.509,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,605,0.022,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51570,606,0.746,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,203,4.263,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,204,3.388,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,205,12.064,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,208,86.612,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,255,73.156,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,269,1.249,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,291,1.414,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,301,20.082,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,303,1.182,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,306,70.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,307,141.728,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51571,328,0.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,401,1.526,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51571,601,41.017,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,605,0.007,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51571,606,0.539,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,203,9.229,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,204,2.547,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,205,46.06,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,208,239.891,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,255,40.455,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,269,3.538,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,291,4.239,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,301,43.189,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,303,1.709,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,306,220.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,307,300.752,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51572,328,0.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,401,12.784,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51572,601,0.581,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51572,606,0.461,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51573,203,6.003,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,204,11.603,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,205,39.553,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,207,1.258,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,208,279.882,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,255,40.802,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,269,16.51,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,291,2.98,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,301,60.677,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,303,1.335,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,306,NULL,'100g',NULL,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,307,249.528,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,328,NULL,'100g',NULL,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,401,1.225,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,539,NULL,'100g',NULL,2,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,601,41.882,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,605,0.04,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51573,606,1.117,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51574,203,6.666,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,204,7.726,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,205,26.073,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,208,194.513,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,255,57.549,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,269,3.417,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,291,3.08,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,301,80.643,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,303,0.623,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,306,174.5,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,307,333.563,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51574,328,0.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,401,0.168,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51574,601,53.728,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,605,0.034,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51574,606,0.909,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,203,7.824,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,204,3.04,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,205,43.633,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,208,229.64,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,255,43.921,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,269,0.845,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,291,4.335,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,301,6.709,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,303,1.313,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,306,153.4,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,307,131.025,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51575,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,401,0.072,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51575,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,605,0.054,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51575,606,0.216,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,203,7.159,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,204,1.311,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,205,33.128,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,208,168.744,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,255,57.258,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,269,7.048,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,291,2.478,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,301,83.304,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,303,1.068,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,306,209,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,307,106.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51576,328,0.7,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,401,0.474,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51576,601,1.244,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51576,606,0.132,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,203,1.741,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,204,1.07,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,205,13.597,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,208,69.715,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,255,80.895,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,269,1.555,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,291,1.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,301,13.093,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,303,0.485,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,306,122.5,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,307,83.593,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51577,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,401,9.018,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51577,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51577,606,0.127,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51578,203,5.995,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,204,7.784,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,205,37.723,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,207,1.073,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,208,245.689,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,255,35.961,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,269,10.276,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,291,3.866,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,301,51.972,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,303,1.301,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,306,NULL,'100g',NULL,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,307,199.846,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,328,NULL,'100g',NULL,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,401,2.547,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,539,NULL,'100g',NULL,2,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,601,40.216,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,605,0.024,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51578,606,1.049,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51579,203,2.195,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,204,1.138,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,205,16.349,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,208,83.794,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,255,72.601,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,269,3.027,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,291,1.899,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,301,10.954,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,303,0.709,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,306,165.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,307,89.542,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51579,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,401,7.835,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51579,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51579,606,0.143,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,203,2.286,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,204,0.861,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,205,15.248,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,208,77.525,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,255,79.853,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,269,2.986,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,291,1.426,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,301,22.574,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,303,0.508,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,306,68.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,307,96.713,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51580,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,401,4.36,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51580,601,1.177,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51580,606,0.332,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,203,4.881,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,204,7.745,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,205,50.648,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,208,279.917,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,255,33.765,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,269,28.116,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,291,2.512,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,301,20.755,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,303,0.928,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,306,154.9,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,307,180.429,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51581,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,401,3.377,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51581,601,10.13,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,605,0.032,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51581,606,0.64,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,203,1.867,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,204,1.761,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,205,14.631,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,208,81.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,255,52.69,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,269,1.496,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,291,1.607,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,301,9.353,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,303,0.361,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,306,76.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,307,101.146,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51582,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,401,7.576,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51582,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,605,0.005,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51582,606,0.191,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,203,3.885,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,204,3.73,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,205,18.895,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,208,121.667,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,255,29.829,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,269,1.97,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,291,1.879,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,301,22.889,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,303,0.757,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,306,117.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,307,182.674,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51583,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,401,0.894,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51583,601,0.219,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51583,606,0.775,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,203,3.795,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,204,4.577,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,205,17.678,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,208,121.296,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,255,72.882,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,269,4.071,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,291,1.778,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,301,45.791,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,303,0.56,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,306,159.4,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,307,169.141,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51584,328,0.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,401,3.609,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51584,601,10.017,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,605,0.009,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51584,606,0.747,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,203,4.526,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,204,5.839,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,205,48.239,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,208,257.09,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,255,39.435,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,269,29.286,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,291,1.869,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,301,69.076,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,303,2.07,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,306,478.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,307,215.879,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51585,328,0.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,401,0.587,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51585,601,37.241,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,605,0.309,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51585,606,1.128,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,203,9.872,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,204,5.834,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,205,17.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,208,159.766,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,255,50.02,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,269,3.252,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,291,2.788,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,301,117.008,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,303,2.249,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,306,218.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,307,237.515,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51587,328,0,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51587,401,14.289,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51587,601,20.524,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,605,0.109,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51587,606,2.352,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,203,9.169,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,204,4.187,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,205,25.17,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,208,167.663,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,255,20.548,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,269,4.019,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,291,4.027,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,301,87.909,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,303,3.291,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,306,301.4,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,307,300.971,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51588,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,401,9.797,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51588,601,13.246,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51588,606,1.926,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,203,9.447,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,204,2.895,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,205,21.011,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,208,148.59,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,269,1.691,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,291,1.952,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,301,86.9,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,303,1.806,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,306,142,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,307,255.82,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51589,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,401,0.748,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51589,601,13.089,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51589,606,0.978,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,203,5.675,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,204,4.666,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,205,18.522,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,208,128.633,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,255,57.38,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,269,1.538,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,291,3.797,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,301,123.46,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,303,1.151,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,306,183.4,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,307,228.638,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51590,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,401,7.919,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51590,601,4.321,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51590,606,1.433,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,203,6.522,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,204,1.679,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,205,10.688,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,208,104.75,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,255,35.944,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,269,0.86,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,291,1.426,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,301,22.799,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,303,0.182,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,306,25.7,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,307,166.513,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51591,328,0,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51591,401,1.102,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51591,601,13.603,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51591,606,0.934,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,203,8.305,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,204,5.171,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,205,14.605,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,208,136.353,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,255,48.541,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,269,4.362,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,291,2.027,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,301,40.373,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,303,1.845,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,306,294,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,307,214.39,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51593,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,401,12.232,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51593,601,26.749,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,605,0.127,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51593,606,1.47,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,203,6.537,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,204,3.634,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,205,14.968,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,208,116.707,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,255,51.285,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,269,3.573,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,291,2.764,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,301,94.822,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,303,1.419,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,306,245.4,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,307,167.97,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51594,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,401,11.987,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51594,601,15.47,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,605,0.048,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51594,606,1.263,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,203,8.303,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,204,3.949,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,205,12.764,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,208,120.137,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,255,45.138,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,269,3.327,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,291,1.623,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,301,86.205,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,303,0.642,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,306,100.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,307,213.047,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51595,328,0.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,401,2.463,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51595,601,24.051,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,605,0.005,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51595,606,1.234,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,203,6.875,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,204,2.212,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,205,6.447,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,208,74.581,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,255,67.935,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,269,1.868,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,291,1.604,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,301,26.122,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,303,0.512,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,306,71.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,307,119.751,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51596,328,0.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,401,3.938,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51596,601,14.724,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51596,606,0.588,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,203,5.931,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,204,1.659,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,205,5.616,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,208,61.794,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,255,66.863,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,269,0.865,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,291,0.848,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,301,18.725,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,303,0.253,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,306,43.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,307,87.676,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51597,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,401,0.615,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51597,601,12.993,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51597,606,0.443,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,203,6.372,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,204,1.588,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,205,4.23,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,208,59.427,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,255,67.047,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,269,1.02,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,291,0.452,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,301,9.995,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,303,0.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,306,59.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,307,120.213,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51598,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,401,2.03,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51598,601,16.935,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51598,606,0.474,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,203,8.188,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,204,4.476,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,205,12.037,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,208,120.814,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,255,56.53,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,269,2.247,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,291,1.632,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,301,42.143,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,303,0.189,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,306,113.7,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,307,176.059,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51599,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,401,1.787,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51599,601,17.755,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,605,0.013,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51599,606,0.992,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,203,7.573,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,204,1.416,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,205,4.55,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,208,62.198,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,255,39.508,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,269,1.039,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,291,1.753,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,301,22.133,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,303,0.929,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,306,125.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,307,170.63,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51600,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,401,2.217,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51600,601,15.489,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,605,0.029,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51600,606,0.319,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,203,5.145,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,204,2.541,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,205,13.435,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,208,87.429,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,269,0.9,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,291,1.562,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,301,20.191,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,303,1.469,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,306,139.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,307,164.225,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51601,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,401,6.279,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51601,601,8.741,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,605,0.044,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51601,606,0.463,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,203,8.567,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,204,2.376,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,205,7.85,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,208,86.884,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,269,3.317,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,291,0.684,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,301,53.263,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,303,0.482,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,306,179,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,307,166.668,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51602,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,401,19.351,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51602,601,19.542,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,605,0.071,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51602,606,0.952,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,203,8.532,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,204,2.502,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,205,15.563,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,208,120.649,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,269,2.381,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,291,0.898,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,301,129.91,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,303,0.643,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,306,103.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,307,239.108,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51603,328,0.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,401,3.122,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51603,601,7.692,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,605,0.023,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51603,606,1.384,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,203,11.07,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,204,2.724,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,205,15.162,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,208,129.137,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,269,3.43,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,291,1.874,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,301,22.028,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,303,1.025,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,306,61.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,307,280.284,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51604,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,401,0.818,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51604,601,34.254,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,605,0.006,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51604,606,0.375,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,203,7.576,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,204,3.015,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,205,15.782,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,208,120.73,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,269,2.363,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,291,2.026,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,301,32.194,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,303,1.445,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,306,97.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,307,193.332,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51605,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,401,13.153,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51605,601,12.311,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,605,0.062,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51605,606,0.798,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,203,12.566,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,204,7.107,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,205,20.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,208,199.445,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,269,0.049,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,291,2.921,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,301,51.954,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,303,0.832,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,306,158.9,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,307,289.343,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51606,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,401,0.082,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51606,601,25.785,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51606,606,2.268,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,203,12.293,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,204,6.805,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,205,23.333,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,208,197.505,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,255,45.669,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,269,4.193,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,291,3.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,301,679.246,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,303,12.473,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,306,222.4,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,307,389.682,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51607,328,1.9,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,401,39.267,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51607,601,30.18,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,605,0.053,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51607,606,1.868,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,203,5.35,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,204,2.392,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,205,15.742,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,208,103.32,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,255,70.172,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,269,3.248,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,291,1.852,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,301,76.165,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,303,0.817,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,306,171,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,307,164.72,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51608,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,401,6.943,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51608,601,4.917,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,605,0.004,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51608,606,1.04,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,203,7.792,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,204,3.622,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,205,19.06,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,208,136.977,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,255,61.523,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,269,3.178,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,291,2.404,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,301,84.801,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,303,1.088,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,306,207.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,307,187.524,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51609,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,401,1.007,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51609,601,11.588,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,605,0.022,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51609,606,1.332,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,203,8.413,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,204,4.823,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,205,21.788,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,208,160.693,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,255,59.116,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,269,3.306,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,291,2.699,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,301,93.725,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,303,1.188,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,306,264.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,307,211.448,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51610,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,401,17.657,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51610,601,12.425,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,605,0.007,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51610,606,1.841,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,203,8.109,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,204,1.827,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,205,7.589,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,208,79.041,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,269,2.614,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,291,0.787,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,301,104.071,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,303,0.465,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,306,139.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,307,252.32,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51611,328,0.7,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,401,10.818,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51611,601,40.447,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,605,0.007,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51611,606,0.787,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,203,11.92,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,204,3.638,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,205,8.51,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,208,114.275,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,269,1.364,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,291,1.169,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,301,28.884,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,303,1.007,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,306,126,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,307,262.209,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51612,328,0.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,401,0.536,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51612,601,22.615,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,605,0.065,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51612,606,0.942,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,203,8.366,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,204,3.679,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,205,9.728,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,207,NULL,'100g',NULL,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51613,208,106.351,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,255,75.594,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,269,1.382,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,291,1.955,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,301,17.68,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,303,1.422,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,306,202.29,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,307,120.376,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51613,328,0,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,401,3.018,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51613,601,20.248,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,605,0.127,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51613,606,1.35,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,203,9.201,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,204,4.491,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,205,11.869,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,207,NULL,'100g',NULL,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51614,208,122.102,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,255,73.196,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,269,1.558,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,291,2.205,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,301,18.416,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,303,1.491,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,306,221.626,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,307,134.55,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51614,328,0,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,401,3.61,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51614,601,24.752,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,605,0.094,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51614,606,1.527,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51615,203,5.209,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,204,3.133,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,205,9.322,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,208,85.793,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,255,66.974,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,269,6.88,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,291,0.507,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,301,9.42,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,303,0.371,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,306,124.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,307,172.438,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51615,328,0.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,401,10.976,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51615,601,14.288,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51615,606,0.955,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,203,8.43,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,204,1.32,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,205,8.11,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,207,NULL,'100g',NULL,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51616,208,76.28,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,255,49.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,269,1.82,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,291,1.22,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,301,28.14,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,303,0.12,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,306,363.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,307,97.26,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51616,328,2.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,401,3.51,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51616,601,5.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51616,606,0.26,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,203,7.865,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,204,3.844,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,205,13.528,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,208,112.661,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,269,3.009,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,291,1.314,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,301,33.85,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,303,0.749,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,306,117.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,307,276.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51617,328,0.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,401,2.668,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51617,601,21.202,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,605,0.007,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51617,606,0.552,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,203,4.367,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,204,2.629,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,205,10.709,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,208,80.631,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,255,67.738,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,269,6.489,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,291,1.731,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,301,22.103,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,303,0.556,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,306,173.5,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,307,105.248,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51618,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,401,17.009,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51618,601,6.23,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,605,0.003,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51618,606,0.273,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,203,5.608,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,204,2.831,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,205,12.278,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,208,92.947,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,255,59.148,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,269,6.971,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,291,1.878,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,301,23.193,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,303,0.948,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,306,197.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,307,158.66,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51619,328,0,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51619,401,15.711,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51619,601,8.275,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,605,0.005,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51619,606,0.36,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,203,4.831,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,204,3.024,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,205,9.474,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,208,82.627,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,255,77.88,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,269,3.717,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,291,1.462,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,301,19.564,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,303,0.523,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,306,139.7,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,307,142.375,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51620,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,401,9.287,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51620,601,9.164,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,605,0.003,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51620,606,0.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,203,10.646,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,204,3.75,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,205,17.592,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,208,165.798,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,255,7.661,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,269,1.175,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,291,2.568,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,301,7.35,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,303,0.143,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,306,46.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,307,258.348,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51621,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,401,3.115,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51621,601,24.01,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,605,0.006,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51621,606,1.387,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,203,8.041,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,204,1.678,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,205,12.471,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,208,96.281,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,255,42.522,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,269,1.824,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,291,1.573,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,301,24.7,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,303,0.414,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,306,50.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,307,148.847,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51622,328,0,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51622,401,1.661,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51622,601,14.701,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51622,606,0.552,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,203,7.391,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,204,3.596,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,205,7.898,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,208,95.794,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,255,30.956,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,269,2.426,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,291,1.014,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,301,46.337,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,303,0.307,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,306,44.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,307,155.739,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51623,328,0.5,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,401,2.734,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51623,601,16.825,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,605,0.004,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51623,606,0.846,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,203,8.133,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,204,4.128,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,205,8.711,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,208,103.592,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,255,52.048,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,269,1.167,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,291,1.057,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,301,25.064,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,303,0.655,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,306,123.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,307,169.866,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51624,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,401,2.187,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51624,601,22.148,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,605,0.164,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51624,606,1.167,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,203,5.389,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,204,2.765,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,205,13.518,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,208,93.313,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,269,1.849,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,291,1.35,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,301,52.569,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,303,1.653,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,306,129,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,307,134.812,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51625,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,401,1.088,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51625,601,10.633,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,605,0.072,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51625,606,1.054,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,203,4.964,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,204,2.514,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,205,12.66,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,208,86.287,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,269,1.873,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,291,1.337,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,301,47.849,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,303,1.545,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,306,132.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,307,122.904,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51627,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,401,1.549,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51627,601,9.639,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,605,0.066,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51627,606,0.946,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,203,3.573,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,204,1.299,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,205,14.719,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,208,78.382,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,269,1.753,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,291,2.277,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,301,61.263,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,303,1.375,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,306,121.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,307,122.521,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51628,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,401,4.837,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51628,601,1.849,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51628,606,0.513,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,203,4.149,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,204,1.607,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,205,11.624,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,208,72.121,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,269,1.908,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,291,1.548,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,301,95.733,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,303,0.696,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,306,114.5,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,307,140.882,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51629,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,401,14.838,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51629,601,4.468,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,605,0.003,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51629,606,0.828,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,203,2.463,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,204,1.715,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,205,8.895,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,208,61.287,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,269,2.847,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,291,2.35,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,301,32.255,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,303,0.549,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,306,120.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,307,114.909,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51630,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,401,3.746,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51630,601,4.411,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,605,0.035,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51630,606,0.73,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,203,2.278,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,204,1.731,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,205,12.803,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,208,77.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,269,0.752,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,291,1.876,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,301,22.003,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,303,0.499,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,306,85.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,307,163.034,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51631,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,401,3.794,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51631,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,605,0.004,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51631,606,0.16,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,203,8.178,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,204,1.961,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,205,12.462,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,208,97.966,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,255,30.017,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,269,2.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,291,1.919,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,301,51.155,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,303,1.676,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,306,192.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,307,160.422,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51632,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,401,7.846,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51632,601,14.394,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,605,0.038,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51632,606,0.813,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,203,6.338,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,204,2.7,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,205,12.344,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,208,97.846,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,255,76.81,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,269,6.99,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,291,0.962,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,301,25.82,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,303,0.511,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,306,128.4,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,307,234.23,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51633,328,0.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,401,4.942,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51633,601,12.052,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51633,606,1.287,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,203,9.809,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,204,7.42,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,205,15.976,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,208,176.946,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,255,28.357,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,269,4.403,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,291,2.163,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,301,34.356,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,303,1.846,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,306,282.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,307,144.451,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51634,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,401,4.628,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51634,601,30.291,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,605,0.343,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51634,606,1.954,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,203,9.053,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,204,9.832,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,205,15.449,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,208,181.754,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,269,3.388,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,291,2.706,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,301,24.191,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,303,1.004,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,306,103.4,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,307,181.238,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51635,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,401,3.7,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51635,601,12.941,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,605,0.016,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51635,606,1.192,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,203,24.792,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,204,2.9,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,205,4.447,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,208,146.196,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,255,56.214,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,269,2.981,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,291,0.016,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,301,13.52,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,303,0.88,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,306,218.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,307,391.122,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51636,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,401,0.782,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51636,601,70.093,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51636,606,0.831,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,203,15.835,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,204,7.898,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,205,8.937,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,208,173.53,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,269,1.902,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,291,2.503,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,301,98.176,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,303,2.406,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,306,220.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,307,186.27,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51637,328,0.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,401,4.59,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51637,601,41.539,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,605,0.417,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51637,606,3.221,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,203,5.228,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,204,2.445,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,205,13.025,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,208,84.38,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,255,81.459,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,269,0.994,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,291,1.321,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,301,86.184,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,303,1.086,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,306,106.7,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,307,165.052,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51638,328,0.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,401,3.025,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51638,601,4.488,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51638,606,0.967,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51639,203,27.161,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,204,9.8,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,205,3.997,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,207,2.218,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,208,216.455,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,255,58.226,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,269,1.65,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,291,0.848,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,301,32.929,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,303,1.977,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,306,NULL,'100g',NULL,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,307,490.253,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,328,NULL,'100g',NULL,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,401,3.494,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,539,NULL,'100g',NULL,2,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,601,75.048,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,605,0.011,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51639,606,2.189,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51640,203,1.722,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,204,1.86,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,205,24.751,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,208,117.236,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,255,38.496,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,269,20.285,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,291,1.632,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,301,42.512,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,303,0.436,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,306,113.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,307,135.26,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51640,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,401,4.141,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51640,601,2.669,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51640,606,0.719,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,203,10.371,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,204,3.16,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,205,6.381,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,208,97.847,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,255,81.979,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,269,3.836,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,291,0.646,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,301,27.939,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,303,0.784,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,306,247.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,307,201.253,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51641,328,0.1,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51641,401,3.821,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51641,601,30.015,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51641,606,0.9,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,203,2.077,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,204,1.89,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,205,25.248,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,208,119.86,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,255,39.822,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,269,20.075,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,291,1.824,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,301,57.643,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,303,0.327,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,306,83.9,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,307,167.297,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51642,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,401,14.181,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51642,601,3.611,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51642,606,0.402,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,203,3.413,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,204,1.678,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,205,22.825,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,208,111.322,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,269,5.926,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,291,2.229,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,301,16.899,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,303,0.763,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,306,69.4,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,307,134.372,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51643,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,401,12.767,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51643,601,1.75,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51643,606,0.269,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,203,2.618,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,204,3.314,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,205,15.816,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,208,99.503,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,269,7.926,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,291,1.192,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,301,12.659,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,303,0.39,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,306,142.7,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,307,138.743,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51644,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,401,17.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51644,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,605,0.014,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51644,606,0.248,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,203,1.558,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,204,2.626,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,205,15.597,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,208,90.786,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,255,72.697,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,269,1.469,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,291,1.718,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,301,6.392,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,303,0.329,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,306,309,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,307,177.931,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51645,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,401,32.502,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51645,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51645,606,0.374,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,203,7.241,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,204,3.194,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,205,12.538,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,208,101.957,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,269,0.595,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,291,1.625,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,301,48.25,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,303,0.832,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,306,100.4,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,307,150.319,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51646,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,401,2.069,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51646,601,12.982,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,605,0.022,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51646,606,1.129,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,203,1.127,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,204,1.829,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,205,8.848,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,208,56.797,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,255,55.522,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,269,5.991,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,291,1.661,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,301,13.416,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,303,0.534,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,306,126.9,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,307,161.621,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51647,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,401,9.214,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51647,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51647,606,0.217,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,203,1.524,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,204,2.925,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,205,27.255,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,208,130.351,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,255,61.653,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,269,22.245,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,291,2.231,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,301,27.901,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,303,0.402,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,306,156.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,307,207.545,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51648,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,401,41.529,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51648,601,6.997,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51648,606,0.024,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,203,4.331,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,204,2.272,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,205,15.133,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,208,94.834,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,269,5.437,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,291,2.294,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,301,86.582,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,303,1.165,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,306,204.9,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,307,145.068,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51649,328,0.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,401,15.99,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51649,601,3.723,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51649,606,0.909,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,203,1.066,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,204,1.287,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,205,5.582,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,208,36.29,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,255,91.416,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,269,1.37,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,291,1.221,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,301,10.854,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,303,39.912,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,306,123.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,307,116.286,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51650,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,401,10.913,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51650,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51650,606,0.179,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,203,0.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,204,0.164,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,205,12.5,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,208,50.582,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,255,77.5,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,269,8.409,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,291,1.045,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,301,3.545,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,303,0.264,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,306,104.5,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,307,60.136,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51651,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,401,28.082,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51651,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51651,606,0.009,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,203,1.055,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,204,0.166,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,205,5.563,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,208,24.921,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,255,73.481,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,269,3.015,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,291,1.568,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,301,17.142,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,303,0.347,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,306,192.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,307,78.833,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51652,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,401,18.287,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51652,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51652,606,0.03,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,203,3.507,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,204,1.038,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,205,3.337,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,208,37.493,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,255,81.602,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,269,0.677,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,291,0.534,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,301,7.746,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,303,0.218,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,306,52.4,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,307,66.641,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51653,328,0,'100g',2,2,'2017-05-01','2019-02-25');
INSERT INTO `cndb_nutval` VALUES (51653,401,0.799,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51653,601,9.325,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51653,606,0.299,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,203,0.431,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,204,0.24,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,205,5.735,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,208,24.979,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,269,3.643,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,291,0.964,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,301,25.854,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,303,0.227,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,306,101.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,307,124.05,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51654,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,401,3.674,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51654,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51654,606,0.16,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,203,3.837,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,204,1.421,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,205,4.771,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,208,45.901,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,255,27.831,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,269,1.803,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,291,0.972,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,301,9.406,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,303,0.514,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,306,99.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,307,127.5,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51655,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,401,1.638,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51655,601,9.378,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,605,0.033,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51655,606,0.477,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,203,2.73,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,204,0.526,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,205,4.609,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,208,33.435,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,255,59.834,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,269,1.932,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,291,0.978,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,301,8.663,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,303,0.214,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,306,53.9,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,307,151.049,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51656,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,401,1.635,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51656,601,5.475,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51656,606,0.146,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,203,2.488,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,204,0.22,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,205,8.24,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,208,42.914,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,255,84.251,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,269,1.346,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,291,1.785,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,301,23.176,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,303,0.56,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,306,134.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,307,93.518,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51657,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,401,2.137,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51657,601,0.115,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,605,0.005,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51657,606,0.066,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51658,203,5.996,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,204,2.193,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,205,10.213,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,207,NULL,'100g',NULL,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,208,92.638,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,255,0,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,269,1.476,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,291,2.91,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,301,34.045,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,303,1.264,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,306,164.554,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,307,112.17,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51658,328,0,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,401,1.032,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51658,601,10.244,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,605,0.122,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51658,606,0.756,'100g',2,2,'2017-05-01','2019-03-01');
INSERT INTO `cndb_nutval` VALUES (51660,203,2.379,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,204,2.669,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,205,14.881,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,208,93.83,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,255,78.533,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,269,0.721,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,291,0.951,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,301,18.286,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,303,0.684,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,306,22.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,307,157.794,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51660,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,401,16.963,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51660,601,0.728,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,605,0.007,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51660,606,0.632,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,203,4.793,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,204,2.535,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,205,5.426,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,208,67.607,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,255,19.562,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,269,1.604,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,291,1.701,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,301,145.711,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,303,0.077,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,306,35.9,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,307,209.928,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51661,328,0.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,401,0.335,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51661,601,3.378,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,605,0.004,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51661,606,0.806,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,203,1.253,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,204,3.432,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,205,11.983,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,208,80.681,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,255,82.281,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,269,4.926,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,291,2.478,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,301,27.138,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,303,0.675,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,306,264.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,307,124.303,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51662,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,401,9.987,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51662,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51662,606,0.482,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,203,0.843,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,204,0.084,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,205,3.999,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,208,21.197,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,255,94.148,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,269,1.835,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,291,1.763,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,301,28.585,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,303,0.693,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,306,53.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,307,9.188,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51663,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,401,4.346,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51663,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51663,606,0.006,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,203,3.619,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,204,0.094,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,205,28.002,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,208,123.126,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,269,17.308,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,291,3.858,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,301,29.933,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,303,0.975,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,306,163.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,307,85.786,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51664,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,401,6.376,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51664,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51664,606,0.009,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,203,0.838,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,204,2.117,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,205,28.989,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,208,134.443,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,269,21.494,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,291,1.905,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,301,74.297,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,303,0.381,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,306,208.7,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,307,125.788,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51665,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,401,13.821,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51665,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51665,606,0.483,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,203,7.981,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,204,1.966,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,205,12.988,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,208,97.335,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,269,1.644,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,291,1.856,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,301,102.672,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,303,0.349,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,306,87.5,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,307,127.586,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51666,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,401,22.256,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51666,601,5.22,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51666,606,1.089,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,203,1.695,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,204,1.225,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,205,6.544,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,208,39.715,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,269,2.668,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,291,2.081,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,301,24.631,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,303,0.52,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,306,220.5,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,307,178.221,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51667,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,401,71.879,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51667,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51667,606,0.117,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,203,3.85,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,204,4.349,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,205,30.582,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,208,163.389,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,269,8.862,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,291,2.452,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,301,33.842,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,303,0.699,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,306,184.5,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,307,179.915,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51668,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,401,2.706,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51668,601,16.644,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,605,0.045,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51668,606,1.126,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,203,3.228,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,204,1.765,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,205,4.143,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,208,45.36,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,269,0.693,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,291,1.078,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,301,18.247,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,303,0.5,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,306,127.9,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,307,108.238,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51669,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,401,2.301,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51669,601,8.124,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51669,606,0.458,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,203,2.101,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,204,1.599,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,205,15.579,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,208,74.772,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,269,3.16,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,291,2.082,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,301,5.763,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,303,0.521,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,306,207.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,307,134.096,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51670,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,401,26.213,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51670,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51670,606,0.316,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51671,203,1.046,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,204,1.047,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,205,21.489,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,207,0.537,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,208,96.567,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,255,75.623,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,269,9.583,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,291,2.056,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,301,26.688,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,303,0.604,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,306,NULL,'100g',NULL,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,307,28.241,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,328,NULL,'100g',NULL,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,401,14.088,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,539,NULL,'100g',NULL,2,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,601,0,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,605,0.005,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51671,606,0.276,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,203,0.116,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,204,0.716,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,205,17.49,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,207,0.09,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,208,74.576,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,255,18.125,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,269,14.656,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,291,1.768,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,301,20.592,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,303,0.298,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,306,NULL,'100g',NULL,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,307,40.474,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,328,NULL,'100g',NULL,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,401,4.088,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,539,NULL,'100g',NULL,2,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,601,0,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,605,0.01,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51672,606,0.193,'100g',2,2,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51673,203,4.259,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,204,1.959,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,205,13.618,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,208,89.43,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,269,1.417,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,291,4.437,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,301,45.278,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,303,0.897,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,306,149.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,307,141.795,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51673,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,401,7.735,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51673,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51673,606,0.342,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,203,1.38,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,204,1.231,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,205,6.023,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,208,35.773,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,255,90.512,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,269,2.746,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,291,1.936,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,301,63.969,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,303,0.531,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,306,80.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,307,82.568,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51674,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,401,10.491,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51674,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,605,0.005,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51674,606,0.094,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,203,2.18,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,204,2.06,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,205,13.04,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,208,79.267,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,269,0.836,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,291,1.552,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,301,13.385,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,303,0.495,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,306,72.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,307,175.589,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51675,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,401,4.806,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51675,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,605,0.004,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51675,606,0.179,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,203,5.273,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,204,3.088,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,205,11.485,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,208,88.907,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,269,2.732,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,291,2.53,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,301,26.449,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,303,0.926,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,306,113.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,307,177.328,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51676,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,401,4.026,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51676,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51676,606,0.534,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,203,2.415,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,204,2.415,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,205,7.343,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,208,49.452,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,255,77.268,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,269,2.864,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,291,2.527,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,301,97.796,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,303,3.342,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,306,444.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,307,265.88,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51677,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,401,35.804,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51677,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51677,606,0.295,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,203,1.063,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,204,1.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,205,30.964,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,208,129.879,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,269,17.162,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,291,1.874,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,301,7.141,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,303,0.526,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,306,412.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,307,21.846,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51678,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,401,14.899,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51678,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51678,606,0.4,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,203,0.593,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,204,2.592,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,205,8.577,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,208,68.513,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,269,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,291,1.176,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,301,3.799,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,303,0.76,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,306,169.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,307,208.973,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51679,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,401,3.674,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51679,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,605,0.01,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51679,606,0.177,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,203,0.662,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,204,2.052,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,205,8.167,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,208,59.423,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,269,0.921,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,291,0.727,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,301,11.059,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,303,0.275,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,306,166.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,307,149.867,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51680,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,401,34.979,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51680,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,605,0.008,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51680,606,0.137,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,203,1.052,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,204,4.215,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,205,21.57,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,208,127.601,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,269,1.582,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,291,1.364,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,301,12.879,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,303,0.287,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,306,184.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,307,168.958,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51681,328,0.1,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,401,45.659,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51681,601,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51681,606,0.591,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,203,4.74,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,204,1.693,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,205,12.29,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,208,81.308,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,269,2.643,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,291,1.058,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,301,77.742,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,303,0.597,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,306,201.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,307,182.219,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51682,328,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,401,11.687,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51682,601,5.119,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,605,0,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51682,606,0.834,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,203,9.545,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,204,8.646,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,205,2.221,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,208,127.684,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,255,78.543,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,269,1.362,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,291,0.013,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,301,77.459,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,303,1.23,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,306,138.7,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,307,208.739,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51683,328,1.7,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,401,0.053,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51683,601,268.218,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,605,0.026,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51683,606,2.618,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,203,6.959,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,204,2.745,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,205,12.202,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,207,1.104,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,208,99.828,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,255,77.107,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,269,1.49,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,291,0.965,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,301,35.042,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,303,0.515,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,306,273.5,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,307,180.442,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51684,328,0.4,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,401,16.148,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51684,601,58.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,605,0.021,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51684,606,0.922,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,203,3.928,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,204,5.999,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,205,28.657,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,208,179.072,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,269,15.217,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,291,2.555,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,301,50.906,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,303,0.733,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,306,158,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,307,87.142,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51685,328,0.2,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,401,14.127,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51685,601,15.615,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,605,0.017,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51685,606,1.309,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,203,10.445,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,204,3.911,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,205,20.936,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,208,158.702,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,269,11.347,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,291,1.84,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,301,73.044,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,303,1.013,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,306,100.3,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,307,216.048,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51686,328,0.6,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,401,0.238,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51686,601,83.229,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,605,0.007,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51686,606,1.028,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,203,8.151,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,204,4.449,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,205,26.003,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,207,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,208,174.288,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,255,NULL,'100g',NULL,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,269,14.266,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,291,2.171,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,301,93.885,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,303,1.211,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,306,169.9,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,307,172.088,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51687,328,0.8,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,401,0.32,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51687,601,104.08,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,605,0.019,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51687,606,1.347,'100g',2,2,'2017-05-01','2017-05-01');
INSERT INTO `cndb_nutval` VALUES (51688,203,2.996,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,204,0.731,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,205,11.321,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,208,58.213,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,255,74.652,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,269,1.012,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,291,2.331,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,301,47.419,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,303,1.204,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,306,138.796,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,307,86.527,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51688,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,401,5.674,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51688,601,1.251,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51688,606,0.283,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,203,2.78,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,204,1.985,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,205,7.976,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,207,0.598,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,208,60.881,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,255,50.191,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,269,4.287,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,291,1.178,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,301,35.537,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,303,0.747,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,306,115.862,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,307,230.109,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51689,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,401,26.988,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51689,601,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51689,606,0.239,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,203,17.682,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,204,6.206,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,205,18.024,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,208,200.608,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,255,54.592,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,269,15.959,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,291,0.177,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,301,3.699,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,303,0.937,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,306,201.748,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,307,291.159,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51691,328,0.215,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,401,3.407,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51691,601,101.267,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,605,0.038,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51691,606,1.685,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51692,203,8.398,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,204,2.344,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,205,14.543,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,207,0.634,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,208,111.497,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,255,46.268,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,269,3.923,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,291,1.873,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,301,63.468,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,303,1.346,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,306,NULL,'100g',NULL,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,307,158.602,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,328,NULL,'100g',NULL,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,401,9.177,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,539,NULL,'100g',NULL,2,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,601,12.927,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,605,0,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51692,606,0.412,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51693,203,5.582,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,204,2.273,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,205,13.296,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,207,1.344,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,208,93.463,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,255,57.216,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,269,2.213,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,291,2.384,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,301,69.942,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,303,1.602,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,306,191.505,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,307,141.081,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51693,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,401,11.351,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51693,601,7.644,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,605,0.003,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51693,606,0.992,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,203,5.631,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,204,2.286,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,205,13.048,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,207,1.309,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,208,93.408,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,255,56.347,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,269,2.222,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,291,2.398,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,301,79.497,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,303,1.586,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,306,190.368,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,307,142.03,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51694,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,401,11.442,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51694,601,7.803,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,605,0.007,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51694,606,1.069,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,203,11.045,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,204,3.882,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,205,15.264,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,207,1.088,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,208,138.051,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,255,64.678,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,269,12.878,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,291,0.679,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,301,28.784,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,303,0.379,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,306,197.807,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,307,190.121,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51695,328,1.412,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,401,13.353,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51695,601,26.309,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,605,0.006,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51695,606,0.913,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,203,8.319,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,204,4.056,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,205,22.936,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,208,157.612,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,255,58.495,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,269,3.518,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,291,2.828,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,301,113.989,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,303,1.166,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,306,264.248,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,307,242.05,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51696,328,0.1,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,401,18.411,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51696,601,7.602,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,605,0.007,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51696,606,1.635,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,203,3.968,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,204,1.175,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,205,10.074,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,207,0.715,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,208,63.726,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,255,67.081,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,269,0.97,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,291,1.108,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,301,14.865,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,303,1.204,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,306,81,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,307,130.997,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51697,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,401,10.848,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51697,601,8.082,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,605,0.023,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51697,606,0.261,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,203,19.597,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,204,5.218,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,205,8.948,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,208,160.681,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,255,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,269,0.851,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,291,0.501,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,301,31.273,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,303,0.488,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,306,236.504,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,307,366.938,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51698,328,14.641,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,401,11.626,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51698,601,46.465,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,605,0.025,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51698,606,1.001,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51699,203,8.885,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,204,4.025,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,205,8.371,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,207,1.388,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,208,101.492,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,255,73.381,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,269,4.539,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,291,0.742,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,301,41.604,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,303,0.861,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,306,NULL,'100g',NULL,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,307,316.911,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,328,NULL,'100g',NULL,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,401,13.134,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,539,NULL,'100g',NULL,2,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,601,128.081,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,605,0,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51699,606,1.433,'100g',2,2,'2019-02-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (51700,203,5.601,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,204,2.059,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,205,14.91,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,207,1.478,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,208,100.835,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,255,49.435,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,269,3.263,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,291,3.537,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,301,96.332,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,303,1.83,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,306,268.939,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,307,169.467,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51700,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,401,14.378,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51700,601,4.659,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51700,606,1.077,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,203,6.631,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,204,1.623,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,205,23.983,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,208,158.542,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,255,38.455,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,269,1.217,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,291,4.212,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,301,65.133,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,303,0.536,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,306,124.495,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,307,323.943,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51701,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,401,10.876,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51701,601,4.789,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51701,606,1.623,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,203,2.463,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,204,4.204,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,205,25.111,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,207,0.941,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,208,140.113,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,255,66.667,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,269,13.57,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,291,2.046,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,301,51.192,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,303,0.699,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,306,251.891,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,307,81.262,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51702,328,0.93,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,401,10.493,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51702,601,15.807,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,605,0.006,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51702,606,1.127,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,203,2.448,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,204,2.512,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,205,13.753,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,207,0.434,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,208,87.773,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,255,78.68,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,269,1.743,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,291,0.892,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,301,32.279,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,303,0.323,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,306,69.529,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,307,102.589,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51703,328,0.352,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,401,0.699,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51703,601,4.109,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,605,0.029,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51703,606,0.986,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,203,4.655,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,204,1.683,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,205,12.019,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,207,1.264,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,208,79.991,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,255,76.16,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,269,3.391,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,291,1.102,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,301,125.013,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,303,0.419,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,306,268.533,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,307,121.849,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51704,328,0.793,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,401,3.356,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51704,601,4.301,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51704,606,0.834,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,203,1.879,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,204,2.729,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,205,23.932,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,207,1.264,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,208,124.469,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,255,70.197,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,269,10.512,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,291,3.176,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,301,37.318,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,303,0.66,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,306,441.948,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,307,33.482,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51705,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,401,18.195,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51705,601,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,605,0.011,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51705,606,0.291,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,203,5.397,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,204,2.513,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,205,12.797,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,208,94.389,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,255,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,269,0.895,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,291,3.881,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,301,94.012,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,303,1.301,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,306,236.815,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,307,198.181,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51706,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,401,0.784,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51706,601,3.29,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51706,606,0.843,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,203,3.299,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,204,1.535,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,205,13.735,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,207,1.177,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,208,79.679,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,255,75.561,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,269,2.986,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,291,1.356,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,301,73.451,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,303,0.55,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,306,307.564,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,307,103.638,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51707,328,0.735,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,401,4.84,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51707,601,2.008,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,605,0.013,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51707,606,0.55,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,203,1.984,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,204,0.229,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,205,20.6,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,208,90.094,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,255,52.645,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,269,7.948,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,291,1.513,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,301,37.602,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,303,0.801,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,306,143.26,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,307,172.775,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51708,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,401,20.918,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51708,601,1.59,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51708,606,0.038,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,203,0.8,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,204,1.389,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,205,4.963,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,207,0.42,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,208,35.026,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,255,91.426,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,269,2.788,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,291,0.841,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,301,29.697,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,303,0.352,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,306,96.051,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,307,147.493,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51709,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,401,15.534,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51709,601,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,605,0.005,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51709,606,0.11,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,203,10.168,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,204,1.769,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,205,20.758,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,207,0.157,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,208,138.128,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,255,46.18,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,269,2.706,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,291,1.374,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,301,10.303,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,303,0.644,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,306,94.242,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,307,147.051,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51710,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,401,3.766,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51710,601,23.285,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51710,606,0.319,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,203,5.903,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,204,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,205,11.359,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,208,70.685,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,255,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,269,6.498,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,291,0.149,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,301,181.994,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,303,0.099,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,306,15.823,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,307,223.958,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51711,328,0.149,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,401,1.19,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51711,601,0.843,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51711,606,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,203,3.264,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,204,2.146,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,205,9.497,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,208,66.686,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,255,59.865,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,269,4.528,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,291,1.735,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,301,108.145,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,303,0.147,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,306,103.528,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,307,576.536,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51713,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,401,1.617,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51713,601,3.117,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51713,606,0.441,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,203,3.622,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,204,4.347,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,205,14.144,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,207,0.47,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,208,110.752,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,255,63.575,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,269,11.366,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,291,1.631,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,301,26.234,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,303,0.667,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,306,173.248,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,307,79.317,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51714,328,0.533,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,401,11.476,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51714,601,90.304,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51714,606,1.032,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,203,2.292,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,204,1.643,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,205,29.926,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,208,138.404,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,255,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,269,25.004,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,291,1.711,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,301,27.204,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,303,0.143,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,306,99.806,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,307,74.836,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51715,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,401,1.079,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51715,601,2.941,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51715,606,0.278,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,203,2.53,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,204,0.913,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,205,8.73,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,208,54.27,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,255,62.798,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,269,1.428,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,291,1.896,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,301,21.993,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,303,0.613,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,306,129.599,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,307,160.256,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51716,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,401,10.215,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51716,601,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,605,0.004,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51716,606,0.086,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,203,5.088,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,204,2.364,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,205,5.868,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,208,66.304,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,255,33.464,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,269,2.861,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,291,0.402,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,301,63.283,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,303,0.08,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,306,46.95,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,307,151.13,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51717,328,0.771,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,401,0.326,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51717,601,10.54,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,605,0.005,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51717,606,0.662,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,203,2.044,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,204,1.33,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,205,7.946,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,208,50.669,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,255,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,269,2.06,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,291,0.946,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,301,51.627,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,303,0.24,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,306,210.067,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,307,121.439,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51718,328,0.363,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,401,3.374,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51718,601,1.45,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,605,0.016,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51718,606,0.423,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,203,0.761,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,204,1.05,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,205,4.812,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,208,31.938,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,255,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,269,2.726,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,291,1.081,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,301,23.959,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,303,0.347,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,306,178.064,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,307,127.221,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51719,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,401,5.753,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51719,601,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,605,0.009,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51719,606,0.225,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,203,11.07,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,204,3.675,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,205,15.107,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,207,0.843,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,208,135.036,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,255,39.687,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,269,2.598,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,291,1.914,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,301,25.765,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,303,0.621,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,306,125.138,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,307,242.051,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51720,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,401,7.794,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51720,601,17.565,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51720,606,0.431,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,203,11.898,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,204,4.412,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,205,27.516,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,207,1.441,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,208,196.876,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,255,38.023,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,269,9.549,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,291,2.228,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,301,106.241,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,303,2.444,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,306,205.333,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,307,217.573,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51721,328,0.895,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,401,4.838,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51721,601,26.995,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,605,0.038,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51721,606,0.781,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,203,13.763,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,204,2.435,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,205,14.082,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,208,131.223,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,255,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,269,3.903,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,291,2.092,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,301,34.327,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,303,1.088,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,306,235.971,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,307,298.007,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51722,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,401,3.69,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51722,601,32.737,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51722,606,0.578,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,203,7.589,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,204,2.407,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,205,14.127,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,208,107.265,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,255,1.339,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,269,3.344,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,291,1.698,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,301,52.867,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,303,71.028,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,306,291.676,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,307,266.958,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51723,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,401,3.702,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51723,601,13.059,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,605,0.044,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51723,606,1.033,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,203,10.365,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,204,0.713,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,205,16.959,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,208,110.618,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,255,43.538,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,269,4.77,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,291,3.001,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,301,18.235,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,303,0.68,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,306,204.273,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,307,118.882,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51724,328,0.859,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,401,11.151,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51724,601,13.231,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51724,606,0.234,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,203,10.89,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,204,4.898,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,205,18.267,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,207,1.439,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,208,163.615,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,255,41.525,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,269,3.587,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,291,2.547,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,301,160.191,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,303,2.472,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,306,183.186,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,307,298.291,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51725,328,0.716,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,401,7.438,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51725,601,24.455,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,605,0.027,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51725,606,1.743,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,203,12.048,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,204,4.636,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,205,22.434,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,207,2.27,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,208,179.821,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,255,51.277,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,269,7.314,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,291,1.377,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,301,68.673,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,303,2.782,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,306,297.848,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,307,290.554,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51726,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,401,8.636,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51726,601,27.984,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,605,0.076,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51726,606,1.315,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,203,10.089,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,204,3.891,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,205,13.423,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,208,123.954,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,255,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,269,3.529,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,291,1.785,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,301,29.836,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,303,0.626,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,306,137.406,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,307,237.498,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51727,328,0.103,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,401,3.162,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51727,601,34.502,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51727,606,0.608,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,203,8.547,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,204,4.443,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,205,19.326,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,208,134.162,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,255,25.238,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,269,2.589,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,291,5.45,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,301,152.396,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,303,1.318,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,306,65.226,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,307,282.914,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51728,328,0.339,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,401,8.482,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51728,601,6.354,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51728,606,1.939,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,203,3.923,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,204,0.686,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,205,20.015,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,208,117.505,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,255,56.341,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,269,2.401,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,291,3.258,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,301,34.762,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,303,0.199,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,306,113.451,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,307,302.147,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51729,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,401,10.419,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51729,601,1.248,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51729,606,0.857,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,203,4.383,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,204,4.923,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,205,17.851,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,207,2.085,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,208,128.664,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,255,71.329,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,269,1.666,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,291,3.805,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,301,74.456,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,303,0.951,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,306,113.841,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,307,154.292,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51730,328,0.1,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,401,4.505,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51730,601,5.167,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,605,0.03,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51730,606,0.944,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,203,6.454,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,204,2.194,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,205,43.903,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,207,1.25,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,208,217.372,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,255,46.224,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,269,11.607,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,291,3.214,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,301,9.031,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,303,1.403,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,306,134.311,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,307,250.408,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51731,328,0.153,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,401,0.077,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51731,601,21.531,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51731,606,0.306,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,203,7.486,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,204,4.38,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,205,17.741,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,207,0.719,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,208,139.022,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,255,39.22,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,269,1.388,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,291,2.228,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,301,86.053,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,303,2.196,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,306,140.27,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,307,275.231,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51732,328,0.783,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,401,3.533,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51732,601,109.58,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,605,0.013,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51732,606,1.42,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,203,6.067,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,204,4.911,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,205,38.135,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,207,0.998,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,208,218.319,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,255,40.171,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,269,20.315,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,291,1.917,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,301,35.115,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,303,1.024,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,306,119.54,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,307,255.246,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51733,328,0.42,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,401,4.767,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51733,601,59.947,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,605,0.026,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51733,606,0.788,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,203,6.061,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,204,6.657,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,205,65.378,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,208,340.659,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,255,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,269,35.385,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,291,6.705,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,301,39.585,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,303,2.792,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,306,47.292,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,307,129.158,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51735,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,401,0.072,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51735,601,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51735,606,1.599,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,203,5.411,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,204,1.046,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,205,10.893,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,207,0.345,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,208,73.676,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,255,45.707,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,269,9.752,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,291,0.624,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,301,68.822,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,303,0.134,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,306,77.408,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,307,18.539,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51736,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,401,11.622,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51736,601,5.439,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,605,0.034,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51736,606,0.667,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,203,2.284,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,204,1.469,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,205,12.815,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,207,0.549,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,208,72.058,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,255,82.087,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,269,7.698,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,291,1.066,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,301,50.465,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,303,0.359,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,306,36.602,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,307,62.716,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51738,328,0.499,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,401,0.402,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51738,601,2.208,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51738,606,0.47,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,203,4.13,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,204,3.458,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,205,10.297,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,208,90.937,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,255,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,269,1.386,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,291,1.85,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,301,9.486,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,303,1.088,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,306,213.955,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,307,94.942,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51739,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,401,31.001,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51739,601,10.31,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,605,0.021,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51739,606,0.478,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,203,4.772,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,204,1.936,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,205,20.801,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,208,118.771,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,255,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,269,13.566,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,291,1.856,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,301,103.886,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,303,0.466,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,306,48.771,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,307,70.518,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51740,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,401,15.064,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51740,601,3.528,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51740,606,0.758,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,203,3.059,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,204,2,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,205,6.076,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,207,0.669,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,208,57.02,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,255,70.957,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,269,0.864,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,291,1.017,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,301,35.781,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,303,1.143,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,306,80.635,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,307,135.405,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51741,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,401,21.936,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51741,601,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51741,606,0.251,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,203,18.997,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,204,2.953,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,205,2.934,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,208,114.41,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,255,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,269,1.3,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,291,0.501,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,301,6.778,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,303,0.427,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,306,24.401,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,307,472.405,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51742,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,401,0.409,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51742,601,39.833,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51742,606,0.167,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,203,1.455,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,204,1.953,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,205,5.245,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,207,0.957,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,208,42.649,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,255,90.046,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,269,1.493,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,291,0.689,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,301,6.087,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,303,0.115,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,306,53.599,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,307,178.484,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51761,328,0.459,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,401,1.302,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51761,601,1.723,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51761,606,0.459,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,203,0.242,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,204,0.031,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,205,18.935,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,207,0.234,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,208,71.321,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,255,80.683,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,269,13.564,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,291,1.138,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,301,4.436,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,303,0.21,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,306,43.639,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,307,19.091,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51762,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,401,14.546,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51762,601,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51762,606,0.016,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,203,1.117,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,204,1.959,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,205,11.978,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,207,0.939,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,208,71.318,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,255,30.965,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,269,7.332,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,291,0.518,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,301,8.789,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,303,0.243,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,306,54.629,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,307,395.565,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51763,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,401,1.813,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51763,601,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51763,606,0.259,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,203,1.697,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,204,0.29,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,205,38.452,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,207,0.455,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,208,162.459,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,255,33.154,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,269,33.32,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,291,0.124,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,301,10.969,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,303,0.166,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,306,60.472,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,307,926.531,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51764,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,401,0.704,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51764,601,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51764,606,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,203,2.35,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,204,1.449,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,205,8.461,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,207,NULL,'100g',NULL,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,208,53.467,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,255,15.981,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,269,4.152,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,291,1.449,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,301,6.385,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,303,0.157,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,306,28.907,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,307,44.849,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51765,328,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,401,0.705,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51765,601,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,605,0,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51765,606,0.078,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,203,3.796,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,204,2.086,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,205,7.76,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,207,1.085,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,208,65.791,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,255,84.898,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,269,4.047,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,291,0.501,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,301,118.231,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,303,0.125,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,306,165.499,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,307,159.074,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,320,NULL,'100g',NULL,2,'2024-12-12','2024-12-12');
INSERT INTO `cndb_nutval` VALUES (51766,328,1.168,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,401,0.96,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,539,NULL,'100g',NULL,2,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (51766,601,3.671,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,605,0.042,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51766,606,0.834,'100g',2,2,'2019-02-22','2019-02-22');
INSERT INTO `cndb_nutval` VALUES (51767,203,4.906,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,204,3.717,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,205,13.891,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,207,0.137,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,208,107.782,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,255,3.634,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,269,0.891,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,291,2.709,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,301,26.289,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,303,0.923,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,306,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,307,126.911,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,320,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,328,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,401,1.064,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,539,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,601,49.647,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,605,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51767,606,1.077,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,203,1.384,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,204,4.260,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,205,5.142,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,207,1.048,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,208,58.557,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,255,88.145,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,269,2.373,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,291,2.124,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,301,20.053,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,303,0.358,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,306,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,307,188.844,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,320,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,328,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,401,47.822,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,539,0.000,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,601,0.000,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,605,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51768,606,0.572,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,203,16.13,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,204,6.450,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,205,4.550,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,207,1.197,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,208,142.014,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,255,71.306,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,269,1.419,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,291,0.684,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,301,22.711,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,303,0.816,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,306,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,307,153.970,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,320,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,328,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,401,2.194,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,539,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,601,51.334,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,605,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51769,606,1.538,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,203,6.141,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,204,13.688,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,205,37.017,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,207,1.866,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,208,289.945,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,255,41.549,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,269,3.554,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,291,3.192,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,301,111.234,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,303,2.124,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,306,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,307,349.132,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,320,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,328,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,401,0.528,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,539,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,601,23.218,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,605,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51770,606,1.446,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,203,4.797,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,204,7.011,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,205,13.911,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,207,0.875,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,208,144.426,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,255,72.408,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,269,1.132,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,291,2.496,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,301,22.858,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,303,1.199,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,306,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,307,106.863,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,320,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,328,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,401,12.847,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,539,0.000,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,601,49.733,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,605,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51771,606,1.210,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,203,4.117,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,204,6.141,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,205,20.881,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,207,1.058,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,208,150.353,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,255,36.55,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,269,2.945,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,291,3.792,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,301,41.436,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,303,1.23,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,306,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,307,125.859,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,320,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,328,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,401,11.944,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,539,0.000,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,601,0.000,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,605,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51772,606,0.852,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,203,10.375,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,204,5.752,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,205,4.756,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,207,0.775,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,208,109.767,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,255,47.044,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,269,1.273,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,291,1.474,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,301,25.421,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,303,1.654,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,306,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,307,176.259,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,320,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,328,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,401,4.102,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,539,0.000,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,601,29.270,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,605,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51773,606,2.389,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,203,6.51,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,204,15.666,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,205,29.188,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,207,2.484,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,208,274.030,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,255,45.5,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,269,8.199,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,291,3.179,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,301,157.669,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,303,1.463,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,306,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,307,460.425,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,320,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,328,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,401,0.376,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,539,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,601,45.881,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,605,NULL,'100g',NULL,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (51774,606,1.758,'100g',2,2,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (80200,203,16.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (80200,204,0.3,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (80200,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (80200,207,1.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (80200,208,73,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (80200,255,81.9,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (80200,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (80200,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (80200,301,18,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (80200,303,1.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (80200,306,285,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (80200,307,58,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (80200,320,15,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (80200,328,0.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (80200,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (80200,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (80200,601,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (80200,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (80200,606,0.076,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (83110,203,18.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (83110,204,25.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (83110,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (83110,207,13.4,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (83110,208,305,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (83110,255,43,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (83110,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (83110,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (83110,301,66,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (83110,303,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (83110,306,520,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (83110,307,4450,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (83110,320,47,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (83110,328,25.2,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (83110,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (83110,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (83110,601,95,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (83110,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (83110,606,7.148,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (90240,203,20.54,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90240,204,0.84,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90240,205,5.41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90240,207,2.97,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90240,208,111,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90240,255,70.25,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90240,269,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90240,291,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90240,301,10,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90240,303,0.58,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90240,306,314,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (90240,307,667,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90240,320,2,'100g',2,1,'2024-12-12','2010-01-08');
INSERT INTO `cndb_nutval` VALUES (90240,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (90240,401,0,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90240,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (90240,601,41,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90240,605,0.009,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90240,606,0.218,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (90480,203,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (90480,204,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (90480,205,73.14,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (90480,207,0.86,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (90480,208,269,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (90480,255,26,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (90480,269,73.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90480,291,0,'100g',3,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (90480,301,13,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (90480,303,3.6,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (90480,306,63,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (90480,307,58,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (90480,320,0,'100g',2,1,'2024-12-12','2006-01-10');
INSERT INTO `cndb_nutval` VALUES (90480,328,0,'100g',3,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (90480,401,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (90480,539,73.2,'100g',5,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (90480,601,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (90480,605,NULL,'100g',NULL,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (90480,606,0,'100g',1,1,'2013-02-22','2013-02-22');
INSERT INTO `cndb_nutval` VALUES (90560,203,16.1,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90560,204,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90560,205,2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90560,207,1.3,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90560,208,90,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90560,255,79.2,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90560,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90560,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90560,301,10,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90560,303,3.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90560,306,382,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (90560,307,70,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90560,320,30,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (90560,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (90560,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90560,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (90560,601,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90560,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (90560,606,0.361,'100g',3,1,'2013-12-23','2015-06-19');
INSERT INTO `cndb_nutval` VALUES (93600,203,19.8,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (93600,204,0.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (93600,205,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (93600,207,1.2,'100g',3,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (93600,208,89,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (93600,255,78.5,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (93600,269,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (93600,291,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (93600,301,118,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (93600,303,1.4,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (93600,306,230,'100g',1,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (93600,307,68,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (93600,320,30,'100g',2,1,'2024-12-12','2009-01-03');
INSERT INTO `cndb_nutval` VALUES (93600,328,0,'100g',4,1,'2017-05-02','2017-05-02');
INSERT INTO `cndb_nutval` VALUES (93600,401,0,'100g',4,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (93600,539,0,'100g',4,4,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (93600,601,50,'100g',1,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (93600,605,NULL,'100g',NULL,1,'2013-12-23','2013-12-23');
INSERT INTO `cndb_nutval` VALUES (93600,606,0.127,'100g',3,1,'2013-12-23','2015-01-07');
INSERT INTO `cndb_nutval` VALUES (119936,203,9.600,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,204,7.400,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,205,27.700,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,207,NULL,'100g',NULL,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,208,213,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,255,NULL,'100g',NULL,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,269,6.400,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,291,3.200,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,301,160,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,303,1.800,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,306,394,'100g',6,3,'2017-05-02','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,307,340,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,320,0.000,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,328,0,'100g',6,3,'2017-05-02','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,401,0,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,539,2,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,601,16,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,605,0,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119936,606,2.100,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119937,203,10.600,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,204,6.700,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,205,29.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,208,221,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,269,4.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,291,2.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,301,183,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,303,1.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,306,202,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,307,298,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,320,19.200,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,401,1.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,539,2,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,601,19.200,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119937,606,1.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,203,11.700,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,204,10.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,205,24.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,208,234,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,269,7.600,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,291,2.100,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,301,241,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,303,1.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,306,338,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,307,352,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,320,48.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,401,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,539,2,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,601,24.100,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119940,606,4.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119951,203,16.5,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,204,4.400,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,205,10.100,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,207,NULL,'100g',NULL,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,208,139,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,255,NULL,'100g',NULL,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,269,8.900,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,291,1.300,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,301,0,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,303,0.800,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,306,190,'100g',6,3,'2017-05-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,307,367,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,320,0.000,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,328,0,'100g',6,3,'2017-05-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,401,0,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,539,9,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,601,63,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,605,0,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119951,606,1.900,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (119952,203,13.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,204,5.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,205,16.100,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,208,161,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,269,8,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,291,0.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,301,12.500,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,303,0.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,306,156,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,307,268,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,401,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,539,8,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,601,49.100,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119952,606,0.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,203,12.200,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,204,9.600,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,205,22.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,208,224,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,269,6.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,291,1.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,301,218,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,303,1.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,306,320,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,307,314,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,320,51.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,401,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,601,22.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119976,606,4.5,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,203,12.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,204,10.500,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,205,22.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,208,235,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,269,5.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,291,2,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,301,183,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,303,1.600,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,306,353,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,307,431,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,320,58.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,401,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,601,26.100,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119977,606,4.600,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,203,12.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,204,11.100,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,205,27.5,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,208,261,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,269,5.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,291,1.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,301,229,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,303,1.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,306,235,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,307,379,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,320,52.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,401,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,601,26.100,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119981,606,5.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,203,13,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,204,11.700,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,205,27.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,208,266,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,269,5.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,291,1.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,301,182,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,303,2,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,306,273,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,307,474,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,320,64.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,401,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,601,26,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119982,606,5.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,203,11.5,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,204,8.500,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,205,24.600,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,208,215,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,269,6.200,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,291,3.100,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,301,231,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,303,1.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,306,400,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,307,354,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,320,84.600,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,401,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,539,2,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,601,11.500,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119983,606,2.700,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,203,11.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,204,8.700,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,205,24.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,208,213,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,269,6.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,291,3.100,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,301,189,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,303,2,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,306,425,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,307,417,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,320,110.000,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,401,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,539,2,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,601,11.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119984,606,2.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,203,16,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,204,9.200,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,205,24.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,208,244,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,269,4.200,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,291,1.700,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,301,311.000,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,303,1.500,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,306,269.000,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,307,344.000,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,320,92.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,401,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,601,25.200,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119989,606,5,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119990,203,11.800,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,204,8.200,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,205,28.200,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,207,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,208,224,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,255,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,269,7.100,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,291,2.400,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,301,200,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,303,1.900,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,306,376,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,307,353,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,320,0.000,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,328,0,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,401,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,539,2,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,601,23.500,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,605,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119990,606,2.400,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,203,11.900,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,204,10.700,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,205,27.400,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,207,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,208,250,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,255,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,269,6,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,291,2.400,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,301,190,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,303,1.800,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,306,250,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,307,393,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,320,47.600,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,328,0,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,401,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,539,2,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,601,71.400,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,605,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119991,606,4.200,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119992,203,12.100,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,204,7.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,205,22.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,208,214,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,269,5.700,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,291,2.100,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,301,229,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,303,1.600,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,306,329,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,307,307,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,320,78.600,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,401,1.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,601,10.700,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119992,606,2.5,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119993,203,12.900,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,204,8.600,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,205,22.900,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,207,NULL,'100g',NULL,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,208,221,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,255,NULL,'100g',NULL,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,269,5,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,291,2.100,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,301,179,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,303,1.900,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,306,350,'100g',6,3,'2017-05-02','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,307,407,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,320,78.600,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,328,0,'100g',6,3,'2017-05-02','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,401,1.400,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,539,1,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,601,17.900,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,605,0,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119993,606,2.900,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (119994,203,14.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,204,12.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,205,23.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,208,262,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,269,3.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,291,1.600,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,301,270,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,303,1.700,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,306,180,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,307,434,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,320,41.000,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,401,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,601,16.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119994,606,4.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,203,14.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,204,12.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,205,23.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,208,262,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,269,3.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,291,1.600,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,301,270,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,303,1.700,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,306,180,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,307,434,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,320,41.000,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,401,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,601,16.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119996,606,4.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (119999,203,11.900,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,204,9.500,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,205,20.600,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,207,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,208,222,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,255,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,269,6.300,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,291,2.400,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,301,222,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,303,1.400,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,306,310,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,307,325,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,320,47.600,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,328,0,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,401,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,539,2,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,601,23.800,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,605,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (119999,606,4.800,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,203,12.600,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,204,10.200,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,205,22,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,207,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,208,228,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,255,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,269,6.300,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,291,2.400,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,301,205,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,303,1.5,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,306,339,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,307,386,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,320,47.200,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,328,0,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,401,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,539,2,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,601,27.600,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,605,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120000,606,4.700,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,203,11.900,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,204,9.500,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,205,22.200,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,207,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,208,222,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,255,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,269,6.300,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,291,2.400,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,301,222,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,303,1.300,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,306,318,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,307,325,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,320,47.600,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,328,0,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,401,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,539,2,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,601,23.800,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,605,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120001,606,4.800,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,203,12.600,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,204,10.200,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,205,22,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,207,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,208,228,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,255,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,269,3.900,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,291,2.400,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,301,205,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,303,1.5,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,306,339,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,307,386,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,320,47.200,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,328,0,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,401,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,539,2,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,601,27.600,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,605,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120002,606,4.700,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,203,11.300,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,204,9.200,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,205,22,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,207,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,208,220,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,255,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,269,6.400,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,291,2.100,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,301,199,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,303,1.5,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,306,312,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,307,312,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,320,42.600,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,328,0,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,401,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,539,1,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,601,21.300,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,605,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120003,606,4.300,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120004,203,12.100,'100g',6,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,204,9.200,'100g',6,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,205,23.400,'100g',6,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,207,NULL,'100g',NULL,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,208,220,'100g',6,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,255,NULL,'100g',NULL,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,269,5.700,'100g',6,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,291,2.100,'100g',6,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,301,170,'100g',6,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,303,1.600,'100g',6,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,306,333,'100g',6,3,'2017-05-02','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,307,362,'100g',6,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,320,49.600,'100g',6,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,328,0,'100g',6,3,'2017-05-02','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,401,0,'100g',6,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,539,1,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,601,24.800,'100g',6,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,605,0,'100g',6,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120004,606,3.5,'100g',6,3,'2014-12-07','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (120007,203,15.200,'100g',6,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,204,9.600,'100g',6,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,205,24.800,'100g',6,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,207,NULL,'100g',NULL,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,208,240.000,'100g',6,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,255,NULL,'100g',NULL,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,269,1.600,'100g',6,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,291,2.400,'100g',6,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,301,272.000,'100g',6,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,303,1.800,'100g',6,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,306,208.000,'100g',6,3,'2017-05-02','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,307,392.000,'100g',6,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,320,64.000,'100g',6,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,328,0,'100g',6,3,'2017-05-02','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,401,0,'100g',6,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,539,1.000,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,601,36,'100g',6,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,605,0,'100g',6,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120007,606,4.800,'100g',6,3,'2014-12-07','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (120008,203,15.200,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,204,8.800,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,205,24.800,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,207,NULL,'100g',NULL,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,208,232.000,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,255,NULL,'100g',NULL,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,269,1.600,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,291,2.400,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,301,208.000,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,303,1.800,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,306,216.000,'100g',6,3,'2017-05-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,307,408.000,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,320,32.000,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,328,0,'100g',6,3,'2017-05-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,401,0,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,539,1.000,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,601,36,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,605,0,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120008,606,3.600,'100g',6,3,'2014-12-07','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (120019,203,14.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,204,10.900,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,205,23.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,208,245,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,269,6.100,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,291,2,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,301,300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,303,1.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,306,295,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,307,333,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,320,63.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,401,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,601,23.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120019,606,4.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,203,14.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,204,11.600,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,205,22.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,208,245,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,269,6.100,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,291,2,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,301,252,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,303,1.5,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,306,306,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,307,395,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,320,74.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,401,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,601,30.600,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120020,606,4.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120033,203,12,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,204,7.500,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,205,24.800,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,207,NULL,'100g',NULL,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,208,211,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,255,NULL,'100g',NULL,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,269,6,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,291,3.800,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,301,158,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,303,2,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,306,474,'100g',6,3,'2017-05-02','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,307,346,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,320,30.100,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,328,0,'100g',6,3,'2017-05-02','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,401,0,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,539,2,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,601,22.600,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,605,0,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120033,606,3,'100g',6,3,'2014-12-07','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120036,203,12,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,204,10.100,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,205,27.200,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,207,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,208,253,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,255,NULL,'100g',NULL,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,269,4.400,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,291,2.5,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,301,216,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,303,1.5,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,306,296,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,307,278,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,320,46.200,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,328,0,'100g',6,3,'2017-05-02','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,401,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,539,1,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,601,22.200,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,605,0,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120036,606,4.400,'100g',6,3,'2014-12-07','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120037,203,12.600,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,204,11.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,205,27,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,207,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,208,258,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,255,NULL,'100g',NULL,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,269,4.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,291,2.5,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,301,174,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,303,1.800,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,306,295,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,307,365,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,320,62.300,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,401,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,601,25.200,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,605,0,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120037,606,4.400,'100g',6,3,'2014-12-07','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120242,203,0.810,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,204,4.840,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,205,6.450,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,207,NULL,'100ml',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,208,73.000,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,255,NULL,'100ml',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,269,0,'100ml',6,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,291,0,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,301,8,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,303,0.160,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,306,24.000,'100ml',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,307,637.000,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,328,0,'100ml',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,401,NULL,'100ml',NULL,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,539,0,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,601,0,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,605,0,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120242,606,0.810,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120256,203,1.610,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,204,2.020,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,205,7.260,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,207,NULL,'100ml',NULL,3,'2016-03-11','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,208,56.000,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,255,NULL,'100ml',NULL,3,'2016-03-11','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,269,0,'100ml',6,3,'2016-03-11','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,291,0,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,301,8,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,303,0,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,306,411.000,'100ml',6,3,'2017-05-02','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,307,315.000,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,320,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,328,0,'100ml',6,3,'2017-05-02','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,401,NULL,'100ml',NULL,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,539,0,'100ml',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,601,4,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,605,0,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120256,606,0.400,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,203,1.610,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,204,1.610,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,205,8.060,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,207,NULL,'100ml',NULL,3,'2016-03-11','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,208,56.000,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,255,NULL,'100ml',NULL,3,'2016-03-11','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,269,1.610,'100ml',6,3,'2016-03-11','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,291,0,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,301,81.000,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,303,0.240,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,306,387.000,'100ml',6,3,'2017-05-02','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,307,315.000,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,320,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,328,0,'100ml',6,3,'2017-05-02','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,401,NULL,'100ml',NULL,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,539,0.800,'100ml',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,601,0,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,605,0,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120257,606,0.400,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,203,1.610,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,204,0.810,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,205,14.500,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,207,NULL,'100ml',NULL,3,'2016-03-11','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,208,73.000,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,255,NULL,'100ml',NULL,3,'2016-03-11','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,269,8.060,'100ml',6,3,'2016-03-11','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,291,0.800,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,301,8,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,303,0.320,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,306,185.000,'100ml',6,3,'2017-05-02','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,307,315.000,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,320,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,328,0,'100ml',6,3,'2017-05-02','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,401,8.900,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,539,5.600,'100ml',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,601,0,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,605,0,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120258,606,0,'100ml',6,3,'2016-02-05','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120261,203,1.590,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,204,8.730,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,205,7.940,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,207,NULL,'100ml',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,208,119.000,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,255,NULL,'100ml',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,269,1.590,'100ml',6,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,291,1.600,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,301,53.000,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,303,0.240,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,306,83.000,'100ml',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,307,635.000,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,328,0,'100ml',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,401,NULL,'100ml',NULL,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,539,0.800,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,601,8,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,605,0,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120261,606,0.790,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,203,2.380,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,204,6.350,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,205,14.300,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,207,NULL,'100ml',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,208,127.000,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,255,NULL,'100ml',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,269,2.380,'100ml',6,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,291,1.600,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,301,79.000,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,303,0.320,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,306,198.000,'100ml',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,307,683.000,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,328,2,'100ml',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,401,NULL,'100ml',NULL,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,539,0,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,601,8,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,605,0,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120266,606,1.590,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,203,2.380,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,204,0,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,205,16.700,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,207,NULL,'100ml',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,208,79.000,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,255,NULL,'100ml',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,269,10.300,'100ml',6,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,291,0.800,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,301,16.000,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,303,0.790,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,306,643.000,'100ml',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,307,325.000,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,328,0,'100ml',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,401,NULL,'100ml',NULL,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,539,6.300,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,601,0,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,605,0,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120287,606,0,'100ml',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120289,203,3.970,'100ml',6,3,'2016-02-05','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,204,1.190,'100ml',6,3,'2016-02-05','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,205,13.500,'100ml',6,3,'2016-02-05','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,207,NULL,'100ml',NULL,3,'2016-03-11','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,208,79.000,'100ml',6,3,'2016-02-05','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,255,NULL,'100ml',NULL,3,'2016-03-11','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,269,3.170,'100ml',6,3,'2016-03-11','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,291,4.000,'100ml',6,3,'2016-02-05','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,301,56.000,'100ml',6,3,'2016-02-05','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,303,0.790,'100ml',6,3,'2016-02-05','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,306,619.000,'100ml',6,3,'2017-05-02','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,307,325.000,'100ml',6,3,'2016-02-05','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,320,159.000,'100ml',6,3,'2016-02-05','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,328,0,'100ml',6,3,'2017-05-02','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,401,NULL,'100ml',NULL,3,'2016-02-05','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,539,0.800,'100ml',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,601,0,'100ml',6,3,'2016-02-05','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,605,0,'100ml',6,3,'2016-02-05','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120289,606,0,'100ml',6,3,'2016-02-05','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (120296,203,9.520,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,204,16.700,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,205,66.700,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,207,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,208,429,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,255,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,269,0,'100g',6,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,291,4.800,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,301,95,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,303,3.330,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,306,333,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,307,952,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,328,0,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,401,NULL,'100g',NULL,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,601,0,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,605,0,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120296,606,2.380,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,203,9.520,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,204,16.700,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,205,66.700,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,207,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,208,476,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,255,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,269,0,'100g',6,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,291,4.800,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,301,95,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,303,3.330,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,306,286,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,307,810,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,328,0,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,401,NULL,'100g',NULL,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,601,0,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,605,0,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120297,606,2.380,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,203,10.700,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,204,17.900,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,205,64.300,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,207,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,208,464,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,255,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,269,0,'100g',6,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,291,7.100,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,301,107,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,303,3.210,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,306,236,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,307,786,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,328,0,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,401,NULL,'100g',NULL,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,601,18,'100g',6,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,605,0,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120298,606,3.570,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120299,203,10,'100g',6,3,'2016-02-05','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,204,16.700,'100g',6,3,'2016-02-05','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,205,63.300,'100g',6,3,'2016-02-05','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,207,NULL,'100g',NULL,3,'2016-03-11','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,208,467,'100g',6,3,'2016-02-05','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,255,NULL,'100g',NULL,3,'2016-03-11','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,269,0,'100g',6,3,'2016-03-11','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,291,6.700,'100g',6,3,'2016-02-05','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,301,100,'100g',6,3,'2016-02-05','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,303,3.330,'100g',6,3,'2016-02-05','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,306,233,'100g',6,3,'2017-05-02','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,307,800,'100g',6,3,'2016-02-05','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,328,0,'100g',6,3,'2017-05-02','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,401,NULL,'100g',NULL,3,'2016-02-05','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,539,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,601,17,'100g',6,3,'2016-03-11','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,605,0,'100g',6,3,'2016-02-05','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120299,606,3.330,'100g',6,3,'2016-02-05','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120300,203,9.520,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,204,7.140,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,205,76.200,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,207,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,208,429,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,255,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,269,0,'100g',6,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,291,4.800,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,301,48,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,303,3.330,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,306,214,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,307,952,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,328,0,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,401,NULL,'100g',NULL,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,601,0,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,605,0,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120300,606,0,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,203,9.520,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,204,16.700,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,205,66.700,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,207,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,208,476,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,255,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,269,0,'100g',6,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,291,4.800,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,301,95,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,303,3.330,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,306,286,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,307,810,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,328,0,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,401,NULL,'100g',NULL,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,601,0,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,605,0,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120301,606,2.380,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,203,3.850,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,204,15.400,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,205,73.100,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,207,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,208,462,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,255,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,269,26.900,'100g',6,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,291,3.800,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,301,385,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,303,7.690,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,306,154,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,307,538,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,328,0,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,401,NULL,'100g',NULL,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,539,26.900,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,601,0,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,605,0,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120304,606,3.850,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,203,3.850,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,204,15.400,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,205,73.100,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,207,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,208,462,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,255,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,269,26.900,'100g',6,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,291,3.800,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,301,385,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,303,8.080,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,306,154,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,307,404,'100g',6,3,'2019-02-13','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,328,0,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,401,NULL,'100g',NULL,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,539,26.900,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,601,0,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,605,0,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120306,606,3.850,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,203,3.080,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,204,5.640,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,205,12.300,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,207,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,208,113,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,255,NULL,'100g',NULL,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,269,0.510,'100g',6,3,'2016-03-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,291,0.5,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,301,41,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,303,0.510,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,306,26,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,307,354,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,328,0,'100g',6,3,'2017-05-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,401,NULL,'100g',NULL,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,539,0.5,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,601,5,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,605,0,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120347,606,1.030,'100g',6,3,'2016-02-05','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120348,203,8.590,'100g',6,3,'2016-02-05','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,204,9.820,'100g',6,3,'2016-02-05','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,205,7.360,'100g',6,3,'2016-02-05','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,207,NULL,'100g',NULL,3,'2016-03-11','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,208,153,'100g',6,3,'2016-02-05','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,255,NULL,'100g',NULL,3,'2016-03-11','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,269,1.230,'100g',6,3,'2016-03-11','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,291,0.600,'100g',6,3,'2016-02-05','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,301,18,'100g',6,3,'2016-02-05','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,303,1.230,'100g',6,3,'2016-02-05','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,306,129,'100g',6,3,'2017-05-02','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,307,423,'100g',6,3,'2016-02-05','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,320,NULL,'100g',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,328,NULL,'100g',NULL,3,'2017-05-02','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,401,NULL,'100g',NULL,3,'2016-02-05','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,539,0.600,'100g',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,601,28,'100g',6,3,'2016-02-05','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,605,0.610,'100g',6,3,'2016-02-05','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120348,606,4.290,'100g',6,3,'2016-02-05','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (120447,203,2.690,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,204,1.180,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,205,16.300,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,207,NULL,'100g',NULL,3,'2016-03-11','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,208,86,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,255,NULL,'100g',NULL,3,'2016-03-11','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,269,6.200,'100g',6,3,'2016-03-11','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,291,3.100,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,301,2,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,303,0.400,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,306,236,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,307,3.900,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,401,NULL,'100g',NULL,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,601,16.300,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,605,0,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120447,606,0,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,203,0.830,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,204,0,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,205,8.330,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,207,NULL,'100g',NULL,3,'2016-03-11','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,208,33,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,255,NULL,'100g',NULL,3,'2016-03-11','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,269,3.330,'100g',6,3,'2016-03-11','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,291,2.5,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,301,26,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,303,1.670,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,306,206,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,307,4,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,320,778.000,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,328,0,'100g',6,3,'2017-05-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,401,4.200,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,601,0,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,605,0,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120453,606,0,'100g',6,3,'2016-02-05','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120472,203,0,'100g',6,3,'2016-02-05','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,204,0,'100g',6,3,'2016-02-05','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,205,13.300,'100g',6,3,'2016-02-05','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,207,NULL,'100g',NULL,3,'2016-03-11','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,208,47,'100g',6,3,'2016-02-05','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,255,NULL,'100g',NULL,3,'2016-03-11','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,269,11.700,'100g',6,3,'2016-03-11','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,291,0.800,'100g',6,3,'2016-02-05','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,301,4,'100g',6,3,'2016-02-05','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,303,0,'100g',6,3,'2016-02-05','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,306,70,'100g',6,3,'2017-05-02','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,307,12,'100g',6,3,'2016-02-05','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,328,NULL,'100g',NULL,3,'2017-05-02','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,401,46.900,'100g',6,3,'2016-02-05','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,539,2.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,601,0,'100g',6,3,'2016-02-05','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,605,0,'100g',6,3,'2016-02-05','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120472,606,0,'100g',6,3,'2016-02-05','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (120601,203,11,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,204,9.100,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,205,27.900,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,207,NULL,'100g',NULL,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,208,234,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,255,NULL,'100g',NULL,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,269,5.200,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,291,2.600,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,301,156,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,303,2,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,306,307,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,307,461,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,320,59.100,'100g',6,3,'2017-01-26','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,328,0,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,401,0,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,539,2,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,601,16.200,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,605,0,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120601,606,3.900,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120605,203,13.5,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,204,12.800,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,205,22.300,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,207,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,208,257,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,255,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,269,5.400,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,291,2,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,301,223,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,303,1.400,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,306,250,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,307,493,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,320,47.300,'100g',6,3,'2017-01-26','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,328,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,401,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,601,30.400,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,605,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120605,606,5.400,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120607,203,13.300,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,204,11.300,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,205,24,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,207,NULL,'100g',NULL,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,208,247,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,255,NULL,'100g',NULL,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,269,6.700,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,291,2,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,301,193,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,303,1.600,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,306,340,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,307,420,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,320,33.300,'100g',6,3,'2017-01-26','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,328,0,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,401,0,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,539,1,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,601,26.700,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,605,0,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120607,606,4.700,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120608,203,14.300,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,204,10.900,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,205,23.800,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,207,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,208,245,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,255,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,269,6.100,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,291,2,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,301,300,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,303,1.400,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,306,295,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,307,333,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,320,63.300,'100g',6,3,'2017-01-26','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,328,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,401,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,601,23.800,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,605,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120608,606,4.800,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,203,14.300,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,204,11.600,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,205,22.400,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,207,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,208,245,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,255,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,269,6.100,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,291,2,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,301,252,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,303,1.5,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,306,306,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,307,395,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,320,74.800,'100g',6,3,'2017-01-26','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,328,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,401,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,601,30.600,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,605,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120609,606,4.800,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120612,203,13.200,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,204,12.300,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,205,29.800,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,207,NULL,'100g',NULL,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,208,281,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,255,NULL,'100g',NULL,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,269,0.880,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,291,3.5,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,301,206,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,303,0.880,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,306,257,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,307,482,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,328,0,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,401,NULL,'100g',NULL,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,539,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,601,22,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,605,0,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120612,606,3.950,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120617,203,6.25,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,204,9.380,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,205,67.200,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,207,NULL,'100g',NULL,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,208,375,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,255,NULL,'100g',NULL,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,269,26.600,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,291,3.100,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,301,28,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,303,1.560,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,306,161,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,307,172,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,328,0,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,401,NULL,'100g',NULL,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,539,20.300,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,601,16,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,605,0,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120617,606,3.910,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,203,6.25,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,204,9.380,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,205,67.200,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,207,NULL,'100g',NULL,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,208,375,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,255,NULL,'100g',NULL,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,269,26.600,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,291,3.100,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,301,28,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,303,1.560,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,306,159,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,307,133,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,328,0,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,401,NULL,'100g',NULL,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,539,20.300,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,601,16,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,605,0,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120618,606,3.910,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120620,203,13.100,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,204,11.700,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,205,23.400,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,207,NULL,'100g',NULL,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,208,241,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,255,NULL,'100g',NULL,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,269,4.800,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,291,2.100,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,301,269,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,303,1.400,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,306,324,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,307,324,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,320,62.100,'100g',6,3,'2017-01-30','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,328,0,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,401,0,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,539,1,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,601,31,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,605,0,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120620,606,5.5,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,203,13.100,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,204,11.700,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,205,23.400,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,207,NULL,'100g',NULL,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,208,241,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,255,NULL,'100g',NULL,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,269,4.800,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,291,2.100,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,301,228,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,303,1.5,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,306,345,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,307,393,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,320,69.000,'100g',6,3,'2017-01-30','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,328,0,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,401,0,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,539,1,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,601,31,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,605,0,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120622,606,5.5,'100g',6,3,'2017-05-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (120668,203,9.520,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,204,16.700,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,205,66.700,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,207,NULL,'100g',NULL,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,208,476,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,255,NULL,'100g',NULL,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,269,0,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,291,4.800,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,301,95,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,303,3.330,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,306,286,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,307,810,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,328,0,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,401,NULL,'100g',NULL,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,601,0,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,605,0,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120668,606,2.380,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120765,203,3.510,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,204,7.890,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,205,49.100,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,207,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,208,263.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,255,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,269,28.100,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,291,3.500,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,301,35.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,303,3.160,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,306,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,307,281.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,328,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,401,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,601,0.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,605,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120765,606,2.630,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,203,1.75,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,204,5.260,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,205,31.600,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,207,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,208,175,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,255,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,269,17.5,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,291,1.800,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,301,35,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,303,1.890,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,306,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,307,184,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,328,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,401,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,601,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,605,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120766,606,1.75,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,203,12.300,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,204,9.090,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,205,25.300,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,207,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,208,227,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,255,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,269,2.600,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,291,2.600,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,301,162,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,303,1.170,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,306,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,307,370,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,328,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,401,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,601,32,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,605,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120767,606,4.550,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120768,203,12.300,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,204,9.090,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,205,25.300,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,207,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,208,227,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,255,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,269,2.600,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,291,2.600,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,301,162,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,303,1.170,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,306,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,307,370,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,328,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,401,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,539,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,601,32,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,605,0,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120768,606,4.550,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120769,203,4.880,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,204,11,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,205,39,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,207,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,208,305,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,255,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,269,23.200,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,291,2.400,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,301,49,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,303,1.320,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,306,85,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,307,305,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,328,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,401,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,539,12.200,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,601,43,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,605,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120769,606,1.220,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120771,203,4.650,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,204,14.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,205,62.800,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,207,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,208,372.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,255,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,269,34.900,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,291,2.300,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,301,0.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,303,2.510,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,306,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,307,209.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,328,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,401,2.800,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,601,23.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,605,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120771,606,4.650,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120772,203,4.650,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,204,14,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,205,62.800,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,207,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,208,372,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,255,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,269,34.900,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,291,2.300,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,301,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,303,2.510,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,306,163,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,307,209,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,328,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,401,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,539,14,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,601,23,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,605,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120772,606,3.490,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,203,5.880,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,204,13.200,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,205,64.700,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,207,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,208,382,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,255,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,269,32.400,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,291,2.900,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,301,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,303,3.180,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,306,97,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,307,294,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,328,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,401,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,539,17.600,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,601,29,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,605,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120783,606,2.940,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120785,203,4.650,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,204,14,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,205,62.800,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,207,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,208,372,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,255,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,269,34.900,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,291,2.300,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,301,0,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,303,2.510,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,306,160,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,307,209,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,328,0,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,401,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,539,14,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,601,23,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,605,0,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120785,606,3.490,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120786,203,5.770,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,204,13.5,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,205,61.5,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,207,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,208,385,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,255,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,269,34.600,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,291,3.800,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,301,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,303,2.080,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,306,135,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,307,212,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,328,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,401,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,539,15.400,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,601,29,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,605,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120786,606,3.850,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120790,203,4.650,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,204,14,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,205,60.5,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,207,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,208,372,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,255,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,269,25.600,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,291,2.300,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,301,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,303,1.670,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,306,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,307,326,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,328,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,401,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,601,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,605,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120790,606,2.330,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,203,4.650,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,204,14,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,205,60.5,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,207,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,208,372,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,255,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,269,27.900,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,291,2.300,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,301,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,303,1.670,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,306,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,307,326,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,328,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,401,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,601,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,605,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120792,606,2.330,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,203,12.200,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,204,8.330,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,205,25.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,207,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,208,218.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,255,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,269,2.560,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,291,2.600,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,301,160.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,303,1.150,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,306,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,307,378.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,328,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,401,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,601,32.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,605,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120803,606,4.490,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,203,5.880,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,204,13.200,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,205,64.700,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,207,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,208,382.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,255,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,269,32.400,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,291,2.900,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,301,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,303,1.060,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,306,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,307,294.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,328,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,401,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,601,29.000,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,605,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120804,606,2.940,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120805,203,5.880,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,204,13.200,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,205,64.700,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,207,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,208,382,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,255,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,269,32.400,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,291,2.900,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,301,0,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,303,1.060,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,306,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,307,294,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,328,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,401,0,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,539,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,601,29,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,605,0,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120805,606,2.940,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120806,203,5.880,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,204,13.200,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,205,64.700,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,207,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,208,382,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,255,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,269,32.400,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,291,2.900,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,301,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,303,1.060,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,306,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,307,294,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,328,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,401,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,601,29,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,605,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120806,606,2.940,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,203,5.880,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,204,13.200,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,205,64.700,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,207,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,208,382,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,255,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,269,32.400,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,291,2.900,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,301,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,303,1.060,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,306,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,307,294,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,328,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,401,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,601,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,605,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120807,606,2.940,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120808,203,5.880,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,204,13.200,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,205,64.700,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,207,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,208,382,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,255,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,269,32.400,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,291,2.900,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,301,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,303,3.180,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,306,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,307,294,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,328,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,401,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,539,17.600,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,601,29,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,605,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120808,606,2.940,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,203,5.880,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,204,13.200,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,205,64.700,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,207,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,208,382,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,255,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,269,32.400,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,291,2.900,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,301,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,303,3.180,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,306,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,307,294,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,328,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,401,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,539,17.600,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,601,29,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,605,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120809,606,2.940,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120810,203,5.880,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,204,13.200,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,205,64.700,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,207,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,208,382,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,255,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,269,32.400,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,291,2.900,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,301,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,303,1.060,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,306,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,307,294,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,328,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,401,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,601,29,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,605,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120810,606,2.940,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,203,5.880,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,204,13.200,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,205,64.700,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,207,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,208,382,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,255,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,269,32.400,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,291,2.900,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,301,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,303,1.060,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,306,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,307,294,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,328,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,401,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,601,29,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,605,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120811,606,2.940,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120813,203,4.440,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,204,7.780,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,205,46.700,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,207,NULL,'100g',NULL,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,208,267.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,255,NULL,'100g',NULL,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,269,18.900,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,291,2.200,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,301,22.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,303,2.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,306,78.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,307,244.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,328,0.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,401,NULL,'100g',NULL,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,539,17.800,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,601,28.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,605,0,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120813,606,0.560,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,203,4.400,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,204,9.890,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,205,45,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,207,NULL,'100g',NULL,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,208,286,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,255,NULL,'100g',NULL,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,269,22,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,291,2.200,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,301,22,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,303,2.970,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,306,154.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,307,275.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,328,0.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,401,NULL,'100g',NULL,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,539,13.200,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,601,22,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,605,0,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120814,606,2.200,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,203,4.440,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,204,8.890,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,205,47.800,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,207,NULL,'100g',NULL,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,208,289.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,255,NULL,'100g',NULL,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,269,21.100,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,291,2.200,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,301,22,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,303,2.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,306,78.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,307,333.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,328,0.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,401,NULL,'100g',NULL,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,539,16.700,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,601,22,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,605,0,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120815,606,2.220,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,203,4.710,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,204,8.240,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,205,45.900,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,207,NULL,'100g',NULL,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,208,271.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,255,NULL,'100g',NULL,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,269,18.800,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,291,2.400,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,301,31.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,303,2.120,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,306,111.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,307,235,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,328,0.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,401,NULL,'100g',NULL,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,539,15.300,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,601,24.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,605,0,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120818,606,1.180,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (120819,203,3.920,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,204,7.840,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,205,45.100,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,207,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,208,275,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,255,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,269,19.600,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,291,3.900,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,301,0,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,303,2.120,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,306,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,307,275,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,328,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,401,0,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,539,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,601,29,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,605,0,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120819,606,0.980,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120820,203,7.140,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,204,10,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,205,42.900,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,207,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,208,271,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,255,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,269,12.900,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,291,2.900,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,301,57,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,303,2.570,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,306,100,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,307,371,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,328,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,401,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,539,11.400,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,601,29,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,605,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120820,606,2.140,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120821,203,5.050,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,204,10.100,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,205,44.400,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,207,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,208,283,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,255,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,269,19.200,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,291,4,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,301,20,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,303,1.820,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,306,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,307,253,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,328,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,401,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,601,25,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,605,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120821,606,2.020,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120831,203,5,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,204,8.75,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,205,47.5,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,207,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,208,275,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,255,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,269,15,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,291,2.5,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,301,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,303,2.700,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,306,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,307,238,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,328,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,401,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,539,12.5,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,601,25,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,605,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120831,606,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,203,3.920,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,204,8.820,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,205,47.100,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,207,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,208,275,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,255,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,269,15.700,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,291,2,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,301,39,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,303,2.120,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,306,137,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,307,235,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,328,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,401,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,539,13.700,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,601,20,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,605,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120832,606,0.980,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120837,203,4.400,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,204,7.690,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,205,46.200,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,207,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,208,264,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,255,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,269,18.700,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,291,2.200,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,301,22,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,303,1.980,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,306,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,307,231,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,328,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,401,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,601,27,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,605,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120837,606,0.550,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120838,203,4.650,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,204,14,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,205,62.800,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,207,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,208,372,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,255,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,269,34.900,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,291,2.300,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,301,0,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,303,2.510,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,306,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,307,209,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,328,NULL,'100g',NULL,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,401,2.800,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,539,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,601,23,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,605,0,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120838,606,4.650,'100g',6,3,'2017-05-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (120839,203,4.230,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,204,9.860,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,205,47.900,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,207,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,208,282,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,255,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,269,21.100,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,291,2.800,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,301,28,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,303,1.520,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,306,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,307,324,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,328,NULL,'100g',NULL,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,401,1.700,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,601,21,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,605,0,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120839,606,2.110,'100g',6,3,'2017-05-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (120858,203,4.900,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,204,10.800,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,205,45.100,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,207,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,208,294,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,255,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,269,21.600,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,291,2,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,301,59,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,303,1.760,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,306,137,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,307,167,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,328,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,401,NULL,'100g',NULL,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,539,6.900,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,601,29,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,605,0,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120858,606,0.980,'100g',6,3,'2017-05-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (120869,203,0.830,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,204,0.000,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,205,2.5,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,207,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,208,12,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,255,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,269,0.830,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,291,0.800,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,301,22,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,303,0.830,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,306,52,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,307,100,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,328,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,401,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,601,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,605,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120869,606,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,203,2.400,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,204,0.000,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,205,8.800,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,207,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,208,48,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,255,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,269,4,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,291,2.400,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,301,13.600,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,303,0.800,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,306,106,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,307,104,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,328,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,401,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,539,1.600,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,601,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,605,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120873,606,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,203,0.800,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,204,0.400,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,205,7.200,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,207,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,208,48,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,255,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,269,1.600,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,291,0.800,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,301,10,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,303,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,306,100,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,307,8,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,328,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,401,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,601,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,605,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120876,606,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,203,6.150,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,204,1.150,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,205,17.700,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,207,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,208,108,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,255,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,269,0.770,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,291,4.600,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,301,38,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,303,1.540,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,306,408,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,307,108,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,328,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,401,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,601,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,605,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120884,606,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,203,6.150,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,204,1.150,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,205,18.5,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,207,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,208,108,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,255,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,269,0.769,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,291,4.620,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,301,3.850,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,303,1.540,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,306,415,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,307,108,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,328,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,401,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,601,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,605,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120885,606,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (120909,203,13.300,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,204,13.300,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,205,1.670,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,207,NULL,'100g',NULL,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,208,183,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,255,NULL,'100g',NULL,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,269,0,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,291,0,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,301,160,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,303,1.670,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,306,130,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,307,383,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,328,2,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,401,NULL,'100g',NULL,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,601,275,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,605,0,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120909,606,5.830,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,203,8.570,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,204,10.000,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,205,0,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,207,NULL,'100g',NULL,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,208,143,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,255,NULL,'100g',NULL,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,269,0,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,291,0,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,301,60,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,303,1.030,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,306,129,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,307,357,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,328,3,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,401,NULL,'100g',NULL,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,601,286,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,605,0,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120916,606,2.860,'100g',6,3,'2017-05-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (120931,203,12,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,204,7.000,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,205,26,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,207,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,208,210,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,255,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,269,13,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,291,1,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,301,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,303,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,306,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,307,420,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,328,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,401,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,539,13,'100g',6,3,'2022-04-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,601,50,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,605,0,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120931,606,1.5,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120932,203,10.800,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,204,6.330,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,205,22.600,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,207,NULL,'100g',NULL,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,208,190,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,255,NULL,'100g',NULL,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,269,11.800,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,291,0.900,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,301,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,303,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,306,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,307,416,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,328,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,401,NULL,'100g',NULL,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,539,11.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,601,41,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,605,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120932,606,0.900,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (120933,203,11,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,204,6.000,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,205,26,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,207,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,208,210,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,255,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,269,14,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,291,1,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,301,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,303,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,306,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,307,370,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,328,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,401,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,539,13,'100g',6,3,'2022-04-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,601,45,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,605,0,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120933,606,1,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,203,12,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,204,6.000,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,205,25,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,207,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,208,200,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,255,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,269,11,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,291,2,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,301,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,303,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,306,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,307,490,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,328,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,401,NULL,'100g',NULL,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,539,10,'100g',6,3,'2022-04-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,601,45,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,605,0,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120935,606,1,'100g',6,3,'2017-05-01','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (120942,203,18.800,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,204,4.120,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,205,3.530,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,207,NULL,'100g',NULL,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,208,118,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,255,NULL,'100g',NULL,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,269,0,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,291,0,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,301,0,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,303,NULL,'100g',NULL,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,306,NULL,'100g',NULL,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,307,447,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,328,NULL,'100g',NULL,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,401,NULL,'100g',NULL,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,539,NULL,'100g',NULL,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,601,53,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,605,0,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (120942,606,1.180,'100g',6,3,'2017-05-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121018,203,15,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,204,7.960,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,205,17.700,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,207,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,208,204,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,255,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,269,0.880,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,291,1.800,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,301,19,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,303,1.770,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,306,293,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,307,319,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,328,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,401,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,539,0,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,601,35,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,605,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121018,606,0.880,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,203,14.200,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,204,8.850,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,205,16.800,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,207,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,208,204,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,255,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,269,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,291,1.800,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,301,9,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,303,1.330,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,306,283,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,307,301,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,328,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,401,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,539,0,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,601,40,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,605,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121019,606,0.880,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,203,13.700,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,204,8.820,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,205,13.700,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,207,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,208,186,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,255,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,269,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,291,2,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,301,10,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,303,1.080,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,306,275,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,307,275,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,328,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,401,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,539,0,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,601,39,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,605,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121020,606,0.980,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,203,12.5,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,204,8.590,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,205,19.5,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,207,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,208,203,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,255,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,269,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,291,1.600,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,301,14,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,303,0.780,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,306,383,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,307,430,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,328,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,401,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,539,0,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,601,35,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,605,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121021,606,0.780,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,203,14.200,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,204,9.730,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,205,16.800,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,207,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,208,204,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,255,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,269,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,291,1.800,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,301,18.000,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,303,1.150,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,306,274.000,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,307,434,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,320,48.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,328,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,401,2.100,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,539,0,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,601,40,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,605,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121022,606,0.880,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,203,14.200,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,204,8.850,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,205,17.700,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,207,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,208,204,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,255,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,269,0.880,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,291,1.800,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,301,15,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,303,1.770,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,306,281,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,307,319,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,328,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,401,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,539,0,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,601,40,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,605,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121023,606,0.880,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121024,203,13.400,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,204,9.370,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,205,14.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,207,NULL,'100g',NULL,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,208,192.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,255,NULL,'100g',NULL,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,269,0.140,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,291,1.740,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,301,14.700,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,303,0.850,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,306,273.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,307,379.000,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,328,0.130,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,401,0,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,539,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,601,39.400,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,605,0,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121024,606,1.010,'100g',6,3,'2017-05-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121034,203,14.100,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,204,9.410,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,205,17.600,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,207,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,208,200,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,255,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,269,1.180,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,291,2.400,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,301,12,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,303,1.410,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,306,282,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,307,318,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,328,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,401,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,539,0,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,601,41,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,605,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121034,606,0.590,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,203,14.700,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,204,8.820,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,205,14.700,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,207,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,208,196,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,255,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,269,0.980,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,291,2,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,301,10,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,303,1.180,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,306,294,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,307,294,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,328,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,401,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,539,0,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,601,44,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,605,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121035,606,0.980,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121036,203,15,'100g',6,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,204,11.5,'100g',6,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,205,16.800,'100g',6,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,207,NULL,'100g',NULL,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,208,230,'100g',6,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,255,NULL,'100g',NULL,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,269,0,'100g',6,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,291,1.800,'100g',6,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,301,73,'100g',6,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,303,0.880,'100g',6,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,306,265,'100g',6,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,307,717,'100g',6,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,320,NULL,'100g',NULL,3,'2024-12-12','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,328,0,'100g',6,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,401,0,'100g',6,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,539,0,'100g',6,3,'2022-04-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,601,44,'100g',6,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,605,0,'100g',6,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121036,606,2.650,'100g',6,3,'2017-05-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (121037,203,14.700,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,204,8.820,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,205,14.700,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,207,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,208,196,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,255,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,269,0.980,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,291,2,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,301,10,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,303,1.180,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,306,294,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,307,294,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,320,0.000,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,328,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,401,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,539,0,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,601,44,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,605,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121037,606,0.980,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,203,14.200,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,204,8.850,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,205,15.900,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,207,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,208,195,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,255,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,269,0.880,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,291,1.800,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,301,18,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,303,1.240,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,306,292,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,307,292,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,328,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,401,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,539,0,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,601,40,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,605,0,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121038,606,0.880,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121039,203,14.200,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,204,8.850,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,205,17.700,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,207,NULL,'100g',NULL,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,208,204,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,255,NULL,'100g',NULL,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,269,0.880,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,291,1.800,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,301,18,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,303,1.420,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,306,283,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,307,319,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,328,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,401,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,601,40,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,605,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121039,606,0.880,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,203,14.200,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,204,9.730,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,205,15.900,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,207,NULL,'100g',NULL,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,208,204,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,255,NULL,'100g',NULL,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,269,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,291,1.800,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,301,27,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,303,0.970,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,306,283,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,307,434,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,328,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,401,NULL,'100g',NULL,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,601,40,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,605,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121040,606,0.880,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,203,14.700,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,204,8.820,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,205,14.700,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,207,NULL,'100g',NULL,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,208,196,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,255,NULL,'100g',NULL,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,269,0.980,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,291,2,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,301,10,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,303,1.180,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,306,294,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,307,294,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,328,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,401,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,601,44,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,605,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121041,606,0.980,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121042,203,14.200,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,204,8.850,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,205,17.700,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,207,NULL,'100g',NULL,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,208,204,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,255,NULL,'100g',NULL,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,269,0.880,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,291,1.800,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,301,18,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,303,1.330,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,306,283,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,307,345,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,320,0.000,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,328,0.000,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,401,0,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,539,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,601,31,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,605,0,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121042,606,0.880,'100g',6,3,'2017-05-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121043,203,14.700,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,204,8.820,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,205,14.700,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,207,NULL,'100g',NULL,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,208,196,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,255,NULL,'100g',NULL,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,269,0.980,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,291,2,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,301,20,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,303,1.080,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,306,294,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,307,324,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,328,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,401,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,601,34,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,605,0,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121043,606,0.490,'100g',6,3,'2017-05-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121044,203,13.300,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,204,9.730,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,205,18.600,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,207,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,208,212.000,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,255,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,269,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,291,1.800,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,301,18,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,303,0.800,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,306,398.000,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,307,257.000,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,328,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,401,NULL,'100g',NULL,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,601,40,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,605,0,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121044,606,1.770,'100g',6,3,'2017-05-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121045,203,14.000,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,204,9.800,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,205,15.000,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,207,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,208,201.000,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,255,NULL,'100g',NULL,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,269,0.350,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,291,1.300,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,301,13.800,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,303,0.680,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,306,384.000,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,307,242.000,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,328,0.180,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,401,1.200,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,539,0.120,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,601,43.600,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,605,0.060,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121045,606,1.540,'100g',6,3,'2017-05-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121111,203,8.060,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,204,8.060,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,205,43.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,208,274,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,269,6.450,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,291,3.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,301,144,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,303,1.610,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,306,484.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,307,403,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,539,4.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121111,606,5.650,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,203,5.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,204,8.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,205,45.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,208,281,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,269,24.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,301,25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,303,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,306,96,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,307,167,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,539,22.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,601,35,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121114,606,0.880,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,203,5.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,204,7.020,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,205,49.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,208,281,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,269,26.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,301,25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,303,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,306,114,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,307,175,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,539,24.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,601,35,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121115,606,0.880,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,203,5.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,204,8.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,205,47.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,208,281,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,269,22.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,301,25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,303,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,306,96,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,307,175,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,539,21.100,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,601,44,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121116,606,0.880,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,203,5.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,204,8.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,205,50.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,208,298,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,269,26.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,301,26,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,303,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,306,105,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,307,175,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,539,26.300,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,601,35,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121117,606,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121120,203,4.900,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,204,7.840,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,205,47.100,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,207,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,208,275,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,255,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,269,23.5,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,291,2,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,301,25,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,303,1.960,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,306,103,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,307,157,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,328,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,401,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,539,22.5,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,601,29,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,605,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121120,606,0.980,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121121,203,3.920,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,204,6.860,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,205,49,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,208,275,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,269,25.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,291,2,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,301,25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,303,1.960,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,306,108,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,307,176,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,539,23.5,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,601,29,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121121,606,0.980,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121122,203,3.920,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,204,9.800,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,205,51,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,207,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,208,294,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,255,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,269,27.400,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,291,2,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,301,25,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,303,1.960,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,306,108,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,307,176,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,328,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,401,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,539,27.5,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,601,29,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,605,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121122,606,1.960,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121124,203,7.840,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,204,11.800,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,205,39.200,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,207,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,208,294.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,255,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,269,13.700,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,291,2,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,301,49.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,303,1.960,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,306,127.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,307,265.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,328,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,401,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,539,13.700,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,601,69.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,605,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121124,606,1.960,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121128,203,4.710,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,204,9.410,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,205,45.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,208,282,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,269,17.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,291,2.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,301,41,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,303,1.180,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,306,88,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,307,176,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,539,17.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,601,29,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121128,606,1.180,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,203,5.880,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,204,9.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,205,45.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,208,294,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,269,17.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,291,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,301,41,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,303,1.960,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,306,88,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,307,176,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,539,17.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,601,29,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121129,606,0.980,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,203,4.420,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,204,7.960,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,205,46,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,208,274,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,269,23.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,301,24,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,303,1.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,306,93,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,307,168,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,539,23,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,601,31,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121136,606,0.880,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,203,5.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,204,12.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,205,47.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,208,316,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,269,21,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,301,37,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,303,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,306,114,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,307,316,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,539,21.100,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,601,53,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121137,606,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,203,5.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,204,10.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,205,50.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,208,316,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,269,26.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,301,37.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,303,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,306,70,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,307,158,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,539,26.300,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,601,26,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121138,606,0.880,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,203,4.420,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,204,7.080,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,205,49.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,208,274,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,269,25.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,301,25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,303,1.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,306,111,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,307,177,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,539,23.900,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,601,32.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121139,606,0.880,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121140,203,6.190,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,204,9.730,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,205,47.800,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,207,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,208,292,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,255,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,269,23,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,291,1.800,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,301,30,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,303,2.650,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,306,221,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,307,150,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,328,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,401,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,539,22.100,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,601,44,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,605,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121140,606,2.210,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121141,203,4.420,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,204,8.850,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,205,46.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,208,274,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,269,23,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,301,26,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,303,1.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,306,97,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,307,177,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,539,22.100,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,601,44,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121141,606,1.330,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,203,3.510,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,204,12.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,205,52.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,208,333,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,269,28.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,301,47,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,303,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,306,105,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,307,281,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,539,28.100,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,601,18,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121144,606,2.630,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121147,203,5.260,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,204,2.630,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,205,49.100,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,207,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,208,228,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,255,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,269,26.300,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,291,1.800,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,301,23,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,303,1.75,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,306,79,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,307,404,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,320,NULL,'100g',NULL,3,'2024-12-12','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,328,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,401,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,539,24.600,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,601,0,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,605,0,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121147,606,0.700,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121152,203,5.310,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,204,8.850,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,205,50.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,208,292,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,269,25.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,301,26,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,303,1.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,306,93,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,307,177,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,539,25.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,601,35,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121152,606,0.880,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,203,5.310,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,204,9.730,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,205,50.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,208,301,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,269,26.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,301,26,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,303,1.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,306,111,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,307,177,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,539,26.5,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,601,31,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121153,606,1.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,203,6.450,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,204,9.680,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,205,48.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,208,306,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,269,19.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,291,1.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,301,142,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,303,1.610,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,306,40,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,307,468,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,539,17.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,601,32,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121154,606,0.810,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121155,203,7.020,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,204,1.75,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,205,43.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,208,228,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,269,1.75,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,291,3.5,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,301,70,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,303,2.630,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,306,140,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,307,333,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,401,17.5,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121155,606,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121156,203,5.260,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,204,10.5,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,205,47.400,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,207,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,208,298,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,255,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,269,24.600,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,291,1.800,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,301,53,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,303,3.510,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,306,211,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,307,193,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,328,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,401,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,539,24.600,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,601,53,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,605,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121156,606,2.630,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121157,203,10.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,204,4.390,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,205,56.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,208,298,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,269,8.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,291,5.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,301,230,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,303,3.510,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,306,175.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,307,509,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,539,8.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121157,606,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,203,5.410,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,204,8.110,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,205,32.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,208,243,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,269,5.410,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,291,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,301,81,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,303,1.890,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,306,135,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,307,297,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,539,2.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,601,14,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121158,606,1.350,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121159,203,5.260,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,204,3.950,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,205,42.100,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,207,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,208,237,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,255,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,269,13.200,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,291,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,301,103,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,303,1.840,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,306,105.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,307,250,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,328,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,401,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,539,10.5,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,601,13,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,605,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121159,606,1.050,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121161,203,5.410,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,204,8.110,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,205,32.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,208,216,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,269,5.410,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,291,2.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,301,172,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,303,2,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,306,108.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,307,311,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,539,2.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,601,14,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121161,606,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121162,203,2.700,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,204,8.110,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,205,21.600,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,208,162,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,269,5.410,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,291,2.700,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,301,108,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,303,1.220,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,306,108,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,307,324,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,539,2.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,601,14,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121162,606,1.350,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121163,203,5.410,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,204,4.050,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,205,40.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,208,216,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,269,13.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,291,2.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,301,99,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,303,1.970,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,306,108.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,307,243,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,539,5.400,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,601,14,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121163,606,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121164,203,5.410,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,204,4.730,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,205,41.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,208,230,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,269,13.5,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,291,2.700,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,301,68,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,303,1.890,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,306,108,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,307,297,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,539,6.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,601,14,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121164,606,0.680,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121165,203,5.410,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,204,4.730,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,205,43.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,208,230,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,269,16.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,291,2.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,301,68,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,303,1.760,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,306,108,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,307,284,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,539,12.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,601,14,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121165,606,0.680,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121168,203,3.570,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,204,12.5,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,205,42.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,208,286,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,269,25,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,291,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,301,32,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,303,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,306,125,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,307,250,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,539,21.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,601,36,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121168,606,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121169,203,3.570,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,204,12.5,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,205,50,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,207,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,208,321,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,255,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,269,28.600,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,291,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,301,32,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,303,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,306,107,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,307,268,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,328,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,401,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,539,25,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,601,36,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,605,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121169,606,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121170,203,5,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,204,7.500,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,205,35,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,207,NULL,'100g',NULL,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,208,225,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,255,NULL,'100g',NULL,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,269,7.5,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,291,2.5,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,301,163,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,303,1.880,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,306,100.000,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,307,288,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,320,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,328,0,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,401,NULL,'100g',NULL,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,539,5,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,601,12,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,605,0,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121170,606,0,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121171,203,5,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,204,7.5,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,205,37.5,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,207,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,208,250,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,255,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,269,10,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,291,2.5,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,301,75,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,303,1.75,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,306,125,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,307,288,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,328,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,401,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,539,10,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,601,12,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,605,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121171,606,1.25,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121174,203,5.060,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,204,7.590,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,205,34.200,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,207,NULL,'100g',NULL,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,208,228,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,255,NULL,'100g',NULL,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,269,8.860,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,291,2.5,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,301,63,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,303,1.770,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,306,114,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,307,380,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,320,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,328,0,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,401,NULL,'100g',NULL,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,539,6.300,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,601,13,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,605,0,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121174,606,1.270,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121175,203,5.410,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,204,8.110,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,205,33.800,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,208,230,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,269,5.410,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,291,2.700,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,301,108,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,303,2.160,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,306,135,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,307,324,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,539,2.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,601,14,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121175,606,1.350,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121176,203,5.410,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,204,4.730,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,205,43.200,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,207,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,208,243,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,255,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,269,16.200,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,291,2.700,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,301,68,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,303,1.760,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,306,108,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,307,297,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,328,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,401,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,539,13.5,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,601,14,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,605,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121176,606,0.680,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121177,203,5,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,204,3.750,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,205,42.5,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,208,225,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,269,15,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,291,2.5,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,301,98,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,303,1.75,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,306,100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,307,238,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,328,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,401,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,539,15,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,601,12,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,605,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121177,606,0.500,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121179,203,5,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,204,7.500,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,205,37.500,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,207,NULL,'100g',NULL,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,208,225,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,255,NULL,'100g',NULL,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,269,10,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,291,2.5,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,301,114,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,303,1.75,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,306,100.000,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,307,250.000,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,320,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,328,0,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,401,NULL,'100g',NULL,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,539,10.000,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,601,12,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,605,0,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121179,606,1.000,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,203,5.060,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,204,7.590,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,205,36.700,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,207,NULL,'100g',NULL,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,208,241.000,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,255,NULL,'100g',NULL,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,269,8.860,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,291,2.5,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,301,127.000,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,303,1.900,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,306,101.000,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,307,253.000,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,320,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,328,0,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,401,NULL,'100g',NULL,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,539,7.600,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,601,6,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,605,0,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121180,606,1.270,'100g',6,3,'2019-03-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (121181,203,4.050,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,204,6.760,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,205,32.400,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,208,216,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,269,8.110,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,291,2.700,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,301,68,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,303,1.760,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,306,108,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,307,257,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,539,6.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,601,7,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121181,606,1.350,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121184,203,8.110,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,204,9.460,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,205,37.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,208,270,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,269,2.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,291,2.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,301,27,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,303,2.970,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,306,351,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,307,338,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121184,606,1.350,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121185,203,8.820,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,204,10.300,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,205,35.300,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,207,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,208,265,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,255,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,269,2.940,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,291,2.900,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,301,29,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,303,2.940,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,306,294.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,307,338.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,328,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,401,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,601,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,605,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121185,606,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121187,203,8.110,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,204,9.460,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,205,37.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,208,270,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,269,2.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,291,2.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,301,27,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,303,3.140,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,306,351,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,307,324,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121187,606,1.350,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121188,203,11.800,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,204,12.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,205,32.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,208,282,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,269,2.350,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,291,2.400,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,301,200,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,303,2.470,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,306,106,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,307,518,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,539,1.200,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,601,18,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121188,606,4.120,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,203,12.300,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,204,17.5,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,205,26.300,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,208,298,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,269,1.75,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,291,1.800,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,301,281,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,303,1.75,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,306,88,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,307,632,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,601,26,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121190,606,6.140,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121194,203,8.820,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,204,7.350,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,205,38.200,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,207,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,208,265,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,255,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,269,2.940,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,291,2.900,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,301,29,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,303,2.940,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,306,324.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,307,294,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,328,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,401,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,601,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,605,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121194,606,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,203,7.140,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,204,8.930,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,205,42.900,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,207,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,208,286.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,255,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,269,1.790,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,291,3.600,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,301,18,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,303,2.320,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,306,375.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,307,268.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,328,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,401,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,601,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,605,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121195,606,1.790,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121196,203,2.940,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,204,8.820,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,205,44.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,208,294,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,269,2.940,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,291,2.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,301,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,303,2.350,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,306,294,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,307,279,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,539,2.900,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121196,606,1.470,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121197,203,7.140,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,204,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,205,42.900,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,208,214,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,269,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,291,3.600,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,301,36.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,303,2.5,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,306,357.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,307,161.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,320,0.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,328,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,401,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,601,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121197,606,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121198,203,7.840,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,204,17.600,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,205,41.200,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,208,333,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,269,1.960,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,291,3.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,301,20,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,303,3.140,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,306,333,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,307,275,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121198,606,2.940,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,203,10.300,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,204,13.200,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,205,45.600,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,208,316,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,269,5.880,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,291,4.400,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,301,147,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,303,2.210,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,306,59,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,307,324,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,539,2.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121199,606,2.940,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,203,10.600,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,204,12.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,205,47.100,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,208,318,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,269,5.880,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,291,4.700,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,301,153,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,303,2.350,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,306,59,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,307,318,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,539,2.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121201,606,2.350,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121203,203,7.690,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,204,12.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,205,48.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,208,333,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,269,18,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,291,3.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,301,51,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,303,1.920,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,306,128,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,307,179,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,539,17.900,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121203,606,5.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,203,6.410,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,204,12.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,205,50,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,208,333,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,269,19.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,291,3.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,301,77,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,303,1.920,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,306,128,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,307,173,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,539,17.900,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121204,606,5.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121209,203,5.630,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,204,21.100,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,205,46.5,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,208,394,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,269,18.300,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,291,1.400,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,301,42,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,303,1.830,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,306,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,307,408,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,401,25.400,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,539,18.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121209,606,9.860,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,203,3.230,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,204,21,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,205,48.400,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,208,387,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,269,22.600,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,291,1.600,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,301,32,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,303,1.450,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,306,16,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,307,419,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,539,22.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,601,8,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121211,606,8.060,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,203,5.880,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,204,21.200,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,205,47.100,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,208,400,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,269,18.800,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,291,1.200,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,301,47,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,303,2.120,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,306,24,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,307,224,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,539,18.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121215,606,9.410,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,203,4.840,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,204,21,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,205,43.600,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,208,387,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,269,19.400,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,291,1.600,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,301,65,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,303,1.770,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,306,32,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,307,468,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,539,19.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121226,606,9.680,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,203,6.980,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,204,11.600,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,205,51.200,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,208,326,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,269,20.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,291,2.300,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,301,47,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,303,1.630,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,306,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,307,221,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,401,46.5,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,539,20.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121228,606,4.650,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,203,5.490,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,204,16.5,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,205,50.600,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,208,363,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,269,22,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,291,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,301,55,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,303,2.970,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,306,220,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,307,560,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,539,22,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,601,38,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121229,606,6.590,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,203,3.300,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,204,16.5,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,205,57.100,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,208,385,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,269,31.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,291,2.200,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,301,44,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,303,1.430,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,306,77,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,307,275,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,539,31.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,601,22,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121235,606,7.690,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121237,203,4.440,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,204,15.600,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,205,57.800,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,207,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,208,378,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,255,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,269,31.100,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,291,2.200,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,301,44,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,303,1.330,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,306,67,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,307,267,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,328,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,401,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,539,31.100,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,601,22,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,605,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121237,606,7.780,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,203,6.670,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,204,20,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,205,38.300,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,207,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,208,367,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,255,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,269,5,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,291,1.700,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,301,83,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,303,2.330,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,306,50,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,307,633,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,328,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,401,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,539,5,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,601,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,605,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121238,606,8.330,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121243,203,7.020,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,204,12.300,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,205,47.400,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,208,316,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,269,15.800,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,291,3.5,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,301,53,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,303,2.460,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,306,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,307,246,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,539,15.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121243,606,5.260,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121247,203,7.060,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,204,12.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,205,47.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,208,329,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,269,14.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,291,3.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,301,47,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,303,2.120,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,306,153,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,307,188,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,539,14.100,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121247,606,5.880,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121248,203,7.670,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,204,9.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,205,43.800,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,208,292.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,269,8.010,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,291,3.600,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,301,88,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,303,1.980,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,306,225,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,307,842,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,328,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,401,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,539,2.600,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,601,3.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,605,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121248,606,4.990,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,203,7.140,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,204,10.700,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,205,46.400,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,208,286,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,269,10.700,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,291,3.600,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,301,82,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,303,3.570,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,306,214.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,307,482,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,328,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,401,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,539,3.600,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,601,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,605,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121250,606,5.360,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121257,203,5.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,204,10.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,205,50.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,208,316,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,269,26.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,301,37,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,303,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,306,70,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,307,158,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,539,26.300,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,601,26,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121257,606,0.880,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,203,5.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,204,8.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,205,49.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,208,298,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,269,26.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,301,25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,303,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,306,96,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,307,175,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,539,24.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,601,35,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121258,606,0.880,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121260,203,4.710,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,204,21.200,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,205,42.400,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,208,376,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,269,16.5,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,291,2.400,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,301,82,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,303,2.120,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,306,35,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,307,412,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,539,16.5,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121260,606,10.600,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,203,5.880,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,204,11.800,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,205,50.600,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,208,329,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,269,21.200,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,291,3.5,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,301,47,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,303,1.760,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,306,24,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,307,224,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,401,28.200,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,539,21.200,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121261,606,5.290,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121265,203,5.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,204,8.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,205,47.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,208,281,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,269,24.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,301,23,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,303,3.510,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,306,219,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,307,88,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,539,24.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,601,53,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121265,606,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,203,5.680,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,204,7.950,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,205,46.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,208,273,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,269,19.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,291,2.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,301,25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,303,1.140,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,306,102,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,307,182,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,539,18.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,601,40,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121266,606,1.140,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,203,5.680,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,204,7.950,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,205,48.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,208,284,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,269,21.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,291,2.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,301,26,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,303,2.270,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,306,114,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,307,170,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,539,20.5,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,601,40,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121267,606,1.140,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,203,5.680,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,204,7.950,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,205,50,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,208,284,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,269,25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,291,2.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,301,26,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,303,2.270,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,306,119,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,307,170,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,539,23.900,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,601,40,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121268,606,1.140,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,203,5.680,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,204,9.090,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,205,51.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,208,307,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,269,25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,291,2.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,301,27,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,303,2.270,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,306,125,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,307,159,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,539,25,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,601,40,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121269,606,1.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,203,4.230,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,204,11.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,205,50.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,208,310,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,269,25.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,291,1.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,301,38,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,303,1.410,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,306,63,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,307,162,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,539,25.400,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,601,28,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121271,606,1.410,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,203,7.140,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,204,14.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,205,53.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,208,393,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,269,14.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,291,7.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,301,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,303,2.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,306,321,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,307,214,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,539,10.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121272,606,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121273,203,7.140,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,204,14.300,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,205,53.600,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,207,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,208,393,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,255,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,269,14.300,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,291,7.100,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,301,21,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,303,3.570,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,306,221,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,307,214,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,328,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,401,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,539,14.300,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,601,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,605,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121273,606,1.790,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121299,203,6.980,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,204,14,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,205,41.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,208,326,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,269,4.650,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,291,4.700,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,301,47,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,303,2.330,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,306,186,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,307,395,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,539,4.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121299,606,4.650,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,203,6.450,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,204,12.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,205,41.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,208,323,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,269,6.450,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,291,1.600,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,301,48,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,303,2.580,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,306,81,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,307,242,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,539,4.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121300,606,3.230,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,203,8.060,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,204,17.700,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,205,43.600,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,208,323,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,269,6.450,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,291,4.800,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,301,48,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,303,2.100,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,306,145,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,307,387,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,539,3.200,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121301,606,8.060,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121304,203,3.510,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,204,0.880,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,205,40.400,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,208,211,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,269,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,291,3.5,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,301,53,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,303,2.630,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,306,351.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,307,149.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,320,0.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,328,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,401,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,601,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,605,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121304,606,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121305,203,6.980,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,204,3.490,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,205,53.5,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,208,279,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,269,2.330,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,291,4.700,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,301,26,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,303,2.330,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,306,188,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,307,512,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,539,2.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121305,606,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121306,203,7.140,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,204,1.790,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,205,46.400,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,207,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,208,214,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,255,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,269,3.570,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,291,3.600,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,301,21,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,303,3.570,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,306,161.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,307,446,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,328,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,401,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,539,3.600,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,601,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,605,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121306,606,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121308,203,7.140,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,204,1.790,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,205,42.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,208,214,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,269,3.570,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,291,7.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,301,14,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,303,3.570,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,306,89.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,307,446,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,539,3.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121308,606,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,203,7.140,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,204,1.790,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,205,42.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,208,214,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,269,3.570,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,291,7.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,301,25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,303,3.570,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,306,196.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,307,446,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,539,3.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121309,606,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121310,203,7.140,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,204,3.570,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,205,42.900,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,207,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,208,214,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,255,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,269,3.570,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,291,7.100,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,301,14.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,303,3.570,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,306,393.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,307,268,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,328,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,401,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,539,3.600,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,601,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,605,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121310,606,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121313,203,5.260,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,204,14,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,205,49.100,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,208,333,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,269,28.100,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,291,1.800,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,301,33,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,303,1.75,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,306,105,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,307,281,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,539,26.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,601,35,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121313,606,1.75,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121315,203,8.820,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,204,2.940,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,205,47.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,208,265,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,269,2.940,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,291,2.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,301,88,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,303,2.940,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,306,176,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,307,471,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,539,2.900,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121315,606,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121319,203,7.020,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,204,2.630,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,205,43.900,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,207,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,208,228.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,255,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,269,5.260,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,291,3.5,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,301,11.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,303,1.75,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,306,70.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,307,439.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,328,0,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,401,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,539,5.300,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,601,0,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,605,0,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121319,606,0,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121321,203,3.920,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,204,4.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,205,52.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,208,294,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,269,7.840,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,291,3.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,301,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,303,2.550,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,306,39,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,307,314,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,539,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,601,10,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121321,606,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121323,203,7.840,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,204,2.940,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,205,47.100,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,207,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,208,255.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,255,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,269,1.960,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,291,3.900,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,301,20,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,303,2.550,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,306,412.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,307,206.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,328,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,401,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,601,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,605,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121323,606,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121324,203,8.450,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,204,1.060,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,205,47.200,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,208,239,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,269,0.700,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,291,1.400,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,301,77,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,303,3.030,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,306,77,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,307,430,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121324,606,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121326,203,8.590,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,204,1.260,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,205,47.5,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,207,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,208,242,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,255,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,269,0.510,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,291,1.5,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,301,76,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,303,3.080,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,306,81,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,307,434,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,328,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,401,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,539,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,601,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,605,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121326,606,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121328,203,3.570,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,204,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,205,42.900,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,208,214,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,269,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,291,3.600,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,301,71,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,303,2.860,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,306,107,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,307,446.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,328,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,401,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,601,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121328,606,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,203,7.060,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,204,2.350,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,205,43.500,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,208,224.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,269,3.530,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,291,3.500,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,301,71,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,303,2.710,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,306,129.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,307,388.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,328,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,401,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,539,2.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,601,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121329,606,0.590,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121333,203,7.060,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,204,1.180,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,205,45.900,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,207,NULL,'100g',NULL,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,208,224,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,255,NULL,'100g',NULL,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,269,1.180,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,291,1.200,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,301,61,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,303,0,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,306,NULL,'100g',NULL,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,307,376,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,328,NULL,'100g',NULL,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,401,5.600,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,539,NULL,'100g',NULL,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,601,0,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,605,0,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121333,606,0,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121334,203,7.840,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,204,0.980,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,205,41.200,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,207,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,208,216,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,255,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,269,1.960,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,291,3.900,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,301,78,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,303,2.350,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,306,118,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,307,373,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,328,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,401,NULL,'100g',NULL,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,601,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,605,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121334,606,0,'100g',6,3,'2019-03-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121335,203,7.060,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,204,1.180,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,205,42.400,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,208,212.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,269,3.530,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,291,3.500,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,301,71.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,303,2.590,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,306,129.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,307,365.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,328,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,401,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,539,2.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,601,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121335,606,0.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121336,203,8.240,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,204,1.180,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,205,45.900,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,207,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,208,224,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,255,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,269,3.530,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,291,4.700,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,301,61,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,303,1.270,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,306,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,307,353,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,320,0.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,328,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,401,7.100,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,539,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,601,0,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,605,0,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121336,606,0,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121337,203,7.610,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,204,0.820,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,205,46.200,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,207,NULL,'100g',NULL,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,208,223,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,255,NULL,'100g',NULL,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,269,1.630,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,291,1.600,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,301,43,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,303,0.200,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,306,NULL,'100g',NULL,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,307,440,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,328,NULL,'100g',NULL,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,401,4.900,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,539,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,601,0,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,605,0,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121337,606,0,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121338,203,7.140,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,204,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,205,42.900,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,208,214,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,269,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,291,3.600,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,301,71,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,303,2.860,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,306,107,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,307,446.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,328,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,401,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,601,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121338,606,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,203,7.020,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,204,0.880,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,205,42.100,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,208,211.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,269,3.510,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,291,1.800,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,301,70,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,303,2.630,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,306,105.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,307,351.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,328,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,401,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,539,1.800,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,601,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121339,606,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,203,7.020,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,204,0.880,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,205,42.100,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,208,211.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,269,1.75,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,291,1.800,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,301,70,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,303,2.630,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,306,105.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,307,439.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,328,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,401,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,539,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,601,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121341,606,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,203,7.020,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,204,0.880,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,205,43.900,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,208,211.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,269,3.510,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,291,3.500,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,301,70,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,303,2.630,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,306,123.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,307,404.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,328,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,401,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,539,1.800,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,601,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121342,606,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121352,203,7.610,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,204,1.090,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,205,46.700,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,207,NULL,'100g',NULL,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,208,223,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,255,NULL,'100g',NULL,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,269,3.260,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,291,3.300,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,301,106,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,303,0.590,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,306,NULL,'100g',NULL,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,307,516,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,328,NULL,'100g',NULL,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,401,9.800,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,539,NULL,'100g',NULL,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,601,0,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,605,0,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121352,606,0,'100g',6,3,'2019-03-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (121353,203,7.060,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,204,1.180,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,205,45.900,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,207,NULL,'100g',NULL,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,208,224,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,255,NULL,'100g',NULL,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,269,1.180,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,291,1.200,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,301,47,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,303,0,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,306,NULL,'100g',NULL,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,307,376,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,328,NULL,'100g',NULL,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,401,5.600,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,539,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,601,0,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,605,0,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121353,606,0,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121356,203,8.770,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,204,2.630,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,205,50.900,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,207,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,208,263,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,255,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,269,5.260,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,291,5.300,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,301,70,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,303,2.630,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,306,175,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,307,491,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,328,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,401,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,539,3.5,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,601,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,605,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121356,606,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121357,203,7.140,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,204,0.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,205,46.400,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,208,214.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,269,7.140,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,291,3.600,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,301,71,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,303,2.500,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,306,107.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,307,357.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,328,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,401,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,539,3.600,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,601,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121357,606,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121359,203,5.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,204,8.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,205,45.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,208,281,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,269,24.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,301,25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,303,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,306,96,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,307,167,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,539,22.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,601,35,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121359,606,0.880,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,203,5.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,204,7.020,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,205,49.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,208,281,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,269,26.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,301,25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,303,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,306,114,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,307,175,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,539,24.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,601,35,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121360,606,0.880,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121361,203,5.260,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,204,8.770,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,205,47.400,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,208,281,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,269,22.800,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,291,1.800,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,301,25,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,303,1.75,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,306,96,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,307,175,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,328,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,401,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,539,21.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,601,44,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,605,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121361,606,0.880,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121362,203,6.980,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,204,2.330,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,205,44.200,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,207,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,208,233,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,255,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,269,2.330,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,291,2.300,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,301,12,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,303,2.330,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,306,70.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,307,419,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,328,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,401,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,539,2.300,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,601,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,605,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121362,606,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121363,203,5.880,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,204,2.940,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,205,43.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,208,216,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,269,1.960,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,291,3.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,301,31,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,303,1.960,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,306,225.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,307,431,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,539,2,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121363,606,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,203,6.380,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,204,8.510,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,205,44.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,208,277,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,269,14.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,291,2.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,301,25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,303,0.740,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,306,59,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,307,309,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,539,14.900,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,601,11,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121364,606,1.060,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121365,203,7.140,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,204,8.330,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,205,45.200,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,208,286,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,269,14.300,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,291,2.400,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,301,25,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,303,0.710,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,306,60,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,307,310,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,328,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,401,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,539,14.300,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,601,12,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,605,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121365,606,1.190,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,203,7.060,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,204,8.240,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,205,44.700,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,208,282,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,269,14.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,291,2.400,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,301,25,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,303,0.710,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,306,59,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,307,306,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,328,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,401,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,539,14.100,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,601,12,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,605,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121366,606,1.180,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121367,203,8.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,204,3.510,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,205,49.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,208,263,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,269,7.020,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,291,3.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,301,204,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,303,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,306,149.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,307,456,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,539,7,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121367,606,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121368,203,6.380,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,204,14.900,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,205,35.100,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,207,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,208,319.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,255,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,269,10.600,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,291,4.300,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,301,53.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,303,1.810,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,306,128.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,307,191.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,328,0,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,401,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,539,10.600,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,601,11,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,605,0,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121368,606,2.130,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121369,203,12.100,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,204,11.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,205,29.700,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,207,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,208,253.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,255,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,269,5.490,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,291,2.200,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,301,143,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,303,1.100,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,306,429,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,307,473,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,328,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,401,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,539,4.400,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,601,22,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,605,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121369,606,5.490,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121370,203,7.140,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,204,14.300,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,205,35.700,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,207,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,208,310.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,255,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,269,9.520,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,291,4.800,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,301,48.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,303,1.900,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,306,119.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,307,190.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,328,0,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,401,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,539,9.500,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,601,12,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,605,0,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121370,606,2.380,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,203,5.880,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,204,15.300,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,205,35.300,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,207,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,208,318.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,255,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,269,10.600,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,291,3.500,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,301,59.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,303,1.760,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,306,129.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,307,188.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,328,0,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,401,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,539,10.600,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,601,6.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,605,0,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121371,606,2.350,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121372,203,12.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,204,11.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,205,21,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,208,226,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,269,4.840,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,291,1.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,301,48,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,303,1.610,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,306,210,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,307,468,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,539,1.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,601,32,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121372,606,4.030,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,203,6.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,204,2.590,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,205,44.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,208,224.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,269,3.450,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,291,5.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,301,19,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,303,3.450,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,306,69.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,307,431.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,539,1.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121378,606,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121382,203,7.020,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,204,2.630,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,205,45.600,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,207,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,208,228,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,255,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,269,3.510,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,291,5.300,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,301,19,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,303,3.510,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,306,70.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,307,439,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,328,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,401,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,539,1.800,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,601,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,605,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121382,606,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121388,203,5.880,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,204,1.960,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,205,45.100,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,207,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,208,235,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,255,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,269,1.960,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,291,2,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,301,10,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,303,1.960,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,306,78.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,307,412,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,328,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,401,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,539,2,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,601,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,605,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121388,606,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121390,203,5.880,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,204,1.960,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,205,39.200,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,207,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,208,196.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,255,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,269,3.920,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,291,3.900,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,301,10.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,303,1.960,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,306,59.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,307,373.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,328,0,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,401,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,539,3.900,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,601,0,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,605,0,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121390,606,0,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121392,203,9.300,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,204,3.490,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,205,46.500,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,207,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,208,256.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,255,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,269,2.330,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,291,4.700,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,301,14.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,303,2.330,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,306,372.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,307,186.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,328,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,401,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,601,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,605,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121392,606,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,203,3.570,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,204,3.570,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,205,46.400,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,207,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,208,250.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,255,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,269,3.570,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,291,3.600,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,301,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,303,2.500,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,306,286.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,307,214.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,328,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,401,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,601,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,605,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121393,606,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121394,203,9.680,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,204,3.230,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,205,48.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,208,258,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,269,3.230,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,291,3.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,301,194,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,303,2.580,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,306,161,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,307,484,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,328,1,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,539,3.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121394,606,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121395,203,6.450,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,204,12.900,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,205,77.400,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,207,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,208,419,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,255,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,269,29,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,291,3.200,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,301,13,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,303,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,306,161.000,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,307,306,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,328,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,401,NULL,'100g',NULL,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,539,29,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,601,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,605,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121395,606,0,'100g',6,3,'2019-03-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121396,203,6.450,'100g',6,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,204,12.900,'100g',6,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,205,77.400,'100g',6,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,207,NULL,'100g',NULL,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,208,419,'100g',6,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,255,NULL,'100g',NULL,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,269,29,'100g',6,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,291,3.200,'100g',6,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,301,13,'100g',6,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,303,0,'100g',6,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,306,161,'100g',6,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,307,306,'100g',6,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,320,NULL,'100g',NULL,3,'2024-12-12','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,328,0,'100g',6,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,401,NULL,'100g',NULL,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,539,29,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,601,0,'100g',6,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,605,0,'100g',6,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121396,606,0,'100g',6,3,'2019-03-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121398,203,7.840,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,204,1.960,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,205,45.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,208,216,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,269,1.960,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,291,3.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,301,18,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,303,1.960,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,306,69.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,307,431,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,539,2,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121398,606,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121401,203,13,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,204,2.170,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,205,73.900,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,207,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,208,348,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,255,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,269,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,291,13,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,301,39,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,303,4.350,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,306,400,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,307,1000,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,328,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,401,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,539,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,601,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,605,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121401,606,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121407,203,7.590,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,204,1.270,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,205,46.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,208,241,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,269,6.330,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,291,3.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,301,63,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,303,2.280,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,306,127,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,307,456,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,539,3.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121407,606,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121408,203,8.240,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,204,1.180,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,205,48.200,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,207,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,208,247,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,255,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,269,5.880,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,291,4.700,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,301,71,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,303,2.940,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,306,165,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,307,471,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,328,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,401,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,539,1.200,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,601,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,605,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121408,606,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121412,203,13,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,204,6.520,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,205,25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,208,207,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,269,2.170,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,291,1.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,301,207,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,303,1.740,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,306,163,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,307,522,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,601,71,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121412,606,2.170,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,203,11,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,204,9.890,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,205,31.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,208,242,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,269,2.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,291,2.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,301,44,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,303,2.090,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,306,231,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,307,714,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,539,1.100,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,601,16,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121413,606,3.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121414,203,11.600,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,204,10.900,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,205,19.700,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,207,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,208,190,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,255,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,269,3.400,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,291,2,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,301,156,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,303,1.220,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,306,211,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,307,456,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,320,NULL,'100g',NULL,3,'2024-12-12','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,328,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,401,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,539,1.400,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,601,14,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,605,0,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121414,606,4.760,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121415,203,13.400,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,204,8.960,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,205,26.900,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,207,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,208,239,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,255,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,269,2.990,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,291,1.5,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,301,194,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,303,1.490,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,306,239,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,307,552,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,328,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,401,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,539,1.5,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,601,97,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,605,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121415,606,2.990,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,203,12.700,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,204,10.600,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,205,23.200,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,207,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,208,232,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,255,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,269,4.230,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,291,2.100,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,301,146,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,303,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,306,143,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,307,817,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,328,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,401,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,539,0,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,601,39,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,605,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121416,606,3.870,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121417,203,14.800,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,204,6.25,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,205,23.400,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,207,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,208,219,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,255,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,269,3.910,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,291,1.600,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,301,250,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,303,1.170,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,306,305,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,307,562,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,320,NULL,'100g',NULL,3,'2024-12-12','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,328,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,401,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,539,3.100,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,601,27,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,605,0,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121417,606,3.120,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,203,16.400,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,204,7.810,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,205,23.400,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,207,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,208,227,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,255,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,269,3.910,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,291,1.600,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,301,250,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,303,0.780,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,306,375,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,307,570,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,320,NULL,'100g',NULL,3,'2024-12-12','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,328,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,401,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,539,3.100,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,601,39,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,605,0,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121418,606,3.520,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,203,13.5,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,204,10.5,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,205,21,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,207,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,208,233,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,255,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,269,3.760,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,291,2.300,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,301,180,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,303,1.350,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,306,301,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,307,481,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,320,NULL,'100g',NULL,3,'2024-12-12','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,328,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,401,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,539,1.5,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,601,26,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,605,0,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121419,606,5.260,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121420,203,13.900,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,204,9.020,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,205,25.400,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,207,NULL,'100g',NULL,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,208,238,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,255,NULL,'100g',NULL,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,269,4.100,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,291,1.600,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,301,295,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,303,0.980,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,306,320,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,307,680,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,320,NULL,'100g',NULL,3,'2024-12-12','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,328,NULL,'100g',NULL,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,401,NULL,'100g',NULL,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,539,3.300,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,601,37,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,605,0,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121420,606,3.690,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121421,203,13.400,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,204,10.600,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,205,23.200,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,207,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,208,239,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,255,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,269,4.230,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,291,2.800,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,301,195,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,303,1.410,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,306,231,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,307,803,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,320,NULL,'100g',NULL,3,'2024-12-12','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,328,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,401,NULL,'100g',NULL,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,539,2.800,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,601,39,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,605,0,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121421,606,3.870,'100g',6,3,'2019-03-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121422,203,9.410,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,204,7.060,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,205,24.700,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,208,200,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,269,5.880,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,291,1.200,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,301,47,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,303,1.650,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,306,188,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,307,506,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,328,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,401,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,539,3.5,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,601,18,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,605,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121422,606,1.180,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,203,11.300,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,204,11.300,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,205,21.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,208,239,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,269,7.040,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,291,1.400,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,301,28,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,303,0.990,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,306,70,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,307,394,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,328,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,401,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,539,5.600,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,601,56,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,605,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121423,606,2.110,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121424,203,12.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,204,12.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,205,29.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,208,270,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,269,3.370,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,291,4.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,301,247,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,303,2.25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,306,483,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,307,494,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,539,2.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,601,17,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121424,606,4.490,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,203,15.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,204,14.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,205,23.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,208,271,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,269,3.390,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,291,3.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,301,373,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,303,1.690,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,306,534,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,307,610,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,539,1.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,601,25,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121425,606,5.930,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,203,14.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,204,21.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,205,21.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,208,336,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,269,2.340,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,291,3.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,301,359,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,303,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,306,164,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,307,492,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,539,1.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,601,23,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121428,606,7.030,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121429,203,8.860,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,204,1.270,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,205,49.400,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,207,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,208,241,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,255,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,269,5.060,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,291,3.800,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,301,63,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,303,3.040,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,306,177,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,307,468,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,328,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,401,NULL,'100g',NULL,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,539,1.300,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,601,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,605,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121429,606,0,'100g',6,3,'2019-03-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121431,203,10.500,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,204,1.75,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,205,54.400,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,208,263.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,269,8.770,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,291,5.300,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,301,68.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,303,1.750,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,306,167.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,307,333.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,328,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,401,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,539,7.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,601,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,605,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121431,606,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,203,10.500,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,204,1.75,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,205,50.900,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,208,263.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,269,8.770,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,291,5.300,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,301,68.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,303,1.750,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,306,167.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,307,333.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,328,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,401,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,539,7.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,601,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,605,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121432,606,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121438,203,7.020,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,204,12.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,205,45.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,208,316,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,269,3.510,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,301,53,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,303,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,306,140,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,307,614,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,539,1.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121438,606,7.890,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121461,203,7.080,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,204,15.900,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,205,39.800,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,207,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,208,319,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,255,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,269,6.190,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,291,4.400,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,301,97,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,303,2.390,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,306,71,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,307,363,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,320,142.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,328,1,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,401,1.800,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,539,5.300,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,601,49,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,605,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121461,606,9.730,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121481,203,6.980,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,204,0,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,205,46.5,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,207,NULL,'100g',NULL,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,208,233,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,255,NULL,'100g',NULL,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,269,4.650,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,291,2.300,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,301,0,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,303,2.510,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,306,NULL,'100g',NULL,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,307,419,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,320,NULL,'100g',NULL,3,'2024-12-12','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,328,NULL,'100g',NULL,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,401,2.800,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,539,NULL,'100g',NULL,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,601,0,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,605,0,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121481,606,0,'100g',6,3,'2019-03-27','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121491,203,4.550,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,204,13.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,205,36.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,208,282,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,269,10,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,301,59,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,303,1.640,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,306,41.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,307,309,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,539,10,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,601,18,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121491,606,1.820,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121492,203,10.500,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,204,1.750,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,205,54.400,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,208,263.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,269,8.770,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,291,5.300,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,301,79.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,303,3.510,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,306,202.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,307,351.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,328,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,401,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,539,3.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,601,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,605,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121492,606,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121499,203,7.020,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,204,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,205,40.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,208,211,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,269,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,301,105,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,303,2.810,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,306,70,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,307,439,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121499,606,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,203,10.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,204,2.630,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,205,36.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,208,211,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,269,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,291,3.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,301,158,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,303,2.460,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,306,158,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,307,474,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121501,606,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121502,203,7.020,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,204,10.500,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,205,47.400,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,208,316,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,269,1.75,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,291,1.800,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,301,21,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,303,3.510,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,306,79,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,307,1140,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,328,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,401,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,601,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,605,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121502,606,7.020,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121505,203,10.900,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,204,7.440,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,205,23.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,208,203.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,269,7.940,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,291,1.500,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,301,63,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,303,1.020,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,306,147.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,307,341.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,328,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,401,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,539,7.900,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,601,32.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,605,0.010,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121505,606,1.720,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121506,203,8.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,204,10.500,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,205,49.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,208,316,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,269,8.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,291,3.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,301,174,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,303,1.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,306,579.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,307,491,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,539,7,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121506,606,7.020,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121507,203,6.670,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,204,11.100,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,205,44.400,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,207,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,208,289,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,255,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,269,2.220,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,291,4.400,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,301,27,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,303,2.220,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,306,178,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,307,756,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,328,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,401,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,539,2.200,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,601,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,605,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121507,606,6.670,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121508,203,10.500,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,204,0.880,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,205,54.400,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,208,263.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,269,7.020,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,291,7.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,301,93.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,303,1.750,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,306,228.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,307,386.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,328,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,401,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,539,3.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,601,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,605,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121508,606,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,203,10.500,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,204,1.750,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,205,54.400,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,208,263.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,269,8.770,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,291,5.300,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,301,79.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,303,3.510,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,306,202.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,307,351.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,328,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,401,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,539,3.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,601,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,605,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121509,606,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,203,10.500,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,204,1.750,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,205,54.400,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,208,263.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,269,5.260,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,291,5.300,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,301,95.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,303,3.510,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,306,184.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,307,386.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,328,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,401,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,539,3.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,601,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,605,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121510,606,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,203,10.500,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,204,0.880,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,205,61.400,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,208,281.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,269,7.020,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,291,3.500,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,301,75.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,303,3.510,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,306,96.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,307,579.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,328,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,401,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,539,5.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,601,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,605,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121511,606,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,203,10.500,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,204,0.880,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,205,54.400,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,208,263.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,269,7.020,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,291,7.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,301,93.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,303,1.750,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,306,228.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,307,386.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,328,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,401,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,539,3.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,601,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,605,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121516,606,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121518,203,8.060,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,204,4.840,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,205,54.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,208,290,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,269,12.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,291,3.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,301,19,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,303,3.230,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,306,169.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,307,274,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,328,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,401,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,539,12.900,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,601,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,605,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121518,606,1.610,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121520,203,7.140,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,204,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,205,50,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,208,250,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,269,3.570,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,291,3.600,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,301,36.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,303,2.860,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,306,107.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,307,339.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,328,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,401,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,539,3.600,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,601,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121520,606,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121521,203,10.500,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,204,1.750,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,205,54.400,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,208,263.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,269,5.260,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,291,5.300,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,301,95.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,303,3.510,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,306,184.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,307,386.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,328,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,401,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,539,3.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,601,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,605,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121521,606,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121522,203,7.140,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,204,0.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,205,50,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,208,250,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,269,3.570,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,291,3.600,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,301,36.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,303,2.860,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,306,107.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,307,339.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,328,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,401,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,539,3.600,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,601,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121522,606,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,203,15.600,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,204,12.400,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,205,8.550,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,208,207,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,269,1.270,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,291,1.200,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,301,50,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,303,2.040,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,306,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,307,333,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,320,0.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,328,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,401,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,601,48,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,605,0.740,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121523,606,4.740,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121525,203,16.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,204,12.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,205,8.070,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,208,209,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,269,2.470,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,291,1.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,301,81,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,303,1.950,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,307,299,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,401,0.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,601,49,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,605,0.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121525,606,4.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,203,16.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,204,12.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,205,8.040,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,208,209,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,269,2.490,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,291,1.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,301,78,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,303,1.170,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,307,301,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,401,0.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,601,45,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,605,0.230,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121526,606,4.410,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121527,203,16.600,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,204,14.800,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,205,2.750,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,208,213,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,269,1.200,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,291,0.900,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,301,28,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,303,2.030,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,307,426.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,320,0.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,401,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,601,68,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,605,0.920,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121527,606,5.690,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121531,203,15.400,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,204,15.200,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,205,7.640,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,207,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,208,225,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,255,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,269,1.520,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,291,1.5,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,301,95,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,303,1.950,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,306,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,307,391,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,328,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,401,0.800,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,539,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,601,69,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,605,0.450,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121531,606,5.400,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121533,203,8.570,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,204,8.380,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,205,30.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,208,225,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,269,9.470,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,291,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,301,44,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,303,1.580,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,307,317,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,401,45.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,601,33,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,605,0.040,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121533,606,1.570,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121534,203,2.090,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,204,2.190,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,205,11.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,208,71.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,269,8.450,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,291,1.200,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,301,47,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,303,0.420,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,307,272.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,320,63.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,401,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,601,9.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,605,0.090,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121534,606,1.340,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121536,203,11.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,204,10.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,205,12.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,208,193,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,269,3.720,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,291,0.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,301,169,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,303,0.930,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,307,366,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,401,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,601,35,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,605,0.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121536,606,5.010,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121537,203,8.810,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,204,9.940,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,205,3.780,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,207,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,208,141,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,255,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,269,0.590,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,291,0.700,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,301,19,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,303,1.25,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,306,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,307,221,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,320,114.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,328,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,401,3.800,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,539,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,601,34,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,605,0.600,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121537,606,3.770,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121538,203,16.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,204,10.200,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,205,4.700,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,208,134.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,269,1.090,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,291,1.900,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,301,61.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,303,2.410,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,307,341.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,320,131.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,401,5.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,601,54.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,605,0.010,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121538,606,1.540,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,203,17.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,204,9.830,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,205,3.210,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,208,171,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,269,0.320,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,291,1.700,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,301,31,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,303,1.840,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,307,254,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,320,156.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,401,0.600,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,601,57,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,605,0.130,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121539,606,2.860,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,203,14.400,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,204,5.220,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,205,5.910,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,208,125.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,269,1.810,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,291,2.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,301,56,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,303,1.600,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,307,311.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,320,130.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,401,5.300,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,601,35.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,605,0.110,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121540,606,1.840,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121543,203,15,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,204,3.190,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,205,7.920,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,208,111,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,269,2.710,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,291,3.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,301,73,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,303,2.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,307,266,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,401,6.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,601,18,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,605,0.180,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121543,606,1.170,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,203,16.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,204,7.090,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,205,5.370,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,208,152,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,269,2.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,291,1.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,301,41,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,303,1.660,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,307,280,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,401,4.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,601,42,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,605,0.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121544,606,2.090,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121545,203,17.800,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,204,8.890,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,205,2.550,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,208,161,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,269,0.210,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,291,1.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,301,26,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,303,2.110,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,307,374,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,320,94.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,401,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,601,64,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,605,0.530,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121545,606,3.570,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,203,14.400,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,204,5.240,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,205,5.920,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,208,127.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,269,1.840,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,291,2.400,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,301,56,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,303,2.200,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,307,329,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,320,130.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,401,6,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,601,38,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,605,0.320,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121546,606,1.990,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121547,203,15.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,204,12.400,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,205,3.740,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,207,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,208,184.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,255,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,269,0.920,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,291,1.900,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,301,48,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,303,1.730,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,306,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,307,428.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,320,86.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,328,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,401,2.200,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,539,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,601,43,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,605,0.740,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121547,606,4.690,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121548,203,15.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,204,7,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,205,3.450,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,208,139,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,269,0.540,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,291,1.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,301,43,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,303,1.950,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,307,425,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,401,0.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,601,41,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,605,0.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121548,606,2.070,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121549,203,6.620,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,204,2.850,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,205,9.350,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,207,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,208,90.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,255,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,269,4.280,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,291,1.800,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,301,31,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,303,1.100,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,306,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,307,250.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,320,90.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,328,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,401,17.5,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,539,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,601,21.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,605,0.180,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121549,606,1.080,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121552,203,9.660,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,204,8.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,205,6.170,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,208,137,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,269,1.950,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,301,35,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,303,1.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,307,263,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,401,6.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,601,28,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,605,0.510,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121552,606,3.130,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121555,203,5.220,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,204,3.25,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,205,16.900,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,208,115,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,269,2.690,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,291,5,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,301,40,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,303,1.770,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,306,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,307,237,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,320,21.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,328,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,401,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,539,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,601,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,605,0.060,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121555,606,0.490,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121559,203,13.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,204,5.620,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,205,9.980,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,208,144.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,269,6.790,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,291,1.400,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,301,39,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,303,1.750,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,307,417.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,320,79.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,401,6.400,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,601,43.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,605,0.350,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121559,606,2.150,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121563,203,9.450,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,204,4.490,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,205,7.280,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,208,109,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,269,3.490,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,291,1.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,301,30,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,303,0.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,307,267,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,401,12.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,601,31,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,605,0.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121563,606,1.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121565,203,10.800,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,204,4.940,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,205,7.140,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,208,118,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,269,4.060,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,291,1.5,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,301,29,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,303,1.270,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,306,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,307,228,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,320,58.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,328,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,401,14.100,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,601,32,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,605,0.080,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121565,606,1.490,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121566,203,9.340,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,204,9.680,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,205,7.670,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,208,157,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,269,5,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,291,1.300,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,301,25,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,303,1.240,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,307,228,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,320,62.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,401,10.900,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,601,34,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,605,0.610,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121566,606,3.710,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121567,203,9.400,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,204,4.570,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,205,6.720,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,208,108.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,269,3.920,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,291,1.400,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,301,25.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,303,1.360,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,306,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,307,184.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,320,74.000,'100g',6,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,328,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,401,12.100,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,539,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,601,34.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,605,0.280,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121567,606,1.740,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121568,203,8.740,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,204,7.730,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,205,3.830,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,208,159.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,269,2.670,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,291,1.500,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,301,24,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,303,1.450,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,307,207.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,320,51.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,401,10.800,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,601,26,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,605,0.460,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121568,606,2.910,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,203,9.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,204,7.730,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,205,12.900,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,208,159.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,269,2.690,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,291,1.500,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,301,24.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,303,1.450,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,307,214.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,320,51.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,401,10.800,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,601,26,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,605,0.460,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121569,606,2.900,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121575,203,17.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,204,11.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,205,2.930,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,208,182,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,269,0.770,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,291,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,301,43,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,303,2.320,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,307,339,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,401,2.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,601,46,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,605,0.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121575,606,4.360,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,203,17.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,204,19.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,205,1.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,208,254,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,269,0.620,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,291,0.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,301,28,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,303,1.020,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,307,423,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,601,65,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,605,0.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121576,606,6.970,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121577,203,14.600,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,204,27.800,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,205,1.510,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,207,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,208,319.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,255,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,269,0.640,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,291,0.300,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,301,27,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,303,0.950,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,306,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,307,521.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,320,24.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,328,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,401,0,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,539,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,601,70,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,605,0.530,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121577,606,9.940,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121580,203,20.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,204,13.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,205,2.270,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,208,208,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,269,0.160,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,291,1.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,301,56,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,303,2.540,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,307,421,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,601,55,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,605,0.830,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121580,606,5.150,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,203,20.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,204,13.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,205,2.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,208,208,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,269,0.140,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,291,1.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,301,64,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,303,2.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,307,422,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,601,55,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,605,0.830,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121581,606,5.150,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,203,17.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,204,17.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,205,1.190,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,208,237,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,269,0.090,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,291,0.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,301,29,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,303,2.070,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,307,282,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,601,71,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,605,1.090,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121584,606,6.830,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121587,203,19.700,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,204,11.600,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,205,2.800,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,207,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,208,190,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,255,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,269,0.200,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,291,2.300,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,301,49,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,303,2.630,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,306,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,307,374,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,328,NULL,'100g',NULL,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,401,0,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,601,48,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,605,0.720,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121587,606,4.390,'100g',6,3,'2019-03-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121588,203,20.300,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,204,15,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,205,1.720,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,208,220,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,269,0.110,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,291,1.300,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,301,31,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,303,2.260,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,306,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,307,253,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,320,0.000,'100g',6,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,328,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,401,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,539,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,601,57,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,605,0.910,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121588,606,6.160,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,203,19.600,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,204,17.900,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,205,1.360,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,208,248,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,269,0.110,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,291,0.900,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,301,35,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,303,2.330,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,306,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,307,321,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,320,0.000,'100g',6,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,328,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,401,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,539,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,601,81,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,605,1.090,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121589,606,6.850,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121591,203,17.600,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,204,12.600,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,205,7.560,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,208,214,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,269,6.300,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,291,1.300,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,301,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,303,1.360,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,306,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,307,504,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,320,23.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,328,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,401,1.5,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,601,50,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121591,606,4.410,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,203,16.800,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,204,17.900,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,205,11.600,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,208,274,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,269,1.050,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,291,2.100,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,301,42,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,303,1.710,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,306,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,307,347,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,320,0.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,328,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,401,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,601,42,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121592,606,4.740,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121593,203,16.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,204,17.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,205,11.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,208,274,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,269,1.050,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,291,2.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,301,42,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,303,2.840,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,307,358,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,601,47,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,605,0.530,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121593,606,5.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121594,203,1.780,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,204,1.630,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,205,13.900,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,207,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,208,76,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,255,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,269,9.630,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,291,2.100,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,301,30,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,303,0.910,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,306,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,307,81,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,328,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,401,17.5,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,539,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,601,0,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,605,0.060,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121594,606,0.260,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,203,1.410,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,204,10.300,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,205,7.900,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,207,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,208,138,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,255,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,269,4.130,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,291,1.600,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,301,35,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,303,0.630,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,306,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,307,278,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,328,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,401,10.600,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,539,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,601,0,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,605,0.180,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121595,606,1.520,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121596,203,12.600,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,204,16.600,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,205,3.240,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,208,218,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,269,1.570,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,291,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,301,388,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,303,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,306,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,307,746.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,320,140.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,328,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,401,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,601,50,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121596,606,9.520,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,203,12.600,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,204,16.600,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,205,3.240,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,208,218,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,269,1.570,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,291,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,301,388,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,303,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,306,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,307,746.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,320,140.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,328,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,401,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,601,50,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121598,606,9.540,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121600,203,1.380,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,204,0.140,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,205,32.400,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,207,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,208,135,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,255,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,269,27.100,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,291,1.700,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,301,28,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,303,0.510,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,306,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,307,390,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,328,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,401,8.5,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,539,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,601,0,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,605,0.030,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121600,606,0.060,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121601,203,10.300,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,204,10.300,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,205,9.240,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,207,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,208,173,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,255,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,269,6.650,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,291,0,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,301,353,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,303,0,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,306,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,307,691.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,320,84.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,328,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,401,1.100,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,539,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,601,33,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,605,0.040,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121601,606,5.940,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121602,203,11.800,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,204,17,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,205,2.290,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,207,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,208,215,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,255,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,269,0.510,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,291,0.100,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,301,370,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,303,0,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,306,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,307,771,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,328,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,401,1.100,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,539,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,601,51,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,605,0.020,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121602,606,9.790,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,203,0.930,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,204,0.570,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,205,8.030,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,207,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,208,38,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,255,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,269,2.130,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,291,1.400,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,301,0,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,303,0.600,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,306,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,307,263,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,328,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,401,10,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,539,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,601,0,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,605,0.030,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121603,606,0.100,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121604,203,10.900,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,204,10.800,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,205,8.460,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,208,178,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,269,6.590,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,291,0.100,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,301,366,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,303,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,306,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,307,703.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,320,69.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,328,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,401,1.200,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,601,36,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,605,0.040,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121604,606,6.280,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121605,203,10.500,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,204,10.300,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,205,9.430,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,208,176.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,269,6.720,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,291,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,301,355,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,303,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,307,682.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,320,84.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,401,1.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,601,33,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,605,0.040,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121605,606,5.970,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121606,203,11.5,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,204,12.800,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,205,6.050,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,208,189,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,269,4.430,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,291,0.100,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,301,370,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,303,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,306,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,307,703.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,320,95.000,'100g',6,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,328,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,401,1.100,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,539,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,601,40,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,605,0.020,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121606,606,7.350,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121607,203,12.900,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,204,16.800,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,205,3.050,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,207,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,208,221.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,255,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,269,1.560,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,291,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,301,414,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,303,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,306,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,307,753.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,320,124.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,328,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,401,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,539,NULL,'100g',NULL,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,601,51,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,605,0,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121607,606,9.670,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121608,203,11.800,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,204,17.100,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,205,2.350,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,208,215,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,269,0.560,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,291,0.100,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,301,370,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,303,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,306,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,307,727.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,320,127.000,'100g',6,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,328,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,401,1.100,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,539,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,601,51,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,605,0.020,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121608,606,9.820,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121609,203,9.050,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,204,6.740,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,205,18.5,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,207,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,208,172,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,255,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,269,4.330,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,291,1.200,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,301,223,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,303,0.630,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,306,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,307,259,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,328,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,401,0.700,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,539,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,601,20,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,605,0.080,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121609,606,3.75,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121610,203,8.640,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,204,9.120,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,205,15,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,207,NULL,'100g',NULL,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,208,181,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,255,NULL,'100g',NULL,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,269,2.090,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,291,0,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,301,212,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,303,0.530,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,306,NULL,'100g',NULL,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,307,465,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,328,NULL,'100g',NULL,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,401,0.400,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,539,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,601,27,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,605,0.080,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121610,606,5.190,'100g',6,3,'2019-03-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121611,203,8.700,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,204,6.870,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,205,17.100,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,207,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,208,168,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,255,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,269,4.620,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,291,0.5,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,301,223,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,303,0.530,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,306,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,307,462,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,328,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,401,0.400,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,539,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,601,21,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,605,0.080,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121611,606,3.900,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,203,8.920,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,204,9.370,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,205,15,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,207,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,208,182,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,255,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,269,2.400,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,291,0,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,301,212,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,303,0.630,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,306,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,307,459,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,328,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,401,0.400,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,539,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,601,27,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,605,0.020,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121612,606,5.420,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121613,203,8.990,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,204,6.730,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,205,17.600,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,207,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,208,171.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,255,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,269,4.830,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,291,0.500,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,301,223,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,303,0.630,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,306,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,307,341.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,320,53.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,328,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,401,0.700,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,539,NULL,'100g',NULL,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,601,21,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,605,0.020,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121613,606,3.820,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121614,203,9.780,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,204,7.290,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,205,18.300,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,207,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,208,180.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,255,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,269,4.740,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,291,1.100,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,301,235.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,303,0.630,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,306,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,307,396.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,320,48.000,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,328,NULL,'100g',NULL,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,401,0.700,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,539,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,601,22,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,605,0.040,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121614,606,4.110,'100g',6,3,'2019-03-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (121615,203,9.180,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,204,6.860,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,205,17.600,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,207,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,208,170.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,255,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,269,4.500,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,291,1.200,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,301,223,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,303,0.630,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,306,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,307,269.000,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,320,53.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,328,NULL,'100g',NULL,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,401,0.700,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,539,NULL,'100g',NULL,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,601,21,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,605,0.020,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121615,606,3.830,'100g',6,3,'2019-03-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (121616,203,2.450,'100g',6,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,204,6.940,'100g',6,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,205,27.000,'100g',6,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,207,NULL,'100g',NULL,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,208,179.000,'100g',6,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,255,NULL,'100g',NULL,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,269,2.700,'100g',6,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,291,0.800,'100g',6,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,301,170.000,'100g',6,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,303,0.850,'100g',6,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,306,NULL,'100g',NULL,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,307,210.000,'100g',6,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,320,NULL,'100g',NULL,3,'2024-12-12','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,328,NULL,'100g',NULL,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,401,0.700,'100g',6,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,539,NULL,'100g',NULL,3,'2022-04-01','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,601,16.000,'100g',6,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,605,0.010,'100g',6,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121616,606,6.110,'100g',6,3,'2019-03-27','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (121617,203,8.980,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,204,9.360,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,205,16.200,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,207,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,208,187,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,255,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,269,1.980,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,291,1.200,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,301,218,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,303,0.630,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,306,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,307,459,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,328,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,401,0.400,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,539,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,601,27,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,605,0.080,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121617,606,5.260,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121618,203,9.120,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,204,8.970,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,205,15.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,208,179,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,269,2,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,291,1.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,301,218,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,303,0.630,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,307,434.000,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,401,0.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,601,27,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,605,0.020,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121618,606,5.090,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121619,203,9.400,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,204,9.430,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,205,16,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,207,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,208,189,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,255,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,269,2.210,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,291,1.100,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,301,223,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,303,0.630,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,306,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,307,474,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,328,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,401,0.400,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,539,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,601,28,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,605,0.020,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121619,606,5.330,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,203,9.230,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,204,6.730,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,205,17.200,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,207,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,208,168,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,255,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,269,4.510,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,291,1.200,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,301,223,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,303,0.630,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,306,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,307,459,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,328,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,401,0.700,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,539,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,601,21,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,605,0.020,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121621,606,3.830,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,203,8.880,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,204,7.030,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,205,17.400,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,207,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,208,169,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,255,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,269,4.480,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,291,1.200,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,301,223,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,303,0.630,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,306,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,307,461,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,328,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,401,0.700,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,539,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,601,21,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,605,0.080,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121622,606,3.940,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,203,9.620,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,204,7.25,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,205,17.300,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,207,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,208,175,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,255,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,269,4.720,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,291,1.100,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,301,241,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,303,0.630,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,306,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,307,406,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,328,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,401,0.700,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,539,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,601,22,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,605,0.020,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121623,606,4.090,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121624,203,8.060,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,204,2.670,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,205,9.470,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,208,93,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,269,2.650,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,291,2.800,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,301,30,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,303,1.520,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,307,157.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,320,136.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,401,11.600,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,601,18,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,605,0.160,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121624,606,1,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121626,203,18.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,204,17.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,205,1.140,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,208,231,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,269,0.120,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,291,1,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,301,43,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,303,2.080,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,307,249,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,601,60,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,605,1.040,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121626,606,6.520,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121628,203,6.810,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,204,2.630,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,205,51.5,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,207,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,208,254,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,255,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,269,0.530,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,291,4.800,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,301,21,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,303,2.950,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,306,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,307,269,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,328,NULL,'100g',NULL,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,401,1.200,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,539,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,601,0,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,605,0.020,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121628,606,0.470,'100g',6,3,'2019-03-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121632,203,15.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,204,12.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,205,8.550,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,208,207,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,269,1.270,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,291,1.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,301,50,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,303,2.040,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,307,333,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,401,0.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,601,48,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,605,0.740,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121632,606,4.740,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,203,16.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,204,12.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,205,8.070,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,208,209,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,269,2.470,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,291,1.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,301,81,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,303,1.950,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,307,299,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,401,0.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,601,49,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,605,0.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121634,606,4.75,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,203,16.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,204,12.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,205,8.040,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,208,209,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,269,2.490,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,291,1.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,301,78,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,303,1.170,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,307,301,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,401,0.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,601,45,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,605,0.230,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121635,606,4.410,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121636,203,16.600,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,204,14.800,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,205,2.750,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,208,213,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,269,1.200,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,291,0.900,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,301,28,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,303,2.030,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,307,426.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,320,0.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,401,0,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,601,68,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,605,0.920,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121636,606,5.690,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121640,203,11.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,204,10.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,205,12.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,208,193,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,269,3.720,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,291,0.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,301,169,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,303,0.930,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,307,366,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,401,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,601,35,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,605,0.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121640,606,5.010,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,203,12.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,204,10.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,205,16.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,208,213,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,269,3.810,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,291,1.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,301,165,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,303,1.160,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,307,363,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,401,1.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,601,34,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,605,0.420,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121641,606,5.190,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121642,203,8.810,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,204,9.940,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,205,3.780,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,207,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,208,141,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,255,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,269,0.590,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,291,0.700,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,301,19,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,303,1.25,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,306,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,307,221,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,320,114.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,328,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,401,3.800,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,539,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,601,34,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,605,0.600,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121642,606,3.770,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121644,203,14.400,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,204,5.220,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,205,5.910,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,208,125.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,269,1.810,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,291,2.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,301,56,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,303,1.600,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,307,311.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,320,130.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,401,5.300,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,601,35.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,605,0.110,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121644,606,1.840,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121646,203,15,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,204,3.190,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,205,7.920,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,208,111,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,269,2.710,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,291,3.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,301,73,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,303,2.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,307,266,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,401,6.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,601,18,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,605,0.180,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121646,606,1.170,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,203,17.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,204,8.890,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,205,2.550,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,208,161,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,269,0.210,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,291,1.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,301,26,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,303,2.110,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,307,374,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,601,64,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,605,0.530,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121647,606,3.570,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,203,14.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,204,5.340,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,205,5.940,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,208,127,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,269,1.870,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,291,2.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,301,45,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,303,2.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,307,331,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,401,6,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,601,38,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,605,0.320,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121648,606,2,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,203,15,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,204,12.5,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,205,3.670,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,208,185,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,269,0.890,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,291,2,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,301,48,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,303,2.380,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,307,428,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,401,2.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,601,43,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,605,0.740,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121649,606,4.690,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121651,203,6.620,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,204,2.850,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,205,9.350,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,207,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,208,90.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,255,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,269,4.280,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,291,1.800,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,301,31,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,303,1.100,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,306,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,307,250.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,320,90.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,328,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,401,17.5,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,539,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,601,21.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,605,0.180,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121651,606,1.080,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121652,203,9.880,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,204,3.950,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,205,7.730,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,208,105.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,269,3.190,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,291,2.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,301,34.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,303,1.600,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,307,230.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,320,166.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,401,13.600,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,601,28.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,605,0.250,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121652,606,1.490,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,203,13.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,204,5.620,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,205,9.980,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,208,144.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,269,6.790,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,291,1.400,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,301,39.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,303,1.75,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,307,417.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,320,79.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,401,6.400,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,601,43,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,605,0.350,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121657,606,2.150,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121658,203,8.580,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,204,7.650,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,205,11.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,208,150,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,269,3.790,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,291,1.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,301,26,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,303,1.350,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,307,296,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,401,6.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,601,26,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,605,0.460,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121658,606,2.950,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121659,203,8.240,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,204,7.620,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,205,11,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,208,147,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,269,3.430,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,291,1.700,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,301,26,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,303,1.350,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,306,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,307,212,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,320,24.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,328,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,401,6.900,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,601,26,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,605,0.460,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121659,606,2.950,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121661,203,8.980,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,204,4.270,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,205,6.910,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,207,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,208,104.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,255,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,269,3.320,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,291,1.400,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,301,24.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,303,0.640,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,306,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,307,253.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,320,64.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,328,NULL,'100g',NULL,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,401,12.200,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,539,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,601,30.000,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,605,0.100,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121661,606,1.520,'100g',6,3,'2019-03-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (121663,203,9.340,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,204,9.680,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,205,7.670,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,208,157,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,269,5,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,291,1.300,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,301,25,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,303,1.240,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,307,228,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,320,62.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,401,10.900,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,601,34,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,605,0.610,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121663,606,3.710,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121664,203,9.400,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,204,4.570,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,205,6.720,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,208,108.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,269,3.920,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,291,1.400,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,301,25.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,303,1.360,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,306,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,307,184.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,320,74.000,'100g',6,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,328,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,401,12.100,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,539,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,601,34.000,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,605,0.280,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121664,606,1.740,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121665,203,8.740,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,204,7.730,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,205,3.830,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,208,159.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,269,2.670,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,291,1.500,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,301,24,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,303,1.450,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,307,207.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,320,51.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,401,10.800,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,601,26,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,605,0.460,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121665,606,2.910,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,203,9.100,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,204,7.730,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,205,12.900,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,208,159.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,269,2.690,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,291,1.500,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,301,24.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,303,1.450,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,307,214.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,320,51.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,401,10.800,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,601,26,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,605,0.460,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121666,606,2.900,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121669,203,19.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,204,18,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,205,1.340,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,208,250,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,269,0.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,291,0.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,301,28,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,303,2.290,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,307,266,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,601,81,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,605,1.110,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121669,606,6.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,203,17.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,204,19.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,205,1.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,208,254,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,269,0.620,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,291,0.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,301,28,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,303,1.020,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,307,423,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,601,65,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,605,0.400,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121678,606,6.970,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,203,14.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,204,27.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,205,1.510,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,208,319,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,269,0.640,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,291,0.300,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,301,27,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,303,0.950,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,307,522,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,601,70,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,605,0.530,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121679,606,9.950,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,203,20.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,204,13.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,205,2.270,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,208,208,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,269,0.160,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,291,1.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,301,56,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,303,2.540,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,307,421,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,601,55,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,605,0.830,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121682,606,5.150,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,203,20.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,204,13.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,205,2.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,208,208,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,269,0.140,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,291,1.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,301,64,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,303,2.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,307,422,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,601,55,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,605,0.830,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121683,606,5.150,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,203,17.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,204,17.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,205,1.190,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,208,237,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,269,0.090,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,291,0.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,301,29,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,303,2.070,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,307,282,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,601,71,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,605,1.090,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121686,606,6.830,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,203,19.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,204,11.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,205,2.810,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,208,190,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,269,0.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,291,2.200,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,301,65,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,303,2.630,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,307,376,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,601,48,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,605,0.700,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121690,606,4.390,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121691,203,20.300,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,204,15,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,205,1.720,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,207,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,208,220,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,255,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,269,0.110,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,291,1.300,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,301,31,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,303,2.260,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,306,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,307,253,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,320,0.000,'100g',6,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,328,NULL,'100g',NULL,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,401,0,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,539,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,601,57,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,605,0.910,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121691,606,6.160,'100g',6,3,'2019-03-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121692,203,19.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,204,17.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,205,1.360,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,208,248,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,269,0.110,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,291,0.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,301,35,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,303,2.330,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,307,321,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,601,81,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,605,1.090,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121692,606,6.850,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121693,203,17.700,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,204,12.700,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,205,7.590,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,208,215,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,269,6.330,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,291,1.100,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,301,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,303,1.370,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,306,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,307,506,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,320,23.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,328,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,401,1.5,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,601,51,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121693,606,4.430,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,203,16.800,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,204,17.900,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,205,11.600,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,207,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,208,274,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,255,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,269,1.050,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,291,2.100,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,301,42,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,303,1.710,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,306,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,307,347,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,320,0.000,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,328,NULL,'100g',NULL,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,401,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,601,42,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,605,0,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121694,606,4.740,'100g',6,3,'2019-03-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121695,203,16.800,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,204,17.900,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,205,11.600,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,208,274,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,269,1.050,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,291,2.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,301,42,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,303,2.840,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,307,358,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,601,47,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,605,0.530,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121695,606,5.260,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121696,203,8.060,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,204,2.670,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,205,9.470,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,207,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,208,93.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,255,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,269,2.650,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,291,2.800,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,301,30.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,303,1.520,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,306,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,307,157.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,320,136.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,328,NULL,'100g',NULL,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,401,11.600,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,601,18.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,605,0.160,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121696,606,1.000,'100g',6,3,'2019-03-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121699,203,18.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,204,17.100,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,205,1.140,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,207,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,208,231,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,255,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,269,0.120,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,291,1,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,301,43,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,303,2.080,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,306,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,307,249,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,328,NULL,'100g',NULL,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,401,0,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,601,60,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,605,1.040,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121699,606,6.520,'100g',6,3,'2019-03-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121766,203,11,'100g',6,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,204,0.970,'100g',6,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,205,32.300,'100g',6,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,207,NULL,'100g',NULL,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,208,181,'100g',6,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,255,NULL,'100g',NULL,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,269,6.450,'100g',6,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,291,3.900,'100g',6,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,301,0,'100g',6,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,303,1.160,'100g',6,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,306,NULL,'100g',NULL,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,307,387,'100g',6,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,320,NULL,'100g',NULL,3,'2024-12-12','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,328,NULL,'100g',NULL,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,401,NULL,'100g',NULL,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,539,NULL,'100g',NULL,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,601,19,'100g',6,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,605,0,'100g',6,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121766,606,1.940,'100g',6,3,'2019-03-31','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (121767,203,11.600,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,204,10.300,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,205,26.400,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,207,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,208,239.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,255,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,269,1.290,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,291,1.900,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,301,161.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,303,1.160,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,306,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,307,361.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,328,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,401,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,601,29,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,605,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121767,606,5.160,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,203,11.600,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,204,10.300,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,205,26.400,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,207,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,208,239,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,255,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,269,1.290,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,291,1.900,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,301,161,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,303,1.160,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,306,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,307,361,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,328,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,401,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,601,29,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,605,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121768,606,5.160,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,203,10.300,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,204,0.970,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,205,26.400,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,207,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,208,161.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,255,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,269,1.290,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,291,3.900,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,301,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,303,1.160,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,306,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,307,342.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,328,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,401,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,601,19.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,605,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121769,606,1.940,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,203,8.850,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,204,7.960,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,205,11.5,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,207,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,208,150,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,255,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,269,0.880,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,291,3.5,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,301,177,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,303,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,306,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,307,292,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,328,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,401,2.100,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,601,27,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,605,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121773,606,3.980,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,203,8.850,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,204,8.850,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,205,11.5,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,207,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,208,150,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,255,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,269,0.880,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,291,3.5,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,301,177,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,303,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,306,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,307,301,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,328,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,401,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,601,27,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,605,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121774,606,4.420,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,203,3.920,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,204,7.840,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,205,45.100,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,207,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,208,275.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,255,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,269,17.600,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,291,2.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,301,39.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,303,2.120,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,306,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,307,314.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,328,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,401,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,601,29.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,605,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121775,606,1.960,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,203,3.920,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,204,7.840,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,205,45.100,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,207,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,208,275.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,255,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,269,21.600,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,291,2.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,301,0.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,303,2.120,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,306,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,307,275.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,328,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,401,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,601,29.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,605,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121776,606,1.960,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121778,203,4.710,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,204,9.410,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,205,48.200,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,207,NULL,'100g',NULL,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,208,294,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,255,NULL,'100g',NULL,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,269,22.400,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,291,2.400,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,301,24,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,303,2.120,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,306,82,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,307,282,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,328,0,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,401,NULL,'100g',NULL,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,539,10.600,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,601,24,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,605,0,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121778,606,2.350,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,203,3.920,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,204,7.840,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,205,45.100,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,207,NULL,'100g',NULL,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,208,275,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,255,NULL,'100g',NULL,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,269,17.600,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,291,2,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,301,39,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,303,2.120,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,306,137,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,307,235,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,328,0,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,401,0,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,539,15.700,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,601,29,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,605,0,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121780,606,1.960,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121781,203,4.710,'100g',6,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,204,8.240,'100g',6,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,205,45.900,'100g',6,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,207,NULL,'100g',NULL,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,208,271,'100g',6,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,255,NULL,'100g',NULL,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,269,20,'100g',6,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,291,2.400,'100g',6,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,301,24,'100g',6,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,303,2.120,'100g',6,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,306,NULL,'100g',NULL,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,307,282,'100g',6,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,328,NULL,'100g',NULL,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,401,0,'100g',6,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,539,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,601,29,'100g',6,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,605,0,'100g',6,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121781,606,0.590,'100g',6,3,'2019-03-31','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121783,203,5.880,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,204,13.200,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,205,64.700,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,207,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,208,382,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,255,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,269,32.400,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,291,2.900,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,301,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,303,1.060,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,306,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,307,294,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,328,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,401,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,601,29,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,605,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121783,606,2.940,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121784,203,5.880,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,204,13.200,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,205,64.700,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,207,NULL,'100g',NULL,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,208,382,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,255,NULL,'100g',NULL,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,269,32.400,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,291,2.900,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,301,0,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,303,3.180,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,306,0,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,307,294,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,328,0,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,401,NULL,'100g',NULL,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,539,17.600,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,601,29,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,605,0,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121784,606,2.940,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,203,5.770,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,204,13.5,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,205,61.5,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,207,NULL,'100g',NULL,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,208,385,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,255,NULL,'100g',NULL,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,269,34.600,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,291,3.800,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,301,0,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,303,2.080,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,306,135,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,307,212,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,328,0,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,401,0,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,539,15.400,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,601,29,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,605,0,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121785,606,3.850,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121789,203,5.310,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,204,11.500,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,205,46.900,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,207,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,208,301.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,255,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,269,22.100,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,291,2.700,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,301,71.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,303,1.590,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,306,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,307,310.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,328,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,401,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,601,44.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,605,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121789,606,1.330,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,203,4.630,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,204,4.630,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,205,35.200,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,207,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,208,204.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,255,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,269,12.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,291,1.900,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,301,19.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,303,1.670,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,306,97,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,307,333.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,328,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,401,NULL,'100g',NULL,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,601,32.000,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,605,0,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121790,606,2.310,'100g',6,3,'2019-03-31','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121791,203,4.630,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,204,4.170,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,205,38,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,207,NULL,'100g',NULL,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,208,213,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,255,NULL,'100g',NULL,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,269,13.900,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,291,1.900,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,301,19,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,303,1.670,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,306,130,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,307,306,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,328,0,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,401,NULL,'100g',NULL,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,539,6.5,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,601,32,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,605,0,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121791,606,2.310,'100g',6,3,'2019-03-31','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (121792,203,4.630,'100g',6,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,204,4.630,'100g',6,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,205,38,'100g',6,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,207,NULL,'100g',NULL,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,208,204,'100g',6,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,255,NULL,'100g',NULL,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,269,13.900,'100g',6,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,291,1.900,'100g',6,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,301,19,'100g',6,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,303,1.670,'100g',6,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,306,NULL,'100g',NULL,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,307,315,'100g',6,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,328,NULL,'100g',NULL,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,401,NULL,'100g',NULL,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,539,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,601,36,'100g',6,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,605,0,'100g',6,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121792,606,2.310,'100g',6,3,'2019-03-31','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (121868,203,5.410,'100g',6,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,204,13.5,'100g',6,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,205,64.900,'100g',6,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,207,NULL,'100g',NULL,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,208,405,'100g',6,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,255,NULL,'100g',NULL,3,'2019-04-04','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,269,24.300,'100g',6,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,291,2.700,'100g',6,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,301,27,'100g',6,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,303,2.700,'100g',6,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,306,159,'100g',6,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,307,135,'100g',6,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,328,NULL,'100g',NULL,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,401,NULL,'100g',NULL,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,539,18.900,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,601,0,'100g',6,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,605,0,'100g',6,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121868,606,4.050,'100g',6,3,'2019-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121869,203,5.560,'100g',6,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,204,13.900,'100g',6,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,205,66.700,'100g',6,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,207,NULL,'100g',NULL,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,208,417,'100g',6,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,255,NULL,'100g',NULL,3,'2019-04-04','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,269,25,'100g',6,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,291,2.800,'100g',6,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,301,25,'100g',6,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,303,2.780,'100g',6,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,306,114,'100g',6,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,307,125,'100g',6,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,328,NULL,'100g',NULL,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,401,NULL,'100g',NULL,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,539,22.200,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,601,0,'100g',6,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,605,0,'100g',6,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121869,606,4.170,'100g',6,3,'2019-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121878,203,13.100,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,204,11.700,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,205,23.400,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,207,NULL,'100g',NULL,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,208,241,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,255,NULL,'100g',NULL,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,269,4.800,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,291,2.100,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,301,228,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,303,1.5,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,306,345,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,307,393,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,320,69.000,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,328,0,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,401,0,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,601,31,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,605,0,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121878,606,5.5,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,203,13.100,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,204,11.700,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,205,23.400,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,207,NULL,'100g',NULL,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,208,241,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,255,NULL,'100g',NULL,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,269,4.800,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,291,2.100,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,301,269,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,303,1.400,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,306,324,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,307,324,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,320,62.100,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,328,0,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,401,0,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,601,31,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,605,0,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121879,606,5.5,'100g',6,3,'2019-04-02','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121887,203,12.100,'100g',6,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,204,9.200,'100g',6,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,205,23.400,'100g',6,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,207,NULL,'100g',NULL,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,208,220,'100g',6,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,255,NULL,'100g',NULL,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,269,5.700,'100g',6,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,291,2.100,'100g',6,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,301,170,'100g',6,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,303,1.600,'100g',6,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,306,333,'100g',6,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,307,362,'100g',6,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,328,0,'100g',6,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,401,0,'100g',6,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,539,1,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,601,25,'100g',6,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,605,0,'100g',6,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121887,606,3.5,'100g',6,3,'2019-04-02','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (121893,203,7.140,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,204,1.790,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,205,42.900,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,207,NULL,'100g',NULL,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,208,214,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,255,NULL,'100g',NULL,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,269,0,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,291,3.600,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,301,36,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,303,2.5,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,306,36,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,307,286,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,320,0.000,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,328,0,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,401,0,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,601,0,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,605,0,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121893,606,0,'100g',6,3,'2019-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (121896,203,4.650,'100g',6,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,204,14.000,'100g',6,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,205,65.100,'100g',6,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,207,NULL,'100g',NULL,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,208,442,'100g',6,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,255,NULL,'100g',NULL,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,269,32.600,'100g',6,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,291,2.300,'100g',6,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,301,23,'100g',6,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,303,2.330,'100g',6,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,306,228,'100g',6,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,307,186,'100g',6,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,328,0,'100g',6,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,401,NULL,'100g',NULL,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,539,32.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,601,12,'100g',6,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,605,0,'100g',6,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121896,606,4.650,'100g',6,3,'2019-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121908,203,14.200,'100g',6,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,204,8.850,'100g',6,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,205,17.700,'100g',6,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,207,NULL,'100g',NULL,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,208,204,'100g',6,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,255,NULL,'100g',NULL,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,269,0.880,'100g',6,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,291,1.800,'100g',6,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,301,18,'100g',6,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,303,1.420,'100g',6,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,306,283,'100g',6,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,307,319,'100g',6,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,328,0,'100g',6,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,401,NULL,'100g',NULL,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,539,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,601,40,'100g',6,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,605,0,'100g',6,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121908,606,0.880,'100g',6,3,'2019-04-02','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121909,203,14.700,'100g',6,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,204,8.820,'100g',6,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,205,13.700,'100g',6,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,207,NULL,'100g',NULL,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,208,186,'100g',6,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,255,NULL,'100g',NULL,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,269,0,'100g',6,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,291,1,'100g',6,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,301,15,'100g',6,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,303,0.980,'100g',6,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,306,369,'100g',6,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,307,353,'100g',6,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,328,0,'100g',6,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,401,0,'100g',6,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,601,44,'100g',6,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,605,0,'100g',6,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121909,606,0.980,'100g',6,3,'2019-04-02','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (121941,203,14.300,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,204,7.790,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,205,14.300,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,208,195,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,269,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,291,1.300,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,301,13,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,303,1.170,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,306,221,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,307,351,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,328,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,601,58,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121941,606,1.300,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121943,203,6.900,'100g',6,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,204,3.450,'100g',6,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,205,34.5,'100g',6,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,207,NULL,'100g',NULL,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,208,190,'100g',6,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,255,NULL,'100g',NULL,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,269,0,'100g',6,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,291,0,'100g',6,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,301,16,'100g',6,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,303,1.720,'100g',6,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,306,129,'100g',6,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,307,52,'100g',6,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,320,NULL,'100g',NULL,3,'2024-12-12','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,328,0,'100g',6,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,401,NULL,'100g',NULL,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,539,0,'100g',6,3,'2022-04-01','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,601,0,'100g',6,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,605,0,'100g',6,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121943,606,0,'100g',6,3,'2020-02-21','2023-07-13');
INSERT INTO `cndb_nutval` VALUES (121954,203,5,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,204,8.75,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,205,40,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,207,NULL,'100g',NULL,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,208,250,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,255,NULL,'100g',NULL,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,269,12.5,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,291,0,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,301,125,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,303,2,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,306,100,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,307,262,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,320,NULL,'100g',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,328,NULL,'100g',NULL,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,401,NULL,'100g',NULL,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,539,10,'100g',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,601,12,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,605,0,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121954,606,1.25,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (121955,203,5,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,204,8.75,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,205,37.5,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,207,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,208,250,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,255,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,269,7.5,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,291,0,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,301,125,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,303,2,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,306,125,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,307,288,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,328,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,401,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,539,5,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,601,12,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,605,0,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121955,606,1.25,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121956,203,5.410,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,204,8.110,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,205,32.400,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,207,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,208,216,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,255,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,269,5.410,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,291,5.400,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,301,81,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,303,1.890,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,306,135,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,307,284,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,328,1,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,401,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,539,2.700,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,601,14,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,605,0,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121956,606,0,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,203,5.410,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,204,4.050,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,205,40.5,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,207,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,208,216,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,255,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,269,13.5,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,291,5.400,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,301,81,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,303,1.890,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,306,108,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,307,297,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,328,0,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,401,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,539,5.400,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,601,14,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,605,0,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121957,606,0,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121958,203,5.410,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,204,4.730,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,205,43.200,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,207,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,208,216,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,255,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,269,16.200,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,291,1.400,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,301,54,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,303,1.620,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,306,108,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,307,311,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,328,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,401,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,539,13.5,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,601,14,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,605,0,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121958,606,0.680,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121959,203,5.410,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,204,4.730,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,205,41.900,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,207,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,208,230,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,255,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,269,16.200,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,291,1.400,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,301,68,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,303,1.760,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,306,108,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,307,311,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,328,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,401,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,539,12.200,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,601,14,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,605,0,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121959,606,0.680,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,203,5.410,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,204,4.730,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,205,41.900,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,207,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,208,230,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,255,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,269,16.200,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,291,1.400,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,301,68,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,303,1.760,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,306,108,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,307,311,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,328,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,401,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,539,12.200,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,601,14,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,605,0,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121961,606,0.680,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121962,203,6.410,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,204,10.300,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,205,46.200,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,207,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,208,295,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,255,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,269,16.700,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,291,3.800,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,301,38,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,303,1.790,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,306,13,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,307,231,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,328,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,401,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,539,16.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,601,0,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,605,0,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121962,606,4.490,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,203,5.130,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,204,18,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,205,42.300,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,207,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,208,359,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,255,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,269,14.100,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,291,1.300,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,301,90,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,303,2.050,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,306,38,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,307,449,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,328,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,401,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,539,14.100,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,601,0,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,605,0,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121963,606,7.690,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (121965,203,4.230,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,204,8.450,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,205,46.5,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,208,268,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,269,23.900,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,291,1.400,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,301,80,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,303,1.410,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,306,77,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,307,225,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,539,23.900,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,601,35,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121965,606,0.700,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121966,203,7.140,'100g',6,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,204,17.900,'100g',6,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,205,50,'100g',6,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,207,NULL,'100g',NULL,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,208,393,'100g',6,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,255,NULL,'100g',NULL,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,269,10.700,'100g',6,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,291,7.100,'100g',6,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,301,0,'100g',6,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,303,2.5,'100g',6,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,306,321,'100g',6,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,307,196,'100g',6,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,328,0,'100g',6,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,401,NULL,'100g',NULL,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,539,7.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,601,0,'100g',6,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,605,0,'100g',6,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121966,606,3.570,'100g',6,3,'2020-02-21','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (121972,203,14.700,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,204,11.800,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,205,19.100,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,208,235,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,269,4.410,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,291,1.5,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,301,118,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,303,1.470,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,306,265,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,307,529,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,539,1.5,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,601,37,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121972,606,5.150,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121985,203,15.100,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,204,8.400,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,205,26.900,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,207,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,208,235,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,255,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,269,1.680,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,291,1.700,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,301,57,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,303,3.360,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,306,252,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,307,395,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,328,0,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,401,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,539,1.700,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,601,34,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,605,0,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121985,606,2.520,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (121986,203,15,'100g',6,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,204,8.270,'100g',6,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,205,24.800,'100g',6,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,207,NULL,'100g',NULL,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,208,241,'100g',6,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,255,NULL,'100g',NULL,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,269,2.260,'100g',6,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,291,1.5,'100g',6,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,301,120,'100g',6,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,303,2.630,'100g',6,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,306,165,'100g',6,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,307,466,'100g',6,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,320,NULL,'100g',NULL,3,'2024-12-12','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,328,NULL,'100g',NULL,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,401,NULL,'100g',NULL,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,539,1.5,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,601,38,'100g',6,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,605,0,'100g',6,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121986,606,3.760,'100g',6,3,'2020-02-21','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (121987,203,13.400,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,204,6.720,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,205,26.900,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,207,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,208,235,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,255,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,269,1.680,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,291,1.700,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,301,50,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,303,2.940,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,306,101,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,307,395,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,328,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,401,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,539,1.700,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,601,34,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,605,0,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121987,606,2.520,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121988,203,15,'100g',6,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,204,8.270,'100g',6,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,205,24.800,'100g',6,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,207,NULL,'100g',NULL,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,208,241,'100g',6,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,255,NULL,'100g',NULL,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,269,2.260,'100g',6,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,291,1.5,'100g',6,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,301,120,'100g',6,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,303,2.630,'100g',6,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,306,165,'100g',6,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,307,466,'100g',6,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,320,NULL,'100g',NULL,3,'2024-12-12','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,328,0,'100g',6,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,401,NULL,'100g',NULL,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,539,1.5,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,601,38,'100g',6,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,605,0,'100g',6,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121988,606,3.760,'100g',6,3,'2020-02-21','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (121989,203,5,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,204,14.000,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,205,40,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,208,300,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,269,15,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,291,2,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,301,59,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,303,1.600,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,306,45.000,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,307,310,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,539,15,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,601,20,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121989,606,2,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121990,203,12.400,'100g',6,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,204,8.640,'100g',6,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,205,22.200,'100g',6,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,207,NULL,'100g',NULL,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,208,210,'100g',6,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,255,NULL,'100g',NULL,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,269,7.410,'100g',6,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,291,1.200,'100g',6,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,301,122,'100g',6,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,303,0.930,'100g',6,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,306,198,'100g',6,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,307,395,'100g',6,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,328,0,'100g',6,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,401,NULL,'100g',NULL,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,539,7.400,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,601,37,'100g',6,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,605,0,'100g',6,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121990,606,2.470,'100g',6,3,'2020-02-21','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (121992,203,4.420,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,204,11.5,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,205,52.200,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,208,327,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,269,29.200,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,291,1.800,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,301,47,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,303,1.770,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,306,106,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,307,274,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,539,29.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,601,18,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121992,606,2.210,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (121993,203,7.140,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,204,10.700,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,205,42.900,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,207,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,208,286,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,255,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,269,7.140,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,291,3.600,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,301,89,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,303,3.570,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,306,229,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,307,857,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,328,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,401,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,539,3.600,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,601,0,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,605,0,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121993,606,5.360,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,203,7.140,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,204,10.700,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,205,42.900,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,207,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,208,286,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,255,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,269,7.140,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,291,3.600,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,301,89,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,303,3.570,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,306,229,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,307,857,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,328,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,401,NULL,'100g',NULL,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,539,3.600,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,601,0,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,605,0,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (121994,606,5.360,'100g',6,3,'2020-02-21','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122011,203,21.400,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,204,21.400,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,205,3.570,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,207,NULL,'100g',NULL,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,208,286,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,255,NULL,'100g',NULL,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,269,0,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,291,0,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,301,604,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,303,0,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,306,79,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,307,714,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,320,NULL,'100g',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,328,NULL,'100g',NULL,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,401,NULL,'100g',NULL,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,539,0,'100g',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,601,54,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,605,0,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122011,606,12.5,'100g',6,3,'2020-02-21','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122013,203,21.400,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,204,32.100,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,205,3.570,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,208,393,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,269,3.570,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,291,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,301,607,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,303,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,306,179,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,307,1250,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,601,89,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122013,606,17.900,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,203,21.400,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,204,32.100,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,205,3.570,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,208,393,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,269,3.570,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,291,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,301,607,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,303,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,306,179,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,307,1250,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,601,89,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122016,606,17.900,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,203,28.600,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,204,21.400,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,205,3.570,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,208,321,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,269,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,291,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,301,714,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,303,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,306,71,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,307,643,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,601,71,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122017,606,12.5,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,203,28.600,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,204,21.400,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,205,3.570,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,208,321,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,269,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,291,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,301,714,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,303,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,306,89,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,307,643,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,601,54,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122018,606,12.5,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,203,25,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,204,21.400,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,205,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,208,286,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,269,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,291,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,301,714,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,303,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,306,86,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,307,714,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,601,54,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122019,606,12.5,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,203,25,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,204,10.700,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,205,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,208,214,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,269,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,291,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,301,714,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,303,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,306,82,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,307,714,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,601,36,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122020,606,7.140,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122023,203,25,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,204,32.100,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,205,0,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,207,NULL,'100g',NULL,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,208,393,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,255,NULL,'100g',NULL,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,269,0,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,291,0,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,301,729,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,303,0.710,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,306,71,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,307,643,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,328,1,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,401,NULL,'100g',NULL,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,539,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,601,107,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,605,0,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122023,606,21.400,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122024,203,25,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,204,32.100,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,205,3.570,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,208,393,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,269,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,291,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,301,693,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,303,0.710,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,306,107,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,307,607,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,328,1,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,601,107,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122024,606,17.900,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,203,22.700,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,204,31.800,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,205,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,208,364,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,269,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,291,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,301,695,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,303,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,306,68,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,307,591,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,601,91,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122025,606,20.400,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,203,22.700,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,204,27.300,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,205,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,208,318,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,269,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,291,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,301,732,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,303,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,306,136,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,307,682,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,601,68,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122027,606,15.900,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,203,27.300,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,204,31.800,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,205,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,208,364,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,269,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,291,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,301,859,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,303,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,306,68,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,307,182,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,601,91,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122028,606,18.200,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,203,22.700,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,204,27.300,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,205,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,208,364,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,269,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,291,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,301,723,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,303,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,306,68,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,307,636,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,601,91,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122029,606,18.200,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122031,203,25,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,204,21.400,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,205,7.140,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,207,NULL,'100g',NULL,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,208,286,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,255,NULL,'100g',NULL,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,269,3.570,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,291,0,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,301,714,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,303,0.360,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,306,214,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,307,679,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,328,0,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,401,NULL,'100g',NULL,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,539,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,601,71,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,605,0,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122031,606,10.700,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122032,203,21.400,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,204,32.100,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,205,3.570,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,208,393,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,269,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,291,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,301,714,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,303,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,306,71,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,307,679,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,328,1,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,601,107,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122032,606,17.900,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,203,25,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,204,21.400,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,205,7.140,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,208,286,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,269,3.570,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,291,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,301,714,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,303,0.360,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,306,214,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,307,679,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,601,71,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122036,606,10.700,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,203,28.600,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,204,21.400,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,205,3.570,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,208,321,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,269,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,291,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,301,714,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,303,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,306,71,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,307,750,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,601,71,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122037,606,12.5,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,203,25,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,204,32.100,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,205,3.570,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,208,393,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,269,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,291,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,301,750,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,303,0.360,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,306,71,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,307,643,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,328,1,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,601,89,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122039,606,17.900,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122040,203,12.300,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,204,10.400,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,205,24.700,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,207,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,208,234,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,255,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,269,1.950,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,291,1.900,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,301,195,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,303,1.170,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,306,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,307,390,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,328,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,401,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,601,32,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,605,0,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122040,606,5.190,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122041,203,11.300,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,204,9.520,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,205,22.600,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,207,NULL,'100g',NULL,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,208,214,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,255,NULL,'100g',NULL,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,269,1.790,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,291,1.800,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,301,179,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,303,1.070,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,306,NULL,'100g',NULL,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,307,357,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,328,0,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,401,NULL,'100g',NULL,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,539,1.200,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,601,30,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,605,0,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122041,606,4.760,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122042,203,13,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,204,10.400,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,205,24.700,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,207,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,208,240,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,255,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,269,1.950,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,291,1.900,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,301,195,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,303,1.170,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,306,45,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,307,377,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,328,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,401,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,539,1.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,601,36,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,605,0,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122042,606,5.840,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122052,203,5.880,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,204,11.800,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,205,52.900,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,207,NULL,'100g',NULL,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,208,333,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,255,NULL,'100g',NULL,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,269,25.5,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,291,2,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,301,78,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,303,2.120,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,306,137,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,307,333,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,328,0,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,401,0,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,539,23.5,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,601,39,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,605,0,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122052,606,1.960,'100g',6,3,'2020-02-21','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (122063,203,6.980,'100g',6,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,204,11.600,'100g',6,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,205,58.100,'100g',6,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,207,NULL,'100g',NULL,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,208,372,'100g',6,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,255,NULL,'100g',NULL,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,269,30.200,'100g',6,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,291,2.300,'100g',6,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,301,47,'100g',6,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,303,2.510,'100g',6,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,306,163,'100g',6,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,307,326,'100g',6,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,320,NULL,'100g',NULL,3,'2024-12-12','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,328,NULL,'100g',NULL,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,401,NULL,'100g',NULL,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,539,30.200,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,601,23,'100g',6,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,605,0,'100g',6,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122063,606,3.490,'100g',6,3,'2020-02-21','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122065,203,4.650,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,204,10.500,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,205,53.500,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,207,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,208,349.000,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,255,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,269,32.600,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,291,2.300,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,301,0.000,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,303,2.510,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,306,63,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,307,349.000,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,328,0,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,401,0,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,601,12.000,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,605,0,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122065,606,3.490,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,203,4.710,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,204,8.240,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,205,45.900,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,207,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,208,271,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,255,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,269,18.800,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,291,2.400,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,301,24,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,303,1.270,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,306,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,307,282,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,328,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,401,0,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,601,24,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,605,0,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122068,606,1.180,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122070,203,5.880,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,204,9.800,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,205,47.100,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,207,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,208,294,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,255,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,269,21.600,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,291,3.900,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,301,39,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,303,2.120,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,306,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,307,294,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,328,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,401,0,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,539,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,601,29,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,605,0,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122070,606,1.960,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122075,203,7.410,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,204,11.100,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,205,63.000,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,207,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,208,370.000,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,255,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,269,33.300,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,291,3.700,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,301,37.000,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,303,3.330,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,306,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,307,407.000,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,328,NULL,'100g',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,401,0,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,601,46.000,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,605,0,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122075,606,3.700,'100g',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122076,203,4.630,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,204,4.630,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,205,38.900,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,207,NULL,'100g',NULL,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,208,222,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,255,NULL,'100g',NULL,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,269,16.700,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,291,1.900,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,301,19,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,303,1.670,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,306,NULL,'100g',NULL,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,307,306,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,328,NULL,'100g',NULL,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,401,NULL,'100g',NULL,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,539,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,601,32,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,605,0,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122076,606,2.310,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122077,203,2.860,'100ml',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,204,1.220,'100ml',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,205,6.120,'100ml',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,207,NULL,'100ml',NULL,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,208,49.000,'100ml',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,255,NULL,'100ml',NULL,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,269,0.820,'100ml',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,291,0.400,'100ml',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,301,8,'100ml',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,303,0.410,'100ml',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,306,73.000,'100ml',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,307,159.000,'100ml',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,320,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,328,0,'100ml',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,401,NULL,'100ml',NULL,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,539,0,'100ml',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,601,6.000,'100ml',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,605,0,'100ml',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122077,606,0.410,'100ml',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122079,203,0.830,'100ml',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,204,0.620,'100ml',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,205,5.830,'100ml',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,207,NULL,'100ml',NULL,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,208,33,'100ml',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,255,NULL,'100ml',NULL,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,269,3.75,'100ml',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,291,1.200,'100ml',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,301,17,'100ml',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,303,0.420,'100ml',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,306,188,'100ml',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,307,162,'100ml',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,320,NULL,'100ml',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,328,0,'100ml',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,401,NULL,'100ml',NULL,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,539,1.200,'100ml',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,601,2,'100ml',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,605,0,'100ml',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122079,606,0.420,'100ml',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122080,203,9.520,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,204,16.700,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,205,66.700,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,207,NULL,'100g',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,208,476,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,255,NULL,'100g',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,269,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,291,4.800,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,301,95,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,303,3.330,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,306,238,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,307,762,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,328,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,401,NULL,'100g',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,601,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,605,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122080,606,2.380,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,203,0.970,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,204,0.970,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,205,4.370,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,207,NULL,'100g',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,208,29,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,255,NULL,'100g',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,269,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,291,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,301,5,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,303,0.150,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,306,19,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,307,383,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,328,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,401,NULL,'100g',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,601,7,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,605,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122081,606,0.240,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,203,7.140,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,204,16.100,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,205,75,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,207,NULL,'100g',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,208,464,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,255,NULL,'100g',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,269,28.600,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,291,7.100,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,301,36,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,303,2.140,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,306,214,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,307,500,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,328,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,401,NULL,'100g',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,539,28.600,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,601,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,605,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122089,606,3.570,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,203,7.140,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,204,16.100,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,205,75,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,207,NULL,'100g',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,208,464,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,255,NULL,'100g',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,269,28.600,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,291,3.600,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,301,36,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,303,2.140,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,306,214,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,307,464,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,328,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,401,NULL,'100g',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,539,28.600,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,601,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,605,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122090,606,3.570,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122092,203,1.25,'100ml',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,204,0,'100ml',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,205,5.830,'100ml',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,207,NULL,'100ml',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,208,29,'100ml',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,255,NULL,'100ml',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,269,1.670,'100ml',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,291,1.700,'100ml',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,301,17,'100ml',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,303,0.330,'100ml',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,306,100,'100ml',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,307,162,'100ml',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,320,NULL,'100ml',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,328,0,'100ml',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,401,NULL,'100ml',NULL,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,539,0.400,'100ml',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,601,0,'100ml',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,605,0,'100ml',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122092,606,0,'100ml',6,3,'2020-02-21','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122096,203,1.540,'100ml',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,204,2.310,'100ml',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,205,8.460,'100ml',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,207,NULL,'100ml',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,208,62.000,'100ml',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,255,NULL,'100ml',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,269,6.150,'100ml',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,291,2.300,'100ml',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,301,38.000,'100ml',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,303,1.150,'100ml',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,306,354.000,'100ml',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,307,31.000,'100ml',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,328,0,'100ml',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,401,NULL,'100ml',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,539,0,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,601,0,'100ml',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,605,0,'100ml',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122096,606,0.380,'100ml',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122109,203,2.450,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,204,3.070,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,205,33.100,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,207,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,208,172,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,255,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,269,11.700,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,291,1.800,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,301,80.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,303,2.210,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,306,165,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,307,175,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,328,2.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,401,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,539,3.700,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,601,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,605,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122109,606,0.610,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,203,1.800,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,204,2.690,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,205,33.500,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,207,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,208,162,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,255,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,269,15.600,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,291,1.800,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,301,59.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,303,1.920,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,306,101.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,307,141.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,328,1,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,401,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,539,7.800,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,601,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,605,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122110,606,0.600,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122111,203,12.300,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,204,12.300,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,205,5.260,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,207,NULL,'100g',NULL,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,208,175,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,255,NULL,'100g',NULL,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,269,3.510,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,291,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,301,358,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,303,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,306,258,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,307,333,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,328,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,401,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,539,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,601,44,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,605,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122111,606,6.140,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,203,12.300,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,204,12.300,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,205,5.260,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,207,NULL,'100g',NULL,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,208,175,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,255,NULL,'100g',NULL,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,269,3.510,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,291,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,301,358,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,303,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,306,258,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,307,333,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,320,9.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,328,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,401,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,539,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,601,44,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,605,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122112,606,6.140,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122113,203,1.590,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,204,1.190,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,205,20.600,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,207,NULL,'100g',NULL,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,208,99,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,255,NULL,'100g',NULL,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,269,13.5,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,291,0.400,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,301,122,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,303,0.400,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,306,123,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,307,50,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,328,2,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,401,0,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,539,5.600,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,601,0,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,605,0,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122113,606,0.400,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,203,16,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,204,15.200,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,205,24.800,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,207,NULL,'100g',NULL,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,208,288,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,255,NULL,'100g',NULL,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,269,5.600,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,291,1.600,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,301,338,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,303,0.800,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,306,522,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,307,512,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,328,0,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,401,0,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,539,2.400,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,601,24,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,605,0,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122114,606,4.800,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122115,203,10,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,204,7.060,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,205,16.5,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,207,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,208,171,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,255,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,269,3.530,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,291,1.200,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,301,306,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,303,0.590,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,306,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,307,324,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,328,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,401,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,539,0,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,601,24,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,605,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122115,606,4.710,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,203,4.530,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,204,10.400,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,205,30.200,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,207,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,208,226.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,255,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,269,17.400,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,291,3.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,301,36,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,303,3.090,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,306,297.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,307,179.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,328,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,401,0.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,539,1.100,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,601,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,605,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122116,606,1.130,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,203,4.5,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,204,10.400,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,205,14.200,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,207,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,208,169,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,255,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,269,5.790,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,291,1.600,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,301,113,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,303,2.25,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,306,205,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,307,320,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,328,1,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,401,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,539,0.600,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,601,13,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,605,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122117,606,3.220,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122118,203,1.440,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,204,3.590,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,205,28.200,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,207,NULL,'100g',NULL,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,208,148,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,255,NULL,'100g',NULL,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,269,15.800,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,291,1.400,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,301,13,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,303,1.100,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,306,93.000,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,307,77.000,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,328,0,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,401,0,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,539,10.000,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,601,7.000,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,605,0,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122118,606,0.720,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122120,203,1.680,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,204,3.630,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,205,34.600,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,207,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,208,179,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,255,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,269,15.600,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,291,2.200,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,301,155,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,303,2.960,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,306,121,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,307,92,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,328,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,401,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,539,8.900,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,601,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,605,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122120,606,0.840,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122123,203,7.140,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,204,12.5,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,205,67.900,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,207,NULL,'100g',NULL,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,208,393,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,255,NULL,'100g',NULL,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,269,7.140,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,291,7.100,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,301,18,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,303,17.900,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,306,300,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,307,571,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,328,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,401,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,539,7.100,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,601,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,605,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122123,606,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122124,203,15.600,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,204,9.020,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,205,27.900,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,207,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,208,254.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,255,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,269,2.460,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,291,2.5,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,301,295.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,303,1.890,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,306,172.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,307,557.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,328,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,401,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,539,1.600,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,601,29,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,605,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122124,606,4.100,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,203,17.700,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,204,10.600,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,205,30.100,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,207,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,208,274,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,255,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,269,2.650,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,291,2.700,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,301,274.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,303,2.210,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,306,150.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,307,522.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,328,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,401,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,539,1.800,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,601,22.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,605,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122125,606,4.420,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,203,15.5,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,204,9.480,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,205,29.300,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,207,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,208,259.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,255,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,269,2.590,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,291,2.600,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,301,319.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,303,1.980,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,306,181.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,307,474.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,328,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,401,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,539,1.700,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,601,22,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,605,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122126,606,4.310,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,203,14.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,204,8.530,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,205,27.100,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,207,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,208,233,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,255,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,269,2.330,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,291,3.100,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,301,287.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,303,1.860,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,306,186.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,307,419.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,328,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,401,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,539,1.600,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,601,19.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,605,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122127,606,3.880,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122128,203,15,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,204,10.200,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,205,31.5,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,207,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,208,268,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,255,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,269,2.360,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,291,2.400,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,301,242,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,303,2.360,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,306,76,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,307,528,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,328,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,401,0,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,539,1.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,601,28,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,605,0,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122128,606,4.720,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,203,12.300,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,204,12.300,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,205,33.300,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,207,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,208,281,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,255,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,269,3.510,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,291,3.5,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,301,193,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,303,1.75,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,306,216,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,307,702,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,328,NULL,'100g',NULL,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,401,0,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,539,1.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,601,105,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,605,0,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122129,606,6.140,'100g',6,3,'2020-02-21','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122130,203,2.330,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,204,4.420,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,205,29.800,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,207,NULL,'100g',NULL,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,208,158,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,255,NULL,'100g',NULL,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,269,15.400,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,291,1.900,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,301,20,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,303,1.070,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,306,95.000,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,307,102.000,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,328,0,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,401,0,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,539,9.800,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,601,9.000,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,605,0,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122130,606,1.160,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,203,2.330,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,204,4.190,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,205,28.400,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,207,NULL,'100g',NULL,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,208,153.000,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,255,NULL,'100g',NULL,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,269,14.400,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,291,1.900,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,301,19.000,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,303,1.070,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,306,98.000,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,307,107.000,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,328,0,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,401,0,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,539,8.800,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,601,9,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,605,0,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122131,606,0.930,'100g',6,3,'2020-02-21','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122132,203,6.450,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,204,14.5,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,205,67.700,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,207,NULL,'100g',NULL,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,208,387,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,255,NULL,'100g',NULL,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,269,19.400,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,291,6.5,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,301,29,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,303,3.230,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,306,203,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,307,371,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,328,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,401,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,539,19.400,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,601,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,605,0,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122132,606,4.840,'100g',6,3,'2020-02-21','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122133,203,16.400,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,204,10.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,205,26.400,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,207,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,208,236,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,255,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,269,3.640,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,291,1.800,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,301,373.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,303,0.910,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,306,564.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,307,627.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,328,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,401,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,539,0.900,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,601,27,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,605,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122133,606,4.550,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,203,14.400,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,204,16.200,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,205,24.300,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,207,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,208,297.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,255,NULL,'100g',NULL,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,269,1.800,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,291,1.800,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,301,324.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,303,0.900,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,306,126.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,307,658.000,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,328,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,401,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,539,0.900,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,601,45,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,605,0,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122134,606,9.010,'100g',6,3,'2020-02-21','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122135,203,14.600,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,204,4.460,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,205,32.400,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,208,225,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,269,9.610,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,291,3.400,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,301,61,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,303,2.530,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,306,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,307,514,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,328,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,401,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,601,26,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,605,0.050,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122135,606,0.800,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,203,10.800,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,204,10.700,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,205,6.510,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,208,169,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,269,0.980,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,291,0.400,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,301,135,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,303,0.700,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,306,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,307,414,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,328,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,401,8.700,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,539,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,601,114,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,605,0.120,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122136,606,4.480,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,203,7.060,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,204,3.530,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,205,21.200,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,208,141,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,269,3.530,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,291,5.900,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,301,48,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,303,2.350,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,306,236,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,307,212,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,601,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122225,606,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122226,203,2.690,'100g',6,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,204,0,'100g',6,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,205,80.600,'100g',6,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,207,NULL,'100g',NULL,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,208,349,'100g',6,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,255,NULL,'100g',NULL,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,269,64.400,'100g',6,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,291,2.700,'100g',6,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,301,54,'100g',6,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,303,1.610,'100g',6,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,306,752,'100g',6,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,307,27,'100g',6,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,328,NULL,'100g',NULL,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,401,NULL,'100g',NULL,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,539,0,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,601,0,'100g',6,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,605,0,'100g',6,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122226,606,0,'100g',6,3,'2020-02-21','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122227,203,8.700,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,204,13.000,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,205,65.200,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,207,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,208,391,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,255,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,269,8.700,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,291,4.300,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,301,17,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,303,17.400,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,306,296,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,307,543,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,328,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,401,NULL,'100g',NULL,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,539,8.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,601,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,605,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122227,606,0,'100g',6,3,'2020-02-21','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122230,203,3.530,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,204,1.760,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,205,14.100,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,207,NULL,'100g',NULL,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,208,94,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,255,NULL,'100g',NULL,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,269,0,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,291,4.700,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,301,29,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,303,1.180,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,306,11,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,307,224,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,320,5.000,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,328,0,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,401,0,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,539,1.200,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,601,0,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,605,0,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122230,606,0,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,203,11.5,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,204,8.900,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,205,27.400,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,207,NULL,'100g',NULL,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,208,229,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,255,NULL,'100g',NULL,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,269,7.600,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,291,2.5,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,301,178,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,303,1.600,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,306,344,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,307,255,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,320,31.800,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,328,0,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,401,0,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,539,2,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,601,15.900,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,605,0,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122243,606,3.200,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122244,203,11.300,'100g',6,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,204,9.200,'100g',6,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,205,23.400,'100g',6,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,207,NULL,'100g',NULL,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,208,220,'100g',6,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,255,NULL,'100g',NULL,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,269,6.400,'100g',6,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,291,2.100,'100g',6,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,301,199,'100g',6,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,303,1.5,'100g',6,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,306,319,'100g',6,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,307,312,'100g',6,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,328,0,'100g',6,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,401,0,'100g',6,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,539,1,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,601,21,'100g',6,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,605,0,'100g',6,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122244,606,4.300,'100g',6,3,'2020-02-21','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122245,203,0.800,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,204,0.000,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,205,5.600,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,207,NULL,'100g',NULL,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,208,36,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,255,NULL,'100g',NULL,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,269,1.600,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,291,1.600,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,301,14,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,303,0.800,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,306,122,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,307,104,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,328,0,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,401,NULL,'100g',NULL,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,601,0,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,605,0,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122245,606,0,'100g',6,3,'2020-02-21','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122255,203,21,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,204,2.340,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,205,4.670,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,207,NULL,'100g',NULL,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,208,117,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,255,NULL,'100g',NULL,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,269,1.170,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,291,0,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,301,0,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,303,NULL,'100g',NULL,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,306,NULL,'100g',NULL,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,307,362,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,328,NULL,'100g',NULL,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,401,NULL,'100g',NULL,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,539,NULL,'100g',NULL,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,601,53,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,605,0,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122255,606,0.470,'100g',6,3,'2020-02-21','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122266,203,7.020,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,204,1.75,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,205,43.900,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,207,NULL,'100g',NULL,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,208,0,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,255,NULL,'100g',NULL,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,269,1.75,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,291,5.300,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,301,18,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,303,2.460,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,306,53,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,307,298,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,328,0,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,401,0,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,539,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,601,0,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,605,0,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122266,606,0,'100g',6,3,'2020-02-21','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122267,203,13.300,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,204,8.850,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,205,15,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,207,NULL,'100g',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,208,186,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,255,NULL,'100g',NULL,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,269,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,291,1.800,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,301,14,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,303,0.880,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,306,284,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,307,336,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,328,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,401,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,601,40,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,605,0,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122267,606,0.880,'100g',6,3,'2020-02-21','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122268,203,14.200,'100g',6,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,204,8.850,'100g',6,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,205,17.700,'100g',6,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,207,NULL,'100g',NULL,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,208,204,'100g',6,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,255,NULL,'100g',NULL,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,269,0,'100g',6,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,291,1.800,'100g',6,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,301,18,'100g',6,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,303,1.060,'100g',6,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,306,301,'100g',6,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,307,310,'100g',6,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,320,NULL,'100g',NULL,3,'2024-12-12','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,328,0,'100g',6,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,401,NULL,'100g',NULL,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,539,0,'100g',6,3,'2022-04-01','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,601,40,'100g',6,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,605,0,'100g',6,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122268,606,0.880,'100g',6,3,'2020-02-21','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (122271,203,22.700,'100g',6,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,204,2.840,'100g',6,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,205,0,'100g',6,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,207,NULL,'100g',NULL,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,208,125,'100g',6,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,255,NULL,'100g',NULL,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,269,0,'100g',6,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,291,0,'100g',6,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,301,0,'100g',6,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,303,NULL,'100g',NULL,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,306,NULL,'100g',NULL,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,307,386,'100g',6,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,328,NULL,'100g',NULL,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,401,NULL,'100g',NULL,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,539,NULL,'100g',NULL,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,601,51,'100g',6,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,605,0,'100g',6,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122271,606,1.140,'100g',6,3,'2020-03-20','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122348,203,7.060,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,204,8.820,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,205,44.700,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,207,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,208,294,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,255,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,269,14.100,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,291,2.400,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,301,25,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,303,0.710,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,306,59,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,307,318,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,328,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,401,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,539,14.100,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,601,12,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,605,0,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122348,606,1.180,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122349,203,5.880,'100g',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,204,15.300,'100g',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,205,35.300,'100g',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,207,NULL,'100g',NULL,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,208,318.000,'100g',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,255,NULL,'100g',NULL,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,269,10.600,'100g',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,291,3.500,'100g',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,301,59.000,'100g',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,303,1.760,'100g',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,306,129.000,'100g',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,307,188.000,'100g',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,328,0,'100g',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,401,NULL,'100g',NULL,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,539,10.600,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,601,6.000,'100g',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,605,0,'100g',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122349,606,2.350,'100g',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122350,203,6.450,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,204,16.100,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,205,71,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,207,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,208,452,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,255,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,269,32.300,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,291,3.200,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,301,48,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,303,3.230,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,306,177.000,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,307,355,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,328,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,401,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,539,29,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,601,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,605,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122350,606,4.840,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,203,5.880,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,204,7.840,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,205,47.100,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,207,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,208,275,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,255,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,269,21.600,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,291,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,301,22,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,303,1.960,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,306,59,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,307,167,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,328,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,401,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,539,19.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,601,39,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,605,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122351,606,0.980,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,203,5.490,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,204,20.900,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,205,44,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,207,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,208,385,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,255,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,269,17.600,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,291,2.200,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,301,77,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,303,1.540,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,306,132,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,307,341,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,328,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,401,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,539,16.5,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,601,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,605,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122353,606,11,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122354,203,5.880,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,204,13.200,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,205,67.600,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,208,412,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,269,29.400,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,291,2.900,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,301,18,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,303,2.940,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,306,141,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,307,250,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,401,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,539,26.5,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,601,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122354,606,4.410,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122355,203,5.880,'100g',6,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,204,13.200,'100g',6,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,205,67.600,'100g',6,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,207,NULL,'100g',NULL,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,208,412,'100g',6,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,255,NULL,'100g',NULL,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,269,29.400,'100g',6,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,291,2.900,'100g',6,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,301,21,'100g',6,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,303,2.940,'100g',6,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,306,147.000,'100g',6,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,307,250,'100g',6,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,320,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,328,0,'100g',6,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,401,NULL,'100g',NULL,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,539,26.5,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,601,0,'100g',6,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,605,0,'100g',6,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122355,606,4.410,'100g',6,3,'2021-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (122356,203,5.880,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,204,13.200,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,205,67.600,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,207,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,208,412,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,255,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,269,29.400,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,291,2.900,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,301,24,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,303,2.940,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,306,179,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,307,221,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,328,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,401,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,539,23.5,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,601,0,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,605,0,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122356,606,2.940,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122357,203,5.880,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,204,13.200,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,205,67.600,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,207,NULL,'100g',NULL,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,208,412,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,255,NULL,'100g',NULL,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,269,29.400,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,291,2.900,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,301,24,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,303,2.940,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,306,176.000,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,307,250,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,328,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,401,NULL,'100g',NULL,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,539,23.5,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,601,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,605,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122357,606,4.410,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122358,203,10.700,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,204,14.300,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,205,57.100,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,208,418,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,269,21.400,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,291,7.100,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,301,29,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,303,3.570,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,306,221,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,307,193,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,401,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,539,17.900,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,601,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122358,606,1.790,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122359,203,7.140,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,204,14.300,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,205,53.600,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,207,NULL,'100g',NULL,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,208,393,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,255,NULL,'100g',NULL,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,269,14.300,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,291,7.100,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,301,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,303,2.5,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,306,321,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,307,196,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,328,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,401,NULL,'100g',NULL,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,539,10.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,601,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,605,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122359,606,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122360,203,7.020,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,204,14.000,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,205,52.600,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,207,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,208,386,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,255,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,269,14,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,291,7,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,301,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,303,2.460,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,306,316,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,307,211,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,328,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,401,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,539,7,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,601,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,605,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122360,606,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122361,203,7.020,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,204,14,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,205,52.600,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,207,NULL,'100g',NULL,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,208,386,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,255,NULL,'100g',NULL,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,269,14,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,291,7,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,301,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,303,2.460,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,306,316,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,307,211,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,328,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,401,NULL,'100g',NULL,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,539,10.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,601,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,605,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122361,606,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,203,7.020,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,204,14,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,205,56.100,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,207,NULL,'100g',NULL,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,208,386,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,255,NULL,'100g',NULL,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,269,14,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,291,7,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,301,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,303,2.460,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,306,316,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,307,158,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,328,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,401,NULL,'100g',NULL,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,539,10.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,601,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,605,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122362,606,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122363,203,7.140,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,204,14.300,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,205,57.100,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,208,393,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,269,14.300,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,291,7.100,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,301,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,303,2.5,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,306,321,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,307,161,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,401,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,539,10.700,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,601,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122363,606,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122364,203,2.420,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,204,4.350,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,205,30.900,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,208,169,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,269,17.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,291,1,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,301,14,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,303,0.480,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,306,117,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,307,94,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,401,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,539,10.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,601,10,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122364,606,0.240,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122365,203,2.560,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,204,4.620,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,205,30.800,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,207,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,208,169,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,255,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,269,15.900,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,291,1,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,301,17,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,303,0.360,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,306,96,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,307,100,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,328,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,401,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,539,9.200,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,601,0,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,605,0,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122365,606,1.030,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122366,203,2.050,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,204,5.640,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,205,34.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,208,185,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,269,19.5,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,291,1,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,301,17,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,303,0.310,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,306,110,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,307,115,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,401,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,539,11.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,601,5,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122366,606,1.790,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,203,1.560,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,204,2.810,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,205,24.100,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,208,119,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,269,14.100,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,291,0.900,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,301,12,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,303,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,306,107,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,307,62,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,401,114,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,539,3.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,601,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122367,606,0.780,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,203,1.490,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,204,2.680,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,205,25.900,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,208,128,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,269,16.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,291,0.900,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,301,10,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,303,0.300,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,306,102,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,307,61,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,401,108,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,539,7.100,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,601,6,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122368,606,0.300,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122369,203,7.020,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,204,1.750,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,205,42.100,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,207,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,208,211,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,255,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,269,7.020,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,291,7,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,301,25,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,303,3.510,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,306,202.000,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,307,439,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,328,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,401,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,539,3.5,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,601,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,605,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122369,606,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122370,203,11.100,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,204,4.630,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,205,53.700,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,207,NULL,'100g',NULL,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,208,296,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,255,NULL,'100g',NULL,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,269,5.560,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,291,3.700,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,301,93,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,303,2.960,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,306,167,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,307,556,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,328,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,401,NULL,'100g',NULL,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,539,3.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,601,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,605,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122370,606,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122371,203,8.770,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,204,2.630,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,205,49.100,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,207,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,208,263,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,255,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,269,3.510,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,291,5.300,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,301,70,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,303,2.980,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,306,123,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,307,456,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,328,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,401,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,539,1.800,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,601,0,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,605,0,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122371,606,0,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122372,203,10.700,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,204,3.570,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,205,53.600,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,208,286,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,269,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,291,3.600,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,301,36,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,303,3.210,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,306,71,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,307,339,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,401,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,601,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122372,606,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,203,8.770,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,204,2.630,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,205,47.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,208,263,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,269,1.75,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,291,1.800,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,301,53,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,303,2.810,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,306,70,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,307,316,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,401,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,601,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122373,606,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122385,203,14.300,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,204,7.940,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,205,18.200,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,207,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,208,198,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,255,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,269,1.590,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,291,1.600,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,301,173,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,303,1.110,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,306,230.000,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,307,508,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,328,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,401,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,601,67,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,605,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122385,606,2.380,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122386,203,12.800,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,204,6.380,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,205,30.800,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,207,NULL,'100g',NULL,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,208,223,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,255,NULL,'100g',NULL,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,269,4.260,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,291,2.100,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,301,223,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,303,1.170,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,306,191,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,307,511,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,320,NULL,'100g',NULL,3,'2024-12-12','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,328,NULL,'100g',NULL,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,401,NULL,'100g',NULL,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,539,4.300,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,601,21,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,605,0,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122386,606,2.130,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122387,203,12.100,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,204,9.090,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,205,30.300,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,208,253,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,269,4.040,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,291,2,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,301,263,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,303,1.010,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,306,182,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,307,677,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,401,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,539,4,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,601,30,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122387,606,3.030,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,203,17.200,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,204,10.200,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,205,25.800,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,208,250,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,269,4.510,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,291,1.600,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,301,350,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,303,2.460,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,306,319,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,307,652,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,401,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,539,3.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,601,31,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122391,606,4.710,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122392,203,14.200,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,204,5.310,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,205,24.800,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,207,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,208,221,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,255,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,269,3.540,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,291,1.800,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,301,106,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,303,1.770,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,306,239,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,307,363,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,328,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,401,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,539,3.5,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,601,31,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,605,0,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122392,606,2.210,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122393,203,15.600,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,204,7.030,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,205,22.700,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,207,NULL,'100g',NULL,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,208,227,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,255,NULL,'100g',NULL,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,269,3.910,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,291,1.600,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,301,172,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,303,1.560,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,306,281,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,307,430,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,320,NULL,'100g',NULL,3,'2024-12-12','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,328,NULL,'100g',NULL,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,401,NULL,'100g',NULL,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,539,3.100,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,601,35,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,605,0,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122393,606,3.520,'100g',6,3,'2021-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (122394,203,13.700,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,204,6.870,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,205,22.900,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,207,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,208,206,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,255,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,269,1.530,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,291,1.5,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,301,55,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,303,1.910,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,306,215,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,307,427,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,328,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,401,NULL,'100g',NULL,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,539,1.5,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,601,31,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,605,0,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122394,606,2.290,'100g',6,3,'2021-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (122395,203,14.300,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,204,15.100,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,205,24.400,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,207,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,208,286,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,255,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,269,4.200,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,291,2.5,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,301,361,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,303,1.090,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,306,235,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,307,555,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,328,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,401,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,539,1.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,601,25,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,605,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122395,606,8.400,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122409,203,9.520,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,204,16.700,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,205,66.700,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,207,NULL,'100g',NULL,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,208,476,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,255,NULL,'100g',NULL,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,269,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,291,4.800,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,301,143,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,303,4.290,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,306,143,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,307,857,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,328,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,401,NULL,'100g',NULL,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,601,24,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,605,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122409,606,2.380,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122417,203,12.300,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,204,10.5,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,205,33.300,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,208,281,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,269,1.75,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,291,3.5,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,301,193,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,303,1.75,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,306,204,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,307,544,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,401,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,539,1.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,601,105,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122417,606,5.260,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122420,203,6.030,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,204,13.200,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,205,27.200,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,208,254,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,269,18.100,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,291,2.200,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,301,30,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,303,1.510,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,306,264,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,307,282,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,328,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,539,0,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,601,6,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122420,606,2.800,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122421,203,3.030,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,204,9.850,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,205,20.900,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,207,NULL,'100g',NULL,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,208,179,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,255,NULL,'100g',NULL,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,269,12.400,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,291,2.400,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,301,14,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,303,0.700,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,306,131,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,307,109,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,328,0,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,401,0,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,539,4.200,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,601,0,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,605,0,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122421,606,1.210,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122423,203,3.990,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,204,7.520,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,205,16.900,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,208,147,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,269,11.400,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,291,1.200,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,301,13,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,303,0.830,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,306,128,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,307,176,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,320,0.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,328,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,539,3.100,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,601,6,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122423,606,1.230,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122424,203,2.900,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,204,9,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,205,28.5,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,208,203,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,269,15.700,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,291,2.900,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,301,7,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,303,0.580,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,306,103,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,307,119,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,401,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,539,7.5,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,601,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122424,606,0.580,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122425,203,1.650,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,204,3.570,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,205,35.200,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,208,170,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,269,18.100,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,291,2.200,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,301,81,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,303,1.590,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,306,153,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,307,118.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,328,1.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,539,11.000,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,601,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122425,606,0.820,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,203,1.600,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,204,3.190,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,205,36.700,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,208,176.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,269,18.100,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,291,2.100,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,301,73,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,303,1.490,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,306,127,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,307,104.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,328,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,539,11.200,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,601,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122426,606,1.060,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,203,2.860,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,204,4,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,205,33.100,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,208,183,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,269,12.600,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,291,2.300,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,301,160,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,303,1.710,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,306,154,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,307,151,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,328,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,539,4.600,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,601,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122427,606,0.570,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122428,203,1.680,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,204,3.630,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,205,34.600,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,207,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,208,179,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,255,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,269,16.200,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,291,2.200,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,301,150,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,303,1.400,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,306,94,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,307,101,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,328,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,401,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,539,8.900,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,601,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,605,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122428,606,0.840,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122429,203,2.120,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,204,3.700,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,205,38.100,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,208,185,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,269,17.5,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,291,2.600,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,301,74,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,303,1.480,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,306,122,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,307,111.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,328,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,539,10.600,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,601,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122429,606,1.320,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122430,203,7.470,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,204,4.980,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,205,14.100,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,208,133,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,269,2.490,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,291,1.700,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,301,227,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,303,0.410,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,306,69,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,307,249,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,401,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,601,17,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122430,606,4.980,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122431,203,4.090,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,204,0.740,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,205,17.800,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,208,93,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,269,1.490,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,291,3.300,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,301,23,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,303,1.120,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,306,189,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,307,245,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,401,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,539,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,601,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122431,606,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,203,8.570,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,204,6.120,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,205,13.5,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,208,147,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,269,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,291,1.200,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,301,204,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,303,0.820,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,306,288,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,307,286,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,401,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,539,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,601,22,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122432,606,4.490,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122433,203,10.200,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,204,8.980,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,205,13.100,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,208,171,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,269,2.040,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,291,1.600,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,301,154,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,303,1.630,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,306,127,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,307,294,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,401,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,539,0.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,601,18,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122433,606,2.450,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122434,203,4.020,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,204,4.360,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,205,15.800,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,207,NULL,'100g',NULL,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,208,117,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,255,NULL,'100g',NULL,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,269,9.050,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,291,1,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,301,67,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,303,0.230,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,306,134,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,307,322,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,328,0,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,401,0,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,539,0.300,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,601,17,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,605,0,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122434,606,2.010,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122435,203,5.280,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,204,1.940,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,205,15.600,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,207,NULL,'100g',NULL,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,208,94,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,255,NULL,'100g',NULL,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,269,8.610,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,291,0.800,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,301,59,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,303,0.640,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,306,170,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,307,250,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,328,0,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,401,0,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,539,0.300,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,601,10,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,605,0,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122435,606,0.690,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122436,203,5.490,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,204,3.140,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,205,18.600,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,208,123,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,269,7.840,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,291,1.300,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,301,32,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,303,1.050,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,306,87,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,307,167,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,401,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,539,1,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,601,9,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122436,606,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,203,3.410,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,204,3.700,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,205,15.400,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,208,111,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,269,8.820,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,291,0.900,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,301,69,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,303,0.510,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,306,115,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,307,158,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,401,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,539,1.100,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,601,10,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122437,606,1.140,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,203,5,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,204,3.420,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,205,16.600,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,208,113,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,269,8.680,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,291,1.100,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,301,57,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,303,0.870,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,306,138,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,307,284,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,401,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,539,1.300,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,601,12,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122438,606,1.180,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122440,203,4.520,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,204,8.330,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,205,17.200,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,208,161.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,269,9.320,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,291,1.700,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,301,19.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,303,1.890,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,306,181.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,307,150.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,328,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,539,1.400,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,601,8.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122440,606,0.990,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,203,3.860,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,204,9.640,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,205,19.600,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,208,172,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,269,12.400,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,291,1.900,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,301,16,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,303,1.180,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,306,164,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,307,113,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,328,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,539,4.400,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,601,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122441,606,1.380,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,203,4.600,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,204,7.060,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,205,14.400,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,208,140,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,269,7.980,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,291,0.600,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,301,120,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,303,0.280,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,306,88,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,307,310,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,328,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,539,0,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,601,18,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122442,606,4.290,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122443,203,5.680,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,204,11.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,205,28.800,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,208,235,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,269,18.200,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,291,2.300,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,301,130,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,303,2.650,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,306,295,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,307,310,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,401,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,539,2.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,601,15,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122443,606,3.790,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122444,203,5.990,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,204,10.800,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,205,30.300,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,208,234.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,269,21.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,291,2.200,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,301,86.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,303,2.730,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,306,253.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,307,253.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,328,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,401,0.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,539,4.900,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,601,9,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122444,606,3.560,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,203,5.300,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,204,7.240,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,205,15.200,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,208,145,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,269,6.360,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,291,1.800,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,301,133,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,303,1.770,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,306,161,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,307,382,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,328,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,401,21.200,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,539,1.100,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,601,18,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122445,606,4.420,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,203,2.310,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,204,3.180,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,205,34.100,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,208,168,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,269,16.200,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,291,2.300,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,301,50.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,303,2.660,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,306,105,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,307,171.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,328,2.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,539,8.700,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,601,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122446,606,0.870,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122447,203,2.890,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,204,0,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,205,33,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,207,NULL,'100g',NULL,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,208,168,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,255,NULL,'100g',NULL,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,269,13.900,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,291,2.300,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,301,52,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,303,2.140,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,306,178,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,307,136,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,328,1,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,401,0,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,539,6.400,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,601,0,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,605,0,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122447,606,0,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122448,203,2.450,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,204,2.150,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,205,32.5,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,207,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,208,160,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,255,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,269,11,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,291,1.800,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,301,12,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,303,1.660,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,306,147,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,307,202,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,328,1,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,401,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,539,3.700,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,601,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,605,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122448,606,0.610,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122449,203,2.310,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,204,3.180,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,205,34.100,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,208,168.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,269,13.900,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,291,2.300,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,301,86.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,303,8.030,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,306,180.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,307,116.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,328,2.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,539,6.900,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,601,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122449,606,0.870,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,203,1.730,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,204,2.600,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,205,34.700,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,208,168,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,269,15.600,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,291,1.700,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,301,57,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,303,1.620,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,306,105,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,307,176,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,328,1,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,539,8.700,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,601,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122450,606,0.870,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122451,203,2.340,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,204,3.510,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,205,35.100,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,207,NULL,'100g',NULL,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,208,176,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,255,NULL,'100g',NULL,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,269,16.400,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,291,2.300,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,301,83,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,303,3.220,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,306,177,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,307,141,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,328,1,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,401,0,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,539,8.200,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,601,0,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,605,0,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122451,606,0,'100g',6,3,'2021-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (122452,203,1.820,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,204,2.720,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,205,33.900,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,208,163,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,269,17,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,291,1.800,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,301,52,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,303,2.240,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,306,92,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,307,100,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,328,1,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,401,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,539,9.100,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,601,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122452,606,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122453,203,1.800,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,204,3.290,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,205,32.900,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,208,162.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,269,15,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,291,3,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,301,53,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,303,1.680,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,306,101,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,307,141,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,328,1,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,539,7.800,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,601,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122453,606,0.600,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122454,203,1.660,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,204,3.040,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,205,29.800,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,207,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,208,144.000,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,255,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,269,13.800,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,291,3.300,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,301,51,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,303,1.710,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,306,79,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,307,124,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,328,1,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,401,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,539,7.200,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,601,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,605,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122454,606,0.550,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122455,203,1.600,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,204,3.190,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,205,37.200,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,208,176.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,269,18.100,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,291,2.100,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,301,73,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,303,1.490,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,306,127.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,307,104.000,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,328,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,539,11.700,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,601,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122455,606,1.060,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,203,2.170,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,204,4.350,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,205,35.900,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,208,185,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,269,14.700,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,291,2.700,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,301,130,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,303,1.470,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,306,98,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,307,117,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,328,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,539,7.600,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,601,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122456,606,0.820,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122457,203,10.400,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,204,9.380,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,205,53.100,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,207,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,208,344,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,255,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,269,33.300,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,291,5.200,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,301,417,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,303,0.420,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,306,24,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,307,354,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,328,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,401,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,539,30.200,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,601,10,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,605,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122457,606,3.120,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,203,0.900,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,204,2.040,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,205,19.900,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,207,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,208,95,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,255,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,269,12.700,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,291,0.900,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,301,63,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,303,0.450,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,306,123,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,307,43,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,328,1,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,401,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,539,2.700,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,601,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,605,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122458,606,0.680,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,203,0.460,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,204,1.390,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,205,19,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,207,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,208,88,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,255,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,269,13.900,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,291,0.5,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,301,64,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,303,0.460,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,306,120,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,307,35,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,328,1,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,401,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,539,3.200,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,601,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,605,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122459,606,0.460,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,203,1.050,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,204,1.830,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,205,19.400,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,207,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,208,99,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,255,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,269,11.5,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,291,0.5,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,301,79,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,303,0.470,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,306,136,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,307,84,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,328,1,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,401,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,539,0,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,601,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,605,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122460,606,0.520,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,203,0.900,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,204,2.030,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,205,19.800,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,207,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,208,95,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,255,NULL,'100g',NULL,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,269,13.100,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,291,0.900,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,301,63,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,303,0.450,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,306,123,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,307,56,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,328,1,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,401,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,539,2.700,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,601,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,605,0,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122461,606,0.680,'100g',6,3,'2021-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (122462,203,4.660,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,204,3.010,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,205,17,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,208,112,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,269,8.770,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,291,0.800,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,301,102,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,303,0.630,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,306,153,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,307,181,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,401,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,539,1.100,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,601,12,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122462,606,1.100,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122463,203,4.950,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,204,6.180,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,205,21.200,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,208,159,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,269,11.300,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,291,1.600,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,301,74,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,303,0.520,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,306,137,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,307,179,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,328,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,539,3.300,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,601,3,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122463,606,1.790,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,203,5.210,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,204,1.640,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,205,15.300,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,208,93,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,269,8.220,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,291,0.800,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,301,58,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,303,0.360,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,306,168,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,307,225,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,328,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,539,1.400,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,601,10,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122464,606,0.680,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122488,203,6.25,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,204,3.520,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,205,21.100,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,207,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,208,141,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,255,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,269,3.120,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,291,6.200,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,301,47,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,303,2.340,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,306,231,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,307,211,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,328,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,401,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,601,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,605,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122488,606,0.390,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122493,203,23.800,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,204,14.300,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,205,66.700,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,207,NULL,'100g',NULL,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,208,429,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,255,NULL,'100g',NULL,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,269,4.760,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,291,19,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,301,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,303,4.760,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,306,762,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,307,667,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,328,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,401,NULL,'100g',NULL,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,601,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,605,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122493,606,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,203,23.800,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,204,14.300,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,205,57.100,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,207,NULL,'100g',NULL,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,208,476,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,255,NULL,'100g',NULL,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,269,4.760,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,291,19,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,301,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,303,4.760,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,306,762,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,307,357,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,328,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,401,NULL,'100g',NULL,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,539,4.800,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,601,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,605,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122494,606,0,'100g',6,3,'2021-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (122495,203,23.800,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,204,14.300,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,205,57.100,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,207,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,208,476,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,255,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,269,4.760,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,291,19,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,301,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,303,4.760,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,306,714,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,307,571,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,328,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,401,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,539,4.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,601,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,605,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122495,606,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122533,203,14.300,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,204,11.100,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,205,24.600,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,207,NULL,'100g',NULL,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,208,254,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,255,NULL,'100g',NULL,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,269,4.800,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,291,2.400,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,301,230,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,303,2,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,306,341,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,307,476,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,328,0,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,401,0,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,539,1,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,601,32,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,605,0,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122533,606,5.600,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,203,14.300,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,204,8.700,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,205,24.600,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,207,NULL,'100g',NULL,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,208,230,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,255,NULL,'100g',NULL,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,269,3.200,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,291,1.600,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,301,198,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,303,1.800,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,306,262,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,307,500,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,328,0,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,401,0,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,539,1,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,601,28,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,605,0,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122534,606,4,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,203,15.100,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,204,9.500,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,205,24.600,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,207,NULL,'100g',NULL,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,208,238,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,255,NULL,'100g',NULL,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,269,4,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,291,2.400,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,301,190,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,303,2.100,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,306,421,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,307,468,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,328,0,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,401,0,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,539,1,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,601,24,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,605,0,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122535,606,4,'100g',6,3,'2021-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (122546,203,8.900,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,204,6.160,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,205,32.200,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,208,212,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,269,1.370,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,291,2.700,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,301,103,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,303,1.850,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,306,96,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,307,384,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,401,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,539,1.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,601,14,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122546,606,2.740,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,203,13,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,204,10.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,205,24.700,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,208,240,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,269,1.950,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,291,1.900,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,301,195,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,303,1.170,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,306,45,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,307,377,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,401,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,539,1.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,601,36,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122547,606,5.840,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122548,203,14.200,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,204,4.520,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,205,29,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,207,NULL,'100g',NULL,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,208,206,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,255,NULL,'100g',NULL,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,269,1.940,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,291,3.900,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,301,65,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,303,1.160,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,306,181,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,307,387,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,320,NULL,'100g',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,328,NULL,'100g',NULL,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,401,0,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,539,1.300,'100g',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,601,13,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,605,0.650,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122548,606,1.940,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,203,11.600,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,204,7.740,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,205,29,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,207,NULL,'100g',NULL,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,208,226,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,255,NULL,'100g',NULL,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,269,1.940,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,291,2.600,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,301,194,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,303,1.740,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,306,90,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,307,368,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,320,NULL,'100g',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,328,NULL,'100g',NULL,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,401,0,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,539,1.900,'100g',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,601,19,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,605,0,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122549,606,3.870,'100g',6,3,'2021-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (122551,203,4.400,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,204,9.890,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,205,48.400,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,208,297.000,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,269,20.900,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,291,3.300,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,301,22.000,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,303,1.980,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,306,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,307,231.000,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,328,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,401,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,601,27.000,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122551,606,1.100,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122552,203,4.650,'100g',6,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,204,14,'100g',6,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,205,62.800,'100g',6,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,207,NULL,'100g',NULL,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,208,395,'100g',6,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,255,NULL,'100g',NULL,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,269,32.600,'100g',6,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,291,2.300,'100g',6,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,301,47,'100g',6,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,303,2.510,'100g',6,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,306,0,'100g',6,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,307,267,'100g',6,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,320,NULL,'100g',NULL,3,'2024-12-12','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,328,NULL,'100g',NULL,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,401,0,'100g',6,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,539,16.300,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,601,23,'100g',6,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,605,0,'100g',6,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122552,606,4.650,'100g',6,3,'2021-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (122554,203,4.170,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,204,10.400,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,205,38.500,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,208,292,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,269,26,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,291,2.100,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,301,62.000,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,303,1.500,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,306,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,307,302.000,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,328,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,401,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,601,21.000,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122554,606,1.040,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,203,5.210,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,204,12.5,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,205,50,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,208,323,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,269,21.900,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,291,2.100,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,301,42,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,303,1.880,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,306,4,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,307,302,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,401,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,601,21,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122555,606,1.560,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122558,203,14.200,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,204,7.960,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,205,17.700,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,207,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,208,195.000,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,255,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,269,0.000,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,291,1.800,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,301,18.000,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,303,4.600,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,306,283.000,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,307,283.000,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,328,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,401,NULL,'100g',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,539,0.000,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,601,40,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,605,0,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122558,606,0.880,'100g',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122560,203,8.240,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,204,0.590,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,205,11.800,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,207,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,208,94,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,255,NULL,'100g',NULL,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,269,2.350,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,291,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,301,12,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,303,0.120,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,306,306,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,307,541,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,328,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,401,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,539,2.400,'100g',6,3,'2022-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,601,12,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,605,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122560,606,0,'100g',6,3,'2021-04-01','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (122630,203,5.880,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,204,13.200,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,205,67.600,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,207,NULL,'100g',NULL,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,208,412,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,255,NULL,'100g',NULL,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,269,26.5,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,291,2.900,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,301,29,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,303,2.940,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,306,179,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,307,265,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,328,0,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,401,NULL,'100g',NULL,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,539,23.5,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,601,15,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,605,0,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122630,606,1.470,'100g',6,3,'2021-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (122631,203,7.940,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,204,11.900,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,205,59.5,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,208,397,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,269,3.970,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,291,7.900,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,301,75,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,303,3.970,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,306,222,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,307,675,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,401,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,601,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122631,606,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,203,7.940,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,204,11.900,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,205,63.5,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,208,397,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,269,3.970,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,291,7.900,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,301,75,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,303,3.970,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,306,222,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,307,635,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,401,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,601,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122632,606,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,203,5.950,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,204,13.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,205,68.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,208,417,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,269,26.800,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,291,3,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,301,33,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,303,2.980,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,306,185,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,307,223,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,401,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,539,23.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,601,15,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122636,606,2.980,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,203,5.950,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,204,13.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,205,68.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,208,417,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,269,26.800,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,291,3,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,301,30,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,303,2.980,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,306,161,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,307,223,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,401,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,539,23.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,601,15,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122637,606,1.490,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,203,7.140,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,204,14.300,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,205,75,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,208,429,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,269,28.600,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,291,7.100,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,301,21,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,303,3.570,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,306,139,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,307,268,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,401,186,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,539,25,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,601,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122638,606,1.790,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,203,7.140,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,204,12.5,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,205,75,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,208,429,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,269,28.600,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,291,7.100,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,301,21,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,303,3.570,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,306,293,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,307,304,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,401,175,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,539,28.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,601,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122639,606,1.790,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,203,7.140,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,204,12.5,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,205,75,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,208,429,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,269,28.600,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,291,7.100,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,301,18,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,303,3.570,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,306,182,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,307,214,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,401,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,539,28.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,601,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122640,606,1.790,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,203,7.140,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,204,7.140,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,205,78.600,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,208,429,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,269,21.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,291,7.100,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,301,68,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,303,3.570,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,306,314,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,307,268,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,401,204,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,539,21.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,601,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122641,606,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,203,5.100,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,204,12.800,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,205,68.900,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,208,408,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,269,30.600,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,291,5.100,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,301,31,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,303,2.550,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,306,214,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,307,230,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,401,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,539,23,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,601,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122644,606,3.830,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,203,5.100,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,204,11.5,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,205,71.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,208,408,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,269,30.600,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,291,5.100,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,301,20,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,303,2.550,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,306,161,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,307,230,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,401,25.5,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,539,25.5,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,601,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122645,606,2.550,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122646,203,5.950,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,204,13.400,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,205,68.400,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,207,NULL,'100g',NULL,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,208,417,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,255,NULL,'100g',NULL,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,269,28.300,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,291,4.5,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,301,30,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,303,2.980,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,306,185,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,307,253,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,328,NULL,'100g',NULL,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,401,3,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,539,23.800,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,601,7,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,605,0,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122646,606,2.230,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122647,203,5.950,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,204,13.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,205,68.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,208,417,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,269,28.300,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,291,4.5,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,301,33,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,303,2.980,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,306,182,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,307,208,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,401,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,539,23.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,601,7,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122647,606,2.980,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,203,5.950,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,204,13.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,205,68.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,208,417,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,269,28.300,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,291,4.5,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,301,30,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,303,2.980,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,306,162,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,307,223,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,401,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,539,23.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,601,7,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122648,606,2.230,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,203,5.950,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,204,13.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,205,68.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,208,417,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,269,28.300,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,291,4.5,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,301,33,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,303,2.980,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,306,182,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,307,208,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,401,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,539,23.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,601,7,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122649,606,2.980,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122650,203,5.950,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,204,13.400,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,205,68.400,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,207,NULL,'100g',NULL,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,208,417,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,255,NULL,'100g',NULL,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,269,28.300,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,291,3,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,301,30,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,303,2.980,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,306,161,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,307,223,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,328,NULL,'100g',NULL,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,401,3,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,539,23.800,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,601,7,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,605,0,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122650,606,2.230,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122651,203,11.900,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,204,13.900,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,205,67.5,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,208,437,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,269,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,291,7.900,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,301,56,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,303,3.970,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,306,238,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,307,714,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,401,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,601,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122651,606,3.970,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,203,7.140,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,204,7.140,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,205,78.600,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,207,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,208,393,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,255,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,269,21.400,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,291,7.100,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,301,32,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,303,3.570,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,306,207,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,307,286,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,328,NULL,'100g',NULL,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,401,204,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,539,17.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,601,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,605,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122653,606,0,'100g',6,3,'2021-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (122684,203,1.070,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,204,0.120,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,205,7.870,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,207,NULL,'100g',NULL,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,208,32.000,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,255,90,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,269,6.200,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,291,1,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,301,12.000,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,303,0.760,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,306,0,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,307,40.000,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,328,NULL,'100g',NULL,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,401,5.5,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,539,NULL,'100g',NULL,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,601,0,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,605,0,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122684,606,0.020,'100g',6,3,'2021-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (122707,203,9.720,'100g',6,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,204,10.200,'100g',6,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,205,10.100,'100g',6,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,207,NULL,'100g',NULL,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,208,174,'100g',6,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,255,NULL,'100g',NULL,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,269,1.75,'100g',6,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,291,0.800,'100g',6,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,301,198,'100g',6,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,303,0.680,'100g',6,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,306,NULL,'100g',NULL,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,307,417.000,'100g',6,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,320,0.000,'100g',6,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,328,NULL,'100g',NULL,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,401,0,'100g',6,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,539,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,601,123,'100g',6,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,605,0.030,'100g',6,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122707,606,4.820,'100g',6,3,'2021-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (122708,203,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,204,0.000,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,205,22,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,207,NULL,'100ml',NULL,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,208,90,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,255,NULL,'100ml',NULL,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,269,22,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,291,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,301,20,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,303,0.5,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,306,240,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,307,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,320,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,328,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,401,86,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,539,0,'100ml',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,601,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,605,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122708,606,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,203,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,204,0.000,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,205,22,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,207,NULL,'100ml',NULL,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,208,90,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,255,NULL,'100ml',NULL,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,269,22,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,291,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,301,20,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,303,0.5,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,306,240,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,307,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,320,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,328,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,401,86,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,539,0,'100ml',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,601,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,605,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122709,606,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122710,203,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,204,0.000,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,205,22,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,207,NULL,'100ml',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,208,90,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,255,NULL,'100ml',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,269,22,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,291,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,301,20,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,303,0.5,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,306,240,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,307,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,328,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,401,86,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,539,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,601,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,605,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122710,606,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122711,203,0,'100ml',6,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,204,0,'100ml',6,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,205,22,'100ml',6,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,207,NULL,'100ml',NULL,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,208,90,'100ml',6,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,255,NULL,'100ml',NULL,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,269,22,'100ml',6,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,291,0,'100ml',6,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,301,20,'100ml',6,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,303,0.5,'100ml',6,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,306,240,'100ml',6,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,307,0,'100ml',6,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,320,NULL,'100ml',NULL,3,'2024-12-12','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,328,NULL,'100ml',NULL,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,401,86,'100ml',6,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,539,0,'100ml',6,3,'2022-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,601,0,'100ml',6,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,605,0,'100ml',6,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122711,606,0,'100ml',6,3,'2021-04-01','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (122712,203,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,204,0.000,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,205,23,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,207,NULL,'100ml',NULL,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,208,90,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,255,NULL,'100ml',NULL,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,269,22,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,291,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,301,20,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,303,0.5,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,306,240,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,307,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,320,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,328,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,401,86,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,539,0,'100ml',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,601,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,605,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122712,606,0,'100ml',6,3,'2021-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (122713,203,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,204,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,205,22,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,207,NULL,'100ml',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,208,90,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,255,NULL,'100ml',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,269,22,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,291,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,301,20,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,303,0.5,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,306,240,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,307,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,328,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,401,86,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,539,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,601,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,605,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122713,606,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122714,203,0,'100ml',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,204,0.000,'100ml',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,205,22,'100ml',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,207,NULL,'100ml',NULL,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,208,90,'100ml',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,255,NULL,'100ml',NULL,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,269,22,'100ml',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,291,0,'100ml',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,301,20,'100ml',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,303,0.5,'100ml',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,306,240,'100ml',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,307,0,'100ml',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,320,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,328,0,'100ml',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,401,86,'100ml',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,539,0,'100ml',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,601,0,'100ml',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,605,0,'100ml',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122714,606,0,'100ml',6,3,'2021-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (122715,203,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,204,0.000,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,205,22,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,207,NULL,'100ml',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,208,90,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,255,NULL,'100ml',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,269,22,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,291,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,301,20,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,303,0.5,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,306,240,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,307,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,328,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,401,86,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,539,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,601,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,605,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122715,606,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,203,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,204,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,205,22,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,207,NULL,'100ml',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,208,90,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,255,NULL,'100ml',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,269,22,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,291,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,301,20,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,303,0.5,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,306,240,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,307,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,328,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,401,86,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,539,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,601,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,605,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122716,606,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,203,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,204,0.000,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,205,22,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,207,NULL,'100ml',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,208,90,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,255,NULL,'100ml',NULL,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,269,22,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,291,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,301,20,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,303,0.5,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,306,240,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,307,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,328,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,401,86,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,539,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,601,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,605,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122717,606,0,'100ml',6,3,'2021-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (122718,203,10,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,204,9,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,205,27,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,208,232,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,269,2,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,291,1,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,301,91,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,303,2,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,306,72,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,307,517,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,401,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,539,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,601,47,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122718,606,4,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122719,203,10.000,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,204,9,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,205,26.000,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,207,NULL,'100g',NULL,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,208,230.000,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,255,NULL,'100g',NULL,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,269,3.000,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,291,2.000,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,301,121.000,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,303,2.700,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,306,142.000,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,307,530.000,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,320,0.000,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,328,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,401,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,539,1,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,601,45.000,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,605,0,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122719,606,4.000,'100g',6,3,'2021-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (122722,203,13,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,204,11,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,205,24,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,208,244,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,269,2,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,291,1,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,301,202,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,303,1,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,306,31,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,307,292,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,401,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,539,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,601,27,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122722,606,7,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,203,18,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,204,19,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,205,31,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,208,372,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,269,3,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,291,2,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,301,248,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,303,2,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,306,67,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,307,630,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,401,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,539,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,601,45,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122723,606,11,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,203,13,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,204,13,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,205,21,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,208,258,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,269,2,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,291,1,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,301,173,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,303,1,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,306,46,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,307,437,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,401,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,539,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,601,31,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122724,606,7,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,203,12,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,204,10,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,205,26,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,208,243,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,269,3,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,291,1,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,301,139,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,303,2,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,306,35,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,307,474,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,401,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,539,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,601,25,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (122725,606,6,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,203,14.200,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,204,15.900,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,205,26.600,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,208,301,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,269,1.770,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,291,2.700,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,301,288,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,303,0.880,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,306,158,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,307,407,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,328,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,401,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,539,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,601,27,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123144,606,6.190,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,203,6.25,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,204,10.900,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,205,64.100,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,207,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,208,359,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,255,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,269,21.900,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,291,3.100,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,301,105,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,303,1.560,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,306,98,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,307,148,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,328,3,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,401,NULL,'100g',NULL,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,539,18.800,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,601,16,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,605,0,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123146,606,4.690,'100g',6,3,'2021-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123169,203,0.970,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,204,0.490,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,205,6.800,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,207,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,208,34,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,255,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,269,2.430,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,291,1,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,301,5,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,303,0.100,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,306,58,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,307,51,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,328,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,401,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,539,1.5,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,601,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,605,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123169,606,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,203,1.460,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,204,1.210,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,205,3.880,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,207,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,208,34,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,255,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,269,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,291,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,301,5,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,303,0.240,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,306,44,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,307,29,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,328,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,401,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,601,5,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,605,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123170,606,0.240,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,203,3.690,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,204,5.990,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,205,14.800,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,207,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,208,129,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,255,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,269,1.840,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,291,1.400,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,301,60,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,303,0.460,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,306,88,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,307,318,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,328,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,401,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,539,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,601,5,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,605,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123173,606,1.150,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,203,3.850,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,204,2.880,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,205,11.100,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,207,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,208,87,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,255,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,269,4.330,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,291,1.900,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,301,29,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,303,0.480,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,306,183,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,307,361,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,328,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,401,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,539,1,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,601,12,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,605,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123174,606,1.200,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123178,203,4.170,'100ml',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,204,1.670,'100ml',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,205,12.5,'100ml',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,207,NULL,'100ml',NULL,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,208,83,'100ml',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,255,NULL,'100ml',NULL,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,269,2.5,'100ml',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,291,2.5,'100ml',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,301,33,'100ml',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,303,0.830,'100ml',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,306,192,'100ml',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,307,567,'100ml',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,320,NULL,'100ml',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,328,0,'100ml',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,401,NULL,'100ml',NULL,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,539,0.800,'100ml',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,601,0,'100ml',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,605,0,'100ml',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123178,606,0.420,'100ml',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123180,203,2.5,'100ml',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,204,1.25,'100ml',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,205,10.800,'100ml',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,207,NULL,'100ml',NULL,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,208,67,'100ml',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,255,NULL,'100ml',NULL,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,269,2.5,'100ml',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,291,1.700,'100ml',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,301,25,'100ml',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,303,0.830,'100ml',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,306,417,'100ml',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,307,342,'100ml',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,320,NULL,'100ml',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,328,NULL,'100ml',NULL,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,401,NULL,'100ml',NULL,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,539,1.700,'100ml',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,601,0,'100ml',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,605,0,'100ml',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123180,606,0,'100ml',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123181,203,4.170,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,204,1.25,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,205,10,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,207,NULL,'100ml',NULL,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,208,67,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,255,NULL,'100ml',NULL,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,269,1.670,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,291,0.800,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,301,17,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,303,0.830,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,306,417,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,307,342,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,320,NULL,'100ml',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,328,NULL,'100ml',NULL,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,401,NULL,'100ml',NULL,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,539,0.800,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,601,21,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,605,0,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123181,606,0.420,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,203,5,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,204,1.670,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,205,10.800,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,207,NULL,'100ml',NULL,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,208,75,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,255,NULL,'100ml',NULL,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,269,1.670,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,291,1.700,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,301,25,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,303,0.830,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,306,167,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,307,342,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,320,NULL,'100ml',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,328,NULL,'100ml',NULL,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,401,NULL,'100ml',NULL,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,539,0.800,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,601,8,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,605,0,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123182,606,0.830,'100ml',6,3,'2022-04-01','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123189,203,3.230,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,204,0,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,205,0.810,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,207,NULL,'100ml',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,208,16.000,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,255,NULL,'100ml',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,269,0.810,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,291,0,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,301,0,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,303,0,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,306,16.000,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,307,444.000,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,328,0,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,401,NULL,'100ml',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,539,0.800,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,601,0,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,605,0,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123189,606,0,'100ml',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123198,203,15.100,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,204,9.500,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,205,24.600,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,208,238,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,269,4,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,291,2.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,301,190,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,303,2.100,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,306,421,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,307,468,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,320,55.600,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,539,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,601,23.800,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123198,606,4,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,203,12.700,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,204,10.200,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,205,26.800,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,208,248,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,269,12.700,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,291,1.900,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,301,210,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,303,1.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,306,274,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,307,388,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,320,44.600,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,539,6,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,601,28.700,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123200,606,4.5,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123202,203,12.5,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,204,7.500,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,205,28.800,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,207,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,208,225,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,255,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,269,7.5,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,291,2.5,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,301,238,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,303,1.800,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,306,238,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,307,475,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,328,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,401,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,539,1,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,601,69,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,605,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123202,606,3.800,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,203,11.400,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,204,7.600,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,205,29.100,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,207,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,208,228,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,255,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,269,7.600,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,291,2.5,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,301,253,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,303,1.600,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,306,202,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,307,481,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,328,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,401,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,539,1,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,601,70,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,605,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123203,606,3.800,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123204,203,11.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,204,7.790,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,205,24.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,208,208,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,269,1.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,291,1.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,301,130,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,303,1.170,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,306,91,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,307,260,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,539,1.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,601,26,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123204,606,3.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123205,203,4.230,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,204,8.450,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,205,46.5,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,207,NULL,'100g',NULL,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,208,268,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,255,NULL,'100g',NULL,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,269,15.5,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,291,1.400,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,301,28,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,303,1.520,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,306,99,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,307,239,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,320,NULL,'100g',NULL,3,'2024-12-12','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,328,NULL,'100g',NULL,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,401,NULL,'100g',NULL,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,539,14.100,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,601,21,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,605,0,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123205,606,0.700,'100g',6,3,'2022-04-01','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123210,203,8.920,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,204,4.690,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,205,11.700,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,207,NULL,'100g',NULL,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,208,127,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,255,NULL,'100g',NULL,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,269,2.820,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,291,0.900,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,301,77,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,303,0.940,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,306,273,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,307,455,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,320,NULL,'100g',NULL,3,'2024-12-12','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,328,0,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,401,0,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,539,0.5,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,601,12,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,605,0,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123210,606,1.410,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123211,203,7.020,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,204,2.630,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,205,42.100,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,208,228,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,269,1.75,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,291,5.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,301,175,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,303,2.280,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,306,35,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,307,219,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,539,1.800,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123211,606,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123212,203,7.140,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,204,5.360,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,205,46.400,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,207,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,208,268,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,255,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,269,1.790,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,291,5.400,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,301,143,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,303,2.570,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,306,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,307,241,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,328,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,401,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,539,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,601,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,605,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123212,606,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123213,203,3,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,204,1.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,205,32.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,208,150.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,291,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,301,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,303,0.500,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,306,110.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,307,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,401,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123213,606,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,203,2,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,204,1.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,205,13,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,208,70,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,269,6,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,291,2,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,301,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,303,0.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,306,140,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,307,10,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,401,2,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123214,606,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123215,203,7.140,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,204,10.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,205,46.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,208,286,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,269,10.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,291,3.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,301,82,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,303,3.570,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,306,232,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,307,482,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,539,3.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,601,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123215,606,5.360,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,203,1.820,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,204,1.820,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,205,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,208,109,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,269,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,291,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,301,47,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,303,0.650,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,306,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,307,564,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,401,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,601,55,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123216,606,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123217,203,4.650,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,204,11.600,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,205,67.400,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,207,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,208,442,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,255,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,269,27.900,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,291,2.300,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,301,63,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,303,2.330,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,306,109,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,307,116,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,328,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,401,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,539,25.600,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,601,12,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,605,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123217,606,4.650,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123218,203,15,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,204,13.000,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,205,13,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,207,NULL,'100g',NULL,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,208,230,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,255,NULL,'100g',NULL,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,269,1,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,291,2,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,301,19,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,303,1,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,306,287,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,307,380,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,320,0.000,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,328,0,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,401,0,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,539,1,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,601,45,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,605,0,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123218,606,3,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123219,203,14.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,204,14.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,205,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,208,190,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,291,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,301,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,303,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,306,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,307,643,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,328,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,601,95,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123219,606,4.760,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123220,203,16,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,204,14,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,205,13,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,207,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,208,240,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,255,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,269,1,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,291,2,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,301,24,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,303,2,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,306,321,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,307,380,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,320,0.000,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,328,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,401,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,539,1,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,601,40,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,605,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123220,606,3.5,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,203,15,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,204,13,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,205,13,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,207,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,208,230,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,255,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,269,1,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,291,2,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,301,19,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,303,1,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,306,287,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,307,380,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,320,0.000,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,328,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,401,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,539,1,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,601,45,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,605,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123221,606,3,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123222,203,5.880,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,204,13.200,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,205,67.600,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,207,NULL,'100g',NULL,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,208,412,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,255,NULL,'100g',NULL,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,269,26.5,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,291,2.900,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,301,29,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,303,2.940,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,306,159,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,307,221,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,320,NULL,'100g',NULL,3,'2024-12-12','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,328,NULL,'100g',NULL,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,401,0,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,539,23.5,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,601,15,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,605,0,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123222,606,1.470,'100g',6,3,'2022-04-01','2022-04-01');
INSERT INTO `cndb_nutval` VALUES (123223,203,7.960,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,204,1.330,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,205,50.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,208,239,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,269,5.310,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,291,3.5,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,301,62,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,303,2.740,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,306,142,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,307,416,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,539,2.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,601,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123223,606,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,203,8.850,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,204,1.330,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,205,57.5,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,208,274,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,269,9.730,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,291,5.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,301,18,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,303,2.830,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,306,150,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,307,327,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,601,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123224,606,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,203,8.850,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,204,1.330,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,205,59.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,208,274,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,269,11.5,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,291,4.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,301,62,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,303,3.270,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,306,150,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,307,336,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,601,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123225,606,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123228,203,7.690,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,204,0.130,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,205,22.300,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,207,NULL,'100g',NULL,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,208,45.000,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,255,64.800,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,269,2.310,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,291,5.400,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,301,16.000,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,303,0.510,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,306,0,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,307,52.000,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,328,NULL,'100g',NULL,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,401,0.400,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,539,NULL,'100g',NULL,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,601,0,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,605,0,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123228,606,0.020,'100g',6,3,'2022-04-01','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (123229,203,6.450,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,204,9.680,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,205,41.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,208,274,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,269,3.230,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,291,1.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,301,150,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,303,1.610,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,306,419.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,307,419,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,328,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,539,1.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123229,606,5.650,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123230,203,7.840,'100g',6,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,204,2.940,'100g',6,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,205,41.200,'100g',6,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,207,NULL,'100g',NULL,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,208,216,'100g',6,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,255,NULL,'100g',NULL,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,269,1.960,'100g',6,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,291,3.900,'100g',6,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,301,51,'100g',6,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,303,2.820,'100g',6,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,306,118,'100g',6,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,307,147.000,'100g',6,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,328,0,'100g',6,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,401,NULL,'100g',NULL,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,539,2,'100g',6,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,601,0,'100g',6,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,605,0,'100g',6,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123230,606,0,'100g',6,3,'2022-04-01','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (123231,203,5.460,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,204,0.246,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,205,17.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,208,91.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,269,2.810,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,291,5.450,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,301,56.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,303,1.640,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,306,373,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,307,360,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,539,0.607,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123231,606,0.058,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,203,5.830,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,204,1.070,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,205,23,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,208,121,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,269,8.910,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,291,3.640,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,301,40.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,303,1.460,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,306,295.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,307,413,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,328,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,539,7.730,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,601,1.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123232,606,0.296,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,203,5.75,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,204,0.784,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,205,23.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,208,120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,269,8.780,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,291,3.750,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,301,41.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,303,1.480,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,306,302,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,307,400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,539,7.570,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,601,0.648,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123233,606,0.189,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,203,4.780,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,204,0.368,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,205,24.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,208,119.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,269,11.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,291,3.350,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,301,35.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,303,1.270,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,306,279.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,307,444.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,328,0.001,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,539,10.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,601,0.001,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,605,0.001,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123234,606,0.043,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,203,4.860,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,204,0.373,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,205,24.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,208,120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,269,11.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,291,3.410,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,301,36.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,303,1.290,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,306,283,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,307,438,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,539,9.980,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,601,0.001,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123235,606,0.043,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,203,5.260,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,204,0.370,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,205,23.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,208,115,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,269,9.390,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,291,3.610,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,301,40.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,303,1.460,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,306,288,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,307,288,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,539,8.460,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123237,606,0.042,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,203,5.310,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,204,0.370,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,205,23.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,208,115,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,269,9.310,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,291,3.660,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,301,40.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,303,1.470,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,306,291,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,307,424,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,539,8.370,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123238,606,0.041,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123240,203,6.190,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,204,0.407,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,205,17.900,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,208,97.700,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,269,0.645,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,291,4.360,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,301,37.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,303,1.440,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,306,425.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,307,350.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,401,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123240,606,0.105,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123241,203,5.070,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,204,0.333,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,205,14.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,208,80,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,269,0.528,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,291,3.570,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,301,30.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,303,1.180,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,306,348,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,307,353,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123241,606,0.086,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,203,5.720,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,204,0.711,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,205,17.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,208,97.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,269,0.928,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,291,4.150,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,301,74.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,303,1.550,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,306,409,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,307,336,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,539,0.095,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,601,0.001,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,605,0.018,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123243,606,0.152,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,203,5.340,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,204,0.286,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,205,13.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,208,76.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,269,1.570,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,291,2.410,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,301,26.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,303,1.880,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,306,252,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,307,345,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123244,606,0.075,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,203,4.710,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,204,0.252,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,205,12,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,208,67.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,269,1.380,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,291,2.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,301,24,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,303,1.660,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,306,223,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,307,388,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123245,606,0.066,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,203,5.770,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,204,1.030,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,205,13.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,208,81.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,269,1.530,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,291,2.330,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,301,26.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,303,1.840,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,306,248,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,307,378,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,539,0.016,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,601,1.210,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123246,606,0.346,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,203,5.640,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,204,0.305,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,205,14.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,208,80.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,269,1.680,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,291,2.620,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,301,29.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,303,2,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,306,272,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,307,346,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123247,606,0.080,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,203,5.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,204,1.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,205,23.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,208,125,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,269,9.790,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,291,3.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,301,43.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,303,1.470,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,306,301,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,307,324,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,539,6.250,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,601,0.548,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123248,606,0.349,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,203,5.75,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,204,1.160,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,205,24,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,208,126,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,269,9.220,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,291,3.680,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,301,49.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,303,1.670,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,306,323,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,307,301,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,539,8.290,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,601,0.509,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,605,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123249,606,0.330,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123250,203,5.120,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,204,0.354,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,205,25.900,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,208,125,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,269,11.5,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,291,3.530,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,301,43.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,303,1.520,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,306,297,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,307,379,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,401,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,539,10.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123250,606,0.042,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123251,203,5.150,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,204,0.387,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,205,25.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,208,124,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,269,11.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,291,3.560,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,301,37.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,303,1.330,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,306,284.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,307,433,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,328,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,539,10.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,605,0.001,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123251,606,0.045,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,203,5.160,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,204,0.388,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,205,25.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,208,123,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,269,11.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,291,3.650,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,301,38.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,303,1.320,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,306,279,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,307,425,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,539,10.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123252,606,0.045,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123253,203,5.180,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,204,0.390,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,205,22.400,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,207,NULL,'100g',NULL,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,208,110,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,255,NULL,'100g',NULL,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,269,8.550,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,291,3.600,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,301,38,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,303,1.330,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,306,285,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,307,302,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,328,0,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,401,NULL,'100g',NULL,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,539,7.5,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,601,0,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,605,0,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123253,606,0.040,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123254,203,5.720,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,204,0.201,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,205,14.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,208,80.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,269,0.541,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,291,6.040,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,301,65.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,303,1.990,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,306,342,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,307,220,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123254,606,0.029,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,203,5.390,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,204,1.040,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,205,25.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,208,127,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,269,12,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,291,3.260,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,301,39.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,303,1.450,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,306,272,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,307,496,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,539,11.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,601,1.130,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123255,606,0.293,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,203,5.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,204,0.746,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,205,25.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,208,126,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,269,12,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,291,3.290,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,301,39.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,303,1.450,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,306,273,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,307,493,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,539,11.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,601,0.650,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123256,606,0.185,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,203,5.090,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,204,0.889,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,205,25.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,208,126,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,269,12.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,291,3.130,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,301,38.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,303,1.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,306,262,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,307,511,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,539,11.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,601,0.902,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,605,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123257,606,0.240,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,203,5.790,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,204,0.310,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,205,14.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,208,82.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,269,1.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,291,2.610,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,301,44.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,303,2.040,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,306,274,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,307,357,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123258,606,0.081,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,203,5.660,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,204,0.206,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,205,17,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,208,91,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,269,2.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,291,3.820,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,301,64,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,303,1.680,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,306,343,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,307,205,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,539,1.590,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123260,606,0.039,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,203,6.310,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,204,0.230,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,205,18.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,208,100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,269,2,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,291,4.260,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,301,61.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,303,1.880,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,306,382,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,307,183,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,539,1.410,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123261,606,0.043,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,203,4.780,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,204,0.421,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,205,15.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,208,82.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,269,0.708,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,291,3.620,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,301,33,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,303,1.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,306,316,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,307,377,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123262,606,0.055,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,203,5.440,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,204,0.349,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,205,15.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,208,88.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,269,0.540,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,291,3.940,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,301,30.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,303,1.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,306,355,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,307,325,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123263,606,0.062,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,203,4.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,204,1.430,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,205,14.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,208,89.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,269,2.530,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,291,2.880,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,301,26.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,303,1.020,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,306,170,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,307,370,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123266,606,0.142,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,203,1.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,204,0.540,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,205,12.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,208,60.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,269,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,291,1.510,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,301,2.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,303,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,306,10.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,307,453,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123267,606,0.160,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,203,1.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,204,0.540,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,205,12.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,208,60.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,269,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,291,1.510,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,301,2.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,303,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,306,10.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,307,453,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123268,606,0.160,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,203,1.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,204,0.540,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,205,12.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,208,60.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,269,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,291,1.510,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,301,2.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,303,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,306,10.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,307,453,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123269,606,0.160,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,203,6.070,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,204,0.317,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,205,17.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,208,94.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,269,0.628,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,291,5.610,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,301,71.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,303,1.520,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,306,386,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,307,300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123270,606,0.099,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,203,5.070,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,204,0.264,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,205,14.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,208,78.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,269,0.524,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,291,4.680,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,301,53.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,303,1.270,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,306,322,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,307,359,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123271,606,0.083,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,203,5.360,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,204,1.060,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,205,22.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,208,115,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,269,9.650,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,291,3.350,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,301,37.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,303,1.430,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,306,285.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,307,443,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,328,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,539,8.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,601,1.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123272,606,0.296,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,203,5.240,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,204,0.767,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,205,22.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,208,115,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,269,9.610,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,291,3.430,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,301,38.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,303,1.450,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,306,289,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,307,435,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,539,8.440,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,601,0.641,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,605,4.480,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123273,606,0.189,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123274,203,5.190,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,204,0.705,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,205,22,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,208,112,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,269,9.170,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,291,3.420,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,301,36.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,303,1.370,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,306,280,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,307,426,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,401,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,539,8.060,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,601,0.544,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123274,606,0.166,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123275,203,5.130,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,204,0.911,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,205,22.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,208,113,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,269,9.840,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,291,3.270,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,301,37.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,303,1.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,306,278.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,307,451,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,328,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,539,8.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,601,0.893,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123275,606,0.244,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123276,203,4.920,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,204,0.450,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,205,27.700,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,207,NULL,'100g',NULL,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,208,131,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,255,NULL,'100g',NULL,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,269,13.800,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,291,3.5,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,301,42,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,303,1.5,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,306,298,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,307,318,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,328,0,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,401,NULL,'100g',NULL,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,539,12.5,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,601,0,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,605,0,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123276,606,0.050,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123277,203,5.530,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,204,1.060,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,205,24.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,208,127,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,269,11.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,291,3.420,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,301,35.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,303,1.250,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,306,269.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,307,419,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,328,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,539,10.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,601,1.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,605,0.001,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123277,606,0.293,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,203,5.480,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,204,0.777,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,205,25.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,208,126,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,269,11.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,291,3.550,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,301,36.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,303,1.290,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,306,278,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,307,405,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,539,10.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,601,0.641,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,605,0.001,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123278,606,0.186,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,203,5.590,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,204,0.472,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,205,16.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,208,90.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,269,0.814,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,291,3.910,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,301,54.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,303,1.75,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,306,352,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,307,360,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,539,0.176,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,605,0.003,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123279,606,0.076,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,203,5.75,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,204,0.487,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,205,16.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,208,93.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,269,0.847,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,291,4.060,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,301,55,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,303,1.810,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,306,365,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,307,356,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,539,0.172,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123280,606,0.079,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,203,5.270,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,204,0.170,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,205,16.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,208,85.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,269,2.740,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,291,4.670,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,301,21.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,303,1.850,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,306,424,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,307,360,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,539,0.654,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123281,606,0.040,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,203,6.330,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,204,0.231,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,205,18.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,208,100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,269,2.020,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,291,4.270,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,301,62.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,303,1.880,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,306,383,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,307,197,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,539,1.430,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123282,606,0.043,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,203,5.660,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,204,0.206,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,205,17,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,208,91,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,269,2.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,291,3.820,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,301,64,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,303,1.680,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,306,343,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,307,205,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,539,1.590,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123283,606,0.039,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123284,203,6.240,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,204,0.410,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,205,18,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,207,NULL,'100g',NULL,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,208,99,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,255,NULL,'100g',NULL,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,269,0.650,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,291,4.400,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,301,63,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,303,1.450,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,306,429,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,307,102,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,328,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,401,NULL,'100g',NULL,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,539,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,601,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,605,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123284,606,0.110,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123285,203,6.090,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,204,0.214,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,205,15.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,208,86,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,269,0.576,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,291,6.430,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,301,68.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,303,2.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,306,364,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,307,95,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123285,606,0.031,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,203,6.330,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,204,0.231,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,205,18.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,208,100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,269,2.020,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,291,4.270,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,301,62.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,303,1.880,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,306,383,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,307,107,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,539,1.430,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123286,606,0.043,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,203,5.450,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,204,1.590,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,205,16.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,208,99.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,269,2.810,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,291,3.210,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,301,26.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,303,1.130,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,306,189,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,307,107,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123287,606,0.158,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,203,5.130,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,204,0.295,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,205,15,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,208,83.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,269,0.506,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,291,3.720,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,301,45.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,303,1.220,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,306,335,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,307,110,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123288,606,0.056,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,203,5.510,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,204,0.684,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,205,17.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,208,97.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,269,0.891,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,291,4.210,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,301,75.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,303,1.480,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,306,380,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,307,101,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,539,0.186,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,605,0.003,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123289,606,0.112,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,203,5.080,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,204,0.917,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,205,19.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,208,103,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,269,1.230,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,291,6.850,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,301,89.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,303,2.290,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,306,415,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,307,97.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,539,0.186,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,605,0.003,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123290,606,0.117,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,203,5.420,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,204,1.220,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,205,21,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,208,112,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,269,8.260,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,291,3.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,301,33.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,303,1.260,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,306,260,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,307,490,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,539,7.420,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,601,1.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123291,606,0.324,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,203,5.380,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,204,0.926,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,205,21.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,208,113,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,269,8.160,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,291,3.430,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,301,35.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,303,1.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,306,270,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,307,484,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,539,7.290,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,601,0.719,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123292,606,0.217,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,203,5.440,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,204,0.513,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,205,16.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,208,91.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,269,0.806,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,291,3.940,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,301,57.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,303,1.550,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,306,355,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,307,350,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,539,0.171,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123293,606,0.084,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,203,4.910,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,204,0.330,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,205,13.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,208,74.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,269,0.853,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,291,3.360,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,301,43,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,303,1.220,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,306,261,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,307,365,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123294,606,0.037,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123295,203,5.170,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,204,0.370,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,205,25.5,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,207,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,208,124,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,255,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,269,11.100,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,291,3.600,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,301,45,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,303,1.520,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,306,296,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,307,352,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,328,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,401,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,539,10.200,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,601,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,605,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123295,606,0.040,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123296,203,5.450,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,204,0.358,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,205,15.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,208,86,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,269,0.568,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,291,3.830,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,301,31.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,303,1.270,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,306,374,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,307,148,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123296,606,0.093,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,203,5.920,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,204,0.390,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,205,17.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,208,93.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,269,0.617,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,291,4.170,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,301,35.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,303,1.380,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,306,407.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,307,95.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123297,606,0.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,203,5.820,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,204,0.212,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,205,15.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,208,87,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,269,0.542,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,291,3.920,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,301,56,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,303,1.730,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,306,352,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,307,203,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123298,606,0.040,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,203,6.280,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,204,0.229,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,205,17.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,208,93.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,269,0.585,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,291,4.240,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,301,58.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,303,1.870,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,306,380,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,307,77,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123299,606,0.043,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,203,5.780,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,204,1.680,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,205,17.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,208,105,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,269,2.980,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,291,3.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,301,16.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,303,1.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,306,200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,307,278,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123300,606,0.168,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,203,5.210,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,204,1.520,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,205,15.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,208,95.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,269,2.690,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,291,3.060,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,301,36.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,303,1.080,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,306,181.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,307,86.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123301,606,0.152,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,203,5.880,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,204,0.338,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,205,17.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,208,95.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,269,0.579,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,291,4.260,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,301,32.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,303,1.390,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,306,382,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,307,75,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123302,606,0.065,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,203,4.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,204,0.259,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,205,13.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,208,73,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,269,0.444,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,291,3.260,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,301,25.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,303,1.070,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,306,293,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,307,90,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123303,606,0.049,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,203,5.510,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,204,0.553,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,205,23.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,208,117,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,269,9.190,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,291,3.690,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,301,40.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,303,1.480,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,306,294,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,307,421,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,539,8.250,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,601,0.281,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123304,606,0.106,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,203,5.780,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,204,1.070,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,205,23.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,208,121,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,269,9.230,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,291,3.590,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,301,40.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,303,1.460,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,306,289.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,307,434,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,328,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,539,8.310,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,601,1.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123305,606,0.295,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,203,5.550,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,204,0.896,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,205,23,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,208,118,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,269,9.410,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,291,3.520,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,301,39.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,303,1.440,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,306,283,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,307,441,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,539,8.510,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,601,0.853,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123306,606,0.234,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,203,5.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,204,0.769,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,205,23.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,208,118,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,269,9.380,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,291,3.560,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,301,39.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,303,1.450,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,306,286,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,307,436,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,539,8.470,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,601,0.641,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123307,606,0.186,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,203,5.440,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,204,0.702,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,205,23,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,208,117,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,269,9.370,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,291,3.560,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,301,39.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,303,1.440,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,306,285,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,307,435,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,539,8.460,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,601,0.544,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123308,606,0.163,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,203,5.320,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,204,0.905,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,205,22.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,208,116,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,269,9.710,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,291,3.360,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,301,38.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,303,1.390,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,306,271,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,307,458,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,539,8.850,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,601,0.893,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123309,606,0.241,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,203,5.130,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,204,0.295,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,205,15,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,208,83.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,269,0.506,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,291,3.720,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,301,38.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,303,1.220,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,306,334,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,307,335,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123310,606,0.056,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,203,4.510,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,204,0.259,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,205,13.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,208,73,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,269,0.444,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,291,3.260,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,301,26.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,303,1.080,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,306,293,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,307,359,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123311,606,0.050,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,203,4.810,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,204,0.276,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,205,14.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,208,78,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,269,0.474,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,291,3.480,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,301,28.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,303,1.140,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,306,313,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,307,327,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123312,606,0.053,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,203,4.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,204,0.264,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,205,13.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,208,74.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,269,0.454,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,291,3.330,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,301,27.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,303,1.090,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,306,300.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,307,339,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123313,606,0.051,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,203,4.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,204,0.276,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,205,14,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,208,77.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,269,0.473,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,291,3.480,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,301,28.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,303,1.140,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,306,313,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,307,341,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123314,606,0.053,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,203,4.760,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,204,0.559,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,205,15,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,208,83.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,269,0.752,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,291,3.610,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,301,33.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,303,1.240,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,306,326,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,307,412,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,539,0.141,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123315,606,0.093,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,203,4.730,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,204,0.562,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,205,14.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,208,82.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,269,0.735,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,291,3.560,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,301,33,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,303,1.260,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,306,305,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,307,411,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123316,606,0.093,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,203,5.030,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,204,0.545,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,205,15.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,208,87.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,269,0.741,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,291,3.770,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,301,33.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,303,1.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,306,340,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,307,391,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,539,0.134,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123317,606,0.091,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,203,4.740,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,204,0.543,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,205,14.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,208,83.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,269,0.726,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,291,3.570,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,301,32.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,303,1.230,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,306,322,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,307,412,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,539,0.141,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123318,606,0.090,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,203,4.560,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,204,0.541,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,205,14.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,208,80.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,269,0.717,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,291,3.440,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,301,32,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,303,1.190,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,306,310,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,307,416,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,539,0.146,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,605,0.003,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123319,606,0.089,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,203,5.050,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,204,1.060,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,205,12.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,208,79.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,269,0.452,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,291,3.190,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,301,26.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,303,1.060,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,306,290,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,307,355,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,539,0.017,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,601,1.290,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123320,606,0.340,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,203,4.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,204,0.278,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,205,14,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,208,75.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,269,1.440,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,291,3.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,301,26.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,303,1.050,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,306,297,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,307,304,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,539,0.706,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123321,606,0.055,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,203,5.540,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,204,0.296,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,205,14.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,208,79.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,269,1.620,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,291,2.490,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,301,27.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,303,1.950,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,306,262,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,307,345,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123322,606,0.078,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123323,203,4.560,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,204,0.506,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,205,16.900,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,208,88.900,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,269,1.610,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,291,6.370,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,301,41.200,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,303,1.940,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,306,356,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,307,378,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,401,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,539,0.799,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123323,606,0.059,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123324,203,4.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,204,0.761,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,205,17,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,208,91.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,269,1.090,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,291,6.340,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,301,71.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,303,1.990,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,306,365,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,307,362,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,539,0.171,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123324,606,0.096,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,203,4.480,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,204,0.752,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,205,16.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,208,90.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,269,1.070,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,291,6.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,301,70.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,303,1.980,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,306,362,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,307,358,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,539,0.170,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123325,606,0.094,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,203,4.470,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,204,0.752,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,205,16.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,208,90.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,269,1.070,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,291,6.280,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,301,72.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,303,1.980,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,306,361,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,307,360,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,539,0.176,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123326,606,0.094,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,203,4.590,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,204,0.759,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,205,17.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,208,92.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,269,1.080,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,291,6.440,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,301,72.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,303,2.030,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,306,370,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,307,349,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,539,0.172,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123327,606,0.095,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,203,5.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,204,0.388,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,205,17,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,208,93.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,269,0.615,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,291,4.150,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,301,35.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,303,1.370,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,306,405,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,307,157,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123328,606,0.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,203,5.950,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,204,0.210,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,205,15.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,208,84.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,269,0.563,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,291,6.290,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,301,69.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,303,2.070,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,306,356,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,307,90.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123329,606,0.030,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,203,5.660,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,204,0.206,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,205,17,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,208,91.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,269,2.160,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,291,3.820,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,301,65,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,303,1.680,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,306,343,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,307,85.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,539,1.630,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123330,606,0.039,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,203,5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,204,1.460,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,205,15.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,208,91.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,269,2.580,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,291,2.940,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,301,26.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,303,1.040,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,306,173,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,307,188,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123331,606,0.145,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,203,4.780,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,204,0.249,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,205,13.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,208,74.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,269,0.494,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,291,4.410,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,301,52.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,303,1.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,306,304,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,307,135,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123332,606,0.078,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,203,4.25,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,204,0.244,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,205,12.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,208,68.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,269,0.419,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,291,3.080,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,301,25.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,303,1.010,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,306,277,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,307,172,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123333,606,0.047,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,203,6.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,204,2.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,205,17.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,208,113,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,269,0.605,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,291,4.390,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,301,36.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,303,1.540,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,306,421,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,307,315,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,601,0.966,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123334,606,0.791,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,203,5.910,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,204,0.394,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,205,17.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,208,93.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,269,0.622,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,291,4.170,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,301,35.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,303,1.390,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,306,406,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,307,345,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,539,0.001,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,605,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123335,606,0.101,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,203,4.360,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,204,0.256,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,205,12.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,208,71.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,269,0.441,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,291,3.160,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,301,26.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,303,1.030,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,306,284,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,307,374,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,539,0.005,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,601,0.001,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123337,606,0.049,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,203,5.040,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,204,0.722,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,205,26,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,208,128,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,269,11.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,291,3.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,301,42.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,303,1.460,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,306,291,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,307,452,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,328,0.335,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,539,10.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,601,0.069,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,605,0.003,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123338,606,0.090,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,203,5.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,204,0.419,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,205,26.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,208,128,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,269,12.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,291,3.670,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,301,40.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,303,1.410,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,306,304,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,307,396,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,539,9.990,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,601,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123339,606,0.051,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,203,5.460,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,204,0.399,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,205,30,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,208,142,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,269,14.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,291,3.770,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,301,47.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,303,1.710,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,306,326,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,307,342,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,539,13.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,601,0.001,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123340,606,0.045,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123341,203,5.190,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,204,0.380,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,205,20.900,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,207,NULL,'100g',NULL,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,208,104,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,255,NULL,'100g',NULL,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,269,7.300,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,291,3.600,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,301,40,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,303,1.490,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,306,301,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,307,315,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,328,0,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,401,NULL,'100g',NULL,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,539,6.100,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,601,0,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,605,0,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123341,606,0.050,'100g',6,3,'2022-04-01','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123342,203,5.440,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,204,0.510,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,205,17.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,208,92.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,269,0.826,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,291,3.970,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,301,37.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,303,1.590,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,306,376,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,307,355,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123342,606,0.095,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,203,5.610,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,204,2.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,205,16.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,208,107,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,269,0.557,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,291,4.070,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,301,31.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,303,1.440,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,306,366,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,307,318,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,601,0.787,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123343,606,0.701,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,203,5.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,204,0.374,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,205,22.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,208,113,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,269,9.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,291,3.560,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,301,38.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,303,1.460,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,306,296,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,307,429,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,539,8.290,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123344,606,0.044,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,203,4.930,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,204,0.367,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,205,22.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,208,111,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,269,9.730,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,291,3.430,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,301,38.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,303,1.440,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,306,288,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,307,433,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,539,8.550,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123345,606,0.044,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,203,5.240,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,204,0.373,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,205,22.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,208,113,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,269,9.610,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,291,3.430,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,301,38.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,303,1.450,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,306,296.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,307,435,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,328,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,539,8.440,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123346,606,0.189,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,203,5.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,204,0.412,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,205,15.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,208,84.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,269,0.697,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,291,4.680,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,301,58.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,303,1.570,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,306,329,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,307,300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,539,0.037,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,601,0.257,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123347,606,0.105,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,203,2.090,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,204,1.050,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,205,16.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,208,81,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,269,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,291,1.620,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,301,3.570,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,303,0.602,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,306,63.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,307,499,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123348,606,0.148,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,203,1.190,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,204,0.550,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,205,12.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,208,60.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,269,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,291,1.570,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,301,3.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,303,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,306,12.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,307,470,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123349,606,0.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,203,1.190,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,204,0.550,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,205,12.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,208,60.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,269,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,291,1.570,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,301,3.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,303,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,306,12.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,307,470,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123350,606,0.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,203,4.510,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,204,0.628,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,205,15,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,208,81.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,269,1.690,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,291,3.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,301,46.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,303,1.670,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,306,330,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,307,948,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,539,0.761,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,601,0.004,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123351,606,0.134,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,203,4.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,204,0.388,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,205,13.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,208,73.500,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,269,1.350,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,291,3.050,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,301,33.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,303,1.320,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,306,293,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,307,769,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,539,0.490,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123352,606,0.082,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123353,203,2.350,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,204,9.410,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,205,25.900,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,208,188,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,291,2.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,301,12,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,303,1.180,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,306,247,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,307,518,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123353,606,0.590,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,203,2.350,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,204,9.410,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,205,23.5,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,208,188.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,291,2.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,301,12.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,303,0.470,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,306,318.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,307,294.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123354,606,0.590,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123355,203,1.430,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,204,8.570,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,205,25.700,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,207,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,208,200,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,255,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,269,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,291,1.400,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,301,14.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,303,0.430,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,306,286.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,307,300,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,320,0.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,328,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,401,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,539,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,601,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,605,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123355,606,0.710,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123356,203,13.300,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,204,9.380,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,205,28.100,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,207,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,208,250,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,255,NULL,'100g',NULL,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,269,2.340,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,291,3.900,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,301,138,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,303,2.340,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,306,377,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,307,422,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,328,0,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,401,138,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,539,0,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,601,20,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,605,0,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123356,606,3.120,'100g',6,3,'2022-04-01','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123357,203,10,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,204,3.000,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,205,20,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,208,140,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,269,3,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,291,2,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,301,31,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,303,1,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,306,206,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,307,330,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,539,1,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,601,10,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123357,606,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123358,203,15.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,204,8.240,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,205,15.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,208,212,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,269,1.180,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,291,1.200,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,301,47,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,303,1.690,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,306,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,307,518,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,401,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,601,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123358,606,0.590,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,203,12.100,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,204,12.100,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,205,21.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,208,234,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,269,4.260,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,291,1.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,301,131,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,303,1.420,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,306,271,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,307,560,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,401,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,539,2.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,601,85,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123359,606,5.670,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,203,101,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,204,8.280,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,205,17.200,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,208,186,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,269,1.380,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,291,1.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,301,127,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,303,1.380,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,306,101,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,307,490,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,401,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,539,0.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,601,83,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123360,606,3.100,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123361,203,15,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,204,13,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,205,13,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,207,NULL,'100g',NULL,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,208,230,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,255,NULL,'100g',NULL,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,269,1,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,291,2,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,301,19,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,303,1,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,306,287,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,307,380,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,320,0.000,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,328,0,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,401,0,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,539,1,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,601,45,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,605,0,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123361,606,3,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,203,5.630,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,204,15.500,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,205,52.100,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,207,NULL,'100g',NULL,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,208,366,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,255,NULL,'100g',NULL,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,269,22.500,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,291,2.800,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,301,56.000,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,303,1.690,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,306,85.000,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,307,190.000,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,320,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,328,0,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,401,NULL,'100g',NULL,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,539,22.500,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,601,28.000,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,605,0,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123362,606,4.230,'100g',6,3,'2022-04-01','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123363,203,5.880,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,204,15.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,205,51.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,208,365.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,269,22.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,291,2.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,301,59,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,303,1.760,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,306,94.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,307,188.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,539,22.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,601,24.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123363,606,4.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,203,2.350,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,204,9.410,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,205,23.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,208,188,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,269,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,291,2.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,301,28,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,303,0.590,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,306,379,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,307,188,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,320,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,401,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123364,606,1.760,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,203,2.350,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,204,7.060,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,205,24.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,208,165,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,269,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,291,2.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,301,11,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,303,0.820,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,306,282,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,307,506,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,320,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,401,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123365,606,0.590,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123366,203,16.300,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,204,5.100,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,205,7.140,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,207,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,208,156,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,255,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,269,5.100,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,291,1,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,301,41,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,303,1.470,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,306,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,307,265,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,320,37.000,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,328,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,401,1.200,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,539,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,601,45,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,605,0,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123366,606,2.040,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,203,17,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,204,5.320,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,205,3.190,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,207,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,208,150,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,255,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,269,2.130,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,291,1.100,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,301,21,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,303,1.150,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,306,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,307,489,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,320,19.000,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,328,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,401,0,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,539,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,601,49,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,605,0,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123367,606,2.130,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123368,203,13.800,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,204,3.190,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,205,12.800,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,207,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,208,132,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,255,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,269,8.510,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,291,2.100,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,301,38.000,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,303,1.060,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,306,93.000,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,307,468,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,328,3.000,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,401,2.600,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,539,0.000,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,601,27,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,605,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123368,606,1.060,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,203,13.800,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,204,3.450,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,205,6.900,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,207,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,208,130,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,255,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,269,5.170,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,291,0.900,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,301,34,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,303,1.240,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,306,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,307,262,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,328,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,401,1,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,539,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,601,34,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,605,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123369,606,0.860,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123370,203,15.800,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,204,4.880,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,205,11,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,207,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,208,150,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,255,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,269,8.540,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,291,1.200,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,301,24,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,303,1.320,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,306,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,307,449,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,320,44.000,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,328,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,401,1.5,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,539,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,601,39,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,605,0,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123370,606,1.220,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123371,203,15.800,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,204,4.880,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,205,3.660,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,207,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,208,120,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,255,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,269,2.440,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,291,1.200,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,301,24,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,303,1.320,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,306,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,307,607,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,328,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,401,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,539,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,601,39,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,605,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123371,606,1.220,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123372,203,16.200,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,204,14.900,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,205,5.410,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,207,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,208,216,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,255,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,269,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,291,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,301,69,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,303,1.350,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,306,189,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,307,554,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,320,0.000,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,328,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,401,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,539,0.700,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,601,54,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,605,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123372,606,3.380,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123373,203,2.350,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,204,7.060,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,205,25.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,208,176,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,269,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,291,1.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,301,21,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,303,0.590,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,306,291,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,307,565,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,320,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,401,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123373,606,1.180,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123374,203,7.060,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,204,15.300,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,205,41.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,208,329,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,269,5.880,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,291,1.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,301,35,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,303,2.590,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,306,82,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,307,106,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,539,4.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,601,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123374,606,3.530,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,203,6.450,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,204,11.300,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,205,46.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,208,306,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,269,6.450,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,291,1.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,301,111,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,303,3.230,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,306,89.000,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,307,371,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,328,2,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,539,6.5,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,601,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123375,606,4.840,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123376,203,6.450,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,204,12.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,205,41.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,208,323,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,269,6.450,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,291,1.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,301,48,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,303,2.580,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,306,81,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,307,242,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,539,4.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,601,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123376,606,3.230,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,203,7.350,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,204,10.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,205,45.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,208,309,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,269,7.350,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,291,4.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,301,44,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,303,2.210,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,306,162,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,307,309,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,539,4.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,601,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123377,606,4.410,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,203,7.350,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,204,10.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,205,45.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,208,309,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,269,7.350,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,291,4.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,301,44,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,303,2.210,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,306,162,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,307,309,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,539,4.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,601,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123378,606,4.410,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,203,6.980,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,204,14,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,205,41.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,208,326,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,269,4.650,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,291,4.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,301,47,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,303,2.330,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,306,186,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,307,395,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,539,4.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,601,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123379,606,4.650,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123380,203,8.060,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,204,8.060,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,205,46.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,208,274,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,269,4.840,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,291,3.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,301,131,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,303,1.610,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,306,169.000,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,307,484,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,328,2,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,539,4.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,601,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123380,606,3.230,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,203,9.300,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,204,8.140,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,205,44.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,208,279,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,269,6.980,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,291,4.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,301,181,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,303,2.330,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,306,233.000,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,307,372,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,539,4.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,601,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123381,606,3.490,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123382,203,8.060,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,204,14.5,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,205,43.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,208,323,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,269,6.450,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,291,4.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,301,48,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,303,2.100,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,306,161,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,307,387,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,539,3.200,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,601,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123382,606,8.060,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,203,9.090,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,204,3.030,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,205,42.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,208,212,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,269,3.030,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,291,6.100,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,301,79,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,303,3.030,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,306,136,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,307,485,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,401,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,539,3,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,601,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123383,606,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123384,203,10.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,204,3.570,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,205,57.100,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,208,321,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,269,3.570,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,291,3.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,301,93,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,303,5.140,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,306,214,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,307,232.000,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,539,3.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,601,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123384,606,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123385,203,4.400,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,204,13.200,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,205,51.600,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,207,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,208,341,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,255,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,269,27.5,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,291,3.300,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,301,165,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,303,1.650,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,306,132,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,307,286,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,328,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,401,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,539,26.400,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,601,5,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,605,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123385,606,5.490,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,203,4.400,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,204,13.200,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,205,51.600,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,207,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,208,341,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,255,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,269,27.5,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,291,3.300,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,301,165,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,303,1.870,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,306,121,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,307,286,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,328,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,401,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,539,26.400,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,601,5,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,605,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123386,606,6.590,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,203,3.300,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,204,19.800,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,205,45,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,207,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,208,363,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,255,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,269,24.200,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,291,3.300,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,301,33,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,303,2.200,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,306,154,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,307,264,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,328,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,401,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,539,24.200,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,601,22,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,605,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123387,606,12.100,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,203,4.400,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,204,13.200,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,205,53.800,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,207,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,208,352,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,255,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,269,26.400,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,291,3.300,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,301,132,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,303,1.650,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,306,121,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,307,286,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,328,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,401,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,539,25.300,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,601,5,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,605,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123388,606,5.490,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123389,203,3.25,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,204,0.240,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,205,11.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,208,60.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,269,6.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,291,3.060,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,301,15.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,303,0.883,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,306,146,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,307,262,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,539,3,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123389,606,0.043,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123390,203,5.230,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,204,11.900,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,205,62.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,208,373,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,269,29.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,291,3.500,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,301,21,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,303,2.270,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,306,179,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,307,288,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,539,29.300,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,601,18,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,605,0.100,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123390,606,3.350,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123391,203,2.350,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,204,4.120,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,205,23.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,208,141,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,269,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,291,2.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,301,12,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,303,0.350,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,306,353,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,307,482,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,320,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,401,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123391,606,0.590,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123392,203,2.350,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,204,4.710,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,205,24.700,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,207,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,208,153,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,255,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,269,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,291,1.200,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,301,12,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,303,0.470,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,306,306,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,307,506,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,320,0.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,328,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,401,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,539,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,601,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,605,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123392,606,0.590,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123393,203,2.350,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,204,4.710,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,205,24.700,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,208,153,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,291,1.200,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,301,12,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,303,0.470,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,306,311,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,307,506,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123393,606,0.590,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123394,203,2.350,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,204,4.710,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,205,24.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,208,153,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,269,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,291,2.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,301,16,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,303,0.710,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,306,360,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,307,529,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,320,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,401,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123394,606,0.590,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,203,2.350,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,204,5.880,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,205,24.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,208,165,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,269,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,291,2.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,301,12,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,303,1.180,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,306,365,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,307,459,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,320,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,401,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123395,606,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123396,203,5.300,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,204,12.600,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,205,64,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,207,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,208,381,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,255,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,269,29.200,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,291,4.700,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,301,23,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,303,2.960,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,306,196,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,307,247,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,328,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,401,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,539,28.900,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,601,19,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,605,0.100,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123396,606,3.980,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123397,203,5.570,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,204,11.300,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,205,61.400,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,207,NULL,'100g',NULL,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,208,364.000,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,255,NULL,'100g',NULL,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,269,27.800,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,291,4.700,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,301,30.000,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,303,3.630,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,306,303.000,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,307,329.000,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,320,NULL,'100g',NULL,3,'2024-12-12','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,328,0,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,401,NULL,'100g',NULL,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,539,27.400,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,601,18,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,605,0.110,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123397,606,3.800,'100g',6,3,'2022-04-01','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (123399,203,7.140,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,204,12.5,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,205,64.300,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,207,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,208,393,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,255,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,269,28.600,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,291,3.600,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,301,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,303,2.140,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,306,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,307,304,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,328,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,401,0.300,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,601,36,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,605,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123399,606,3.570,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123400,203,5.350,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,204,10.400,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,205,64.400,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,208,373,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,269,30.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,291,3.500,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,301,19,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,303,1.830,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,306,208,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,307,275,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,539,30.400,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,601,26,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,605,0.130,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123400,606,3.530,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123402,203,4.970,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,204,13,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,205,63.800,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,207,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,208,386,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,255,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,269,30.100,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,291,4.700,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,301,21,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,303,2.280,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,306,156,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,307,300,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,328,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,401,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,539,29.700,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,601,21,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,605,0.120,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123402,606,3.620,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123403,203,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,204,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,205,45.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,208,192.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,269,41.800,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,291,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,301,25.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,303,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,306,35.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,307,41.800,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,401,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,539,41.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123403,606,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,203,16.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,204,9.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,205,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,208,140,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,291,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,301,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,303,0.840,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,306,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,307,605,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,328,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,401,2.800,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,601,93,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123404,606,2.330,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123405,203,14.300,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,204,14.300,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,205,0,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,207,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,208,190,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,255,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,269,0,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,291,0,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,301,0,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,303,0.860,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,306,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,307,714,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,320,0.000,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,328,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,401,2.900,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,539,NULL,'100g',NULL,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,601,95,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,605,0,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123405,606,3.570,'100g',6,3,'2022-04-01','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123406,203,15,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,204,12.5,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,205,5,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,208,200,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,291,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,301,50,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,303,0.900,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,306,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,307,600,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,328,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,601,88,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123406,606,3.75,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123407,203,16.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,204,16.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,205,2.380,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,208,238,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,269,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,291,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,301,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,303,0.860,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,306,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,307,405,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,401,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,539,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,601,60,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123407,606,7.140,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,203,14.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,204,42.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,205,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,208,429,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,269,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,291,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,301,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,303,1.290,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,306,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,307,321,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,401,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,539,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,601,71,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123408,606,14.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123409,203,13,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,204,43.5,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,205,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,208,435,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,291,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,301,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,303,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,306,191.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,307,696,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,328,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,539,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,601,87,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123409,606,15.200,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,203,14.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,204,42.900,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,205,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,208,429,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,291,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,301,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,303,1.290,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,306,193.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,307,714,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,328,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,539,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,601,89,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123410,606,17.900,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123411,203,16.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,204,16.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,205,2.380,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,208,238,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,269,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,291,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,301,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,303,0.860,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,306,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,307,405,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,401,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,539,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,601,60,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123411,606,7.140,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123412,203,14.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,204,39.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,205,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,208,429,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,291,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,301,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,303,1.290,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,306,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,307,321,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,328,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,601,71,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123412,606,14.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,203,14.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,204,39.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,205,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,208,429,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,291,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,301,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,303,1.290,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,306,193.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,307,679,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,328,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,539,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,601,71,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123414,606,14.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,203,14.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,204,40.5,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,205,2.380,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,208,429,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,291,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,301,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,303,0.860,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,306,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,307,667,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,328,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,601,71,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123415,606,14.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,203,7,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,204,22,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,205,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,208,230,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,291,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,301,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,303,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,306,108.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,307,370,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,328,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,539,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,601,45,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123416,606,8,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,203,11.900,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,204,40.5,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,205,2.380,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,208,429,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,291,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,301,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,303,0.860,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,306,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,307,310,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,328,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,539,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,601,71,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123417,606,14.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,203,19,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,204,8.330,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,205,2.380,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,208,167,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,291,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,301,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,303,2.570,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,306,190.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,307,381,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,328,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,539,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,601,71,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123418,606,2.380,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,203,19,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,204,9.520,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,205,4.760,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,208,167,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,269,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,291,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,301,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,303,1.710,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,306,671.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,307,429,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,328,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,539,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,601,71,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123419,606,2.380,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123420,203,7.840,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,204,2.940,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,205,41.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,208,216,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,269,1.960,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,291,3.900,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,301,51,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,303,2.820,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,306,118,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,307,147.000,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,539,2,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,601,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123420,606,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123421,203,8.240,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,204,1.180,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,205,45.900,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,207,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,208,224,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,255,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,269,3.530,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,291,4.700,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,301,47,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,303,1.270,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,306,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,307,353,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,328,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,401,7.100,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,601,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,605,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123421,606,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123423,203,8.770,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,204,3.510,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,205,50.900,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,208,263,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,269,1.75,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,291,3.5,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,301,46,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,303,2.530,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,306,149,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,307,184.000,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,539,1.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,601,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123423,606,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123424,203,7.060,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,204,1.180,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,205,42.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,208,212,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,269,3.530,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,291,3.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,301,71.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,303,2.590,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,306,129.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,307,365.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,539,2.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123424,606,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123425,203,7.840,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,204,2.940,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,205,41.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,208,216,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,269,1.960,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,291,3.900,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,301,51,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,303,2.820,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,306,118,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,307,147.000,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,539,2,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,601,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123425,606,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123426,203,8.210,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,204,3.080,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,205,16.400,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,207,NULL,'100g',NULL,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,208,128,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,255,NULL,'100g',NULL,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,269,1.540,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,291,2.100,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,301,113,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,303,0.510,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,306,159,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,307,308,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,320,NULL,'100g',NULL,3,'2024-12-12','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,328,1,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,401,0,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,539,0.5,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,601,13,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,605,0,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123426,606,1.280,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123427,203,0,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,204,2.350,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,205,44.700,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,207,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,208,247,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,255,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,269,3.530,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,291,1.200,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,301,59,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,303,2.710,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,306,71,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,307,424,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,328,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,401,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,539,3.5,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,601,0,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,605,0,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123427,606,1.180,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123428,203,5.5,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,204,14.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,205,75.600,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,207,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,208,436,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,255,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,269,29.700,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,291,4.100,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,301,21,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,303,2.700,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,306,143,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,307,358,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,328,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,401,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,539,29.400,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,601,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,605,0.200,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123428,606,4.400,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123429,203,7.180,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,204,3.830,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,205,17.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,208,134,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,269,4.310,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,291,2.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,301,196,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,303,0.480,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,306,149,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,307,273,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,401,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,539,0.5,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,601,10,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123429,606,1.910,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123430,203,6.25,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,204,10.900,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,205,65.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,208,375,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,269,21.900,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,291,3.100,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,301,34,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,303,1.560,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,306,123,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,307,250,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,539,18.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,601,16,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123430,606,4.690,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,203,10.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,204,3.570,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,205,57.100,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,208,321,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,269,3.570,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,291,3.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,301,93,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,303,5.140,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,306,214,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,307,232.000,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,539,3.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,601,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123432,606,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123433,203,9.310,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,204,3.920,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,205,18.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,208,147,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,269,3.430,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,291,2,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,301,144,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,303,0.980,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,306,234,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,307,314,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,401,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,539,0.5,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,601,12,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123433,606,2.210,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123434,203,5.790,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,204,10.200,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,205,54.300,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,207,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,208,322,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,255,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,269,28.200,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,291,3.5,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,301,57,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,303,1.570,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,306,197,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,307,222,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,328,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,401,4.400,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,539,26.900,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,601,63,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,605,0.090,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123434,606,3.280,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,203,5.790,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,204,10.600,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,205,53.200,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,207,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,208,329,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,255,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,269,29.300,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,291,3.5,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,301,55,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,303,1.550,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,306,215,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,307,228,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,328,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,401,3.700,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,539,27.300,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,601,67,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,605,0.090,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123435,606,3.260,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,203,6.040,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,204,13.5,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,205,58,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,207,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,208,362,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,255,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,269,27,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,291,4.400,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,301,70,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,303,2.25,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,306,188,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,307,233,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,328,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,401,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,539,24.5,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,601,76,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,605,0.180,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123436,606,3.600,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,203,6.130,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,204,10.200,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,205,58.600,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,207,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,208,335,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,255,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,269,30.800,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,291,3.5,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,301,72,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,303,2.610,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,306,241,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,307,229,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,328,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,401,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,539,30.5,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,601,61,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,605,0.090,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123437,606,3.440,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123438,203,6.190,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,204,11.5,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,205,54,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,207,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,208,336,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,255,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,269,22.100,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,291,2.700,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,301,44,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,303,1.770,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,306,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,307,336,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,328,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,401,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,539,NULL,'100g',NULL,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,601,71,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,605,0,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123438,606,3.540,'100g',6,3,'2022-04-01','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123439,203,6.600,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,204,11.700,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,205,54.500,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,207,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,208,335.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,255,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,269,22.800,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,291,1.800,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,301,35.300,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,303,2.010,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,306,229.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,307,335.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,328,0.350,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,401,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,539,21.500,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,601,70.900,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,605,0.150,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123439,606,3.350,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123440,203,5.310,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,204,10.300,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,205,52,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,207,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,208,332,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,255,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,269,28.800,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,291,3.5,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,301,56,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,303,1.620,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,306,154,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,307,227,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,328,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,401,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,539,27.900,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,601,57,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,605,0.100,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123440,606,3.360,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123441,203,5.260,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,204,2.630,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,205,49.100,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,208,228,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,269,26.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,291,1.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,301,23,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,303,1.75,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,306,70,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,307,421,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,539,24.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,601,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123441,606,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123442,203,11.5,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,204,9.350,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,205,24.5,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,207,NULL,'100g',NULL,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,208,100,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,255,NULL,'100g',NULL,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,269,2.880,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,291,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,301,324,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,303,2.160,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,306,124,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,307,568,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,328,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,401,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,539,0.700,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,601,29,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,605,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123442,606,5.040,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123443,203,11.5,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,204,9.350,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,205,24.5,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,207,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,208,100,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,255,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,269,2.880,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,291,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,301,324,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,303,2.160,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,306,124,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,307,568,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,328,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,401,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,539,0.700,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,601,29,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,605,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123443,606,5.040,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123444,203,5.980,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,204,10.400,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,205,52.800,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,207,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,208,323,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,255,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,269,28.200,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,291,4.400,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,301,40,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,303,1.510,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,306,242,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,307,142,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,328,0,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,401,NULL,'100g',NULL,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,539,27,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,601,65,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,605,0.110,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123444,606,3.240,'100g',6,3,'2022-04-01','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123445,203,5.410,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,204,5.410,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,205,43.200,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,207,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,208,243,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,255,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,269,16.200,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,291,2.700,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,301,108,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,303,1.890,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,306,108,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,307,257,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,328,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,401,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,539,10.800,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,601,14,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,605,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123445,606,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123446,203,5.410,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,204,4.050,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,205,40.5,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,208,216,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,269,13.5,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,291,2.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,301,99,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,303,1.970,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,306,108.000,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,307,243,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,539,5.400,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,601,14,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123446,606,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123447,203,9.860,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,204,8.450,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,205,23.900,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,207,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,208,218,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,255,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,269,4.230,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,291,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,301,239,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,303,1.410,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,306,67,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,307,451,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,328,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,401,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,539,1.400,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,601,25,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,605,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123447,606,4.230,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,203,9.520,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,204,8.330,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,205,28.600,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,207,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,208,238,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,255,NULL,'100g',NULL,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,269,4.760,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,291,2.400,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,301,217,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,303,2.380,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,306,64,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,307,429,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,328,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,401,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,539,2.400,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,601,24,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,605,0,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123448,606,3.570,'100g',6,3,'2022-04-01','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123449,203,2.350,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,204,3.530,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,205,23.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,208,129,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,269,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,291,2.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,301,9,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,303,0.590,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,306,329,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,307,29,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,320,0.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,401,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,601,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123449,606,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123450,203,2.650,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,204,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,205,79.600,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,208,292,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,269,58.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,291,2.700,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,301,50,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,303,2.650,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,306,743,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,307,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,401,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,539,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123450,606,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123451,203,15.600,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,204,7.030,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,205,22.700,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,207,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,208,227,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,255,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,269,3.910,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,291,1.600,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,301,172,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,303,1.560,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,306,281,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,307,430,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,328,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,401,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,539,3.100,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,601,35,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,605,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123451,606,3.520,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123452,203,15.600,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,204,7.030,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,205,22.700,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,207,NULL,'100g',NULL,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,208,227,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,255,NULL,'100g',NULL,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,269,3.910,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,291,1.600,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,301,172,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,303,1.560,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,306,281,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,307,430,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,320,NULL,'100g',NULL,3,'2024-12-12','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,328,NULL,'100g',NULL,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,401,NULL,'100g',NULL,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,539,3.100,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,601,35,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,605,0,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123452,606,3.520,'100g',6,3,'2022-04-01','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123453,203,14.200,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,204,5.310,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,205,24.800,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,207,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,208,221,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,255,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,269,3.540,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,291,1.800,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,301,106,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,303,1.770,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,306,239,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,307,363,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,328,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,401,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,539,3.5,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,601,31,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,605,0,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123453,606,2.210,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123454,203,14.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,204,5.310,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,205,24.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,208,221,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,269,3.540,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,291,1.800,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,301,106,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,303,1.770,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,306,239,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,307,363,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,539,3.5,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,601,31,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123454,606,2.210,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,203,12.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,204,8.970,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,205,20.5,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,208,212,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,269,6.410,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,291,1.300,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,301,108,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,303,1.540,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,306,205,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,307,449,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,539,3.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,601,42,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123455,606,2.880,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123456,203,13.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,204,10.200,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,205,21.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,208,227,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,269,7.950,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,291,1.100,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,301,159,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,303,1.930,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,306,284,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,307,545,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,539,8,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,601,40,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123456,606,3.980,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,203,13.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,204,3.980,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,205,21.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,208,227,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,269,7.950,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,291,1.100,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,301,159,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,303,1.930,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,306,284,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,307,545,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,539,8,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,601,40,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123457,606,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,203,10.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,204,6.760,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,205,24.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,208,216,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,269,9.460,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,291,1.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,301,41,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,303,2.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,306,189,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,307,459,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,539,9.5,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,601,34,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123458,606,2.030,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,203,10.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,204,6.760,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,205,24.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,208,216,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,269,9.460,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,291,1.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,301,41,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,303,2.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,306,189,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,307,459,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,539,9.5,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,601,34,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123459,606,2.030,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123460,203,10.900,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,204,9.520,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,205,19,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,208,197,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,269,4.080,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,291,1.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,301,97,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,303,1.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,306,143.000,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,307,381,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,539,3.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,601,34,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123460,606,2.040,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123461,203,13.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,204,6.110,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,205,25.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,208,206,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,269,3.050,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,291,1.5,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,301,53,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,303,1.070,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,306,153,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,307,389,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,539,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,601,31,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123461,606,2.290,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123462,203,13.700,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,204,6.870,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,205,22.900,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,207,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,208,206,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,255,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,269,1.530,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,291,1.5,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,301,55,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,303,1.910,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,306,215,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,307,427,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,328,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,401,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,539,1.5,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,601,31,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,605,0,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123462,606,2.290,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123463,203,17,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,204,14.400,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,205,23.700,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,207,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,208,288,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,255,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,269,3.390,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,291,3.400,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,301,398,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,303,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,306,347,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,307,602,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,328,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,401,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,539,1.700,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,601,25,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,605,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123463,606,6.780,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123464,203,15.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,204,11.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,205,22.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,208,270,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,269,1.740,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,291,3.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,301,391,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,303,1.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,306,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,307,487,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,539,1.700,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,601,26,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123464,606,6.090,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123465,203,15.600,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,204,21.100,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,205,21.900,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,207,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,208,336,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,255,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,269,3.120,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,291,3.100,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,301,367,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,303,0,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,306,320,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,307,555,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,328,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,401,NULL,'100g',NULL,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,539,3.100,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,601,23,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,605,0,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123465,606,7.030,'100g',6,3,'2022-04-01','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123466,203,15.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,204,16.500,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,205,22.600,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,208,313,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,269,1.740,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,291,3.5,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,301,374,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,303,1.300,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,306,26,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,307,504,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,539,1.700,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,601,35,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123466,606,7.830,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123467,203,15.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,204,18.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,205,22.600,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,208,330,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,269,1.740,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,291,3.5,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,301,348,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,303,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,306,52,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,307,530,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,539,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,601,43,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123467,606,9.570,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,203,5.330,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,204,0.676,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,205,19,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,208,100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,269,5.550,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,291,3.590,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,301,36.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,303,1.320,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,306,287,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,307,476,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,539,4.440,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,601,0.206,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123468,606,0.159,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,203,5.460,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,204,0.675,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,205,19.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,208,102,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,269,5.470,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,291,3.690,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,301,37.100,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,303,1.350,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,306,294,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,307,469,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,539,4.340,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,601,0.199,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123469,606,0.156,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,203,5.570,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,204,0.625,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,205,18.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,208,98.300,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,269,4.210,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,291,3.780,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,301,46.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,303,1.390,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,306,302,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,307,380,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,539,3.060,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,601,0.155,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123470,606,0.134,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,203,5.620,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,204,0.681,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,205,18.400,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,207,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,208,99.200,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,255,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,269,3.040,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,291,3.800,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,301,47,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,303,1.390,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,306,304,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,307,388,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,328,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,401,NULL,'100g',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,539,3.040,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,601,0.191,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,605,0,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123471,606,0.154,'100g',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123472,203,10.700,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,204,3.570,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,205,57.100,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,207,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,208,321,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,255,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,269,3.570,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,291,3.600,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,301,93,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,303,5.140,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,306,214,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,307,232.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,328,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,401,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,539,3.600,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,601,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,605,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123472,606,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123473,203,5.430,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,204,5.430,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,205,44.600,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,207,NULL,'100g',NULL,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,208,261,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,255,NULL,'100g',NULL,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,269,15.200,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,291,0,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,301,22,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,303,1.090,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,306,24,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,307,293,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,320,NULL,'100g',NULL,3,'2024-12-12','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,328,0,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,401,0,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,539,13,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,601,0,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,605,0,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123473,606,2.720,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123474,203,5.430,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,204,5.430,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,205,44.600,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,207,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,208,261,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,255,NULL,'100g',NULL,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,269,15.200,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,291,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,301,22,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,303,1.090,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,306,24,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,307,293,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,320,0.000,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,328,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,401,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,539,13,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,601,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,605,0,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123474,606,2.720,'100g',6,3,'2022-04-01','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123475,203,7.340,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,204,3.210,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,205,17,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,207,NULL,'100g',NULL,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,208,128,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,255,NULL,'100g',NULL,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,269,4.130,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,291,0.900,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,301,188,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,303,0.460,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,306,143,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,307,284,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,320,NULL,'100g',NULL,3,'2024-12-12','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,328,0,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,401,0,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,539,0.5,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,601,9,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,605,0,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123475,606,1.610,'100g',6,3,'2022-04-01','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (123478,203,8.240,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,204,0.590,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,205,11.800,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,207,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,208,94,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,255,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,269,2.350,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,291,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,301,12,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,303,0.120,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,306,306,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,307,541,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,328,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,401,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,539,2.400,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,601,12,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,605,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123478,606,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123479,203,6.100,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,204,4.880,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,205,46.300,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,207,NULL,'100g',NULL,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,208,256,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,255,NULL,'100g',NULL,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,269,12.200,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,291,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,301,29,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,303,1.220,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,306,21,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,307,232,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,328,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,401,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,539,9.800,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,601,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,605,0,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123479,606,2.440,'100g',6,3,'2022-04-01','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123480,203,6.100,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,204,4.880,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,205,46.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,208,256,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,269,12.200,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,291,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,301,29,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,303,1.220,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,306,21,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,307,232,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,401,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,539,9.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,601,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123480,606,2.440,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123481,203,2.350,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,204,4.710,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,205,28.200,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,207,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,208,165,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,255,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,269,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,291,3.5,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,301,12,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,303,1.180,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,306,376,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,307,306,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,320,0.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,328,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,401,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,539,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,601,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,605,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123481,606,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123482,203,7.060,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,204,11.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,205,47.100,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,208,318,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,269,15.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,291,3.5,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,301,47,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,303,2.470,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,306,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,307,259,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,539,15.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,601,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123482,606,5.290,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123483,203,4.710,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,204,3.530,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,205,28.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,207,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,208,153.000,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,255,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,269,2.350,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,291,3.500,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,301,32.000,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,303,1.180,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,306,188.000,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,307,235.000,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,328,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,401,NULL,'100g',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,539,1.200,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,601,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,605,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123483,606,0,'100g',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123484,203,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,204,0.000,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,205,11.200,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,207,NULL,'100ml',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,208,44,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,255,NULL,'100ml',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,269,11.200,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,291,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,301,10,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,303,0.270,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,306,125,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,307,5,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,320,NULL,'100ml',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,328,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,401,30.500,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,539,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,601,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,605,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123484,606,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,203,0.340,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,204,0.000,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,205,15.600,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,207,NULL,'100ml',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,208,61,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,255,NULL,'100ml',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,269,14.900,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,291,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,301,10,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,303,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,306,68,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,307,5,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,320,NULL,'100ml',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,328,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,401,30.500,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,539,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,601,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,605,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123485,606,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,203,0.340,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,204,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,205,12.200,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,207,NULL,'100ml',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,208,51,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,255,NULL,'100ml',NULL,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,269,9.490,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,291,0.300,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,301,14,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,303,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,306,136,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,307,8,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,320,NULL,'100ml',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,328,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,401,30.500,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,539,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,601,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,605,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123486,606,0,'100ml',6,3,'2022-04-01','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123487,203,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,204,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,205,11.200,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,207,NULL,'100ml',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,208,44,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,255,NULL,'100ml',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,269,11.200,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,291,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,301,12,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,303,0.260,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,306,126,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,307,4,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,328,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,401,17.600,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,539,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,601,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,605,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123487,606,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,203,0.290,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,204,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,205,12.100,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,207,NULL,'100ml',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,208,50,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,255,NULL,'100ml',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,269,9.410,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,291,0.300,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,301,12,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,303,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,306,135,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,307,9,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,328,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,401,17.600,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,539,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,601,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,605,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123488,606,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,203,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,204,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,205,11.100,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,207,NULL,'100ml',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,208,43,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,255,NULL,'100ml',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,269,11.100,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,291,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,301,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,303,0.25,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,306,123,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,307,6,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,328,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,401,37,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,539,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,601,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,605,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123489,606,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,203,0.620,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,204,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,205,15.400,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,207,NULL,'100ml',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,208,62,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,255,NULL,'100ml',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,269,14.800,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,291,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,301,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,303,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,306,62,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,307,6,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,328,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,401,25.900,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,539,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,601,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,605,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123490,606,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,203,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,204,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,205,12.400,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,207,NULL,'100ml',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,208,49,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,255,NULL,'100ml',NULL,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,269,9.260,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,291,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,301,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,303,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,306,136,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,307,9,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,328,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,401,37,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,539,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,601,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,605,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123491,606,0,'100ml',6,3,'2022-04-01','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123492,203,4.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,204,8.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,205,41.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,208,258,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,269,12.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,291,2.200,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,301,22,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,303,1.940,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,306,151,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,307,269,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,401,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,539,4.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,601,32,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123492,606,1.080,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,203,12.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,204,2.890,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,205,24,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,208,174,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,269,4.130,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,291,1.700,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,301,149,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,303,1.070,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,306,174,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,307,198,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,401,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,601,4,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123493,606,1.650,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,203,11.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,204,11.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,205,28.5,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,208,272,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,269,11.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,291,2,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,301,13,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,303,1.790,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,306,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,307,424,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,539,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,601,23,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123494,606,2.320,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,203,13,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,204,2.440,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,205,27.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,208,187,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,269,4.070,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,291,2.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,301,122,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,303,1.380,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,306,154,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,307,195,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,401,4.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,601,4,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123495,606,1.220,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,203,12.300,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,204,2.870,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,205,23.800,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,208,180,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,269,4.100,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,291,1.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,301,139,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,303,1.070,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,306,164,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,307,205,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,401,4.900,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,601,4,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123496,606,1.640,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,203,13,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,204,2.440,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,205,27.600,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,207,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,208,187,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,255,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,269,3.25,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,291,2.400,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,301,122,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,303,1.380,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,306,154,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,307,195,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,328,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,401,NULL,'100g',NULL,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,539,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,601,4,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,605,0,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123497,606,1.220,'100g',6,3,'2022-04-01','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123498,203,17.600,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,204,44.100,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,205,32.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,208,559,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,269,14.700,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,291,8.800,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,301,79,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,303,2.940,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,306,429,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,307,191,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,320,0.000,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,401,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,539,11.800,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123498,606,5.880,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123499,203,6,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,204,13.200,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,205,75.200,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,207,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,208,428,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,255,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,269,25.600,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,291,4.400,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,301,34,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,303,3.100,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,306,187,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,307,344,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,328,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,401,NULL,'100g',NULL,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,539,25.400,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,601,0,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,605,0.200,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123499,606,4.100,'100g',6,3,'2022-04-01','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123501,203,16.700,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,204,6.500,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,205,19.900,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,208,183,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,269,2.100,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,291,6.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,301,83.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,303,1.700,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,306,358,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,307,396,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,401,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,539,1.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,601,5,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123501,606,1,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,203,7.100,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,204,13.200,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,205,76.100,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,208,450,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,269,20.900,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,291,4.900,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,301,41.500,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,303,3.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,306,167,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,307,329,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,401,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,539,20.600,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,605,0.200,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123502,606,4.100,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,203,4,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,204,10.100,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,205,76.200,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,208,409,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,269,28.5,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,291,1.5,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,301,17,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,303,5.700,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,306,120,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,307,362,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,401,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,539,28.5,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,605,0.100,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123505,606,2.5,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,203,6.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,204,10.500,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,205,77.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,208,412,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,269,21.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,291,4.600,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,301,48.900,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,303,3.5,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,306,205,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,307,420,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,401,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,539,21.200,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123506,606,1.5,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,203,6.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,204,12.100,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,205,75.300,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,208,420,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,269,18.600,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,291,4.600,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,301,54.200,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,303,3.600,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,306,215,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,307,455,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,401,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,539,18.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,605,0.200,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123507,606,1.800,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,203,8,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,204,2.200,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,205,84.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,207,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,208,353,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,255,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,269,20.800,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,291,9.700,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,301,15.100,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,303,30,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,306,270,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,307,17,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,328,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,401,NULL,'100g',NULL,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,539,20.100,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,601,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,605,0,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123508,606,0.400,'100g',6,3,'2022-04-01','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123513,203,1.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,204,0.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,205,4.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,207,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,208,20.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,255,NULL,'100g',NULL,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,269,2.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,291,2.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,301,30.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,303,0.400,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,306,100.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,307,140.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,320,0.000,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,328,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,401,2.500,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,539,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,601,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,605,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123513,606,0,'100g',6,3,'2022-04-01','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123515,203,17.200,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,204,10.200,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,205,25.800,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,207,NULL,'100g',NULL,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,208,250,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,255,NULL,'100g',NULL,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,269,4.510,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,291,1.600,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,301,350,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,303,2.460,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,306,319,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,307,652,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,320,NULL,'100g',NULL,3,'2024-12-12','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,328,NULL,'100g',NULL,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,401,NULL,'100g',NULL,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,539,3.300,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,601,31,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,605,0,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123515,606,4.710,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,203,3.300,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,204,12.100,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,205,57.100,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,207,NULL,'100g',NULL,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,208,341,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,255,NULL,'100g',NULL,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,269,31.900,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,291,2.200,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,301,44,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,303,1.430,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,306,77,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,307,275,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,320,NULL,'100g',NULL,3,'2024-12-12','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,328,NULL,'100g',NULL,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,401,NULL,'100g',NULL,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,539,31.900,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,601,22,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,605,0,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123516,606,5.490,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,203,3.300,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,204,19.800,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,205,45,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,207,NULL,'100g',NULL,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,208,363,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,255,NULL,'100g',NULL,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,269,24.200,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,291,3.300,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,301,33,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,303,2.200,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,306,154,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,307,264,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,320,NULL,'100g',NULL,3,'2024-12-12','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,328,NULL,'100g',NULL,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,401,NULL,'100g',NULL,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,539,24.200,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,601,22,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,605,0,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123517,606,12.100,'100g',6,3,'2023-05-27','2022-09-15');
INSERT INTO `cndb_nutval` VALUES (123520,203,15,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,204,9.25,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,205,26,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,207,NULL,'100g',NULL,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,208,243,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,255,NULL,'100g',NULL,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,269,1.730,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,291,2.300,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,301,301,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,303,1.390,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,306,179,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,307,410,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,320,NULL,'100g',NULL,3,'2024-12-12','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,328,NULL,'100g',NULL,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,401,NULL,'100g',NULL,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,539,NULL,'100g',NULL,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,601,26,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,605,0,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123520,606,4.620,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,203,16.900,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,204,12.700,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,205,33.800,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,207,NULL,'100g',NULL,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,208,303,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,255,NULL,'100g',NULL,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,269,1.410,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,291,2.800,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,301,352,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,303,2.110,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,306,127,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,307,444,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,320,NULL,'100g',NULL,3,'2024-12-12','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,328,NULL,'100g',NULL,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,401,NULL,'100g',NULL,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,539,0.700,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,601,28,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,605,0,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123521,606,6.340,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,203,13.400,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,204,12.700,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,205,33.800,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,207,NULL,'100g',NULL,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,208,303,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,255,NULL,'100g',NULL,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,269,1.410,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,291,2.800,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,301,352,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,303,2.110,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,306,127,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,307,444,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,320,NULL,'100g',NULL,3,'2024-12-12','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,328,NULL,'100g',NULL,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,401,NULL,'100g',NULL,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,539,0.700,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,601,28,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,605,0,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123522,606,6.340,'100g',6,3,'2023-05-27','2022-12-07');
INSERT INTO `cndb_nutval` VALUES (123524,203,5.050,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,204,9.090,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,205,47.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,208,283,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,269,22.200,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,291,2,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,301,20,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,303,1.820,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,306,141,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,307,283,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,401,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,539,9.100,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,601,25,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123524,606,2.020,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,203,10.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,204,1.75,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,205,49.100,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,208,246,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,269,5.260,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,291,5.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,301,35,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,303,3.160,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,306,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,307,509,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,328,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,401,2.100,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,539,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123525,606,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123526,203,6.25,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,204,12.5,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,205,38.5,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,207,NULL,'100g',NULL,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,208,312,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,255,NULL,'100g',NULL,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,269,22.900,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,291,2.100,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,301,62,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,303,1.880,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,306,146,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,307,281,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,320,NULL,'100g',NULL,3,'2024-12-12','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,328,NULL,'100g',NULL,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,401,NULL,'100g',NULL,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,539,9.400,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,601,36,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,605,0,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123526,606,2.600,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123527,203,5.880,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,204,13.200,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,205,64.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,208,382,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,269,32.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,291,2.900,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,301,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,303,3.180,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,306,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,307,294,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,401,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,539,17.600,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,601,29,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123527,606,2.940,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123528,203,4.710,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,204,7.060,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,205,54.100,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,207,NULL,'100g',NULL,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,208,282,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,255,NULL,'100g',NULL,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,269,18.800,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,291,4.700,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,301,118,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,303,6.350,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,306,82,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,307,306,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,320,NULL,'100g',NULL,3,'2024-12-12','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,328,NULL,'100g',NULL,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,401,17.600,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,539,18.800,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,601,6,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,605,0,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123528,606,2.350,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,203,5.880,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,204,13.200,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,205,64.700,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,207,NULL,'100g',NULL,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,208,382,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,255,NULL,'100g',NULL,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,269,32.400,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,291,2.900,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,301,0,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,303,3.180,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,306,0,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,307,294,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,320,NULL,'100g',NULL,3,'2024-12-12','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,328,NULL,'100g',NULL,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,401,NULL,'100g',NULL,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,539,2.900,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,601,29,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,605,0,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123529,606,2.940,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123531,203,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,204,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,205,12.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,208,50,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,269,10.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,291,2.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,301,28,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,303,0.210,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,306,108,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,307,4,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,328,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,401,67.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,539,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,605,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123531,606,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123532,203,4.710,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,204,7.060,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,205,54.100,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,207,NULL,'100g',NULL,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,208,282,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,255,NULL,'100g',NULL,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,269,18.800,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,291,4.700,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,301,118,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,303,6.350,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,306,82,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,307,306,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,320,NULL,'100g',NULL,3,'2024-12-12','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,328,NULL,'100g',NULL,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,401,17.600,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,539,18.800,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,601,6,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,605,0,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123532,606,2.350,'100g',6,3,'2023-05-27','2023-01-26');
INSERT INTO `cndb_nutval` VALUES (123533,203,14.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,204,4.930,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,205,23.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,208,197,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,269,4.230,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,291,2.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,301,176,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,303,1.270,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,306,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,307,345,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,328,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,401,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,539,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,601,7,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123533,606,2.110,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123534,203,7.140,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,204,14.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,205,64.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,208,393,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,269,32.100,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,291,3.600,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,301,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,303,3.860,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,306,250,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,307,214,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,401,4.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,539,14.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,601,214,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123534,606,3.570,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123538,203,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,204,0.000,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,205,13.300,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,208,47,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,269,10.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,291,0.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,301,4,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,303,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,306,70,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,307,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,401,46.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,539,2.300,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,605,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123538,606,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,203,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,204,0.000,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,205,13.300,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,208,47,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,269,11.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,291,0.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,301,4,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,303,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,306,70,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,307,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,401,46.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,539,2.300,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,605,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123543,606,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123546,203,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,204,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,205,14.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,208,55,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,269,11.700,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,291,0.800,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,301,4,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,303,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,306,105,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,307,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,328,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,401,46.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,539,1.600,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,601,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123546,606,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123551,203,6.450,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,204,14.5,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,205,62.900,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,207,NULL,'100g',NULL,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,208,403,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,255,NULL,'100g',NULL,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,269,21,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,291,4.800,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,301,34,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,303,1.610,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,306,169,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,307,129,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,328,NULL,'100g',NULL,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,401,NULL,'100g',NULL,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,539,16.100,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,601,0,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,605,0,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123551,606,1.610,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,203,6.450,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,204,12.900,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,205,67.700,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,207,NULL,'100g',NULL,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,208,403,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,255,NULL,'100g',NULL,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,269,22.600,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,291,3.200,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,301,21,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,303,3.230,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,306,166,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,307,129,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,328,NULL,'100g',NULL,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,401,NULL,'100g',NULL,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,539,21,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,601,0,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,605,0,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123552,606,4.030,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,203,6.600,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,204,10.400,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,205,31.100,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,207,NULL,'100g',NULL,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,208,236,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,255,NULL,'100g',NULL,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,269,0.940,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,291,0.900,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,301,28,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,303,2.830,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,306,91,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,307,358,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,320,NULL,'100g',NULL,3,'2024-12-12','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,328,NULL,'100g',NULL,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,401,3.400,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,539,0,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,601,14,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,605,0,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123554,606,4.25,'100g',6,3,'2023-05-27','2023-02-16');
INSERT INTO `cndb_nutval` VALUES (123555,203,7.140,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,204,14.300,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,205,75,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,208,429,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,269,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,301,18,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,306,196,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,307,196,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,539,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,601,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123555,606,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123556,203,7.030,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,204,2.730,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,205,21.100,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,207,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,208,133,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,255,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,269,3.910,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,291,5.5,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,301,41,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,303,2.340,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,306,217,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,307,117,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,328,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,401,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,539,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,601,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,605,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123556,606,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123559,203,13.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,204,6.700,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,205,73.700,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,207,4.510,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,208,367.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,255,NULL,'100g',NULL,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,269,4.560,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,291,10.800,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,301,333,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,303,32.300,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,306,653.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,307,498.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,320,231.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,328,10.300,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,401,23.100,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,539,2.560,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,601,0,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,605,0.005,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123559,606,1.380,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123561,203,4.650,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,204,14,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,205,62.800,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,208,37,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,269,34.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,291,2.300,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,301,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,303,1.670,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,306,100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,307,302,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,328,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,401,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,539,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,601,23,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123561,606,3.490,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123568,203,6.670,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,204,11.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,205,46.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,208,317,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,269,1.670,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,291,1.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,301,20,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,303,3.330,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,306,78,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,307,1150,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,539,1.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,605,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123568,606,6.670,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,203,22.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,204,51.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,205,22.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,208,571,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,269,5.710,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,291,11.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,301,286,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,303,3.430,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,306,743,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,307,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,539,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,605,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123579,606,2.860,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123584,203,5.570,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,204,10.5,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,205,54.400,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,207,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,208,329,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,255,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,269,28.100,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,291,4.400,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,301,35,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,303,1.600,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,306,243,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,307,124,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,328,0,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,401,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,539,27.400,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,601,69,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,605,0.110,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123584,606,3.320,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,203,6.050,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,204,10.300,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,205,53.600,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,207,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,208,325,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,255,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,269,29.200,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,291,4.400,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,301,36,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,303,1.5,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,306,259,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,307,126,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,328,0,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,401,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,539,27.400,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,601,65,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,605,0.110,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123585,606,3.230,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123586,203,7.080,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,204,10.600,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,205,55.800,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,208,345,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,269,30.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,291,4.400,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,301,44,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,303,2.650,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,306,327,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,307,230,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,328,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,401,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,539,30.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,601,75,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123586,606,3.540,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123592,203,10,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,204,16.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,205,63.300,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,208,467,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,269,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,291,6.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,301,100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,303,3.330,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,306,233,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,307,800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,539,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,601,17,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,605,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123592,606,3.330,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123601,203,0.100,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,204,0.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,205,6.900,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,208,27,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,269,0.790,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,291,0.200,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,301,16,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,303,0.290,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,306,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,307,423,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,328,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,401,4.800,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,539,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123601,606,0.050,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,203,8.970,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,204,9.340,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,205,16.200,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,208,186,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,269,1.970,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,291,1.200,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,301,218,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,303,0.630,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,306,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,307,462,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,328,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,401,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,539,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,601,27,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,605,0.080,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123608,606,5.240,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123609,203,1.380,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,204,1.060,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,205,27.600,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,207,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,208,124,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,255,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,269,21.300,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,291,0.5,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,301,35,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,303,0.000,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,306,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,307,681.000,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,320,32.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,328,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,401,2.100,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,539,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,601,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,605,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123609,606,0.140,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,203,1.450,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,204,0.070,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,205,27,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,207,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,208,112,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,255,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,269,20.100,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,291,0.400,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,301,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,303,0.000,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,306,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,307,401,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,328,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,401,29.600,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,539,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,601,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,605,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123610,606,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,203,1.550,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,204,0.040,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,205,32.700,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,207,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,208,136,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,255,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,269,26.400,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,291,0.5,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,301,35,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,303,0.000,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,306,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,307,763.000,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,328,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,401,2.100,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,539,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,601,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,605,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123611,606,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123612,203,1.340,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,204,2.050,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,205,32.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,208,151,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,269,27,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,291,0.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,301,35,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,303,0.630,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,306,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,307,756,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,328,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,401,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,539,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,605,0.040,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123612,606,0.320,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123613,203,0.420,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,204,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,205,36.600,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,207,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,208,152,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,255,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,269,31.800,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,291,0.200,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,301,35,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,303,0.630,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,306,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,307,234.000,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,328,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,401,4.200,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,539,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,601,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,605,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123613,606,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,203,1.410,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,204,0.040,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,205,43.200,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,207,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,208,177,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,255,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,269,36.900,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,291,0.5,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,301,35,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,303,0.000,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,306,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,307,680.000,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,328,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,401,2.100,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,539,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,601,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,605,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123614,606,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123626,203,8.590,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,204,9.820,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,205,7.360,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,207,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,208,153,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,255,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,269,1.230,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,291,0.600,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,301,18,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,303,1.230,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,306,129,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,307,423,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,320,NULL,'100g',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,328,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,401,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,539,0.600,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,601,28,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,605,0.610,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123626,606,4.290,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123631,203,4.170,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,204,1.670,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,205,12.5,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,207,NULL,'100ml',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,208,83,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,255,NULL,'100ml',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,269,2.5,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,291,2.5,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,301,33,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,303,0.830,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,306,192,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,307,567,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,320,NULL,'100ml',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,328,0,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,401,NULL,'100ml',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,539,0.800,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,601,0,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,605,0,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123631,606,0.420,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123632,203,4.170,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,204,1.25,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,205,10,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,207,NULL,'100ml',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,208,67,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,255,NULL,'100ml',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,269,1.670,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,291,0.800,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,301,17,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,303,0.830,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,306,417,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,307,342,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,320,NULL,'100ml',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,328,NULL,'100ml',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,401,NULL,'100ml',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,539,0.800,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,601,21,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,605,0,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123632,606,0.420,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,203,5,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,204,1.670,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,205,10.800,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,207,NULL,'100ml',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,208,75,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,255,NULL,'100ml',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,269,1.670,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,291,1.700,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,301,25,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,303,0.830,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,306,167,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,307,342,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,320,NULL,'100ml',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,328,NULL,'100ml',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,401,NULL,'100ml',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,539,0.800,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,601,8,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,605,0,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123633,606,0.830,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,203,21.400,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,204,21.400,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,205,3.570,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,207,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,208,286,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,255,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,269,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,291,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,301,604,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,303,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,306,79,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,307,714,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,320,NULL,'100g',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,328,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,401,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,539,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,601,54,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,605,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123645,606,12.5,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,203,11.600,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,204,7.740,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,205,29,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,207,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,208,226,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,255,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,269,1.940,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,291,2.600,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,301,194,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,303,1.740,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,306,90,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,307,368,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,320,NULL,'100g',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,328,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,401,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,539,1.300,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,601,19,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,605,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123677,606,3.870,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123678,203,4.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,204,11.800,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,205,48,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,208,324,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,269,23.5,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,291,2.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,301,78,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,303,1.760,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,306,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,307,176,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,328,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,401,5.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,539,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,601,29,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123678,606,1.960,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,203,21.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,204,53.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,205,21.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,208,625,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,269,12.500,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,291,6.200,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,301,69,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,303,4.380,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,306,650,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,307,375,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,328,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,401,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,539,9.400,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,601,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123686,606,9.380,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123687,203,5.570,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,204,10.5,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,205,54.400,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,207,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,208,329,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,255,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,269,28.100,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,291,4.400,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,301,35,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,303,1.600,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,306,243,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,307,124,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,328,0,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,401,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,539,27.400,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,601,69,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,605,0.110,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123687,606,3.320,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,203,6.050,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,204,10.300,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,205,53.600,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,207,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,208,325,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,255,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,269,29.200,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,291,4.400,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,301,36,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,303,1.5,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,306,259,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,307,126,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,328,0,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,401,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,539,27.400,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,601,65,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,605,0.110,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123688,606,3.230,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123689,203,7.080,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,204,10.600,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,205,55.800,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,208,345,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,269,30.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,291,4.400,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,301,44,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,303,2.650,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,306,327,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,307,230,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,328,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,401,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,539,30.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,601,75,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123689,606,3.540,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123690,203,5.980,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,204,10.400,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,205,52.800,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,207,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,208,323,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,255,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,269,28.200,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,291,4.400,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,301,40,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,303,1.510,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,306,242,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,307,142,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,328,0,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,401,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,539,27,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,601,65,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,605,0.110,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123690,606,3.240,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (123691,203,8.700,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,204,10.900,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,205,4.350,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,208,152,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,269,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,291,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,301,52,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,303,1.570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,306,126,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,307,304,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,328,2,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,601,261,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123691,606,2.170,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123692,203,10.700,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,204,10.700,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,205,3.570,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,207,NULL,'100g',NULL,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,208,161,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,255,NULL,'100g',NULL,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,269,0,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,291,0,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,301,64,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,303,0,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,306,146,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,307,464,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,320,64.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,328,4,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,401,NULL,'100g',NULL,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,539,0,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,601,339,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,605,0,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123692,606,3.570,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123693,203,13,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,204,10.000,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,205,1,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,208,150,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,269,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,291,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,301,59,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,303,2,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,306,136,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,307,135,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,328,2,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,601,405,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123693,606,3.5,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123694,203,9.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,204,3.490,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,205,48.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,208,256,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,269,6.980,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,291,4.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,301,30,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,303,2.330,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,306,200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,307,395,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,539,4.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123694,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,203,10.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,204,3.510,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,205,47.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,208,263,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,269,7.020,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,291,5.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,301,30,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,303,3.510,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,306,198,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,307,404,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,539,5.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123695,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,203,10.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,204,3.570,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,205,50,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,208,286,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,269,7.140,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,291,3.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,301,136,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,303,3.570,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,306,221,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,307,482,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,401,21.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,539,7.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123696,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,203,6.980,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,204,5.810,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,205,44.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,208,256,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,269,6.980,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,291,2.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,301,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,303,2.330,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,306,70,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,307,442,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,401,8.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,539,7,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123697,606,2.330,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,203,11.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,204,2.860,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,205,51.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,208,286,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,269,8.570,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,291,5.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,301,31,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,303,2.860,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,306,209,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,307,429,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,539,5.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123698,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,203,10.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,204,3.510,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,205,49.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,208,263,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,269,7.020,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,291,5.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,301,30,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,303,3.510,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,306,202,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,307,421,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,539,5.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123699,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,203,10.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,204,3.510,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,205,49.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,208,263,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,269,7.020,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,291,5.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,301,30,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,303,3.510,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,306,202,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,307,404,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,401,4.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,539,5.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123700,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123701,203,6.25,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,204,9.380,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,205,46.900,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,207,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,208,297,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,255,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,269,9.380,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,291,3.100,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,301,364,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,303,3.120,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,306,180,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,307,500,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,320,0.000,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,328,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,401,1.200,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,539,7.800,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,601,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,605,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123701,606,3.120,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123702,203,8.770,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,204,3.510,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,205,45.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,208,246,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,269,7.020,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,291,3.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,301,39,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,303,1.75,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,306,186,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,307,456,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,401,10.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,539,5.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123702,606,1.75,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,203,7.020,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,204,8.770,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,205,45.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,208,298,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,269,8.770,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,291,3.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,301,365,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,303,1.75,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,306,181,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,307,491,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,539,7,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123703,606,3.510,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,203,5.710,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,204,8.570,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,205,45.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,208,286,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,269,8.570,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,291,2.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,301,360,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,303,2.860,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,306,177,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,307,486,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,401,1.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,539,8.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123704,606,2.860,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123705,203,6.450,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,204,8.060,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,205,45.200,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,207,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,208,290,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,255,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,269,6.450,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,291,3.200,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,301,129,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,303,3.230,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,306,181,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,307,516,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,320,0.000,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,328,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,401,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,539,6.5,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,601,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,605,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123705,606,3.230,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123706,203,10.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,204,2.940,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,205,48.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,208,265,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,269,7.350,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,291,4.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,301,29,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,303,2.940,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,306,199,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,307,412,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,539,5.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123706,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,203,6.25,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,204,9.380,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,205,46.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,208,297,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,269,9.380,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,291,3.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,301,364,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,303,3.120,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,306,180,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,307,500,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,401,1.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,539,7.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123707,606,3.120,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,203,6.25,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,204,9.380,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,205,43.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,208,297,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,269,4.690,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,291,1.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,301,97,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,303,3.120,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,306,131,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,307,953,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,539,3.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123708,606,5.470,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,203,5.630,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,204,8.450,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,205,42.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,208,268,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,269,8.450,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,291,2.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,301,235,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,303,1.410,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,306,148,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,307,479,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,401,1.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,539,7,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123709,606,2.820,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,203,5.630,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,204,7.040,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,205,46.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,208,282,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,269,11.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,291,2.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,301,239,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,303,2.820,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,306,165,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,307,423,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,539,7,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123710,606,3.520,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,203,5.630,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,204,8.450,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,205,47.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,208,282,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,269,12.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,291,2.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,301,241,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,303,2.820,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,306,165,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,307,423,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,401,1.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,539,8.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123711,606,3.520,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,203,10.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,204,3.510,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,205,47.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,208,263,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,269,7.020,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,291,5.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,301,30,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,303,1.75,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,306,186,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,307,404,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,401,8.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,539,5.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123712,606,0.350,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123713,203,7.140,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,204,3.570,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,205,46.400,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,207,NULL,'100g',NULL,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,208,250.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,255,NULL,'100g',NULL,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,269,3.570,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,291,3.600,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,301,29.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,303,3.570,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,306,150.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,307,446.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,320,0.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,328,0,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,401,21.400,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,539,3.600,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,601,0,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,605,0,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123713,606,0.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123714,203,7.020,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,204,3.510,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,205,45.600,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,207,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,208,246,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,255,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,269,5.260,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,291,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,301,30,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,303,1.75,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,306,47,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,307,439,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,320,0.000,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,328,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,401,10.5,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,539,3.5,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,601,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,605,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123714,606,0.880,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123715,203,6.25,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,204,7.810,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,205,46.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,208,281,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,269,6.25,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,291,1.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,301,180,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,303,3.120,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,306,139,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,307,547,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,539,3.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123715,606,3.120,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,203,10.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,204,3.570,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,205,50,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,208,286,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,269,7.140,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,291,3.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,301,82,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,303,3.570,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,306,161,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,307,429,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,328,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,401,8.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,539,7.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123716,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,203,7.040,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,204,9.860,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,205,50.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,208,324,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,269,11.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,291,2.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,301,28,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,303,2.030,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,306,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,307,437,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,328,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,539,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123717,606,2.820,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,203,5.710,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,204,8.570,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,205,45.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,208,286,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,269,8.570,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,291,2.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,301,129,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,303,2.860,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,306,174,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,307,629,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,328,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,539,8.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123718,606,2.860,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,203,8.770,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,204,3.510,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,205,45.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,208,246,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,269,5.260,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,291,3.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,301,39,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,303,1.75,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,306,154,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,307,456,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,539,5.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123719,606,0.880,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123720,203,6.600,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,204,11,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,205,6.920,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,208,155,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,269,0.820,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,291,0.200,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,301,27,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,303,0.320,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,306,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,307,455,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,328,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,401,0.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,539,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,601,23,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,605,0.160,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123720,606,6.130,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123721,203,16.400,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,204,8.030,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,205,4.310,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,207,NULL,'100g',NULL,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,208,155.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,255,NULL,'100g',NULL,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,269,1.370,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,291,1.300,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,301,22,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,303,2.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,306,NULL,'100g',NULL,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,307,377.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,320,0.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,328,NULL,'100g',NULL,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,401,0,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,539,NULL,'100g',NULL,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,601,58.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,605,0.490,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123721,606,3.230,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123722,203,9.880,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,204,4.410,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,205,8.210,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,207,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,208,113,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,255,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,269,2.260,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,291,2.100,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,301,22,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,303,1.710,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,306,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,307,167.000,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,320,105.000,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,328,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,401,8.700,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,539,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,601,32,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,605,0.270,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123722,606,1.670,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (123723,203,9.660,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,204,8.300,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,205,6.170,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,208,137,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,269,1.950,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,291,1.800,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,301,35,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,303,1.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,306,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,307,263,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,328,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,401,6.800,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,539,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,601,28,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,605,0.510,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123723,606,3.130,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123724,203,14.100,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,204,5.980,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,205,9.440,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,207,NULL,'100g',NULL,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,208,148.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,255,NULL,'100g',NULL,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,269,6.710,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,291,1.400,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,301,41.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,303,1.110,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,306,NULL,'100g',NULL,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,307,640.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,320,92.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,328,NULL,'100g',NULL,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,401,6.800,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,539,NULL,'100g',NULL,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,601,43.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,605,0.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123724,606,2.050,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (123725,203,1.610,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,204,0.000,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,205,16.100,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,207,NULL,'100ml',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,208,73.000,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,255,NULL,'100ml',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,269,9.680,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,291,1.600,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,301,8,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,303,0.400,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,306,468.000,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,307,387.000,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,328,0,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,401,7.300,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,539,6.500,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,601,0,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,605,0,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123725,606,0,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123726,203,0.850,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,204,0,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,205,3.670,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,207,NULL,'100ml',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,208,17,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,255,NULL,'100ml',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,269,2.820,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,291,0.800,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,301,14,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,303,0.280,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,306,198,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,307,271,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,320,NULL,'100ml',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,328,NULL,'100ml',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,401,31.100,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,539,0,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,601,0,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,605,0,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123726,606,0,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,203,0.880,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,204,0,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,205,3.820,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,207,NULL,'100ml',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,208,18,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,255,NULL,'100ml',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,269,2.940,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,291,0.900,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,301,15,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,303,0.320,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,306,200,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,307,271,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,320,NULL,'100ml',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,328,NULL,'100ml',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,401,29.400,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,539,0,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,601,0,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,605,0,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123727,606,0,'100ml',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123728,203,1.610,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,204,0.000,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,205,16.100,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,207,NULL,'100ml',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,208,73.000,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,255,NULL,'100ml',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,269,9.680,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,291,1.600,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,301,8,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,303,0.400,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,306,468.000,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,307,387.000,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,328,0,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,401,7.300,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,539,6.500,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,601,0,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,605,0,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123728,606,0,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,203,1.610,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,204,0.000,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,205,12.900,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,207,NULL,'100ml',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,208,56.000,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,255,NULL,'100ml',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,269,6.450,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,291,1.600,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,301,8,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,303,0.400,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,306,411.000,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,307,331.000,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,328,0,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,401,7.300,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,539,3.200,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,601,0,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,605,0,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123729,606,0,'100ml',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123730,203,4.370,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,204,2.780,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,205,12.300,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,207,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,208,91,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,255,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,269,3.170,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,291,0.800,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,301,32,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,303,0.910,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,306,127,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,307,238,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,320,NULL,'100g',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,328,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,401,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,539,2,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,601,12,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,605,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123730,606,0.990,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123731,203,17.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,204,28.600,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,205,7.140,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,208,357,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,269,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,301,536,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,306,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,307,1500,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,601,89,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123731,606,17.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123732,203,17.900,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,204,32.100,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,205,7.140,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,208,357,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,269,3.570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,291,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,301,500,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,303,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,306,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,307,1570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,328,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,601,89,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123732,606,17.900,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123733,203,17.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,204,32.100,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,205,7.140,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,208,357,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,269,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,301,500,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,306,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,307,1570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,601,89,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123733,606,17.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,203,17.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,204,32.100,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,205,7.140,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,208,357,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,269,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,301,500,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,306,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,307,1610,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,601,89,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123734,606,17.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123735,203,21.400,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,204,16.100,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,205,7.140,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,208,250,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,269,7.140,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,291,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,301,693,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,303,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,306,221,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,307,1570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,328,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,601,54,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123735,606,8.930,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,203,17.900,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,204,32.100,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,205,7.140,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,208,357,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,269,3.570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,291,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,301,500,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,303,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,306,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,307,1570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,328,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,601,89,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123736,606,17.900,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123737,203,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,204,21.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,205,7.140,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,208,286,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,269,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,301,739,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,306,725,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,307,1000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,601,54,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123737,606,12.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123738,203,15.800,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,204,31.600,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,205,5.260,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,208,368,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,269,5.260,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,291,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,301,526,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,303,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,306,184,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,307,1470,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,328,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,601,79,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123738,606,18.400,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123739,203,17.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,204,28.600,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,205,7.140,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,208,357,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,269,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,301,500,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,306,182,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,307,1500,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,601,89,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123739,606,17.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,203,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,204,32.100,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,205,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,208,357,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,269,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,301,679,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,306,164,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,307,857,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,601,89,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123740,606,17.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,203,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,204,21.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,205,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,208,286,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,269,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,301,707,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,306,136,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,307,786,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,601,54,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123741,606,12.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,203,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,204,25.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,205,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,208,357,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,269,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,301,786,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,306,125,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,307,482,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,601,71,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123742,606,16.100,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,203,21.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,204,28.600,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,205,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,208,357,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,269,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,301,607,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,306,114,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,307,821,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,601,89,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123743,606,17.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,203,21.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,204,21.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,205,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,208,286,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,269,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,301,607,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,306,79,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,307,714,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,601,54,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123744,606,12.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,203,21.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,204,25.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,205,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,208,321,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,269,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,301,643,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,306,82,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,307,607,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,601,71,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123745,606,14.300,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,203,14.300,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,204,21.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,205,7.140,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,208,286,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,269,7.140,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,301,496,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,306,250,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,307,1430,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,401,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,601,71,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123746,606,12.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123747,203,25,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,204,32.100,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,205,3.570,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,207,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,208,393,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,255,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,269,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,291,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,301,714,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,303,0.710,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,306,71,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,307,643,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,320,NULL,'100g',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,328,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,401,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,539,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,601,107,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,605,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123747,606,21.400,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,203,25,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,204,17.900,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,205,7.140,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,207,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,208,286,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,255,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,269,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,291,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,301,714,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,303,0.360,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,306,179,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,307,679,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,320,NULL,'100g',NULL,3,'2024-12-12','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,328,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,401,NULL,'100g',NULL,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,539,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,601,54,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,605,0,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123748,606,10.700,'100g',6,3,'2023-05-27','2023-03-16');
INSERT INTO `cndb_nutval` VALUES (123749,203,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,204,21.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,205,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,208,321,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,269,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,301,714,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,303,0.360,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,306,179,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,307,679,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,601,71,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123749,606,12.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,203,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,204,25.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,205,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,208,321,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,269,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,301,750,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,303,0.360,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,306,179,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,307,786,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,601,71,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123750,606,14.300,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,203,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,204,21.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,205,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,208,321,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,269,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,301,750,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,303,0.360,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,306,179,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,307,750,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,601,71,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123751,606,12.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,203,21.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,204,32.100,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,205,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,208,357,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,269,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,301,607,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,306,179,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,307,1250,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,601,89,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123752,606,17.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,203,21.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,204,32.100,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,205,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,208,393,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,269,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,301,714,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,306,71,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,307,679,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,328,1,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,601,107,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123753,606,17.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123754,203,4.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,204,5.170,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,205,18.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,208,141,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,269,10.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,291,1.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,301,67,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,303,1.440,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,306,76,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,307,152,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,401,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,539,3.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,601,3,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,605,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123754,606,1.150,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,203,22.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,204,51.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,205,22.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,208,571,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,269,5.710,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,291,11.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,301,286,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,303,3.430,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,306,743,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,307,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,539,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,605,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123755,606,2.860,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123756,203,6.600,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,204,11,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,205,6.920,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,208,155,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,269,0.820,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,291,0.200,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,301,27,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,303,0.320,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,306,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,307,455,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,328,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,401,0.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,539,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,601,23,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,605,0.160,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123756,606,6.130,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,203,9.880,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,204,4.410,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,205,8.210,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,208,113,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,269,2.260,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,291,2.100,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,301,22,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,303,1.710,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,306,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,307,168,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,328,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,401,8.700,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,539,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,601,32,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,605,0.270,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123757,606,1.670,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,203,19.600,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,204,18.100,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,205,1.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,208,250,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,269,0.110,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,291,0.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,301,42,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,303,2.290,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,306,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,307,329,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,328,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,401,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,539,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,601,81,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,605,1.100,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123758,606,7.080,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123759,203,6.25,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,204,2.730,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,205,21.100,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,208,133,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,269,3.910,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,291,5.5,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,301,38,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,303,2.340,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,306,238,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,307,117,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,328,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,601,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123759,606,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123760,203,7.690,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,204,21.500,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,205,56.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,208,431,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,269,38.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,291,6.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,301,78,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,303,1.540,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,306,203,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,307,308,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,539,15.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123760,606,3.080,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,203,2.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,204,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,205,78.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,208,297,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,269,59.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,291,2.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,301,51,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,303,2.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,306,749,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,307,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123761,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123762,203,2.440,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,204,0.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,205,73.200,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,208,317,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,269,61,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,291,2.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,301,46,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,303,0.880,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,306,695,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,307,24,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,539,4.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,601,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123762,606,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,203,2.440,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,204,0.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,205,75.600,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,208,317,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,269,48.800,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,291,2.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,301,46,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,303,1.760,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,306,695,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,307,24,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,539,4.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,601,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123763,606,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123764,203,6.450,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,204,12.900,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,205,66.100,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,208,403,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,269,22.600,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,291,4.800,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,301,29,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,303,1.610,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,306,158,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,307,121,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,328,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,539,21,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,601,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123764,606,4.030,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,203,6.450,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,204,12.900,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,205,67.700,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,208,403,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,269,22.600,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,291,3.200,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,301,21,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,303,3.230,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,306,166,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,307,129,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,328,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,539,21,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,601,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123765,606,4.030,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123766,203,6.450,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,204,14.500,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,205,62.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,208,403,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,269,21,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,291,4.800,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,301,34,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,303,1.610,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,306,169,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,307,129,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,539,16.100,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,601,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123766,606,1.610,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123767,203,6.450,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,204,12.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,205,66.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,208,403,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,269,22.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,291,3.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,301,29,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,303,1.610,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,306,140,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,307,121,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,539,19.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123767,606,4.030,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123768,203,5.560,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,204,13.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,205,66.700,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,208,417,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,269,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,291,2.800,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,301,28,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,303,2.780,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,306,164,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,307,139,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,539,19.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,601,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123768,606,4.170,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,203,5.560,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,204,13.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,205,66.700,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,208,417,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,269,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,291,5.600,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,301,28,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,303,2.780,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,306,150,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,307,125,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,539,22.200,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,601,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123770,606,4.170,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123771,203,5.560,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,204,13.900,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,205,66.700,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,208,417,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,269,25,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,291,2.800,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,301,19,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,303,2.780,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,306,158,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,307,139,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,328,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,539,22.200,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,601,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123771,606,4.170,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123772,203,5.560,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,204,13.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,205,66.700,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,208,417,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,269,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,291,2.800,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,301,31,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,303,2.780,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,306,147,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,307,139,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,539,19.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,601,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123772,606,4.170,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123773,203,5.560,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,204,13.900,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,205,66.700,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,208,417,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,269,25,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,291,2.800,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,301,25,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,303,2.780,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,306,114,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,307,125,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,328,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,539,22.200,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,601,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123773,606,4.170,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (123774,203,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,204,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,205,85.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,208,341,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,269,73.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,291,2.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,301,44,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,303,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,306,29,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,307,232,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,539,41.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123774,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123775,203,7.890,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,204,18.400,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,205,65.800,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,207,NULL,'100g',NULL,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,208,474,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,255,NULL,'100g',NULL,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,269,5.260,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,291,5.300,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,301,26,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,303,1.580,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,306,1470,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,307,474,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,328,0,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,401,NULL,'100g',NULL,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,539,5.300,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,601,0,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,605,0,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123775,606,1.320,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (123779,203,5.660,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,204,0.206,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,205,17,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,208,91,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,269,2.120,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,291,3.820,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,301,64,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,303,1.680,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,306,343,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,307,205,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,539,1.590,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123779,606,0.039,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123782,203,4.710,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,204,0.25,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,205,12,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,207,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,208,67,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,255,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,269,1.380,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,291,2.100,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,301,24,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,303,1.660,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,306,223,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,307,388,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,328,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,401,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,539,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,601,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,605,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123782,606,0.070,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123783,203,5.310,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,204,0.370,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,205,23.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,208,115,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,269,9.310,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,291,3.660,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,301,40.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,303,1.470,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,306,291,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,307,424,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,539,8.370,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123783,606,0.041,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,203,4.25,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,204,0.244,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,205,12.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,208,68.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,269,0.419,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,291,3.080,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,301,25.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,303,1.010,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,306,277,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,307,172,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123784,606,0.047,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,203,4.860,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,204,0.373,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,205,24.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,208,120,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,269,11.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,291,3.410,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,301,36.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,303,1.290,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,306,283,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,307,438,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,539,9.980,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,601,0.001,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123785,606,0.043,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,203,5.610,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,204,2.120,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,205,16.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,208,107,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,269,0.557,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,291,4.070,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,301,31.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,303,1.440,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,306,366,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,307,318,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,601,0.787,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123788,606,0.701,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,203,1.120,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,204,0.540,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,205,12.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,208,60.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,269,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,291,1.510,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,301,2.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,303,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,306,10.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,307,453,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123789,606,0.160,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,203,5.440,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,204,0.510,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,205,17.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,208,92.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,269,0.826,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,291,3.970,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,301,37.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,303,1.590,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,306,376,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,307,355,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123790,606,0.095,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,203,4.470,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,204,0.752,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,205,16.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,208,90.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,269,1.070,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,291,6.280,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,301,72.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,303,1.980,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,306,361,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,307,360,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,539,0.176,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123791,606,0.094,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,203,5.950,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,204,0.210,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,205,15.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,208,84.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,269,0.563,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,291,6.290,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,301,69.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,303,2.070,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,306,356,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,307,90.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123792,606,0.030,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,203,5.540,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,204,0.296,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,205,14.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,208,79.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,269,1.620,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,291,2.490,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,301,27.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,303,1.950,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,306,262,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,307,345,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123793,606,0.078,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,203,4.910,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,204,0.330,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,205,13.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,208,74.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,269,0.853,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,291,3.360,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,301,43,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,303,1.220,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,306,261,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,307,365,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123794,606,0.037,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,203,4.780,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,204,0.249,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,205,13.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,208,74.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,269,0.494,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,291,4.410,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,301,52.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,303,1.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,306,304,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,307,135,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123795,606,0.078,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123797,203,6.120,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,204,2.200,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,205,17.700,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,207,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,208,113,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,255,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,269,0.605,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,291,4.390,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,301,36.800,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,303,1.540,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,306,421,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,307,315,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,320,NULL,'100',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,328,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,401,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,539,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,601,0.966,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,605,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123797,606,0.791,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123798,203,4.510,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,204,0.259,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,205,13.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,208,73,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,269,0.444,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,291,3.260,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,301,26.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,303,1.080,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,306,293,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,307,359,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123798,606,0.050,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,203,5.620,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,204,0.681,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,205,18.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,208,99.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,269,3.040,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,291,3.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,301,47,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,303,1.390,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,306,304,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,307,388,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,539,3.040,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,601,0.191,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123799,606,0.154,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,203,5.570,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,204,0.625,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,205,18.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,208,98.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,269,4.210,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,291,3.780,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,301,46.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,303,1.390,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,306,302,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,307,380,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,539,3.060,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,601,0.155,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123801,606,0.134,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,203,5.780,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,204,1.680,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,205,17.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,208,105,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,269,2.980,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,291,3.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,301,16.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,303,1.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,306,200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,307,278,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123802,606,0.168,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,203,5.360,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,204,1.060,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,205,22.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,208,115,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,269,9.650,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,291,3.350,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,301,37.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,303,1.430,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,306,285.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,307,443,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,328,0.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,539,8.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,601,1.120,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123804,606,0.296,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,203,5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,204,1.460,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,205,15.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,208,91.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,269,2.580,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,291,2.940,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,301,26.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,303,1.040,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,306,173,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,307,188,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123805,606,0.145,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,203,4.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,204,0.761,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,205,17,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,208,91.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,269,1.090,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,291,6.340,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,301,71.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,303,1.990,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,306,365,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,307,362,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,539,0.171,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123807,606,0.096,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,203,4.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,204,0.259,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,205,13.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,208,73,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,269,0.444,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,291,3.260,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,301,25.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,303,1.070,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,306,293,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,307,90,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123808,606,0.049,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,203,5.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,204,1.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,205,23.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,208,125,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,269,9.790,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,291,3.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,301,43.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,303,1.470,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,306,301,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,307,324,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,539,6.250,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,601,0.548,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123809,606,0.349,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,203,4.560,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,204,0.541,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,205,14.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,208,80.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,269,0.717,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,291,3.440,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,301,32,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,303,1.190,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,306,310,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,307,416,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,539,0.146,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,605,0.003,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123810,606,0.089,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,203,5.440,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,204,0.513,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,205,16.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,208,91.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,269,0.806,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,291,3.940,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,301,57.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,303,1.550,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,306,355,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,307,350,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,539,0.171,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123811,606,0.084,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,203,5.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,204,0.374,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,205,22.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,208,113,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,269,9.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,291,3.560,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,301,38.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,303,1.460,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,306,296,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,307,429,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,539,8.290,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123813,606,0.044,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,203,5.070,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,204,0.333,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,205,14.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,208,80,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,269,0.528,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,291,3.570,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,301,30.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,303,1.180,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,306,348,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,307,353,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123814,606,0.086,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,203,6.330,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,204,0.231,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,205,18.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,208,100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,269,2.020,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,291,4.270,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,301,62.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,303,1.880,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,306,383,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,307,107,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,539,1.430,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123819,606,0.043,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,203,4.360,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,204,0.256,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,205,12.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,208,71.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,269,0.441,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,291,3.160,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,301,26.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,303,1.030,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,306,284,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,307,374,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,539,0.005,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,601,0.001,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123820,606,0.049,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,203,5.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,204,0.419,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,205,26.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,208,128,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,269,12.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,291,3.670,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,301,40.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,303,1.410,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,306,304,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,307,396,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,539,9.990,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,601,0.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123821,606,0.051,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,203,4.810,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,204,0.276,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,205,14.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,208,78,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,269,0.474,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,291,3.480,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,301,28.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,303,1.140,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,306,313,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,307,327,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123823,606,0.053,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,203,4.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,204,0.276,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,205,14,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,208,77.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,269,0.473,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,291,3.480,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,301,28.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,303,1.140,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,306,313,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,307,341,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123824,606,0.053,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123825,203,4.300,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,204,0.280,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,205,14,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,207,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,208,75,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,255,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,269,1.440,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,291,3.300,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,301,27,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,303,1.090,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,306,297,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,307,304,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,328,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,401,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,539,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,601,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,605,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123825,606,0.050,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123826,203,5.450,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,204,1.590,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,205,16.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,208,99.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,269,2.810,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,291,3.210,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,301,26.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,303,1.130,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,306,189,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,307,107,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123826,606,0.158,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,203,5.910,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,204,0.394,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,205,17.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,208,93.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,269,0.622,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,291,4.170,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,301,35.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,303,1.390,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,306,406,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,307,345,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,539,0.001,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,605,0.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123827,606,0.101,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123830,203,5.660,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,204,0.206,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,205,17,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,207,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,208,91,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,255,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,269,2.120,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,291,3.820,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,301,64,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,303,1.680,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,306,343,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,307,205,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,320,NULL,'100',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,328,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,401,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,539,1.590,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,601,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,605,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123830,606,0.039,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,203,5.460,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,204,0.399,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,205,30,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,207,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,208,142,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,255,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,269,14.900,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,291,3.770,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,301,47.900,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,303,1.710,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,306,326,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,307,342,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,320,NULL,'100',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,328,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,401,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,539,13.800,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,601,0.001,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,605,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123831,606,0.045,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123832,203,5.440,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,204,0.349,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,205,15.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,208,88.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,269,0.540,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,291,3.940,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,301,30.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,303,1.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,306,355,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,307,325,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123832,606,0.062,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123833,203,0,'100ml',6,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,204,0,'100ml',6,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,205,22,'100ml',6,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,207,NULL,'100ml',NULL,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,208,90,'100ml',6,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,255,NULL,'100ml',NULL,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,269,22,'100ml',6,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,291,0,'100ml',6,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,301,20,'100ml',6,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,303,0.5,'100ml',6,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,306,240,'100ml',6,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,307,0,'100ml',6,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,320,NULL,'100ml',NULL,3,'2024-12-12','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,328,NULL,'100ml',NULL,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,401,86,'100ml',6,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,539,0,'100ml',6,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,601,0,'100ml',6,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,605,0,'100ml',6,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123833,606,0,'100ml',6,3,'2023-05-27','2023-03-23');
INSERT INTO `cndb_nutval` VALUES (123835,203,6.190,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,204,0.407,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,205,17.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,208,97.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,269,0.645,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,291,4.360,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,301,37.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,303,1.440,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,306,425.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,307,350.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123835,606,0.105,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123836,203,5.320,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,204,0.905,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,205,22.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,208,116,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,269,9.710,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,291,3.360,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,301,38.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,303,1.390,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,306,271,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,307,458,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,539,8.850,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,601,0.893,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123836,606,0.241,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,203,5.480,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,204,0.777,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,205,25.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,208,126,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,269,11.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,291,3.550,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,301,36.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,303,1.290,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,306,278,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,307,405,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,539,10.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,601,0.641,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,605,0.001,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123837,606,0.186,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,203,5.090,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,204,0.889,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,205,25.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,208,126,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,269,12.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,291,3.130,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,301,38.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,303,1.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,306,262,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,307,511,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,539,11.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,601,0.902,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,605,0.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123838,606,0.240,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,203,1.190,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,204,0.550,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,205,12.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,208,60.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,269,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,291,1.570,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,301,3.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,303,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,306,12.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,307,470,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123839,606,0.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,203,5.460,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,204,0.246,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,205,17.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,208,91.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,269,2.810,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,291,5.450,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,301,56.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,303,1.640,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,306,373,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,307,360,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,539,0.607,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123840,606,0.058,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,203,6.070,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,204,0.317,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,205,17.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,208,94.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,269,0.628,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,291,5.610,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,301,71.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,303,1.520,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,306,386,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,307,300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123841,606,0.099,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,203,5.510,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,204,0.553,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,205,23.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,208,117,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,269,9.190,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,291,3.690,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,301,40.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,303,1.480,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,306,294,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,307,421,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,539,8.250,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,601,0.281,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123842,606,0.106,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,203,4.930,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,204,0.367,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,205,22.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,208,111,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,269,9.730,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,291,3.430,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,301,38.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,303,1.440,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,306,288,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,307,433,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,539,8.550,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123843,606,0.044,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,203,6.310,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,204,0.230,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,205,18.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,208,100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,269,2,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,291,4.260,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,301,61.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,303,1.880,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,306,382,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,307,183,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,539,1.410,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123845,606,0.043,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,203,5.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,204,0.746,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,205,25.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,208,126,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,269,12,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,291,3.290,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,301,39.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,303,1.450,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,306,273,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,307,493,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,539,11.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,601,0.650,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123847,606,0.185,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,203,6.330,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,204,0.231,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,205,18.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,208,100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,269,2.020,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,291,4.270,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,301,62.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,303,1.880,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,306,383,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,307,197,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,539,1.430,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123850,606,0.043,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123855,203,5.120,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,204,0.354,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,205,25.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,208,125,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,269,11.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,291,3.530,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,301,43.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,303,1.520,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,306,297,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,307,379,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,539,10.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123855,606,0.042,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123856,203,4.760,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,204,0.559,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,205,15,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,208,83.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,269,0.752,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,291,3.610,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,301,33.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,303,1.240,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,306,326,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,307,412,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,539,0.141,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123856,606,0.093,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,203,4.590,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,204,0.759,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,205,17.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,208,92.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,269,1.080,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,291,6.440,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,301,72.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,303,2.030,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,306,370,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,307,349,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,539,0.172,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123857,606,0.095,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,203,5.830,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,204,1.070,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,205,23,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,208,121,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,269,8.910,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,291,3.640,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,301,40.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,303,1.460,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,306,295.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,307,413,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,328,0.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,539,7.730,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,601,1.120,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123858,606,0.296,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123859,203,17,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,204,15.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,205,6,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,207,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,208,220,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,269,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,291,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,301,68,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,303,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,306,188,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,307,550,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,320,0.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,401,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,539,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,601,55,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123859,606,3.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123861,203,5.130,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,204,0.295,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,205,15,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,208,83.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,269,0.506,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,291,3.720,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,301,45.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,303,1.220,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,306,335,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,307,110,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123861,606,0.056,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,203,5.75,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,204,0.487,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,205,16.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,208,93.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,269,0.847,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,291,4.060,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,301,55,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,303,1.810,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,306,365,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,307,356,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,539,0.172,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123863,606,0.079,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123864,203,4.560,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,204,0.510,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,205,16.900,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,207,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,208,89,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,255,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,269,1.610,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,291,6.400,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,301,41,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,303,1.940,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,306,356,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,307,378,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,328,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,401,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,539,0.800,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,601,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,605,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123864,606,0.060,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,203,4.920,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,204,0.450,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,205,27.700,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,207,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,208,131,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,255,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,269,13.800,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,291,3.5,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,301,42,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,303,1.5,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,306,298,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,307,318,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,328,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,401,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,539,12.5,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,601,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,605,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123865,606,0.050,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123866,203,5.720,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,204,0.201,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,205,14.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,208,80.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,269,0.541,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,291,6.040,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,301,65.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,303,1.990,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,306,342,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,307,220,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123866,606,0.029,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123869,203,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,204,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,205,82.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,208,334,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,269,69.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,291,6.080,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,301,12.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,303,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,306,51.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,307,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,539,66.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123869,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123871,203,5.340,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,204,0.286,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,205,13.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,208,76.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,269,1.570,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,291,2.410,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,301,26.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,303,1.880,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,306,252,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,307,345,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123871,606,0.075,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,203,5.150,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,204,0.387,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,205,25.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,208,124,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,269,11.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,291,3.560,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,301,37.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,303,1.330,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,306,284.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,307,433,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,328,0.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,539,10.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,605,0.001,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123872,606,0.045,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,203,5.240,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,204,0.767,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,205,22.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,208,115,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,269,9.610,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,291,3.430,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,301,38.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,303,1.450,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,306,289,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,307,435,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,539,8.440,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,601,0.641,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,605,4.480,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123873,606,0.189,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,203,5.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,204,0.769,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,205,23.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,208,118,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,269,9.380,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,291,3.560,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,301,39.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,303,1.450,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,306,286,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,307,436,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,539,8.470,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,601,0.641,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123876,606,0.186,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,203,1.120,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,204,0.540,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,205,12.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,208,60.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,269,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,291,1.510,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,301,2.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,303,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,306,10.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,307,453,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123877,606,0.160,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,203,5.160,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,204,0.388,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,205,25.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,208,123,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,269,11.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,291,3.650,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,301,38.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,303,1.320,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,306,279,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,307,425,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,539,10.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123878,606,0.045,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,203,3.25,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,204,0.240,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,205,11.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,208,60.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,269,6.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,291,3.060,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,301,15.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,303,0.883,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,306,146,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,307,262,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,539,3,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123879,606,0.043,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123880,203,5.210,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,204,1.520,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,205,15.800,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,207,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,208,95.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,255,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,269,2.690,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,291,3.100,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,301,37,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,303,1.080,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,306,181.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,307,87.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,328,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,401,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,539,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,601,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,605,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123880,606,0.150,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123882,203,1.120,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,204,0.540,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,205,12.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,208,60.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,269,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,291,1.510,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,301,2.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,303,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,306,10.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,307,453,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123882,606,0.160,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,203,5.550,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,204,0.896,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,205,23,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,208,118,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,269,9.410,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,291,3.520,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,301,39.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,303,1.440,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,306,283,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,307,441,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,539,8.510,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,601,0.853,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123883,606,0.234,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,203,5.510,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,204,0.684,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,205,17.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,208,97.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,269,0.891,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,291,4.210,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,301,75.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,303,1.480,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,306,380,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,307,101,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,539,0.186,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,605,0.003,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123886,606,0.112,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,203,1.190,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,204,0.550,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,205,12.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,208,60.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,269,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,291,1.570,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,301,3.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,303,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,306,12.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,307,470,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123887,606,0.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,203,4.780,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,204,0.421,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,205,15.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,208,82.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,269,0.708,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,291,3.620,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,301,33,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,303,1.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,306,316,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,307,377,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123889,606,0.055,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,203,5.240,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,204,0.373,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,205,22.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,208,113,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,269,9.610,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,291,3.430,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,301,38.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,303,1.450,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,306,296.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,307,435,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,328,0.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,539,8.440,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123890,606,0.189,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,203,4.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,204,1.430,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,205,14.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,208,89.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,269,2.530,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,291,2.880,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,301,26.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,303,1.020,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,306,170,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,307,370,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123891,606,0.142,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,203,5.790,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,204,0.310,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,205,14.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,208,82.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,269,1.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,291,2.610,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,301,44.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,303,2.040,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,306,274,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,307,357,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123892,606,0.081,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,203,5.390,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,204,1.040,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,205,25.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,208,127,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,269,12,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,291,3.260,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,301,39.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,303,1.450,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,306,272,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,307,496,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,539,11.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,601,1.130,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123893,606,0.293,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,203,5.640,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,204,0.305,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,205,14.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,208,80.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,269,1.680,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,291,2.620,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,301,29.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,303,2,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,306,272,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,307,346,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123896,606,0.080,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123897,203,5.190,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,204,0.705,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,205,22,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,208,112,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,269,9.170,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,291,3.420,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,301,36.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,303,1.370,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,306,280,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,307,426,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,539,8.060,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,601,0.544,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123897,606,0.166,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123898,203,5.420,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,204,1.220,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,205,21,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,208,112,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,269,8.260,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,291,3.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,301,33.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,303,1.260,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,306,260,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,307,490,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,539,7.420,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,601,1.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123898,606,0.324,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123899,203,5.120,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,204,0.412,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,205,15.700,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,207,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,208,84.600,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,255,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,269,0.697,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,291,4.680,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,301,58.500,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,303,1.570,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,306,329,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,307,300,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,320,NULL,'100',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,328,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,401,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,539,0.037,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,601,0.257,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,605,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123899,606,0.105,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123900,203,6.280,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,204,0.229,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,205,17.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,208,93.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,269,0.585,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,291,4.240,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,301,58.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,303,1.870,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,306,380,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,307,77,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123900,606,0.043,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123902,203,5.040,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,204,0.722,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,205,26,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,207,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,208,128,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,255,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,269,11.900,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,291,3.5,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,301,42.500,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,303,1.460,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,306,291,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,307,452,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,320,NULL,'100',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,328,0.335,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,401,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,539,10.700,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,601,0.069,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,605,0.003,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123902,606,0.090,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123903,203,5.080,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,204,0.917,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,205,19.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,208,103,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,269,1.230,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,291,6.850,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,301,89.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,303,2.290,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,306,415,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,307,97.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,539,0.186,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,605,0.003,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123903,606,0.117,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,203,5.450,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,204,0.358,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,205,15.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,208,86,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,269,0.568,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,291,3.830,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,301,31.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,303,1.270,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,306,374,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,307,148,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123904,606,0.093,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,203,4.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,204,0.264,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,205,13.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,208,74.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,269,0.454,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,291,3.330,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,301,27.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,303,1.090,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,306,300.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,307,339,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123905,606,0.051,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123907,203,5.180,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,204,0.390,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,205,22.400,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,207,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,208,110,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,255,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,269,8.550,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,291,3.600,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,301,38,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,303,1.330,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,306,285,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,307,302,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,328,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,401,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,539,7.5,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,601,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,605,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123907,606,0.040,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123908,203,5.820,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,204,0.212,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,205,15.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,208,87,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,269,0.542,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,291,3.920,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,301,56,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,303,1.730,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,306,352,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,307,203,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123908,606,0.040,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,203,5.050,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,204,1.060,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,205,12.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,208,79.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,269,0.452,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,291,3.190,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,301,26.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,303,1.060,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,306,290,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,307,355,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,539,0.017,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,601,1.290,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123909,606,0.340,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123910,203,6.240,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,204,0.410,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,205,18,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,208,99,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,269,0.650,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,291,4.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,301,63,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,303,1.450,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,306,429,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,307,102,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,539,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,605,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123910,606,0.110,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (123911,203,15,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,204,13,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,205,13,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,207,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,208,230,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,269,2,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,291,2,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,301,19,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,303,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,306,287,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,307,380,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,320,0.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,401,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,539,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,601,45,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123911,606,3,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (123912,203,5.190,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,204,0.380,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,205,20.900,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,207,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,208,104,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,255,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,269,7.300,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,291,3.600,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,301,40,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,303,1.490,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,306,301,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,307,315,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,328,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,401,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,539,6.100,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,601,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,605,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123912,606,0.050,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,203,5.920,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,204,0.390,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,205,17.100,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,207,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,208,94.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,255,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,269,0.620,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,291,4.200,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,301,35.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,303,1.380,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,306,407.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,307,96.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,328,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,401,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,539,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,601,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,605,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123913,606,0.100,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123914,203,5.440,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,204,0.702,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,205,23,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,208,117,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,269,9.370,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,291,3.560,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,301,39.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,303,1.440,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,306,285,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,307,435,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,539,8.460,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,601,0.544,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123914,606,0.163,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,203,5.130,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,204,0.911,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,205,22.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,208,113,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,269,9.840,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,291,3.270,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,301,37.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,303,1.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,306,278.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,307,451,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,328,0.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,539,8.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,601,0.893,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123915,606,0.244,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,203,4.730,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,204,0.562,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,205,14.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,208,82.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,269,0.735,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,291,3.560,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,301,33,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,303,1.260,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,306,305,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,307,411,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123916,606,0.093,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,203,5.270,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,204,0.170,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,205,16.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,208,85.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,269,2.740,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,291,4.670,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,301,21.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,303,1.850,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,306,424,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,307,360,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,539,0.654,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123917,606,0.040,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123918,203,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,204,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,205,11.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,208,39.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,269,9.520,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,291,0.794,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,301,3.970,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,303,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,306,73.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,307,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,401,71.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123918,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (123919,203,2.090,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,204,1.050,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,205,16.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,208,81,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,269,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,291,1.620,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,301,3.570,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,303,0.602,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,306,63.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,307,499,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123919,606,0.148,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,203,5.770,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,204,1.030,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,205,13.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,208,81.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,269,1.530,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,291,2.330,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,301,26.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,303,1.840,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,306,248,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,307,378,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,539,0.016,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,601,1.210,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123920,606,0.346,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,203,5.260,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,204,0.370,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,205,23.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,208,115,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,269,9.390,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,291,3.610,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,301,40.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,303,1.460,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,306,288,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,307,288,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,539,8.460,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123921,606,0.042,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123922,203,5.590,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,204,0.472,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,205,16.400,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,207,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,208,90.700,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,255,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,269,0.814,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,291,3.910,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,301,54.700,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,303,1.75,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,306,352,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,307,360,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,320,NULL,'100',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,328,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,401,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,539,0.176,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,601,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,605,0.003,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123922,606,0.076,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123923,203,5.75,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,204,0.784,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,205,23.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,208,120,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,269,8.780,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,291,3.750,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,301,41.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,303,1.480,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,306,302,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,307,400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,539,7.570,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,601,0.648,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123923,606,0.189,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,203,5.380,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,204,0.926,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,205,21.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,208,113,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,269,8.160,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,291,3.430,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,301,35.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,303,1.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,306,270,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,307,484,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,539,7.290,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,601,0.719,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123924,606,0.217,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123925,203,5.720,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,204,0.711,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,205,17.800,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,207,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,208,97.700,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,255,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,269,0.928,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,291,4.150,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,301,74.800,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,303,1.550,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,306,409,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,307,336,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,320,NULL,'100',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,328,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,401,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,539,0.095,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,601,0.001,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,605,0.018,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123925,606,0.152,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123928,203,5.130,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,204,0.295,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,205,15,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,208,83.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,269,0.506,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,291,3.720,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,301,38.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,303,1.220,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,306,334,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,307,335,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123928,606,0.056,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,203,5.460,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,204,0.675,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,205,19.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,208,102,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,269,5.470,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,291,3.690,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,301,37.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,303,1.350,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,306,294,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,307,469,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,539,4.340,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,601,0.199,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123929,606,0.156,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,203,4.740,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,204,0.543,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,205,14.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,208,83.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,269,0.726,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,291,3.570,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,301,32.800,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,303,1.230,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,306,322,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,307,412,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,539,0.141,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123930,606,0.090,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,203,5.330,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,204,0.676,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,205,19,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,208,100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,269,5.550,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,291,3.590,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,301,36.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,303,1.320,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,306,287,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,307,476,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,539,4.440,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,601,0.206,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123931,606,0.159,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,203,6.090,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,204,0.214,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,205,15.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,208,86,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,269,0.576,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,291,6.430,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,301,68.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,303,2.120,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,306,364,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,307,95,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123932,606,0.031,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,203,5.75,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,204,1.160,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,205,24,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,208,126,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,269,9.220,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,291,3.680,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,301,49.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,303,1.670,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,306,323,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,307,301,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,539,8.290,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,601,0.509,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,605,0.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123933,606,0.330,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123935,203,5.900,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,204,0.388,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,205,17,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,207,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,208,93.200,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,255,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,269,0.615,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,291,4.150,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,301,35.200,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,303,1.370,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,306,405,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,307,157,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,320,NULL,'100',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,328,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,401,NULL,'100',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,539,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,601,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,605,0,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123935,606,0.100,'100',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (123936,203,5.030,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,204,0.545,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,205,15.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,208,87.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,269,0.741,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,291,3.770,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,301,33.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,303,1.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,306,340,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,307,391,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,539,0.134,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123936,606,0.091,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,203,5.880,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,204,0.338,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,205,17.200,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,208,95.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,269,0.579,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,291,4.260,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,301,32.500,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,303,1.390,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,306,382,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,307,75,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123939,606,0.065,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,203,5.660,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,204,0.206,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,205,17,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,208,91.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,269,2.160,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,291,3.820,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,301,65,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,303,1.680,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,306,343,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,307,85.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,539,1.630,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123940,606,0.039,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,203,5.070,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,204,0.264,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,205,14.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,208,78.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,269,0.524,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,291,4.680,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,301,53.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,303,1.270,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,306,322,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,307,359,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123941,606,0.083,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,203,4.480,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,204,0.752,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,205,16.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,208,90.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,269,1.070,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,291,6.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,301,70.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,303,1.980,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,306,362,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,307,358,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,539,0.170,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,601,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123944,606,0.094,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,203,5.530,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,204,1.060,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,205,24.900,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,208,127,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,269,11.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,291,3.420,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,301,35.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,303,1.250,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,306,269.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,307,419,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,328,0.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,539,10.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,601,1.120,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,605,0.001,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123945,606,0.293,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,203,5.780,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,204,1.070,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,205,23.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,208,121,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,269,9.230,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,291,3.590,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,301,40.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,303,1.460,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,306,289.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,307,434,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,328,0.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,539,8.310,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,601,1.120,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123946,606,0.295,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,203,4.570,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,204,0.356,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,205,24.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,207,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,208,117,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,269,12,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,291,3.210,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,301,34.600,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,303,1.230,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,306,269,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,307,457,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,401,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,539,10.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,601,0.001,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123947,606,0.042,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (123949,203,14.200,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,204,5.910,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,205,9.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,208,151,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,269,6.720,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,291,0.800,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,301,31,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,303,1.110,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,306,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,307,640,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,328,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,401,11.700,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,539,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,601,36,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,605,0.020,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123949,606,2.010,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123961,203,8.420,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,204,12,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,205,72.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,208,427,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,269,6.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,291,4.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,301,94,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,303,2.730,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,306,502,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,307,723,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,539,0.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,601,4,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,605,0.060,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123961,606,1.610,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,203,7.220,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,204,18.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,205,70,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,208,458,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,269,5.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,291,5.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,301,54,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,303,3.590,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,306,353,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,307,544,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,539,3,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,601,2,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,605,0.040,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123962,606,1.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,203,4.640,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,204,14.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,205,75.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,208,451,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,269,33.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,291,5.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,301,3,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,303,1.340,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,306,121,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,307,585,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,539,33,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,605,0.030,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123963,606,1.760,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,203,10.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,204,15.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,205,68,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,208,440,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,269,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,291,13.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,301,9,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,303,2.330,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,306,263,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,307,740,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,605,0.020,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123964,606,1.540,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,203,6.680,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,204,22.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,205,66.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,208,481,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,269,2.680,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,291,6,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,301,42,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,303,2.020,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,306,301,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,307,719,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,539,0.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,601,2,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,605,0.290,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123966,606,3.050,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,203,10.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,204,12.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,205,25.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,207,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,208,245,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,269,0.940,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,291,0.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,301,7,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,303,2.830,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,306,120,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,307,302,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,601,28,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123967,606,4.720,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,203,10.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,204,13.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,205,24.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,207,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,208,264,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,269,0.940,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,291,0.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,301,5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,303,1.890,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,306,125,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,307,302,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,601,28,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123968,606,5.660,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,203,10.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,204,13.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,205,24.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,207,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,208,264,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,269,0.940,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,291,0.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,301,6,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,303,1.890,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,306,126,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,307,302,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,601,28,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123969,606,5.660,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,203,8.490,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,204,13.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,205,24.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,207,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,208,255,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,269,0.940,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,291,0.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,301,18,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,303,1.890,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,306,101,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,307,481,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,601,80,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123970,606,4.720,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,203,8.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,204,0.220,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,205,21.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,208,89.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,255,76.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,269,1.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,291,6.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,301,53.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,303,3.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,306,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,307,120.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,401,1.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123971,606,0.030,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,203,7.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,204,0.310,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,205,20.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,208,110.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,255,77.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,269,0.520,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,291,3.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,301,30.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,303,1.260,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,306,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,307,101.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,401,1.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123972,606,0.060,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,203,7.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,204,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,205,15.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,208,87.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,255,74.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,269,0.540,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,291,2.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,301,24.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,303,1.460,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,306,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,307,107.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,401,1.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123973,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,203,5.320,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,204,0.290,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,205,21.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,208,87.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,255,76.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,269,1.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,291,4.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,301,45.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,303,1.720,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,306,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,307,101.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123974,606,0.070,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,203,5.320,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,204,0.310,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,205,20.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,208,86.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,255,77.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,269,0.520,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,291,5.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,301,30.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,303,2.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,306,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,307,130.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,401,1.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123975,606,0.060,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,203,5.420,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,204,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,205,15.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,208,100.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,255,74.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,269,0.540,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,291,2.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,301,24.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,303,0.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,306,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,307,105.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,401,1.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123976,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,203,4.430,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,204,1.500,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,205,17.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,208,100.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,255,80.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,269,3.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,291,3.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,301,22.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,303,1.330,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,306,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,307,120.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,401,1.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123977,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,203,5.320,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,204,0.290,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,205,16.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,208,110.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,255,76.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,269,1.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,291,3.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,301,59.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,303,2.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,306,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,307,101.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123978,606,0.070,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,203,7.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,204,0.590,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,205,24.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,208,121.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,255,67.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,269,9.270,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,291,3.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,301,51.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,303,2.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,306,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,307,345.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123979,606,0.110,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,203,4.430,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,204,1.500,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,205,13.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,208,100.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,255,80.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,269,2.460,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,291,3.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,301,29.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,303,2.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,306,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,307,91.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,401,1.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123980,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,203,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,204,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,205,46.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,208,214,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,269,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,291,3.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,301,21,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,303,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,306,321,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,307,268,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123985,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (123990,203,21.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,204,53.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,205,21.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,208,625,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,269,12.500,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,291,6.200,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,301,69,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,303,4.380,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,306,650,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,307,375,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,328,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,401,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,539,9.400,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,601,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123990,606,9.380,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123991,203,7.410,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,204,18.5,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,205,66.700,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,208,481,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,269,33.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,291,7.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,301,56,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,303,3.700,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,306,263,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,307,426,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,539,33.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,601,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123991,606,3.700,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (123992,203,7.410,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,204,18.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,205,70.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,208,481,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,269,33.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,291,7.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,301,33,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,303,7.410,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,306,363,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,307,481,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,401,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,539,29.600,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123992,606,3.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,203,3.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,204,18.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,205,70.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,208,481,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,269,33.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,291,3.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,301,59,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,303,3.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,306,189,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,307,389,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,401,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,539,33.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123993,606,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (123994,203,5.460,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,204,11.300,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,205,65.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,208,368.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,269,31.300,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,291,5.700,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,301,31.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,303,2.260,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,306,161.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,307,366.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,539,30.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,601,33,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,605,0.100,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123994,606,3.060,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,203,4.800,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,204,11.300,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,205,65.200,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,208,364,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,269,30.800,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,291,5.700,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,301,17,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,303,1.560,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,306,147,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,307,326,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,539,30.200,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,601,26,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,605,0.120,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123995,606,3.790,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123996,203,5.330,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,204,11.600,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,205,63.5,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,207,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,208,361.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,255,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,269,31.400,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,291,5.700,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,301,26.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,303,2.850,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,306,347.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,307,366.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,328,0.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,401,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,539,31.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,601,29,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,605,0.100,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123996,606,3.970,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (123997,203,5.770,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,204,11.5,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,205,65.400,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,208,385,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,269,32.700,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,291,3.800,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,301,38,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,303,2.690,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,306,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,307,385,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,328,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,401,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,539,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,601,29,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123997,606,2.880,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (123998,203,5.340,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,204,12.700,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,205,62.200,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,208,375,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,269,29.600,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,291,3.500,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,301,24,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,303,2.850,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,306,217,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,307,296,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,539,29.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,601,19,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,605,0.110,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (123998,606,3.990,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124006,203,11.400,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,204,8.570,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,205,2.860,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,207,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,208,143,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,255,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,269,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,291,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,301,54,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,303,2.860,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,306,134,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,307,143,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,328,3,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,401,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,539,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,601,357,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,605,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124006,606,2.860,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,203,6.25,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,204,10.900,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,205,43.800,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,207,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,208,297,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,255,NULL,'100g',NULL,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,269,4.690,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,291,1.600,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,301,97.000,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,303,3.120,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,306,130,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,307,906.000,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,320,0.000,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,328,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,401,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,539,3.100,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,601,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,605,0,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124007,606,4.690,'100g',6,3,'2023-05-27','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124008,203,9.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,204,3.490,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,205,46.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,208,256,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,269,6.980,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,291,4.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,301,40,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,303,2.330,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,306,186,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,307,465,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,401,8.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,539,4.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124008,606,1.160,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,203,7.040,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,204,7.040,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,205,46.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,208,268,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,269,11.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,291,2.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,301,239,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,303,2.820,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,306,158,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,307,380,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,539,7,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124009,606,2.820,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,203,5.630,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,204,8.450,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,205,46.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,208,282,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,269,12.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,291,2.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,301,241,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,303,2.820,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,306,158,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,307,394,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,401,1.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,539,8.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124010,606,3.520,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,203,7.810,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,204,10.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,205,37.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,208,281,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,269,4.690,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,291,1.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,301,105,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,303,1.560,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,306,102,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,307,906,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,539,3.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,601,16,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124011,606,6.25,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124012,203,2.310,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,204,3.470,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,205,33.5,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,208,168,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,269,12.100,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,291,2.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,301,7,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,303,5.780,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,306,103,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,307,101,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,328,1,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,539,5.800,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,601,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124012,606,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124013,203,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,204,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,205,10.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,208,39,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,269,9.380,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,291,0.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,301,4,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,303,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,306,74,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,307,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124013,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,203,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,204,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,205,10.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,208,39,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,269,9.380,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,291,0.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,301,4,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,303,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,306,74,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,307,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124014,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,203,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,204,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,205,10.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,208,39,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,269,9.380,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,291,0.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,301,4,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,303,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,306,74,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,307,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124015,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,203,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,204,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,205,10.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,208,39,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,269,9.380,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,291,0.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,301,4,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,303,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,306,74,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,307,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124016,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,203,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,204,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,205,10.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,208,39,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,269,9.380,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,291,0.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,301,4,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,303,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,306,74,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,307,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124017,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124018,203,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,204,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,205,12.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,208,53,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,269,10.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,291,1.800,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,301,47,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,303,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,306,102,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,307,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,401,68.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,539,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124018,606,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124019,203,0.860,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,204,0.230,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,205,3.700,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,207,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,208,19,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,255,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,269,2.570,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,291,0.910,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,301,9.900,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,303,0.310,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,306,190,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,307,148,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,328,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,401,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,539,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,601,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,605,0,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124019,606,0.020,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124020,203,7.060,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,204,2.350,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,205,21.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,208,129,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,269,3.530,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,291,5.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,301,40,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,303,2.350,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,306,218,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,307,118,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124020,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,203,7.060,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,204,2.350,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,205,21.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,208,129,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,269,4.710,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,291,5.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,301,39,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,303,2.350,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,306,238,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,307,118,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,320,21.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,401,14.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124021,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124022,203,7.140,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,204,14.300,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,205,75,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,208,429,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,269,28.600,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,291,3.600,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,301,14,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,303,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,306,164,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,307,286,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,539,28.600,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,601,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124022,606,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124023,203,2.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,204,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,205,83.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,208,351,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,269,70.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,291,2.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,301,54,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,303,1.080,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,306,459,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,307,81,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,539,21.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124023,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124024,203,20,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,204,48.600,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,205,22.900,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,208,571,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,269,2.860,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,291,11.400,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,301,89,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,303,2.860,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,306,466,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,307,386,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,328,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,601,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124024,606,7.140,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,203,17.600,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,204,50.000,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,205,23.5,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,208,559,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,269,2.940,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,291,11.800,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,301,106,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,303,2.940,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,306,462,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,307,529,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,328,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,601,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124025,606,7.350,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124026,203,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,204,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,205,83.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,208,324,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,269,64.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,291,5.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,301,38,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,303,10.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,306,530,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,307,68,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,539,21.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124026,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124027,203,4,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,204,8.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,205,41,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,208,260,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,269,14,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,291,3,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,301,18,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,303,1,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,306,97,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,307,75,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,539,12,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,601,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124027,606,2.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,203,5.880,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,204,13.700,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,205,64.700,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,208,392,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,269,31.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,291,3.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,301,24,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,303,3.920,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,306,275,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,307,78,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,539,27.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,601,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124028,606,3.920,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,203,7.140,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,204,14.300,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,205,75,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,208,429,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,269,28.600,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,301,14,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,306,175,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,307,179,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,539,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,601,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124029,606,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124030,203,5.370,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,204,12.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,205,69.800,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,208,403,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,269,34.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,291,2.700,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,301,27,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,303,2.950,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,306,188,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,307,309,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,328,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,401,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,539,34.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,601,27,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124030,606,4.030,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124032,203,7.070,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,204,17.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,205,70.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,208,459,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,269,3.530,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,291,7.100,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,301,106,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,303,1.060,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,306,212,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,307,636,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,401,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,539,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124032,606,1.770,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124033,203,7.140,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,204,21.400,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,205,67.900,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,207,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,208,500,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,255,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,269,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,291,7.100,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,301,107,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,303,1.070,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,306,143,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,307,375,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,328,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,401,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,539,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,601,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,605,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124033,606,1.790,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124037,203,8.330,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,204,5.210,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,205,77.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,208,375,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,269,29.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,291,6.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,301,42,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,303,2.710,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,306,271,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,307,604,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,539,29.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,605,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124037,606,1.040,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124038,203,14,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,204,8.000,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,205,68,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,207,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,208,380,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,255,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,269,20,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,291,10,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,301,60,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,303,2.800,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,306,280,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,307,360,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,328,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,401,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,539,20,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,601,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,605,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124038,606,1,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,203,9.300,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,204,4.650,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,205,76.700,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,207,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,208,372,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,255,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,269,25.600,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,291,9.300,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,301,47,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,303,2.790,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,306,349,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,307,372,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,328,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,401,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,539,18.600,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,601,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,605,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124039,606,1.160,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124040,203,13.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,204,4.900,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,205,72.600,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,208,353,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,269,23.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,291,9.800,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,301,39,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,303,2.550,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,306,294,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,307,333,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,401,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,539,19.600,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124040,606,0.980,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124041,203,6.150,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,204,0.170,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,205,16.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,208,69.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,255,58.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,269,0.460,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,291,5.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,301,31.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,303,1.680,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,306,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,307,70.000,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,401,0.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124041,606,0.020,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124042,203,0.620,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,204,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,205,15.400,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,207,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,208,62,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,255,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,269,14.800,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,291,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,301,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,303,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,306,62,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,307,6,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,320,NULL,'100ml',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,328,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,401,25.900,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,539,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,601,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,605,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124042,606,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124043,203,7.940,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,204,11.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,205,63.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,208,397,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,269,7.940,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,291,7.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,301,75,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,303,3.970,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,306,222,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,307,675,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,539,4,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124043,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,203,7.940,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,204,11.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,205,63.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,208,397,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,269,3.970,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,291,7.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,301,75,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,303,3.970,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,306,222,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,307,635,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124044,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,203,7.940,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,204,17.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,205,63.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,208,437,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,269,3.970,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,291,7.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,301,32,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,303,3.970,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,306,190,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,307,635,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,539,4,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124045,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,203,5.950,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,204,13.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,205,68.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,208,417,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,269,26.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,291,3,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,301,33,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,303,2.980,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,306,185,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,307,223,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,539,23.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,601,15,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124046,606,2.980,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,203,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,204,14.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,205,75,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,208,429,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,269,28.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,291,7.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,301,21,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,303,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,306,139,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,307,268,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,401,186,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,539,25,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124047,606,1.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,203,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,204,12.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,205,75,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,208,429,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,269,28.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,291,7.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,301,21,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,303,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,306,293,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,307,304,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,401,175,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,539,28.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124048,606,1.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,203,5.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,204,13.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,205,73.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,208,425,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,269,27,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,291,5.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,301,17,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,303,1.930,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,306,156,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,307,222,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,539,25.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124049,606,1.930,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,203,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,204,12.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,205,75,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,208,429,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,269,28.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,291,7.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,301,18,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,303,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,306,182,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,307,214,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,539,28.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124050,606,1.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,203,5.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,204,13.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,205,73.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,208,425,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,269,27,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,291,5.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,301,17,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,303,1.930,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,306,156,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,307,222,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,539,25.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124051,606,1.930,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,203,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,204,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,205,78.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,208,429,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,269,21.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,291,7.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,301,68,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,303,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,306,314,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,307,268,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,401,204,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,539,21.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124052,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,203,5.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,204,12.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,205,68.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,208,408,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,269,30.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,291,5.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,301,31,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,303,2.550,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,306,214,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,307,230,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,539,23,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124053,606,3.830,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,203,5.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,204,11.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,205,71.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,208,408,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,269,30.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,291,5.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,301,20,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,303,2.550,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,306,161,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,307,230,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,401,25.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,539,25.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124054,606,2.550,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,203,5.950,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,204,13.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,205,68.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,208,417,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,269,28.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,291,4.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,301,33,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,303,2.980,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,306,182,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,307,208,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,539,23.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,601,7,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124055,606,2.980,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,203,5.950,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,204,13.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,205,68.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,208,417,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,269,28.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,291,4.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,301,30,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,303,2.980,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,306,162,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,307,223,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,539,23.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,601,7,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124056,606,2.230,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,203,5.950,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,204,13.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,205,68.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,208,417,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,269,28.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,291,4.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,301,33,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,303,2.980,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,306,182,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,307,208,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,539,23.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,601,7,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124057,606,2.980,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,203,11.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,204,13.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,205,67.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,208,437,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,269,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,291,7.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,301,56,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,303,3.970,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,306,238,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,307,714,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124058,606,3.970,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,203,11.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,204,13.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,205,67.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,208,437,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,269,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,291,7.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,301,56,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,303,3.970,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,306,238,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,307,714,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124059,606,3.970,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,203,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,204,12.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,205,64.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,208,393,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,269,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,291,7.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,301,32,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,303,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,306,221,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,307,500,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124060,606,1.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124061,203,7.720,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,204,13.5,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,205,65.600,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,208,405,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,269,1.930,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,291,7.700,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,301,35,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,303,3.860,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,306,228,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,307,483,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,328,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,401,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,539,1.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,601,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124061,606,1.930,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124062,203,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,204,12.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,205,64.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,208,393,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,269,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,291,7.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,301,32,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,303,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,306,221,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,307,500,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124062,606,1.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,203,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,204,12.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,205,64.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,208,393,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,269,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,291,7.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,301,32,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,303,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,306,221,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,307,500,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124063,606,1.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,203,7.720,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,204,13.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,205,65.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,208,405,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,269,1.930,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,291,7.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,301,35,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,303,3.860,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,306,228,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,307,483,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,539,1.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124064,606,1.930,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,203,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,204,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,205,78.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,208,393,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,269,21.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,291,7.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,301,32,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,303,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,306,207,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,307,286,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,401,204,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,539,17.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124065,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,203,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,204,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,205,78.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,208,393,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,269,21.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,291,7.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,301,32,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,303,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,306,207,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,307,286,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,401,204,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,539,17.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124066,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,203,11.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,204,7.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,205,24.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,208,208,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,269,1.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,291,1.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,301,130,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,303,1.170,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,306,91,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,307,260,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,539,1.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,601,26,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124067,606,3.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,203,8.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,204,6.160,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,205,32.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,208,212,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,269,1.370,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,291,2.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,301,103,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,303,1.850,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,306,96,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,307,384,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,539,1.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,601,14,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124068,606,2.740,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,203,12.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,204,2.880,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,205,25.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,208,173,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,269,1.920,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,291,3.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,301,38,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,303,1.730,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,306,135,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,307,308,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,539,1.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124069,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,203,9.890,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,204,11,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,205,33,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,208,253,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,269,5.490,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,291,2.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,301,88,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,303,1.980,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,306,77,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,307,341,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,539,3.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,601,110,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124070,606,3.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124073,203,7.140,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,204,14.300,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,205,57.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,208,393,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,269,14.300,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,291,7.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,301,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,303,2.5,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,306,321,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,307,161,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,328,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,401,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,539,10.700,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,601,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124073,606,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124074,203,5.950,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,204,16.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,205,55.100,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,208,387,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,269,28.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,291,0.000,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,301,10,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,303,1.490,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,306,45,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,307,156,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,539,25.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,601,22,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124074,606,4.460,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,203,5.950,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,204,17.900,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,205,55.100,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,208,387,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,269,28.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,291,0.000,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,301,16,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,303,1.490,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,306,43,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,307,149,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,539,26.800,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,601,22,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124075,606,5.950,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124076,203,8.930,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,204,10.700,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,205,48.200,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,207,NULL,'100g',NULL,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,208,304,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,255,NULL,'100g',NULL,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,269,5.360,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,291,5.400,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,301,21,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,303,3.570,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,306,195,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,307,339,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,320,NULL,'100g',NULL,3,'2024-12-12','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,328,0,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,401,0,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,539,3.600,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,601,0,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,605,0,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124076,606,2.680,'100g',6,3,'2023-05-27','2023-09-14');
INSERT INTO `cndb_nutval` VALUES (124077,203,9.380,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,204,2.340,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,205,31.200,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,208,188,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,269,1.560,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,291,3.100,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,301,55,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,303,3.120,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,306,173,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,307,219,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,539,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,601,31,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124077,606,0.780,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,203,4,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,204,12,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,205,37,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,208,260,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,269,19,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,291,2,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,301,11,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,303,1,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,306,29,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,307,100,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,539,18,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,601,15,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124078,606,4,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124081,203,21.300,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,204,5.640,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,205,15,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,207,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,208,188,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,255,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,269,12.5,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,291,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,301,13,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,303,0.880,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,306,188,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,307,514,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,328,1,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,401,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,539,12.5,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,601,75,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,605,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124081,606,1.25,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124082,203,3.350,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,204,7.810,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,205,26.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,208,201,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,269,2.230,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,291,4.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,301,45,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,303,1.210,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,307,246,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,401,1.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124082,606,1.120,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124083,203,6.25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,204,10.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,205,65.600,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,208,375,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,269,21.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,291,3.100,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,301,34,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,303,1.560,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,306,123,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,307,250,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,539,18.800,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,601,16,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124083,606,4.690,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124084,203,6.25,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,204,9.380,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,205,67.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,208,375,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,269,26.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,291,3.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,301,28,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,303,1.560,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,306,161,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,307,172,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,320,28.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,401,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,539,20.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,601,16,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124084,606,3.910,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124085,203,6.25,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,204,9.380,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,205,67.200,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,208,375,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,269,26.600,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,291,3.100,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,301,28,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,303,1.560,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,306,159,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,307,133,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,328,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,539,20.300,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,601,16,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124085,606,3.910,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124086,203,13.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,204,12.300,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,205,29.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,208,281,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,269,0.880,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,291,3.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,301,206,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,303,0.880,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,306,257,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,307,482,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,539,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,601,22,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,605,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124086,606,3.950,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124087,203,5.310,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,204,10.300,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,205,52,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,207,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,208,332,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,255,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,269,28.800,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,291,3.5,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,301,56,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,303,1.620,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,306,154,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,307,227,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,328,0,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,401,0,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,539,27.900,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,601,57,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,605,0.100,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124087,606,3.360,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,203,5.790,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,204,10.600,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,205,53.200,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,207,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,208,329,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,255,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,269,29.300,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,291,3.5,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,301,55,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,303,1.550,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,306,215,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,307,228,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,328,0,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,401,3.700,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,539,27.300,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,601,67,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,605,0.090,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124088,606,3.260,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,203,6.130,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,204,10.200,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,205,58.600,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,207,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,208,335,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,255,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,269,30.800,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,291,3.5,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,301,72,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,303,2.610,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,306,241,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,307,229,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,328,0,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,401,0,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,539,30.5,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,601,61,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,605,0.090,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124089,606,3.440,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124090,203,5.790,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,204,10.200,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,205,54.300,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,208,322,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,269,28.200,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,291,3.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,301,57,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,303,1.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,306,197,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,307,222,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,401,0.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,539,26.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,601,63,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,605,0.090,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124090,606,3.280,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124091,203,6.600,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,204,11.700,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,205,54.500,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,207,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,208,335.000,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,255,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,269,22.800,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,291,1.800,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,301,35.300,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,303,2.010,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,306,229.000,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,307,335.000,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,328,0.350,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,401,NULL,'100g',NULL,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,539,21.500,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,601,70.900,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,605,0.150,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124091,606,3.350,'100g',6,3,'2023-05-27','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124092,203,6.25,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,204,11.600,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,205,54.5,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,208,339,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,269,22.300,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,291,2.700,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,301,45,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,303,1.790,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,306,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,307,339,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,328,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,401,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,539,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,601,71,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124092,606,3.570,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,203,5.370,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,204,12.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,205,69.800,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,208,403,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,269,34.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,291,2.700,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,301,27,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,303,2.950,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,306,188,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,307,309,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,328,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,401,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,539,34.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,601,27,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124093,606,4.030,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124094,203,5.520,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,204,12.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,205,50.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,207,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,208,329.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,269,24.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,291,3.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,301,61.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,303,1.960,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,306,250.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,307,201.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,320,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,401,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,539,22.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,601,67.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,605,0.160,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124094,606,3.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124095,203,6.040,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,204,13.5,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,205,58,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,207,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,208,362,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,255,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,269,27,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,291,4.400,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,301,70,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,303,2.25,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,306,188,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,307,233,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,328,0,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,401,0,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,539,24.5,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,601,76,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,605,0.180,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124095,606,3.600,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124096,203,2,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,204,1.000,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,205,13,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,207,NULL,'100g',NULL,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,208,70,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,255,NULL,'100g',NULL,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,269,6,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,291,2,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,301,0,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,303,0.400,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,306,140,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,307,10,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,320,NULL,'100g',NULL,3,'2024-12-12','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,328,0,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,401,2,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,539,0,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,601,0,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,605,0,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124096,606,0,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124097,203,7.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,204,20,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,205,67.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,208,473,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,269,0.910,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,291,5.470,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,301,91.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,303,1.830,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,306,82.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,307,394,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,605,0.240,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124097,606,2.580,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,203,7.370,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,204,20.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,205,68.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,208,478,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,269,0.920,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,291,5.530,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,301,92.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,303,1.840,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,306,82.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,307,5.530,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,605,0.25,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124098,606,2.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124099,203,8.420,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,204,12,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,205,72.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,208,427,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,269,6.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,291,4.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,301,94,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,303,2.730,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,306,502,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,307,723,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,539,0.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,601,4,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,605,0.060,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124099,606,1.610,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,203,7.220,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,204,18.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,205,70,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,208,458,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,269,5.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,291,5.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,301,54,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,303,3.590,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,306,353,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,307,544,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,539,3,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,601,2,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,605,0.040,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124100,606,1.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,203,4.640,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,204,14.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,205,75.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,208,451,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,269,33.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,291,5.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,301,3,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,303,1.340,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,306,121,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,307,585,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,539,33,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,605,0.030,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124101,606,1.760,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,203,10.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,204,15.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,205,68,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,208,440,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,269,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,291,13.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,301,9,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,303,2.330,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,306,263,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,307,740,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,605,0.020,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124102,606,1.540,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124103,203,10.700,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,204,10.700,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,205,3.570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,208,161,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,269,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,291,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,301,64,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,303,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,306,146,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,307,464,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,328,4,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,601,339,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124103,606,3.570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,203,10.700,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,204,10.700,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,205,3.570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,208,161,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,269,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,291,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,301,64,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,303,1.290,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,306,146,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,307,464,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,328,4,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,601,339,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124104,606,3.570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,203,10.700,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,204,10.700,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,205,3.570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,208,161,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,269,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,291,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,301,64,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,303,1.290,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,306,146,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,307,464,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,328,4,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,601,339,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124105,606,3.570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,203,10.5,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,204,15.800,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,205,5.260,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,208,211,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,269,1.75,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,291,1.800,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,301,105,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,303,1.75,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,306,123,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,307,333,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,328,2,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,601,228,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124106,606,4.390,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,203,8.570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,204,10.000,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,205,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,208,143,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,269,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,291,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,301,60,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,303,1.030,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,306,129,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,307,357,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,328,3,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,601,286,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124107,606,2.860,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,203,10.700,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,204,10.700,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,205,3.570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,208,161,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,269,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,291,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,301,64,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,303,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,306,146,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,307,464,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,328,4,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,601,339,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124108,606,3.570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,203,14.600,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,204,15.400,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,205,2.730,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,208,209.000,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,269,0.910,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,291,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,301,118.000,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,303,1.450,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,306,127.000,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,307,500,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,328,2.000,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,539,0.000,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,601,305.000,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124109,606,5.450,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,203,8.570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,204,10.000,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,205,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,208,143,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,269,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,291,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,301,60,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,303,1.030,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,306,129,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,307,357,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,328,3,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,601,286,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124111,606,2.860,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,203,10.700,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,204,10.700,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,205,3.570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,208,161,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,269,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,291,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,301,64,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,303,1.290,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,306,146,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,307,464,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,328,4,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,601,339,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124112,606,3.570,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124113,203,5.490,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,204,11,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,205,74.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,208,385,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,269,33,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,291,5.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,301,27,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,303,3.850,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,306,192,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,307,302,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,539,33,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124113,606,4.120,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124114,203,2.630,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,204,0,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,205,79,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,207,NULL,'100g',NULL,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,208,316,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,255,NULL,'100g',NULL,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,269,63,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,291,5.300,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,301,53,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,303,1.840,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,306,737,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,307,26,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,320,NULL,'100g',NULL,3,'2024-12-12','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,328,0,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,401,NULL,'100g',NULL,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,539,0,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,601,0,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,605,0,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124114,606,0,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124115,203,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,204,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,205,12.400,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,207,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,208,49,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,255,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,269,9.260,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,291,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,301,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,303,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,306,136,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,307,9,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,320,NULL,'100ml',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,328,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,401,37,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,539,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,601,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,605,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124115,606,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,203,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,204,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,205,11.100,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,207,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,208,43,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,255,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,269,11.100,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,291,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,301,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,303,0.25,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,306,123,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,307,6,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,320,NULL,'100ml',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,328,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,401,37,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,539,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,601,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,605,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124116,606,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124117,203,0,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,204,0.000,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,205,11.200,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,207,NULL,'100ml',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,208,44,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,255,NULL,'100ml',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,269,11.200,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,291,0,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,301,10,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,303,0.270,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,306,125,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,307,5,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,320,NULL,'100ml',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,328,0,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,401,20.300,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,539,0,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,601,0,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,605,0,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124117,606,0,'100ml',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124118,203,0.340,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,204,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,205,12.200,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,207,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,208,51,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,255,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,269,9.490,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,291,0.300,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,301,14,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,303,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,306,136,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,307,8,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,320,NULL,'100ml',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,328,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,401,20.300,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,539,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,601,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,605,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124118,606,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124119,203,0.340,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,204,0.000,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,205,15.600,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,207,NULL,'100ml',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,208,61,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,255,NULL,'100ml',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,269,14.900,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,291,0,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,301,10,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,303,0,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,306,68,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,307,5,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,320,NULL,'100ml',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,328,0,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,401,20.300,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,539,0,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,601,0,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,605,0,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124119,606,0,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124120,203,0.290,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,204,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,205,12.100,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,207,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,208,50,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,255,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,269,9.410,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,291,0.300,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,301,12,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,303,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,306,135,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,307,9,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,320,NULL,'100ml',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,328,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,401,17.600,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,539,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,601,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,605,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124120,606,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,203,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,204,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,205,11.200,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,207,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,208,44,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,255,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,269,11.200,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,291,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,301,12,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,303,0.260,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,306,126,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,307,4,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,320,NULL,'100ml',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,328,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,401,17.600,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,539,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,601,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,605,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124121,606,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124122,203,7.020,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,204,2.630,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,205,42.100,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,208,228,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,269,1.75,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,291,5.300,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,301,175,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,303,2.280,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,306,35,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,307,219,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,328,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,539,1.800,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,601,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124122,606,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124123,203,7.140,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,204,5.360,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,205,46.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,208,268,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,269,1.790,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,291,5.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,301,143,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,303,2.570,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,306,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,307,241,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,328,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,539,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,601,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124123,606,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124126,203,14.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,204,4.460,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,205,69.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,208,375,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,269,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,291,3.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,301,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,303,17.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,307,18,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,601,118,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124126,606,0.890,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,203,14.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,204,4.460,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,205,69.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,208,375,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,269,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,291,3.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,301,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,303,17.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,307,18,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,601,118,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124127,606,0.890,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,203,12.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,204,1.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,205,73.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,208,357,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,269,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,291,1.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,301,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,303,17.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,307,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124128,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,203,14.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,204,4.460,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,205,69.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,208,375,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,269,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,291,3.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,301,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,303,17.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,307,18,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,601,118,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124129,606,0.890,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,203,14.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,204,4.460,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,205,69.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,208,375,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,269,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,291,3.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,301,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,303,17.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,307,18,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,601,118,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124130,606,0.890,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,203,14.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,204,4.460,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,205,69.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,208,375,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,269,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,291,3.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,301,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,303,17.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,307,18,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,601,118,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124131,606,0.890,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,203,14.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,204,4.460,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,205,69.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,208,375,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,269,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,291,3.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,301,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,303,17.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,307,18,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,601,118,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124132,606,0.890,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,203,14.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,204,4.460,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,205,69.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,208,375,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,269,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,291,3.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,301,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,303,17.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,307,18,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,601,118,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124133,606,0.890,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,203,14.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,204,4.460,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,205,69.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,208,375,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,269,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,291,3.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,301,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,303,17.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,307,18,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,601,118,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124134,606,0.890,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,203,10.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,204,1.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,205,64.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,208,321,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,269,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,291,1.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,301,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,303,17.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,307,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124135,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124136,203,3.980,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,204,9.290,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,205,39.800,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,207,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,208,266,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,255,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,269,7.970,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,291,2.700,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,301,66.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,303,1.330,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,306,159.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,307,266,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,328,0.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,401,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,539,5.300,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,601,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,605,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124136,606,1.330,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124137,203,12.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,204,6.25,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,205,67.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,208,375,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,269,2.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,291,10,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,301,45,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,303,3.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,306,318,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,307,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124137,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,203,21.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,204,53.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,205,21.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,208,625,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,269,12.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,291,6.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,301,69,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,303,4.380,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,306,650,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,307,375,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,539,9.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124138,606,9.380,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,203,0.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,204,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,205,16,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,208,64,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,269,12.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,291,1.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,301,3,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,303,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,306,128,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,307,12,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,539,6.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124139,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,203,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,204,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,205,12.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,208,52.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,269,9.750,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,291,1.500,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,301,10.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,303,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,306,80.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,307,4,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,328,37.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,539,5.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124140,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,203,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,204,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,205,14.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,208,62,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,269,12.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,291,1.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,301,15,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,303,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,306,141,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,307,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,539,7.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124141,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,203,0.710,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,204,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,205,13.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,208,57,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,269,10,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,291,1.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,301,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,303,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,306,193,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,307,4,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,539,6.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124142,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124143,203,13.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,204,4.110,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,205,24.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,208,197,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,269,1.650,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,291,1.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,301,165,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,303,1.180,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,307,296,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,401,5.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,601,25,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124143,606,1.650,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,203,16,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,204,6.870,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,205,18.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,208,198,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,269,3.050,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,291,3.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,301,267,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,303,1.370,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,307,427,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,401,4.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,601,15,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124144,606,3.820,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,203,13.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,204,5.340,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,205,19.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,208,176,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,269,3.820,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,291,3.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,301,153,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,303,2.060,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,307,527,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,401,6.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,601,23,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124145,606,2.670,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,203,17.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,204,11.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,205,17.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,208,245,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,269,2.040,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,291,1,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,301,204,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,303,0.730,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,307,745,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,601,41,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124146,606,5.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124147,203,14.900,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,204,14.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,205,33.900,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,207,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,208,314.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,255,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,269,10.800,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,291,0.800,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,301,203.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,303,1.650,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,306,341.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,307,711.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,328,0.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,401,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,539,9.900,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,601,29.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,605,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124147,606,5.790,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,203,15.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,204,14.200,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,205,30.800,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,207,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,208,300.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,255,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,269,8.690,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,291,3.200,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,301,186.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,303,0.790,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,306,199.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,307,601.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,328,0.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,401,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,539,7.900,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,601,40.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,605,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124148,606,6.320,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124149,203,7.690,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,204,2.75,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,205,18.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,208,132,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,269,3.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,291,1.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,301,137,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,303,0.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,307,319,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,401,8.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,601,8,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124149,606,1.650,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,203,8.840,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,204,11.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,205,23.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,208,245,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,269,4.760,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,291,2.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,301,408,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,303,1.220,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,307,510,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,401,4.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,601,20,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124150,606,6.120,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124151,203,13.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,204,11.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,205,26.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,207,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,208,253.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,255,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,269,3.250,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,291,2.600,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,301,252.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,303,1.950,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,306,188.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,307,734.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,328,4.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,401,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,539,1.300,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,601,29.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,605,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124151,606,4.550,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124152,203,14.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,204,9.520,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,205,23,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,208,230,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,269,3.170,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,291,1.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,301,198,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,303,1.590,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,306,130,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,307,722,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,401,4.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,539,2.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,601,36,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124152,606,3.970,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,203,15.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,204,8.730,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,205,26.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,208,254,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,269,4.760,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,291,2.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,301,159,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,303,2.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,307,571,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,601,32,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124153,606,2.780,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,203,10.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,204,2.450,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,205,24.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,208,166,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,269,3.910,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,291,2,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,301,137,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,303,1.080,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,306,176,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,307,176,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,601,5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124154,606,1.470,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,203,11.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,204,3.850,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,205,6.920,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,208,177,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,269,2.310,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,291,0.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,301,108,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,303,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,306,8,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,307,185,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,539,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,601,19,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124155,606,2.310,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,203,13.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,204,7.310,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,205,20.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,208,203,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,269,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,291,1.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,301,162,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,303,1.170,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,307,357,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,401,4.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,601,45,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124156,606,3.650,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,203,9.970,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,204,2.490,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,205,23.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,208,158,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,269,3.320,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,291,1.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,301,166,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,303,0.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,307,307,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,401,15,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,601,8,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124157,606,1.25,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124158,203,16.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,204,7.220,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,205,22.500,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,207,NULL,'100g',NULL,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,208,217.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,255,NULL,'100g',NULL,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,269,3.210,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,291,1.600,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,301,194.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,303,1.610,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,306,248.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,307,634.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,320,29.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,328,0.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,401,0,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,539,2.400,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,601,28.000,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,605,0,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124158,606,3.210,'100g',6,3,'2023-05-27','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124159,203,15.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,204,8.070,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,205,24.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,208,227,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,269,3.670,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,291,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,301,224,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,303,1.470,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,306,179,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,307,667,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,539,3.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,601,29,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124159,606,2.930,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,203,16.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,204,10.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,205,26.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,208,268,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,269,1.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,291,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,301,254,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,303,1.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,306,121,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,307,393,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,539,1.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,601,18,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124160,606,5.360,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,203,12.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,204,9.220,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,205,31.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,208,265,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,269,2.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,291,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,301,230,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,303,2.070,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,307,380,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,601,17,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124161,606,4.610,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124162,203,14.800,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,204,6.990,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,205,21.700,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,208,194,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,269,4.660,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,291,1.600,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,301,194,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,303,1.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,306,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,307,365,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,328,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,539,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,601,27,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124162,606,2.720,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124163,203,15.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,204,9.320,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,205,23.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,208,241,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,269,3.880,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,291,2.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,301,155,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,303,2.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,307,629,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,601,31,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124163,606,4.660,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,203,15.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,204,11.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,205,26.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,208,269,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,269,4.25,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,291,2.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,301,169,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,303,1.420,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,306,316,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,307,624,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,539,1.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,601,28,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124164,606,4.960,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,203,17,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,204,8.930,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,205,24.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,208,244,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,269,5.680,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,291,1.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,301,203,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,303,2.190,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,307,722,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,601,28,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124165,606,3.25,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,203,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,204,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,205,42.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,208,286,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,269,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,291,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,301,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,303,3.860,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,307,357,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124166,606,1.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124167,203,15.100,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,204,7.940,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,205,23.800,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,208,238,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,269,3.170,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,291,2.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,301,119,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,303,1.430,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,306,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,307,540,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,328,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,401,4.800,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,539,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,601,32,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124167,606,3.170,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124168,203,5.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,204,14,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,205,39.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,208,293,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,269,11.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,291,3.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,301,102,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,303,1.840,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,307,293,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124168,606,6.380,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,203,7.140,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,204,8.930,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,205,44.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,208,286,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,269,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,291,5.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,301,29,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,303,1.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,306,193,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,307,375,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,401,10.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,539,1.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124169,606,1.790,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,203,10.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,204,3.210,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,205,31,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,208,192,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,269,1.070,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,291,3.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,301,107,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,303,1.920,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,306,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,307,321,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,401,51.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,539,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,601,16,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124170,606,1.070,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124171,203,13.5,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,204,10.100,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,205,27.900,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,208,253,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,269,1.690,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,291,2.5,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,301,338,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,303,12.200,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,306,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,307,371,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,328,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,539,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,601,30,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124171,606,5.070,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124172,203,10,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,204,8.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,205,24.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,208,221,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,269,4.290,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,291,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,301,242,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,303,1.430,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,306,68,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,307,457,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,539,1.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,601,25,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124172,606,4.290,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,203,10.700,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,204,3.570,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,205,55.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,208,268,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,269,5.360,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,291,5.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,301,27,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,303,3.390,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,306,184,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,307,518,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,539,3.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,601,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124173,606,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,203,16.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,204,16.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,205,32.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,208,347,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,269,9.370,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,291,2.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,301,207,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,303,7.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,306,208,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,307,881,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,539,6.600,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,601,52,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124174,606,4.690,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124175,203,4,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,204,11,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,205,37,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,208,260,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,269,19,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,291,2,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,301,7,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,303,1,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,306,30,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,307,105,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,539,17,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,601,15,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124175,606,3,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124176,203,5.950,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,204,17.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,205,55.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,208,387,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,269,28.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,291,3,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,301,16,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,303,1.490,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,306,43,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,307,149,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,539,26.800,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,601,22,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124176,606,5.950,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124177,203,16.900,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,204,7.680,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,205,26.900,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,208,238,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,269,5.380,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,291,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,301,270,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,303,2.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,306,303,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,307,553,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,539,4.600,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,601,23,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124177,606,2.690,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,203,15.800,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,204,8.270,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,205,26.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,208,241,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,269,5.260,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,291,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,301,262,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,303,2.260,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,306,332,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,307,624,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,539,4.5,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,601,30,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124178,606,3.010,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,203,15.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,204,13.600,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,205,25.5,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,208,281,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,269,3.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,291,2.600,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,301,365,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,303,0.850,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,306,225,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,307,527,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,539,1.700,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,601,30,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124179,606,7.650,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,203,15.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,204,9.530,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,205,24.900,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,208,242,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,269,4.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,291,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,301,230,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,303,2.200,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,306,151,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,307,711,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,539,3.700,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,601,33,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124180,606,3.670,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,203,16.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,204,10.100,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,205,24.100,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,208,248,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,269,3.880,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,291,2.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,301,210,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,303,1.550,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,306,253,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,307,497,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,539,2.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,601,27,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124181,606,4.660,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124182,203,13.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,204,10.300,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,205,21.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,208,236,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,269,2.210,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,291,2.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,301,170,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,303,1.470,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,306,83,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,307,633,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,401,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,539,1.5,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,601,33,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,605,0,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124182,606,5.150,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124183,203,9.440,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,204,2.360,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,205,31.5,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,208,189,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,269,1.570,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,291,3.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,301,55,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,303,3.150,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,306,175,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,307,220,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,328,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,401,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,539,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,601,31,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124183,606,0.790,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124184,203,7.410,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,204,18.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,205,66.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,208,481,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,269,33.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,291,7.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,301,56,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,303,3.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,306,263,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,307,426,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,401,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,539,33.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124184,606,3.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,203,7.410,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,204,18.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,205,70.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,208,481,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,269,33.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,291,7.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,301,33,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,303,7.410,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,306,363,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,307,481,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,401,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,539,29.600,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124185,606,3.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124186,203,6.270,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,204,27.100,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,205,61.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,208,506,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,269,2.640,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,291,5.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,301,41,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,303,1.880,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,306,284,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,307,718,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,539,0.200,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,601,2,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,605,0.370,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124186,606,3.700,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124187,203,7.340,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,204,20,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,205,67.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,208,475,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,269,0.920,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,291,5.510,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,301,92,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,303,1.840,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,306,82.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,307,397,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,605,0.240,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124187,606,2.580,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124188,203,7.140,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,204,21.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,205,67.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,208,500,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,269,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,291,7.100,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,301,107,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,303,1.790,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,306,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,307,393,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,601,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124188,606,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124189,203,7.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,204,19.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,205,67.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,208,473,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,269,0.910,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,291,5.480,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,301,91.500,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,303,1.830,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,306,82.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,307,395,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,605,0.240,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124189,606,2.570,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,203,7.370,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,204,20.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,205,68.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,208,478,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,269,0.920,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,291,5.530,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,301,92.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,303,1.840,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,306,82.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,307,5.530,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,605,0.25,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124190,606,2.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,203,7.130,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,204,21.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,205,65.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,208,482,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,269,0.890,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,291,5.340,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,301,89.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,303,1.780,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,306,127,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,307,395,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,605,0.270,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124191,606,2.810,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,203,7.370,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,204,20.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,205,68.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,208,478,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,269,0.920,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,291,5.530,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,301,92.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,303,1.840,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,306,82.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,307,5.530,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,605,0.25,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124192,606,2.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124193,203,6.680,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,204,22.100,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,205,66.400,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,207,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,208,481,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,255,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,269,2.680,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,291,5.900,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,301,42,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,303,2.020,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,306,301,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,307,719,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,320,NULL,'100g',NULL,3,'2024-12-12','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,328,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,401,NULL,'100g',NULL,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,539,0.200,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,601,2,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,605,0.290,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124193,606,3.050,'100g',6,3,'2023-05-27','2023-04-27');
INSERT INTO `cndb_nutval` VALUES (124194,203,8.060,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,204,21.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,205,58.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,208,435,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,269,43.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,291,8.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,301,44,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,303,1.610,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,306,223,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,307,89,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,539,40.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124194,606,3.230,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124195,203,19,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,204,11.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,205,61.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,208,429,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,269,9.520,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,291,23.800,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,301,90,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,303,4.760,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,306,690,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,307,524,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,539,4.800,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,601,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124195,606,1.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124196,203,7.410,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,204,18.5,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,205,66.700,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,208,481,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,269,33.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,291,7.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,301,56,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,303,3.700,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,306,263,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,307,426,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,539,33.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,601,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124196,606,3.700,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,203,7.410,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,204,18.5,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,205,70.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,208,481,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,269,33.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,291,7.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,301,33,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,303,7.410,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,306,363,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,307,481,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,539,29.600,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,601,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124197,606,3.700,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124198,203,3.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,204,18.500,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,205,70.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,208,481,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,269,33.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,291,3.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,301,59,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,303,3.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,306,189,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,307,389,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,401,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,539,33.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124198,606,1.850,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124199,203,21.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,204,3.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,205,8.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,208,141,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,269,1.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,291,3.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,301,83,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,303,2,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,306,258,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,307,573,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,539,1.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,605,0.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124199,606,0.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124200,203,23.000,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,204,9.600,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,205,8.600,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,207,NULL,'100g',NULL,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,208,197.000,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,255,NULL,'100g',NULL,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,269,0.800,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,291,4.100,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,301,56.000,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,303,2.400,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,306,240.000,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,307,447.000,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,320,NULL,'100g',NULL,3,'2024-12-12','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,328,0,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,401,NULL,'100g',NULL,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,539,0.400,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,601,0,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,605,0.000,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124200,606,1.400,'100g',6,3,'2023-05-27','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (124201,203,16.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,204,6.500,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,205,19.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,208,183,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,269,2.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,291,6.300,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,301,83,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,303,1.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,306,358,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,307,396,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,539,1.300,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,601,5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,605,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124201,606,1,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,203,7.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,204,13.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,205,76.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,208,450,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,269,20.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,291,4.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,301,42,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,303,3.300,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,306,167,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,307,329,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,539,20.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,605,0.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124202,606,4.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,203,5.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,204,14.000,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,205,75.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,208,436,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,269,29.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,291,4.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,301,21,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,303,2.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,306,143,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,307,358,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,539,29.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,605,0.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124203,606,4.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,203,5.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,204,14.000,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,205,75.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,208,436,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,269,29.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,291,4.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,301,21,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,303,2.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,306,143,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,307,358,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,539,29.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,605,0.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124204,606,4.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,203,7.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,204,13.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,205,76.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,208,450,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,269,23.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,291,4.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,301,26,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,303,3.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,306,201,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,307,295,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,539,23,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,605,0.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124205,606,4.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,203,6.300,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,204,10.500,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,205,77.300,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,208,412,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,269,21.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,291,4.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,301,49,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,303,3.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,306,205,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,307,420,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,539,21.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,605,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124206,606,1.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,203,6.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,204,12.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,205,75.300,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,208,420,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,269,18.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,291,4.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,301,54,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,303,3.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,306,215,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,307,455,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,539,18.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,605,0.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124207,606,1.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,203,6,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,204,13.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,205,74.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,208,431,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,269,24.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,291,4.300,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,301,34,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,303,3.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,306,183,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,307,338,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,539,24.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,605,0.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124208,606,4.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,203,6,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,204,13.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,205,75.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,208,428,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,269,25.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,291,4.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,301,34,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,303,3.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,306,187,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,307,344,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,539,25.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,605,0.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124209,606,4.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124210,203,7.410,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,204,18.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,205,66.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,208,481,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,269,33.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,291,7.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,301,56,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,303,3.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,306,263,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,307,426,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,401,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,539,33.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124210,606,3.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,203,7.410,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,204,18.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,205,70.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,208,481,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,269,33.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,291,7.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,301,33,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,303,7.410,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,306,363,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,307,481,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,401,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,539,29.600,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124211,606,3.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124212,203,3.700,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,204,18.5,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,205,70.400,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,207,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,208,481,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,255,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,269,33.300,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,291,3.700,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,301,59,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,303,3.700,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,306,189,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,307,389,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,328,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,401,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,539,33.300,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,601,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,605,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124212,606,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124213,203,5.380,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,204,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,205,16.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,208,85,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,269,0.770,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,291,3.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,301,31,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,303,1.310,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,306,354,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,307,92,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124213,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,203,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,204,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,205,10.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,208,39,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,269,9.380,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,291,0.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,301,4,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,303,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,306,74,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,307,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,328,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,401,71.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124214,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124216,203,5.950,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,204,13.400,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,205,68.400,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,208,417,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,255,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,269,28.300,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,291,4.5,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,301,30,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,303,2.980,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,306,185,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,307,253,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,401,3,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,539,23.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,601,7,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124216,606,2.230,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124217,203,11.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,204,5.540,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,205,29.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,207,2.120,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,208,212,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,269,1.25,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,291,5.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,301,109,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,303,2.670,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,306,399,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,307,335,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,320,205.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,401,1.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,539,0.500,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,601,9,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124217,606,2.180,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,203,11.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,204,4.210,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,205,31.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,207,2,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,208,208,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,269,1.790,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,291,5.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,301,113,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,303,2.650,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,306,476,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,307,222,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,320,193.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,401,1.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,539,0.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,601,4,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124218,606,1.470,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,203,11.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,204,5.720,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,205,21.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,207,1.560,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,208,184,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,269,1.130,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,291,3.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,301,82,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,303,1.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,306,262,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,307,282,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,320,286.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,401,2.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,601,25,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124220,606,2.020,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124221,203,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,204,21.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,205,7.140,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,208,286,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,269,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,301,739,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,306,725,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,307,1000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,401,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,601,54,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124221,606,12.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124222,203,10.600,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,204,6.080,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,205,29.5,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,207,1.730,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,208,215,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,255,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,269,0.950,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,291,5.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,301,113,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,303,2.350,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,306,285,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,307,326,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,401,0.900,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,539,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,601,10,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124222,606,2.460,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124223,203,9.25,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,204,9.170,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,205,27.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,207,1.350,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,208,230,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,269,1.180,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,291,3.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,301,116,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,303,0.970,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,306,134,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,307,313.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,320,339.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,401,2.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,601,60.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124223,606,3.490,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124224,203,25,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,204,21.400,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,205,7.140,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,208,286,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,255,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,269,3.570,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,291,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,301,739,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,303,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,306,725,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,307,1000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,401,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,539,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,601,54,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124224,606,12.5,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124225,203,6.620,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,204,8.25,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,205,13.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,207,1.710,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,208,152,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,269,1.430,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,291,1.100,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,301,202,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,303,0.720,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,306,145,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,307,292,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,401,1.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,539,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,601,24,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124225,606,4.420,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124228,203,12.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,204,10.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,205,24.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,207,1.950,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,208,242,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,269,1.280,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,291,4,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,301,100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,303,2.620,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,306,289,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,307,412,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,320,172.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,401,0.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,601,26,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124228,606,4.270,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124231,203,16.900,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,204,16.900,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,205,32.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,208,347,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,255,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,269,9.370,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,291,2.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,301,207,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,303,7.5,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,306,208,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,307,881,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,401,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,539,6.600,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,601,52,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124231,606,4.690,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124233,203,15.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,204,6.620,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,205,24.600,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,208,220,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,269,0.830,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,291,3.5,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,301,88,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,303,2.290,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,306,275,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,307,355,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,401,0.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,539,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,601,34,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124233,606,2.100,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124234,203,11.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,204,8.480,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,205,22.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,207,1.150,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,208,212,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,269,0.390,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,291,3.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,301,166,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,303,1.940,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,306,271,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,307,363,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,320,216.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,328,3,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,401,0.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,601,24,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124234,606,4.050,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,203,10.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,204,9.550,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,205,21.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,207,1.210,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,208,213,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,269,0.630,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,291,2.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,301,195,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,303,1.540,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,306,96,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,307,393,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,320,340.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,401,1.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,601,49,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124235,606,4.070,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124236,203,5.950,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,204,13.400,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,205,68.400,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,208,417,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,255,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,269,26.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,291,3,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,301,33,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,303,2.980,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,306,185,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,307,223,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,401,3,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,539,23.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,601,15,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124236,606,2.980,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124237,203,12.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,204,9.260,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,205,28.700,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,207,1.780,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,208,248.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,269,1.150,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,291,4,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,301,128.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,303,2.460,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,306,236.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,307,328,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,320,249.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,328,1,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,401,0.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,539,0.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,601,57.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124237,606,3.540,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124238,203,12.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,204,9.130,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,205,26.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,207,1.880,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,208,235.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,269,1.170,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,291,3.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,301,127,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,303,2.220,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,306,241.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,307,367.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,320,253.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,401,1.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,601,60,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124238,606,3.580,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,203,14,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,204,10.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,205,25.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,207,1.730,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,208,251,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,269,0.840,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,291,3.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,301,209,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,303,2.040,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,306,241,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,307,314,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,320,261.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,401,1.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,601,31,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124239,606,4.760,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,203,12.500,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,204,9.990,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,205,25.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,207,1.890,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,208,241.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,269,1.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,291,3.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,301,139,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,303,2.270,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,306,219.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,307,369,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,320,287.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,401,0.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,601,68.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124241,606,4.010,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124243,203,5.380,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,204,0.290,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,205,16.900,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,208,92.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,255,58.5,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,269,0.770,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,291,3.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,301,27.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,303,1.540,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,306,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,307,77.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,401,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,539,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,601,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124243,606,0.080,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124244,203,14,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,204,7.030,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,205,24.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,207,1.590,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,208,218,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,269,0.820,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,291,3.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,301,89,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,303,2.350,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,306,277,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,307,313,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,320,233.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,401,0.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,601,29,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124244,606,2.260,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,203,10.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,204,6.110,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,205,28.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,207,1.940,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,208,211,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,269,0.920,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,291,5.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,301,116,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,303,2.280,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,306,316,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,307,336,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,320,223.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,401,0.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,539,0.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,601,11,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124245,606,2.540,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124247,203,25,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,204,21.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,205,7.140,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,208,296,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,269,3.570,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,291,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,301,696,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,303,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,306,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,307,600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,320,221.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,601,57.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124247,606,10.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124248,203,5.950,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,204,13.400,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,205,68.400,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,208,417,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,255,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,269,26.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,291,3,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,301,30,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,303,2.980,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,306,164,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,307,223,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,401,3,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,539,23.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,601,15,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124248,606,1.490,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124249,203,10,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,204,7.070,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,205,22.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,207,0.880,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,208,194,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,269,0.350,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,291,3.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,301,164,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,303,1.570,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,306,255,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,307,356,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,320,96.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,328,3,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,401,2.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,601,18,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124249,606,3.110,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,203,11.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,204,5.960,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,205,30.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,207,2.070,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,208,219,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,269,1.190,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,291,5.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,301,115,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,303,2.630,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,306,390,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,307,319,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,320,213.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,401,1.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,601,10,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124250,606,2.380,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,203,12.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,204,13.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,205,16.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,207,1.760,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,208,237,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,269,0.410,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,291,2.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,301,316,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,303,0.420,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,306,77,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,307,311,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,320,414.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,401,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,601,47,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124251,606,7.440,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,203,13.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,204,9.950,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,205,24.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,207,2.210,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,208,237,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,269,1.390,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,291,4.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,301,122,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,303,2.880,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,306,316,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,307,408,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,320,332.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,401,0.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,601,26,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124252,606,3.770,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124253,203,1.190,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,204,0.500,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,205,10.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,208,45.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,255,89.200,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,269,8.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,291,1.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,301,16.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,303,1.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,306,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,307,140.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,401,0.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,539,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,601,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124253,606,0.080,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124254,203,10.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,204,9.590,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,205,27.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,207,1.420,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,208,238.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,269,0.940,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,291,3.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,301,122,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,303,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,306,140.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,307,362.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,320,393.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,401,3,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,601,34.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124254,606,3.720,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,203,0.600,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,204,0.000,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,205,4.220,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,207,NULL,'100ml',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,208,18,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,255,NULL,'100ml',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,269,2.410,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,291,0.600,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,301,17,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,303,0.420,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,306,190,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,307,283,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,320,23.000,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,328,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,401,30.100,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,539,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,601,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,605,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124257,606,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,203,10.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,204,6.860,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,205,27.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,207,1.870,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,208,212,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,269,1.230,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,291,4.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,301,51,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,303,1.020,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,306,331,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,307,281,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,320,175.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,401,0.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,601,12,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124259,606,2.780,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,203,11.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,204,8.150,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,205,16.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,207,2.530,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,208,184,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,269,0.990,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,291,4.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,301,207,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,303,1.75,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,306,418,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,307,486,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,320,384.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,401,1.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,539,0.500,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,601,23,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124260,606,4.520,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124261,203,5.950,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,204,13.400,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,205,68.400,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,208,417,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,255,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,269,26.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,291,3,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,301,30,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,303,2.980,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,306,182,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,307,268,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,401,3,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,539,23.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,601,15,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124261,606,1.490,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124262,203,10.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,204,6.980,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,205,26.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,207,0.670,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,208,207,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,269,0.850,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,291,5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,301,134,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,303,2.210,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,306,405,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,307,432,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,320,223.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,401,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,539,0.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,601,13,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124262,606,3.460,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124263,203,1.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,204,0.470,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,205,10.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,208,45.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,255,89.5,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,269,8.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,291,1.100,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,301,16.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,303,1.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,306,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,307,85.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,401,5.700,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,539,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,601,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124263,606,0.080,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124264,203,12.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,204,9.260,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,205,28.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,207,1.780,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,208,248.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,269,1.150,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,291,4,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,301,127,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,303,2.460,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,306,236.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,307,328,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,320,249.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,401,0.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,601,57.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124264,606,3.540,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,203,4.760,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,204,0.580,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,205,15.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,207,1.740,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,208,83,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,269,1.830,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,291,4.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,301,27,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,303,1.370,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,306,247,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,307,389,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,320,216.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,401,7.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,539,0.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,601,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124266,606,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,203,11.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,204,8.080,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,205,30.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,207,1.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,208,239,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,269,1.260,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,291,5.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,301,117,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,303,2.570,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,306,379,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,307,294,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,320,155.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,401,2.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,539,0.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,601,9,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124267,606,2.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,203,10.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,204,5.25,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,205,38.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,207,1.830,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,208,241,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,269,1.110,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,291,3.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,301,101,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,303,2.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,306,283,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,307,350,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,320,208.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,328,0.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,401,1.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,601,10,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124269,606,2.130,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124270,203,7.940,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,204,13.900,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,205,71.400,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,208,437,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,255,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,269,23.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,291,7.900,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,301,16,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,303,3.970,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,306,187,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,307,238,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,401,385,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,539,23.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,601,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124270,606,1.980,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124271,203,13.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,204,9.950,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,205,24.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,207,2.210,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,208,237,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,269,1.390,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,291,4.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,301,122,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,303,2.880,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,306,316,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,307,408,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,320,332.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,401,0.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,601,26,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124271,606,3.770,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,203,11.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,204,5.680,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,205,27.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,207,1.870,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,208,207,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,269,1.270,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,291,5.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,301,51,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,303,2.840,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,306,403,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,307,403.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,320,245.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,401,0.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,539,0.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,601,11,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124273,606,1.690,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,203,10.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,204,5.280,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,205,37.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,207,1.860,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,208,239,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,269,1.110,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,291,3.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,301,103,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,303,2.870,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,306,287,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,307,353,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,320,211.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,328,0.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,401,1.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,601,10,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124275,606,2.160,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,203,10.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,204,5.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,205,35,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,207,1.970,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,208,230,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,269,1.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,291,3.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,301,111,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,303,2.740,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,306,308,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,307,369,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,320,227.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,328,0.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,401,1.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,601,11,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124276,606,2.310,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124277,203,0.830,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,204,0.000,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,205,3.75,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,207,NULL,'100ml',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,208,19,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,255,NULL,'100ml',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,269,2.920,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,291,0.800,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,301,12,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,303,0.290,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,306,196,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,307,267,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,320,NULL,'100ml',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,328,0,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,401,30,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,539,0,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,601,0,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,605,0,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124277,606,0,'100ml',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,203,4.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,204,6.000,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,205,76.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,208,363,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,269,31.300,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,291,5.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,301,271,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,303,3.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,306,147,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,307,254,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,539,31,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,605,0.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124278,606,2,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124279,203,12.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,204,13.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,205,16.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,207,1.760,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,208,237,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,269,0.410,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,291,2.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,301,336,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,303,0.620,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,306,77,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,307,311,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,320,414.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,401,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,601,47,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124279,606,7.440,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,203,10.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,204,6.480,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,205,33.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,207,1.820,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,208,232,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,269,1.130,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,291,5.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,301,104,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,303,2.760,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,306,315,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,307,346,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,320,208.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,401,1.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,601,10,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124280,606,2.310,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124282,203,11.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,204,4.75,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,205,17,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,208,156,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,269,0.440,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,291,3,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,301,78,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,303,0.940,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,306,192,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,307,291,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,328,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,401,0.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,539,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,601,32,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124282,606,1.700,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124283,203,1.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,204,0.130,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,205,8.070,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,208,20.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,255,89.600,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,269,4.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,291,1.100,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,301,12.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,303,0.880,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,306,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,307,68.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,401,5.900,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,539,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,601,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124283,606,0.030,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124286,203,12.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,204,10.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,205,23.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,207,1.780,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,208,236,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,269,1.030,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,291,4,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,301,102,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,303,2.170,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,306,283,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,307,311,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,320,411.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,401,0.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,539,0.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,601,27,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124286,606,4.040,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,203,7.880,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,204,6.75,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,205,24,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,207,0.860,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,208,186,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,269,0.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,291,3.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,301,146,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,303,1.680,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,306,260,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,307,319,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,320,247.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,401,16.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,539,0.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,601,10,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124287,606,2.950,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124289,203,0.610,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,204,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,205,3.680,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,207,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,208,18,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,255,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,269,3.070,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,291,0.600,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,301,12,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,303,0.180,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,306,196,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,307,270,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,320,NULL,'100ml',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,328,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,401,30.700,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,539,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,601,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,605,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124289,606,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124290,203,8.340,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,204,5.040,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,205,24.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,207,0.830,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,208,174,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,269,1.550,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,291,4.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,301,88,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,303,1.870,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,306,434,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,307,257,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,320,177.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,401,13.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,539,0.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,601,6,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124290,606,1.910,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124291,203,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,204,14.300,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,205,7.140,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,208,250,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,269,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,301,732,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,306,750,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,307,679,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,601,54,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124291,606,8.930,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124292,203,11.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,204,8.480,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,205,22.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,207,1.150,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,208,212,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,269,0.390,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,291,3.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,301,166,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,303,1.940,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,306,271,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,307,363,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,320,216.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,328,3,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,401,0.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,601,24,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124292,606,4.050,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,203,11.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,204,9.990,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,205,18.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,207,1.630,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,208,210.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,269,1.220,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,291,1.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,301,126,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,303,1.330,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,306,298.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,307,393.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,320,540.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,401,0.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,601,28,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124293,606,4.710,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,203,9.320,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,204,9.110,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,205,28.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,207,1.020,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,208,231,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,269,1.240,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,291,3.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,301,118,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,303,0.910,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,306,133,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,307,303,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,320,350.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,401,8.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,601,66,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124294,606,3.480,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124295,203,10,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,204,4.380,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,205,32.200,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,207,1.960,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,208,207,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,255,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,269,1.620,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,291,6.200,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,301,52,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,303,2.680,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,306,452,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,307,342,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,401,16.900,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,539,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,601,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124295,606,0.820,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124296,203,10.700,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,204,6.510,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,205,22.400,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,208,190,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,269,0.350,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,291,3.300,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,301,159,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,303,1.430,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,306,238,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,307,366,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,328,3,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,401,2.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,539,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,601,21,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124296,606,2.880,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124297,203,14.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,204,16.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,205,15.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,207,1.780,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,208,263.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,269,0.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,291,2.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,301,344.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,303,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,306,118,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,307,307,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,320,384.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,328,11,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,401,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,601,44,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124297,606,9.740,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,203,10.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,204,7.180,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,205,27.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,207,1.850,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,208,216,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,269,1.140,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,291,4.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,301,92,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,303,2.430,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,306,330,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,307,335,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,320,188.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,401,1.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,601,14,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124298,606,2.620,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,203,12.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,204,7.270,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,205,20.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,207,1.160,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,208,197,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,269,1.050,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,291,3.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,301,118,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,303,2.030,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,306,279,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,307,322,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,320,210.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,401,2.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,601,23,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124299,606,2.990,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,203,10.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,204,5.150,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,205,23.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,207,0.780,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,208,181,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,269,1.350,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,291,4.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,301,135,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,303,2.780,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,306,403,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,307,365,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,320,189.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,401,0.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,539,0.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,601,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124300,606,1.620,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,203,7.880,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,204,6.75,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,205,24,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,207,0.860,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,208,186,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,269,0.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,291,3.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,301,146,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,303,1.680,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,306,260,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,307,319,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,320,6.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,401,16.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,601,10,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124301,606,2.950,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,203,11.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,204,5.960,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,205,30,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,207,2.080,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,208,218,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,269,1.190,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,291,5.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,301,116,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,303,2.610,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,306,391,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,307,322,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,320,215.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,401,1.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,539,0.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,601,10,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124302,606,2.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,203,13.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,204,17.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,205,16.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,207,1.850,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,208,279,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,269,0.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,291,2.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,301,372,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,303,0.490,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,306,115,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,307,333,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,320,621.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,401,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,601,50,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124303,606,9.630,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124305,203,4.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,204,5.500,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,205,75.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,208,354,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,269,30.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,291,5.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,301,271,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,303,3.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,306,119,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,307,238,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,539,29.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,605,0.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124305,606,1.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124306,203,12.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,204,10.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,205,26,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,207,1.580,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,208,249,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,269,1.370,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,291,3.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,301,152,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,303,2.330,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,306,238,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,307,226,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,320,621.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,401,0.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,539,0.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,601,47,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124306,606,4.470,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124307,203,11.300,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,204,5.960,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,205,30,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,207,2.080,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,208,218,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,255,NULL,'100g',NULL,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,269,1.190,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,291,5.5,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,301,116,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,303,2.610,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,306,391,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,307,322,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,320,215.000,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,328,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,401,1.100,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,539,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,601,10,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,605,0,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124307,606,2.400,'100g',6,3,'2023-05-27','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124308,203,13.200,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,204,10.300,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,205,21.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,208,236,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,269,2.210,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,291,2.200,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,301,170,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,303,1.470,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,306,83,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,307,633,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,401,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,539,1.5,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,601,33,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124308,606,5.150,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124309,203,11,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,204,6.090,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,205,28.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,207,1.700,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,208,214,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,255,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,269,0.900,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,291,5.300,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,301,44,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,303,2.320,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,306,370,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,307,268,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,401,0.900,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,539,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,601,13,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124309,606,1.840,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124310,203,5.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,204,6.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,205,45.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,208,248,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,269,11.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,291,5.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,301,347,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,303,4.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,306,187,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,307,280,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,539,10.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,605,0.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124310,606,1.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124312,203,11.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,204,5.75,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,205,28.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,207,1.870,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,208,211,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,269,1.130,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,291,5.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,301,51,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,303,2.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,306,415,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,307,286,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,320,9.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,401,0.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,539,0.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,601,11,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124312,606,1.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124313,203,1.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,204,0.130,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,205,5.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,208,33.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,255,89.600,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,269,6.230,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,291,1.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,301,7.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,303,0.880,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,306,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,307,40.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,401,0.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,539,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,601,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124313,606,0.030,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124314,203,25,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,204,21.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,205,7.140,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,208,286,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,269,3.570,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,291,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,301,739,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,303,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,306,725,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,307,1000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,401,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,539,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,601,54,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124314,606,12.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124316,203,9.320,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,204,9.110,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,205,28.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,207,1.020,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,208,231,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,269,1.240,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,291,3.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,301,118,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,303,0.910,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,306,133,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,307,303,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,320,350.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,401,8.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,539,0.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,601,66,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124316,606,3.480,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,203,12.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,204,10.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,205,24.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,207,0.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,208,242,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,269,1.280,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,291,4,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,301,100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,303,2.620,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,306,289,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,307,412,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,320,172.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,401,0.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,601,26,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124318,606,4.270,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,203,11.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,204,5.540,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,205,29.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,207,2.120,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,208,212,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,269,1.25,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,291,5.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,301,109,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,303,2.670,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,306,399,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,307,335,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,320,207.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,401,1.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,601,9,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124319,606,2.180,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,203,12.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,204,10.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,205,25.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,207,1.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,208,249,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,269,1.080,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,291,3.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,301,134,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,303,1.740,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,306,238,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,307,387,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,320,275.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,401,0.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,601,66,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124321,606,4.240,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124322,203,0.880,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,204,0.000,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,205,4.120,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,207,NULL,'100ml',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,208,21,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,255,NULL,'100ml',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,269,2.650,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,291,0.900,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,301,18,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,303,0.590,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,306,193,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,307,288,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,320,NULL,'100ml',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,328,0,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,401,30.600,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,539,0,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,601,0,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,605,0,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124322,606,0,'100ml',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124323,203,5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,204,6.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,205,75.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,208,364,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,269,30.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,291,5.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,301,271,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,303,3.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,306,160,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,307,254,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,539,30.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,605,0.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124323,606,2,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,203,4.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,204,5.500,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,205,75.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,208,354,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,269,30.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,291,5.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,301,271,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,303,3.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,306,119,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,307,238,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,539,29.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,605,0.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124324,606,1.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124326,203,13.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,204,11.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,205,25.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,207,0.560,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,208,258,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,269,0.860,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,291,3.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,301,238,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,303,1.450,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,306,166,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,307,323,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,320,315.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,401,1.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,601,32.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124326,606,5.540,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124327,203,2.210,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,204,0.500,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,205,12.700,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,208,160.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,255,84.300,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,269,5.900,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,291,7.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,301,69.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,303,3.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,306,0.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,307,68.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,401,0.600,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,539,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,601,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124327,606,0.020,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124328,203,0.830,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,204,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,205,3.75,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,207,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,208,19,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,255,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,269,2.920,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,291,0.400,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,301,12,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,303,0.210,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,306,196,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,307,267,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,320,NULL,'100ml',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,328,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,401,30,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,539,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,601,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,605,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124328,606,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124329,203,7.940,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,204,13.900,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,205,71.400,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,208,437,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,255,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,269,23.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,291,7.900,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,301,16,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,303,3.970,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,306,187,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,307,238,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,401,385,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,539,23.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,601,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124329,606,1.980,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124330,203,9.370,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,204,4.240,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,205,30,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,207,1.440,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,208,192,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,269,1.480,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,291,5.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,301,115,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,303,2.510,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,306,429,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,307,431,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,320,45.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,401,3.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,601,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124330,606,0.680,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124331,203,13.200,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,204,5.260,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,205,23.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,208,192,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,269,0.950,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,291,3,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,301,86,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,303,1.670,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,306,264,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,307,292,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,328,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,401,3.300,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,539,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,601,26,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124331,606,1.930,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124332,203,11.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,204,10.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,205,25.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,207,1.950,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,208,242,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,269,1.070,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,291,3.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,301,157,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,303,2.190,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,306,208,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,307,376,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,320,323.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,401,0.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,601,74,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124332,606,4.290,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124333,203,4.300,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,204,5.500,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,205,75.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,208,354,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,269,29.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,291,5.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,301,271,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,303,3.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,306,119,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,307,239,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,539,29.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,605,0.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124333,606,1.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124335,203,10.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,204,5.640,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,205,16.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,207,1.030,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,208,157,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,269,0.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,291,2.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,301,80,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,303,1.030,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,306,191,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,307,273,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,320,216.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,401,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,601,32,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124335,606,2.120,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124336,203,3.200,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,204,0.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,205,9.600,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,208,56,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,269,4.800,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,291,2.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,301,20,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,303,1.120,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,306,80,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,307,240,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,401,7.200,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,539,1.600,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,601,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124336,606,0.070,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124337,203,13.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,204,12.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,205,17.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,207,1.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,208,235,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,269,0.710,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,291,2.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,301,342,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,303,0.560,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,306,110,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,307,320,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,320,418.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,401,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,601,42,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124337,606,7.090,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,203,11.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,204,7.190,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,205,28.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,207,1.850,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,208,225,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,269,0.920,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,291,5.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,301,75,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,303,2.640,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,306,356,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,307,307,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,320,230.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,401,0.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,601,15,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124338,606,2.530,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,203,14,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,204,7.030,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,205,24.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,207,1.590,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,208,218,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,269,0.820,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,291,3.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,301,89,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,303,2.350,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,306,277,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,307,313,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,320,233.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,401,0.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,539,0.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,601,29,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124340,606,2.260,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,203,5.840,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,204,15.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,205,17.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,207,1.260,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,208,235,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,269,0.580,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,291,1.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,301,146,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,303,0.230,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,306,68,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,307,347,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,320,632.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,401,4.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,601,18,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124341,606,7.720,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124342,203,0.850,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,204,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,205,3.660,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,207,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,208,17,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,255,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,269,2.820,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,291,0.800,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,301,14,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,303,0.280,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,306,197,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,307,270,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,320,NULL,'100ml',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,328,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,401,31,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,539,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,601,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,605,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124342,606,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,203,8.160,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,204,12.800,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,205,15.300,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,207,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,208,205,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,269,0.590,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,291,1.400,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,301,6,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,303,0.440,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,306,27,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,307,204,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,328,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,401,4.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,539,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,601,18,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,605,1.200,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124343,606,2.630,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124344,203,10.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,204,6.110,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,205,28.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,207,1.940,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,208,211,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,269,0.920,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,291,5.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,301,116,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,303,2.280,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,306,316,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,307,336,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,320,223.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,401,0.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,601,11,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124344,606,2.540,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,203,12.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,204,10.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,205,25.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,207,1.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,208,249,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,269,1.080,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,291,3.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,301,134,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,303,1.740,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,306,238,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,307,387,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,320,275.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,401,0.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,601,66,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124347,606,4.240,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,203,9.970,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,204,5.150,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,205,17.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,207,0.960,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,208,156,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,269,0.490,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,291,3,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,301,78,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,303,1.010,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,306,196,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,307,253,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,320,198.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,401,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,539,0.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,601,28,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124349,606,1.850,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,203,2.380,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,204,0.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,205,13.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,207,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,208,67,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,269,4.760,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,291,1.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,301,12,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,303,0.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,306,107,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,307,238,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,320,40.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,401,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,539,2.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,601,2,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124355,606,0.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,203,0.830,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,204,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,205,3.730,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,207,NULL,'100ml',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,208,19,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,255,NULL,'100ml',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,269,2.900,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,291,0.400,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,301,12,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,303,0.410,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,306,353.000,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,307,58,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,320,79.000,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,328,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,401,29.900,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,539,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,601,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,605,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124356,606,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,203,12.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,204,9.260,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,205,28.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,207,1.780,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,208,248.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,269,1.150,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,291,4,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,301,127,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,303,2.460,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,306,236.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,307,328,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,320,249.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,401,0.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,601,57.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124357,606,3.540,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,203,10.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,204,8.440,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,205,17.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,207,1.270,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,208,189.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,269,0.020,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,291,1.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,301,106,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,303,0.730,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,306,216.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,307,381.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,320,131.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,401,2.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,601,34.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124358,606,4.010,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,203,0.830,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,204,0.000,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,205,3.730,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,207,NULL,'100ml',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,208,19,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,255,NULL,'100ml',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,269,2.900,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,291,0.800,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,301,12,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,303,0.25,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,306,344.000,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,307,58,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,320,75.000,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,328,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,401,29.900,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,539,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,601,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,605,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124365,606,0,'100ml',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,203,11.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,204,5.960,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,205,30,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,207,2.080,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,208,218,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,269,1.190,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,291,5.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,301,116,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,303,2.610,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,306,391,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,307,322,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,320,215.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,401,1.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,539,0.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,601,10,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124366,606,2.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,203,12.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,204,12.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,205,18.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,207,1.460,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,208,236,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,269,0.75,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,291,3.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,301,317,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,303,0.550,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,306,125,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,307,293,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,320,123.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,401,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,601,38,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124367,606,6.830,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124368,203,1.070,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,204,0.120,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,205,5.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,208,20.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,255,90,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,269,6.200,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,291,1,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,301,12.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,303,0.760,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,306,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,307,40.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,401,5.5,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,539,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,601,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124368,606,0.020,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,203,5.740,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,204,0.590,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,205,22.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,208,160.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,255,76.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,269,0.560,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,291,5.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,301,51.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,303,1.340,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,306,1.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,307,100.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,401,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,539,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,601,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124369,606,0.110,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124371,203,5.840,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,204,15.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,205,17.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,207,1.260,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,208,235,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,269,0.580,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,291,1.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,301,146,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,303,0.230,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,306,68,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,307,347,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,320,632.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,401,4.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,601,18,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124371,606,7.720,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,203,12.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,204,9.130,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,205,26.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,207,1.880,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,208,235.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,269,1.170,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,291,3.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,301,122,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,303,2.240,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,306,241.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,307,367.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,320,253.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,401,1.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,601,60,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124372,606,3.580,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124373,203,5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,204,6.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,205,75.900,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,208,364,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,269,30.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,291,5.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,301,271,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,303,3.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,306,160,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,307,254,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,539,30.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,605,0.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124373,606,2,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124374,203,0.880,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,204,0,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,205,3.820,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,207,NULL,'100ml',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,208,18,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,255,NULL,'100ml',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,269,2.940,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,291,0.900,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,301,15,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,303,0.320,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,306,200,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,307,271,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,320,NULL,'100ml',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,328,NULL,'100ml',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,401,29.400,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,539,0,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,601,0,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,605,0,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124374,606,0,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124377,203,11.100,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,204,6.180,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,205,29.400,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,207,1.060,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,208,219,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,255,NULL,'100g',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,269,0.920,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,291,5.700,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,301,45,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,303,2.710,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,306,371,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,307,279,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,328,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,401,0.900,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,539,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,601,13,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,605,0,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124377,606,1.860,'100g',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,203,0.610,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,204,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,205,3.680,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,207,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,208,18,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,255,NULL,'100ml',NULL,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,269,3.070,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,291,0.600,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,301,12,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,303,0.180,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,306,196,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,307,270,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,320,NULL,'100ml',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,328,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,401,30.700,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,539,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,601,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,605,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124378,606,0,'100ml',6,3,'2023-05-27','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124379,203,3.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,204,0.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,205,9.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,208,56,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,269,4.800,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,291,2.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,301,20,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,303,1.120,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,306,80,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,307,112,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,401,7.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,539,1.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,605,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124379,606,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124380,203,14.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,204,9.830,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,205,25.5,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,207,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,208,249,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,269,0.840,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,291,3.5,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,301,206,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,303,1.960,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,306,201,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,307,380,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,401,1.600,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,539,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,601,34,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124380,606,4.600,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124381,203,2.5,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,204,1.25,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,205,10.800,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,207,NULL,'100ml',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,208,67,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,255,NULL,'100ml',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,269,2.5,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,291,1.700,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,301,25,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,303,0.830,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,306,417,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,307,342,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,320,NULL,'100ml',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,328,NULL,'100ml',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,401,NULL,'100ml',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,539,1.700,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,601,0,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,605,0,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124381,606,0,'100ml',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,203,5.950,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,204,13.400,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,205,68.400,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,208,417,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,255,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,269,28.300,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,291,3,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,301,30,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,303,2.980,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,306,161,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,307,223,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,401,3,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,539,23.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,601,7,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124382,606,2.230,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124383,203,11.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,204,5.680,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,205,27.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,207,1.870,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,208,207.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,269,1.270,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,291,5.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,301,47,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,303,2.440,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,306,403,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,307,286.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,320,245.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,401,0.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,601,11,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124383,606,1.690,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124384,203,15.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,204,10.5,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,205,28.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,207,0.900,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,208,269,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,255,NULL,'100g',NULL,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,269,1.280,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,291,3,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,301,150,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,303,2.320,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,306,274,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,307,508,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,328,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,401,0.400,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,539,0.600,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,601,28,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,605,0,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124384,606,3.710,'100g',6,3,'2023-05-27','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124386,203,13.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,204,11.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,205,25.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,207,1.920,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,208,258,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,269,0.850,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,291,3.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,301,254,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,303,1.940,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,306,163,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,307,328,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,320,322.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,401,1.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,601,33,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124386,606,5.660,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124387,203,1.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,204,0.500,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,205,10.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,208,45.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,255,89.5,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,269,6.220,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,291,1.100,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,301,16.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,303,1.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,306,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,307,69.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,401,5.700,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,539,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,601,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124387,606,0.080,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124390,203,9.350,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,204,6.580,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,205,29.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,207,1.830,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,208,214,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,269,0.820,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,291,5.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,301,115,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,303,2.240,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,306,258,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,307,380,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,320,237.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,401,1.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,539,0.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,601,12,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124390,606,2.620,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124391,203,1.190,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,204,0.500,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,205,10.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,208,45.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,255,89.200,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,269,8.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,291,1.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,301,16.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,303,1.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,306,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,307,140.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,401,0.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,539,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,601,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124391,606,0.080,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124393,203,11,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,204,6.110,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,205,29,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,207,1.720,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,208,216,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,269,0.910,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,291,5.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,301,44,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,303,2.680,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,306,366,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,307,276,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,320,139.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,401,0.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,601,13,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124393,606,1.840,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,203,9.620,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,204,6.970,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,205,26.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,207,1.660,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,208,205,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,269,1.350,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,291,4.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,301,112,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,303,1.75,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,306,372,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,307,276,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,320,377.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,401,3.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,539,0.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,601,11,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124394,606,2.660,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,203,8.690,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,204,5.570,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,205,24.500,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,207,0.980,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,208,178.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,269,1.470,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,291,4.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,301,100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,303,1.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,306,297.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,307,247,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,320,290.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,401,3.5,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,601,9,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124397,606,1.920,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,203,11.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,204,12.500,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,205,20.500,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,207,1.830,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,208,238.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,269,1.090,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,291,1.800,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,301,287,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,303,0.530,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,306,208.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,307,492.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,320,316.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,401,1.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,601,25,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124398,606,6.550,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,203,12.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,204,13.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,205,22.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,207,1.930,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,208,260,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,269,0.430,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,291,3.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,301,150,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,303,2.090,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,306,183,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,307,322,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,320,205.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,401,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,601,36,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,605,0.480,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124399,606,5.790,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,203,12.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,204,9.310,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,205,28.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,207,1.660,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,208,248.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,269,1.150,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,291,3.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,301,128,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,303,2.440,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,306,235.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,307,332.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,320,250.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,401,0.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,601,58.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124400,606,3.580,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,203,11.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,204,5.960,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,205,30.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,207,2.070,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,208,219,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,269,1.190,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,291,5.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,301,115,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,303,2.630,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,306,390,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,307,319,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,320,213.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,401,1.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,601,10,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124403,606,2.380,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124405,203,1.070,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,204,0.120,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,205,7.870,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,208,32.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,255,90,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,269,6.200,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,291,1,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,301,12.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,303,0.760,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,306,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,307,40.000,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,401,5.5,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,539,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,601,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124405,606,0.020,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124406,203,11.500,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,204,7.790,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,205,27.500,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,207,2.090,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,208,227.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,269,1.930,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,291,3.700,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,301,135,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,303,2.220,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,306,278.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,307,441.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,320,259.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,328,1,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,401,1.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,539,0.200,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,601,47.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124406,606,2.660,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,203,8.300,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,204,7.160,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,205,14.600,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,207,1.080,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,208,156,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,269,0.670,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,291,3,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,301,31,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,303,1.25,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,306,216,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,307,260,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,320,60.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,328,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,401,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,539,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,601,22,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124408,606,2.560,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124409,203,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,204,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,205,10.900,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,207,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,208,39,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,255,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,269,9.380,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,291,0.800,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,301,4,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,303,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,306,74,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,307,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,328,NULL,'100g',NULL,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,401,21.100,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,539,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,601,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,605,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124409,606,0,'100g',6,3,'2023-05-27','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124411,203,10,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,204,7.070,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,205,22.900,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,207,0.880,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,208,194,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,255,NULL,'100g',NULL,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,269,0.350,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,291,3.400,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,301,164,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,303,1.570,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,306,255,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,307,356,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,320,96.000,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,328,3,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,401,2.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,539,0.100,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,601,18,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,605,0,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124411,606,3.110,'100g',6,3,'2023-05-27','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124448,203,12.5,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,204,11.200,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,205,2.5,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,207,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,208,150,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,255,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,269,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,291,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,301,57,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,303,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,306,140,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,307,238,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,328,2,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,401,NULL,'100g',NULL,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,539,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,601,438,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,605,0,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124448,606,3.75,'100g',6,3,'2023-05-27','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124449,203,10.800,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,204,5.390,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,205,33.700,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,208,229.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,269,6.740,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,291,2.700,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,301,69.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,303,2.700,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,306,77.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,307,391.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,328,1,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,539,6.700,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,601,142.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124449,606,1.350,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,203,9.850,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,204,8.620,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,205,34.500,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,208,259.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,269,9.850,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,291,2.500,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,301,64.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,303,2.460,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,306,71.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,307,369.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,328,1,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,539,9.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,601,129.000,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124450,606,3.080,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124452,203,9.410,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,204,8.240,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,205,32.900,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,207,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,208,247.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,255,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,269,9.410,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,291,2.400,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,301,61.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,303,2.350,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,306,68.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,307,353.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,328,1,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,401,NULL,'100g',NULL,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,539,9.400,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,601,124.000,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,605,0,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124452,606,2.940,'100g',6,3,'2023-05-27','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124453,203,9.850,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,204,8.620,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,205,34.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,208,259,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,269,9.850,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,291,2.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,301,64,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,303,2.460,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,306,71,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,307,369,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,328,1,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,401,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,539,9.900,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,601,129,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124453,606,3.080,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124455,203,9.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,204,3.490,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,205,48.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,208,256,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,269,6.980,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,291,4.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,301,133,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,303,2.330,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,306,216,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,307,465,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,539,7,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124455,606,1.160,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124456,203,10.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,204,3.510,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,205,47.400,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,207,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,208,246,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,255,NULL,'100g',NULL,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,269,8.770,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,291,3.5,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,301,32,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,303,1.75,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,306,198,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,307,421,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,328,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,401,6.300,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,539,7,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,601,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,605,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124456,606,0,'100g',6,3,'2023-05-27','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124457,203,6.450,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,204,12.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,205,40.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,208,306,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,269,3.230,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,291,1.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,301,52,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,303,3.230,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,306,119,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,307,1310,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,539,1.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124457,606,9.680,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,203,9.380,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,204,7.030,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,205,50,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,208,297,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,269,12.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,291,4.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,301,44,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,303,3.120,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,306,186,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,307,359,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,539,10.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124458,606,1.560,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,203,10.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,204,3.510,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,205,47.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,208,263,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,269,7.020,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,291,5.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,301,30,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,303,1.75,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,306,188,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,307,404,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,401,2.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,539,5.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124459,606,0.350,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,203,10.5,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,204,3.510,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,205,49.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,208,263,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,269,7.020,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,291,5.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,301,30,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,303,3.510,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,306,193,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,307,421,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,401,1.600,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,539,5.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124460,606,0.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,203,8.450,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,204,7.040,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,205,47.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,208,296,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,269,12.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,291,4.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,301,42,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,303,2.820,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,306,168,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,307,352,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,401,1.400,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,539,11.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124461,606,1.410,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,203,9.380,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,204,9.380,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,205,46.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,208,312,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,269,6.25,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,291,3.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,301,62,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,303,3.120,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,306,191,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,307,438,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,401,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,539,6.200,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124462,606,1.560,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124463,203,10.700,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,204,3.570,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,205,50.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,207,NULL,'100g',NULL,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,208,250.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,255,NULL,'100g',NULL,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,269,7.140,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,291,3.600,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,301,29.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,303,3.570,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,306,189.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,307,411.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,320,0.000,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,328,0,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,401,4.300,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,539,7.100,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,601,0,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,605,0,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124463,606,0.710,'100g',6,3,'2023-05-27','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124464,203,6.320,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,204,19.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,205,70.100,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,208,473,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,269,0.580,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,291,6.660,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,301,6.620,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,303,2.170,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,306,262,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,307,393,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,401,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,539,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,605,0.240,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124464,606,2.610,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,203,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,204,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,205,13.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,207,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,208,55,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,255,NULL,'100g',NULL,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,269,11.700,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,291,0.800,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,301,4,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,303,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,306,70,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,307,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,320,0.000,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,328,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,401,46.900,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,539,2.300,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,601,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,605,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124465,606,0,'100g',6,3,'2023-05-27','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124466,203,11.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,204,16.000,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,205,68.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,208,464,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,269,0.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,291,5.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,301,112,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,303,4.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,306,250,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,307,731,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,539,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,601,12,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,605,0.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124466,606,4.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,203,11.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,204,16.000,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,205,68.400,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,208,464,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,269,0.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,291,5.600,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,301,112,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,303,4.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,306,250,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,307,731,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,539,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,601,12,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,605,0.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124467,606,4.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124468,203,8,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,204,2.200,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,205,84.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,208,353,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,269,20.800,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,291,9.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,301,15,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,303,30,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,306,270,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,307,17,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,401,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,539,20.100,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124468,606,0.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,203,7.800,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,204,1.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,205,87.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,208,362,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,269,22.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,291,8,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,301,19,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,303,6.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,306,278,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,307,601,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,328,7,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,401,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,539,21.800,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124469,606,0.200,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,203,6.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,204,2.600,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,205,85.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,208,370,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,269,28.600,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,291,6,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,301,14,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,303,6.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,306,176,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,307,592,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,328,7,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,401,32,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,539,28.100,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124470,606,0.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,203,6.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,204,2.600,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,205,85.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,208,370,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,269,28.600,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,291,6.100,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,301,15,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,303,6.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,306,175,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,307,587,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,328,7,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,401,32,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,539,28,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124471,606,0.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124472,203,4,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,204,10.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,205,76.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,208,409,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,269,28.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,291,1.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,301,17,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,303,5.700,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,306,120,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,307,362,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,328,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,539,28.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,601,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,605,0.100,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124472,606,2.5,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124473,203,7.800,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,204,1.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,205,87.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,208,362,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,269,22.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,291,8,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,301,19,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,303,6.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,306,278,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,307,601,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,328,7,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,401,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,539,21.800,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124473,606,0.200,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,203,7.900,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,204,1.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,205,87,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,208,361,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,269,22.900,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,291,8.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,301,23,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,303,6.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,306,285,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,307,632,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,328,7,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,401,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,539,22.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124474,606,0.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,203,8,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,204,2.200,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,205,84.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,208,353,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,269,20.800,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,291,9.700,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,301,15,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,303,30,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,306,270,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,307,17,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,328,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,401,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,539,20.100,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124475,606,0.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,203,7.800,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,204,1.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,205,87.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,208,362,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,269,22.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,291,8,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,301,19,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,303,6.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,306,278,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,307,601,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,328,7,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,401,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,539,21.800,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124476,606,0.200,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,203,7.900,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,204,1.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,205,87,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,208,361,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,269,22.900,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,291,8.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,301,23,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,303,6.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,306,285,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,307,632,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,328,7,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,401,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,539,22.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124477,606,0.300,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,203,6.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,204,2.600,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,205,85.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,208,370,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,269,28.600,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,291,6.100,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,301,15,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,303,6.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,306,175,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,307,587,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,328,7,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,401,32,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,539,28,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124478,606,0.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,203,6.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,204,2.600,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,205,85.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,207,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,208,370,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,255,NULL,'100g',NULL,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,269,28.600,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,291,6,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,301,14,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,303,6.400,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,306,176,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,307,592,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,328,7,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,401,32,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,539,28.100,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,601,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,605,0,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124479,606,0.5,'100g',6,3,'2023-05-27','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124480,203,20.200,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,204,3.030,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,205,4.040,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,207,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,208,131,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,255,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,269,1.010,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,291,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,301,26,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,303,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,306,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,307,414,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,328,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,401,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,539,NULL,'100g',NULL,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,601,56,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,605,0,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124480,606,1.010,'100g',6,3,'2023-05-27','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124483,203,3.700,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,204,18.5,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,205,70.400,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,207,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,208,481,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,255,NULL,'100g',NULL,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,269,33.300,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,291,3.700,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,301,59,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,303,3.700,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,306,189,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,307,389,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,328,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,401,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,539,33.300,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,601,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,605,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124483,606,0,'100g',6,3,'2023-05-27','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124484,203,13.5,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,204,8.700,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,205,21.5,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,207,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,208,200,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,255,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,269,2.100,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,291,4.100,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,301,48,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,303,2.600,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,306,617,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,307,389,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,328,0,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,401,NULL,'100g',NULL,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,539,0.5,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,601,0,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,605,0.100,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124484,606,1.300,'100g',6,3,'2023-05-27','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124485,203,5.950,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,204,13.400,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,205,68.400,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,207,NULL,'100g',NULL,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,208,417,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,255,NULL,'100g',NULL,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,269,26.800,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,291,3,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,301,30,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,303,2.980,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,306,164,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,307,223,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,328,NULL,'100g',NULL,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,401,3,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,539,23.800,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,601,15,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,605,0,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124485,606,1.490,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,203,5.950,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,204,13.400,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,205,68.400,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,207,NULL,'100g',NULL,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,208,417,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,255,NULL,'100g',NULL,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,269,26.800,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,291,3,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,301,33,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,303,2.980,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,306,185,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,307,223,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,328,NULL,'100g',NULL,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,401,3,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,539,23.800,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,601,15,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,605,0,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124486,606,2.980,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,203,7.940,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,204,13.900,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,205,71.400,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,207,NULL,'100g',NULL,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,208,437,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,255,NULL,'100g',NULL,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,269,23.800,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,291,7.900,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,301,16,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,303,3.970,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,306,187,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,307,238,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,328,NULL,'100g',NULL,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,401,385,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,539,23.800,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,601,0,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,605,0,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124487,606,1.980,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,203,5.950,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,204,13.400,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,205,68.400,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,207,NULL,'100g',NULL,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,208,417,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,255,NULL,'100g',NULL,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,269,26.800,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,291,3,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,301,30,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,303,2.980,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,306,182,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,307,268,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,320,NULL,'100g',NULL,3,'2024-12-12','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,328,NULL,'100g',NULL,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,401,3,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,539,23.800,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,601,15,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,605,0,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124488,606,1.490,'100g',6,3,'2024-01-22','2023-05-25');
INSERT INTO `cndb_nutval` VALUES (124489,203,3.230,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,204,0.540,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,205,21.5,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,207,NULL,'100g',NULL,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,208,92,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,255,NULL,'100g',NULL,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,269,2.150,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,291,2.200,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,301,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,303,0.430,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,306,231,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,307,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,328,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,401,NULL,'100g',NULL,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,539,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,601,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,605,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124489,606,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,203,0.830,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,204,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,205,8.330,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,207,NULL,'100g',NULL,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,208,33,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,255,NULL,'100g',NULL,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,269,3.330,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,291,2.5,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,301,26,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,303,1.670,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,306,206,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,307,4,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,328,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,401,4.200,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,539,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,601,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,605,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124490,606,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,203,3.230,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,204,0.540,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,205,21.5,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,207,NULL,'100g',NULL,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,208,92,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,255,NULL,'100g',NULL,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,269,2.150,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,291,2.200,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,301,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,303,0.430,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,306,231,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,307,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,320,NULL,'100g',NULL,3,'2024-12-12','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,328,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,401,NULL,'100g',NULL,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,539,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,601,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,605,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124491,606,0,'100g',6,3,'2024-01-22','2023-06-29');
INSERT INTO `cndb_nutval` VALUES (124493,203,11.400,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,204,8.570,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,205,2.860,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,208,143,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,269,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,291,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,301,66,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,303,2.860,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,306,151,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,307,143,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,328,3,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,401,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,539,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,601,343,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124493,606,2.860,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124495,203,12.200,'100g',6,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,204,8.330,'100g',6,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,205,25,'100g',6,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,207,NULL,'100g',NULL,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,208,218,'100g',6,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,255,NULL,'100g',NULL,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,269,2.560,'100g',6,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,291,2.600,'100g',6,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,301,160,'100g',6,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,303,1.150,'100g',6,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,306,NULL,'100g',NULL,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,307,378,'100g',6,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,320,NULL,'100g',NULL,3,'2024-12-12','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,328,NULL,'100g',NULL,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,401,NULL,'100g',NULL,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,539,NULL,'100g',NULL,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,601,32,'100g',6,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,605,0,'100g',6,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124495,606,4.490,'100g',6,3,'2024-01-22','2023-08-31');
INSERT INTO `cndb_nutval` VALUES (124496,203,6.450,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,204,14.5,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,205,67.700,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,207,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,208,387,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,255,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,269,19.400,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,291,6.5,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,301,29,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,303,3.230,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,306,200,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,307,274,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,328,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,401,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,539,19.400,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,601,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,605,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124496,606,4.840,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124497,203,11,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,204,6.110,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,205,29,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,207,1.720,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,208,216,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,255,NULL,'100g',NULL,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,269,0.910,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,291,5.600,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,301,44,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,303,2.680,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,306,366,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,307,276,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,320,139.000,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,328,0,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,401,0.900,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,539,0,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,601,13,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,605,0,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124497,606,1.840,'100g',6,3,'2024-01-22','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (124498,203,7.140,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,204,10.700,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,205,67.900,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,207,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,208,393,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,255,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,269,25,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,291,7.100,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,301,121,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,303,3.570,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,306,214,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,307,232,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,328,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,401,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,539,17.900,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,601,18,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,605,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124498,606,3.570,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,203,7.140,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,204,10.700,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,205,64.300,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,207,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,208,393,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,255,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,269,21.400,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,291,7.100,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,301,207,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,303,3.570,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,306,193,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,307,286,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,328,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,401,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,539,17.900,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,601,18,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,605,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124499,606,3.570,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124505,203,16.100,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,204,12.500,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,205,5.360,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,207,NULL,'100g',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,208,196,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,255,NULL,'100g',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,269,1.790,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,291,1.800,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,301,125,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,303,3.75,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,306,179,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,307,839,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,328,0,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,401,NULL,'100g',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,539,1.800,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,601,0,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,605,0,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124505,606,0.890,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124506,203,21.100,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,204,11.400,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,205,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,207,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,208,195,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,255,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,269,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,291,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,301,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,303,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,306,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,307,244,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,328,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,401,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,539,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,601,73,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,605,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124506,606,4.060,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,203,2.310,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,204,4.340,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,205,31.200,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,207,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,208,162,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,255,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,269,14.400,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,291,2.900,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,301,28,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,303,1.330,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,306,124,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,307,87,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,328,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,401,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,539,6.400,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,601,3,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,605,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124507,606,1.450,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124508,203,2.310,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,204,4.340,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,205,31.200,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,207,NULL,'100g',NULL,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,208,168,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,255,NULL,'100g',NULL,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,269,13.900,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,291,2.300,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,301,39,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,303,1.160,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,306,136,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,307,118,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,328,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,401,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,539,6.400,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,601,3,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,605,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124508,606,1.450,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124509,203,22.700,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,204,6.590,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,205,0.800,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,207,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,208,153,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,255,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,269,0.010,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,291,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,301,6.680,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,303,0.610,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,306,467,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,307,109,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,328,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,401,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,539,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,601,90.900,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,605,0.060,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124509,606,1.840,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124510,203,4.710,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,204,9.410,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,205,40,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,207,NULL,'100g',NULL,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,208,259,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,255,NULL,'100g',NULL,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,269,10.600,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,291,2.400,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,301,89,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,303,1.180,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,306,100,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,307,329,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,328,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,401,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,539,10.600,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,601,12,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,605,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124510,606,2.350,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124511,203,3.850,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,204,11.5,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,205,69.200,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,207,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,208,385,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,255,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,269,26.900,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,291,3.800,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,301,30800,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,303,3850,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,306,192,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,307,250,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,328,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,401,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,539,26.900,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,601,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,605,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124511,606,3.850,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124512,203,11.700,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,204,10.300,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,205,26.400,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,207,NULL,'100g',NULL,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,208,249.000,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,255,NULL,'100g',NULL,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,269,2.930,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,291,0.700,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,301,301.000,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,303,1.980,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,306,220.000,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,307,616.000,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,320,53.000,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,328,0,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,401,0.000,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,539,NULL,'100g',NULL,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,601,18.000,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,605,0,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124512,606,3.670,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124513,203,11,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,204,8.760,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,205,28.5,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,207,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,208,241,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,255,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,269,2.920,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,291,1.5,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,301,248,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,303,2.120,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,306,153,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,307,569,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,328,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,401,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,539,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,601,15,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,605,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124513,606,2.920,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124514,203,3.910,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,204,1.560,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,205,14.800,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,208,94,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,269,0.780,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,291,4.700,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,301,30,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,303,0.780,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,306,10,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,307,227,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,320,7.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,328,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,401,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,539,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,601,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124514,606,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,203,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,204,0.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,205,17,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,208,60,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,269,15,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,291,1,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,301,5,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,303,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,306,90,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,307,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,320,0.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,328,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,401,46.900,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,539,3,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,601,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124515,606,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124516,203,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,204,0.000,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,205,17.200,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,208,70,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,269,14.800,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,291,0.800,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,301,9,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,303,0.780,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,306,73,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,307,8,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,328,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,401,46.900,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,539,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,601,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,605,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124516,606,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124517,203,5.560,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,204,13.900,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,205,66.700,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,208,417,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,269,25,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,291,5.600,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,301,28,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,303,2.780,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,306,150,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,307,125,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,320,0.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,328,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,401,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,539,22.200,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,601,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124517,606,4.170,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124518,203,7.140,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,204,14.300,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,205,75,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,208,464,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,269,28.600,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,291,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,301,21,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,303,3.570,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,306,193,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,307,196,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,328,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,401,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,539,25,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,601,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,605,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124518,606,3.570,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,203,5.510,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,204,33.100,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,205,57.900,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,208,551,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,269,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,291,13.800,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,301,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,303,2.760,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,306,110,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,307,551,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,328,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,401,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,539,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,601,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,605,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124519,606,5.510,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,203,5.510,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,204,33.100,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,205,57.900,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,208,551,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,269,2.760,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,291,11,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,301,28,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,303,2.760,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,306,55,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,307,413,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,328,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,401,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,539,1.400,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,601,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,605,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124520,606,4.130,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,203,5.510,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,204,33.100,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,205,60.600,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,208,551,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,269,8.270,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,291,13.800,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,301,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,303,2.760,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,306,14,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,307,28,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,328,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,401,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,539,5.5,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,601,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,605,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124521,606,4.130,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124522,203,23.800,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,204,16.700,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,205,52.400,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,207,NULL,'100g',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,208,452,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,255,NULL,'100g',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,269,2.380,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,291,21.400,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,301,48,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,303,4.760,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,306,638,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,307,905,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,328,0,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,401,NULL,'100g',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,539,0,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,601,0,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,605,0,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124522,606,1.190,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124523,203,21.400,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,204,16.700,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,205,57.100,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,208,452,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,269,9.520,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,291,28.600,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,301,45,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,303,4.760,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,306,643,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,307,71,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,328,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,401,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,539,7.100,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,601,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,605,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124523,606,2.380,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124527,203,2.380,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,204,1.190,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,205,11.900,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,207,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,208,71.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,255,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,269,2.380,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,291,1.600,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,301,16.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,303,0.790,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,306,206.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,307,492.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,328,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,401,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,539,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,601,4,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,605,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124527,606,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,203,2.380,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,204,0.790,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,205,8.730,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,207,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,208,56.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,255,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,269,3.170,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,291,2.400,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,301,24.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,303,0.790,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,306,238.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,307,516.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,328,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,401,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,539,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,601,4,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,605,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124528,606,0.400,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,203,3.170,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,204,1.590,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,205,7.940,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,207,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,208,56.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,255,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,269,0.790,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,291,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,301,8,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,303,0.480,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,306,48.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,307,635.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,328,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,401,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,539,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,601,12,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,605,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124529,606,0.400,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124530,203,5,'100ml',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,204,2.080,'100ml',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,205,11.700,'100ml',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,207,NULL,'100ml',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,208,83,'100ml',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,255,NULL,'100ml',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,269,0.830,'100ml',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,291,0.800,'100ml',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,301,21,'100ml',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,303,0.830,'100ml',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,306,67,'100ml',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,307,550,'100ml',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,320,NULL,'100ml',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,328,0,'100ml',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,401,NULL,'100ml',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,539,0.800,'100ml',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,601,8,'100ml',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,605,0,'100ml',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124530,606,0.830,'100ml',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124531,203,4.690,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,204,1.560,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,205,18.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,207,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,208,102.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,255,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,269,3.120,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,291,3.900,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,301,47.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,303,1.170,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,306,242.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,307,508.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,328,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,401,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,539,2.300,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,601,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,605,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124531,606,0.390,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,203,4.760,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,204,1.590,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,205,9.520,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,207,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,208,71.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,255,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,269,0.790,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,291,0.800,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,301,16.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,303,0.400,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,306,429.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,307,325.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,328,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,401,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,539,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,601,16.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,605,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124532,606,0.400,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124533,203,5.560,'100ml',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,204,1.590,'100ml',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,205,14.300,'100ml',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,207,NULL,'100ml',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,208,95.000,'100ml',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,255,NULL,'100ml',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,269,2.380,'100ml',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,291,1.600,'100ml',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,301,32.000,'100ml',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,303,0.790,'100ml',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,306,500.000,'100ml',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,307,325.000,'100ml',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,320,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,328,0,'100ml',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,401,NULL,'100ml',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,539,0,'100ml',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,601,8.000,'100ml',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,605,0,'100ml',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124533,606,0.790,'100ml',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124551,203,3.170,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,204,1.190,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,205,10.300,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,207,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,208,56.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,255,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,269,5.560,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,291,2.400,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,301,32.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,303,0.790,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,306,516.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,307,341.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,328,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,401,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,539,2.400,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,601,4,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,605,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124551,606,0.400,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124552,203,1.590,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,204,1.190,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,205,20.600,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,207,NULL,'100g',NULL,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,208,99,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,255,NULL,'100g',NULL,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,269,13.5,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,291,0.400,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,301,118,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,303,0.400,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,306,131,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,307,52,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,328,2,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,401,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,539,7.100,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,601,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,605,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124552,606,0.400,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124553,203,4.450,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,204,4.150,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,205,18.100,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,207,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,208,128,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,255,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,269,10.400,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,291,1.5,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,301,73,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,303,1.870,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,306,118,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,307,134,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,328,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,401,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,539,2.400,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,601,3,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,605,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124553,606,1.040,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124554,203,7.140,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,204,10.700,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,205,67.900,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,207,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,208,393,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,255,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,269,25,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,291,7.100,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,301,71.000,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,303,3.570,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,306,179.000,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,307,214,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,328,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,401,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,539,17.900,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,601,18,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,605,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124554,606,1.790,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124555,203,4.100,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,204,9.300,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,205,67.800,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,207,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,208,359,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,255,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,269,33.800,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,291,4.200,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,301,351,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,303,4.900,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,306,242,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,307,308,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,328,5,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,401,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,539,32.400,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,601,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,605,0.100,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124555,606,1.600,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,203,4.100,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,204,9.400,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,205,68.5,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,207,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,208,362,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,255,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,269,33.800,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,291,4,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,301,351,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,303,4.900,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,306,240,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,307,324,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,328,5,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,401,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,539,32.800,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,601,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,605,0.100,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124556,606,1.600,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,203,4.100,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,204,9.400,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,205,68.100,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,207,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,208,360,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,255,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,269,33.400,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,291,3.900,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,301,351,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,303,4.900,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,306,241,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,307,321,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,328,5,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,401,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,539,32.300,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,601,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,605,0.100,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124557,606,1.600,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,203,4.100,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,204,9.400,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,205,68.5,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,207,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,208,362,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,255,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,269,33.800,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,291,4,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,301,351,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,303,4.900,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,306,241,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,307,364,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,320,NULL,'100g',NULL,3,'2024-12-12','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,328,5,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,401,NULL,'100g',NULL,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,539,32.700,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,601,0,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,605,0.100,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124558,606,1.600,'100g',6,3,'2024-01-22','2023-10-26');
INSERT INTO `cndb_nutval` VALUES (124569,203,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,204,0.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,205,18,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,208,70,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,269,15,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,291,1,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,301,5,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,303,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,306,135,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,307,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,320,0.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,328,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,401,46.900,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,539,2,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,601,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124569,606,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124570,203,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,204,0.000,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,205,17.200,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,208,70,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,269,14.800,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,291,0.800,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,301,9,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,303,0.780,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,306,73,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,307,8,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,328,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,401,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,539,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,601,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,605,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124570,606,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,203,10.200,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,204,4.170,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,205,8.080,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,208,110,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,269,3.360,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,291,2.200,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,301,41,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,303,1.600,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,306,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,307,241,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,328,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,401,13.600,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,539,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,601,30,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,605,0.260,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124571,606,1.570,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124574,203,7.430,'100g',6,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,204,6.580,'100g',6,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,205,7.970,'100g',6,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,207,NULL,'100g',NULL,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,208,122.000,'100g',6,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,255,NULL,'100g',NULL,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,269,4.630,'100g',6,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,291,0.900,'100g',6,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,301,235,'100g',6,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,303,0.320,'100g',6,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,306,NULL,'100g',NULL,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,307,240.000,'100g',6,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,320,106.000,'100g',6,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,328,NULL,'100g',NULL,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,401,10.600,'100g',6,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,539,NULL,'100g',NULL,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,601,21,'100g',6,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,605,0.020,'100g',6,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124574,606,3.780,'100g',6,3,'2024-01-22','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124575,203,4.650,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,204,14,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,205,62.800,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,207,NULL,'100g',NULL,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,208,395,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,255,NULL,'100g',NULL,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,269,30.200,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,291,0,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,301,0,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,303,2.510,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,306,163,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,307,279,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,320,NULL,'100g',NULL,3,'2024-12-12','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,328,0,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,401,0,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,539,0,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,601,23,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,605,0,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124575,606,3.490,'100g',6,3,'2024-01-22','2023-11-16');
INSERT INTO `cndb_nutval` VALUES (124576,203,14.800,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,204,8.75,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,205,6.720,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,208,158,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,269,2.210,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,291,2.900,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,301,58,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,303,2.100,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,306,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,307,272,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,328,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,401,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,539,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,601,28,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,605,0.520,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124576,606,3.400,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124577,203,5.360,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,204,10.400,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,205,64.300,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,207,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,208,373,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,255,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,269,30.700,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,291,4.700,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,301,18,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,303,1.810,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,306,207,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,307,276,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,328,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,401,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,539,30.400,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,601,27,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,605,0.130,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124577,606,3.520,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124578,203,17.5,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,204,12.5,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,205,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,207,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,208,175,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,255,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,269,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,291,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,301,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,303,0.030,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,306,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,307,650,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,328,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,401,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,539,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,601,75,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,605,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124578,606,3.75,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124579,203,17.5,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,204,7.020,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,205,3.510,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,208,158,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,269,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,291,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,301,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,303,1.260,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,306,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,307,526,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,328,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,401,2.100,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,539,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,601,70,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,605,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124579,606,2.630,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,203,14.300,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,204,14.300,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,205,3.570,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,208,202,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,269,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,291,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,301,82,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,303,95.200,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,306,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,307,1200,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,328,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,401,23.800,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,539,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,601,95,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,605,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124580,606,4.760,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124581,203,17.900,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,204,15.200,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,205,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,207,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,208,205.000,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,255,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,269,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,291,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,301,18.000,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,303,1.520,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,306,232.000,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,307,76.000,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,328,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,401,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,539,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,601,76.000,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,605,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124581,606,3.120,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124582,203,16.100,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,204,4.460,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,205,3.570,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,208,107,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,269,3.570,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,291,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,301,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,303,1.290,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,306,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,307,1180,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,328,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,401,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,539,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,601,45,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,605,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124582,606,0.890,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124583,203,14.300,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,204,14.300,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,205,1.790,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,207,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,208,196,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,255,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,269,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,291,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,301,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,303,1.290,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,306,0.000,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,307,946,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,328,0.000,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,401,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,539,0.000,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,601,80,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,605,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124583,606,4.460,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124584,203,19,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,204,35.800,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,205,2.110,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,207,NULL,'100g',NULL,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,208,126,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,255,NULL,'100g',NULL,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,269,1.050,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,291,0,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,301,0,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,303,4.210,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,306,0,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,307,326,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,320,0.000,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,328,0,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,401,0,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,539,0,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,601,53,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,605,0,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124584,606,1.050,'100g',6,3,'2024-01-22','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124585,203,17.5,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,204,12.5,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,205,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,207,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,208,175,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,255,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,269,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,291,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,301,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,303,0.900,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,306,0.000,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,307,650,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,328,0.000,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,401,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,539,0.000,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,601,75,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,605,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124585,606,3.75,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124586,203,21.5,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,204,3.400,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,205,1.130,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,207,NULL,'100g',NULL,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,208,113,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,255,NULL,'100g',NULL,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,269,1.130,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,291,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,301,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,303,0.110,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,306,213,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,307,295,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,328,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,401,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,539,1.100,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,601,62,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,605,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124586,606,1.700,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124587,203,16.700,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,204,5.880,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,205,1.960,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,207,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,208,137,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,255,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,269,1.960,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,291,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,301,4,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,303,0.010,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,306,1070,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,307,392,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,328,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,401,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,539,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,601,54,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,605,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124587,606,1.470,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124588,203,14.700,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,204,9.800,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,205,4.900,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,207,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,208,167,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,255,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,269,1.960,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,291,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,301,0.000,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,303,1.410,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,306,1070,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,307,431,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,328,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,401,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,539,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,601,64,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,605,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124588,606,2.940,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124589,203,15.700,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,204,7.840,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,205,3.920,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,208,147.000,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,269,2.940,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,291,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,301,20,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,303,1.410,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,306,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,307,353.000,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,328,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,401,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,539,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,601,54.000,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,605,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124589,606,1.960,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124590,203,15.800,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,204,14.000,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,205,1.750,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,207,0,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,208,193.000,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,255,NULL,'100g',NULL,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,269,1.750,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,291,0,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,301,0,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,303,0.020,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,306,223.000,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,307,649.000,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,320,0.000,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,328,0,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,401,0,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,539,0,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,601,61.000,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,605,0,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124590,606,3.510,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124591,203,15.200,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,204,15.200,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,205,0.25,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,208,177,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,269,0.25,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,291,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,301,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,303,0.25,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,306,616,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,307,405,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,328,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,401,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,539,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,601,76,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,605,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124591,606,5.070,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124592,203,15.200,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,204,15.200,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,205,0.25,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,207,NULL,'100g',NULL,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,208,177,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,255,NULL,'100g',NULL,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,269,0.25,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,291,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,301,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,303,1.820,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,306,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,307,405,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,328,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,401,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,539,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,601,76,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,605,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124592,606,5.070,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124593,203,21.600,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,204,1.470,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,205,1.960,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,207,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,208,108.000,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,255,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,269,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,291,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,301,27.000,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,303,0.980,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,306,598.000,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,307,225.000,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,328,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,401,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,539,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,601,54.000,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,605,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124593,606,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124594,203,19,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,204,4.210,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,205,2.110,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,208,126,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,269,1.050,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,291,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,301,14,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,303,0.760,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,306,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,307,326.000,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,328,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,401,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,539,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,601,53,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,605,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124594,606,1.050,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,203,23.5,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,204,16.500,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,205,54.100,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,208,447,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,269,2.350,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,291,28.200,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,301,61,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,303,4.710,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,306,727,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,307,706,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,328,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,401,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,539,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,601,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,605,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124595,606,2.350,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124598,203,8,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,204,9.330,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,205,72,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,207,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,208,387,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,255,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,269,29.300,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,291,6.700,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,301,40,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,303,2.270,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,306,347,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,307,333,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,328,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,401,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,539,22.700,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,601,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,605,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124598,606,1.330,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,203,13.300,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,204,6.670,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,205,68.900,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,207,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,208,378,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,255,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,269,2.220,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,291,8.900,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,301,44,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,303,3.780,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,306,378,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,307,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,328,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,401,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,539,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,601,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,605,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124599,606,1.110,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,203,12.5,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,204,7.500,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,205,67.5,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,207,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,208,375,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,255,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,269,2.5,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,291,10,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,301,50,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,303,3.75,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,306,375,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,307,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,328,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,401,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,539,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,601,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,605,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124600,606,1.25,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,203,12.5,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,204,7.500,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,205,67.5,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,207,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,208,375,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,255,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,269,2.5,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,291,10,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,301,50,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,303,3.75,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,306,375,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,307,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,328,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,401,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,539,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,601,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,605,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124601,606,1.25,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,203,12.5,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,204,7.500,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,205,67.5,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,207,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,208,375,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,255,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,269,2.5,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,291,10,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,301,50,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,303,3.75,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,306,375,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,307,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,328,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,401,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,539,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,601,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,605,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124602,606,1.25,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124603,203,15.600,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,204,13.100,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,205,23.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,208,270.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,269,2.5,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,291,1.600,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,301,279.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,303,1.600,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,306,164.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,307,443.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,320,49.200,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,328,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,401,0.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,539,1,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,601,28.700,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124603,606,5.700,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124604,203,6.290,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,204,11.000,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,205,75.5,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,207,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,208,440,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,255,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,269,9.430,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,291,6.300,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,301,31,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,303,0.940,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,306,755,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,307,503,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,320,NULL,'100g',NULL,3,'2024-12-12','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,328,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,401,NULL,'100g',NULL,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,539,9.400,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,601,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,605,0,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124604,606,1.570,'100g',6,3,'2024-01-22','2023-12-21');
INSERT INTO `cndb_nutval` VALUES (124611,203,12.5,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,204,14.300,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,205,3.570,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,207,NULL,'100g',NULL,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,208,179,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,255,NULL,'100g',NULL,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,269,1.790,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,291,0,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,301,0,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,303,0.020,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,306,0,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,307,429,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,320,0.000,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,328,0,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,401,0,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,539,0,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,601,80,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,605,0,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124611,606,4.460,'100g',6,3,'2024-01-22','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (124612,203,23.200,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,204,1.790,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,205,1.790,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,207,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,208,107,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,255,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,269,1.790,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,291,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,301,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,303,0.640,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,306,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,307,804,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,328,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,401,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,539,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,601,54,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,605,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124612,606,0.360,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124622,203,7.140,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,204,35.700,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,205,57.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,208,571,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,269,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,291,3.600,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,301,107,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,303,0.710,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,306,107,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,307,607,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,328,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,539,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,601,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,605,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124622,606,5.360,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124626,203,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,204,0.000,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,205,3.890,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,207,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,208,17,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,255,NULL,'100ml',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,269,3.610,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,291,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,301,3,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,303,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,306,8,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,307,7,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,328,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,401,4.200,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,539,3.600,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,601,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,605,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124626,606,0,'100ml',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124627,203,17.800,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,204,30.200,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,205,6.700,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,208,357,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,269,4,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,291,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,301,546,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,303,0.230,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,306,189,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,307,1560,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,328,1,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,539,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,601,96,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,605,1.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124627,606,19,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,203,19.200,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,204,15.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,205,12.800,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,208,255,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,269,7,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,291,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,301,587,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,303,0.190,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,306,855,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,307,1010,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,328,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,539,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,601,51,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,605,0.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124628,606,9,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,203,19.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,204,15.000,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,205,13,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,208,255,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,269,7,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,291,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,301,548,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,303,0.190,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,306,291,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,307,1500,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,328,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,539,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,601,50,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,605,0.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124629,606,9,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,203,19.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,204,15.000,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,205,12.600,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,208,254,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,269,7,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,291,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,301,585,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,303,0.190,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,306,1280,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,307,741,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,328,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,539,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,601,50,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,605,0.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124630,606,9,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,203,18.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,204,30.200,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,205,6.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,208,357,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,269,3.700,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,291,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,301,546,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,303,0.230,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,306,185,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,307,1600,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,328,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,539,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,601,94,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,605,1.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124631,606,18.600,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,203,18.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,204,30.200,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,205,6.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,208,357,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,269,3.700,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,291,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,301,546,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,303,0.230,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,306,185,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,307,1600,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,328,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,539,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,601,94,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,605,1.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124632,606,18.600,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,203,6.600,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,204,6.400,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,205,46.800,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,208,252,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,269,11.400,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,291,7,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,301,347,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,303,4.800,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,306,240,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,307,263,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,328,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,539,11.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,601,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,605,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124633,606,1.700,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,203,3.900,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,204,8.500,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,205,70,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,208,350,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,269,31.700,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,291,7.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,301,325,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,303,4.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,306,258,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,307,285,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,328,5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,539,30.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,601,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,605,0.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124634,606,1.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,203,4.400,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,204,5.700,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,205,42.900,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,208,224,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,269,13.300,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,291,4.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,301,302,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,303,4.200,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,306,165,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,307,244,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,328,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,539,13,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,601,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,605,0.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124635,606,1.600,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,203,3.900,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,204,8.400,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,205,69.400,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,208,346,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,269,31.800,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,291,7.300,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,301,325,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,303,4.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,306,259,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,307,269,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,328,5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,539,30.200,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,601,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,605,0.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124636,606,1.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,203,3.900,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,204,8.500,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,205,69.900,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,208,349,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,269,31.700,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,291,7.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,301,325,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,303,4.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,306,258,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,307,322,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,328,5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,539,30.400,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,601,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,605,0.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124637,606,1.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,203,4.700,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,204,7.300,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,205,41.600,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,208,230,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,269,12.600,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,291,6.600,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,301,54,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,303,4.200,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,306,174,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,307,242,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,328,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,539,12.400,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,601,1,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,605,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124638,606,1.200,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,203,7.900,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,204,1.900,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,205,79.700,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,208,325,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,269,28.600,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,291,12.300,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,301,37,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,303,3.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,306,478,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,307,340,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,328,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,539,15,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,601,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,605,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124639,606,0.400,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,203,23.700,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,204,7.000,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,205,10.200,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,208,187,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,269,1.300,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,291,2.300,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,301,53,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,303,4.300,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,306,269,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,307,669,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,328,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,539,1.300,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,601,1,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,605,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124640,606,1.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124641,203,18.900,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,204,43.200,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,205,29.700,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,208,568,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,269,16.200,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,291,8.100,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,301,54,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,303,5.950,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,306,541,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,307,284,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,328,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,401,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,539,16.200,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,601,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124641,606,6.760,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124642,203,18.900,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,204,43.200,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,205,29.700,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,207,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,208,568,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,255,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,269,16.200,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,291,8.100,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,301,54,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,303,5.950,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,306,541,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,307,284,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,328,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,401,NULL,'100g',NULL,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,539,16.200,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,601,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,605,0,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124642,606,6.760,'100g',6,3,'2024-01-22','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (124643,203,7.140,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,204,10.700,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,205,64.300,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,207,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,208,393,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,255,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,269,21.400,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,291,7.100,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,301,214,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,303,3.570,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,306,196,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,307,286,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,328,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,401,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,539,17.900,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,601,18,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,605,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124643,606,3.570,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,203,7.140,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,204,10.700,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,205,67.900,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,207,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,208,393,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,255,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,269,25,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,291,7.100,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,301,139,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,303,3.570,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,306,214,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,307,232,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,328,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,401,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,539,17.900,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,601,18,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,605,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124644,606,3.570,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,203,7.140,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,204,10.700,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,205,67.900,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,207,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,208,393,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,255,NULL,'100g',NULL,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,269,25,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,291,7.100,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,301,71,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,303,3.570,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,306,179,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,307,214,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,328,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,401,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,539,17.900,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,601,18,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,605,0,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124645,606,1.790,'100g',6,3,'2024-01-22','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124646,203,11.800,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,204,16.200,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,205,45.600,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,207,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,208,382,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,255,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,269,13.200,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,291,5.900,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,301,60,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,303,8.820,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,306,268,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,307,324,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,328,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,401,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,539,11.800,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,601,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,605,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124646,606,2.210,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,203,2.310,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,204,2.890,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,205,34.700,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,207,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,208,162,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,255,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,269,15.600,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,291,2.300,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,301,5,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,303,1.620,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,306,128,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,307,171,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,328,1,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,401,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,539,8.100,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,601,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,605,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124647,606,0.870,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124665,203,4.800,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,204,8.200,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,205,41.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,208,241,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,269,11.700,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,291,4.400,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,301,54,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,303,4.200,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,306,151,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,307,244,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,328,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,539,11.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,601,1,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,605,0.100,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124665,606,1.300,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,203,0.670,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,204,0.000,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,205,13,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,207,NULL,'100ml',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,208,57,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,255,NULL,'100ml',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,269,11.700,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,291,0,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,301,7,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,303,0.230,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,306,167,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,307,7,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,320,NULL,'100ml',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,328,0,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,401,10,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,539,0,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,601,0,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,605,0,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124688,606,0,'100ml',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124689,203,14.300,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,204,8.040,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,205,5.360,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,207,NULL,'100g',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,208,161,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,255,NULL,'100g',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,269,0,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,291,3.600,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,301,161,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,303,3.570,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,306,161,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,307,696,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,328,0,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,401,NULL,'100g',NULL,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,539,0,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,601,0,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,605,0,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124689,606,0.890,'100g',6,3,'2024-01-22','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (124690,203,2.310,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,204,4.340,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,205,31.800,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,207,NULL,'100g',NULL,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,208,168,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,255,NULL,'100g',NULL,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,269,14.400,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,291,2.300,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,301,17,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,303,1.160,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,306,134,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,307,107,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,328,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,401,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,539,6.400,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,601,3,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,605,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124690,606,1.160,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124691,203,9.730,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,204,8.850,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,205,27.400,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,207,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,208,230,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,255,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,269,5.310,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,291,1.800,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,301,54,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,303,1.770,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,306,236,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,307,478,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,320,0.000,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,328,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,401,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,539,4.400,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,601,40,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,605,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124691,606,2.650,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,203,2.300,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,204,3.450,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,205,33.300,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,207,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,208,161,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,255,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,269,13.200,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,291,2.300,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,301,5,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,303,2.130,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,306,92,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,307,92,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,328,1,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,401,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,539,6.300,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,601,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,605,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124692,606,0.860,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,203,7.260,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,204,9.270,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,205,29.900,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,207,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,208,231,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,255,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,269,20.5,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,291,2.100,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,301,34,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,303,1.280,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,306,330,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,307,203,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,328,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,401,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,539,2.100,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,601,13,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,605,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124693,606,1.070,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,203,1.800,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,204,2.100,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,205,34.100,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,207,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,208,156,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,255,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,269,16.200,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,291,1.800,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,301,5,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,303,1.680,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,306,125.000,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,307,141,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,328,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,401,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,539,9,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,601,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,605,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124694,606,0.600,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,203,2.890,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,204,3.470,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,205,33.5,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,207,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,208,168,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,255,NULL,'100g',NULL,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,269,14.400,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,291,2.300,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,301,51,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,303,2.140,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,306,180,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,307,171,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,320,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,328,1,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,401,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,539,6.900,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,601,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,605,0,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124695,606,0.870,'100g',6,3,'2024-01-22','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124697,203,5.880,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,204,13.200,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,205,67.600,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,208,412,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,269,26.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,291,2.900,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,301,29,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,303,2.940,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,306,179,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,307,265,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,328,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,401,NULL,'100g',NULL,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,539,23.5,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,601,15,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,605,0,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124697,606,1.470,'100g',6,3,'2024-01-22','2024-02-01');
INSERT INTO `cndb_nutval` VALUES (124698,203,1.000,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,204,0.000,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,205,4.000,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,207,NULL,'100g',NULL,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,208,20.000,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,255,NULL,'100g',NULL,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,269,2.000,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,291,2.000,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,301,30.000,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,303,0.400,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,306,100.000,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,307,140.000,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,320,NULL,'100g',NULL,3,'2024-12-12','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,328,0,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,401,2.500,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,539,0,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,601,0,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,605,0,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124698,606,0,'100g',6,3,'2024-01-22','2024-02-15');
INSERT INTO `cndb_nutval` VALUES (124699,203,6.150,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,204,1.150,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,205,18.5,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,208,108,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,269,0.769,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,291,4.620,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,301,3.850,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,303,1.540,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,306,415,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,307,108,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,328,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,401,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,539,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,601,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124699,606,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,203,0.800,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,204,0.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,205,5.600,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,208,36,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,269,1.600,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,291,1.600,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,301,14,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,303,0.800,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,306,122,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,307,16,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,328,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,401,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,539,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,601,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124700,606,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,203,2.400,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,204,0.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,205,8.800,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,208,48,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,269,4,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,291,2.400,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,301,14,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,303,0.800,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,306,106,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,307,104,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,328,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,401,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,539,1.600,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,601,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124701,606,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,203,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,204,0.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,205,3.330,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,208,17,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,269,1.670,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,291,0.800,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,301,31,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,303,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,306,106,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,307,100,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,328,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,401,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,539,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,601,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124702,606,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,203,0.830,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,204,0.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,205,2.5,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,208,12,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,269,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,291,0.800,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,301,21,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,303,0.830,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,306,50,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,307,12,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,328,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,401,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,539,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,601,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124703,606,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,203,0.800,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,204,0.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,205,5.600,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,208,36,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,269,1.600,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,291,1.600,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,301,14,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,303,0.800,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,306,122,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,307,16,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,328,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,401,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,539,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,601,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124704,606,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,203,0.833,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,204,0.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,205,2.5,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,208,12.500,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,269,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,291,0.833,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,301,20.800,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,303,0.833,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,306,50,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,307,12.500,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,328,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,401,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,539,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,601,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124705,606,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,203,0.800,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,204,0.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,205,5.600,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,208,36,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,269,1.600,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,291,1.600,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,301,14,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,303,0.800,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,306,122,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,307,16,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,328,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,401,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,539,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,601,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124706,606,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,203,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,204,0.000,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,205,3.330,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,207,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,208,17,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,255,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,269,1.670,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,291,0.800,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,301,31,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,303,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,306,106,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,307,100,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,328,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,401,NULL,'100g',NULL,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,539,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,601,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,605,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124707,606,0,'100g',6,3,'2024-01-22','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124708,203,5.620,'100g',6,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,204,11.800,'100g',6,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,205,65.800,'100g',6,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,207,NULL,'100g',NULL,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,208,387.000,'100g',6,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,255,NULL,'100g',NULL,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,269,33.400,'100g',6,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,291,2.400,'100g',6,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,301,30.000,'100g',6,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,303,2.030,'100g',6,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,306,224.000,'100g',6,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,307,313.000,'100g',6,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,320,NULL,'100g',NULL,3,'2024-12-12','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,328,0,'100g',6,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,401,NULL,'100g',NULL,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,539,26.400,'100g',6,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,601,26.000,'100g',6,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,605,0.140,'100g',6,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124708,606,3.470,'100g',6,3,'2024-01-22','2024-06-13');
INSERT INTO `cndb_nutval` VALUES (124709,203,21,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,204,2.110,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,205,1.050,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,207,NULL,'100g',NULL,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,208,105,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,255,NULL,'100g',NULL,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,269,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,291,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,301,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,303,0.760,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,306,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,307,505,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,328,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,401,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,539,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,601,53,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,605,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124709,606,0,'100g',6,3,'2024-01-22','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (124710,203,21.500,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,204,6.510,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,205,1.610,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,208,154.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,269,0.020,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,291,0.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,301,8.360,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,303,0.760,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,306,434.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,307,150.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,328,0.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,401,0.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,539,0.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,601,65.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,605,0.020,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124710,606,1.790,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124711,203,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,204,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,205,10.900,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,208,39.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,269,9.380,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,291,0.800,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,301,4.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,303,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,306,74.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,307,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,401,71.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,539,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,601,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,605,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124711,606,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124712,203,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,204,8.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,205,69.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,208,349.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,269,31.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,291,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,301,325.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,303,4.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,306,258.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,307,322.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,328,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,539,30.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124712,606,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124713,203,15.900,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,204,22.300,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,205,4.770,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,208,283.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,269,0.330,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,291,0.260,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,301,12.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,303,1.790,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,306,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,307,275.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,328,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,401,0.140,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,539,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,601,48.500,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,605,0.850,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124713,606,8.160,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124714,203,13.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,204,10.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,205,24.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,208,232.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,269,4.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,291,2.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,301,159.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,303,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,306,449.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,307,435.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,320,58.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,539,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,601,87.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124714,606,4.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,203,13.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,204,10.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,205,24.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,208,232.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,269,4.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,291,2.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,301,159.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,303,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,306,449.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,307,435.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,320,58.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,539,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,601,87.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124715,606,4.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124716,203,14.800,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,204,12.700,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,205,10.300,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,208,213.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,269,5.900,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,291,0.960,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,301,76.500,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,303,1.500,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,306,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,307,498.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,328,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,401,12.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,539,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,601,46.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,605,0.520,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124716,606,5.980,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124717,203,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,204,7.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,205,28.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,208,225.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,269,7.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,291,2.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,301,238.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,303,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,306,238.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,307,475.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,320,37.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,539,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,601,68.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124717,606,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124718,203,11.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,204,7.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,205,29.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,208,228.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,269,7.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,291,2.500,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,301,253.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,303,1.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,306,202.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,307,481.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,320,50.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,401,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,539,1.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,601,69.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,605,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124718,606,3.800,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124719,203,22.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,204,31.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,205,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,208,364.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,301,695.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,306,68.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,307,591.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,601,91.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124719,606,20.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124720,203,25.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,204,32.100,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,205,3.570,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,208,393.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,269,0.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,291,0.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,301,750.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,303,0.360,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,306,71.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,307,643.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,328,1.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,401,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,539,0.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,601,89.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,605,0.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124720,606,17.900,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124721,203,21.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,204,21.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,205,3.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,208,286.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,301,607.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,306,79.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,307,714.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,601,54.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124721,606,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,203,21.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,204,28.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,205,3.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,208,357.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,301,607.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,306,114.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,307,821.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,601,89.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124722,606,17.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,203,21.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,204,25.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,205,3.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,208,321.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,301,643.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,306,82.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,307,607.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,601,71.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124723,606,14.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,203,25.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,204,21.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,205,3.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,208,286.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,301,707.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,306,136.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,307,786.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,320,214.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,601,54.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124724,606,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,203,25.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,204,25.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,205,3.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,208,357.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,301,786.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,306,125.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,307,482.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,601,71.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124725,606,16.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,203,25.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,204,32.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,205,3.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,208,357.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,301,679.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,306,164.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,307,857.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,601,89.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124726,606,17.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,203,22.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,204,27.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,205,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,208,364.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,301,723.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,306,68.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,307,636.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,601,91.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124727,606,18.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,203,22.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,204,27.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,205,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,208,318.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,301,732.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,306,136.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,307,682.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,601,68.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124728,606,15.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,203,27.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,204,31.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,205,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,208,364.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,301,859.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,306,68.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,307,182.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,601,91.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124729,606,18.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,203,21.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,204,32.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,205,3.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,208,393.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,269,3.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,301,607.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,306,179.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,307,1250.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,601,89.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124730,606,17.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,203,25.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,204,21.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,205,7.140,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,208,286.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,269,3.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,301,714.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,303,0.360,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,306,214.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,307,679.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,601,71.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124731,606,10.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,203,21.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,204,32.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,205,3.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,208,393.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,301,714.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,306,71.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,307,679.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,328,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,601,107.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124732,606,17.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,203,1.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,204,0.211,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,205,23.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,208,95.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,269,20.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,291,1.460,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,301,13.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,303,0.669,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,306,233.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,307,917.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,539,18.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,605,0.002,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124733,606,0.075,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,203,1.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,204,0.211,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,205,23.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,208,95.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,269,20.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,291,1.460,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,301,13.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,303,0.669,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,306,233.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,307,917.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,539,18.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,605,0.002,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124734,606,0.075,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,203,11.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,204,16.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,205,68.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,208,464.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,269,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,291,5.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,301,112.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,303,4.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,306,250.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,307,731.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,328,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,601,12.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,605,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124735,606,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,203,19.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,204,15.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,205,12.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,208,254.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,269,7.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,301,585.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,303,0.190,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,306,1280.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,307,741.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,328,0.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,601,50.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,605,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124736,606,9.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,203,0.860,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,204,0.230,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,205,3.710,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,208,17.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,269,2.580,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,291,0.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,301,9.930,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,303,0.310,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,306,189.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,307,145.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124737,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,203,1.270,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,204,0.204,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,205,6.560,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,208,28.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,269,3.750,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,291,1.550,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,301,14.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,303,1.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,306,340.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,307,288.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124738,606,0.028,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,203,1.410,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,205,6.680,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,208,33.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,269,3.710,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,291,1.380,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,301,16.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,303,0.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,306,353.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,307,223.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,539,0.310,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,601,0.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124739,606,0.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,203,5.560,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,204,1.590,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,205,14.300,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,207,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,208,95.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,255,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,269,2.380,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,291,1.600,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,301,32.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,303,0.790,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,306,500.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,307,325.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,320,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,328,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,401,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,539,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,601,8.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,605,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124740,606,0.790,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124741,203,2.860,'100ml',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,204,1.220,'100ml',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,205,6.120,'100ml',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,207,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,208,49.000,'100ml',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,255,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,269,0.820,'100ml',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,291,0.400,'100ml',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,301,8.000,'100ml',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,303,0.410,'100ml',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,306,73.000,'100ml',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,307,159.000,'100ml',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,320,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,328,0.000,'100ml',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,401,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,539,0.000,'100ml',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,601,6.000,'100ml',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,605,0.000,'100ml',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124741,606,0.410,'100ml',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124742,203,0.980,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,204,0.070,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,205,4.230,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,208,18.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,269,2.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,291,0.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,301,9.930,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,303,0.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,306,187.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,307,255.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124742,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,203,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,204,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,205,16.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,208,80.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,269,9.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,301,22.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,303,3.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,306,338.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,307,1480.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,539,6.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124743,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,203,1.660,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,204,0.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,205,27.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,208,115.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,269,23.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,291,2.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,301,25.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,303,0.860,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,306,335.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,307,902.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,539,19.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124744,606,0.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,203,1.240,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,204,0.980,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,205,33.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,208,144.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,269,29.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,291,1.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,301,13.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,303,0.540,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,306,161.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,307,200.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,539,27.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124745,606,0.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,203,1.220,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,204,0.970,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,205,33.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,208,147.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,269,29.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,291,1.150,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,301,11.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,303,0.770,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,306,469.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,307,224.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,328,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,539,27.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,601,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124746,606,0.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,203,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,205,27.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,208,113.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,269,23.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,291,1.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,301,16.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,303,0.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,306,225.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,307,923.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,539,20.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124747,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,203,2.260,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,204,0.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,205,9.880,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,208,47.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,269,5.850,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,291,2.760,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,301,20.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,303,1.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,306,434.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,307,142.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,601,0.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124748,606,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,203,0.610,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,204,0.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,205,2.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,208,14.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,269,2.070,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,291,0.880,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,301,10.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,303,0.190,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,306,157.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,307,249.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124749,606,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,203,0.860,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,204,0.220,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,205,3.720,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,208,20.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,269,2.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,291,0.950,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,301,9.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,303,0.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,306,191.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,307,150.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124750,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,203,2.270,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,204,0.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,205,9.910,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,208,48.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,269,5.850,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,291,2.780,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,303,1.070,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,306,426.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,307,147.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,601,0.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124751,606,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,203,1.270,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,204,0.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,205,22.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,208,93.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,269,20.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,291,1.540,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,301,14.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,303,0.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,306,350.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,307,250.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,539,17.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124752,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,203,1.270,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,204,0.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,205,22.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,208,93.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,269,20.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,291,1.540,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,301,14.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,303,0.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,306,350.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,307,261.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,539,17.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124753,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,203,1.310,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,204,0.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,205,23.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,208,96.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,269,21.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,291,1.620,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,301,18.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,303,0.740,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,306,268.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,307,917.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,539,17.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124754,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,203,1.310,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,204,0.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,205,23.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,208,96.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,269,21.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,291,1.620,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,301,18.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,303,0.740,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,306,268.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,307,917.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,539,17.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124755,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,203,1.310,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,204,0.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,205,23.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,208,96.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,269,21.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,291,1.620,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,301,18.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,303,0.740,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,306,268.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,307,917.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,539,17.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124756,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,203,1.080,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,205,27.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,208,114.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,269,23.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,291,1.330,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,301,16.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,303,0.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,306,220.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,307,931.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,539,20.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124757,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,203,1.080,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,205,27.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,208,114.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,269,23.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,291,1.330,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,301,16.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,303,0.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,306,220.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,307,931.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,539,20.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124758,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,203,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,204,0.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,205,27.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,208,112.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,269,23.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,291,1.220,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,301,15.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,303,0.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,306,204.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,307,914.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,539,20.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124759,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,203,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,205,27.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,208,113.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,269,23.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,291,1.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,301,16.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,303,0.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,306,225.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,307,923.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,539,20.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124760,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,203,1.320,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,205,22.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,208,97.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,269,20.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,291,1.590,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,301,13.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,303,0.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,306,339.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,307,259.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,539,16.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,601,0.060,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124761,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,205,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,208,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,306,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124762,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,203,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,205,27.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,208,113.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,269,23.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,291,1.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,301,16.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,303,0.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,306,225.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,307,923.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,539,20.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124763,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,203,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,205,27.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,208,113.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,269,23.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,291,1.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,301,16.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,303,0.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,306,225.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,307,923.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,539,20.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124764,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,203,1.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,205,27.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,208,115.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,269,23.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,291,1.360,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,301,16.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,303,0.650,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,306,226.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,307,910.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124765,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,203,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,205,27.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,208,113.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,269,23.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,291,1.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,301,16.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,303,0.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,306,225.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,307,923.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,539,20.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124766,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,203,1.080,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,205,27.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,208,114.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,269,23.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,291,1.330,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,301,16.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,303,0.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,306,220.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,307,931.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,539,20.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124767,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,203,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,204,0.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,205,27.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,208,112.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,269,23.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,291,1.220,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,301,15.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,303,0.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,306,204.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,307,914.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,539,20.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124768,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,203,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,204,0.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,205,27.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,208,112.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,269,23.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,291,1.220,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,301,15.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,303,0.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,306,204.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,307,914.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,539,20.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124769,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,203,1.270,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,204,0.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,205,22.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,208,93.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,269,20.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,291,1.540,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,301,14.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,303,0.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,306,265.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,307,261.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,539,17.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124770,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,203,1.270,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,204,0.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,205,22.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,208,93.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,269,20.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,291,1.540,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,301,14.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,303,0.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,306,350.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,307,250.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,539,17.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124771,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,203,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,204,1.270,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,205,9.880,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,208,55.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,269,6.340,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,291,2.220,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,301,26.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,303,0.240,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,306,375.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,307,276.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,539,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124772,606,0.190,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,203,1.390,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,204,1.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,205,6.430,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,208,38.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,269,3.810,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,291,1.520,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,301,16.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,303,0.790,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,306,262.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,307,304.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,539,0.370,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,601,0.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124773,606,0.150,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,203,1.850,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,204,0.150,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,205,10.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,208,47.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,269,6.710,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,291,2.340,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,301,24.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,303,0.910,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,306,372.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,307,431.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,539,2.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124774,606,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,203,1.520,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,204,0.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,205,7.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,208,34.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,269,3.920,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,291,1.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,301,40.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,303,0.780,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,306,291.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,307,235.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124775,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,203,1.320,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,204,0.190,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,205,6.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,208,31.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,269,3.450,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,291,1.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,301,15.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,303,0.680,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,306,235.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,307,149.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,539,0.290,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,601,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124776,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,203,1.320,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,204,0.190,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,205,6.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,208,31.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,269,3.450,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,291,1.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,301,15.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,303,0.680,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,306,235.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,307,149.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,539,0.290,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,601,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124777,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,205,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,208,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,306,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124778,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,203,5.720,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,204,3.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,205,10.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,208,90.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,269,4.830,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,291,1.930,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,301,44.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,303,1.310,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,306,258.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,307,166.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,539,2.210,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124779,606,0.410,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124780,203,1.630,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,204,0.410,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,205,22.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,208,95.700,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,269,16.900,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,291,1.980,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,301,24.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,303,1.140,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,306,319.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,307,920.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,539,13.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,601,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,605,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124780,606,0.060,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124781,203,0.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,204,0.220,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,205,6.250,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,208,27.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,269,5.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,291,0.960,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,301,11.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,303,0.610,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,306,187.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,307,202.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,539,2.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124781,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,203,0.950,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,204,0.080,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,205,27.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,208,115.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,269,24.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,291,1.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,301,14.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,303,0.590,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,306,185.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,307,928.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,539,21.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,601,0.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124782,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,203,0.850,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,204,0.290,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,205,3.530,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,208,17.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,269,2.580,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,291,0.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,301,10.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,303,0.390,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,306,173.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,307,9.990,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,401,44.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124783,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,203,4.210,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,204,0.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,205,19.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,208,91.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,269,11.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,291,4.690,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,301,37.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,303,0.520,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,306,822.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,307,55.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,601,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124784,606,0.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,203,1.320,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,205,5.770,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,208,29.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,269,3.360,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,291,1.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,301,15.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,303,0.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,306,309.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,307,456.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124785,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,203,0.870,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,204,0.230,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,205,3.760,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,208,20.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,269,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,291,0.930,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,301,10.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,303,0.310,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,306,187.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,307,12.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124786,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,203,1.770,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,204,0.150,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,205,9.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,208,45.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,269,5.180,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,291,2.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,301,19.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,303,0.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,306,343.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,307,393.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,539,0.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,601,0.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124787,606,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,203,1.770,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,204,0.150,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,205,9.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,208,45.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,269,5.180,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,291,2.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,301,19.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,303,0.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,306,343.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,307,393.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,539,0.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,601,0.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124788,606,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,203,0.860,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,204,0.230,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,205,3.710,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,208,17.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,269,2.580,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,291,0.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,301,9.930,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,303,0.310,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,306,189.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,307,101.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124789,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,203,2.580,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,204,0.190,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,205,11.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,208,54.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,269,6.670,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,291,3.140,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,301,22.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,303,1.160,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,306,500.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,307,26.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,601,0.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124790,606,0.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,203,1.680,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,204,0.140,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,205,25.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,208,108.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,269,20.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,291,2.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,301,17.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,303,0.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,306,309.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,307,1050.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,539,16.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,601,0.080,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124791,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,203,2.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,204,0.160,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,205,9.320,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,208,45.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,269,5.520,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,291,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,301,19.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,303,0.970,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,306,414.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,307,144.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,601,0.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124792,606,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,203,0.860,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,204,0.220,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,205,3.720,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,208,20.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,269,2.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,291,0.950,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,301,9.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,303,0.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,306,191.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,307,150.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124793,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,203,1.910,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,204,0.650,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,205,8.470,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,208,45.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,269,4.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,291,2.410,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,301,31.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,303,1.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,306,365.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,307,412.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124794,606,0.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,203,1.390,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,204,1.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,205,6.430,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,208,38.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,269,3.810,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,291,1.520,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,301,16.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,303,0.790,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,306,262.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,307,304.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,539,0.370,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,601,0.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124795,606,0.150,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,203,1.560,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,204,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,205,7.330,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,208,41.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,269,4.420,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,291,1.760,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,301,23.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,303,0.950,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,306,308.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,307,389.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,539,0.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,601,0.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124796,606,0.150,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,203,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,204,1.160,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,205,8.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,208,47.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,269,4.730,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,291,1.730,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,301,44.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,303,0.880,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,306,283.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,307,108.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,539,1.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124797,606,0.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,203,1.550,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,204,0.940,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,205,9.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,208,49.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,269,6.590,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,291,1.970,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,301,22.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,303,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,306,571.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,307,111.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,539,2.910,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124798,606,0.140,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,203,0.860,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,204,0.230,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,205,3.730,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,208,19.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,269,2.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,291,0.910,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,301,9.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,303,0.310,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,306,190.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,307,148.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124799,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,203,4.210,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,204,0.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,205,19.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,208,91.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,269,11.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,291,4.690,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,301,37.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,303,0.520,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,306,822.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,307,55.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,601,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124800,606,0.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,203,1.320,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,205,5.770,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,208,29.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,269,3.360,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,291,1.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,301,15.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,303,0.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,306,309.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,307,456.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124801,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,203,0.990,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,204,0.180,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,205,4.810,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,208,21.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,269,2.930,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,291,1.260,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,301,11.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,303,0.630,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,306,207.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,307,145.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124802,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,203,0.910,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,204,0.210,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,205,5.880,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,208,25.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,269,4.560,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,291,1.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,301,11.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,303,0.340,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,306,185.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,307,204.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,539,1.950,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124803,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,203,1.270,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,204,0.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,205,6.730,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,208,31.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,269,4.240,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,291,1.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,301,17.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,303,0.550,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,306,253.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,307,373.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,539,0.950,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124804,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,203,0.910,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,204,0.070,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,205,3.960,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,208,19.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,269,2.410,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,291,0.840,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,301,9.840,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,303,0.370,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,306,189.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,307,256.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124805,606,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,203,0.980,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,204,0.070,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,205,4.230,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,208,18.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,269,2.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,291,0.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,301,9.930,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,303,0.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,306,187.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,307,255.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124806,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,203,0.920,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,204,0.070,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,205,4.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,208,20.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,269,2.650,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,291,0.840,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,301,12.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,303,0.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,306,182.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,307,260.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,401,43.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124807,606,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,203,2.270,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,204,0.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,205,9.910,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,208,48.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,269,5.850,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,291,2.780,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,303,1.070,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,306,426.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,307,147.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,601,0.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124808,606,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,203,1.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,204,0.960,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,205,7.330,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,208,38.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,269,5.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,291,0.540,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,301,13.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,303,0.610,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,306,213.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,307,391.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,539,1.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124809,606,0.160,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,203,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,204,0.830,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,205,8.320,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,208,40.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,269,4.990,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,291,1.530,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,303,1.440,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,306,272.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,307,400.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,539,1.290,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124810,606,0.140,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,205,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,208,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,306,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,401,367.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124811,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,205,14.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,208,50.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,269,12.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,291,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,301,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,306,93.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,401,90.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124812,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,203,0.860,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,204,0.230,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,205,3.710,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,208,17.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,269,2.580,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,291,0.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,301,9.930,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,303,0.310,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,306,189.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,307,101.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124813,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124814,203,1.390,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,204,1.020,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,205,6.430,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,208,38.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,269,3.810,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,291,1.310,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,301,16.300,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,303,0.790,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,306,262.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,307,304.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,539,0.370,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,601,0.050,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,605,0.010,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124814,606,0.150,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,203,14.800,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,204,23.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,205,8.040,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,208,304.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,269,0.780,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,291,0.830,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,301,12.200,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,303,1.120,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,306,347.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,307,526.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,328,0.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,539,0.570,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,601,71.900,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,605,0.170,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124815,606,6.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,203,14.700,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,204,20.700,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,205,4.190,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,208,262.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,269,0.130,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,291,0.340,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,301,13.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,303,0.980,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,306,239.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,307,289.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,328,0.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,539,0.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,601,77.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,605,0.130,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124816,606,5.720,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124817,203,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,204,8.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,205,25.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,208,219.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,269,7.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,291,3.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,301,203.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,303,1.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,306,391.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,307,336.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,320,39.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,539,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,601,19.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124817,606,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,203,12.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,204,8.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,205,25.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,208,215.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,269,6.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,291,3.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,301,238.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,303,1.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,306,415.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,307,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,320,84.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,539,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,601,11.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124818,606,2.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,203,11.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,204,8.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,205,26.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,208,220.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,269,6.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,291,3.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,301,189.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,303,2.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,306,433.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,307,425.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,320,110.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,539,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,601,11.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124819,606,2.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,203,12.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,204,8.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,205,25.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,208,228.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,269,6.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,291,3.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,301,173.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,303,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,306,417.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,307,409.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,320,78.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,539,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,601,19.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124820,606,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124821,203,7.140,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,204,0.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,205,42.900,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,208,214.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,269,0.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,291,3.600,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,301,36.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,303,2.500,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,306,357.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,307,161.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,320,0.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,328,0.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,401,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,539,0.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,601,0.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,605,0.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124821,606,0.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124822,203,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,204,8.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,205,69.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,208,346.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,269,31.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,291,7.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,301,325.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,303,4.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,306,259.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,307,269.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,328,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,539,30.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124822,606,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,203,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,204,8.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,205,70.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,208,350.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,269,31.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,291,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,301,325.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,303,4.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,306,258.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,307,285.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,328,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,539,30.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124823,606,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,203,12.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,204,16.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,205,4.240,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,208,226.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,269,1.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,301,388.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,306,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,307,405.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,328,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,539,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,601,50.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124824,606,9.520,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,203,8.240,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,204,5.880,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,205,56.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,208,306.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,269,14.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,291,4.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,301,24.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,303,2.470,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,306,165.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,307,259.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,539,12.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124825,606,1.180,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,203,8.450,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,204,5.630,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,205,56.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,208,296.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,269,14.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,291,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,301,28.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,303,2.390,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,306,155.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,307,268.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,539,12.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124826,606,0.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124827,203,10.900,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,204,10.700,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,205,8.380,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,208,178.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,269,6.280,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,291,0.100,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,301,366.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,303,0.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,306,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,307,365.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,320,0.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,328,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,401,0.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,539,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,601,35.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,605,0.060,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124827,606,6.250,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124828,203,11.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,204,16.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,205,1.430,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,208,210.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,269,0.190,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,291,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,301,353.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,306,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,307,379.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,328,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,539,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,601,50.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124828,606,9.510,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,203,0.780,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,204,0.710,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,205,45.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,208,192.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,269,37.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,291,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,303,0.630,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,306,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,307,1070.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,320,63.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,328,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,401,2.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,539,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124829,606,0.070,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124830,203,12.100,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,204,8.510,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,205,22.700,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,208,213.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,269,2.130,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,291,0.700,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,301,241.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,303,1.700,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,306,227.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,307,489.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,320,26.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,328,0.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,401,0.900,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,539,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,601,14.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,605,0.000,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124830,606,2.130,'100g',6,3,'2024-12-19','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (124831,203,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,204,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,205,20.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,208,130.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,269,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,291,3.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,303,0.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,306,60.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,307,140.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,539,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124831,606,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,203,1.680,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,204,0.140,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,205,25.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,208,108.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,269,20.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,291,2.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,301,17.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,303,0.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,306,309.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,307,1050.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,539,16.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,601,0.080,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124832,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124833,203,20.300,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,204,17.500,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,205,2.290,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,208,248.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,269,0.420,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,291,0.250,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,301,12.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,303,1.020,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,306,283.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,307,440.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,328,0.120,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,539,0.380,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,601,107.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,605,0.160,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124833,606,5.020,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,203,16.800,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,204,16.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,205,18.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,208,285.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,269,0.920,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,291,3.610,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,301,32.500,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,303,2.180,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,306,703.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,307,518.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,328,0.090,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,539,0.540,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,601,26.500,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,605,0.160,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124834,606,3.050,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,203,19.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,204,9.460,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,205,12.800,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,208,212.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,269,0.800,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,291,1.350,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,301,11.900,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,303,1.370,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,306,615.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,307,428.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,328,0.020,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,539,0.480,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,601,45.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,605,0.090,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124835,606,1.760,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124836,203,11.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,204,16.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,205,68.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,208,464.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,269,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,291,5.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,301,112.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,303,4.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,306,250.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,307,731.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,328,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,601,12.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,605,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124836,606,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124837,203,21.300,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,204,14.400,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,205,0.300,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,208,216.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,269,0.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,291,0.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,301,6.830,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,303,0.640,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,306,328.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,307,306.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,328,0.130,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,401,0.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,539,0.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,601,98.200,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,605,0.140,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124837,606,4.010,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124838,203,20.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,204,11.200,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,205,14.800,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,208,237.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,269,0.270,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,291,2.110,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,301,18.200,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,303,1.650,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,306,400.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,307,420.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,328,0.020,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,401,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,539,0.220,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,601,45.800,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,605,0.110,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124838,606,2.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124839,203,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,204,7.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,205,28.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,208,225.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,269,7.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,291,2.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,301,238.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,303,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,306,238.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,307,475.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,320,37.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,539,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,601,68.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124839,606,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,203,0.840,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,204,0.290,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,205,3.510,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,207,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,208,16.900,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,255,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,269,2.560,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,291,0.400,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,301,11.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,303,0.390,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,306,174.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,307,255.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,320,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,328,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,401,44.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,539,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,601,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,605,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124840,606,0.020,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124841,203,1.770,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,204,3.980,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,205,18.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,208,115.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,269,13.300,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,291,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,301,57.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,303,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,306,80.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,307,40.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,320,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,401,80.500,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,539,10.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,601,18.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,605,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124841,606,2.650,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124842,203,1.770,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,204,3.980,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,205,18.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,208,115.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,269,13.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,301,57.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,306,80.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,307,40.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,401,80.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,539,10.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,601,18.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124842,606,2.650,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,203,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,204,5.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,205,75.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,208,354.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,269,30.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,306,119.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,307,238.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,539,29.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124843,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,203,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,204,5.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,205,75.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,208,354.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,269,30.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,306,119.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,307,238.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,539,29.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124844,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,203,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,204,5.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,205,75.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,208,354.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,269,30.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,306,119.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,307,238.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,539,29.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124845,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,203,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,204,5.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,205,75.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,208,354.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,269,30.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,306,119.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,307,238.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,539,29.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124846,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,203,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,204,5.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,205,75.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,208,354.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,269,30.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,306,119.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,307,238.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,539,29.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124847,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,203,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,204,5.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,205,75.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,208,354.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,269,30.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,306,119.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,307,238.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,539,29.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124848,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,203,1.080,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,205,27.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,208,114.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,269,23.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,291,1.330,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,301,16.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,303,0.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,306,220.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,307,931.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,539,20.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124849,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,205,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,208,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,306,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124850,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,203,5.720,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,204,3.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,205,10.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,208,90.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,269,4.830,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,291,1.930,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,301,44.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,303,1.310,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,306,258.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,307,166.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,539,2.210,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124851,606,0.410,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,203,2.140,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,204,0.160,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,205,9.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,208,45.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,269,5.520,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,291,2.620,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,301,20.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,303,1.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,306,415.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,307,141.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,601,0.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124852,606,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,203,2.140,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,204,0.160,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,205,9.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,208,45.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,269,5.520,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,291,2.620,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,301,20.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,303,1.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,306,415.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,307,141.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,601,0.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124853,606,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,203,0.950,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,204,0.080,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,205,27.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,208,115.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,269,24.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,291,1.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,301,14.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,303,0.590,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,306,185.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,307,928.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,539,21.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,601,0.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124854,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,203,1.630,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,204,0.650,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,205,8.330,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,208,44.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,269,5.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,291,2.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,301,20.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,303,0.780,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,306,310.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,307,373.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,539,1.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124855,606,0.060,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,203,1.630,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,204,0.650,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,205,8.330,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,208,44.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,269,5.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,291,2.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,301,20.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,303,0.780,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,306,310.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,307,373.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,539,1.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124856,606,0.060,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,203,1.630,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,204,0.650,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,205,8.330,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,208,44.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,269,5.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,291,2.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,301,20.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,303,0.780,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,306,310.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,307,373.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,539,1.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124857,606,0.060,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,205,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,208,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,306,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,401,367.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124858,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,203,1.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,204,0.960,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,205,7.330,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,208,38.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,269,5.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,291,0.540,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,301,13.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,303,0.610,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,306,213.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,307,391.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,539,1.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124859,606,0.160,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124860,203,1.270,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,204,0.090,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,205,7.930,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,208,36.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,269,5.560,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,291,1.580,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,301,12.500,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,303,0.750,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,306,237.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,307,61.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,539,2.330,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,601,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,605,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124860,606,0.020,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,203,1.270,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,204,0.090,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,205,7.930,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,208,36.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,269,5.560,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,291,1.580,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,301,12.500,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,303,0.750,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,306,237.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,307,61.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,539,2.330,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,601,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,605,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124861,606,0.020,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,203,1.270,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,204,0.490,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,205,7.350,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,208,37.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,269,4.520,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,291,1.580,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,301,15.800,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,303,0.670,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,306,240.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,307,110.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,539,1.350,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,601,0.060,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,605,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124862,606,0.080,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,203,1.250,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,204,0.290,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,205,7.440,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,208,36.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,269,4.650,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,291,1.520,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,301,13.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,303,0.590,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,306,240.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,307,110.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,539,1.480,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,601,0.060,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,605,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124863,606,0.050,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,203,19.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,204,12.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,205,6.190,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,208,216.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,269,1.760,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,291,1.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,301,57.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,303,2.590,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,306,460.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,307,362.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,539,1.390,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,601,48.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,605,0.120,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124864,606,5.150,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124865,203,11.700,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,204,8.180,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,205,30.100,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,208,241.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,269,7.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,291,2.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,301,69.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,303,2.070,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,306,243.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,307,358.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,401,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,539,7.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,601,25.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,605,0.300,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124865,606,3.580,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124866,203,14.300,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,204,7.830,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,205,4.140,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,208,144.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,269,1.940,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,291,0.250,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,301,4.720,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,303,0.820,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,306,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,307,439.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,328,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,401,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,539,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,601,68.200,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,605,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124866,606,3.030,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124867,203,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,204,8.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,205,69.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,208,346.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,269,31.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,291,7.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,301,325.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,303,4.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,306,259.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,307,269.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,328,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,539,30.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124867,606,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,203,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,204,8.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,205,69.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,208,346.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,269,31.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,291,7.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,301,325.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,303,4.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,306,259.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,307,269.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,328,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,539,30.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124868,606,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,203,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,204,8.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,205,70.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,208,350.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,269,31.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,291,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,301,325.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,303,4.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,306,258.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,307,285.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,328,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,539,30.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124869,606,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,203,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,204,8.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,205,70.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,208,350.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,269,31.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,291,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,301,325.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,303,4.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,306,258.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,307,285.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,328,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,539,30.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124870,606,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,203,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,204,8.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,205,69.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,208,349.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,269,31.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,291,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,301,325.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,303,4.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,306,258.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,307,322.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,328,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,539,30.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124871,606,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,203,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,204,8.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,205,69.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,208,349.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,269,31.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,291,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,301,325.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,303,4.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,306,258.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,307,322.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,328,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,539,30.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124872,606,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,203,23.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,204,7.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,205,10.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,208,187.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,269,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,291,2.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,301,52.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,303,4.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,306,269.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,307,669.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,539,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,601,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124873,606,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,203,13.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,204,8.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,205,21.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,208,200.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,269,2.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,291,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,301,48.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,303,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,306,617.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,307,389.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,539,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124874,606,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124875,203,18.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,204,24.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,205,0.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,208,292.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,269,0.010,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,291,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,301,5.930,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,303,1.680,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,306,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,307,151.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,328,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,401,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,539,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,601,69.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,605,0.090,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124875,606,9.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124876,203,20.100,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,204,14.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,205,0.170,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,208,221.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,269,0.010,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,291,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,301,5.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,303,1.840,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,306,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,307,310.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,328,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,539,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,601,71.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,605,0.140,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124876,606,6.090,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,203,14.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,204,19.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,205,12.600,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,208,278.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,269,10.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,291,1.100,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,301,44.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,303,1.480,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,306,377.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,307,707.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,401,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,539,5.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,601,25.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,605,0.110,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124877,606,6.690,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124878,203,19.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,204,15.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,205,13.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,208,255.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,269,7.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,301,548.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,303,0.190,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,306,291.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,307,1500.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,328,0.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,601,50.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,605,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124878,606,9.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,203,19.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,204,15.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,205,12.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,208,255.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,269,7.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,301,587.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,303,0.190,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,306,855.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,307,1010.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,328,0.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,601,50.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,605,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124879,606,9.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,203,17.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,204,30.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,205,6.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,208,357.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,269,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,301,546.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,303,0.230,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,306,189.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,307,1560.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,328,0.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,601,96.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,605,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124880,606,19.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,203,18.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,204,30.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,205,6.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,208,357.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,269,3.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,301,546.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,303,0.230,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,306,185.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,307,1600.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,328,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,601,94.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,605,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124881,606,18.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,203,18.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,204,30.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,205,6.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,208,357.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,269,3.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,301,546.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,303,0.230,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,306,185.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,307,1600.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,328,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,601,94.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,605,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124882,606,18.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124883,203,18.600,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,204,13.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,205,7.410,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,208,257.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,269,0.550,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,291,1.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,301,35.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,303,1.480,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,306,465.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,307,269.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,539,0.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,601,76.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,605,0.080,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124883,606,4.180,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,203,20.100,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,204,13.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,205,7.070,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,208,234.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,269,0.530,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,291,1.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,301,36.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,303,1.750,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,306,464.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,307,263.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,539,0.500,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,601,68.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,605,0.120,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124884,606,3.410,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124885,203,14.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,204,8.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,205,24.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,208,230.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,269,3.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,291,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,301,198.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,303,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,306,262.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,307,500.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,320,47.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,539,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,601,27.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124885,606,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,203,14.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,204,11.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,205,24.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,208,254.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,269,4.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,291,2.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,301,230.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,303,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,306,341.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,307,476.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,320,63.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,539,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,601,31.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124886,606,5.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124887,203,15.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,204,9.500,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,205,24.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,208,238.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,269,4.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,291,2.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,301,190.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,303,2.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,306,421.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,307,468.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,320,55.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,401,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,539,1.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,601,23.800,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,605,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124887,606,4.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124888,203,11.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,204,9.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,205,23.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,208,220.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,269,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,291,2.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,301,199.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,303,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,306,319.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,307,312.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,320,42.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,539,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,601,21.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124888,606,4.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124889,203,12.100,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,204,9.200,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,205,23.400,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,208,220.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,269,5.700,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,291,2.100,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,301,170.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,303,1.600,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,306,333.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,307,362.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,320,49.600,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,328,0.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,401,0.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,539,1.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,601,24.800,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,605,0.000,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124889,606,3.500,'100g',6,3,'2024-12-19','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124890,203,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,204,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,205,86.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,208,342.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,269,47.400,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,291,5.300,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,301,53.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,303,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,306,26.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,307,224.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,320,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,401,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,539,26.300,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,601,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124890,606,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124891,203,16.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,204,18.600,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,205,16.500,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,208,298.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,269,0.840,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,291,1.440,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,301,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,303,1.590,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,306,334.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,307,417.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,328,0.000,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,401,NULL,'100g',NULL,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,539,0.620,'100g',6,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,601,49.900,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,605,0.220,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124891,606,5.230,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124892,203,15.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,204,14.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,205,13.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,208,243.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,269,10.600,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,291,1.600,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,301,46.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,303,2.430,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,306,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,307,709.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,328,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,401,1.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,539,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,601,41.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,605,0.650,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124892,606,5.770,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124893,203,17.400,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,204,11.500,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,205,14.900,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,208,230.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,269,0.320,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,291,1.640,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,301,26.300,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,303,2.730,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,306,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,307,324.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,328,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,401,13.800,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,539,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,601,44.900,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,605,0.430,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124893,606,4.710,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,203,17.400,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,204,11.500,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,205,14.900,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,208,230.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,269,0.320,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,291,1.640,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,301,26.300,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,303,2.730,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,306,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,307,324.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,328,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,401,13.800,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,539,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,601,44.900,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,605,0.430,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124894,606,4.710,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124895,203,17.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,204,12.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,205,5.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,208,199.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,269,2.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,291,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,301,24.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,303,1.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,306,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,307,324.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,328,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,401,0.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,539,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,601,50.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,605,0.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124895,606,5.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124896,203,10.100,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,204,8.700,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,205,27.700,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,208,231.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,269,3.130,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,291,2.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,301,123.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,303,1.780,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,306,153.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,307,473.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,539,2.600,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,601,24.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,605,0.220,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124896,606,4.160,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,203,15.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,204,12.500,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,205,28.500,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,208,287.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,269,4.950,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,291,2.400,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,301,322.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,303,1.530,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,306,187.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,307,428.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,401,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,539,3.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,601,29.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,605,0.370,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124897,606,6.350,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124898,203,16.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,204,10.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,205,26.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,208,266.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,269,2.240,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,291,2.460,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,301,364.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,303,1.620,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,306,133.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,307,447.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,328,0.140,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,401,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,539,1.240,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,601,31.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,605,0.330,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124898,606,5.850,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,203,9.350,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,204,7.070,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,205,29.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,208,218.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,269,4.040,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,291,3.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,301,150.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,303,1.770,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,306,139.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,307,407.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,328,0.080,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,539,3.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,601,20.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,605,0.210,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124899,606,3.690,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124900,203,14.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,204,8.760,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,205,31.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,208,263.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,269,1.440,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,291,1.700,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,301,253.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,303,1.940,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,306,103.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,307,360.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,328,3.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,539,0.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,601,18.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,605,0.020,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124900,606,3.950,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124901,203,16.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,204,8.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,205,27.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,208,251.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,269,2.190,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,291,2.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,301,363.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,303,1.590,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,306,132.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,307,368.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,328,2.870,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,401,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,539,1.290,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,601,23.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,605,0.110,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124901,606,4.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124902,203,14.400,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,204,8.120,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,205,31.700,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,208,257.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,269,2.190,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,291,3.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,301,264.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,303,1.910,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,306,143.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,307,337.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,328,2.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,539,1.600,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,601,18.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,605,0.050,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124902,606,3.730,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,203,14.100,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,204,9.230,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,205,26.700,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,208,246.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,269,5.540,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,291,3.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,301,107.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,303,2.340,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,306,324.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,307,376.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,401,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,539,4.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,601,30.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,605,0.340,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124903,606,4.030,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124904,203,14.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,204,9.230,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,205,26.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,208,246.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,269,5.540,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,291,2.970,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,301,107.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,303,2.340,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,306,324.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,307,376.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,539,4.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,601,29.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,605,0.340,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124904,606,4.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,203,11.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,204,8.180,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,205,30.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,208,241.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,269,7.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,291,2.820,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,301,68.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,303,2.070,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,306,243.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,307,358.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,328,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,539,7.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,601,25.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,605,0.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124905,606,3.580,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,203,23.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,204,4.710,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,205,2.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,208,146.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,269,0.450,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,291,0.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,301,9.440,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,303,0.460,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,306,480.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,307,460.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,539,0.370,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,601,77.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,605,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124906,606,1.210,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124907,203,23.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,204,4.710,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,205,2.170,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,208,146.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,269,0.450,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,291,0.090,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,301,9.440,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,303,0.460,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,306,480.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,307,460.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,539,0.370,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,601,77.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,605,0.040,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124907,606,1.210,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124908,203,14.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,204,10.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,205,25.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,208,256.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,269,5.190,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,291,2.330,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,301,81.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,303,1.580,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,306,260.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,307,417.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,539,4.650,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,601,51.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,605,0.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124908,606,4.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124909,203,14.600,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,204,10.500,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,205,25.700,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,208,256.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,269,5.190,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,291,2.300,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,301,82.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,303,1.580,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,306,260.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,307,417.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,401,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,539,4.700,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,601,52.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,605,0.170,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124909,606,4.010,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,203,18.400,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,204,11.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,205,3.310,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,208,186.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,269,0.830,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,291,1.600,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,301,43.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,303,3.570,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,306,644.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,307,312.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,401,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,539,0.700,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,601,49.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,605,0.680,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124910,606,4.940,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124911,203,19.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,204,8.060,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,205,2.380,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,208,160.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,269,0.360,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,291,0.240,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,301,16.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,303,1.050,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,306,285.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,307,481.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,539,0.340,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,601,96.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,605,0.070,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124911,606,2.330,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124912,203,18.900,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,204,6.290,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,205,1.340,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,208,137.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,269,0.010,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,291,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,301,6.390,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,303,0.660,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,306,435.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,307,144.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,328,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,401,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,539,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,601,78.600,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,605,0.060,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124912,606,1.790,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,203,18.100,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,204,11.800,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,205,10.200,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,208,219.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,269,0.790,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,291,1.040,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,301,11.100,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,303,1.110,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,306,320.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,307,627.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,328,0.090,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,401,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,539,0.620,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,601,87.200,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,605,0.190,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124913,606,2.560,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124914,203,19.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,204,9.850,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,205,12.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,208,216.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,269,0.610,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,291,1.290,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,301,10.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,303,1.070,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,306,429.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,307,469.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,539,0.360,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,601,56.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,605,0.120,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124914,606,1.860,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124915,203,19.300,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,204,8.190,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,205,2.010,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,208,159.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,269,0.520,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,291,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,301,11.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,303,0.460,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,306,272.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,307,391.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,328,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,401,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,539,0.490,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,601,92.500,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,605,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124915,606,2.400,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124916,203,17.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,204,21.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,205,1.390,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,208,272.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,269,0.350,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,291,0.010,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,301,11.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,303,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,306,445.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,307,323.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,539,0.330,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,601,120.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,605,0.240,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124916,606,5.870,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124917,203,18.500,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,204,9.060,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,205,2.050,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,208,164.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,269,0.830,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,291,0.080,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,301,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,303,0.600,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,306,364.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,307,377.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,328,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,401,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,539,0.780,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,601,95.700,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,605,0.170,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124917,606,2.210,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124918,203,23.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,204,6.080,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,205,1.470,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,208,156.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,269,0.570,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,291,0.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,301,9.630,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,303,0.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,306,512.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,307,487.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,328,0.030,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,539,0.520,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,601,60.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,605,0.060,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124918,606,1.370,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124919,203,17.200,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,204,12.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,205,4.310,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,208,198.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,269,0.130,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,291,0.340,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,301,15.100,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,303,0.970,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,306,202.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,307,342.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,328,0.070,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,401,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,539,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,601,94.700,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,605,0.080,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124919,606,2.700,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124920,203,19.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,204,7.950,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,205,2.880,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,208,162.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,269,0.520,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,291,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,301,7.340,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,303,0.720,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,306,822.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,307,264.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,539,0.510,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,601,96.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,605,0.070,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124920,606,2.320,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,203,15.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,204,9.470,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,205,10.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,208,189.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,269,6.340,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,291,0.390,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,301,12.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,303,0.670,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,306,214.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,307,418.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,328,0.080,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,539,5.920,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,601,78.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,605,0.150,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124921,606,2.130,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,203,14.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,204,17.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,205,12.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,208,265.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,269,0.560,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,291,0.930,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,301,9.360,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,303,1.150,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,306,393.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,307,412.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,328,0.240,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,539,0.280,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,601,41.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,605,0.190,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124922,606,3.550,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,203,18.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,204,14.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,205,12.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,208,258.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,269,0.150,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,291,1.230,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,301,9.790,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,303,1.470,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,306,229.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,307,447.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,328,0.210,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,539,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,601,59.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,605,0.120,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124923,606,3.470,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,203,14.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,204,14.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,205,16.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,208,251.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,269,1.290,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,291,2.860,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,301,42.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,303,2.250,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,306,345.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,307,504.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,328,0.070,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,401,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,539,0.930,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,601,21.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,605,0.140,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124924,606,2.670,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,203,16.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,204,10.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,205,15.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,208,223.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,269,0.130,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,291,1.570,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,301,18.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,303,2.320,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,306,183.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,307,465.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,539,0.130,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,601,49.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,605,0.070,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124925,606,2.150,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,203,15.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,204,14.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,205,13.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,208,245.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,269,0.150,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,291,1.230,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,301,9.190,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,303,1.380,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,306,233.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,307,445.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,328,0.210,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,539,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,601,57.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,605,0.150,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124926,606,3.370,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,203,16.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,204,10.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,205,13.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,208,213.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,269,0.140,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,291,1.570,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,301,18.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,303,2.320,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,306,149.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,307,467.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,328,0.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,539,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,601,48.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,605,0.070,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124927,606,2.150,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,203,14.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,204,14.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,205,16.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,208,250.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,269,1.260,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,291,2.780,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,301,38.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,303,2.110,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,306,349.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,307,499.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,328,0.090,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,401,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,539,0.910,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,601,29.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,605,0.140,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124928,606,2.670,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,203,15.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,204,8.960,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,205,12.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,208,191.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,269,1.870,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,291,1.460,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,301,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,303,1.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,306,383.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,307,475.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,539,1.690,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,601,46.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,605,0.080,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124929,606,1.690,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,203,16.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,204,10.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,205,13.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,208,202.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,269,0.190,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,291,3.070,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,301,47.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,303,1.910,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,306,415.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,307,480.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,328,0.040,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,539,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,601,29.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,605,0.110,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124930,606,2.010,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,203,16.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,204,16.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,205,18.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,208,285.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,269,0.920,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,291,3.610,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,301,32.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,303,2.180,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,306,703.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,307,518.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,328,0.090,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,539,0.540,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,601,26.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,605,0.160,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124931,606,3.050,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,203,16.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,204,15.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,205,16.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,208,270.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,269,0.970,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,291,2.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,301,37.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,303,2.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,306,315.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,307,407.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,328,0.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,539,0.560,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,601,25.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,605,0.110,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124932,606,2.770,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,203,20.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,204,8.890,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,205,13.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,208,218.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,269,0.780,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,291,1.610,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,301,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,303,1.440,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,306,414.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,307,514.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,539,0.670,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,601,49.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,605,0.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124933,606,1.650,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,203,18.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,204,8.890,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,205,8.650,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,208,188.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,269,0.440,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,291,2.810,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,301,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,303,0.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,306,672.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,307,280.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,328,0.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,539,0.240,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,601,41.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,605,0.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124934,606,1.650,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,203,17.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,204,9.740,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,205,10.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,208,197.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,269,2.030,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,291,1.330,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,301,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,303,1.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,306,661.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,307,345.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,328,0.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,539,1.160,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,601,37.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,605,0.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124935,606,1.730,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124936,203,16.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,204,15.500,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,205,16.600,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,208,270.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,269,0.970,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,291,2.900,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,301,37.900,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,303,2.200,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,306,307.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,307,407.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,328,0.100,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,401,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,539,0.560,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,601,25.100,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,605,0.110,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124936,606,2.770,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,203,18.700,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,204,13.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,205,14.100,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,208,248.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,269,0.230,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,291,1.960,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,301,20.800,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,303,1.560,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,306,260.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,307,570.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,328,0.050,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,401,NULL,'100g',NULL,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,539,0.190,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,601,45.400,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,605,0.080,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124937,606,2.160,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124938,203,20.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,204,6.990,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,205,14.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,208,202.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,269,0.660,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,291,1.820,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,301,7.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,303,0.740,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,306,715.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,307,453.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,328,0.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,539,0.490,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,601,53.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,605,0.070,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124938,606,1.140,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,203,19.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,204,10.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,205,12.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,208,221.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,269,0.450,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,291,1.630,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,301,13.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,303,1.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,306,545.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,307,373.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,328,0.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,401,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,539,0.450,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,601,48.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,605,0.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124939,606,1.930,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124940,203,16.500,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,204,11.900,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,205,13.200,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,208,226.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,269,0.460,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,291,0.710,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,301,24.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,303,1.880,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,306,351.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,307,510.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,328,0.180,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,401,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,539,0.090,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,601,59.200,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,605,0.090,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124940,606,2.540,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124941,203,17.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,204,9.070,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,205,9.010,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,208,189.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,269,1.230,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,291,1.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,301,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,303,1.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,306,729.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,307,315.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,328,0.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,539,1.130,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,601,42.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,605,0.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124941,606,1.790,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,203,15.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,204,15.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,205,17.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,208,271.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,269,0.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,291,2.920,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,301,40.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,303,2.340,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,306,624.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,307,407.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,539,0.720,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,601,25.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,605,0.110,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124942,606,2.810,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,203,15.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,204,15.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,205,17.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,208,271.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,269,0.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,291,2.920,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,301,40.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,303,2.340,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,306,822.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,307,407.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,539,0.720,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,601,25.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,605,0.110,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124943,606,2.810,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,203,15.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,204,15.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,205,17.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,208,271.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,269,0.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,291,2.920,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,301,40.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,303,2.340,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,306,628.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,307,407.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,539,0.710,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,601,25.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,605,0.110,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124944,606,2.810,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,203,17.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,204,9.070,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,205,9.010,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,208,189.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,269,1.230,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,291,1.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,301,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,303,1.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,306,729.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,307,315.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,328,0.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,539,1.130,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,601,42.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,605,0.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124945,606,1.790,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,203,17.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,204,10.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,205,7.620,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,208,193.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,269,2.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,291,0.940,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,301,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,303,1.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,306,727.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,307,320.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,539,0.380,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,601,41.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,605,0.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124946,606,1.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,203,12.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,204,14.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,205,23.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,208,272.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,269,5.370,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,291,2.490,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,301,14.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,303,1.380,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,306,561.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,307,435.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,328,0.050,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,539,5.050,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,601,42.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,605,0.180,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124947,606,3.110,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,203,12.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,204,15.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,205,20.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,208,273.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,269,4.830,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,291,2.710,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,301,15.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,303,1.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,306,417.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,307,440.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,328,0.060,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,401,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,539,4.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,601,51.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,605,0.140,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124948,606,3.550,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,203,13.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,204,16.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,205,15.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,208,267.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,269,0.320,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,291,2.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,301,13.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,303,1.620,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,306,394.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,307,270.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,328,0.160,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,401,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,539,0.070,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,601,35.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,605,0.130,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124949,606,3.060,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,203,11.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,204,13.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,205,23.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,208,264.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,269,6.930,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,291,1.290,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,301,12.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,303,1.420,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,306,369.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,307,341.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,539,6.770,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,601,42.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,605,0.120,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124950,606,3.010,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,203,16.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,204,15.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,205,16.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,208,270.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,269,0.970,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,291,2.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,301,37.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,303,2.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,306,316.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,307,407.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,539,0.560,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,601,25.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,605,0.110,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124951,606,2.770,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124952,203,21.300,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,204,14.400,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,205,0.300,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,208,216.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,269,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,291,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,301,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,303,0.640,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,306,328.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,307,306.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,328,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,401,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,539,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,601,98.200,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,605,0.140,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124952,606,4.010,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,203,19.400,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,204,9.550,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,205,14.500,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,208,218.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,269,1.590,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,291,1.910,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,301,11.300,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,303,0.970,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,306,630.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,307,396.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,328,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,401,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,539,1.380,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,601,56.700,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,605,0.090,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124953,606,1.840,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124954,203,18.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,204,9.640,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,205,13.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,208,213.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,269,0.570,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,291,1.180,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,301,11.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,303,1.230,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,306,582.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,307,385.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,328,0.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,539,0.410,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,601,45.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,605,0.090,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124954,606,1.840,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124955,203,16.400,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,204,20.800,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,205,6.350,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,208,278.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,269,0.160,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,291,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,301,10.700,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,303,0.460,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,306,319.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,307,267.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,328,0.100,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,401,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,539,0.150,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,601,113.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,605,0.230,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124955,606,5.590,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124956,203,14.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,204,15.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,205,12.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,208,208.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,269,1.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,291,1.450,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,301,18.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,303,1.910,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,306,175.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,307,721.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,401,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,539,0.080,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,601,56.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,605,0.120,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124956,606,2.890,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,203,14.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,204,15.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,205,12.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,208,208.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,269,1.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,291,1.450,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,301,18.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,303,1.910,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,306,193.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,307,721.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,401,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,539,0.080,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,601,56.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,605,0.120,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124957,606,2.890,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124958,203,19.200,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,204,10.200,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,205,11.400,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,208,214.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,269,0.490,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,291,1.470,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,301,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,303,1.130,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,306,578.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,307,409.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,328,0.020,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,401,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,539,0.410,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,601,47.700,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,605,0.100,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124958,606,1.920,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124959,203,14.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,204,12.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,205,14.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,208,224.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,269,2.070,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,291,1.860,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,301,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,303,1.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,306,419.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,307,352.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,328,0.010,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,401,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,539,1.960,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,601,35.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,605,0.110,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124959,606,2.150,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,203,15.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,204,9.010,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,205,15.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,208,204.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,269,2.930,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,291,1.150,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,301,10.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,303,1.080,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,306,316.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,307,256.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,539,2.750,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,601,38.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,605,0.080,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124960,606,1.770,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,203,15.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,204,8.960,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,205,12.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,208,191.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,269,1.870,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,291,1.460,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,301,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,303,0.780,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,306,383.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,307,475.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,539,1.690,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,601,46.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,605,0.080,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124961,606,1.690,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124962,203,16.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,204,12.100,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,205,12.300,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,208,222.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,269,0.580,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,291,1.280,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,301,10.600,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,303,1.230,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,306,249.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,307,469.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,328,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,401,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,539,0.370,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,601,70.100,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,605,0.140,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124962,606,2.650,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124963,203,17.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,204,16.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,205,8.040,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,208,249.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,269,0.780,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,291,0.830,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,301,9.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,303,0.890,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,306,330.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,307,522.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,328,0.240,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,539,0.570,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,601,70.900,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,605,0.180,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124963,606,3.950,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,203,20.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,204,10.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,205,4.480,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,208,189.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,269,0.460,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,291,0.330,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,301,21.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,303,1.270,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,306,213.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,307,365.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,401,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,539,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,601,88.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,605,0.040,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124964,606,2.550,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124965,203,23.600,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,204,4.710,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,205,2.170,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,208,146.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,269,0.450,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,291,0.100,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,301,9.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,303,0.460,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,306,460.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,307,460.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,401,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,539,0.400,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,601,77.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,605,0.040,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124965,606,1.210,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,203,0.600,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,204,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,205,4.220,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,207,NULL,'100ml',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,208,18.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,255,NULL,'100ml',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,269,2.410,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,291,0.600,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,301,17.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,303,0.420,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,306,190.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,307,283.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,320,23.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,328,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,401,30.100,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,539,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,601,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,605,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124966,606,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,203,5.880,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,204,17.600,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,205,55.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,208,368.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,269,19.100,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,291,1.500,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,301,51.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,303,1.470,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,306,154.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,307,426.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,320,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,401,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,539,16.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,601,59.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124967,606,1.470,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,203,0.880,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,204,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,205,16.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,208,71.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,269,12.400,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,291,2.700,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,301,7.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,303,0.880,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,306,140.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,307,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,401,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,539,3.500,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,601,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124968,606,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124969,203,4.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,204,5.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,205,75.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,208,354.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,269,29.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,306,119.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,307,239.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,539,29.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124969,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,203,11.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,204,16.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,205,68.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,208,464.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,269,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,291,5.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,301,112.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,303,4.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,306,250.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,307,731.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,328,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,601,12.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,605,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124970,606,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,203,0.860,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,204,0.220,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,205,3.740,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,208,20.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,269,2.580,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,291,0.990,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,301,9.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,303,0.290,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,306,190.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,307,149.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124971,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124972,203,0.860,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,204,0.220,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,205,3.740,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,208,20.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,269,2.580,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,291,0.990,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,301,9.890,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,303,0.290,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,306,190.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,307,149.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,539,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,601,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,605,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124972,606,0.030,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,203,1.010,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,204,0.220,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,205,5.530,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,208,27.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,269,2.190,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,291,1.330,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,301,10.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,303,0.410,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,306,164.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,307,221.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,539,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,601,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,605,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124973,606,0.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,203,1.280,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,204,0.090,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,205,23.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,208,102.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,269,20.400,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,291,1.560,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,301,18.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,303,0.850,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,306,253.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,307,914.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,539,17.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,601,0.060,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,605,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124974,606,0.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124975,203,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,204,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,205,13.200,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,207,NULL,'100ml',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,208,54.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,255,NULL,'100ml',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,269,11.800,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,291,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,301,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,303,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,306,122.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,307,5.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,320,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,328,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,401,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,539,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,601,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,605,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124975,606,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124976,203,8.820,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,204,10.300,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,205,50.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,208,324.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,269,5.880,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,291,5.900,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,301,29.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,303,2.650,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,306,176.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,307,250.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,320,118.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,328,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,401,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,539,5.900,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,601,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,605,0.000,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124976,606,2.940,'100g',6,3,'2024-11-14','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (124977,203,0.860,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,204,0.220,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,205,3.720,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,208,20.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,269,2.570,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,291,0.950,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,301,9.890,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,303,0.300,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,306,191.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,307,150.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,539,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,601,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,605,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124977,606,0.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,203,1.700,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,204,0.120,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,205,7.820,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,208,37.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,269,4.540,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,291,1.890,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,301,16.500,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,303,0.870,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,306,341.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,307,21.200,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,539,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,601,0.320,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,605,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124978,606,0.040,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,203,1.320,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,204,0.100,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,205,5.770,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,208,29.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,269,3.360,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,291,1.640,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,301,15.800,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,303,0.600,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,306,309.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,307,456.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,328,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,539,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,601,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,605,0.000,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124979,606,0.020,'100g',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124980,203,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,204,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,205,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,208,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,269,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,291,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,301,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,303,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,306,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,307,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,401,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,539,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,601,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124980,606,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124981,203,0.960,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,204,0.190,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,205,29.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,208,128.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,269,25.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,291,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,301,12.700,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,303,0.380,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,306,479.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,307,223.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,539,23.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,601,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,605,0.010,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124981,606,0.020,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124982,203,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,204,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,205,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,208,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,269,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,291,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,301,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,303,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,306,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,307,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,401,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,539,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,601,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124982,606,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124983,203,3.920,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,204,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,205,18.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,208,82.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,269,11.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,301,37.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,303,1.650,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,306,1010.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,307,67.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124983,606,0.080,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,203,7.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,204,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,205,87.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,208,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,269,22.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,291,8.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,301,19.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,306,278.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,307,601.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,539,21.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124984,606,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,203,7.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,204,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,205,87.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,208,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,269,22.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,291,8.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,301,19.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,306,278.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,307,601.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,539,21.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124985,606,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124986,203,6.980,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,204,14.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,205,67.400,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,208,395.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,269,30.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,291,4.700,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,301,23.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,303,3.720,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,306,349.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,307,81.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,401,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,539,27.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,601,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124986,606,3.490,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,203,3.970,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,204,1.190,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,205,13.500,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,207,NULL,'100ml',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,208,79.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,255,NULL,'100ml',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,269,3.170,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,291,4.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,301,56.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,303,0.790,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,306,619.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,307,325.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,320,159.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,328,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,401,NULL,'100ml',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,539,0.800,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,601,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,605,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124987,606,0.000,'100ml',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (124988,203,1.610,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,204,2.020,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,205,7.260,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,207,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,208,56.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,255,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,269,0.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,291,0.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,301,8.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,303,0.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,306,411.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,307,315.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,320,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,328,0.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,401,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,539,0.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,601,4.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,605,0.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124988,606,0.400,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,203,1.610,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,204,1.610,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,205,8.060,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,207,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,208,56.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,255,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,269,1.610,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,291,0.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,301,81.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,303,0.240,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,306,387.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,307,315.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,320,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,328,0.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,401,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,539,0.800,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,601,0.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,605,0.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124989,606,0.400,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,203,1.610,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,204,0.810,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,205,14.500,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,207,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,208,73.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,255,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,269,8.060,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,291,0.800,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,301,8.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,303,0.320,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,306,185.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,307,315.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,320,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,328,0.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,401,8.900,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,539,5.600,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,601,0.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,605,0.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124990,606,0.000,'100ml',6,3,'2024-11-14','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124991,203,2.580,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,204,0.190,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,205,11.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,208,54.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,269,6.670,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,291,3.140,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,301,22.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,303,1.160,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,306,500.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,307,26.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,601,0.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124991,606,0.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,203,1.910,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,204,0.650,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,205,8.470,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,208,45.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,269,4.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,291,2.410,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,301,31.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,303,1.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,306,365.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,307,412.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124992,606,0.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,203,1.320,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,205,5.770,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,208,29.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,269,3.360,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,291,1.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,301,15.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,303,0.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,306,309.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,307,456.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124993,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,203,1.660,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,204,0.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,205,27.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,208,115.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,269,23.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,291,2.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,301,25.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,303,0.860,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,306,335.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,307,902.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,539,19.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124994,606,0.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,203,2.580,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,204,0.190,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,205,11.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,208,54.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,269,6.670,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,291,3.140,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,301,22.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,303,1.160,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,306,500.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,307,26.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,601,0.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124995,606,0.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124996,203,1.240,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,204,0.980,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,205,33.500,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,208,144.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,269,29.900,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,291,1.020,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,301,13.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,303,0.540,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,306,161.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,307,200.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,539,27.900,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,601,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,605,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124996,606,0.090,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (124997,203,0.990,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,204,0.180,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,205,4.370,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,208,20.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,269,2.830,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,291,1.320,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,301,11.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,303,0.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,306,211.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,307,156.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124997,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,203,1.310,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,204,0.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,205,23.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,208,96.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,269,21.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,291,1.620,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,301,18.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,303,0.740,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,306,268.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,307,917.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,539,17.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124998,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,203,1.310,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,204,0.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,205,23.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,208,96.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,269,21.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,291,1.620,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,301,18.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,303,0.740,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,306,268.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,307,917.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,539,17.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (124999,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,203,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,204,0.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,205,27.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,208,114.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,269,23.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,291,1.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,301,16.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,303,0.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,306,224.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,307,915.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,539,20.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125000,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,203,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,204,0.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,205,27.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,208,114.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,269,23.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,291,1.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,301,16.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,303,0.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,306,224.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,307,915.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,539,20.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125001,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,203,0.960,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,204,0.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,205,23.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,208,97.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,269,20.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,291,1.180,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,301,15.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,303,0.590,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,306,196.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,307,923.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,539,17.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125002,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,203,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,205,27.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,208,113.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,269,23.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,291,1.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,301,16.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,303,0.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,306,225.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,307,923.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,539,20.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125003,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,203,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,205,27.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,208,113.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,269,23.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,291,1.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,301,16.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,303,0.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,306,225.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,307,923.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,539,20.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125004,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,203,1.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,205,27.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,208,115.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,269,23.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,291,1.360,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,301,16.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,303,0.650,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,306,226.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,307,910.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125005,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,203,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,205,27.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,208,113.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,269,23.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,291,1.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,301,16.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,303,0.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,306,225.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,307,923.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,539,20.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125006,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,203,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,204,0.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,205,27.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,208,112.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,269,23.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,291,1.220,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,301,15.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,303,0.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,306,204.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,307,914.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,539,20.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125007,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125008,203,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,204,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,205,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,208,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,269,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,291,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,301,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,303,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,306,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,307,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,401,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,539,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,601,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125008,606,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,203,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,204,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,205,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,208,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,269,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,291,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,301,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,303,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,306,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,307,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,320,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,401,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,539,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,601,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125009,606,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125010,203,0.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,204,0.220,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,205,6.250,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,208,27.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,269,5.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,291,0.960,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,301,11.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,303,0.610,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,306,187.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,307,202.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,539,2.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125010,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,203,0.910,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,204,0.070,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,205,3.960,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,208,19.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,269,2.410,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,291,0.840,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,301,9.580,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,303,0.360,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,306,189.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,307,255.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,401,44.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125011,606,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,203,1.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,204,0.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,205,7.820,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,208,37.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,269,4.540,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,291,1.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,301,16.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,303,0.870,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,306,341.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,307,21.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,601,0.320,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125012,606,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,203,1.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,204,0.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,205,7.820,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,208,37.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,269,4.540,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,291,1.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,301,16.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,303,0.870,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,306,341.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,307,21.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,601,0.320,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125013,606,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,203,1.080,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,204,0.180,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,205,4.750,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,208,22.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,269,3.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,291,1.420,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,301,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,303,0.390,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,306,228.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,307,172.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125014,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,203,1.080,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,204,0.180,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,205,4.750,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,208,22.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,269,3.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,291,1.420,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,301,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,303,0.390,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,306,228.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,307,172.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125015,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,203,0.990,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,204,0.180,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,205,4.370,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,208,20.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,269,2.830,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,291,1.320,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,301,11.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,303,0.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,306,211.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,307,156.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125016,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,203,0.860,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,204,0.230,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,205,3.730,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,208,19.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,269,2.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,291,0.910,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,301,9.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,303,0.310,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,306,190.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,307,148.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125017,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,203,1.550,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,204,0.160,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,205,11.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,208,50.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,269,8.480,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,291,2.190,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,301,17.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,303,0.770,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,306,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,307,592.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,539,4.940,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,601,0.080,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125018,606,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,203,0.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,204,0.220,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,205,6.250,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,208,27.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,269,5.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,291,0.960,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,301,11.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,303,0.610,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,306,187.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,307,202.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,539,2.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125019,606,0.030,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,203,1.270,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,204,0.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,205,6.730,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,208,31.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,269,4.240,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,291,1.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,301,17.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,303,0.550,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,306,253.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,307,373.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,539,0.950,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125020,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,203,0.910,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,204,0.070,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,205,3.960,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,208,19.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,269,2.410,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,291,0.840,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,301,9.840,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,303,0.370,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,306,189.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,307,256.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125021,606,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,203,0.980,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,204,0.070,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,205,4.230,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,208,18.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,269,2.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,291,0.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,301,9.930,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,303,0.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,306,187.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,307,255.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125022,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,203,0.920,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,204,0.070,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,205,4.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,208,20.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,269,2.650,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,291,0.840,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,301,12.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,303,0.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,306,182.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,307,260.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,401,43.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,605,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125023,606,0.010,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,203,1.770,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,204,0.150,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,205,9.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,208,45.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,269,5.180,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,291,2.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,301,19.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,303,0.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,306,343.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,307,393.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,539,0.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,601,0.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125024,606,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,203,2.260,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,204,0.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,205,9.880,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,208,47.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,269,5.850,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,291,2.760,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,301,20.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,303,1.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,306,434.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,307,142.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,601,0.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125025,606,0.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125026,203,0.860,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,204,0.230,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,205,3.700,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,208,19.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,269,2.570,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,291,0.910,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,301,9.900,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,303,0.310,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,306,190.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,307,148.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,539,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,601,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,605,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125026,606,0.020,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125027,203,0.860,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,204,0.220,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,205,3.720,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,208,20.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,269,2.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,291,0.950,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,301,9.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,303,0.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,306,191.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,307,150.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125027,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125028,203,11.600,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,204,10.100,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,205,21.700,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,208,232.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,269,2.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,291,1.400,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,301,261.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,303,1.740,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,306,232.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,307,464.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,320,52.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,539,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,601,14.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125028,606,3.620,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,203,12.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,204,6.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,205,25.300,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,208,213.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,269,2.670,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,291,4.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,301,173.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,303,2.130,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,306,347.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,307,440.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,320,24.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,539,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,601,13.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125029,606,2.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,203,12.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,204,6.820,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,205,25.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,208,220.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,269,3.030,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,291,3.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,301,220.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,303,1.890,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,306,333.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,307,462.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,320,68.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,539,0.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,601,19.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125030,606,3.410,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,203,12.400,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,204,6.980,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,205,26.400,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,208,217.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,269,3.100,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,291,3.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,301,233.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,303,2.020,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,306,357.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,307,450.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,320,42.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,539,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,601,12.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125031,606,2.330,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,203,11.600,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,204,6.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,205,24.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,208,202.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,269,3.100,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,291,3.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,301,178.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,303,2.020,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,306,349.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,307,465.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,320,28.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,539,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,601,12.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125032,606,1.940,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125033,203,20.100,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,204,14.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,205,0.170,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,208,221.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,269,0.010,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,291,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,301,5.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,303,1.840,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,306,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,307,310.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,328,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,401,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,539,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,601,71.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,605,0.140,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125033,606,6.090,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125034,203,14.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,204,8.090,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,205,22.100,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,208,228.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,269,2.940,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,291,2.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,301,265.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,303,1.690,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,306,228.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,307,537.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,320,99.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,539,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,601,29.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125034,606,4.410,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,203,16.400,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,204,8.180,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,205,25.400,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,208,236.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,269,3.640,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,291,1.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,301,436.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,303,1.820,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,306,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,307,364.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,320,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,539,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,601,9.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125035,606,2.730,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,203,13.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,204,7.350,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,205,22.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,208,213.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,269,2.940,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,291,2.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,301,346.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,303,1.690,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,306,338.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,307,331.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,320,26.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,401,0.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,539,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,601,11.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125036,606,2.570,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,203,13.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,204,7.350,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,205,22.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,208,213.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,269,2.940,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,291,2.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,301,309.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,303,1.840,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,306,346.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,307,360.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,320,26.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,401,0.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,539,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,601,15.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125037,606,2.570,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,203,13.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,204,7.890,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,205,27.200,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,208,237.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,269,2.630,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,291,3.500,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,301,386.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,303,1.750,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,306,325.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,307,465.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,320,32.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,539,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,601,9.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125038,606,2.630,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,203,11.700,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,204,8.030,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,205,24.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,208,219.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,269,2.920,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,291,2.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,301,263.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,303,1.750,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,306,314.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,307,482.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,320,39.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,401,0.900,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,539,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,601,11.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125039,606,2.550,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,203,13.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,204,7.650,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,205,26.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,208,229.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,269,3.060,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,291,3.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,301,206.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,303,2.060,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,306,359.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,307,551.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,320,55.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,539,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,601,19.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125040,606,3.440,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,203,12.700,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,204,9.860,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,205,21.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,208,225.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,269,2.820,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,291,2.100,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,301,289.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,303,1.550,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,306,218.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,307,521.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,320,95.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,401,0.800,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,539,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,601,25.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125041,606,4.930,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,203,11.400,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,204,10.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,205,22.100,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,207,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,208,221.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,255,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,269,2.860,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,291,2.100,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,301,279.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,303,1.790,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,306,236.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,307,471.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,320,51.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,328,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,401,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,539,NULL,'100g',NULL,3,'2024-12-12','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,601,14.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,605,0.000,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125042,606,3.210,'100g',6,3,'2024-11-14','2024-11-14');
INSERT INTO `cndb_nutval` VALUES (125043,203,14.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,204,4.510,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,205,23.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,208,188.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,269,3.010,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,291,3.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,301,256.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,303,1.880,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,306,406.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,307,391.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,320,14.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,401,1.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,539,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,601,11.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125043,606,1.500,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,203,14.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,204,3.760,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,205,23.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,208,188.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,269,3.010,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,291,3.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,301,323.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,303,1.730,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,306,406.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,307,338.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,320,14.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,401,1.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,539,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,601,8.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125044,606,1.880,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125045,203,14.300,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,204,8.700,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,205,24.600,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,208,230.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,269,3.200,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,291,1.600,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,301,198.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,303,1.800,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,306,262.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,307,500.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,320,47.600,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,328,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,401,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,539,1.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,601,27.800,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,605,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125045,606,4.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125046,203,2.380,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,204,0.400,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,205,13.100,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,208,67.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,269,4.760,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,291,1.200,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,301,12.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,303,0.600,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,306,107.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,307,238.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,320,40.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,401,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,539,2.400,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,601,2.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125046,606,0.200,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,203,12.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,204,6.340,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,205,23.200,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,208,197.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,269,2.110,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,291,2.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,301,197.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,303,1.690,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,306,317.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,307,458.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,320,25.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,401,0.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,539,0.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,601,14.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125047,606,1.760,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,203,14.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,204,6.020,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,205,23.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,208,203.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,269,3.010,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,291,3.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,301,263.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,303,2.030,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,306,421.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,307,474.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,320,14.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,401,1.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,539,1.500,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,601,15.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125048,606,2.260,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125049,203,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,204,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,205,10.900,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,208,39.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,269,9.380,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,291,0.800,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,301,4.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,303,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,306,70.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,307,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,320,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,328,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,401,46.900,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,539,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,601,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,605,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125049,606,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125050,203,7.060,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,204,10.600,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,205,58.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,208,365.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,269,24.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,291,4.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,301,59.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,303,2.350,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,306,159.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,307,147.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,401,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,539,24.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,601,12.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125050,606,2.940,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125051,203,8.110,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,204,9.460,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,205,48.600,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,208,324.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,269,8.110,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,291,5.400,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,301,54.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,303,2.700,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,306,216.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,307,324.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,328,0.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,539,5.400,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,601,0.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,605,0.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125051,606,2.700,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125052,203,8.770,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,204,8.770,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,205,47.400,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,208,316.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,269,7.020,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,291,5.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,301,35.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,303,2.810,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,306,211.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,307,333.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,401,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,539,5.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,601,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125052,606,2.630,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,203,9.190,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,204,10.100,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,205,16.500,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,208,197.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,269,2.020,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,291,1.100,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,301,218.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,303,0.740,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,306,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,307,340.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,320,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,328,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,401,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,539,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,601,29.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,605,0.050,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125053,606,5.760,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125054,203,7.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,204,13.200,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,205,76.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,208,450.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,269,23.200,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,291,4.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,301,25.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,303,3.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,306,201.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,307,295.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,539,23.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,601,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,605,0.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125054,606,4.800,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125055,203,7.840,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,204,2.940,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,205,19.600,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,208,216.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,269,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,291,3.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,301,16.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,303,1.960,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,306,157.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,307,451.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,320,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,401,4.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,539,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,601,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125055,606,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,203,14.600,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,204,13.400,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,205,19.500,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,208,244.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,269,6.100,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,291,1.200,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,301,159.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,303,0.850,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,306,293.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,307,585.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,401,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,539,4.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,601,37.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125056,606,4.270,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125057,203,0.010,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,204,0.000,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,205,0.570,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,207,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,208,2.000,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,255,NULL,'100ml',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,269,0.410,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,291,0.000,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,301,0.000,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,303,0.000,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,306,5.000,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,307,0.000,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,320,0.000,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,328,0.000,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,401,0.800,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,539,0.000,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,601,0.000,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,605,0.000,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125057,606,0.000,'100ml',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125058,203,12.100,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,204,6.820,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,205,25.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,208,212.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,269,3.030,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,291,3.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,301,235.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,303,1.970,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,306,348.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,307,462.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,320,41.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,401,0.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,539,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,601,11.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125058,606,2.270,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,203,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,204,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,205,10.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,208,47.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,269,9.380,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,291,0.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,301,4.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,303,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,306,70.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,307,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,320,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,401,70.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,539,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,601,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125059,606,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,203,14.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,204,21.400,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,205,7.140,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,208,286.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,269,7.140,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,291,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,301,496.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,303,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,306,250.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,307,1430.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,401,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,539,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,601,71.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125060,606,12.500,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,203,12.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,204,6.820,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,205,25.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,208,212.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,269,3.030,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,291,3.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,301,227.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,303,1.890,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,306,333.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,307,470.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,320,68.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,401,0.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,539,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,601,19.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125061,606,3.410,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,203,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,204,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,205,10.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,208,39.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,269,9.380,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,291,0.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,301,4.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,303,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,306,70.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,307,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,320,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,401,46.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,539,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,601,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125062,606,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125063,203,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,204,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,205,10.900,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,208,39.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,269,9.380,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,291,0.800,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,301,4.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,303,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,306,70.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,307,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,320,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,328,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,401,86.700,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,539,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,601,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,605,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125063,606,0.000,'100g',6,3,'2024-10-31','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125064,203,0.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,204,0.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,205,10.900,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,208,47.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,269,9.380,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,291,0.800,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,301,4.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,303,0.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,306,70.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,307,0.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,320,0.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,328,0.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,401,46.900,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,539,0.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,601,0.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,605,0.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125064,606,0.000,'100g',6,3,'2024-10-31','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125065,203,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,204,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,205,13.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,208,47.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,269,11.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,291,0.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,301,4.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,303,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,306,70.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,307,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,320,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,401,70.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,539,2.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,601,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125065,606,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,203,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,204,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,205,11.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,208,47.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,269,9.380,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,291,0.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,301,4.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,303,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,306,70.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,307,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,320,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,401,46.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,539,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,601,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125066,606,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,203,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,204,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,205,10.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,208,39.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,269,9.380,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,291,0.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,301,4.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,303,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,306,70.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,307,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,320,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,401,46.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,539,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,601,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125067,606,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,203,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,204,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,205,10.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,208,47.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,269,9.380,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,291,0.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,301,4.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,303,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,306,74.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,307,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,320,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,401,86700.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,539,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,601,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125068,606,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,203,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,204,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,205,11.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,208,39.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,269,9.380,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,291,0.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,301,4.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,303,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,306,70.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,307,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,320,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,401,46.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,539,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,601,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125069,606,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,203,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,204,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,205,10.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,208,39.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,269,9.380,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,291,0.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,301,4.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,303,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,306,70.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,307,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,320,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,401,46.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,539,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,601,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125070,606,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125071,203,0.850,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,204,0.290,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,205,3.530,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,208,17.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,269,2.580,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,291,0.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,301,10.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,303,0.390,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,306,173.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,307,9.990,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,401,44.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125071,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,203,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,204,9.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,205,67.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,208,359.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,269,33.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,291,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,301,351.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,303,4.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,306,242.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,307,308.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,328,5.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,539,32.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125072,606,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,203,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,204,9.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,205,67.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,208,359.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,269,33.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,291,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,301,351.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,303,4.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,306,242.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,307,308.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,328,5.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,539,32.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125073,606,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,203,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,204,9.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,205,68.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,208,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,269,33.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,291,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,301,351.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,303,4.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,306,241.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,307,364.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,328,5.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,539,32.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125074,606,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,203,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,204,9.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,205,68.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,208,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,269,33.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,291,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,301,351.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,303,4.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,306,241.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,307,364.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,328,5.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,539,32.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125075,606,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,203,21.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,204,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,205,8.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,208,141.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,269,1.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,291,3.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,301,82.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,303,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,306,258.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,307,573.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,539,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125076,606,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,203,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,204,9.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,205,67.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,208,359.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,269,33.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,291,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,301,351.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,303,4.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,306,242.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,307,308.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,328,5.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,539,32.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125077,606,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,203,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,204,9.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,205,68.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,208,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,269,33.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,291,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,301,351.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,303,4.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,306,241.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,307,364.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,328,5.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,539,32.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125078,606,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125079,203,14.600,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,204,12.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,205,25.400,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,208,273.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,269,3.640,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,291,1.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,301,364.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,303,1.640,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,306,182.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,307,564.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,320,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,401,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,539,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,601,36.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125079,606,6.360,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,203,13.600,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,204,7.580,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,205,25.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,208,220.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,269,3.030,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,291,3.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,301,189.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,303,2.050,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,306,348.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,307,545.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,320,55.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,401,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,539,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,601,19.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125080,606,3.410,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,203,12.400,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,204,7.750,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,205,25.600,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,208,217.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,269,3.100,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,291,3.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,301,202.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,303,2.170,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,306,364.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,307,535.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,320,42.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,401,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,539,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,601,12.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125081,606,2.710,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,203,12.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,204,10.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,205,33.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,208,277.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,269,9.230,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,291,1.500,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,301,292.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,303,1.690,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,306,169.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,307,477.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,320,55.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,401,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,539,9.200,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,601,15.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125082,606,3.850,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,203,12.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,204,6.770,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,205,25.600,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,208,211.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,269,3.010,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,291,3.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,301,248.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,303,1.950,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,306,451.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,307,301.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,320,41.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,401,0.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,539,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,601,11.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125083,606,2.260,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,203,12.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,204,7.760,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,205,25.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,208,224.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,269,2.590,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,291,3.400,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,301,224.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,303,1.980,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,306,328.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,307,466.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,320,31.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,401,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,539,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,601,13.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125084,606,2.590,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,203,14.600,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,204,12.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,205,25.400,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,208,273.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,269,1.820,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,291,1.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,301,382.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,303,1.820,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,306,200.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,307,436.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,320,65.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,401,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,539,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,601,18.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125085,606,4.550,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,203,13.200,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,204,9.560,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,205,22.100,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,208,228.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,269,2.940,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,291,2.200,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,301,301.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,303,1.540,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,306,213.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,307,500.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,320,99.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,401,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,539,0.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,601,26.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125086,606,5.150,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,203,11.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,204,9.490,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,205,25.600,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,208,234.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,269,2.920,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,291,0.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,301,321.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,303,1.820,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,306,204.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,307,533.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,320,53.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,401,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,539,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,601,15.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125087,606,3.280,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,203,11.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,204,9.490,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,205,23.400,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,208,226.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,269,2.920,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,291,2.200,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,301,299.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,303,1.750,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,306,234.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,307,467.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,320,53.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,401,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,539,0.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,601,15.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125088,606,3.280,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,203,11.400,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,204,10.600,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,205,23.400,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,208,234.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,269,2.840,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,291,0.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,301,305.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,303,1.770,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,306,220.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,307,518.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,320,38.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,401,0.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,539,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,601,11.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125089,606,3.190,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125090,203,12.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,204,9.030,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,205,25.700,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,207,1.900,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,208,234.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,269,1.190,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,291,3.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,301,150.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,303,2.190,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,306,235.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,307,364.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,320,245.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,328,1.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,401,0.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,539,0.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,601,46.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125090,606,3.610,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,203,6.900,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,204,8.150,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,205,19.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,207,1.680,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,208,180.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,269,0.860,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,291,1.700,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,301,24.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,303,0.770,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,306,171.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,307,519.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,320,213.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,401,2.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,539,0.200,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,601,28.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125091,606,2.930,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,203,6.900,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,204,8.150,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,205,19.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,207,1.670,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,208,180.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,269,0.850,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,291,1.700,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,301,24.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,303,0.780,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,306,171.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,307,519.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,320,213.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,401,2.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,539,0.200,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,601,28.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125092,606,2.930,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,203,6.720,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,204,9.340,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,205,18.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,207,1.740,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,208,183.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,269,0.830,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,291,1.700,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,301,24.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,303,0.750,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,306,162.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,307,502.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,320,186.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,401,2.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,539,0.200,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,601,23.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125093,606,1.580,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,203,6.900,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,204,8.150,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,205,19.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,207,1.680,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,208,180.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,269,0.860,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,291,1.700,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,301,24.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,303,0.770,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,306,171.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,307,519.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,320,213.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,401,2.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,539,0.200,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,601,28.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125094,606,2.930,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,203,6.050,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,204,7.030,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,205,16.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,207,1.550,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,208,183.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,269,0.370,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,291,1.200,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,301,20.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,303,0.990,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,306,136.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,307,458.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,320,1070.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,401,0.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,539,0.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,601,17.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125095,606,2.700,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,203,7.560,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,204,8.780,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,205,20.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,207,1.940,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,208,193.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,269,0.460,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,291,1.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,301,26.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,303,1.230,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,306,170.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,307,572.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,320,1340.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,401,0.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,539,0.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,601,22.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125096,606,3.380,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,203,7.550,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,204,8.780,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,205,20.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,207,1.940,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,208,193.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,269,0.460,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,291,1.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,301,26.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,303,1.230,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,306,170.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,307,572.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,320,1340.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,401,0.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,539,0.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,601,22.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125097,606,3.370,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,203,7.560,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,204,8.780,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,205,20.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,207,1.940,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,208,193.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,269,0.460,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,291,1.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,301,26.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,303,1.230,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,306,170.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,307,572.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,320,1340.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,401,0.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,539,0.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,601,22.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125098,606,3.380,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,203,8.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,204,11.700,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,205,22.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,207,2.170,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,208,193.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,269,1.040,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,291,2.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,301,30.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,303,0.930,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,306,203.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,307,628.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,320,233.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,401,2.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,539,0.200,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,601,29.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125099,606,1.980,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,203,7.030,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,204,9.520,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,205,18.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,207,1.650,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,208,193.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,269,0.470,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,291,1.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,301,23.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,303,0.920,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,306,170.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,307,525.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,320,1200.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,401,0.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,539,0.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,601,16.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125100,606,1.750,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,203,11.200,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,204,9.470,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,205,18.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,207,1.330,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,208,203.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,269,1.230,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,291,1.900,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,301,125.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,303,1.120,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,306,298.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,307,372.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,320,577.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,401,0.900,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,539,0.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,601,27.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125101,606,4.370,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,203,7.030,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,204,9.520,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,205,18.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,207,1.650,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,208,188.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,269,0.470,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,291,1.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,301,23.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,303,0.920,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,306,170.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,307,525.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,320,1200.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,401,0.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,539,0.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,601,16.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125102,606,1.750,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,203,7.240,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,204,8.340,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,205,20.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,207,1.670,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,208,187.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,269,0.460,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,291,1.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,301,24.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,303,0.930,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,306,172.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,307,565.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,320,1340.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,401,0.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,539,0.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,601,21.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125103,606,3.080,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,203,9.440,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,204,11.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,205,25.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,207,2.430,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,208,188.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,269,0.570,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,291,1.800,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,301,32.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,303,1.540,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,306,213.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,307,715.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,320,1670.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,401,0.800,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,539,0.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,601,27.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125104,606,4.220,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,203,5.620,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,204,7.620,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,205,14.700,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,207,1.320,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,208,188.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,269,0.380,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,291,1.200,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,301,19.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,303,0.730,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,306,136.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,307,420.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,320,956.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,401,0.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,539,0.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,601,13.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125105,606,1.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,203,7.020,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,204,9.520,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,205,18.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,207,1.650,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,208,188.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,269,0.480,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,291,1.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,301,23.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,303,0.920,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,306,170.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,307,525.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,320,1200.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,401,0.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,539,0.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,601,16.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125106,606,1.750,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125107,203,13.600,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,204,10.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,205,22.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,208,236.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,269,2.860,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,291,2.100,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,301,264.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,303,1.710,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,306,236.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,307,593.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,320,96.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,401,0.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,539,0.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,601,25.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125107,606,5.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125108,203,8.810,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,204,14.800,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,205,19.200,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,207,2.260,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,208,244.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,269,0.940,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,291,1.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,301,240.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,303,0.490,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,306,121.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,307,590.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,320,74.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,328,1.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,401,1.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,539,0.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,601,21.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125108,606,5.170,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,203,8.810,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,204,14.800,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,205,19.200,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,207,2.260,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,208,244.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,269,0.930,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,291,1.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,301,229.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,303,0.490,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,306,121.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,307,590.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,320,74.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,328,1.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,401,1.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,539,0.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,601,21.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125109,606,5.170,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,203,11.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,204,12.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,205,20.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,207,1.830,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,208,238.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,255,51.200,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,269,1.090,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,291,1.800,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,301,289.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,303,0.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,306,208.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,307,492.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,320,316.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,328,1.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,401,1.700,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,539,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,601,25.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125110,606,6.550,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125111,203,14.600,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,204,12.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,205,25.400,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,208,273.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,269,1.820,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,291,1.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,301,364.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,303,1.820,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,306,200.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,307,436.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,320,65.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,401,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,539,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,601,18.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125111,606,4.550,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125112,203,13.700,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,204,4.900,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,205,72.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,207,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,208,353.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,269,23.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,291,9.800,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,301,39.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,303,2.550,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,306,294.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,307,333.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,320,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,401,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,539,19.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,601,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125112,606,0.980,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,203,14.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,204,8.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,205,68.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,207,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,208,380.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,269,20.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,291,10.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,301,60.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,303,2.800,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,306,280.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,307,360.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,320,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,401,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,539,20.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,601,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125113,606,1.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125114,203,13.000,'100g',6,3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,204,10.400,'100g',6,3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,205,26.000,'100g',6,3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,208,247.000,'100g',6,3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,269,9.090,'100g',6,3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,291,1.300,'100g',6,3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,301,236.000,'100g',6,3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,303,0.910,'100g',6,3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,306,247.000,'100g',6,3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,307,519.000,'100g',6,3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,328,0.000,'100g',6,3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,539,9.100,'100g',6,3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,601,97.000,'100g',6,3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,605,0.000,'100g',6,3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125114,606,3.900,'100g',6,3,'2024-09-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125115,203,12.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,204,10.100,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,205,23.200,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,208,232.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,269,2.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,291,2.200,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,301,275.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,303,1.810,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,306,246.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,307,536.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,320,52.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,401,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,539,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,601,18.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125115,606,3.620,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125116,203,17.900,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,204,32.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,205,7.140,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,207,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,208,357.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,269,3.570,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,291,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,301,500.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,303,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,306,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,307,1570.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,320,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,401,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,539,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,601,89.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125116,606,17.900,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,203,25.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,204,21.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,205,7.140,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,207,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,208,286.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,269,3.570,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,291,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,301,739.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,303,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,306,725.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,307,1000.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,320,179.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,401,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,539,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,601,54.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125117,606,12.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,203,17.900,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,204,28.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,205,7.140,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,207,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,208,357.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,269,3.570,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,291,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,301,536.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,303,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,306,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,307,1500.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,320,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,401,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,539,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,601,89.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125118,606,17.900,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,203,28.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,204,21.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,205,3.570,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,207,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,208,321.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,269,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,291,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,301,714.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,303,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,306,71.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,307,643.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,320,321.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,401,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,539,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,601,71.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125119,606,12.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,203,25.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,204,10.700,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,205,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,207,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,208,214.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,269,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,291,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,301,714.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,303,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,306,82.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,307,714.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,320,196.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,401,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,539,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,601,36.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125120,606,7.140,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,203,28.600,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,204,21.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,205,3.570,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,207,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,208,321.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,269,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,291,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,301,714.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,303,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,306,89.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,307,643.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,320,321.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,401,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,539,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,601,54.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125121,606,12.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,203,25.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,204,21.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,205,7.140,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,207,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,208,286.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,269,3.570,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,291,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,301,739.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,303,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,306,725.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,307,1000.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,320,179.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,401,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,539,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,601,54.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125122,606,12.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,203,25.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,204,14.300,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,205,7.140,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,207,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,208,250.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,269,3.570,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,291,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,301,732.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,303,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,306,750.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,307,679.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,320,179.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,401,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,539,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,601,54.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125123,606,8.930,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,203,21.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,204,16.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,205,7.140,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,207,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,208,250.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,269,7.140,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,291,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,301,693.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,303,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,306,221.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,307,1570.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,320,179.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,401,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,539,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,601,54.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125124,606,8.930,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125125,203,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,204,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,205,10.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,208,39.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,269,9.380,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,291,0.800,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,301,4.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,303,0.280,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,306,74.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,307,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,320,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,401,86.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,539,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,601,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125125,606,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125126,203,0.830,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,204,0.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,205,3.730,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,207,NULL,'100ml',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,208,19.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,255,NULL,'100ml',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,269,2.900,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,291,0.400,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,301,12.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,303,0.410,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,306,353.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,307,58.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,320,79.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,328,0.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,401,29.900,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,539,0.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,601,0.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,605,0.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125126,606,0.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,203,0.830,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,204,0.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,205,3.730,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,207,NULL,'100ml',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,208,19.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,255,NULL,'100ml',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,269,2.900,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,291,0.800,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,301,12.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,303,0.250,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,306,344.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,307,58.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,320,75.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,328,0.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,401,29.900,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,539,0.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,601,0.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,605,0.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125127,606,0.000,'100ml',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,203,5.630,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,204,14.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,205,52.100,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,207,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,208,366.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,269,22.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,291,2.800,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,301,56.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,303,1.690,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,306,85.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,307,197.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,320,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,401,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,539,22.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,601,28.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125128,606,4.230,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,203,5.880,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,204,15.300,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,205,51.800,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,207,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,208,365.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,269,22.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,291,2.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,301,59.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,303,1.760,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,306,94.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,307,188.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,320,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,401,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,539,22.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,601,24.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125129,606,4.120,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,203,5.520,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,204,12.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,205,50.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,207,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,208,329.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,269,24.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,291,3.500,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,301,61.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,303,1.960,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,306,250.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,307,201.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,320,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,401,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,539,22.200,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,601,67.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,605,0.160,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125130,606,3.400,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125131,203,0.340,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,204,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,205,15.600,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,207,NULL,'100ml',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,208,61.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,255,NULL,'100ml',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,269,14.900,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,291,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,301,10.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,303,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,306,68.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,307,5.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,320,NULL,'100ml',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,328,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,401,30.500,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,539,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,601,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,605,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125131,606,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,203,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,204,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,205,11.500,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,207,NULL,'100ml',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,208,47.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,255,NULL,'100ml',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,269,10.800,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,291,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,301,10.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,303,0.240,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,306,129.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,307,5.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,320,NULL,'100ml',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,328,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,401,30.500,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,539,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,601,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,605,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125132,606,0.000,'100ml',6,3,'2024-09-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125133,203,4.350,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,204,13.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,205,65.200,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,208,391.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,269,8.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,291,4.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,301,35.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,303,4.350,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,306,330.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,307,870.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,401,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,539,8.700,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,601,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,605,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125133,606,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125134,203,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,204,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,205,27.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,208,113.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,269,23.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,291,1.350,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,301,16.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,303,0.640,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,306,225.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,307,923.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,539,20.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125134,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,203,1.280,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,204,0.090,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,205,23.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,208,102.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,269,20.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,291,1.560,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,301,18.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,303,0.850,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,306,253.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,307,914.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,539,17.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,601,0.060,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125135,606,0.020,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,203,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,204,13.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,205,76.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,208,450.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,269,23.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,291,4.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,301,25.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,303,3.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,306,201.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,307,295.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,539,23.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125136,606,4.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125137,203,1.110,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,204,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,205,13.300,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,207,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,208,56.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,255,NULL,'100g',NULL,3,'2024-12-12','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,269,8.890,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,291,3.300,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,301,6.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,303,1.110,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,306,102.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,307,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,320,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,328,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,401,53.300,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,539,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,601,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,605,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125137,606,0.000,'100g',6,3,'2024-09-13','2024-09-13');
INSERT INTO `cndb_nutval` VALUES (125138,203,17.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,204,13.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,205,7.450,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,208,223.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,269,0.390,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,291,1.100,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,301,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,303,1.190,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,306,737.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,307,403.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,401,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,539,0.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,601,92.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,605,0.100,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125138,606,2.900,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,203,17.300,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,204,10.600,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,205,7.030,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,207,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,208,192.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,255,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,269,5.160,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,291,0.100,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,301,11.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,303,0.620,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,306,337.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,307,470.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,320,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,328,0.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,401,NULL,'100g',NULL,3,'2024-12-12','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,539,5.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,601,89.000,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,605,0.170,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125139,606,2.280,'100g',6,3,'2024-10-31','2024-10-31');
INSERT INTO `cndb_nutval` VALUES (125140,203,1.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,205,16.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,208,67.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,269,12.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,291,3.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,301,8.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,303,1.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,306,140.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,401,53.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125140,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,203,0.880,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,205,19.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,208,80.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,269,15.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,291,2.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,301,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,303,0.880,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,306,160.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,401,53.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,539,6.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125141,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,205,100.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,208,400.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,269,70.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,291,20.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,306,1300.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125142,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,205,100.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,208,400.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,269,60.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,291,20.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,306,1300.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125143,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,203,0.680,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,204,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,205,11.800,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,207,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,208,47.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,255,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,269,11.200,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,291,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,301,11.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,303,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,306,189.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,307,3.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,320,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,328,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,401,30.400,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,539,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,601,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,605,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125144,606,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,203,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,204,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,205,11.800,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,207,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,208,47.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,255,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,269,10.500,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,291,0.300,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,301,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,303,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,306,115.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,307,3.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,320,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,328,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,401,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,539,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,601,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,605,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125145,606,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,203,1.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,205,13.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,208,50.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,269,8.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,291,3.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,301,6.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,303,1.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,306,102.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,401,53.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125146,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,203,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,204,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,205,12.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,207,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,208,50.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,255,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,269,11.500,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,291,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,301,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,303,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,306,116.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,307,5.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,320,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,328,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,401,30.100,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,539,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,601,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,605,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125147,606,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,203,0.780,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,205,13.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,208,55.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,269,8.590,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,291,3.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,301,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,303,0.780,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,306,102.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,401,46.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125148,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,203,0.880,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,205,13.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,208,53.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,269,8.850,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,291,2.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,301,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,303,0.880,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,306,103.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,401,53.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125149,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125150,203,20.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,204,5.010,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,205,25.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,208,226.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,269,21.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,291,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,301,80.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,303,2.510,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,306,284.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,307,451.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,539,20.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,601,63.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125150,606,1.250,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,203,13.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,204,10.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,205,0.910,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,208,145.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,269,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,291,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,301,55.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,303,1.820,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,306,124.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,307,145.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,328,2.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,601,395.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125151,606,3.180,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,203,10.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,204,10.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,205,3.570,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,208,161.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,269,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,291,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,301,64.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,303,1.290,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,306,146.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,307,464.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,328,4.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,601,339.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125152,606,3.570,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,203,4.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,204,6.860,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,205,53.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,208,294.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,269,29.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,291,2.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,301,29.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,303,1.960,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,306,157.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,307,176.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,539,28.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,601,54.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125153,606,1.960,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,203,3.640,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,204,14.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,205,5.450,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,208,164.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,269,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,291,0.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,301,45.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,303,1.090,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,306,195.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,307,56.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125155,606,1.450,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,203,11.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,204,4.290,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,205,45.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,208,257.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,269,2.860,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,291,2.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,301,57.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,303,2.860,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,306,200.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,307,486.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,539,2.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125156,606,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125157,203,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,204,10.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,205,76.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,208,409.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,269,28.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,291,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,301,17.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,303,5.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,306,120.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,307,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,539,28.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125157,606,2.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,203,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,204,9.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,205,68.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,208,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,269,33.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,291,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,301,351.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,303,4.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,306,240.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,307,324.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,328,5.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,539,32.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125158,606,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,203,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,204,9.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,205,68.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,208,360.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,269,33.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,291,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,301,351.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,303,4.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,306,241.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,307,321.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,328,5.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,539,32.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125159,606,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125160,203,10.900,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,204,1.520,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,205,75.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,208,349.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,269,1.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,291,11.800,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,301,24.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,303,2.540,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,306,374.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,307,2.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,320,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,401,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,539,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,601,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,605,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125160,606,0.180,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125161,203,13.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,204,8.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,205,30.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,208,253.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,269,4.780,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,291,3.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,301,46.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,303,2.460,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,306,238.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,307,482.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,539,4.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,601,24.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,605,0.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125161,606,1.910,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,203,13.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,204,8.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,205,30.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,208,253.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,269,4.780,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,291,3.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,301,46.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,303,2.460,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,306,238.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,307,482.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,539,4.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,601,24.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,605,0.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125162,606,1.910,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125165,203,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,204,9.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,205,68.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,208,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,269,33.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,291,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,301,351.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,303,4.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,306,240.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,307,324.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,328,5.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,539,32.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125165,606,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,203,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,204,9.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,205,68.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,208,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,269,33.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,291,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,301,351.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,303,4.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,306,240.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,307,324.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,328,5.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,539,32.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125166,606,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125167,203,13.900,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,204,1.390,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,205,71.200,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,208,362.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,269,1.020,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,291,2.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,301,21.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,303,1.260,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,306,125.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,307,2.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,320,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,401,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,539,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,601,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,605,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125167,606,0.223,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,203,14.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,204,1.390,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,205,71.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,208,361.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,269,1.020,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,291,2.400,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,301,21.100,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,303,1.260,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,306,125.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,307,2.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,320,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,401,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,539,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,601,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,605,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125168,606,0.223,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125169,203,4.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,204,5.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,205,42.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,208,224.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,269,13.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,291,4.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,301,302.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,303,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,306,165.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,307,244.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,320,209.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,539,13.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125169,606,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,203,4.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,204,8.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,205,41.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,208,241.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,269,11.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,291,4.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,301,54.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,303,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,306,151.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,307,244.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,320,209.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,539,11.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,601,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125170,606,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,203,4.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,204,6.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,205,41.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,208,228.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,269,11.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,291,4.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,301,53.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,303,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,306,151.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,307,242.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,320,209.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,539,11.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,601,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125171,606,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,203,5.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,204,6.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,205,45.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,208,248.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,269,11.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,291,5.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,301,347.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,303,4.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,306,187.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,307,280.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,320,240.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,539,10.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125172,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,203,6.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,204,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,205,46.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,208,252.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,269,11.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,291,7.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,301,347.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,303,4.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,306,240.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,307,263.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,320,240.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,539,11.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125173,606,1.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,203,6.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,204,13.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,205,74.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,208,431.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,269,24.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,291,4.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,301,34.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,303,3.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,306,183.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,307,338.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,539,24.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,605,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125174,606,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125175,203,17.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,204,45.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,205,31.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,208,571.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,269,8.570,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,291,2.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,301,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,303,6.290,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,306,629.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,307,543.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,539,2.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125175,606,7.140,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125176,203,2.010,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,204,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,205,6.820,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,208,44.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,269,5.620,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,291,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,301,56.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,303,0.320,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,306,177.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,307,136.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,539,1.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,601,4.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125176,606,0.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,203,2.010,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,204,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,205,6.820,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,208,44.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,269,5.620,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,291,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,301,56.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,303,0.320,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,306,177.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,307,136.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,539,1.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,601,4.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125177,606,0.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,203,9.520,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,204,16.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,205,66.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,208,429.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,291,4.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,301,95.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,303,3.330,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,306,333.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,307,952.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125178,606,2.380,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,203,17.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,204,32.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,205,7.140,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,208,357.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,269,3.570,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,291,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,301,500.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,303,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,306,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,307,1570.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,601,89.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125179,606,17.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125180,203,3.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,204,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,205,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,208,150.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,291,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,303,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,306,110.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125180,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125181,203,5.880,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,204,17.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,205,42.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,208,353.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,269,19.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,291,2.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,301,59.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,303,1.910,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,306,206.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,307,426.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,539,16.200,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,601,59.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125181,606,1.470,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,203,13.300,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,204,6.670,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,205,68.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,208,378.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,269,2.220,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,291,8.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,301,44.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,303,3.780,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,306,378.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,307,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125182,606,1.110,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,203,6.450,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,204,1.610,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,205,37.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,208,194.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,269,1.610,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,291,3.200,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,301,160.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,303,1.610,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,306,153.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,307,323.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,539,1.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125183,606,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,203,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,204,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,205,6.250,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,208,31.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,269,3.120,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,291,3.100,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,301,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,303,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,306,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,307,781.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125184,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125185,203,7.140,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,204,21.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,205,67.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,208,500.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,269,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,291,7.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,301,107.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,303,1.790,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,306,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,307,393.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125185,606,3.570,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125186,203,6.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,204,13.200,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,205,75.200,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,208,428.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,269,25.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,291,4.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,301,34.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,303,3.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,306,187.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,307,344.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,539,25.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,605,0.200,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125186,606,4.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125187,203,4.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,204,7.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,205,41.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,208,230.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,269,12.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,291,6.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,301,54.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,303,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,306,174.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,307,242.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,320,209.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,539,12.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,601,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125187,606,1.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125188,203,10.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,204,16.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,205,63.300,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,208,467.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,291,6.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,301,100.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,303,3.330,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,306,233.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,307,800.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,601,17.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125188,606,3.330,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,203,1.030,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,204,1.890,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,205,24.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,208,113.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,269,13.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,291,2.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,301,32.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,303,0.960,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,306,90.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,307,81.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,328,1.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,401,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,539,4.500,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125189,606,0.340,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125190,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,205,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,208,55.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,269,11.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,291,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,301,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,303,2340.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,306,37.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,307,3.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,401,37.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125190,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,203,4.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,204,5.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,205,75.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,208,354.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,269,29.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,306,119.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,307,239.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,539,29.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125191,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,203,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,204,6.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,205,75.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,208,364.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,269,30.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,306,160.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,307,254.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,539,30.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125192,606,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125193,203,4.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,204,10.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,205,6.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,208,124.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,291,2.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,301,58.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,303,1.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,306,216.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,307,58.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125193,606,1.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,203,2.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,204,1.200,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,205,7.190,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,208,48.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,269,6.390,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,291,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,301,56.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,303,0.200,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,306,208.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,307,136.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,539,1.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,601,4.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125194,606,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,203,17.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,204,1.760,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,205,1.180,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,208,94.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,291,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,301,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,303,0.420,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,306,221.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,307,459.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,601,76.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125195,606,0.590,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,203,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,204,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,205,3.890,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,208,17.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,269,3.610,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,291,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,301,3.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,303,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,306,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,307,7.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,401,4.200,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,539,3.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125196,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,203,2.380,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,204,1.590,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,205,7.940,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,208,56.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,269,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,291,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,301,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,303,0.400,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,306,32.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,307,643.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,601,12.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125197,606,0.400,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,203,1.590,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,204,4.760,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,205,7.140,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,208,79.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,269,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,291,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,301,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,303,0.240,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,306,12.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,307,595.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,601,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125198,606,0.790,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,203,0.810,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,204,1.610,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,205,11.300,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,208,65.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,269,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,291,1.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,301,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,303,0.160,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,306,476.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,307,476.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,601,4.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125199,606,0.810,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,203,2.380,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,204,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,205,10.300,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,208,48.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,269,2.380,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,291,1.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,301,24.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,303,0.630,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,306,222.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,307,532.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125200,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,203,1.670,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,204,2.500,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,205,5.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,208,50.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,269,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,291,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,301,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,303,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,306,17.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,307,533.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125201,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,203,17.500,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,204,1.460,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,205,0.970,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,208,87.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,291,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,301,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,303,0.350,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,306,183.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,307,456.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,601,78.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125202,606,0.490,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,203,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,204,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,205,6.250,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,208,31.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,269,3.120,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,291,3.100,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,301,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,303,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,306,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,307,781.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125203,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,203,1.610,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,204,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,205,16.100,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,208,73.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,269,9.680,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,291,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,301,16.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,303,0.480,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,306,234.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,307,387.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,401,4.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,539,5.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125204,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,203,2.380,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,204,6.350,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,205,14.300,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,208,127.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,269,2.380,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,291,1.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,301,79.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,303,0.320,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,306,198.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,307,683.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,328,2.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,601,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125205,606,1.590,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,203,3.170,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,204,1.590,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,205,7.940,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,208,56.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,269,0.790,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,291,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,301,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,303,0.480,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,306,48.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,307,635.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,601,12.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125206,606,0.400,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,203,4.690,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,204,1.560,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,205,18.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,208,102.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,269,3.120,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,291,3.900,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,301,47.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,303,1.170,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,306,242.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,307,508.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,539,2.300,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125207,606,0.390,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,203,2.380,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,204,1.190,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,205,11.900,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,208,71.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,269,2.380,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,291,1.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,301,16.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,303,0.790,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,306,206.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,307,492.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,601,4.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125208,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,203,2.380,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,204,0.790,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,205,8.730,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,208,56.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,269,3.170,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,291,2.400,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,301,24.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,303,0.790,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,306,238.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,307,516.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,601,4.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125209,606,0.400,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,203,0.970,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,204,0.490,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,205,10.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,208,53.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,269,7.280,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,291,1.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,301,10.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,303,0.290,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,306,146.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,307,24.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,539,4.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,601,2.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125210,606,0.240,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,203,1.540,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,204,2.310,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,205,8.460,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,208,62.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,269,6.150,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,291,2.300,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,301,38.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,303,1.150,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,306,354.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,307,31.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125211,606,0.380,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125212,203,7.890,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,204,18.400,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,205,65.800,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,208,474.000,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,269,5.260,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,291,5.300,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,301,26.000,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,303,1.580,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,306,1470.000,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,307,474.000,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,328,0.000,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,401,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,539,5.300,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,601,0.000,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,605,0.000,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125212,606,1.320,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125213,203,17.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,204,45.200,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,205,31.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,208,565.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,269,5.650,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,291,2.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,301,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,303,6.210,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,306,621.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,307,339.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125213,606,7.060,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,203,17.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,204,51.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,205,28.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,208,629.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,269,5.710,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,291,2.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,301,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,303,6.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,306,629.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,307,329.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125214,606,8.570,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,203,17.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,204,45.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,205,28.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,208,571.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,269,5.710,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,291,2.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,301,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,303,6.290,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,306,629.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,307,571.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125215,606,7.140,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,203,1.610,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,204,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,205,12.900,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,208,56.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,269,6.450,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,291,1.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,301,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,303,0.400,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,306,411.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,307,331.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,401,7.300,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,539,3.200,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125216,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,203,1.610,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,204,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,205,16.100,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,208,73.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,269,9.680,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,291,1.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,301,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,303,0.400,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,306,468.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,307,387.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,401,7.300,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,539,6.500,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125217,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,203,4.760,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,204,1.590,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,205,9.520,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,208,71.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,269,0.790,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,291,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,301,16.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,303,0.400,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,306,429.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,307,325.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,601,16.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125218,606,0.400,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,203,2.380,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,204,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,205,16.700,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,208,79.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,269,10.300,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,291,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,301,16.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,303,0.790,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,306,643.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,307,325.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,539,6.300,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125219,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,203,9.520,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,204,16.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,205,66.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,208,476.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,291,4.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,301,95.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,303,3.330,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,306,238.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,307,762.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125220,606,2.380,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,203,9.520,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,204,16.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,205,66.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,208,476.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,291,4.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,301,95.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,303,3.330,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,306,286.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,307,810.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125221,606,2.380,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,203,2.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,204,1.200,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,205,7.190,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,208,48.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,269,6.390,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,291,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,301,56.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,303,0.200,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,306,208.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,307,136.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,539,1.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,601,4.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125222,606,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,203,10.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,204,16.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,205,63.300,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,208,467.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,291,6.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,301,100.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,303,3.330,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,306,233.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,307,800.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,601,17.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125223,606,3.330,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,203,3.850,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,204,15.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,205,73.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,208,462.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,269,26.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,291,3.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,301,385.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,303,8.080,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,306,154.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,307,404.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,539,26.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125224,606,3.850,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,203,10.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,204,17.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,205,64.300,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,208,464.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,291,7.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,301,107.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,303,3.210,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,306,236.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,307,786.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,601,18.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125225,606,3.570,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,203,0.430,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,204,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,205,0.430,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,208,4.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,269,0.430,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,291,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,301,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,303,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,306,17.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,307,366.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125226,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,203,0.430,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,204,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,205,0.430,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,208,4.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,269,0.430,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,291,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,301,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,303,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,306,17.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,307,366.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125227,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,203,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,204,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,205,3.890,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,208,17.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,269,3.610,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,291,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,301,3.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,303,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,306,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,307,7.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,401,4.200,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,539,3.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125230,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,203,3.230,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,204,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,205,0.810,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,208,16.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,269,0.810,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,291,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,301,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,303,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,306,16.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,307,444.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,539,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125231,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,203,2.380,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,204,1.590,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,205,7.940,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,208,56.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,269,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,291,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,301,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,303,0.400,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,306,32.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,307,643.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,601,12.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125232,606,0.400,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,203,1.590,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,204,4.760,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,205,7.140,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,208,79.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,269,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,291,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,301,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,303,0.240,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,306,12.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,307,595.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,601,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125233,606,0.790,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,203,0.810,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,204,4.840,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,205,6.450,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,208,73.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,269,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,291,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,301,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,303,0.160,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,306,24.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,307,637.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125234,606,0.810,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,203,0.810,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,204,1.610,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,205,11.300,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,208,65.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,269,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,291,1.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,301,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,303,0.160,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,306,476.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,307,476.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,601,4.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125235,606,0.810,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,203,2.380,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,204,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,205,10.300,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,208,48.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,269,2.380,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,291,1.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,301,24.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,303,0.630,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,306,222.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,307,532.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125236,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,203,1.610,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,204,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,205,16.100,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,208,73.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,269,9.680,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,291,1.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,301,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,303,0.400,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,306,468.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,307,387.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,401,7.300,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,539,6.500,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125237,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,203,1.610,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,204,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,205,16.100,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,208,73.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,269,9.680,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,291,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,301,16.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,303,0.480,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,306,234.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,307,387.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,401,4.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,539,5.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125238,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,203,1.590,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,204,8.730,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,205,7.940,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,208,119.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,269,1.590,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,291,1.600,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,301,53.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,303,0.240,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,306,83.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,307,635.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,539,0.800,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,601,8.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125239,606,0.790,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,203,3.170,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,204,1.190,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,205,10.300,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,208,56.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,269,5.560,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,291,2.400,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,301,32.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,303,0.790,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,306,516.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,307,341.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,539,2.400,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,601,4.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125240,606,0.400,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,203,3.080,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,204,5.640,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,205,12.300,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,208,113.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,269,0.510,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,291,0.500,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,301,41.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,303,0.510,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,306,26.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,307,354.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,539,0.500,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,601,5.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125241,606,1.030,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,203,3.690,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,204,5.990,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,205,14.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,208,129.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,269,1.840,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,291,1.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,301,60.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,303,0.460,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,306,88.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,307,318.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,601,5.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125242,606,1.150,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,203,3.850,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,204,2.880,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,205,11.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,208,87.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,269,4.330,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,291,1.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,301,29.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,303,0.480,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,306,183.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,307,361.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,539,1.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,601,12.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125243,606,1.200,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,203,1.670,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,204,2.500,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,205,5.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,207,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,208,50.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,255,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,269,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,291,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,301,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,303,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,306,17.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,307,533.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,320,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,328,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,401,NULL,'100ml',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,539,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,601,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,605,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125244,606,0.000,'100ml',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,203,0.970,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,204,0.970,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,205,4.370,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,208,29.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,291,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,301,5.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,303,0.150,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,306,19.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,307,383.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,601,7.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125245,606,0.240,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,203,1.460,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,204,1.210,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,205,3.880,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,208,34.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,291,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,301,5.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,303,0.240,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,306,44.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,307,29.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,601,5.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125246,606,0.240,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,203,0.970,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,204,0.490,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,205,10.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,208,53.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,269,7.280,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,291,1.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,301,10.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,303,0.290,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,306,146.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,307,24.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,539,4.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,601,2.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125247,606,0.240,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,203,0.970,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,204,0.490,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,205,6.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,208,34.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,269,2.430,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,291,1.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,301,5.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,303,0.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,306,58.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,307,51.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,539,1.500,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125248,606,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,203,9.520,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,204,16.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,205,66.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,208,476.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,291,4.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,301,143.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,303,4.290,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,306,143.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,307,857.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,601,24.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125249,606,2.380,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,203,9.520,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,204,16.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,205,66.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,208,476.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,291,4.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,301,95.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,303,3.330,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,306,286.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,307,810.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125250,606,2.380,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,203,9.520,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,204,16.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,205,66.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,208,476.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,291,4.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,301,95.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,303,3.330,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,306,286.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,307,810.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125251,606,2.380,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,203,9.520,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,204,7.140,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,205,76.200,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,208,429.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,291,4.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,301,48.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,303,3.330,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,306,214.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,307,952.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125252,606,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,203,3.850,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,204,15.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,205,73.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,208,462.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,269,26.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,291,3.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,301,385.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,303,7.690,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,306,154.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,307,538.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,539,26.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125253,606,3.850,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,203,7.140,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,204,16.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,205,75.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,208,464.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,269,28.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,291,7.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,301,36.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,303,2.140,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,306,214.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,307,500.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,539,28.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125254,606,3.570,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,203,7.140,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,204,16.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,205,75.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,208,464.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,269,28.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,291,3.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,301,36.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,303,2.140,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,306,214.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,307,464.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,539,28.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125255,606,3.570,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125256,203,7.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,204,1.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,205,79.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,208,325.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,269,28.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,291,12.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,301,37.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,303,3.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,306,478.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,307,340.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,539,15.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125256,606,0.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125257,203,2.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,204,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,205,8.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,208,48.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,269,4.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,291,2.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,301,16.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,303,0.560,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,306,104.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,307,104.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,539,1.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125257,606,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,203,25.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,204,32.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,205,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,208,393.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,269,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,291,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,301,729.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,303,0.710,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,306,71.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,307,643.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,328,1.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,601,107.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125258,606,21.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125259,203,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,204,10.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,205,76.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,208,409.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,269,28.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,291,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,301,17.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,303,5.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,306,120.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,307,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,539,28.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125259,606,2.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,203,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,204,11.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,205,75.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,208,421.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,269,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,291,1.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,301,17.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,303,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,306,172.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,307,331.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,539,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,605,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125260,606,4.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125261,203,7.070,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,204,17.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,205,70.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,208,459.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,269,3.530,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,291,7.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,301,106.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,303,1.060,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,306,212.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,307,636.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,539,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125261,606,1.770,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125262,203,6.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,204,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,205,85.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,208,370.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,269,28.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,291,6.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,301,14.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,306,175.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,307,587.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,401,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,539,28.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125262,606,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,203,6.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,204,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,205,85.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,208,370.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,269,28.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,291,6.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,301,14.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,306,175.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,307,587.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,401,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,539,28.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125263,606,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,203,6.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,204,6.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,205,42.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,208,230.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,269,12.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,291,6.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,301,302.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,303,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,306,222.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,307,246.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,320,209.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,539,12.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125264,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,203,6.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,204,6.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,205,42.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,208,230.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,269,12.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,291,6.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,301,302.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,303,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,306,222.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,307,246.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,320,209.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,539,12.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125265,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,203,4.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,204,5.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,205,42.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,208,224.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,269,13.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,291,4.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,301,302.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,303,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,306,165.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,307,244.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,320,209.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,539,13.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125266,606,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,203,4.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,204,8.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,205,41.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,208,241.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,269,11.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,291,4.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,301,54.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,303,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,306,151.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,307,244.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,320,209.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,539,11.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,601,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125267,606,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,203,4.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,204,6.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,205,41.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,208,228.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,269,11.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,291,4.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,301,53.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,303,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,306,151.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,307,242.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,320,209.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,539,11.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,601,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125268,606,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,203,5.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,204,6.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,205,45.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,208,248.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,269,11.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,291,5.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,301,347.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,303,4.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,306,187.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,307,280.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,320,240.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,539,10.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125269,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,203,6.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,204,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,205,46.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,208,252.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,269,11.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,291,7.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,301,347.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,303,4.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,306,240.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,307,263.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,320,240.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,539,11.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125270,606,1.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,203,6.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,204,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,205,85.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,208,370.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,269,28.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,291,6.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,301,13.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,306,176.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,307,592.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,401,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,539,28.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125271,606,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,203,6.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,204,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,205,85.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,208,370.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,269,28.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,291,6.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,301,13.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,306,176.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,307,592.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,401,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,539,28.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125272,606,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,203,7.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,204,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,205,87.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,208,361.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,269,22.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,291,8.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,301,23.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,306,285.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,307,632.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,539,22.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125273,606,0.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,203,7.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,204,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,205,87.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,208,361.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,269,22.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,291,8.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,301,23.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,306,285.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,307,632.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,539,22.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125274,606,0.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,203,8.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,204,2.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,205,84.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,208,353.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,269,20.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,291,9.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,301,15.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,303,30.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,306,270.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,307,17.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,539,20.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125275,606,0.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,203,8.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,204,2.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,205,84.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,208,353.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,269,20.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,291,9.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,301,15.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,303,30.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,306,270.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,307,17.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,539,20.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125276,606,0.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,203,7.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,204,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,205,87.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,208,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,269,22.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,291,8.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,301,19.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,306,278.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,307,601.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,539,21.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125277,606,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,203,7.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,204,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,205,87.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,208,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,269,22.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,291,8.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,301,19.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,306,278.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,307,601.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,539,21.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125278,606,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,203,4.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,204,6.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,205,76.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,208,363.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,269,31.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,306,147.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,307,254.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,539,31.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125279,606,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,203,4.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,204,6.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,205,76.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,208,363.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,269,31.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,306,147.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,307,254.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,539,31.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125280,606,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,203,4.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,204,6.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,205,76.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,208,363.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,269,31.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,306,147.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,307,254.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,539,31.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125281,606,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,203,4.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,204,6.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,205,76.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,208,363.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,269,31.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,306,147.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,307,254.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,539,31.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125282,606,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,203,4.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,204,6.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,205,76.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,208,363.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,269,31.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,306,147.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,307,254.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,539,31.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125283,606,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,203,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,204,9.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,205,68.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,208,360.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,269,33.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,291,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,301,351.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,303,4.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,306,241.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,307,321.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,328,5.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,539,32.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125284,606,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,203,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,204,9.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,205,68.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,208,360.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,269,33.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,291,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,301,351.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,303,4.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,306,241.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,307,321.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,328,5.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,539,32.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125285,606,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,203,7.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,204,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,205,87.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,208,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,269,22.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,291,8.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,301,19.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,306,278.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,307,601.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,539,21.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125286,606,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,203,7.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,204,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,205,87.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,208,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,269,22.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,291,8.040,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,301,19.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,306,278.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,307,601.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,539,21.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125287,606,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,203,7.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,204,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,205,87.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,208,361.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,269,22.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,291,8.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,301,23.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,306,285.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,307,632.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,539,22.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125288,606,0.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,203,7.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,204,1.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,205,87.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,208,361.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,269,22.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,291,8.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,301,23.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,306,285.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,307,632.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,539,22.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125289,606,0.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,203,6.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,204,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,205,85.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,208,370.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,269,28.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,291,6.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,301,14.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,306,175.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,307,587.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,401,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,539,28.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125290,606,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,203,6.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,204,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,205,85.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,208,370.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,269,28.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,291,6.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,301,14.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,306,175.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,307,587.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,401,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,539,28.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125291,606,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,203,4.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,204,7.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,205,41.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,208,230.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,269,12.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,291,6.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,301,54.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,303,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,306,174.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,307,242.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,320,209.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,539,12.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,601,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125292,606,1.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,203,6.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,204,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,205,85.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,208,370.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,269,28.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,291,6.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,301,13.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,306,176.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,307,592.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,401,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,539,28.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125293,606,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,203,6.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,204,13.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,205,74.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,208,431.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,269,24.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,291,4.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,301,34.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,303,3.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,306,183.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,307,338.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,539,24.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,605,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125294,606,4.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,203,8.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,204,2.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,205,84.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,208,353.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,269,20.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,291,9.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,301,15.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,303,30.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,306,270.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,307,17.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,539,20.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125295,606,0.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,203,4.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,204,5.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,205,75.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,208,354.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,269,29.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,306,119.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,307,239.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,539,29.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125296,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,203,4.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,204,5.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,205,75.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,208,354.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,269,29.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,306,119.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,307,239.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,539,29.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125297,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,203,4.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,204,5.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,205,75.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,208,354.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,269,29.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,306,119.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,307,239.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,539,29.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125298,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,203,4.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,204,5.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,205,75.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,208,354.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,269,29.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,306,119.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,307,239.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,539,29.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125299,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,203,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,204,6.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,205,75.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,208,364.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,269,30.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,306,160.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,307,254.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,539,30.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125300,606,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,203,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,204,6.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,205,75.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,208,364.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,269,30.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,306,160.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,307,254.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,539,30.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125301,606,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,203,7.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,204,1.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,205,79.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,208,325.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,269,28.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,291,12.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,301,37.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,303,3.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,306,478.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,307,340.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,539,15.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125302,606,0.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,203,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,204,10.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,205,76.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,208,409.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,269,28.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,291,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,301,17.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,303,5.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,306,120.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,307,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,539,28.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125303,606,2.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,203,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,204,10.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,205,76.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,208,409.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,269,28.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,291,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,301,17.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,303,5.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,306,120.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,307,362.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,539,28.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125304,606,2.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,203,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,204,11.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,205,75.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,208,421.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,269,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,291,1.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,301,17.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,303,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,306,172.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,307,331.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,539,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,605,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125305,606,4.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,203,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,204,11.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,205,75.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,208,421.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,269,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,291,1.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,301,17.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,303,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,306,172.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,307,331.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,539,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,605,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125306,606,4.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,203,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,204,6.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,205,75.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,208,364.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,269,30.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,306,160.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,307,254.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,539,30.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125307,606,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,203,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,204,6.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,205,75.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,208,364.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,269,30.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,306,160.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,307,254.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,539,30.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125308,606,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,203,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,204,6.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,205,75.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,208,364.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,269,30.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,306,160.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,307,254.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,539,30.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125309,606,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,203,11.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,204,16.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,205,68.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,208,464.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,269,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,291,5.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,301,112.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,303,4.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,306,250.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,307,731.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,328,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,601,12.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,605,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125310,606,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,203,6.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,204,10.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,205,77.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,208,412.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,269,21.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,291,4.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,301,48.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,303,3.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,306,205.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,307,420.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,539,21.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125311,606,1.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,203,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,204,12.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,205,75.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,208,420.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,269,18.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,291,4.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,301,54.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,303,3.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,306,215.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,307,455.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,539,18.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,605,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125312,606,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,203,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,204,13.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,205,76.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,208,450.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,269,20.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,291,4.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,301,41.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,303,3.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,306,167.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,307,329.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,539,20.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,605,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125313,606,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125314,203,5.500,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,204,14.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,205,75.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,208,436.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,269,29.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,291,4.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,301,21.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,303,2.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,306,143.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,307,358.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,539,29.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,605,0.200,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125314,606,4.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,203,5.500,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,204,14.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,205,75.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,208,436.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,269,29.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,291,4.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,301,21.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,303,2.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,306,143.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,307,358.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,539,29.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,605,0.200,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125315,606,4.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,203,5.500,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,204,14.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,205,75.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,208,436.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,269,29.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,291,4.100,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,301,21.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,303,2.700,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,306,143.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,307,358.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,539,29.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,605,0.200,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125316,606,4.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125317,203,23.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,204,9.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,205,8.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,208,197.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,269,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,291,4.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,301,56.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,303,2.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,306,240.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,307,447.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,328,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,539,0.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125317,606,1.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125318,203,15.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,204,31.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,205,5.260,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,208,368.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,269,5.260,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,291,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,301,526.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,303,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,306,184.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,307,1470.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,539,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,601,79.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125318,606,18.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125319,203,21.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,204,53.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,205,21.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,208,625.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,269,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,291,6.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,301,69.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,303,4.380,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,306,650.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,307,375.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,539,9.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125319,606,9.380,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125320,203,8.860,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,204,11.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,205,21.500,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,208,215.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,269,1.270,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,291,2.500,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,301,76.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,303,1.520,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,306,165.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,307,456.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,539,1.300,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,601,89.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125320,606,5.060,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125321,203,6.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,204,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,205,85.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,208,370.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,269,28.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,291,6.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,301,13.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,303,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,306,176.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,307,592.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,328,7.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,401,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,539,28.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125321,606,0.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125322,203,8.770,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,204,8.770,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,205,49.100,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,208,316.000,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,269,7.020,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,291,3.500,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,301,18.000,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,303,2.630,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,306,88.000,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,307,596.000,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,328,0.000,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,401,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,539,5.300,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,601,0.000,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,605,0.000,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125322,606,4.390,'100g',6,3,'2024-07-11','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125323,203,8.450,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,204,1.480,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,205,37.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,208,214.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,269,1.140,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,291,3.500,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,301,135.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,303,2.140,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,306,136.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,307,395.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,328,1.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,539,0.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,605,0.010,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125323,606,0.290,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,203,7.020,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,204,3.510,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,205,45.600,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,208,228.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,269,5.260,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,291,3.500,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,301,53.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,303,2.460,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,306,123.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,307,439.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,401,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,539,5.300,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,601,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125324,606,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125325,203,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,205,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,208,30.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,269,3.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,291,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,301,30.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,303,0.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,306,170.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,307,140.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,320,240.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,401,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125325,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125326,203,4.710,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,204,5.290,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,205,42.400,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,208,235.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,269,12.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,291,3.500,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,301,47.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,303,1.760,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,306,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,307,388.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,328,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,401,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,539,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,601,12.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125326,606,1.180,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,203,12.200,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,204,6.880,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,205,26.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,207,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,208,222.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,255,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,269,3.060,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,291,3.800,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,301,214.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,303,2.060,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,306,367.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,307,512.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,320,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,328,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,401,0.900,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,539,NULL,'100g',NULL,3,'2024-12-12','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,601,11.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,605,0.000,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125327,606,2.680,'100g',6,3,'2024-07-11','2024-07-11');
INSERT INTO `cndb_nutval` VALUES (125328,203,12.800,'100g',6,3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,204,6.020,'100g',6,3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,205,25.600,'100g',6,3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,208,211.000,'100g',6,3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,269,3.010,'100g',6,3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,291,3.000,'100g',6,3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,301,211.000,'100g',6,3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,303,2.110,'100g',6,3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,306,466.000,'100g',6,3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,307,353.000,'100g',6,3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,320,27.000,'100g',6,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,328,0.000,'100g',6,3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,401,0.900,'100g',6,3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,539,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,601,15.000,'100g',6,3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,605,0.000,'100g',6,3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125328,606,2.260,'100g',6,3,'2024-07-11','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125329,203,14.000,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,204,14.000,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,205,1.750,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,208,193.000,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,269,0.000,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,291,0.000,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,301,423.000,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,303,0.000,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,306,286.000,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,307,491.000,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,320,0.000,'100g',6,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,328,0.000,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,401,0.000,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,539,0.000,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,601,44.000,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,605,0.000,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125329,606,7.890,'100g',6,3,'2024-05-16','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125330,203,8.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,204,10.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,205,25.700,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,207,0.980,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,208,228.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,255,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,269,0.560,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,291,1.100,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,301,152.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,303,1.970,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,306,134.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,307,487.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,328,1.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,401,1.300,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,539,0.100,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,601,41.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,605,0.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125330,606,4.450,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125331,203,7.130,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,204,21.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,205,65.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,208,482.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,269,0.890,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,291,5.340,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,301,89.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,303,1.780,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,306,127.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,307,395.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,605,0.270,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125331,606,2.810,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125332,203,0.690,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,204,1.550,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,205,24.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,207,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,208,110.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,255,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,269,13.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,291,1.400,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,301,35.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,303,1.200,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,306,90.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,307,81.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,320,NULL,'100g',NULL,3,'2024-12-12','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,328,1.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,401,0.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,539,4.500,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,601,0.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,605,0.000,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125332,606,0.340,'100g',6,3,'2024-05-16','2024-05-16');
INSERT INTO `cndb_nutval` VALUES (125333,203,21.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,204,46.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,205,25.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,208,625.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,269,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,291,6.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,301,94.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,303,3.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,306,938.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,307,312.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,539,6.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125333,606,9.380,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,203,21.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,204,46.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,205,25.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,208,625.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,269,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,291,6.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,301,94.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,303,3.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,306,938.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,307,312.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,539,6.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125334,606,9.380,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,203,21.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,204,46.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,205,25.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,208,625.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,269,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,291,6.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,301,94.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,303,3.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,306,938.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,307,312.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,539,6.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125335,606,9.380,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,203,4.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,204,6.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,205,76.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,208,363.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,269,31.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,291,5.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,301,271.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,303,3.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,306,147.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,307,254.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,320,188.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,539,31.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,605,0.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125336,606,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125337,203,1.790,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,204,0.210,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,205,7.540,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,208,39.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,269,2.210,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,291,2.600,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,301,42.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,303,0.850,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,306,186.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,307,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,328,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,539,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,601,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,605,0.000,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125337,606,0.050,'100g',6,3,'2024-12-19','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125338,203,5.420,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,204,0.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,205,14.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,208,81.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,269,5.670,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,291,5.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,301,25.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,303,1.470,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,306,244.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,307,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125338,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125339,203,5.880,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,204,21.200,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,205,42.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,208,376.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,269,14.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,291,3.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,301,59.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,303,1.530,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,306,141.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,307,306.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,539,12.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125339,606,9.410,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125340,203,5.260,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,204,8.770,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,205,45.600,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,208,281.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,269,24.600,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,291,1.800,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,301,25.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,303,1.750,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,306,96.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,307,167.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,328,0.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,401,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,539,22.800,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,601,35.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,605,0.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125340,606,0.880,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125341,203,8.060,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,204,8.060,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,205,50.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,208,306.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,269,6.450,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,291,4.800,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,301,32.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,303,2.580,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,306,177.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,307,258.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,328,0.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,539,4.800,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,601,0.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,605,0.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125341,606,3.230,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125342,203,7.140,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,204,14.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,205,53.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,208,393.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,269,14.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,291,7.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,301,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,303,2.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,306,321.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,307,214.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,539,10.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125342,606,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,203,10.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,204,4.390,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,205,50.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,208,281.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,269,5.260,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,291,3.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,301,88.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,303,2.810,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,306,158.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,307,526.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,539,3.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125343,606,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125344,203,12.000,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,204,10.300,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,205,26.500,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,208,248.000,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,269,2.560,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,291,1.700,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,301,285.000,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,303,1.710,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,306,68.000,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,307,487.000,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,328,0.000,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,401,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,539,0.900,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,601,26.000,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,605,0.000,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125344,606,5.130,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,203,12.900,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,204,10.300,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,205,27.600,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,207,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,208,250.000,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,255,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,269,2.590,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,291,1.700,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,301,293.000,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,303,1.550,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,306,78.000,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,307,500.000,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,320,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,328,0.000,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,401,NULL,'100g',NULL,3,'2024-12-12','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,539,0.900,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,601,26.000,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,605,0.000,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125345,606,5.170,'100g',6,3,'2024-08-15','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125346,203,12.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,204,10.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,205,26.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,208,248.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,269,2.560,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,291,1.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,301,288.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,303,1.710,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,306,64.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,307,487.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,539,0.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,601,26.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125346,606,5.130,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,203,12.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,204,10.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,205,26.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,208,241.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,269,2.590,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,291,1.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,301,290.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,303,1.720,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,306,65.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,307,491.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,539,0.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,601,26.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125347,606,5.170,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,203,4.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,204,6.860,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,205,50.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,208,275.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,269,25.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,291,2.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,301,25.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,303,1.960,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,306,113.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,307,176.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,539,24.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,601,29.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125348,606,0.980,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,203,5.260,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,204,8.770,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,205,50.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,208,298.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,269,26.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,291,1.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,301,26.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,303,1.750,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,306,105.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,307,175.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,539,26.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,601,35.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125349,606,1.750,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,203,5.880,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,204,17.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,205,54.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,208,368.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,269,19.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,291,2.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,301,53.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,303,1.470,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,306,206.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,307,426.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,539,16.200,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,601,59.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125350,606,1.470,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,203,5.880,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,204,17.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,205,54.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,208,368.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,269,19.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,291,2.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,301,53.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,303,1.470,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,306,206.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,307,426.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,539,16.200,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,601,59.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125351,606,1.470,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,203,13.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,204,8.970,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,205,22.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,208,221.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,269,2.070,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,291,2.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,301,290.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,303,1.380,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,306,186.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,307,338.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,539,0.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,601,24.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125352,606,4.830,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,203,12.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,204,7.780,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,205,24.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,208,216.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,269,1.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,291,2.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,301,251.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,303,1.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,306,192.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,307,323.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,539,0.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,601,21.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125353,606,4.190,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125354,203,13.800,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,204,8.970,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,205,22.100,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,208,221.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,269,2.070,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,291,2.100,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,301,290.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,303,1.380,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,306,186.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,307,338.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,328,0.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,401,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,539,0.700,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,601,24.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,605,0.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125354,606,4.830,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125355,203,12.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,204,7.780,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,205,24.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,208,216.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,269,1.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,291,2.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,301,251.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,303,1.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,306,192.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,307,323.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,539,0.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,601,21.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125355,606,4.190,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,203,12.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,204,6.920,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,205,25.200,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,208,214.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,269,1.890,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,291,2.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,301,201.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,303,1.640,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,306,201.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,307,371.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,539,0.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,601,22.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125356,606,3.140,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125357,203,16.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,204,12.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,205,28.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,208,280.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,269,1.600,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,291,2.400,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,301,336.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,303,1.680,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,306,160.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,307,360.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,328,0.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,401,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,539,0.800,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,601,28.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,605,0.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125357,606,5.600,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125358,203,15.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,204,11.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,205,30.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,208,282.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,269,1.410,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,291,2.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,301,296.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,303,1.830,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,306,169.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,307,352.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,539,0.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,601,25.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125358,606,4.930,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125359,203,16.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,204,12.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,205,28.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,208,280.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,269,1.600,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,291,2.400,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,301,336.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,303,1.680,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,306,160.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,307,360.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,328,0.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,401,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,539,0.800,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,601,28.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,605,0.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125359,606,5.600,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,203,15.500,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,204,11.300,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,205,30.300,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,208,282.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,269,1.410,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,291,2.800,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,301,296.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,303,1.760,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,306,169.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,307,352.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,328,0.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,401,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,539,0.700,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,601,25.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,605,0.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125360,606,4.930,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125361,203,15.800,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,204,13.400,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,205,22.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,208,256.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,269,3.660,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,291,2.400,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,301,149.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,303,1.100,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,306,280.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,307,476.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,328,0.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,539,2.400,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,601,37.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,605,0.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125361,606,4.880,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125362,203,12.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,204,11.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,205,26.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,208,254.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,269,4.230,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,291,2.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,301,185.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,303,1.270,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,306,282.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,307,408.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,539,2.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,601,92.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125362,606,4.230,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,203,11.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,204,12.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,205,26.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,208,254.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,269,4.230,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,291,2.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,301,137.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,303,1.270,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,306,127.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,307,507.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,539,2.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,601,99.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125363,606,5.630,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,203,15.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,204,16.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,205,22.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,208,313.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,269,1.740,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,291,3.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,301,374.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,303,1.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,306,26.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,307,504.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,539,1.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,601,35.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125364,606,7.830,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125365,203,15.600,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,204,11.300,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,205,22.600,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,208,270.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,269,1.740,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,291,3.500,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,301,391.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,303,1.300,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,306,0.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,307,487.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,328,0.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,401,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,539,1.700,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,601,26.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,605,0.000,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125365,606,6.090,'100g',6,3,'2024-08-15','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125366,203,25.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,204,21.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,205,3.570,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,208,321.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,269,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,291,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,301,750.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,303,0.360,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,306,179.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,307,750.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,601,71.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125366,606,12.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,203,25.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,204,32.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,205,3.570,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,208,393.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,269,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,291,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,301,693.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,303,0.710,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,306,107.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,307,607.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,328,1.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,601,107.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125367,606,17.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,203,25.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,204,21.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,205,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,208,286.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,269,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,291,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,301,714.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,303,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,306,86.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,307,714.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,601,54.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125368,606,12.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,203,25.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,204,21.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,205,3.570,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,208,321.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,269,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,291,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,301,714.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,303,0.360,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,306,179.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,307,679.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,601,71.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125369,606,12.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,203,25.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,204,25.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,205,3.570,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,208,321.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,269,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,291,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,301,750.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,303,0.360,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,306,179.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,307,786.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,601,71.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125370,606,14.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,203,17.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,204,28.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,205,7.140,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,208,357.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,269,3.570,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,291,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,301,500.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,303,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,306,182.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,307,1500.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,601,89.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125371,606,17.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,203,21.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,204,32.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,205,3.570,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,208,393.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,269,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,291,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,301,714.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,303,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,306,71.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,307,679.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,328,1.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,601,107.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125372,606,17.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,203,21.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,204,32.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,205,3.570,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,208,357.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,269,3.570,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,291,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,301,607.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,303,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,306,179.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,307,1250.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,601,89.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125373,606,17.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125374,203,21.400,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,204,32.100,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,205,3.570,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,207,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,208,393.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,255,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,269,3.570,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,291,0.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,301,607.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,303,0.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,306,179.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,307,1250.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,320,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,328,0.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,401,NULL,'100g',NULL,3,'2024-12-12','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,539,0.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,601,89.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,605,0.000,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125374,606,17.900,'100g',6,3,'2024-08-15','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125375,203,28.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,204,21.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,205,3.570,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,208,321.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,269,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,291,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,301,714.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,303,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,306,71.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,307,750.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,601,71.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125375,606,12.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,203,17.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,204,32.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,205,7.140,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,208,357.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,269,3.570,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,291,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,301,500.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,303,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,306,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,307,1610.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,601,89.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125376,606,17.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125377,203,9.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,204,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,205,31.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,208,110.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,269,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,291,16.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,301,17.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,303,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,306,720.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,307,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125377,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,203,9.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,204,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,205,31.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,208,110.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,269,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,291,16.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,301,17.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,303,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,306,720.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,307,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125378,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125379,203,9.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,204,4.650,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,205,76.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,208,372.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,269,25.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,291,9.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,301,47.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,303,2.790,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,306,349.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,307,372.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,539,18.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125379,606,1.160,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125380,203,2.050,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,204,0.286,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,205,6.820,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,208,36.900,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,269,0.770,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,291,1.640,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,301,21.100,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,303,0.757,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,306,150.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,307,431.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,328,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,401,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,539,0.346,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,601,0.002,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,605,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125380,606,0.061,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,203,1.870,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,204,0.176,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,205,6.050,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,208,33.400,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,269,0.614,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,291,1.390,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,301,15.200,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,303,0.599,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,306,133.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,307,349.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,328,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,401,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,539,0.223,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,601,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,605,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125381,606,0.037,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,203,5.730,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,204,3.290,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,205,16.700,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,208,117.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,269,0.926,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,291,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,301,45.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,303,1.520,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,306,405.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,307,337.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,328,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,401,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,539,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,601,2.790,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,605,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125382,606,1.250,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,203,5.730,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,204,3.290,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,205,16.700,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,208,117.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,269,0.926,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,291,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,301,45.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,303,1.520,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,306,405.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,307,337.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,328,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,401,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,539,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,601,2.790,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,605,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125383,606,1.250,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,203,5.250,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,204,1.710,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,205,15.800,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,208,98.700,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,269,1.060,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,291,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,301,37.200,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,303,1.490,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,306,363.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,307,328.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,328,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,401,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,539,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,601,1.300,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,605,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125384,606,0.600,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,203,5.250,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,204,1.710,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,205,15.800,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,207,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,208,98.700,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,255,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,269,1.060,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,291,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,301,37.200,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,303,1.490,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,306,363.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,307,328.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,320,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,328,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,401,NULL,'100g',NULL,3,'2024-12-12','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,539,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,601,1.300,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,605,0.000,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125385,606,0.600,'100g',6,3,'2024-05-16','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125386,203,0.710,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,205,13.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,208,57.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,269,10.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,291,1.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,306,193.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,307,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,539,6.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125386,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,203,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,204,0.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,205,7.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,208,48.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,269,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,291,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,301,10.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,306,100.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,307,8.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125387,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125388,203,0.330,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,204,0.000,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,205,16.700,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,207,NULL,'100ml',NULL,3,'2024-12-12','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,208,70.000,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,255,NULL,'100ml',NULL,3,'2024-12-12','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,269,12.000,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,291,0.700,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,301,10.000,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,303,0.130,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,306,153.000,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,307,5.000,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,320,NULL,'100ml',NULL,3,'2024-12-12','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,328,0.000,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,401,24.000,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,539,0.000,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,601,0.000,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,605,0.000,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125388,606,0.000,'100ml',6,3,'2024-03-14','2024-03-14');
INSERT INTO `cndb_nutval` VALUES (125398,203,3.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,204,0.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,205,9.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,208,56.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,269,4.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,291,2.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,301,20.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,303,1.120,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,306,80.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,307,240.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,320,40.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,401,7.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,539,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125398,606,0.070,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125399,203,18.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,204,46.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,205,29.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,208,568.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,269,16.200,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,291,8.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,301,54.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,303,5.950,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,306,541.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,307,284.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,539,16.200,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125399,606,6.760,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125400,203,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,204,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,205,21.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,208,100.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,269,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,291,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,306,110.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,307,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,320,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,401,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125400,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,203,0.833,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,205,2.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,208,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,269,0.833,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,291,0.833,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,301,21.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,303,0.833,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,306,52.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,307,100.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125401,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125402,203,12.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,204,7.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,205,67.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,208,375.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,269,2.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,291,10.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,301,50.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,303,3.750,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,306,375.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,307,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125402,606,1.250,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125403,203,21.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,204,53.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,205,21.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,208,625.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,269,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,291,6.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,301,69.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,303,4.380,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,306,650.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,307,375.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,539,9.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125403,606,9.380,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,205,3.330,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,208,16.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,269,1.670,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,291,0.833,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,301,30.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,306,106.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,307,100.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125404,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,203,7.110,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,204,1.750,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,205,79.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,208,370.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,269,1.610,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,291,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,301,3.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,303,1.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,306,142.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,307,7.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125405,606,0.220,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,205,3.330,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,208,16.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,269,1.670,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,291,0.833,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,301,30.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,306,106.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,307,100.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125406,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,203,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,205,5.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,208,36.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,269,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,291,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,301,14.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,303,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,306,122.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,307,104.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125407,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,203,6.150,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,204,1.150,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,205,17.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,208,108.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,269,0.769,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,291,4.620,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,301,38.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,303,1.540,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,306,408.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,307,108.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125408,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,203,0.606,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,205,8.480,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,208,36.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,269,0.606,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,291,1.210,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,301,6.060,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,303,0.788,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,306,139.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,307,84.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125409,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,203,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,204,0.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,205,7.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,208,48.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,269,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,291,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,301,10.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,306,100.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,307,8.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125410,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,203,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,204,1.530,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,205,72.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,208,361.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,269,0.689,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,291,2.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,301,19.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,303,1.070,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,306,113.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,307,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125411,606,0.218,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,203,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,205,5.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,208,36.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,269,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,291,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,301,14.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,303,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,306,122.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,307,16.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125412,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,203,0.833,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,205,2.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,208,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,269,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,291,0.833,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,301,20.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,303,0.833,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,306,50.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,307,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125413,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,203,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,204,2.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,205,73.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,208,354.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,269,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,291,17.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,301,33.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,303,3.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,306,452.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,307,12.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125414,606,0.482,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,203,12.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,204,1.050,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,205,72.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,208,360.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,269,3.510,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,291,3.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,301,17.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,303,1.230,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,306,186.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,307,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125415,606,0.150,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125416,203,12.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,204,7.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,205,67.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,208,375.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,269,2.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,291,10.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,301,50.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,303,3.750,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,306,375.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,307,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125416,606,1.250,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,203,9.330,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,204,9.330,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,205,69.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,208,373.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,269,25.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,291,8.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,301,67.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,303,2.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,306,360.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,307,200.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,539,21.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125417,606,1.330,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,203,12.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,204,7.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,205,67.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,208,375.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,269,2.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,291,10.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,301,50.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,303,3.750,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,306,375.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,307,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125418,606,1.250,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,203,13.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,204,5.630,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,205,23.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,208,197.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,269,4.930,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,291,0.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,301,282.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,303,1.410,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,306,232.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,307,317.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,539,2.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,601,14.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125419,606,2.460,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,203,12.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,204,9.150,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,205,24.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,208,225.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,269,4.230,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,291,0.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,301,280.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,303,1.410,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,306,228.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,307,331.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,539,2.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,601,25.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125420,606,4.230,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,203,14.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,204,9.860,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,205,25.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,208,246.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,269,4.230,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,291,0.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,301,260.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,303,1.410,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,306,187.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,307,380.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,539,2.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,601,28.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,605,0.350,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125421,606,4.930,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,203,13.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,204,7.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,205,22.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,208,199.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,269,4.260,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,291,2.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,301,213.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,303,1.280,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,306,50.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,307,418.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,328,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,539,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,601,18.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,605,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125422,606,4.260,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,203,5.220,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,204,3.250,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,205,16.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,208,115.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,269,2.690,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,291,5.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,301,40.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,303,1.830,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,306,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,307,237.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,328,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,401,12.200,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,539,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,605,0.050,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125423,606,0.490,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,203,12.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,204,5.970,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,205,8.990,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,208,142.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,269,1.760,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,291,1.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,301,21.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,303,1.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,306,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,307,516.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,328,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,401,7.200,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,539,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,601,39.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,605,0.080,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125424,606,1.790,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125426,203,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,205,23.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,208,100.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,269,17.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,291,3.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,301,20.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,303,0.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,306,290.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125426,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,203,3.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,205,79.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,208,300.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,269,59.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,291,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,301,50.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,303,1.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,306,749.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,307,20.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125427,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125428,203,12.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,204,9.090,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,205,25.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,208,238.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,269,2.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,291,3.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,301,231.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,303,2.030,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,306,231.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,307,469.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,401,2.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,539,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,601,17.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125428,606,4.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,203,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,204,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,205,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,207,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,208,90.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,255,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,269,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,291,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,301,20.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,303,0.500,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,306,240.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,307,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,328,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,401,86.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,539,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,601,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,605,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125429,606,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,203,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,204,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,205,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,207,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,208,90.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,255,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,269,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,291,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,301,20.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,303,0.500,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,306,240.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,307,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,328,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,401,86.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,539,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,601,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,605,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125430,606,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,203,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,204,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,205,8.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,207,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,208,90.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,255,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,269,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,291,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,301,20.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,303,0.500,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,306,240.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,307,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,328,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,401,86.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,539,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,601,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,605,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125431,606,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,203,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,204,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,205,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,207,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,208,90.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,255,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,269,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,291,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,301,20.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,303,0.500,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,306,240.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,307,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,328,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,401,86.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,539,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,601,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,605,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125432,606,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,203,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,204,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,205,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,207,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,208,90.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,255,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,269,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,291,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,301,20.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,303,0.500,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,306,240.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,307,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,328,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,401,86.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,539,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,601,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,605,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125433,606,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,203,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,204,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,205,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,207,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,208,90.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,255,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,269,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,291,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,301,20.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,303,0.500,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,306,240.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,307,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,328,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,401,86.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,539,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,601,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,605,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125434,606,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,203,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,204,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,205,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,207,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,208,90.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,255,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,269,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,291,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,301,20.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,303,0.500,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,306,240.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,307,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,328,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,401,86.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,539,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,601,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,605,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125435,606,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,203,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,204,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,205,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,207,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,208,90.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,255,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,269,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,291,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,301,20.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,303,0.500,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,306,240.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,307,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,328,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,401,86.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,539,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,601,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,605,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125436,606,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,203,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,204,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,205,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,207,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,208,90.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,255,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,269,22.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,291,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,301,20.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,303,0.500,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,306,240.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,307,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,320,NULL,'100ml',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,328,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,401,86.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,539,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,601,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,605,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125437,606,0.000,'100ml',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,203,13.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,204,9.520,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,205,26.200,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,208,254.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,269,3.170,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,291,3.200,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,301,270.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,303,2.220,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,306,103.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,307,587.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,401,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,539,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,601,24.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125438,606,4.760,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125439,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,205,13.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,208,47.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,269,11.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,291,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,301,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,306,70.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,401,46.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,539,2.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125439,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,203,0.780,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,205,14.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,208,62.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,269,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,291,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,301,11.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,303,0.280,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,306,16.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,307,16.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,320,56.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,401,46.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,539,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125440,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,205,14.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,208,55.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,269,11.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,291,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,301,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,306,109.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,401,46.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,539,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125441,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,205,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,208,47.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,269,10.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,291,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,301,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,303,0.280,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,306,98.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,401,86.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125442,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,205,13.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,208,47.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,269,11.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,291,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,301,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,306,70.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,401,46.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,539,2.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125443,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,205,13.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,208,47.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,269,11.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,291,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,301,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,306,70.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,401,71.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,539,2.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125444,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125445,203,12.400,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,204,8.850,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,205,25.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,208,230.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,269,1.770,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,291,1.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,301,273.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,303,1.770,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,306,101.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,307,372.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,328,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,539,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,601,22.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,605,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125445,606,3.980,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125446,203,0.780,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,205,14.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,208,62.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,269,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,291,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,301,11.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,306,8.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,401,71.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125446,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,205,13.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,208,55.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,269,13.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,291,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,301,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,303,2.340,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,306,55.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,307,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,320,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,401,37.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125447,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125448,203,0.780,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,204,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,205,14.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,208,55.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,269,12.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,291,0.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,301,5.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,303,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,306,39.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,307,8.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,328,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,401,46.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125448,606,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125449,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,205,14.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,208,55.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,269,11.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,291,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,301,5.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,306,31.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,307,4.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,401,71.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125449,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,205,59.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,208,243.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,269,51.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,291,2.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,301,16.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,303,2700.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,306,295.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,307,14.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,320,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,401,246.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125450,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125451,203,12.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,204,9.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,205,26.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,208,248.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,269,3.540,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,291,3.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,301,205.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,303,2.330,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,306,269.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,307,530.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,401,2.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,539,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,601,14.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125451,606,4.240,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,203,14.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,204,9.520,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,205,30.200,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,208,254.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,269,3.170,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,291,3.200,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,301,317.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,303,1.590,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,306,159.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,307,492.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,539,1.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,601,32.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125452,606,5.560,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,203,14.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,204,11.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,205,25.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,208,259.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,269,3.230,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,291,1.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,301,356.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,303,1.620,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,306,178.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,307,533.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,401,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,539,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,601,32.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125453,606,6.460,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,203,10.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,204,8.240,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,205,32.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,208,247.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,269,1.180,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,291,3.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,301,229.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,303,2.120,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,306,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,307,435.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,401,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,539,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,601,24.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125454,606,4.710,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,203,10.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,204,10.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,205,28.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,208,235.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,269,3.360,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,291,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,301,146.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,303,1.570,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,306,146.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,307,403.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,401,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,539,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,601,56.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125455,606,3.360,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,203,14.200,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,204,6.600,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,205,28.300,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,208,226.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,269,2.830,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,291,3.800,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,301,236.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,303,1.980,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,306,170.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,307,443.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,401,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,539,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,601,24.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125456,606,3.770,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125457,203,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,205,32.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,208,120.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,269,26.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,291,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,301,20.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,303,0.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,306,300.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,307,10.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125457,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,203,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,205,30.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,208,110.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,269,25.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,291,3.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,301,10.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,303,0.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,306,260.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125458,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125459,203,1.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,204,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,205,32.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,208,120.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,269,26.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,291,2.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,301,20.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,303,0.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,306,300.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,307,10.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,539,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,601,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,605,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125459,606,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125460,203,2.650,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,205,79.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,208,292.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,269,66.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,291,5.310,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,301,61.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,303,2.650,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,306,743.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,307,26.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125460,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,205,18.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,208,72.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,269,15.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,291,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,301,10.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,306,106.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,539,8.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125461,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,205,16.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,208,62.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,269,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,291,1.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,301,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,306,141.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,307,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,539,0.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125462,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,203,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,205,15.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,208,60.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,269,13.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,291,2.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,301,14.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,303,0.380,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,306,141.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,307,1.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,328,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,539,8.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125463,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,203,18.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,204,56.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,205,25.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,208,157.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,269,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,291,6.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,301,94.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,303,9.380,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,306,794.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,307,281.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,539,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125464,606,9.380,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,203,21.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,204,53.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,205,21.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,208,625.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,269,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,291,6.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,301,69.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,303,4.380,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,306,650.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,307,375.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,539,9.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125465,606,9.380,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,203,21.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,204,53.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,205,18.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,208,625.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,269,9.380,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,291,6.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,301,74.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,303,4.690,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,306,709.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,307,309.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,539,9.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125466,606,6.250,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125467,203,6.270,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,204,27.100,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,205,61.900,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,207,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,208,506.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,255,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,269,2.640,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,291,5.500,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,301,41.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,303,1.880,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,306,284.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,307,718.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,320,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,328,0.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,401,NULL,'100g',NULL,3,'2024-12-12','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,539,0.200,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,601,2.000,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,605,0.370,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125467,606,3.700,'100g',6,3,'2024-08-15','2024-08-15');
INSERT INTO `cndb_nutval` VALUES (125468,203,7.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,204,19.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,205,67.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,208,473.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,269,0.910,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,291,5.480,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,301,91.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,303,1.830,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,306,82.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,307,395.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,605,0.240,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125468,606,2.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,203,12.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,204,6.250,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,205,67.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,208,375.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,269,2.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,291,10.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,301,45.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,303,3.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,306,318.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125469,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,203,7.370,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,204,20.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,205,68.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,208,478.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,269,0.920,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,291,5.530,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,301,92.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,303,1.840,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,306,82.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,307,5.530,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,605,0.250,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125470,606,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,203,25.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,204,21.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,205,7.140,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,208,296.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,269,3.570,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,291,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,301,696.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,306,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,307,600.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,320,221.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,401,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,601,57.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125471,606,10.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,203,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,204,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,205,82.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,208,334.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,269,69.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,291,6.080,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,301,12.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,303,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,306,51.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,307,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,539,66.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,605,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125472,606,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,203,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,204,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,205,12.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,207,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,208,50.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,255,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,269,10.500,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,291,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,301,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,303,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,306,122.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,307,3.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,320,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,328,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,401,NULL,'100ml',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,539,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,601,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,605,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125473,606,0.000,'100ml',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,203,7.370,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,204,20.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,205,68.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,208,478.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,269,0.920,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,291,5.530,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,301,92.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,303,1.840,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,306,82.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,307,5.530,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,605,0.250,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125474,606,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,203,7.370,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,204,20.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,205,68.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,208,478.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,269,0.920,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,291,5.530,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,301,92.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,303,1.840,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,306,82.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,307,5.530,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,605,0.250,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125475,606,2.600,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,203,7.340,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,204,20.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,205,67.900,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,208,475.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,269,0.920,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,291,5.510,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,301,92.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,303,1.840,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,306,82.700,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,307,397.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,605,0.240,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125476,606,2.580,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,203,6.320,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,204,19.800,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,205,70.100,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,208,473.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,269,0.580,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,291,6.660,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,301,6.620,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,303,2.170,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,306,262.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,307,393.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,605,0.240,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125477,606,2.610,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,203,7.300,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,204,20.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,205,67.500,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,207,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,208,473.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,255,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,269,0.910,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,291,5.470,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,301,91.400,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,303,1.830,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,306,82.200,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,307,394.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,320,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,328,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,401,NULL,'100g',NULL,3,'2024-12-12','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,539,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,601,0.000,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,605,0.240,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125478,606,2.580,'100g',6,3,'2024-12-19','2024-12-19');
INSERT INTO `cndb_nutval` VALUES (125479,203,4.800,'100g',6,3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,204,6.700,'100g',6,3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,205,41.200,'100g',6,3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,207,NULL,'100g',NULL,3,'2024-12-12','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,208,228.000,'100g',6,3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,255,NULL,'100g',NULL,3,'2024-12-12','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,269,11.800,'100g',6,3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,291,4.400,'100g',6,3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,301,54.000,'100g',6,3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,303,4.200,'100g',6,3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,306,151.000,'100g',6,3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,307,242.000,'100g',6,3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,320,NULL,'100g',NULL,3,'2024-12-12','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,328,0.000,'100g',6,3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,401,NULL,'100g',NULL,3,'2024-12-12','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,539,11.600,'100g',6,3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,601,1.000,'100g',6,3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,605,0.100,'100g',6,3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125479,606,1.000,'100g',6,3,'2024-04-18','2024-04-18');
INSERT INTO `cndb_nutval` VALUES (125480,203,12.900,'100g',6,3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,204,10.300,'100g',6,3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,205,27.600,'100g',6,3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,207,NULL,'100g',NULL,3,'2025-01-13','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,208,250.000,'100g',6,3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,255,NULL,'100g',NULL,3,'2025-01-13','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,269,2.590,'100g',6,3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,291,1.700,'100g',6,3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,301,293.000,'100g',6,3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,303,1.550,'100g',6,3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,306,78.000,'100g',6,3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,307,500.000,'100g',6,3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,320,NULL,'100g',NULL,3,'2025-01-13','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,328,0.000,'100g',6,3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,401,NULL,'100g',NULL,3,'2025-01-13','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,539,0.900,'100g',6,3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,601,26.000,'100g',6,3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,605,0.000,'100g',6,3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125480,606,5.170,'100g',6,3,'2025-01-23','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125481,203,12.100,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,204,10.300,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,205,26.700,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,207,NULL,'100g',NULL,3,'2025-01-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,208,241.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,255,NULL,'100g',NULL,3,'2025-01-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,269,2.590,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,291,1.700,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,301,290.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,303,1.720,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,306,65.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,307,491.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,320,NULL,'100g',NULL,3,'2025-01-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,328,0.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,401,NULL,'100g',NULL,3,'2025-01-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,539,0.900,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,601,26.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,605,0.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125481,606,5.170,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,203,14.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,204,15.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,205,15.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,207,NULL,'100g',NULL,3,'2025-01-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,208,250.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,255,NULL,'100g',NULL,3,'2025-01-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,269,0.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,291,2.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,301,41.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,303,2.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,306,165.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,307,570.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,320,0.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,328,0.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,401,0.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,539,0.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,601,40.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,605,0.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125482,606,3.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125483,203,0.000,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,204,0.000,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,205,0.000,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,207,NULL,'100ml',NULL,3,'2025-01-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,208,0.000,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,255,NULL,'100ml',NULL,3,'2025-01-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,269,0.000,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,291,0.000,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,301,0.000,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,303,0.000,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,306,0.000,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,307,2.000,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,320,NULL,'100ml',NULL,3,'2025-01-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,328,0.000,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,401,0.100,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,539,0.000,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,601,0.000,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,605,0.000,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125483,606,0.000,'100ml',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,203,0.000,'100g',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,204,0.000,'100g',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,205,16.800,'100g',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,207,NULL,'100g',NULL,3,'2025-01-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,208,67.200,'100g',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,255,NULL,'100g',NULL,3,'2025-01-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,269,12.800,'100g',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,291,1.600,'100g',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,301,3.200,'100g',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,303,0.000,'100g',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,306,128.000,'100g',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,307,0.000,'100g',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,320,NULL,'100g',NULL,3,'2025-01-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,328,0.000,'100g',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,401,NULL,'100g',NULL,3,'2025-01-13','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,539,6.400,'100g',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,601,0.000,'100g',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,605,0.000,'100g',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125484,606,0.000,'100g',6,3,'2025-01-23','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125485,203,14.600,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,204,14.600,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,205,2.440,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,207,NULL,'100g',NULL,3,'2025-01-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,208,220.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,255,NULL,'100g',NULL,3,'2025-01-13','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,269,2.440,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,291,0.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,301,0.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,303,0.020,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,306,832.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,307,488.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,320,0.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,328,0.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,401,0.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,539,2.400,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,601,73.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,605,0.000,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125485,606,7.320,'100g',6,3,'2025-01-23','2025-01-23');
INSERT INTO `cndb_nutval` VALUES (125486,203,3.700,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,204,4.760,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,205,10.600,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,208,101.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,269,3.700,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,291,0.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,301,26.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,303,0.850,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,306,177.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,307,349.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,320,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,401,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,539,0.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,601,13.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125486,606,1.850,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,203,3.700,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,204,4.760,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,205,10.600,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,208,101.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,269,3.700,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,291,0.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,301,26.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,303,0.850,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,306,177.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,307,349.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,320,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,401,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,539,0.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,601,13.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125487,606,1.850,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,203,1.770,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,204,3.980,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,205,18.600,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,208,106.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,269,8.850,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,291,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,301,57.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,303,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,306,80.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,307,40.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,320,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,401,80.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,539,7.100,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,601,18.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125488,606,2.650,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,203,16.600,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,204,17.300,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,205,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,208,222.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,269,0.110,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,291,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,301,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,303,0.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,306,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,307,64.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,320,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,328,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,401,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,539,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,601,60.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,605,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125489,606,5.030,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,203,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,204,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,205,16.700,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,208,63.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,269,13.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,291,0.800,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,301,9.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,303,794.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,306,71.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,307,4.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,320,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,401,72.200,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,539,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,601,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125490,606,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,203,10.700,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,204,14.300,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,205,53.600,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,208,393.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,269,17.900,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,291,7.100,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,301,93.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,303,3.860,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,306,321.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,307,214.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,320,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,401,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,539,14.300,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,601,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125491,606,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,203,0.260,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,204,0.070,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,205,12.100,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,208,50.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,269,8.320,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,291,2.800,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,301,8.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,303,0.260,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,306,86.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,307,42.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,320,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,401,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,539,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,601,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125492,606,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,203,6.350,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,204,11.100,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,205,76.200,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,208,444.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,269,9.520,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,291,6.300,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,301,32.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,303,0.950,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,306,762.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,307,508.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,320,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,401,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,539,9.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,601,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125493,606,1.590,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,203,7.140,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,204,35.700,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,205,57.100,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,208,571.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,269,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,291,3.600,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,301,143.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,303,0.710,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,306,107.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,307,536.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,320,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,401,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,539,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,601,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125494,606,5.360,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,203,8.330,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,204,5.210,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,205,77.100,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,208,375.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,269,29.200,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,291,6.200,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,301,42.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,303,2.710,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,306,271.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,307,604.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,320,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,401,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,539,29.200,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,601,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125495,606,1.040,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,203,0.020,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,204,0.000,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,205,0.450,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,207,NULL,'100ml',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,208,2.000,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,255,NULL,'100ml',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,269,0.400,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,291,0.000,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,301,0.000,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,303,0.010,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,306,6.000,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,307,0.000,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,320,2.000,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,328,0.000,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,401,0.300,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,539,0.000,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,601,0.000,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,605,0.000,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125496,606,0.000,'100ml',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,203,8.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,204,9.330,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,205,72.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,208,387.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,269,29.300,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,291,6.700,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,301,40.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,303,2.270,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,306,347.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,307,333.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,320,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,401,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,539,22.700,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,601,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125497,606,1.330,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,203,7.140,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,204,10.700,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,205,78.600,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,208,464.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,269,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,291,7.100,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,301,107.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,303,1.070,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,306,179.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,307,375.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,320,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,401,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,539,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,601,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125498,606,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,203,7.140,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,204,21.400,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,205,67.900,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,208,500.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,269,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,291,7.100,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,301,107.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,303,1.070,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,306,143.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,307,375.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,320,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,401,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,539,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,601,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125499,606,1.790,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,203,5.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,204,7.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,205,77.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,208,400.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,269,30.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,291,5.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,301,488.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,303,1.800,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,306,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,307,338.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,320,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,328,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,401,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,539,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,601,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125500,606,2.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,203,12.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,204,7.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,205,67.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,208,375.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,269,2.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,291,10.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,301,50.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,303,3.750,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,306,375.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,307,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,320,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,401,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,539,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,601,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125501,606,1.250,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,203,7.140,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,204,10.700,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,205,78.600,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,208,429.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,269,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,291,7.100,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,301,107.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,303,1.070,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,306,179.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,307,500.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,320,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,401,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,539,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,601,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125502,606,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,203,19.400,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,204,38.700,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,205,35.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,208,452.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,269,12.900,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,291,6.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,301,45.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,303,3.230,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,306,513.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,307,306.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,320,12.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,401,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,539,12.900,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,601,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125503,606,6.450,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,203,0.780,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,204,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,205,16.400,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,208,70.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,269,14.100,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,291,0.800,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,301,5.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,303,781.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,306,62.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,307,12.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,320,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,401,46.900,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,539,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,601,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125504,606,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,203,5.560,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,204,25.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,205,22.200,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,208,333.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,269,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,291,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,301,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,303,5.560,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,306,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,307,667.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,320,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,401,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,539,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,601,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125505,606,16.700,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,203,4.710,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,204,9.410,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,205,50.600,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,208,294.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,269,22.400,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,291,2.350,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,301,35.300,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,303,2.350,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,306,138.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,307,282.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,320,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,401,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,539,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,601,23.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125506,606,1.180,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,203,1.770,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,204,3.980,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,205,18.600,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,207,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,208,106.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,255,NULL,'100g',NULL,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,269,8.850,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,291,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,301,57.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,303,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,306,80.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,307,40.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,320,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,328,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,401,80.500,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,539,7.100,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,601,18.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,605,0.000,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125507,606,2.650,'100g',6,3,'2025-03-20','2025-03-20');
INSERT INTO `cndb_nutval` VALUES (125508,203,1.980,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,204,1.590,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,205,17.500,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,207,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,208,89.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,255,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,269,11.900,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,291,0.400,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,301,54.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,303,0.400,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,306,127.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,307,50.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,320,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,328,3.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,401,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,539,4.800,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,601,2.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,605,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125508,606,0.600,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,203,1.980,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,204,1.590,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,205,17.500,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,207,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,208,89.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,255,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,269,12.300,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,291,0.400,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,301,54.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,303,0.400,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,306,127.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,307,50.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,320,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,328,3.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,401,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,539,4.800,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,601,2.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,605,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125509,606,0.600,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,203,16.500,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,204,15.400,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,205,18.900,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,207,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,208,280.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,255,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,269,1.480,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,291,2.630,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,301,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,303,2.550,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,306,477.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,307,313.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,320,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,328,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,401,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,539,0.250,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,601,35.100,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,605,0.460,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125510,606,4.430,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,203,16.800,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,204,13.900,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,205,18.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,207,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,208,264.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,255,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,269,1.180,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,291,2.860,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,301,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,303,2.800,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,306,405.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,307,201.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,320,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,328,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,401,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,539,0.130,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,601,31.500,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,605,0.410,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125511,606,3.990,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,203,7.840,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,204,2.940,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,205,43.100,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,207,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,208,216.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,255,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,269,1.960,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,291,5.900,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,301,16.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,303,1.960,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,306,157.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,307,451.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,320,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,328,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,401,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,539,2.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,601,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,605,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125512,606,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,203,1.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,204,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,205,32.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,207,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,208,110.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,255,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,269,26.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,291,2.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,301,20.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,303,0.700,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,306,280.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,307,10.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,320,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,328,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,401,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,539,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,601,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,605,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125513,606,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,203,6.280,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,204,8.240,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,205,27.600,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,207,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,208,205.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,255,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,269,18.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,291,1.700,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,301,86.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,303,2.760,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,306,207.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,307,408.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,320,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,328,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,401,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,539,0.800,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,601,21.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,605,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125514,606,4.180,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,203,7.350,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,204,17.600,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,205,51.500,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,207,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,208,397.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,255,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,269,13.200,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,291,4.400,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,301,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,303,3.240,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,306,147.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,307,294.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,320,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,328,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,401,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,539,13.200,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,601,7.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,605,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125515,606,6.620,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,203,7.350,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,204,17.600,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,205,51.500,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,207,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,208,397.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,255,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,269,13.200,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,291,4.400,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,301,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,303,3.240,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,306,147.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,307,294.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,320,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,328,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,401,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,539,13.200,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,601,7.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,605,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125516,606,6.620,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,203,7.350,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,204,17.600,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,205,50.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,207,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,208,382.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,255,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,269,11.800,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,291,4.400,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,301,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,303,3.240,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,306,162.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,307,324.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,320,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,328,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,401,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,539,10.300,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,601,7.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,605,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125517,606,6.620,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,203,11.500,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,204,4.420,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,205,34.500,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,207,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,208,221.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,255,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,269,5.310,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,291,2.700,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,301,44.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,303,3.360,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,306,407.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,307,327.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,320,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,328,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,401,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,539,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,601,9.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,605,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125518,606,1.770,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,203,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,204,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,205,27.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,207,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,208,110.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,255,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,269,24.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,291,2.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,301,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,303,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,306,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,307,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,320,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,328,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,401,NULL,'100g',NULL,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,539,22.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,601,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,605,0.000,'100g',6,3,'2025-04-24','2025-04-24');
INSERT INTO `cndb_nutval` VALUES (125519,606,0.000,'100g',6,3,'2025-04-24','2025-04-24');
UNLOCK TABLES;
/*!40000 ALTER TABLE `cndb_nutval` ENABLE KEYS */;
LOCK TABLES `cndb_fdes` WRITE;
/*!40000 ALTER TABLE `cndb_fdes` DISABLE KEYS */;
INSERT INTO `cndb_fdes` VALUES (1,'Butter, salted','BUTTER,WITH SALT',1001,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Butter, whipped, with salt','BUTTER,WHIPPED,W/ SALT',1002,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Butter oil, anhydrous','BUTTER OIL,ANHYDROUS',1003,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, blue','CHEESE,BLUE',1004,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, brick','CHEESE,BRICK',1005,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, brie','CHEESE,BRIE',1006,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, camembert','CHEESE,CAMEMBERT',1007,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, caraway','CHEESE,CARAWAY',1008,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cheddar (Includes foods for USDA''s Food Distribution Program)','CHEESE,CHEDDAR',1009,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cheshire','CHEESE,CHESHIRE',1010,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, colby','CHEESE,COLBY',1011,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cottage, creamed, large or small curd','CHEESE,COTTAGE,CRMD,LRG OR SML CURD',1012,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cottage, creamed, with fruit','CHEESE,COTTAGE,CRMD,W/FRUIT',1013,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cottage, nonfat, uncreamed, dry, large or small curd','CHEESE,COTTAGE,NONFAT,UNCRMD,DRY,LRG OR SML CURD',1014,NULL,NULL,NULL,NULL,NULL,1,'1995-06-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cottage, lowfat, 2% milkfat','CHEESE,COTTAGE,LOWFAT,2% MILKFAT',1015,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cottage, lowfat, 1% milkfat','CHEESE,COTTAGE,LOWFAT,1% MILKFAT',1016,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cream','CHEESE,CREAM',1017,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, edam','CHEESE,EDAM',1018,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, feta','CHEESE,FETA',1019,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, fontina','CHEESE,FONTINA',1020,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, gjetost','CHEESE,GJETOST',1021,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, gouda','CHEESE,GOUDA',1022,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, gruyere','CHEESE,GRUYERE',1023,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, limburger','CHEESE,LIMBURGER',1024,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, monterey','CHEESE,MONTEREY',1025,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, mozzarella, whole milk','CHEESE,MOZZARELLA,WHL MILK',1026,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, mozzarella, whole milk, low moisture','CHEESE,MOZZARELLA,WHL MILK,LO MOIST',1027,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, mozzarella, part skim milk','CHEESE,MOZZARELLA,PART SKIM MILK',1028,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, mozzarella, low moisture, part-skim','CHEESE,MOZZARELLA,LO MOIST,PART-SKIM',1029,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, muenster','CHEESE,MUENSTER',1030,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, neufchatel','CHEESE,NEUFCHATEL',1031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, parmesan, grated','CHEESE,PARMESAN,GRATED',1032,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, parmesan, hard','CHEESE,PARMESAN,HARD',1033,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, port de salut','CHEESE,PORT DE SALUT',1034,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, provolone','CHEESE,PROVOLONE',1035,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, ricotta, whole milk','CHEESE,RICOTTA,WHOLE MILK',1036,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, ricotta, part skim milk','CHEESE,RICOTTA,PART SKIM MILK',1037,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, romano','CHEESE,ROMANO',1038,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, roquefort','CHEESE,ROQUEFORT',1039,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, swiss','CHEESE,SWISS',1040,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, tilsit','CHEESE,TILSIT',1041,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, pasteurized process, American, fortified with vitamin D','CHEESE,PAST PROCESS,AMERICAN,FORT W/ VITAMIN D',1042,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, pasteurized process, pimento','CHEESE,PAST PROCESS,PIMENTO',1043,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, pasteurized process, swiss','CHEESE,PAST PROCESS,SWISS',1044,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese food, cold pack, American','CHEESE FD,COLD PK,AMERICAN',1045,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese food, pasteurized process, American, vitamin D fortified','CHEESE FD,PAST PROCESS,AMERICAN,VITAMIN D FORT',1046,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese food, pasteurized process, swiss','CHEESE FD,PAST PROCESS,SWISS',1047,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese spread, pasteurized process, American','CHEESE SPRD,PAST PROCESS,AMERICAN',1048,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream, fluid, half and half','CREAM,FLUID,HALF AND HALF',1049,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream, fluid, light (coffee cream or table cream)','CREAM,FLUID,LT (COFFEE CRM OR TABLE CRM)',1050,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream, fluid, light whipping','CREAM,FLUID,LT WHIPPING',1052,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream, fluid, heavy whipping','CREAM,FLUID,HVY WHIPPING',1053,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream, whipped, cream topping, pressurized','CREAM,WHIPPED,CRM TOPPING,PRESSURIZED',1054,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream, sour, reduced fat, cultured','CREAM,SOUR,RED FAT,CULTURED',1055,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream, sour, cultured','CREAM,SOUR,CULTURED',1056,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Eggnog','EGGNOG',1057,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Sour dressing, non-butterfat, cultured, filled cream-type','SOUR DRSNG,NON-BUTTERFAT,CULTURED,FILLED CREAM-TYPE',1058,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, filled, fluid, with blend of hydrogenated vegetable oils','MILK,FILLED,FLUID,W/BLEND OF HYDR VEG OILS',1059,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, filled, fluid, with lauric acid oil','MILK,FILLED,FLUID,W/LAURIC ACID OIL',1060,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, American, nonfat or fat free','CHEESE,AMERICAN,NONFAT OR FAT FREE',1061,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream substitute, liquid, with hydrogenated vegetable oil and soy protein','CREAM SUB,LIQ,W/HYDR VEG OIL&SOY PROT',1067,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream substitute, liquid, with lauric acid oil and sodium caseinate','CREAM SUB,LIQ,W/LAURIC ACID OIL&NA CASEINATE',1068,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream substitute, powdered','CREAM SUBSTITUTE,POWDERED',1069,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Dessert topping, powdered','DESSERT TOPPING,POWDERED',1070,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Dessert topping, powdered, 1.5 ounce prepared with 1/2 cup milk','DESSERT TOPPING,PDR,1.5 OZ PREP W/1/2 CUP MILK',1071,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Dessert topping, pressurized','DESSERT TOPPING,PRESSURIZED',1072,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Dessert topping, semi solid, frozen','DESSERT TOPPING,SEMI SOLID,FRZ',1073,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Sour cream, imitation, cultured','SOUR CRM,IMITN,CULTURED',1074,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk substitutes, fluid, with lauric acid oil','MILK SUBSTITUTES,FLUID,W/LAURIC ACID OIL',1076,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, whole, 3.25% milkfat, with added vitamin D','MILK,WHL,3.25% MILKFAT,W/ ADDED VITAMIN D',1077,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, producer, fluid, 3.7% milkfat','MILK,PRODUCER,FLUID,3.7% MILKFAT',1078,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, reduced fat, fluid, 2% milkfat, with added vitamin A and vitamin D','MILK,RED FAT,FLUID,2% MILKFAT,W/ ADDED VIT A & VITAMIN D',1079,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, reduced fat, fluid, 2% milkfat, with added nonfat milk solids and vitamin A and vitamin D','MILK,RED FAT,FLUID,2% MILKFAT,W/ ADDED NFMS, VIT A & VIT D',1080,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, reduced fat, fluid, 2% milkfat, protein fortified, with added vitamin A and vitamin D','MILK,RED FAT,FLUID,2% MILKFAT,PROT FORT,W/ ADDED VIT A & D',1081,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, lowfat, fluid, 1% milkfat, with added vitamin A and vitamin D','MILK,LOWFAT,FLUID,1% MILKFAT,W/ ADDED VIT A & VITAMIN D',1082,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, lowfat, fluid, 1% milkfat, with added nonfat milk solids, vitamin A and vitamin D','MILK,LOWFAT,FLUID,1% MILKFAT,W/ ADD NONFAT MILK SOL,VIT A/ D',1083,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, lowfat, fluid, 1% milkfat, protein fortified, with added vitamin A and vitamin D','MILK,LOWFAT,FLUID,1% MILKFAT,PROT FORT,W/ ADDED VIT A & D',1084,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, nonfat, fluid, with added vitamin A and vitamin D (fat free or skim)','MILK,NONFAT,FLUID,W/ ADDED VIT A & VIT D (FAT FREE OR SKIM)',1085,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, nonfat, fluid, with added nonfat milk solids, vitamin A and vitamin D (fat free or skim)','MILK,NONFAT,FLUID,W/ ADDED NONFAT MILK SOL,VIT A & VIT D',1086,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, nonfat, fluid, protein fortified, with added vitamin A and vitamin D (fat free and skim)','MILK,NONFAT,FLUID,PROT FORT,W/ ADD VIT A & D (FAT FREE/SKIM)',1087,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, buttermilk, fluid, cultured, lowfat','MILK,BTTRMLK,FLUID,CULTURED,LOWFAT',1088,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, low sodium, fluid','MILK,LO NA,FLUID',1089,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, dry, whole, with added vitamin D','MILK,DRY,WHL,W/ ADDED VITAMIN D',1090,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, dry, nonfat, regular, without added vitamin A and vitamin D','MILK,DRY,NONFAT,REG,WO/ ADDED VIT A & VITAMIN D',1091,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, dry, nonfat, instant, with added vitamin A and vitamin D','MILK,DRY,NONFAT,INST,W/ ADDED VIT A & VITAMIN D',1092,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, dry, nonfat, calcium reduced','MILK,DRY,NONFAT,CA RED',1093,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, buttermilk, dried','MILK,BUTTERMILK,DRIED',1094,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, canned, condensed, sweetened','MILK,CND,COND,SWTND',1095,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, canned, evaporated, with added vitamin D and without added vitamin A','MILK,CND,EVAP,W/ ADDED VITAMIN D & WO/ ADDED VIT A',1096,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, canned, evaporated, nonfat, with added vitamin A and vitamin D','MILK,CND,EVAP,NONFAT,W/ ADDED VIT A & VITAMIN D',1097,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, chocolate, fluid, commercial, whole, with added vitamin A and vitamin D','MILK,CHOC,FLUID,COMM,WHL,W/ ADDED VIT A & VITAMIN D',1102,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, chocolate, fluid, commercial, reduced fat, with added vitamin A and vitamin D','MILK,CHOC,FLUID,COMM,RED FAT',1103,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, chocolate, lowfat, with added vitamin A and vitamin D','MILK,CHOC,LOWFAT,W/ ADDED VIT A & VITAMIN D',1104,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, chocolate beverage, hot cocoa, homemade','MILK,CHOC BEV,HOT COCOA,HOMEMADE',1105,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, goat, fluid, with added vitamin D','MILK,GOAT,FLUID,W/ ADDED VITAMIN D',1106,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, indian buffalo, fluid','MILK,INDIAN BUFFALO,FLUID',1108,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, sheep, fluid','MILK,SHEEP,FLUID',1109,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk shakes, thick chocolate','MILK SHAKES,THICK CHOC',1110,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk shakes, thick vanilla','MILK SHAKES,THICK VANILLA',1111,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Whey, acid, fluid','WHEY,ACID,FLUID',1112,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Whey, acid, dried','WHEY,ACID,DRIED',1113,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Whey, sweet, fluid','WHEY,SWEET,FLUID',1114,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Whey, sweet, dried','WHEY,SWEET,DRIED',1115,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, plain, whole milk','YOGURT,PLN,WHL MILK',1116,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, plain, low fat','YOGURT,PLN,LOFAT',1117,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, plain, skim milk','YOGURT,PLN,SKIM MILK.',1118,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, vanilla, low fat.','YOGURT,VANILLA,LOFAT.',1119,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, fruit, low fat,9 g protein/8 oz','YOGURT,FRUIT,LOFAT,9 G PROTEIN/8 OZ',1120,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, fruit, low fat, 10 grams protein per 8 ounce','YOGURT,FRUIT,LOFAT,10 GRAMS PROT PER 8 OUNCE',1121,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, fruit, low fat, 11g protein/8 oz','YOGURT,FRUIT,LOFAT,11G PROTEIN/8 OZ',1122,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, whole, raw, fresh','EGG,WHL,RAW,FRSH',1123,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, white, raw, fresh','EGG,WHITE,RAW,FRESH',1124,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, yolk, raw, fresh','EGG,YOLK,RAW,FRSH',1125,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, yolk, raw, frozen, pasteurized','EGG,YOLK,RAW,FRZ,PAST',1126,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, yolk, raw, frozen, sugared, pasteurized','EGG,YOLK,RAW,FRZ,SUGARED,PAST',1127,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, whole, cooked, fried','EGG,WHL,CKD,FRIED',1128,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, whole, cooked, hard-boiled','EGG,WHL,CKD,HARD-BOILED',1129,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, whole, cooked, omelet','EGG,WHOLE,COOKED,OMELET',1130,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, whole, cooked, poached','EGG,WHL,CKD,POACHED',1131,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, whole, cooked, scrambled','EGG,WHL,CKD,SCRMBLD',1132,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, whole, dried','EGG,WHL,DRIED',1133,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, whole, dried, stabilized, glucose reduced','EGG,WHL,DRIED,STABILIZED,GLUCOSE RED',1134,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, white, dried, flakes, stabilized, glucose reduced','EGG,WHITE,DRIED,FLAKES,STABILIZED,GLUCOSE RED',1135,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, white, dried, powder, stabilized, glucose reduced','EGG,WHITE,DRIED,PDR,STABILIZED,GLUCOSE RED',1136,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, yolk, dried','EGG,YOLK,DRIED',1137,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, duck, whole, fresh, raw','EGG,DUCK,WHOLE,FRESH,RAW',1138,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, goose, whole, fresh, raw','EGG,GOOSE,WHOLE,FRESH,RAW',1139,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, quail, whole, fresh, raw','EGG,QUAIL,WHOLE,FRESH,RAW',1140,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, turkey, whole, fresh, raw','EGG,TURKEY,WHL,FRSH,RAW',1141,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg substitute, powder','EGG SUBSTITUTE,POWDER',1144,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Butter, without salt','BUTTER,WITHOUT SALT',1145,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, parmesan, shredded','CHEESE,PARMESAN,SHREDDED',1146,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, nonfat, fluid, without added vitamin A and vitamin D (fat free or skim)','MILK,NONFAT,FLUID,WO/ ADDED VIT A & VIT D (FAT FREE OR SKIM)',1151,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, reduced fat, fluid, 2% milkfat, with added nonfat milk solids, without added vitamin A','MILK,RED FAT,FLUID,2% MILKFAT,W/ NONFAT MILK SOL,WO/ VIT A',1152,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, canned, evaporated, with added vitamin A','MILK,CND,EVAP,W/ VIT A',1153,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, dry, nonfat, regular, with added vitamin A and vitamin D','MILK,DRY,NONFAT,REG,W/ ADDED VIT A & VITAMIN D',1154,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, dry, nonfat, instant, without added vitamin A and vitamin D','MILK,DRY,NONFAT,INST,WO/ ADDED VIT A & VITAMIN D',1155,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, goat, hard type','CHEESE,GOAT,HARD TYPE',1156,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, goat, semisoft type','CHEESE,GOAT,SEMISOFT TYPE',1157,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, goat, soft type','CHEESE,GOAT,SOFT TYPE',1159,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, yolk, raw, frozen, salted, pasteurized','EGG,YOLK,RAW,FRZ,SALTED,PAST',1160,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese substitute, mozzarella','CHEESE SUB,MOZZARELLA',1161,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese sauce, prepared from recipe','CHEESE SAU,PREP FROM RECIPE',1164,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, mexican, queso anejo','CHEESE,MEXICAN,QUESO ANEJO',1165,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, mexican, queso asadero','CHEESE,MEXICAN,QUESO ASADERO',1166,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, mexican, queso chihuahua','CHEESE,MEXICAN,QUESO CHIHUAHUA',1167,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, low fat, cheddar or colby','CHEESE,LOFAT,CHEDDAR OR COLBY',1168,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, low-sodium, cheddar or colby','CHEESE,LOW-SODIUM,CHEDDAR OR COLBY',1169,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, whole, raw, frozen, pasteurized (Includes foods for USDA''s Food Distribution Program)','EGG,WHL,RAW,FRZ,PAST',1171,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, white, raw, frozen, pasteurized','EGG,WHITE,RAW,FRZ,PAST',1172,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, white, dried','EGG,WHITE,DRIED',1173,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, reduced fat, fluid, 2% milkfat, without added vitamin A and vitamin D','MILK,RED FAT,FLUID,2% MILKFAT,WO/ ADDED VIT A & VIT D',1174,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, fluid, 1% fat, without added vitamin A and vitamin D','MILK,FLUID,1% FAT,WO/ ADDED VIT A & VIT D',1175,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Sour cream, reduced fat','SOUR CREAM,REDUCED FAT',1178,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Sour cream, light','SOUR CREAM,LIGHT',1179,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Sour cream, fat free','SOUR CREAM,FAT FREE',1180,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, vanilla or lemon flavor, nonfat milk, sweetened with low-calorie sweetener','YOGURT,VAN OR LEM FLAV,NONFAT MILK,SWTND W/LOW-CALORIE SWTNR',1184,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Parmesan cheese topping, fat free','PARMESAN CHS TOPPING,FAT FREE',1185,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cream, fat free','CHEESE,CREAM,FAT FREE',1186,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, chocolate, nonfat milk','YOGURT,CHOC,NONFAT MILK',1187,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream, half and half, fat free','CREAM,HALF & HALF,FAT FREE',1199,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, chocolate, fluid, commercial, reduced fat, with added calcium','MILK,CHOC,FLUID,COMM,RED FAT,W/ ADDED CA',1202,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, fruit, lowfat, with low calorie sweetener','YOGURT,FRUIT,LOFAT,W/LO CAL SWEETENER',1203,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, parmesan, dry grated, reduced fat','CHEESE,PARMESAN,DRY GRATED,RED FAT',1204,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream substitute, flavored, liquid','CREAM SUB,FLAV,LIQ',1205,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream substitute, flavored, powdered','CREAM SUB,FLAV,PDR',1206,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, provolone, reduced fat','CHEESE,PROVOLONE,RED FAT',1208,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, Mexican, blend, reduced fat','CHEESE,MEXICAN,BLEND,RED FAT',1209,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, whole, 3.25% milkfat, without added vitamin A and vitamin D','MILK,WHL,3.25% MILKFAT,WO/ ADDED VIT A & VITAMIN D',1211,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, dry, whole, without added vitamin D','MILK,DRY,WHL,WO/ ADDED VITAMIN D',1212,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese product, pasteurized process, American, reduced fat, fortified with vitamin D','CHEESE PRODUCT,PAST PROCESS,AMERICAN,RED FAT,FORT W/ VIT D',1215,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, fruit, low fat, 9 grams protein per 8 ounce, fortified with vitamin D','YOGURT,FRUIT,LOFAT,9 GRAMS PROT PER 8 OZ,FORT W/ VITAMIN D',1216,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, fruit, low fat, 10 grams protein per 8 ounce, fortified with vitamin D','YOGURT,FRUIT,LOFAT,10 GRAMS PROT PER 8 OZ,FORT W/ VITAMIN D',1217,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, fruit variety, nonfat, fortified with vitamin D','YOGURT,FRUIT VAR,NONFAT,FORT W/ VITAMIN D',1218,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, fruit, lowfat, with low calorie sweetener, fortified with vitamin D','YOGURT,FRUIT,LOWFAT,W/ LO CAL SWTNR,FORT W/ VITAMIN D',1219,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, vanilla, low fat, fortified with vitamin D','YOGURT,VANILLA,LOFAT,FORT W/ VITAMIN D',1220,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, vanilla or lemon flavor, nonfat milk, sweetened with low-calorie sweetener, fortified with vitamin D','YOGURT,VAN/LEM FLAV,NONFAT MILK,W/ LO-CAL SWTNR,FORT W/VIT D',1221,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, chocolate, nonfat milk, fortified with vitamin D','YOGURT,CHOC,NONFAT MILK,FORT W/ VITAMIN D',1222,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Dulce de Leche','DULCE DE LECHE',1225,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg substitute, liquid or frozen, fat free','EGG SUB,LIQ OR FRZ,FAT FREE',1226,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, dry white, queso seco','CHEESE,DRY WHITE,QUESO SECO',1227,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, fresh, queso fresco','CHEESE,FRSH,QUESO FRESCO',1228,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, white, queso blanco','CHEESE,WHITE,QUESO BLANCO',1229,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, buttermilk, fluid, whole','MILK,BTTRMLK,FLUID,WHL',1230,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, vanilla flavor, lowfat milk, sweetened with low calorie sweetener','YOGURT,VANILLA FLAVOR,LOWFAT MILK,SWTND W/ LO CAL SWTNR',1231,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, frozen, flavors not chocolate, nonfat milk, with low-calorie sweetener','YOGURT,FRZ,FLAVORS NOT CHOC,NONFAT MILK,W/ LOW-CALORIE SWTNR',1235,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Ice cream, soft serve, chocolate','ICE CRM,SOFT SERVE,CHOC',1236,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Ice cream, bar or stick, chocolate covered','ICE CRM,BAR OR STK,CHOC COVERED',1237,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Ice cream sandwich','ICE CRM SNDWCH',1238,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Ice cream cookie sandwich','ICE CRM COOKIE SNDWCH',1239,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Ice cream cone, chocolate covered, with nuts, flavors other than chocolate','ICE CRM CONE,CHOC COVERED,W/ NUTS,FLAVORS OTHER THAN CHOC',1240,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Ice cream sandwich, made with light ice cream, vanilla','ICE CRM SNDWCH,MADE W/ LT ICE CRM,VANILLA',1241,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Ice cream sandwich, vanilla, light, no sugar added','ICE CRM SNDWCH,VANILLA,LT,NO SUGAR ADDED',1242,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Fat free ice cream, no sugar added, flavors other than chocolate','FAT FREE ICE CRM,NO SUGAR ADDED,FLAVORS OTHER THAN CHOC',1243,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk dessert bar, frozen, made from lowfat milk','MILK DSSRT BAR,FRZ,MADE FROM LOWFAT MILK',1244,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Nutritional supplement for people with diabetes, liquid','NUTRITIONAL SUPP FOR PEOPLE W/ DIABETES,LIQ',1250,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, Mexican blend','CHEESE,MEXICAN BLEND',1251,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese product, pasteurized process, American, vitamin D fortified','CHEESE PRODUCT,PAST PROCESS,AMERICAN,VITAMIN D FORT',1252,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, pasteurized process, American, without added vitamin D','CHEESE,PAST PROCESS,AMERICAN,WO/ ADDED VITAMIN D',1253,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese food, pasteurized process, American, without added vitamin D','CHEESE FD,PAST PROCESS,AMERICAN,WO/ ADDED VITAMIN D',1254,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, whole, raw, frozen, salted, pasteurized','EGG,WHL,RAW,FRZ,SALTED,PAST',1255,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, Greek, plain, nonfat (Includes foods for USDA''s Food Distribution Program)','YOGURT,GREEK,PLN,NONFAT',1256,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Egg, white, dried, stabilized, glucose reduced','EGG,WHITE,DRIED,STABILIZED,GLUCOSE RED',1258,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese spread, American or Cheddar cheese base, reduced fat','CHEESE SPRD,AMERICAN OR CHEDDAR CHS BASE,RED FAT',1259,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cheddar, reduced fat (Includes foods for USDA''s Food Distribution Program)','CHEESE,CHEDDAR,RED FAT',1260,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Ice cream, light, soft serve, chocolate','ICE CRM,LT,SOFT SERVE,CHOC',1263,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Ice cream bar, stick or nugget, with crunch coating','ICE CRM BAR,STK OR NUGGET,W/ CRUNCH COATING',1264,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cheddar, nonfat or fat free','CHEESE,CHEDDAR,NONFAT OR FAT FREE',1265,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, Swiss, nonfat or fat free','CHEESE,SWISS,NONFAT OR FAT FREE',1266,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, mexican, queso cotija','CHEESE,MEXICAN,QUESO COTIJA',1267,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cheddar, sharp, sliced','CHEESE,CHEDDAR,SHARP,SLICED',1270,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, mozzarella, low moisture, part-skim, shredded','CHEESE,MOZZARELLA,LO MOIST,PART-SKIM,SHREDDED',1271,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, Greek, strawberry, lowfat','YOGURT,GREEK,STRAWBERRY,LOWFAT',1284,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, Greek, strawberry, nonfat','YOGURT,GREEK,STRAWBERRY,NONFAT',1285,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, Greek, vanilla, nonfat','YOGURT,GREEK,VANILLA,NONFAT',1286,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, Greek, plain, lowfat','YOGURT,GREEK,PLN,LOWFAT',1287,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, evaporated, 2% fat, with added vitamin A and vitamin D','MILK,CND,EVAP,WO/ VIT A',1291,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, chocolate, fat free, with added vitamin A and vitamin D','MILK,CHOC,FAT FREE,W/ ADDED VIT A & VITAMIN D',1292,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, Greek, plain, whole milk','YOGURT,GREEK,PLN,WHL MILK',1293,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, Greek, fruit, whole milk','YOGURT,GREEK,FRUIT,WHL MILK',1294,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, vanilla, non-fat','YOGURT,VANILLA,NON-FAT',1295,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, Greek, vanilla, lowfat','YOGURT,GREEK,VANILLA,LOWFAT',1297,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, frozen, flavors other than chocolate, lowfat','YOGURT,FRZ,FLAVORS OTHER THAN CHOC,LOWFAT',1298,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Ice cream bar, covered with chocolate and nuts','ICE CRM BAR,COVERED W/ CHOC & NUTS',1300,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Ice cream sundae cone','ICE CRM SUNDAE CONE',1301,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream, half and half, lowfat','CREAM,HALF & HALF,LOWFAT',1303,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, chocolate, lowfat, reduced sugar','MILK,CHOC,LOWFAT,RED SUGAR',1305,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Ice cream, lowfat, no sugar added, cone, added peanuts and chocolate sauce','ICE CRM,LOWFAT,NO SUGAR ADDED,CONE,ADDED PNUTS & CHOC SAU',1306,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Butter, Clarified butter (ghee)','BUTTER,CLARIFIED BUTTER (GHEE)',1323,NULL,NULL,NULL,NULL,NULL,1,'2019-02-13','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, allspice, ground','ALLSPICE,GROUND',2001,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, anise seed','ANISE SEED',2002,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, basil, dried','SPICES,BASIL,DRIED',2003,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, bay leaf','SPICES,BAY LEAF',2004,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, caraway seed','CARAWAY SEED',2005,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, cardamom','SPICES,CARDAMOM',2006,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, celery seed','CELERY SEED',2007,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, chervil, dried','CHERVIL,DRIED',2008,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, chili powder','CHILI POWDER',2009,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, cinnamon, ground','CINNAMON,GROUND',2010,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, cloves, ground','CLOVES,GROUND',2011,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, coriander leaf, dried','CORIANDER LEAF,DRIED',2012,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, coriander seed','CORIANDER SEED',2013,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, cumin seed','CUMIN SEED',2014,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, curry powder','CURRY POWDER',2015,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, dill seed','DILL SEED',2016,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, dill weed, dried','DILL WEED,DRIED',2017,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, fennel seed','FENNEL SEED',2018,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, fenugreek seed','FENUGREEK SEED',2019,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, garlic powder','GARLIC POWDER',2020,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, ginger, ground','GINGER,GROUND',2021,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, mace, ground','MACE,GROUND',2022,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, marjoram, dried','MARJORAM,DRIED',2023,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, mustard seed, ground','SPICES,MUSTARD SD,GROUND',2024,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, nutmeg, ground','NUTMEG,GROUND',2025,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, onion powder','ONION POWDER',2026,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, oregano, dried','SPICES,OREGANO,DRIED',2027,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, paprika','PAPRIKA',2028,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, parsley, dried','PARSLEY,DRIED',2029,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, pepper, black','PEPPER,BLACK',2030,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, pepper, red or cayenne','PEPPER,RED OR CAYENNE',2031,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, pepper, white','PEPPER,WHITE',2032,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, poppy seed','POPPY SEED',2033,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, poultry seasoning','POULTRY SEASONING',2034,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, pumpkin pie spice','PUMPKIN PIE SPICE',2035,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, rosemary, dried','ROSEMARY,DRIED',2036,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, saffron','SAFFRON',2037,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, sage, ground','SAGE,GROUND',2038,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, savory, ground','SAVORY,GROUND',2039,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, tarragon, dried','SPICES,TARRAGON,DRIED',2041,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, thyme, dried','SPICES,THYME,DRIED',2042,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spices, turmeric, ground','TURMERIC,GROUND',2043,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Basil, fresh','BASIL,FRESH',2044,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Dill weed, fresh','DILL WEED,FRSH',2045,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Mustard, prepared, yellow','MUSTARD,PREPARED,YELLOW',2046,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Salt, table','SALT,TABLE',2047,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Vinegar, cider','VINEGAR,CIDER',2048,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Thyme, fresh','THYME,FRSH',2049,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Vanilla extract','VANILLA EXTRACT',2050,NULL,NULL,NULL,NULL,NULL,1,'1994-03-16','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Vanilla extract, imitation, no alcohol','VANILLA EXTRACT,IMITN,NO ALCOHOL',2052,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Vinegar, distilled','VINEGAR,DISTILLED',2053,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Capers, canned','CAPERS,CANNED',2054,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Horseradish, prepared','HORSERADISH,PREPARED',2055,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Rosemary, fresh','ROSEMARY,FRESH',2063,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Peppermint, fresh','PEPPERMINT,FRESH',2064,NULL,NULL,NULL,NULL,NULL,1,'2005-12-28','2013-06-15',NULL,'as served',NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spearmint, fresh','SPEARMINT,FRESH',2065,NULL,NULL,NULL,NULL,NULL,1,'2005-12-28','2006-11-30',NULL,'as served',NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Spearmint, dried','SPEARMINT,DRIED',2066,NULL,NULL,NULL,NULL,NULL,1,'2005-12-28','2006-11-30',NULL,'as served',NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Vinegar, red wine','VINEGAR,RED WINE',2068,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Vinegar, balsamic','VINEGAR,BALSAMIC',2069,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Seasoning mix, dry, sazon, coriander & annatto','SEASONING MIX,DRY,SAZON,CORIANDER & ANNATTO',2074,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Seasoning mix, dry, taco, original','SEASONING MIX,DRY,TACO,ORIGINAL',2075,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (2,'Seasoning mix, dry, chili, original','SEASONING MIX,DRY,CHILI,ORIGINAL',2076,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice treats, fruit medley, toddler','BABYFOOD,JUC TREATS,FRUIT MEDLEY,TODD',3001,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, beef, strained','BABYFOOD,MEAT,BF,STR',3002,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, beef, junior','BABYFOOD,MEAT,BF,JR',3003,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, veal, strained','BABYFOOD,MEAT,VEAL,STR',3005,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, pork, strained','BABYFOOD,MEAT,PORK,STR',3007,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, ham, strained','BABYFOOD,MEAT,HAM,STR',3008,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, ham, junior','BABYFOOD,MEAT,HAM,JUNIOR',3009,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, lamb, strained','BABYFOOD,MEAT,LAMB,STR',3010,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, lamb, junior','BABYFOOD,MEAT,LAMB,JUNIOR',3011,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, chicken, strained','BABYFOOD,MEAT,CHICK,STR',3012,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, chicken, junior','BABYFOOD,MEAT,CHICK,JR',3013,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, chicken sticks, junior','BABYFOOD,MEAT,CHICK STKS,JR',3014,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, turkey, strained','BABYFOOD,MEAT,TURKEY,STR',3015,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, turkey, junior','BABYFOOD,MEAT,TURKEY,JR',3016,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, turkey sticks, junior','Babyfood, meat, turkey sticks, junior',3017,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, meat sticks, junior','BABYFOOD,MEAT,MEAT STKS,JR',3021,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, tropical fruit medley','BABYFOOD,TROPICAL FRUIT MEDLEY',3026,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, macaroni and tomato and beef, strained','BABYFOOD,DINNER,MACARONI&TOMATO&BF,STR',3044,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, macaroni and tomato and beef, junior','BABYFOOD,DINNER,MACARONI&TOMATO&BF,JR',3045,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, ravioli, cheese filled, with tomato sauce','BABYFOOD,RAVIOLI,CHS FILLED,W/TOMATO SAU',3046,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, beef noodle, strained','BABYFOOD,DINNER,BF NOODLE,STR',3047,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, macaroni and cheese, toddler','BABYFOOD,MACARONI&CHS,TODD',3048,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, spaghetti and tomato and meat, junior','BABYFOOD,DINNER,SPAGHETTI&TOMATO&MEAT,JR',3050,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, vegetables and beef, strained','BABYFOOD,DINNER,VEG&BF,STR',3053,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, vegetables and beef, junior','BABYFOOD,DINNER,VEG&BF,JR',3054,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, beef with vegetables','BABYFOOD,DINNER,BF W/VEG',3055,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, vegetables and lamb, junior','BABYFOOD,DINNER,VEG&LAMB,JR',3067,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, chicken noodle, strained','BABYFOOD,DINNER,CHICK NOODLE,STR',3068,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, chicken noodle, junior','BABYFOOD,DINNER,CHICK NOODLE,JR',3069,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, chicken soup, strained','BABYFOOD,DINNER,CHICK SOUP,STR',3070,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, chicken stew, toddler','BABYFOOD  DINNER  CHICK STEW  TODD',3072,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, vegetables chicken, strained','BABYFOOD,DINNER,VEG CHICK,STR',3073,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, pasta with vegetables','BABYFOOD,DINNER,PASTA W/VEG',3077,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, turkey and rice, strained','BABYFOOD,DINNER,TURKEY&RICE,STR',3082,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, turkey and rice, junior','BABYFOOD,DINNER,TURKEY & RICE,JR',3083,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, vegetables and turkey, strained','BABYFOOD,DINNER,VEG&TURKEY,STR',3084,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, vegetables and turkey, junior','BABYFOOD,DINNER,VEG&TURKEY,JR',3085,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, macaroni and cheese, strained','BABYFOOD,DINNER,MACARONI&CHS,STR',3089,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, macaroni and cheese, junior','BABYFOOD,DINNER,MACARONI&CHS,JR',3090,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, green beans, strained','BABYFOOD,VEG,GRN BNS,STR',3091,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, green beans, junior','BABYFOOD,VEG,GRN BNS,JR',3092,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, green beans, dices, toddler','BABYFOOD,GRN BNS,DICES,TODD',3093,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetable, green beans and potatoes','BABYFOOD,VEG,GRN BNS&POTATOES',3096,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, beets, strained','BABYFOOD,VEG,BEETS,STR',3098,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, carrots, strained','BABYFOOD,VEG,CARROTS,STR',3099,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, carrots, junior','BABYFOOD,VEG,CARROTS,JR',3100,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, squash, strained','BABYFOOD,VEG,SQUASH,STR',3104,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, squash, junior','BABYFOOD,VEG,SQUASH,JR',3105,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, sweet potatoes strained','BABYFOOD,VEG,SWT POTATOES,STR',3108,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, sweet potatoes, junior','BABYFOOD,VEG,SWT POTATOES,JR',3109,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, potatoes, toddler','BABYFOOD,POTATOES,TODDLER',3112,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetable, butternut squash and corn','BABYFOOD,VEG,BUTTERNUT SQUASH&CORN',3114,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, apples, dices, toddler','BABYFOOD,APPLS,DICES,TODD',3115,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, applesauce, strained','BABYFOOD,FRUIT,APPLSAUC,STR',3116,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, applesauce, junior','BABYFOOD,FRUIT,APPLSAUC,JR',3117,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, apricot with tapioca, strained','BABYFOOD,FRUIT,APRICOT W/TAPIOCA,STR',3118,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, corn, creamed, strained','BABYFOOD,VEG,CORN,CRMD,STR',3119,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, corn, creamed, junior','BABYFOOD,VEG,CORN,CRMD,JR',3120,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, peas, strained','BABYFOOD,VEG,PEAS,STR',3121,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, peas, dices, toddler','BABYFOOD,PEAS,DICES,TODD',3122,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, spinach, creamed, strained','BABYFOOD,VEG,SPINACH,CRMD,STR',3127,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, apricot with tapioca, junior','BABYFOOD,FRUIT,APRICOT W/TAPIOCA,JR',3128,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, bananas with tapioca, strained','BABYFOOD,FRUIT,BANANAS W/TAPIOCA,STR',3129,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, peaches, strained','BABYFOOD,FRUIT,PEACHES,STR',3130,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, peaches, junior','BABYFOOD,FRUIT,PEACHES,JR',3131,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, pears, strained','BABYFOOD,FRUIT,PEARS,STR',3132,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, pears, junior','BABYFOOD,FRUIT,PEARS,JR',3133,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, plums with tapioca, without ascorbic acid, strained','BABYFOOD,FRUIT,PLUMS W/TAPIOCA,WO/VIT C,STR',3134,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, plums with tapioca, without ascorbic acid, junior','BABYFOOD,FRUIT,PLUMS W/TAPIOCA,WO/VIT C,JR',3135,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, prunes with tapioca, without ascorbic acid, strained','BABYFOOD,FRUIT,PRUNES W/TAPIOCA,WO/VIT C,STR',3136,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, prunes with tapioca, without ascorbic acid, junior','BABYFOOD,FRUIT,PRUNES W/TAPIOCA,WO/VIT C,JR',3137,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, prunes, without vitamin c, strained','BABYFOOD,PRUNES,WO/VIT C,STR',3139,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit dessert, mango with tapioca','BABYFOOD,FRUIT DSSRT,MANGO W/ TAPIOCA',3140,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, pears, dices, toddler','BABYFOOD,PEARS,DICES,TODD',3141,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, applesauce and apricots, strained','BABYFOOD,FRUIT,APPLSAUC&APRICOTS,STR',3142,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, applesauce and apricots, junior','BABYFOOD,FRUIT,APPLSAUC&APRICOTS,JR',3143,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, applesauce and cherries, strained','BABYFOOD,FRUIT,APPLSAUC&CHERRIES,STR',3144,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, applesauce and cherries, junior','BABYFOOD,FRUIT,APPLSAUC & CHERRIES,JR',3145,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, applesauce with banana, junior','BABYFOOD,FRUIT,APPLSAUC W/BANANA,JR',3147,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, applesauce and pineapple, strained','BABYFOOD,FRUIT,APPLSAUC&PNAPPL,STR',3150,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, applesauce and pineapple, junior','BABYFOOD,FRUIT,APPLSAUC&PNAPPL,JR',3151,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, apple and raspberry, strained','BABYFOOD,FRUIT,APPL & RASPBERRY,STR',3152,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, apple and raspberry, junior','BABYFOOD,FRUIT,APPL & RASPBERRY,JR',3153,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit and vegetable, apple and sweet potato','BABYFOOD,FRUIT & VEG,APPL & SWT POTATO',3154,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, bananas and pineapple with tapioca, junior','BABYFOOD,FRUIT,BANANAS&PNAPPL W/TAPIOCA,JR',3156,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, bananas and pineapple with tapioca, strained','BABYFOOD,FRUIT,BANANAS&PNAPPL W/TAPIOCA,STR',3157,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, pears and pineapple, strained','BABYFOOD,FRUIT,PEARS&PNAPPL,STR',3158,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, pears and pineapple, junior','BABYFOOD,FRUIT,PEARS&PNAPPL,JR',3159,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, peaches, dices, toddler','BABYFOOD,PEACHES,DICES,TODD',3161,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, bananas with apples and pears, strained','BABYFOOD,FRUIT,BANANAS W/APPLS&PEARS,STR',3163,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, apple and blueberry, strained','BABYFOOD,FRUIT,APPL&BLUEBERRY,STR',3164,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, apple and blueberry, junior','BABYFOOD,FRUIT,APPL&BLUEBERRY,JR',3165,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice, apple','BABYFOOD,JUICE,APPLE',3166,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, apple-banana juice','BABYFOOD,APPLE-BANANA JUC',3167,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice, apple and peach','BABYFOOD,JUC,APPL&PEACH',3168,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice, apple and prune','BABYFOOD,JUC,APPL&PRUNE',3171,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice, orange','BABYFOOD,JUICE,ORANGE',3172,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice, orange and apple and banana','BABYFOOD,JUC,ORANGE&APPL&BANANA',3174,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice, orange and apricot','BABYFOOD,JUC,ORANGE&APRICOT',3175,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice, orange and pineapple','BABYFOOD,JUC,ORANGE&PNAPPL',3177,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice, mixed fruit','BABYFOOD,JUC,MXD FRUIT',3179,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, barley, dry fortified','BABYFOOD,CRL,BARLEY,DRY FORT',3181,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, whole wheat, with apples, dry fortified','BABYFOOD,CRL,WHL WHEAT,W/ APPLS,DRY FORT',3184,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, mixed, dry fortified','BABYFOOD,CRL,MXD,DRY FORT',3185,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, mixed, with bananas, dry','BABYFOOD,CRL,MXD,W/ BANANAS,DRY',3186,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, mixed, with applesauce and bananas, strained','BABYFOOD,CRL,MXD,W/ APPLSAUC & BANANAS,STR',3187,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, mixed, with applesauce and bananas, junior, fortified','BABYFOOD,CRL,MXD,W/ APPLSAUC & BANANAS,JR,FORT',3188,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, oatmeal, dry fortified','BABYFOOD,CRL,OATMEAL,DRY FORT',3189,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, oatmeal, with bananas, dry','BABYFOOD,CRL,OATMEAL,W/ BANANAS,DRY',3190,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, oatmeal, with applesauce and bananas, strained','BABYFOOD,CRL,OATMEAL,W/ APPLSAUC & BANANAS,STR',3191,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, oatmeal, with applesauce and bananas, junior, fortified','BABYFOOD,CRL,OATMEAL,W/ APPLSAUC & BANANAS,JR,FORT',3192,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, rice, dry fortified','BABYFOOD,CRL,RICE,DRY FORT',3194,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, rice, with applesauce and bananas, strained','BABYFOOD,CRL,RICE,W/ APPLSAUC & BANANAS,STR',3195,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, with egg yolks, strained','BABYFOOD,CRL,W/EGG YOLKS,STR',3197,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, with egg yolks, junior','BABYFOOD,CRL,W/EGG YOLKS,JR',3198,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, with eggs, strained','BABYFOOD,CRL,W/EGGS,STR',3199,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, egg yolks and bacon, junior','BABYFOOD,CRL,EGG YOLKS&BACON,JR',3201,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, oatmeal cereal with fruit, dry, instant, toddler fortified','BABYFOOD,OATMEAL CRL W/ FRUIT,DRY,INST,TODD FORT',3205,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cookie, baby, fruit','BABYFOOD,COOKIE,BABY,FRUIT',3206,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, crackers, vegetable','BABYFOOD,CRACKERS,VEG',3209,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, high protein, with apple and orange, dry','BABYFOOD,CRL,HI PROT,W/APPL&ORANGE,DRY',3211,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, rice, with bananas, dry','BABYFOOD,CRL,RICE,W/ BANANAS,DRY',3212,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cookies','BABYFOOD,COOKIES',3213,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cookies, arrowroot','BABYFOOD,COOKIES,ARROWROOT',3214,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, pretzels','BABYFOOD,PRETZELS',3215,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, dutch apple, strained','BABYFOOD,DSSRT,DUTCH APPL,STR',3220,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, dutch apple, junior','BABYFOOD,DSSRT,DUTCH APPL,JR',3221,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cherry cobbler, junior','BABYFOOD,CHERRY COBBLER,JR',3222,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, cherry vanilla pudding, strained','BABYFOOD,DSSRT,CHERRY VANILLA PUDD,STR',3224,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, cherry vanilla pudding, junior','BABYFOOD,DSSRT,CHERRY VANILLA PUDD,JR',3225,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, fruit pudding, orange, strained','BABYFOOD,DSSRT,FRUIT PUDD,ORANGE,STR',3226,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, peach cobbler, strained','BABYFOOD,DSSRT,PEACH COBBLER,STR',3227,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, peach cobbler, junior','BABYFOOD,DSSRT,PEACH COBBLER,JR',3228,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, fruit pudding, pineapple, strained','BABYFOOD,DSSRT,FRUIT PUDD,PNAPPL,STR',3233,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, fruit dessert, without ascorbic acid, strained','BABYFOOD,DSSRT,FRUIT DSSRT,WO/VIT C,STR',3235,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, fruit dessert, without ascorbic acid, junior','BABYFOOD,DSSRT,FRUIT DSSRT,WO/VIT C,JR',3236,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, custard pudding, vanilla, strained','BABYFOOD,DSSRT,CUSTARD PUDD,VANILLA,STR',3245,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, custard pudding, vanilla, junior','BABYFOOD,DSSRT,CUSTARD PUDD,VANILLA,JR',3246,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice, apple and grape','BABYFOOD,JUC,APPL&GRAPE',3265,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice, fruit punch, with calcium','BABYFOOD,JUC,FRUIT PUNCH,W/CA',3267,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice, apple, with calcium','BABYFOOD,JUC,APPL,W/CA',3269,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, vegetables and chicken, junior','BABYFOOD,DINNER,VEG&CHICK,JR',3274,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, mixed vegetable, junior','BABYFOOD,DINNER,MXD VEG,JR',3279,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, bananas with tapioca, junior','BABYFOOD,FRUIT,BANANAS W/TAPIOCA,JR',3280,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, mix vegetables junior','BABYFOOD,VEG,MIX VEG JR',3282,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, garden vegetable, strained','BABYFOOD,VEG,GARDEN VEG,STR',3283,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetables, mix vegetables strained','BABYFOOD,VEG,MIX VEG STR',3286,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, beef noodle, junior','BABYFOOD,DINNER,BF NOODLE,JR',3287,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, apples with ham, strained','BABYFOOD,APPLS W/HAM,STR',3289,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, carrots and beef, strained','BABYFOOD,CARROTS&BF,STR',3290,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, plums, bananas and rice, strained','BABYFOOD,PLUMS,BANANAS&RICE,STR',3293,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, turkey, rice, and vegetables, toddler','BABYFOOD,TURKEY,RICE&VEG,TODD',3296,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, apples and chicken, strained','BABYFOOD,DINNER,APPLS&CHICK,STR',3297,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, broccoli and chicken, junior','BABYFOOD,DINNER,BROCCOLI & CHICK,JR',3298,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, sweet potatoes and chicken, strained','BABYFOOD,DINNER,SWT POTATOES&CHICK,STR',3303,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, barley, prepared with whole milk','BABYFOOD,CRL,BARLEY,PREP W/WHL MILK',3681,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, mixed, prepared with whole milk','BABYFOOD,CRL,MXD,PREP W/WHL MILK',3685,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, mixed, with bananas, prepared with whole milk','BABYFOOD,CRL,MXD,W/BANANAS,PREP W/WHL MILK',3686,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, oatmeal, prepared with whole milk','BABYFOOD,CRL,OATMEAL,PREP W/WHL MILK',3689,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, oatmeal, with bananas, prepared with whole milk','BABYFOOD,CRL,OATMEAL,W/BANANAS,PREP W/WHL MILK',3690,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, rice, prepared with whole milk','BABYFOOD,CRL,RICE,PREP W/WHL MILK',3694,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, rice, with bananas, prepared with whole milk','BABYFOOD,CRL,RICE,W/BANANAS,PREP W/WHL MILK',3712,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, corn and sweet potatoes, strained','BABYFOOD,CORN & SWT POTATOES,STR',3934,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, yogurt, whole milk, with fruit, multigrain cereal and added DHA fortified','BABYFOOD,YOG,WHL MILK,W/ FRUIT,MULTIG CRL & ADD DHA FORT',3956,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, mashed cheddar potatoes and broccoli, toddlers','BABYFOOD,MSHD CHEDDAR POTATOES&BROCCOLI,TODDLER',3959,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fortified cereal bar, fruit filling','BABYFOOD,FORT CRL BAR,FRUIT FILLING',3964,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, yogurt, whole milk, with fruit, multigrain cereal and added iron fortified','BABYFOOD,YOGU,WHL MILK,W/ FRUI,MULTIGRA CRL & ADD IRON FORT',3965,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, banana and strawberry, junior','BABYFD,FRU,BAN AND STRAW, JU',3994,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, banana with mixed berries, strained','BABYFOO,BAN WI MIX BERR,ST',3995,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, Multigrain whole grain cereal, dry fortified','Babyfood, Multigrain whole grain cereal, dry fortified',3996,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Fat, beef tallow','FAT,BEEF TALLOW',4001,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Lard','LARD',4002,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, russian dressing','SALAD DRSNG,RUSSIAN DRSNG',4015,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, sesame seed dressing, regular','SALAD DRSNG,SESAME SD DRSNG,REG',4016,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, thousand island, commercial, regular','SALAD DRSNG,1000 ISLAND,COMM,REG',4017,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, mayonnaise type, regular, with salt','SALAD DRSNG,MAYO TYPE,REG,W/SALT',4018,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, french dressing, reduced fat','SALAD DRSNG,FRENCH DRSNG,RED FAT',4020,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, italian dressing, commercial, reduced fat','SALAD DRSNG,ITALIAN DRSNG,COMM,RED FAT',4021,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, russian dressing, low calorie','SALAD DRSNG,RUSSIAN DRSNG,LO CAL',4022,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, thousand island dressing, reduced fat','SALAD DRSNG,1000 ISLAND DRSNG,RED FAT',4023,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, mayonnaise, regular','SALAD DRSNG,MAYO,REG',4025,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, mayonnaise, soybean and safflower oil, with salt','SALAD DRSNG,MAYO,SOYBN&SAFFLOWER OIL,W/SALT',4026,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, mayonnaise, imitation, soybean','SALAD DRSNG,MAYO,IMITN,SOYBN',4027,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, mayonnaise, imitation, milk cream','SALAD DRSNG,MAYO,IMITN,MILK CRM',4028,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, mayonnaise, imitation, soybean without cholesterol','SALAD DRSNG,MAYO,IMITN,SOYBN WO/CHOL',4029,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Sandwich spread, with chopped pickle, regular, unspecified oils','SANDWICH SPRD,W/CHOPD PICKLE,REG,UNSPEC OILS',4030,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening, household, soybean (partially hydrogenated)-cottonseed (partially hydrogenated)','SHORTENING,HOUSEHOLD,PARTIALLY HYDROG SOYBN -COTTONSEED',4031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, soybean, salad or cooking, (partially hydrogenated)','OIL,SOYBN,SALAD OR COOKING,(PARTIALLY HYDROGENATED)',4034,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, rice bran','OIL,RICE BRAN',4037,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, wheat germ','OIL,WHEAT GERM',4038,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, peanut, salad or cooking','OIL,PNUT,SALAD OR COOKING',4042,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, soybean, salad or cooking','OIL,SOYBN,SALAD OR COOKING',4044,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, coconut','OIL,COCNT',4047,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, olive, salad or cooking','OIL,OLIVE,SALAD OR COOKING',4053,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, palm','OIL,PALM',4055,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, sesame, salad or cooking','OIL,SESAME,SALAD OR COOKING',4058,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, sunflower, linoleic (less than 60%)','OIL,SUNFLOWER,LINOLEIC (LESS THAN 60%)',4060,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine, regular, hard, soybean (hydrogenated)','MARGARINE,REG,HARD,SOYBN (HYDR)',4073,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, italian dressing, commercial, regular','SALAD DRSNG,ITALIAN DRSNG,COMM,REG',4114,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, french dressing, commercial, regular','SALAD DRSNG,FRENCH DRSNG,COMM,REG',4120,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine,spread, 35-39% fat, tub','MARGARINE,SPRD,35-39% FAT,TUB',4128,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, french, home recipe','SALAD DRSNG,FRENCH,HOME RECIPE',4133,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, home recipe, vinegar and oil','SALAD DRSNG,HOME RECIPE,VINEGAR&OIL',4135,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, french dressing, commercial, regular, without salt','SALAD DRSNG,FRENCH DRSNG,COMM,REG,WO/ SALT',4141,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, french dressing, reduced fat, without salt','SALAD DRSNG,FRENCH DRSNG,RED FAT,WO/ SALT',4142,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, italian dressing, commercial, regular, without salt','SALAD DRSNG,ITALIAN DRSNG,COMM,REG,WO/ SALT',4143,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, italian dressing, reduced fat, without salt','SALAD DRSNG,ITALIAN DRSNG,RED FAT,WO/ SALT',4144,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, mayonnaise, soybean oil, without salt','SALAD DRSNG,MAYO,SOYBN OIL,WO/SALT',4145,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, french, cottonseed, oil, home recipe','SALAD DRSNG,FRENCH,CTTNSD,OIL,HOME RECIPE',4146,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, french dressing, fat-free','SALAD DRSNG,FRENCH DRSNG,FAT-FREE',4367,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, cocoa butter','OIL,COCOA BUTTER',4501,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, cottonseed, salad or cooking','OIL,CTTNSD,SALAD OR COOKING',4502,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, sunflower, linoleic, (approx. 65%)','OIL,SUNFLOWER,LINOLEIC,(APPROX. 65%)',4506,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, safflower, salad or cooking, linoleic, (over 70%)','OIL,SAFFLOWER,SALAD OR COOKING,LINOLEIC,(OVER 70%)',4510,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, safflower, salad or cooking, high oleic (primary safflower oil of commerce)','OIL,SAFFLOWER,SALAD OR COOKING,HI OLEIC',4511,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Vegetable oil, palm kernel','VEGETABLE OIL,PALM KERNEL',4513,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, poppyseed','OIL,POPPYSEED',4514,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, tomatoseed','OIL,TOMATOSEED',4515,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, teaseed','OIL,TEASEED',4516,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, grapeseed','OIL,GRAPESEED',4517,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, corn, industrial and retail, all purpose salad or cooking','OIL,CORN,INDUSTRIAL & RTL,ALLPURP SALAD OR COOKING',4518,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, walnut','OIL,WALNUT',4528,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, almond','OIL,ALMOND',4529,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, apricot kernel','OIL,APRICOT KERNEL',4530,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, soybean lecithin','OIL,SOYBN LECITHIN',4531,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, hazelnut','OIL,HAZELNUT',4532,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, babassu','OIL,BABASSU',4534,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, sheanut','OIL,SHEANUT',4536,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, blue or roquefort cheese dressing, commercial, regular','SALAD DRSNG,BLUE OR ROQUEFORT CHS DRSNG,COMM,REG',4539,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, cupu assu','OIL,CUPU ASSU',4541,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Fat, chicken','FAT,CHICKEN',4542,NULL,NULL,NULL,NULL,NULL,1,'1994-07-01','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, soybean, salad or cooking, (partially hydrogenated) and cottonseed','OIL,SOYBN,SALAD OR COOKING,(PARTIALLY HYDROGENATED) & CTTNSD',4543,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening, household, lard and vegetable oil','SHORTENING,HOUSEHOLD,LARD&VEG OIL',4544,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, sunflower, linoleic, (partially hydrogenated)','OIL,SUNFLOWER,LINOLEIC,(PARTIALLY HYDROGENATED)',4545,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening bread, soybean (hydrogenated) and cottonseed','SHORTENING BREAD,SOYBN (HYDR)&CTTNSD',4546,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening cake mix, soybean (hydrogenated) and cottonseed (hydrogenated)','SHORTENING CAKE MIX,SOYBN (HYDR)&CTTNSD (HYDR)',4548,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening industrial, lard and vegetable oil','SHORTENING INDUSTRIAL,LARD&VEG OIL',4549,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening frying (heavy duty), beef tallow and cottonseed','SHORTENING FRYING (HVY DUTY),BF TALLOW&CTTNSD',4550,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening confectionery, coconut (hydrogenated) and or palm kernel (hydrogenated)','SHORTENING CONFECTIONERY,COCNT (HYDR)&OR PALM KERNEL (HYDR)',4551,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening industrial, soybean (hydrogenated) and cottonseed','SHORTENING INDUSTRIAL,SOYBN (HYDR)&CTTNSD',4554,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening frying (heavy duty), palm (hydrogenated)','SHORTENING FRYING (HVY DUTY),PALM (HYDR)',4556,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening household soybean (hydrogenated) and palm','SHORTENING HOUSEHOLD SOYBN (HYDR)&PALM',4559,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening frying (heavy duty), soybean (hydrogenated), linoleic (less than 1%)','SHORTENING FRYING HVY DUTY,SOYBN HYDR,LINOLEIC (LESS THAN 1%',4560,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening, confectionery, fractionated palm','SHORTENING,CONFECTIONERY,FRACTIONATED PALM',4570,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, nutmeg butter','OIL,NUTMEG BUTTER',4572,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, ucuhuba butter','OIL,UCUHUBA BUTTER',4573,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Fat, turkey','FAT,TURKEY',4575,NULL,NULL,NULL,NULL,NULL,1,'1994-07-01','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Fat, goose','FAT,GOOSE',4576,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, avocado','OIL,AVOCADO',4581,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, canola','OIL,CANOLA',4582,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, mustard','OIL,MUSTARD',4583,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, sunflower, high oleic (70% and over)','OIL,SUNFLOWER,HI OLEIC (70% & OVER)',4584,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, margarine-butter blend, soybean oil and butter','MARGARINE-LIKE,MARGARINE-BUTTER BLEND,SOYBN OIL & BUTTER',4585,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening, special purpose for cakes and frostings, soybean (hydrogenated)','SHORTENING,SPL PURPOSE FOR CAKES&FROSTINGS,SOYBN (HYDR)',4586,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening, special purpose for baking, soybean (hydrogenated) palm and cottonseed','SHORTENING,SPL PURPOSE FOR BAKING,SOYBN (HYDR) PALM&CTTNSD',4587,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, oat','OIL,OAT',4588,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Fish oil, cod liver','FISH OIL,COD LIVER',4589,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Fish oil, herring','FISH OIL,HERRING',4590,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Fish oil, menhaden','FISH OIL,MENHADEN',4591,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Fish oil, menhaden, fully hydrogenated','FISH OIL,MENHADEN,FULLY HYDR',4592,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Fish oil, salmon','FISH OIL,SALMON',4593,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Fish oil, sardine','FISH OIL,SARDINE',4594,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening, multipurpose, soybean (hydrogenated) and palm (hydrogenated)','SHORTENING,MULTIPURPOSE,SOYBN (HYDR)&PALM (HYDR)',4595,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, vegetable oil-butter spread, tub, with salt','MARGARINE-LIKE,VEG OIL-BUTTER SPRD,TUB,W/ SALT',4600,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Butter, light, stick, with salt','BUTTER,LT,STK,W/SALT',4601,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Butter, light, stick, without salt','BUTTER,LT,STK,WO/SALT',4602,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Animal fat, bacon grease','ANIMAL FAT,BACON GREASE',4609,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine, regular, 80% fat, composite, stick, with salt','MARGARINE,REG,80% FAT,COMP,STK,W/ SALT',4610,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine, regular, 80% fat, composite, tub, with salt','MARGARINE,REG,80% FAT,COMP,TUB,W/ SALT',4611,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, vegetable oil spread, 60% fat, stick, with salt','MARGARINE-LIKE,VEG OIL SPRD,60% FAT,STK,W/ SALT',4612,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, vegetable oil spread, 60% fat, tub, with salt','MARGARINE-LIKE,VEG OIL SPRD,60% FAT,TUB,W/ SALT',4613,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, vegetable oil spread, 60% fat, stick/tub/bottle, with salt','MARGARINE-LIKE,VEG OIL SPRD,60% FAT,STICK/TUB/BOTTLE,W/ SALT',4614,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening, vegetable, household, composite','SHORTENING,VEG,HOUSEHOLD,COMP',4615,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine, regular, 80% fat, composite, stick, without salt','MARGARINE,REG,80% FAT,COMP,STK,WO/ SALT',4617,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine, regular, 80% fat, composite, tub, without salt','MARGARINE,REG,80% FAT,COMP,TUB,WO/ SALT',4618,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, vegetable oil spread, 60% fat, stick/tub/bottle, without salt','VEG OIL SPRD,60% FAT,STICK/TUB/BOTTLE,WO/ SALT',4620,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, vegetable oil spread, fat free, liquid, with salt','MARGARINE-LIKE,VEG OIL SPRD,FAT FREE,LIQ,W/ SALT',4624,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like spread with yogurt, 70% fat, stick, with salt','MARGARINE-LIKE SPRD W/ YOGURT,70% FAT,STK,W/ SALT',4626,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like spread with yogurt, approximately 40% fat, tub, with salt','MARGARINE-LIKE SPRD W/ YOGURT,APPROX 40% FAT,TUB,W/ SALT',4627,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine, 80% fat, stick, includes regular and hydrogenated corn and soybean oils','MARGARINE,80% FAT,STK,INCL REG & HYDR CORN & SOYBN OILS',4628,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine, margarine-type vegetable oil spread, 70% fat, soybean and partially hydrogenated soybean, stick','MARGARINE, VEG OIL SPRD,70% FAT,SOYBN & PART HYDR SOYBN,STK',4629,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine Spread, 40-49% fat, tub','Margarine 40-49% fat',4630,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, vegetable oil spread, fat-free, tub','MARGARINE-LIKE,VEG OIL SPRD,FAT-FREE,TUB',4631,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, vegetable oil spread, 20% fat, with salt','MARGARINE-LIKE,VEG OIL SPRD,20% FAT,W/ SALT',4633,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, vegetable oil spread, 20% fat, without salt','MARGARINE-LIKE,VEG OIL SPRD,20% FAT,WO/ SALT',4634,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, thousand island dressing, fat-free','SALAD DRSNG,1000 ISLAND DRSNG,FAT-FREE',4635,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, italian dressing, fat-free','SALAD DRSNG,ITALIAN DRSNG,FAT-FREE',4636,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, ranch dressing, fat-free','SALAD DRSNG,RANCH DRSNG,FAT-FREE',4638,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, ranch dressing, regular','SALAD DRSNG,RANCH DRSNG,REG',4639,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, ranch dressing, reduced fat','SALAD DRSNG,RANCH DRSNG,RED FAT',4640,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, mayonnaise, light','SALAD DRSNG,MAYO,LT',4641,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, mid-oleic, sunflower','OIL,INDUSTRIAL,MID-OLEIC,SUNFLOWER',4642,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, canola with antifoaming agent, principal uses salads, woks and light frying','OIL,INDUSTRIAL,CANOLA W/ ANTIFOAMING AGENT',4643,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, canola for salads, woks and light frying','OIL,INDUSTRIAL,CANOLA FOR SALADS,WOKS & LT FRYING',4644,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, canola (partially hydrogenated) oil for deep fat frying','OIL,INDUS,CANOLA (PART HYDROG) OIL FOR DEEP FAT FRYING',4645,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, coconut, principal uses candy coatings, oil sprays, roasting nuts','OIL,INDUSTRIAL,COCNT',4646,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, soy (partially hydrogenated), principal uses popcorn and flavoring vegetables','OIL,INDUSTRIAL,SOY (PART HYDR),FOR POPCORN & FLAVORING VEG',4648,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening, industrial, soy (partially hydrogenated), pourable liquid fry shortening','SHORTENING,INDUS,SOY (PART HYDROG),POURABLE LIQ FRY',4649,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, soy, refined, for woks and light frying','OIL,INDUSTRIAL,SOY,REFINED,FOR WOKS & LT FRYING',4650,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, soy (partially hydrogenated), multiuse for non-dairy butter flavor','OIL,INDUSTRIAL,SOY (PART HYDR),FOR NON-DAIRY BUTTER FLAVOR',4651,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, soy ( partially hydrogenated), all purpose','OIL,INDUSTRIAL,SOY ( PART HYDROGENATED),ALLPURP',4652,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, soy (partially hydrogenated ) and soy (winterized), pourable clear fry','OIL,INDUSTRIAL,SOY (PART HYDR ) & SOY,POURABLE FRY',4653,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, soy (partially hydrogenated)  and cottonseed, principal use as a tortilla shortening','OIL,INDUS,SOY (PART HYDROG) & CTTNSD,TORTILLA SHORTENING',4654,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like shortening, industrial, soy (partially hydrogenated), cottonseed, and soy, principal use flaky pastries','MARGARINE-LIKE SHORTENING,INDUS,SOY(PART  HYDR),CTTNSD,& SOY',4655,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, palm kernel, confection fat, uses similar to high quality cocoa butter','OIL,INDUSTRIAL,PALM KERNEL,CONFECTION FAT',4656,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, palm kernel (hydrogenated), confection fat, uses similar to 95 degree hard butter','OIL,INDUSTRIAL,PALM KERNEL (HYDROGENATED),CONFECTION FAT',4657,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, palm kernel (hydrogenated), confection fat, intermediate grade product','OIL,INDUSTRIAL,PALM KERNEL (HYDROGENATED),CONFECTION FAT',4658,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, coconut, confection fat, typical basis for ice cream coatings','OIL,INDUSTRIAL,COCNT,CONFECTION FAT,ICE CRM COATINGS',4659,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, palm kernel (hydrogenated) , used for whipped toppings, non-dairy','OIL,INDUSTRIAL,PALM KERNEL (HYDROG) FOR WHIPPED TOPPINGS',4660,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, coconut (hydrogenated), used for whipped toppings and coffee whiteners','OIL,INDUSTRIAL,COCNT (HYDROGENATED),FOR TOPPINGS & WHITENERS',4661,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, palm and palm kernel, filling fat (non-hydrogenated)','OIL,INDUSTRIAL,PALM & PALM KERNEL,FILLING FAT (NON-HYDROG)',4662,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, palm kernel (hydrogenated), filling fat','OIL,INDUSTRIAL,PALM KERNEL (HYDROGENATED),FILLING FAT',4663,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, soy (partially hydrogenated ), palm, principal uses icings and fillings','OIL,INDUSTRIAL,SOY (PARTHYDR ),PALM, ICINGS & FILLINGS',4664,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine, industrial, non-dairy, cottonseed, soy oil (partially hydrogenated ), for flaky pastries','MARGARINE,INDUS,NON-DAIRY,CTTNSD,SOY OIL (PART HYDR )',4665,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening, industrial, soy (partially hydrogenated ) and corn for frying','SHORTENING,INDUSTRIAL,SOY (PARTIALLY HYDR )&CORN FOR FRYING',4666,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Shortening, industrial, soy (partially hydrogenated ) for baking and confections','SHORTENING,INDUS,SOY (PART HYDR ) FOR BAKING & CONFECTIONS',4667,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine, industrial, soy and partially hydrogenated soy oil, use for baking, sauces and candy','MARGARINE,INDUS,SOY & PART HYDR SOY OIL,BAKING,SAUCES,CANDY',4668,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, vegetable, soybean, refined','OIL,VEG,SOYBN,REFINED',4669,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, vegetable, Natreon canola, high stability, non trans, high oleic (70%)','OIL,VEG,NATREON CANOLA,HI STABILITY,NON TRANS,HI OLEIC (70%)',4678,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine, margarine-like vegetable oil spread, 67-70% fat, tub','MARGARINE,MARGARINE-LIKE VEG OIL SPRD,67-70% FAT,TUB',4683,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, honey mustard dressing, reduced calorie','SALAD DRSNG,HONEY MUSTARD DRSNG,RED CAL',4686,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, spray-style dressing, assorted flavors','SALAD DRSNG,SPRAY-STYLE DRSNG,ASSORTED FLAVORS',4688,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2009-01-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, vegetable oil spread, approximately 37% fat, unspecified oils, with salt, with added vitamin D','VEG OIL SPRD,37% FAT,UNSPEC OILS,W/ SALT,W/ ADDED VITAMIN D',4690,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine, regular, 80% fat, composite, stick, with salt, with added vitamin D','MARGARINE,REG,80% FAT,COMP,STK,W/ SALT,W/ ADDED VITAMIN D',4691,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine, regular, 80% fat, composite, tub, with salt, with added vitamin D','MARGARINE,REG,80% FAT,COMP,TUB,W/ SALT,W/ ADDED VITAMIN D',4692,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, vegetable oil spread, 60% fat, stick, with salt, with added vitamin D','VEG OIL SPRD,60% FAT,STK,W/ SALT,W/ ADDED VITAMIN D',4693,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, vegetable oil spread, 60% fat, tub, with salt, with added vitamin D','VEG OIL SPRD,60% FAT,TUB,W/ SALT,W/ ADDED VITAMIN D',4694,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like vegetable-oil spread, stick/tub/bottle, 60% fat, with added vitamin D','VEG-OIL SPRD,STICK/TUB/BOTTLE,60% FAT,W/ ADDED VITAMIN D',4695,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine, regular, 80% fat, composite, stick, without salt, with added vitamin D','MARGARINE,REG,80% FAT,COMP,STK,WO/ SALT,W/ ADDED VITAMIN D',4696,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, vegetable oil spread, 60% fat, stick/tub/bottle, without salt, with added vitamin D','VEG OIL SPRD,60% FAT,STICK/TUB/BOTTLE,WO/ SALT,W/VIT D',4697,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, canola, high oleic','OIL,INDUSTRIAL,CANOLA,HI OLEIC',4698,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, soy, low linolenic','OIL,INDUSTRIAL,SOY,LO LINOLENIC',4699,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, soy, ultra low linolenic','OIL,INDUSTRIAL,SOY,ULTRA LO LINOLENIC',4700,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, soy, fully hydrogenated','OIL,INDUSTRIAL,SOY,FULLY HYDR',4701,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, industrial, cottonseed, fully hydrogenated','OIL,INDUSTRIAL,CTTNSD,FULLY HYDR',4702,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, honey mustard, regular','SALAD DRSNG,HONEY MUSTARD,REG',4703,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, poppyseed, creamy','SALAD DRSNG,POPPYSEED,CREAMY',4704,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, caesar, fat-free','SALAD DRSNG,CAESAR,FAT-FREE',4705,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Dressing, honey mustard, fat-free','DRESSING,HONEY MUSTARD,FAT-FREE',4706,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, flaxseed, contains added sliced flaxseed','OIL,FLAXSEED,CONTAINS ADDED SLICED FLAXSEED',4707,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Mayonnaise, reduced fat, with olive oil','MAYONNAISE,RED FAT,W/ OLIVE OIL',4708,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, mayonnaise-type, light','SALAD DRSNG,MAYONNAISE-TYPE,LT',4709,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler, rotisserie, BBQ, breast, meat only','CHICK,BROILER,ROTISSERIE,BBQ,BREAST,MEAT ONLY',5000,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, meat and skin and giblets and neck, raw','CHICKEN,BROILERS OR FRYERS,MEAT&SKN&GIBLETS&NECK,RAW',5001,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, meat and skin and giblets and neck, cooked, fried, batter','CHICKEN,BROILER OR FRYER,MEAT&SKN&GIBLETS&NECK,FRIED,BATTER',5002,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, meat and skin and giblets and neck, cooked, fried, flour','CHICKEN,BROILERS OR FRYERS,MEAT&SKN&GIBLETS&NECK,FRIED,FLR',5003,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, meat and skin and giblets and neck, roasted','CHICKEN,BROILERS OR FRYERS,MEAT&SKN&GIBLETS&NECK,RSTD',5004,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, meat and skin and giblets and neck, stewed','CHICKEN,BROILERS OR FRYERS,MEAT&SKN&GIBLETS&NECK,STWD',5005,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, meat and skin, raw','CHICKEN,BROILERS OR FRYERS,MEAT & SKN,RAW',5006,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, meat and skin, cooked, fried, batter','CHICKEN,BROILERS OR FRYERS,MEAT&SKN,CKD,FRIED,BATTER',5007,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, meat and skin, cooked, fried, flour','CHICKEN,BROILERS OR FRYERS,MEAT&SKN,CKD,FRIED,FLR',5008,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, meat and skin, cooked, roasted','CHICKEN,BROILERS OR FRYERS,MEAT&SKN,CKD,RSTD',5009,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, meat and skin, cooked, stewed','CHICKEN,BROILERS OR FRYERS,MEAT&SKN,CKD,STWD',5010,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, meat only, raw','CHICKEN,BROILERS OR FRYERS,MEAT ONLY,RAW',5011,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, meat only, cooked, fried','CHICKEN,BROILERS OR FRYERS,MEAT ONLY,CKD,FRIED',5012,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, meat only, cooked, roasted','CHICKEN,BROILERS OR FRYERS,MEAT ONLY,CKD,RSTD',5013,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, meat only, cooked, stewed','CHICKEN,BROILERS OR FRYERS,MEAT ONLY,CKD,STWD',5014,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, skin only, raw','CHICKEN,BROILERS OR FRYERS,SKN ONLY,RAW',5015,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, skin only, cooked, fried, batter','CHICKEN,BROILERS OR FRYERS,SKN ONLY,CKD,FRIED,BATTER',5016,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, skin only, cooked, fried, flour','CHICKEN,BROILERS OR FRYERS,SKN ONLY,CKD,FRIED,FLR',5017,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, skin only, cooked, roasted','CHICKEN,BROILERS OR FRYERS,SKN ONLY,CKD,RSTD',5018,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, skin only, cooked, stewed','CHICKEN,BROILERS OR FRYERS,SKN ONLY,CKD,STWD',5019,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, giblets, raw','CHICKEN,BROILERS OR FRYERS,GIBLETS,RAW',5020,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, giblets, cooked, fried','CHICKEN,BROILERS OR FRYERS,GIBLETS,CKD,FRIED',5021,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, giblets, cooked, simmered','CHICKEN,BROILERS OR FRYERS,GIBLETS,CKD,SIMMRD',5022,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, gizzard, all classes, raw','CHICKEN,GIZZARD,ALL CLASSES,RAW',5023,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, gizzard, all classes, cooked, simmered','CHICKEN,GIZZARD,ALL CLASSES,CKD,SIMMRD',5024,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, heart, all classes, raw','CHICKEN,HEART,ALL CLASSES,RAW',5025,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, heart, all classes, cooked, simmered','CHICKEN,HEART,ALL CLASSES,CKD,SIMMRD',5026,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, liver, all classes, raw','CHICKEN,LIVER,ALL CLASSES,RAW',5027,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, liver, all classes, cooked, simmered','CHICKEN,LIVER,ALL CLASSES,CKD,SIMMRD',5028,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, light meat, meat and skin, raw','CHICKEN,BROILERS OR FRYERS,LT MEAT,MEAT & SKN,RAW',5029,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, light meat, meat and skin, cooked, fried, batter','CHICKEN,BROILERS OR FRYERS,LT MEAT,MEAT&SKN,CKD,FRIED,BATTER',5030,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, light meat, meat and skin, cooked, fried, flour','CHICKEN,BROILERS OR FRYERS,LT MEAT,MEAT&SKN,CKD,FRIED,FLR',5031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, light meat, meat and skin, cooked, roasted','CHICKEN,BROILERS OR FRYERS,LT MEAT,MEAT&SKN,CKD,RSTD',5032,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, light meat, meat and skin, cooked, stewed','CHICKEN,BROILERS OR FRYERS,LT MEAT,MEAT&SKN,CKD,STWD',5033,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, meat and skin, raw','CHICKEN,BROILERS OR FRYERS,DK MEAT,MEAT & SKN,RAW',5034,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, meat and skin, cooked, fried, batter','CHICKEN,BROILERS OR FRYERS,DK MEAT,MEAT&SKN,CKD,FRIED,BATTER',5035,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, meat and skin, cooked, fried, flour','CHICKEN,BROILERS OR FRYERS,DK MEAT,MEAT&SKN,CKD,FRIED,FLR',5036,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, meat and skin, cooked, roasted','CHICKEN,BROILERS OR FRYERS,DK MEAT,MEAT&SKN,CKD,RSTD',5037,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, meat and skin, cooked, stewed','CHICKEN,BROILERS OR FRYERS,DK MEAT,MEAT&SKN,CKD,STWD',5038,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, light meat, meat only, raw','CHICKEN,BROILERS OR FRYERS,LT MEAT,MEAT ONLY,RAW',5039,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, light meat, meat only, cooked, fried','CHICKEN,BROILERS OR FRYERS,LT MEAT,MEAT ONLY,CKD,FRIED',5040,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, light meat, meat only, cooked, roasted','CHICKEN,BROILERS OR FRYERS,LT MEAT,MEAT ONLY,CKD,RSTD',5041,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, light meat, meat only, cooked, stewed','CHICKEN,BROILERS OR FRYERS,LT MEAT,MEAT ONLY,CKD,STWD',5042,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, meat only, raw','CHICKEN,BROILERS OR FRYERS,DK MEAT,MEAT ONLY,RAW',5043,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, meat only, cooked, fried','CHICKEN,BROILERS OR FRYERS,DK MEAT,MEAT ONLY,CKD,FRIED',5044,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, meat only, cooked, roasted','CHICKEN,BROILERS OR FRYERS,DK MEAT,MEAT ONLY,CKD,RSTD',5045,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, meat only, cooked, stewed','CHICKEN,BROILERS OR FRYERS,DK MEAT,MEAT ONLY,CKD,STWD',5046,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, separable fat, raw','CHICKEN,BROILERS OR FRYERS,FAT,RAW',5047,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, back, meat and skin, raw','CHICKEN,BROILERS OR FRYERS,BACK,MEAT&SKN,RAW',5048,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, back, meat and skin, cooked, fried, batter','CHICKEN,BROILERS OR FRYERS,BACK,MEAT&SKN,CKD,FRIED,BATTER',5049,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, back, meat and skin, cooked, fried, flour','CHICKEN,BROILERS OR FRYERS,BACK,MEAT&SKN,CKD,FRIED,FLR',5050,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, back, meat and skin, cooked, roasted','CHICKEN,BROILERS OR FRYERS,BACK,MEAT&SKN,CKD,RSTD',5051,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, back, meat and skin, cooked, stewed','CHICKEN,BROILERS OR FRYERS,BACK,MEAT&SKN,CKD,STWD',5052,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, back, meat only, raw','CHICKEN,BROILERS OR FRYERS,BACK,MEAT ONLY,RAW',5053,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, back, meat only, cooked, fried','CHICKEN,BROILERS OR FRYERS,BACK,MEAT ONLY,CKD,FRIED',5054,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, back, meat only, cooked, roasted','CHICKEN,BROILERS OR FRYERS,BACK,MEAT ONLY,CKD,RSTD',5055,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, back, meat only, cooked, stewed','CHICKEN,BROILERS OR FRYERS,BACK,MEAT ONLY,CKD,STWD',5056,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, breast, meat and skin, raw','CHICKEN,BROILERS OR FRYERS,BREAST,MEAT&SKN,RAW',5057,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, breast, meat and skin, cooked, fried, batter','CHICKEN,BROILERS OR FRYERS,BREAST,MEAT&SKN,CKD,FRIED,BATTER',5058,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, breast, meat and skin, cooked, fried, flour','CHICKEN,BROILERS OR FRYERS,BREAST,MEAT&SKN,CKD,FRIED,FLR',5059,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, breast, meat and skin, cooked, roasted','CHICKEN,BROILERS OR FRYERS,BREAST,MEAT&SKN,CKD,RSTD',5060,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, breast, meat and skin, cooked, stewed','CHICKEN,BROILERS OR FRYERS,BREAST,MEAT&SKN,CKD,STWD',5061,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler or fryers, breast, skinless, boneless, meat only, raw','CHICKEN,BROILER OR FRYERS,BRST,SKINLESS,BNLESS,MEAT ONLY,RAW',5062,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, breast, meat only, cooked, fried','CHICKEN,BROILERS OR FRYERS,BREAST,MEAT ONLY,CKD,FRIED',5063,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, breast, meat only, cooked, roasted','CHICKEN,BROILERS OR FRYERS,BREAST,MEAT ONLY,CKD,RSTD',5064,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, breast, meat only, cooked, stewed','CHICKEN,BROILERS OR FRYERS,BREAST,MEAT ONLY,CKD,STWD',5065,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, drumstick, meat and skin, raw','CHICKEN,BROILERS OR FRYERS,DRUMSTK,MEAT&SKN,RAW',5066,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, drumstick, meat and skin, cooked, fried, batter','CHICKEN,BROILERS OR FRYERS,DRUMSTK,MEAT&SKN,CKD,FRIED,BATTER',5067,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, drumstick, meat and skin, cooked, fried, flour','CHICKEN,BROILERS OR FRYERS,DRUMSTK,MEAT&SKN,CKD,FRIED,FLR',5068,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, drumstick, meat and skin, cooked, roasted','CHICKEN,BROILERS OR FRYERS,DRUMSTK,MEAT&SKN,CKD,RSTD',5069,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, drumstick, meat and skin, cooked, stewed','CHICKEN,BROILERS OR FRYERS,DRUMSTK,MEAT&SKN,CKD,STWD',5070,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, drumstick, meat only, raw','CHICKEN,BROILERS OR FRYERS,DK MEAT,DRUMSTK,MEAT ONLY,RAW',5071,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, drumstick, meat only, cooked, fried','CHICKEN,BROILERS OR FRYERS,DRUMSTK,MEAT ONLY,CKD,FRIED',5072,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, drumstick, meat only, cooked, roasted','CHICKEN,BROILERS OR FRYERS,DK MEAT,DRUMSTK,MEAT ONLY,CKD,RST',5073,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, drumstick, meat only, cooked, stewed','CHICKEN,BROILERS OR FRYERS,DRUMSTK,MEAT ONLY,CKD,STWD',5074,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, leg, meat and skin, raw','CHICKEN,BROILERS OR FRYERS,LEG,MEAT&SKN,RAW',5075,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, leg, meat and skin, cooked, fried, batter','CHICKEN,BROILERS OR FRYERS,LEG,MEAT&SKN,CKD,FRIED,BATTER',5076,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, leg, meat and skin, cooked, fried, flour','CHICKEN,BROILERS OR FRYERS,LEG,MEAT&SKN,CKD,FRIED,FLR',5077,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, leg, meat and skin, cooked, roasted','CHICKEN,BROILERS OR FRYERS,LEG,MEAT&SKN,CKD,RSTD',5078,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, leg, meat and skin, cooked, stewed','CHICKEN,BROILERS OR FRYERS,LEG,MEAT&SKN,CKD,STWD',5079,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, leg, meat only, raw','CHICKEN,BROILERS OR FRYERS,LEG,MEAT ONLY,RAW',5080,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, leg, meat only, cooked, fried','CHICKEN,BROILERS OR FRYERS,LEG,MEAT ONLY,CKD,FRIED',5081,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, leg, meat only, cooked, roasted','CHICKEN,BROILERS OR FRYERS,LEG,MEAT ONLY,CKD,RSTD',5082,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, leg, meat only, cooked, stewed','CHICKEN,BROILERS OR FRYERS,LEG,MEAT ONLY,CKD,STWD',5083,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, neck, meat and skin, raw','CHICKEN,BROILERS OR FRYERS,NECK,MEAT&SKN,RAW',5084,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, neck, meat and skin, cooked, fried, batter','CHICKEN,BROILERS OR FRYERS,NECK,MEAT&SKN,CKD,FRIED,BATTER',5085,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, neck, meat and skin, cooked, fried, flour','CHICKEN,BROILERS OR FRYERS,NECK,MEAT&SKN,CKD,FRIED,FLR',5086,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, neck, meat and skin, cooked simmered','CHICKEN,BROILERS OR FRYERS,NECK,MEAT&SKN,CKD SIMMRD',5087,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, neck, meat only, raw','CHICKEN,BROILERS OR FRYERS,NECK,MEAT ONLY,RAW',5088,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, neck, meat only, cooked, fried','CHICKEN,BROILERS OR FRYERS,NECK,MEAT ONLY,CKD,FRIED',5089,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, neck, meat only, cooked, simmered','CHICKEN,BROILERS OR FRYERS,NECK,MEAT ONLY,CKD,SIMMRD',5090,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, thigh, meat and skin, raw','CHICKEN,BROILERS OR FRYERS,THIGH,MEAT&SKN,RAW',5091,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, thigh, meat and skin, cooked, fried, batter','CHICKEN,BROILERS OR FRYERS,THIGH,MEAT&SKN,CKD,FRIED,BATTER',5092,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, thigh, meat and skin, cooked, fried, flour','CHICKEN,BROILERS OR FRYERS,THIGH,MEAT&SKN,CKD,FRIED,FLR',5093,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, thigh, meat and skin, cooked, roasted','CHICKEN,BROILERS OR FRYERS,THIGH,MEAT&SKN,CKD,RSTD',5094,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, thigh, meat and skin, cooked, stewed','CHICKEN,BROILERS OR FRYERS,THIGH,MEAT&SKN,CKD,STWD',5095,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, thigh, meat only, raw','CHICKEN,BROILERS OR FRYERS,DK MEAT,THIGH,MEAT ONLY,RAW',5096,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, thigh, meat only, cooked, fried','CHICKEN,BROILERS OR FRYERS,THIGH,MEAT ONLY,CKD,FRIED',5097,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, thigh, meat only, cooked, roasted','CHICKEN,BROILERS OR FRYERS,THIGH,MEAT ONLY,CKD,RSTD',5098,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, thigh, meat only, cooked, stewed','CHICKEN,BROILERS OR FRYERS,THIGH,MEAT ONLY,CKD,STWD',5099,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, wing, meat and skin, raw','CHICKEN,BROILERS OR FRYERS,WING,MEAT&SKN,RAW',5100,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, wing, meat and skin, cooked, fried, batter','CHICKEN,BROILERS OR FRYERS,WING,MEAT&SKN,CKD,FRIED,BATTER',5101,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, wing, meat and skin, cooked, fried, flour','CHICKEN,BROILERS OR FRYERS,WING,MEAT&SKN,CKD,FRIED,FLR',5102,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, wing, meat and skin, cooked, roasted','CHICKEN,BROILERS OR FRYERS,WING,MEAT&SKN,CKD,RSTD',5103,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, wing, meat and skin, cooked, stewed','CHICKEN,BROILERS OR FRYERS,WING,MEAT&SKN,CKD,STWD',5104,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, wing, meat only, raw','CHICKEN,BROILERS OR FRYERS,WING,MEAT ONLY,RAW',5105,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, wing, meat only, cooked, fried','CHICKEN,BROILERS OR FRYERS,WING,MEAT ONLY,CKD,FRIED',5106,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, wing, meat only, cooked, roasted','CHICKEN,BROILERS OR FRYERS,WING,MEAT ONLY,CKD,RSTD',5107,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, wing, meat only, cooked, stewed','CHICKEN,BROILERS OR FRYERS,WING,MEAT ONLY,CKD,STWD',5108,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, roasting, meat and skin and giblets and neck, raw','CHICKEN,ROASTING,MEAT&SKN&GIBLETS&NECK,RAW',5109,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, roasting, meat and skin and giblets and neck, cooked, roasted','CHICKEN,ROASTING,MEAT&SKN&GIBLETS&NECK,CKD,RSTD',5110,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Canada Goose, breast meat only, skinless, raw','CANADA GOOSE,BREAST MEAT ONLY,SKINLESS,RAW',5111,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, roasting, meat and skin, cooked, roasted','CHICKEN,ROASTING,MEAT&SKN,CKD,RSTD',5112,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, roasting, meat only, raw','CHICKEN,ROASTING,MEAT ONLY,RAW',5113,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, roasting, meat only, cooked, roasted','CHICKEN,ROASTING,MEAT ONLY,CKD,RSTD',5114,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, roasting, giblets, raw','CHICKEN,ROASTING,GIBLETS,RAW',5115,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, roasting, giblets, cooked, simmered','CHICKEN,ROASTING,GIBLETS,CKD,SIMMRD',5116,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, roasting, light meat, meat only, raw','CHICKEN,ROASTING,LT MEAT,MEAT ONLY,RAW',5117,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, roasting, light meat, meat only, cooked, roasted','CHICKEN,ROASTING,LT MEAT,MEAT ONLY,CKD,RSTD',5118,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, roasting, dark meat, meat only, raw','CHICKEN,ROASTING,DK MEAT,MEAT ONLY,RAW',5119,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, roasting, dark meat, meat only, cooked, roasted','CHICKEN,ROASTING,DK MEAT,MEAT ONLY,CKD,RSTD',5120,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, stewing, meat and skin, and giblets and neck, raw','CHICKEN,STEWING,MEAT&SKN,&GIBLETS&NECK,RAW',5121,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, stewing, meat and skin, and giblets and neck, cooked, stewed','CHICKEN,STEWING,MEAT & SKN,& GIBLETS & NECK,CKD,STWD',5122,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, stewing, meat and skin, raw','CHICKEN,STEWING,MEAT&SKN,RAW',5123,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, stewing, meat and skin, cooked, stewed','CHICKEN,STEWING,MEAT&SKN,CKD,STWD',5124,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, stewing, meat only, raw','CHICKEN,STEWING,MEAT ONLY,RAW',5125,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, stewing, meat only, cooked, stewed','CHICKEN,STEWING,MEAT ONLY,CKD,STWD',5126,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, stewing, giblets, raw','CHICKEN,STEWING,GIBLETS,RAW',5127,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, stewing, giblets, cooked, simmered','CHICKEN,STEWING,GIBLETS,CKD,SIMMRD',5128,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, stewing, light meat, meat only, raw','CHICKEN,STEWING,LT MEAT,MEAT ONLY,RAW',5129,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, stewing, light meat, meat only, cooked, stewed','CHICKEN,STEWING,LT MEAT,MEAT ONLY,CKD,STWD',5130,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, stewing, dark meat, meat only, raw','CHICKEN,STEWING,DK MEAT,MEAT ONLY,RAW',5131,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, stewing, dark meat, meat only, cooked, stewed','CHICKEN,STEWING,DK MEAT,MEAT ONLY,CKD,STWD',5132,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, capons, meat and skin and giblets and neck, raw','CHICKEN,CAPONS,MEAT&SKN&GIBLETS&NECK,RAW',5133,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, capons, meat and skin and giblets and neck, cooked, roasted','CHICKEN,CAPONS,MEAT&SKN&GIBLETS&NECK,CKD,RSTD',5134,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, capons, meat and skin, raw','CHICKEN,CAPONS,MEAT&SKN,RAW',5135,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, capons, meat and skin, cooked, roasted','CHICKEN,CAPONS,MEAT&SKN,CKD,RSTD',5136,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, capons, giblets, raw','CHICKEN,CAPONS,GIBLETS,RAW',5137,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, capons, giblets, cooked, simmered','CHICKEN,CAPONS,GIBLETS,CKD,SIMMRD',5138,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Duck, domesticated, meat and skin, raw','DUCK,DOMESTICATED,MEAT&SKN,RAW',5139,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Duck, domesticated, meat and skin, cooked, roasted','DUCK,DOMESTICATED,MEAT&SKN,CKD,RSTD',5140,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Duck, domesticated, meat only, raw','DUCK,DOMESTICATED,MEAT ONLY,RAW',5141,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Duck, domesticated, meat only, cooked, roasted','DUCK,DOMESTICATED,MEAT ONLY,CKD,RSTD',5142,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Duck, domesticated, liver, raw','DUCK,DOMESTICATED,LIVER,RAW',5143,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Duck, wild, meat and skin, raw','DUCK,WILD,MEAT&SKN,RAW',5144,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Duck, wild, breast, meat only, raw','DUCK,WILD,BREAST,MEAT ONLY,RAW',5145,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Goose, domesticated, meat and skin, raw','GOOSE,DOMESTICATED,MEAT&SKN,RAW',5146,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Goose, domesticated, meat and skin, cooked, roasted','GOOSE,DOMESTICATED,MEAT&SKN,CKD,RSTD',5147,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Goose, domesticated, meat only, raw','GOOSE,DOMESTICATED,MEAT ONLY,RAW',5148,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Goose, domesticated, meat only, cooked, roasted','GOOSE,DOMESTICATED,MEAT ONLY,CKD,RSTD',5149,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Goose, liver, raw','GOOSE,LIVER,RAW',5150,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Guinea hen, meat and skin, raw','GUINEA HEN,MEAT&SKN,RAW',5151,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Guinea hen, meat only, raw','GUINEA HEN,MEAT ONLY,RAW',5152,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Pheasant, raw, meat and skin','PHEASANT,RAW,MEAT&SKN',5153,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Pheasant, raw, meat only','PHEASANT,RAW,MEAT ONLY',5154,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Pheasant, breast, meat only, raw','PHEASANT,BREAST,MEAT ONLY,RAW',5155,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Pheasant, leg, meat only, raw','PHEASANT,LEG,MEAT ONLY,RAW',5156,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Quail, meat and skin, raw','QUAIL,MEAT AND SKIN,RAW',5157,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Quail, meat only, raw','QUAIL,MEAT ONLY,RAW',5158,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Quail, breast, meat only, raw','QUAIL,BREAST,MEAT ONLY,RAW',5159,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Squab, (pigeon), meat and skin, raw','SQUAB,(PIGEON),MEAT&SKN,RAW',5160,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Squab, (pigeon), meat only, raw','SQUAB,(PIGEON),MEAT ONLY,RAW',5161,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Squab, (pigeon), light meat without skin, raw','SQUAB,(PIGEON),LT MEAT WO/SKN,RAW',5162,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, meat and skin, raw','TURKEY,WHL,MEAT & SKN,RAW',5165,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, meat and skin, cooked, roasted','TURKEY,WHL,MEAT & SKN,CKD,RSTD',5166,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, meat only, raw','TURKEY,WHL,MEAT ONLY,RAW',5167,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, meat only, cooked, roasted','TURKEY,WHL,MEAT ONLY,CKD,RSTD',5168,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, skin (light and dark), raw','TURKEY,WHL,SKN (LIGHT & DARK),RAW',5169,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, skin (light and dark), roasted','TURKEY,WHL,SKN (LIGHT & DARK),RSTD',5170,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, giblets, raw','TURKEY,WHL,GIBLETS,RAW',5171,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, giblets, cooked, simmered','TURKEY,WHL,GIBLETS,CKD,SIMMRD',5172,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, gizzard, all classes, raw','TURKEY,GIZZARD,ALL CLASSES,RAW',5173,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, all classes, gizzard, cooked, simmered','TURKEY,ALL CLASSES,GIZZARD,CKD,SIMMRD',5174,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, all classes, heart, raw','TURKEY,ALL CLASSES,HEART,RAW',5175,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, all classes, heart, cooked, simmered','TURKEY,ALL CLASSES,HEART,CKD,SIMMRD',5176,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, all classes, liver, raw','TURKEY,ALL CLASSES,LIVER,RAW',5177,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, all classes, liver, cooked, simmered','TURKEY,ALL CLASSES,LIVER,CKD,SIMMRD',5178,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, neck, meat only, raw','TURKEY,WHL,NECK,MEAT ONLY,RAW',5179,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, neck, meat only, cooked, simmered','TURKEY,WHL,NECK,MEAT ONLY,CKD,SIMMRD',5180,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, light meat, meat and skin, raw','TURKEY,WHL,LT MEAT,MEAT & SKN,RAW',5181,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, light meat, meat and skin, cooked, roasted','TURKEY,WHL,LT MEAT,MEAT & SKN,CKD,RSTD',5182,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, dark meat, meat and skin, raw','TURKEY,DK MEAT,MEAT & SKN,RAW',5183,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, dark meat, meat and skin, cooked, roasted','TURKEY,WHL,DK MEAT,MEAT & SKN,CKD,RSTD',5184,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, light meat, raw','TURKEY,WHL,LT MEAT,RAW',5185,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, all classes, light meat, cooked, roasted','TURKEY,ALL CLASSES,LT MEAT,CKD,RSTD',5186,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, dark meat, meat only, raw','TURKEY,WHL,DK MEAT,MEAT ONLY,RAW',5187,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, dark meat, cooked, roasted','TURKEY,WHL,DK MEAT,CKD,RSTD',5188,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, all classes, back, meat and skin, cooked, roasted','TURKEY,ALL CLASSES,BACK,MEAT&SKN,CKD,RSTD',5190,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, all classes, breast, meat and skin, raw','TURKEY,ALL CLASSES,BREAST,MEAT&SKN,RAW',5191,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, all classes, breast, meat and skin, cooked, roasted','TURKEY,ALL CLASSES,BREAST,MEAT&SKN,CKD,RSTD',5192,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, all classes, leg, meat and skin, raw','TURKEY,ALL CLASSES,LEG,MEAT&SKN,RAW',5193,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, all classes, leg, meat and skin, cooked, roasted','TURKEY,ALL CLASSES,LEG,MEAT&SKN,CKD,RSTD',5194,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, all classes, wing, meat and skin, raw','TURKEY,ALL CLASSES,WING,MEAT&SKN,RAW',5195,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, all classes, wing, meat and skin, cooked, roasted','TURKEY,ALL CLASSES,WING,MEAT&SKN,CKD,RSTD',5196,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, fryer-roasters, meat and skin, cooked, roasted','TURKEY,FRYER-ROASTERS,MEAT&SKN,CKD,RSTD',5200,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, back, meat only, cooked, roasted','TURKEY,BACK,FROM WHL BIRD,MEAT ONLY,RSTD',5216,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, breast, meat only, raw','TURKEY,BREAST,FROM WHL BIRD,MEAT ONLY,RAW',5219,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, breast, meat only, cooked, roasted','TURKEY,BREAST,FROM WHL BIRD,MEAT ONLY,RSTD',5220,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, wing, meat only, raw','TURKEY,WING,FROM WHL BIRD,MEAT ONLY,RAW',5227,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, wing, meat only, cooked, roasted','TURKEY,WING,FROM WHL BIRD,MEAT ONLY,RSTD',5228,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, young hen, skin only, cooked, roasted','TURKEY,YOUNG HEN,SKN ONLY,CKD,RSTD',5236,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, canned, meat only, with broth','CHICKEN,CND,MEAT ONLY,W/BROTH',5277,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Pate de foie gras, canned (goose liver pate), smoked','PATE DE FOIE GRAS,CND (GOOSE LIVER PATE),SMOKED',5282,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, canned, meat only, with broth','TURKEY,CND,MEAT ONLY,W/BROTH',5284,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, diced, light and dark meat, seasoned','TURKEY,DICED,LT&DK MEAT,SEASONED',5285,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey and gravy, frozen','TURKEY AND GRAVY,FROZEN',5286,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey breast, pre-basted, meat and skin, cooked, roasted','TURKEY BREAST,PRE-BASTED,MEAT&SKN,CKD,RSTD',5293,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey thigh, pre-basted, meat and skin, cooked, roasted','TURKEY THIGH,PRE-BASTED,MEAT&SKN,CKD,RSTD',5294,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey roast, boneless, frozen, seasoned, light and dark meat, raw','TURKEY RST,BNLESS,FRZ,SEASONED,LT&DK MEAT,RAW',5295,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey sticks, breaded, battered, fried','TURKEY STKS,BREADED,BATTERED,FRIED',5300,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Poultry, mechanically deboned, from backs and necks with skin, raw','POULTRY,MECHANICALLY DEBONED,FROM BACKS&NECKS W/SKN,RAW',5301,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Poultry, mechanically deboned, from backs and necks without skin, raw','POULTRY,MECHANICALLY DEBONED,FROM BACKS&NECKS WO/SKN,RAW',5302,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Poultry, mechanically deboned, from mature hens, raw','POULTRY,MECHANICALLY DEBONED,FROM MATURE HENS,RAW',5303,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, mechanically deboned, from turkey frames, raw','TURKEY,MECHANICALLY DEBONED,FROM TURKEY FRAMES,RAW',5304,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, Ground, raw','TURKEY,GROUND,RAW',5305,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, Ground, cooked','TURKEY,GROUND,CKD',5306,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, cornish game hens, meat and skin, raw','CHICKEN,CORNISH GAME HENS,MEAT&SKN,RAW',5307,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, cornish game hens, meat and skin, cooked, roasted','CHICKEN,CORNISH GAME HENS,MEAT&SKN,CKD,RSTD',5308,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, cornish game hens, meat only, raw','CHICKEN,CORNISH GAME HENS,MEAT ONLY,RAW',5309,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, cornish game hens, meat only, cooked, roasted','CHICKEN,CORNISH GAME HENS,MEAT ONLY,CKD,RSTD',5310,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, canned, no broth','CHICKEN,CANNED,NO BROTH',5311,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, wing, frozen, glazed, barbecue flavored','CHICKEN,WING,FRZ,GLAZED,BARBECUE FLAV',5312,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, wing, frozen, glazed, barbecue flavored, heated (microwave)','CHICKEN,WING,FRZ,GLAZED,BARBECUE FLAV,HTD (MICROWAVE)',5313,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, breast, skinless, boneless, meat only, with added solution, raw','CKN,BROILERS/FRYERS,BRST,SKNLS,BNLS,MEAT ONLY,W ADDED SLN,RW',5314,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Duck, young duckling, domesticated, White Pekin, breast, meat and skin, boneless, cooked, roasted','DUCK,YNG DUCKLING,DOM,WH PEKIN,BRST,MEAT&SKN,BNLESS,CKD,RSTD',5315,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Duck, young duckling, domesticated, White Pekin, breast, meat only, boneless, cooked without skin, broiled','DUCK,YNG DUCKL,DOM,WH PEKIN,BRST,MEAT,BNLESS,CKD WO/SKN,BRLD',5316,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Duck, young duckling, domesticated, White Pekin, leg, meat and skin, bone in, cooked, roasted','DUCK,YNG DUCKLING,DOM,WH PEKIN,LEG,MEAT&SKN,BONE IN,CKD,RSTD',5317,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Duck, young duckling, domesticated, White Pekin, leg, meat only, bone in, cooked without skin, braised','DUCK,YNG DUCKL,DOM,WH PEKIN,LEG,MEAT,BONE IN,CKD WO/SKN,BRSD',5318,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler, rotisserie, BBQ, drumstick, meat only','CHICKEN,BROILER,ROTISSERIE,BBQ,DRUMSTK,MEAT ONLY',5319,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, wing, frozen, glazed, barbecue flavored, heated (conventional oven)','CHICKEN,WING,FRZ,GLAZED,BBQ FLAV,HTD (CONVENTIONAL OVEN)',5320,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken patty, frozen, uncooked','CHICKEN PATTY,FRZ,UNCKD',5323,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken patty, frozen, cooked','CHICKEN PATTY,FRZ,CKD',5324,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken breast tenders, breaded, cooked, microwaved','CHICKEN BREAST TENDERS,BREADED,CKD,MICROWAVED',5326,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken breast tenders, breaded, uncooked','CHICKEN BREAST TENDERS,BREADED,UNCKD',5327,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, ground, raw','CHICKEN,GROUND,RAW',5332,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, ground, crumbles, cooked, pan-browned','CHICKEN,GROUND,CRUMBLES,CKD,PAN-BROWNED',5333,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler, rotisserie, BBQ, thigh, meat only','CHICKEN,BROILER,ROTISSERIE,BBQ,THIGH,MEAT ONLY',5334,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, feet, boiled','CHICK,FEET,BOILED',5335,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler, rotisserie, BBQ, wing, meat only','CHICKEN,BROILER,ROTISSERIE,BBQ,WING,MEAT ONLY',5339,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, rotisserie, original seasoning, back, meat only, cooked','CHIKN,BROLRS OR FYRS,ROTSSRIE,ORIGNL SESONG,BCK,MEAT OLY,CKD',5341,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, rotisserie, original seasoning, breast, meat only, cooked','CHKN,BRILRS OR FYRS,ROTSSRE,ORGNL SESONING,BRST,MEAT OLY,CKD',5342,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, drumstick, rotisserie, original seasoning, meat only, cooked','CHKN,BRLRS OR FYRS,DRMSTK,ROISSRE,ORGNL SESONIG,MEAT OLY,CKD',5343,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, rotisserie, original seasoning, skin only, cooked','CICKN,BRILRS OR FYRS,ROTSSRE,ORGNL SEASNG,SKN ONLY,CKD',5344,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, rotisserie, original seasoning, thigh, meat only, cooked','CHCKN,BROLRS OR FRYRS,ROTSSRIE,ORGNL SEASNG,TGH,MEAT OLY,CKD',5345,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, rotisserie, original seasoning, wing, meat only, cooked','CHCKN,BROLRS OR FRYRS,ROISSRIE,ORGNL SEASONG,WNG,MET OLY,CKD',5346,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, rotisserie, original seasoning, back, meat and skin, cooked','CHKN,BROLRS OR FRYRS,ROTSSERE,ORGNL SESONG,BCK,MET & SKN,CKD',5347,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, rotisserie, original seasoning, breast, meat and skin, cooked','CHKN,BROLRS OR FRYRS,ROTSSRE,ORGNL SASONG,BRST,MAT & SKN,CKD',5348,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers,  rotisserie, original seasoning, drumstick, meat and skin, cooked','CHKN,BROLRS OR FYRS,ROTSSRE,ORGNL SESONG,DRMSTK,MT & SKN,CKD',5349,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, rotisserie, original seasoning, thigh, meat and skin, cooked','CHKN,BROLRS OR FRYRS,ROTSSRE,ORGNL SESONG,THGH,MET & SKN,CKD',5351,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, rotisserie, original seasoning, wing, meat and skin, cooked','CHKN,BROLRS OR FRYRS,ROTSSRE,ORGNL SEASONG,WNG,MET & SKN,CKD',5352,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler, rotisserie, BBQ, skin','CHICKEN,BROILER,ROTISSERIE,BBQ,SKIN',5356,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler, rotisserie, BBQ, back, meat and skin','CHICKEN,BROILER,ROTISSERIE,BBQ,BACK,MEAT & SKN',5357,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler, rotisserie, BBQ, breast, meat and skin','CHICKEN,BROILER,ROTISSERIE,BBQ,BREAST,MEAT & SKN',5358,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler, rotisserie, BBQ, drumstick, meat and skin','CHICKEN,BROILER,ROTISSERIE,BBQ,DRUMSTK,MEAT & SKN',5359,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler, rotisserie, BBQ, thigh, meat and skin','CHICKEN,BROILER,ROTISSERIE,BBQ,THIGH,MEAT & SKN',5361,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler, rotisserie, BBQ, wing, meat and skin','CHICKEN,BROILER,ROTISSERIE,BBQ,WING,MEAT & SKN',5362,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ruffed Grouse, breast meat, skinless, raw','RUFFED GROUSE,BREAST MEAT,SKINLESS,RAW',5363,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Emu, ground, raw','EMU,GROUND,RAW',5621,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Emu, ground, cooked, pan-broiled','EMU,GROUND,CKD,PAN-BROILED',5622,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Emu, fan fillet, raw','EMU,FAN FILLET,RAW',5623,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Emu, fan fillet, cooked, broiled','EMU,FAN FILLET,CKD,BRLD',5624,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Emu, flat fillet, raw','EMU,FLAT FILLET,RAW',5625,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Emu, full rump, raw','EMU,FULL RUMP,RAW',5626,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Emu, full rump, cooked, broiled','EMU,FULL RUMP,CKD,BRLD',5627,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Emu, inside drum, raw','EMU,INSIDE DRUM,RAW',5628,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Emu, inside drums, cooked, broiled','EMU,INSIDE DRUMS,CKD,BRLD',5629,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Emu, outside drum, raw','EMU,OUTSIDE DRUM,RAW',5630,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Emu, oyster, raw','EMU,OYSTER,RAW',5631,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Emu, top loin, cooked, broiled','EMU,TOP LOIN,CKD,BRLD',5632,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, ground, raw','OSTRICH,GROUND,RAW',5641,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, ground, cooked, pan-broiled','OSTRICH,GROUND,CKD,PAN-BROILED',5642,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, fan, raw','OSTRICH,FAN,RAW',5643,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, inside leg, raw','OSTRICH,INSIDE LEG,RAW',5644,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, inside leg, cooked','OSTRICH,INSIDE LEG,CKD',5645,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, inside strip, raw','OSTRICH,INSIDE STRIP,RAW',5646,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, inside strip, cooked','OSTRICH,INSIDE STRIP,CKD',5647,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, outside leg, raw','OSTRICH,OUTSIDE LEG,RAW',5648,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, outside strip, raw','OSTRICH,OUTSIDE STRIP,RAW',5649,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, outside strip, cooked','OSTRICH,OUTSIDE STRIP,CKD',5650,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, oyster, raw','OSTRICH,OYSTER,RAW',5651,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, oyster, cooked','OSTRICH,OYSTER,CKD',5652,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, round, raw','OSTRICH,RND,RAW',5653,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, tenderloin, raw','OSTRICH,TENDERLOIN,RAW',5654,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, tip trimmed, raw','OSTRICH,TIP RAW',5655,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, tip trimmed, cooked','OSTRICH,TIP CKD',5656,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, top loin, raw','OSTRICH,TOP LOIN,RAW',5657,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Ostrich, top loin, cooked','OSTRICH,TOP LOIN,CKD',5658,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, liver, all classes, cooked, pan-fried','CHICKEN,LIVER,ALL CLASSES,CKD,PAN-FRIED',5661,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, ground, fat free, raw','TURKEY,GROUND,FAT FREE,RAW',5662,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, ground, fat free, pan-broiled crumbles','TURKEY,GROUND,FAT FREE,PAN-BROILED CRUMBLES',5663,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, ground, fat free, patties, broiled','TURKEY,GROUND,FAT FREE,PATTIES,BRLD',5664,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, ground, 93% lean, 7% fat, raw','TURKEY,GROUND,93% LN,7% FAT,RAW',5665,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, ground, 93% lean, 7% fat, pan-broiled crumbles','TURKEY,GROUND,93% LN,7% FAT,PAN-BROILED CRUMBLES',5666,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, ground, 93% lean, 7% fat, patties, broiled','TURKEY,GROUND,93% LN,7% FAT,PATTIES,BRLD',5667,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, ground, 85% lean, 15% fat, raw','TURKEY,GROUND,85% LN,15% FAT,RAW',5668,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, ground, 85% lean, 15% fat, pan-broiled crumbles','TURKEY,GROUND,85% LN,15% FAT,PAN-BROILED CRUMBLES',5669,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, ground, 85% lean, 15% fat, patties, broiled','TURKEY,GROUND,85% LN,15% FAT,PATTIES,BRLD',5670,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, drumstick, meat only, cooked, braised','CHICKEN,BROILERS OR FRYERS,DK MEAT,DRUMSTK,MEAT OLY,CKD,BRSD',5671,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, thigh, meat only, cooked, braised','CHICKEN,BROILERS OR FRYERS,DK MEAT,THIGH,MEAT ONLY,CKD,BRSD',5672,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, skin (drumsticks and thighs), cooked, braised','CHICKEN,SKN (DRUMSTICKS & THIGHS),CKD,BRSD',5673,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, skin (drumsticks and thighs), raw','CHICKEN,SKN (DRUMSTICKS & THIGHS),RAW',5674,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, skin (drumsticks and thighs), cooked, roasted','CHICKEN,SKN (DRUMSTICKS & THIGHS),CKD,RSTD',5675,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, drumstick, meat and skin, cooked, braised','CHICKEN,BROILERS OR FRYERS,DK MEAT,DRUMSTK,MT & SKN,CKD,BRSD',5676,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broilers or fryers, dark meat, thigh, meat and skin, cooked, braised','CHICKEN,BROILERS OR FRYERS,DK MEAT,THIGH,MEAT & SKN,CKD,BRSD',5677,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, dark meat, drumstick, meat only, with added solution, raw','CHICKEN,DK MEAT,DRUMSTK,MEAT ONLY,W/ ADDED SOLN,RAW',5678,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, dark meat, drumstick, meat only, with added solution, cooked, roasted','CHICKEN,DK MEAT,DRUMSTK,MEAT ONLY,W/ ADDED SOLN,CKD,RSTD',5679,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, dark meat, drumstick, meat only, with added solution, cooked, braised','CHICKEN,DK MEAT,DRUMSTK,MEAT ONLY,W/ ADDED SOLN,CKD,BRSD',5680,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, dark meat, thigh, meat only, with added solution, cooked, braised','CHICKEN,DK MEAT,THIGH,MEAT ONLY,W/ ADDED SOLN,CKD,BRSD',5681,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, dark meat, thigh, meat only, with added solution, raw','CHICKEN,DK MEAT,THIGH,MEAT ONLY,W/ ADDED SOLN,RAW',5682,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, dark meat, thigh, meat only, with added solution, cooked, roasted','CHICKEN,DK MEAT,THIGH,MEAT ONLY,W/ ADDED SOLN,CKD,RSTD',5683,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, skin (drumsticks and thighs), with added solution, cooked, braised','CHICKEN,SKN (DRUMSTICKS & THIGHS),W/ ADDED SOLN,CKD,BRSD',5684,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, skin (drumsticks and thighs), with added solution, raw','CHICKEN,SKN (DRUMSTICKS & THIGHS),W/ ADDED SOLN,RAW',5685,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, skin (drumsticks and thighs), with added solution, cooked, roasted','CHICKEN,SKN (DRUMSTICKS & THIGHS),W/ ADDED SOLN,CKD,RSTD',5686,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, dark meat, drumstick, meat and skin, with added solution, cooked, braised','CHICKEN,DK MEAT,DRUMSTK,MEAT & SKN,W/ ADDED SOLN,CKD,BRSD',5687,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, dark meat, drumstick, meat and skin, with added solution, raw','CHICKEN,DK MEAT,DRUMSTK,MEAT & SKN,W/ ADDED SOLN,RAW',5688,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, dark meat, drumstick, meat and skin, with added solution, cooked, roasted','CHICKEN,DK MEAT,DRUMSTK,MEAT & SKN,W/ ADDED SOLN,CKD,RSTD',5689,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, dark meat, thigh, meat and skin, with added solution, cooked, braised','CHICKEN,DK MEAT,THIGH,MEAT & SKN,W/ ADDED SOLN,CKD,BRSD',5690,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, dark meat, thigh, meat and skin, with added solution, raw','CHICKEN,DK MEAT,THIGH,MEAT & SKN,W/ ADDED SOLN,RAW',5691,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, dark meat, thigh, meat and skin, with added solution, cooked, roasted','CHICKEN,DK MEAT,THIGH,MEAT & SKN,W/ ADDED SOLN,CKD,RSTD',5692,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler, rotisserie, BBQ, back meat only','CHICKEN,BROILER,ROTISSERIE,BBQ,BACK MEAT ONLY',5693,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, dark meat from whole, meat only, with added solution, raw','TURKEY,DK MEAT FROM WHL,MEAT ONLY,W/ ADDED SOLN,RAW',5694,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, dark meat, meat only, with added solution, cooked, roasted','TURKEY,DK MEAT,MEAT ONLY,W/ ADDED SOLN,CKD,RSTD',5695,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey from whole, light meat, meat only, with added solution, raw','TURKEY FROM WHL,LT MEAT,MEAT ONLY,W/ ADDED SOLN,RAW',5696,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey from whole, light meat, meat only, with added solution, cooked, roasted','TURKEY FROM WHL,LT MEAT,MEAT ONLY,W/ ADDED SOLN,CKD,RSTD',5697,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, skin from whole (light and dark), with added solution, raw','TURKEY,SKN FROM WHL (LIGHT & DARK),W/ ADDED SOLN,RAW',5698,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, skin from whole, (light and dark), with added solution, roasted','TURKEY,SKN FROM WHL,(LIGHT & DARK),W/ ADDED SOLN,RSTD',5699,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, dark meat from whole, meat and skin, with added solution, raw','TURKEY,DK MEAT FROM WHL,MEAT & SKN,W/ ADDED SOLN,RAW',5700,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, dark meat from whole, meat and skin, with added solution, cooked, roasted','TURKEY,DK MEAT FROM WHL,MEAT & SKN,W/ ADDED SOLN,CKD,RSTD',5701,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey from whole, light meat, meat and skin, with added solution, raw','TURKEY FROM WHL,LT MEAT,MEAT & SKN,W/ ADDED SOLN,RAW',5702,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey from whole, light meat, meat and skin, with added solution, cooked, roasted','TURKEY FROM WHL,LT MEAT,MEAT & SKN,W/ ADDED SOLN,CKD,RSTD',5703,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, meat only, with added solution, raw','TURKEY,WHL,MEAT ONLY,W/ ADDED SOLN,RAW',5704,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, meat only, with added solution, roasted','TURKEY,WHL,MEAT ONLY,W/ ADDED SOLN,RSTD',5705,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, meat and skin, with added solution, raw','TURKEY,WHL,MEAT & SKN,W/ ADDED SOLN,RAW',5706,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, whole, meat and skin, with added solution, roasted','TURKEY,WHL,MEAT & SKN,W/ ADDED SOLN,RSTD',5707,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, breast, meat only, with added solution, raw','TURKEY,RTL PARTS,BREAST,MEAT ONLY,W/ ADDED SOLN,RAW',5708,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, breast, meat only, with added solution, cooked, roasted','TURKEY,RTL PARTS,BREAST,MEAT ONLY,W/ ADDED SOLN,CKD,RSTD',5709,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, breast, meat only, raw','TURKEY,RTL PARTS,BREAST,MEAT ONLY,RAW',5710,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, breast, meat only, cooked, roasted','TURKEY,RTL PARTS,BREAST,MEAT ONLY,CKD,RSTD',5711,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, wing, meat only, raw','TURKEY,RTL PARTS,WING,MEAT ONLY,RAW',5712,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, wing, meat only, cooked, roasted','TURKEY,RTL PARTS,WING,MEAT ONLY,CKD,RSTD',5713,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, skin, from retail parts, from dark meat, raw','TURKEY,SKN,FROM RTL PARTS,FROM DK MEAT,RAW',5714,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, skin, from retail parts, from dark meat, cooked, roasted','TURKEY,SKN,FROM RTL PARTS,FROM DK MEAT,CKD,RSTD',5715,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, drumstick, meat only, raw','TURKEY,RTL PARTS,DRUMSTK,MEAT ONLY,RAW',5716,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, thigh, meat only, raw','TURKEY,RTL PARTS,THIGH,MEAT ONLY,RAW',5717,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, breast, from whole bird, meat only, with added solution, roasted','TURKEY,BREAST,FROM WHL BIRD,MEAT ONLY,W/ ADDED SOLN,RSTD',5718,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, back, from whole bird, meat only, with added solution, raw','TURKEY,BACK,FROM WHL BIRD,MEAT ONLY,W/ ADDED SOLN,RAW',5719,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, back, from whole bird, meat only, with added solution, roasted','TURKEY,BACK,FROM WHL BIRD,MEAT ONLY,W/ ADDED SOLN,RSTD',5720,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, breast, from whole bird, meat only, with added solution, raw','TURKEY,BREAST,FROM WHL BIRD,MEAT ONLY,W/ ADDED SOLN,RAW',5721,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, thigh, meat only, cooked, roasted','TURKEY,RTL PARTS,THIGH,MEAT ONLY,CKD,RSTD',5722,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, drumstick, meat only, cooked, roasted','TURKEY,RTL PARTS,DRUMSTK,MEAT ONLY,CKD,RSTD',5723,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, drumstick, from whole bird, meat only, with added solution, raw','TURKEY,DRUMSTK,FROM WHL BIRD,MEAT ONLY,W/ ADDED SOLN,RAW',5724,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, drumstick, from whole bird, meat only, with added solution, roasted','TURKEY,DRUMSTK,FROM WHL BIRD,MEAT ONLY,W/ ADDED SOLN,RSTD',5725,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, thigh, from whole bird, meat only, with added solution, raw','TURKEY,THIGH,FROM WHL BIRD,MEAT ONLY,W/ ADDED SOLN,RAW',5726,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, breast, meat and skin, with added solution, raw','TURKEY,RTL PARTS,BREAST,MEAT & SKN,W/ ADDED SOLN,RAW',5727,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, thigh, from whole bird, meat only, with added solution, roasted','TURKEY,THIGH,FROM WHL BIRD,MEAT ONLY,W/ ADDED SOLN,RSTD',5728,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, wing, from whole bird, meat only, with added solution, raw','TURKEY,WING,FROM WHL BIRD,MEAT ONLY,W/ ADDED SOLN,RAW',5729,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, wing, from whole bird, meat only, with added solution, roasted','TURKEY,WING,FROM WHL BIRD,MEAT ONLY,W/ ADDED SOLN,RSTD',5730,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, breast, meat and skin, raw','TURKEY,RTL PARTS,BREAST,MEAT & SKN,RAW',5732,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, breast, meat and skin, cooked, roasted','TURKEY,RTL PARTS,BREAST,MEAT & SKN,CKD,RSTD',5733,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, wing, meat and skin, raw','TURKEY,RTL PARTS,WING,MEAT & SKN,RAW',5734,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, wing, meat and skin, cooked, roasted','TURKEY,RTL PARTS,WING,MEAT & SKN,CKD,RSTD',5735,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, drumstick, meat and skin, raw','TURKEY,RTL PARTS,DRUMSTK,MEAT & SKN,RAW',5736,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, drumstick, meat and skin, cooked, roasted','TURKEY,RTL PARTS,DRUMSTK,MEAT & SKN,CKD,RSTD',5737,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, drumstick, from whole bird, meat only, raw','TURKEY,DRUMSTK,FROM WHL BIRD,MEAT ONLY,RAW',5738,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, drumstick, from whole bird, meat only, roasted','TURKEY,DRUMSTK,FROM WHL BIRD,MEAT ONLY,RSTD',5739,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, thigh, from whole bird, meat only, raw','TURKEY,THIGH,FROM WHL BIRD,MEAT ONLY,RAW',5740,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, thigh, from whole bird, meat only, roasted','TURKEY,THIGH,FROM WHL BIRD,MEAT ONLY,RSTD',5741,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, thigh, meat and skin, raw','TURKEY,RTL PARTS,THIGH,MEAT & SKN,RAW',5742,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, retail parts, thigh, meat and skin, cooked, roasted','TURKEY,RTL PARTS,THIGH,MEAT & SKN,CKD,RSTD',5743,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, back, from whole bird, meat and skin, with added solution, raw','TURKEY,BACK,FROM WHL BIRD,MEAT & SKN,W/ ADDED SOLN,RAW',5744,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, back, from whole bird, meat and skin, with added solution, roasted','TURKEY,BACK,FROM WHL BIRD,MEAT & SKN,W/ ADDED SOLN,RSTD',5745,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler or fryers, breast, skinless, boneless, meat only, cooked, braised','CHICkN,BROILR OR FRYRS,BRST,SKNLSS,BNLESS,MEAT ONLY,CKD,BRSD',5746,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler or fryers, breast, skinless, boneless, meat only, cooked, grilled','CHCKN,BROLR OR FRYRS,BRST,SKNLSS,BNLESS,MEAT ONLY,CKD,GRILLD',5747,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler or fryers, breast, skinless, boneless, meat only, with added solution, cooked, braised','CKN,BRLER OR FRYERS,BRST,SKNLS,BNLS,MT ONLY,W ADDED SLN,BRSD',5748,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Chicken, broiler or fryers, breast, skinless, boneless, meat only, with added solution, cooked, grilled','CKN,BRLER/FRYERS,BRST,SKNLS,BNLS,MT ONLY,W ADDED SLN,GRILLED',5749,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of asparagus, canned, condensed','SOUP,CRM OF ASPARAGUS,CND,COND',6001,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, black bean, canned, condensed','SOUP,BLACK BEAN,CND,COND',6002,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, bean with pork, canned, condensed','SOUP,BEAN W/ PORK,CND,COND',6004,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, bean with frankfurters, canned, condensed','SOUP,BEAN W/ FRANKFURTERS,CND,COND',6006,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, bean with ham, canned, chunky, ready-to-serve','SOUP,BEAN W/ HAM,CND,CHUNKY,RTS',6007,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef broth or bouillon canned, ready-to-serve','SOUP,BF BROTH OR BOUILLON CND,RTS',6008,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef noodle, canned, condensed','SOUP,BF NOODLE,CND,COND',6009,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of celery, canned, condensed','SOUP,CRM OF CELERY,CND,COND',6010,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cheese, canned, condensed','SOUP,CHS,CND,COND',6011,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken broth, canned, condensed','SOUP,CHICK BROTH,CND,COND',6013,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken, canned, chunky, ready-to-serve','SOUP,CHICK,CND,CHUNKY,RTS',6015,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of chicken, canned, condensed','SOUP,CRM OF CHICK,CND,COND',6016,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken gumbo, canned, condensed','SOUP,CHICK GUMBO,CND,COND',6017,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chunky chicken noodle, canned, ready-to-serve','SOUP,CHUNKY CHICK NOODLE,CND,RTS',6018,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken noodle, canned, condensed','SOUP,CHICK NOODLE,CND,COND',6019,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken rice, canned, chunky, ready-to-serve','SOUP,CHICK RICE,CND,CHUNKY,RTS',6022,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken with rice, canned, condensed','SOUP,CHICK W/ RICE,CND,COND',6023,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken and vegetable, canned, ready-to-serve','SOUP,CHICK & VEG,CND,RTS',6024,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken vegetable, canned, condensed','SOUP,CHICK VEG,CND,COND',6025,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chili beef, canned, condensed','SOUP,CHILI BF,CND,COND',6026,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, clam chowder, manhattan style, canned, chunky, ready-to-serve','SOUP,CLAM CHOWDER,MANHATTAN STYLE,CND,CHUNKY,RTS',6027,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, clam chowder, manhattan, canned, condensed','SOUP,CLAM CHOWDER,MANHATTAN,CND,COND',6028,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, clam chowder, new england, canned, condensed','SOUP,CLAM CHOWDER,NEW ENGLAND,CND,COND',6030,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef broth bouillon and consomme, canned, condensed','SOUP,BF BROTH BOUILLON & CONSOMME,CND,COND',6032,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, lentil with ham, canned, ready-to-serve','SOUP,LENTIL W/HAM,CND,RTS',6037,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, minestrone, canned, chunky, ready-to-serve','SOUP,MINESTRONE,CND,CHUNKY,RTS',6039,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, minestrone, canned, condensed','SOUP,MINESTRONE,CND,COND',6040,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, mushroom barley, canned, condensed','SOUP,MUSHROOM BARLEY,CND,COND',6042,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of mushroom, canned, condensed','SOUP,CRM OF MUSHROOM,CND,COND',6043,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, mushroom with beef stock, canned, condensed','SOUP,MUSHROOM W/ BF STOCK,CND,COND',6044,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, onion, canned, condensed','SOUP,ONION,CND,COND',6045,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of onion, canned, condensed','SOUP,CRM OF ONION,CND,COND',6046,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, oyster stew, canned, condensed','SOUP,OYSTER STEW,CND,COND',6048,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, pea, green, canned, condensed','SOUP,PEA,GRN,CND,COND',6049,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, pea, split with ham, canned, chunky, ready-to-serve','SOUP,PEA,SPLIT W/HAM,CND,CHUNKY,RTS',6050,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, pea, split with ham, canned, condensed','SOUP,PEA,SPLIT W/ HAM,CND,COND',6051,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of potato, canned, condensed','SOUP,CRM OF POTATO,CND,COND',6053,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of shrimp, canned, condensed','SOUP,CRM OF SHRIMP,CND,COND',6056,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, tomato beef with noodle, canned, condensed','SOUP,TOMATO BF W/ NOODLE,CND,COND',6061,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, tomato rice, canned, condensed','SOUP,TOMATO RICE,CND,COND',6063,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, turkey, chunky, canned, ready-to-serve','SOUP,TURKEY,CHUNKY,CND,RTS',6064,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chunky vegetable, canned, ready-to-serve','SOUP,CHUNKY VEG,CND,RTS',6067,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, vegetarian vegetable, canned, condensed','SOUP,VEGETARIAN VEG,CND,COND',6068,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chunky beef, canned, ready-to-serve','SOUP,CHUNKY BF,CND,RTS',6070,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, vegetable beef, canned, condensed','SOUP,VEG BF,CND,COND',6071,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, vegetable with beef broth, canned, condensed','SOUP,VEG W/ BF BROTH,CND,COND',6072,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef broth or bouillon, powder, dry','SOUP,BF BROTH OR BOUILLON,PDR,DRY',6075,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef broth, cubed, dry','SOUP,BEEF BROTH,CUBED,DRY',6076,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken broth or bouillon, dry','SOUP,CHICK BROTH OR BOUILLON,DRY',6080,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken broth cubes, dry','SOUP,CHICK BROTH CUBES,DRY',6081,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, onion, dry, mix','SOUP,ONION,DRY,MIX',6094,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of vegetable, dry, powder','SOUP,CRM OF VEG,DRY,PDR',6101,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, teriyaki, ready-to-serve','SAUCE,TERIYAKI,RTS',6112,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, au jus, canned','GRAVY,AU JUS,CANNED',6114,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, au jus, dry','GRAVY,AU JUS,DRY',6115,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, beef, canned, ready-to-serve','GRAVY,BF,CND,RTS',6116,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, brown, dry','GRAVY,BROWN,DRY',6118,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, chicken, canned or bottled, ready-to-serve','GRVY, CHCKN, CNND BTTLD, RTS',6119,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, chicken, dry','GRAVY,CHICKEN,DRY',6120,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, mushroom, canned','GRAVY,MUSHROOM,CANNED',6121,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, mushroom, dry, powder','GRAVY,MUSHROOM,DRY,PDR',6122,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, onion, dry, mix','GRAVY,ONION,DRY,MIX',6123,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, pork, dry, powder','GRAVY,PORK,DRY,PDR',6124,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, turkey, canned, ready-to-serve','GRAVY,TURKEY,CND,RTS',6125,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, turkey, dry','GRAVY,TURKEY,DRY',6126,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, unspecified type, dry','GRAVY,UNSPEC TYPE,DRY',6127,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken noodle, dry, mix','SOUP,CHICK NOODLE,DRY,MIX',6128,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef mushroom, canned, condensed','SOUP,BF MUSHROOM,CND,COND',6147,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken mushroom, canned, condensed','SOUP,CHICK MUSHROOM,CND,COND',6149,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, barbecue','SAUCE,BARBECUE',6150,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, plum, ready-to-serve','SAUCE,PLUM,READY-TO-SERVE',6151,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, pizza, canned, ready-to-serve','SAUCE,PIZZA,CND,RTS',6152,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, tomato bisque, canned, condensed','SOUP,TOMATO BISQUE,CND,COND',6158,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, tomato, canned, condensed','SOUP,TOMATO,CND,COND',6159,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, salsa, ready-to-serve','SAUCE,SALSA,RTS',6164,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, homemade, white, medium','SAUCE,HOMEMADE,WHITE,MED',6166,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, homemade, white, thick','SAUCE,HOMEMADE,WHITE,THICK',6167,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, ready-to-serve, pepper or hot','SAUCE,RTS,PEPPER OR HOT',6168,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, stock, beef, home-prepared','SOUP,STOCK,BEEF,HOME-PREPARED',6170,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, stock, chicken, home-prepared','SOUP,STOCK,CHICK,HOME-PREPARED',6172,NULL,NULL,NULL,NULL,NULL,1,'1995-06-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, stock, fish, home-prepared','SOUP,STOCK,FISH,HOME-PREPARED',6174,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, hoisin, ready-to-serve','SAUCE,HOISIN,RTS',6175,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, oyster, ready-to-serve','SAUCE,OYSTER,RTS',6176,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, minestrone, canned, reduced sodium, ready-to-serve','SOUP,MINESTRONE,CND,RED NA,RTS',6177,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, fish, ready-to-serve','SAUCE,FISH,READY-TO-SERVE',6179,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, shark fin, restaurant-prepared','SOUP,SHARK FIN,REST-PREP',6180,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of mushroom, canned, condensed, reduced sodium','SOUP,CRM OF MUSHROOM,CND,COND,RED NA',6182,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken broth, less/reduced sodium, ready to serve','SOUP,CHICK BROTH,LESS/REDUCED NA,READY TO SERVE',6183,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef broth, less/reduced sodium, ready to serve','SOUP,BF BROTH,LESS/REDUCED NA,READY TO SERVE',6188,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, teriyaki, ready-to-serve, reduced sodium','SAUCE,TERIYAKI,RTS,RED NA',6189,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, bean & ham, canned, reduced sodium, prepared with water or ready-to-serve','SOUP,BEAN&HAM,CND,RED NA,PREP W/H2O OR RTS',6190,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Split pea soup, canned, reduced sodium, prepared with water or ready-to serve','SPLIT PEA SOUP,CND,RED NA,PREP W/ H2O OR READY-TO SERVE',6192,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Split pea with ham soup, canned, reduced sodium, prepared with water or ready-to-serve','SPLIT PEA W/ HAM SOUP,CND,RED NA,PREP W/ H2O OR RTS',6193,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken broth, ready-to-serve','SOUP,CHICK BROTH,RTS',6194,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of asparagus, canned, prepared with equal volume milk','SOUP,CRM OF ASPARAGUS,CND,PREP W/ EQ VOLUME MILK',6201,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken vegetable with potato and cheese, chunky, ready-to-serve','SOUP,CHICK VEG W/POTATO&CHS,CHUNKY,RTS',6208,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of celery, canned, prepared with equal volume milk','SOUP,CRM OF CELERY,CND,PREP W/ EQ VOLUME MILK',6210,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cheese, canned, prepared with equal volume milk','SOUP,CHS,CND,PREP W/ EQ VOLUME MILK',6211,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of chicken, canned, prepared with equal volume milk','SOUP,CRM OF CHICK,CND,PREP W/ EQ VOLUME MILK',6216,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, vegetable, canned, low sodium, condensed','SOUP,VEG,CND,LO NA,COND',6217,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, clam chowder, new england, canned, prepared with equal volume low fat (2%) milk','SOUP,CLAM CHOWDER,NEW ENG,CND,PREP W/ EQ VLM LOFAT (2%) MILK',6230,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of mushroom, canned, prepared with equal volume low fat (2%) milk','SOUP,CRM OF MUSHROOM,CND,PREP W/ EQ VOLUME LOFAT (2%) MILK',6243,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of onion, canned, prepared with equal volume milk','SOUP,CRM OF ONION,CND,PREP W/ EQ VOLUME MILK',6246,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, oyster stew, canned, prepared with equal volume milk','SOUP,OYSTER STEW,CND,PREP W/ EQ VOLUME MILK',6248,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, pea, green, canned, prepared with equal volume milk','SOUP,PEA,GRN,CND,PREP W/ EQ VOLUME MILK',6249,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of potato, canned, prepared with equal volume milk','SOUP,CRM OF POTATO,CND,PREP W/ EQ VOLUME MILK',6253,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of shrimp, canned, prepared with equal volume low fat (2%) milk','SOUP,CRM OF SHRIMP,CND,PREP W/ EQ VOLUME LOFAT (2%) MILK',6256,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, white, thin, prepared-from-recipe, with butter','SAUCE,WHITE,THIN,PREPARED-FROM-RECIPE,W/ BUTTER',6264,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, sweet and sour, prepared-from-recipe','SAUCE,SWT & SOUR,PREPARED-FROM-RECIPE',6285,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, tomato bisque, canned, prepared with equal volume milk','SOUP,TOMATO BISQUE,CND,PREP W/ EQ VOLUME MILK',6358,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, tomato, canned, prepared with equal volume low fat (2%) milk','SOUP,TOMATO,CND,PREP W/ EQ VOLUME LOFAT (2%) MILK',6359,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of asparagus, canned, prepared with equal volume water','SOUP,CRM OF ASPARAGUS,CND,PREP W/ EQ VOLUME H2O',6401,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, black bean, canned, prepared with equal volume water','SOUP,BLACK BEAN,CND,PREP W/ EQ VOLUME H2O',6402,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, bean with pork, canned, prepared with equal volume water','SOUP,BEAN W/ PORK,CND,PREP W/ EQ VOLUME H2O',6404,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, bean with frankfurters, canned, prepared with equal volume water','SOUP,BEAN W/ FRANKFURTERS,CND,PREP W/ EQ VOLUME H2O',6406,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef noodle, canned, prepared with equal volume water','SOUP,BF NOODLE,CND,PREP W/ EQ VOLUME H2O',6409,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of celery, canned, prepared with equal volume water','SOUP,CRM OF CELERY,CND,PREP W/ EQ VOLUME H2O',6410,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cheese, canned, prepared with equal volume water','SOUP,CHS,CND,PREP W/ EQ VOLUME H2O',6411,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken broth, canned, prepared with equal volume water','SOUP,CHICK BROTH,CND,PREP W/ EQ VOLUME H2O',6413,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of chicken, canned, prepared with equal volume water','SOUP,CRM OF CHICK,CND,PREP W/ EQ VOLUME H2O',6416,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken gumbo, canned, prepared with equal volume water','SOUP,CHICK GUMBO,CND,PREP W/ EQ VOLUME H2O',6417,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken noodle, canned, prepared with equal volume water','SOUP,CHICK NOODLE,CND,PREP W/ EQ VOLUME H2O',6419,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken with rice, canned, prepared with equal volume water','SOUP,CHICK W/ RICE,CND,PREP W/ EQ VOLUME H2O',6423,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chili beef, canned, prepared with equal volume water','SOUP,CHILI BF,CND,PREP W/ EQ VOLUME H2O',6426,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, clam chowder, manhattan, canned, prepared with equal volume water','SOUP,CLAM CHOWDER,MANHATTAN,CND,PREP W/EQ VOLUME H2O',6428,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, clam chowder, new england, canned, prepared with equal volume water','SOUP,CLAM CHOWDER,NEW ENGLAND,CND,PREP W/ EQ VOLUME H2O',6430,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef broth, bouillon, consomme, prepared with equal volume water','SOUP,BF BROTH,BOUILLON,CONSOMME,PREP W/ EQ VOLUME H2O',6432,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, minestrone, canned, prepared with equal volume water','SOUP,MINESTRONE,CND,PREP W/ EQ VOLUME H2O',6440,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, mushroom barley, canned, prepared with equal volume water','SOUP,MUSHROOM BARLEY,CND,PREP W/ EQ VOLUME H2O',6442,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of mushroom, canned, prepared with equal volume water','SOUP,CRM OF MUSHROOM,CND,PREP W/ EQ VOLUME H2O',6443,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, mushroom with beef stock, canned, prepared with equal volume water','SOUP,MUSHROOM W/ BF STOCK,CND,PREP W/ EQ VOLUME H2O',6444,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of onion, canned, prepared with equal volume water','SOUP,CRM OF ONION,CND,PREP W/ EQ VOLUME H2O',6446,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, oyster stew, canned, prepared with equal volume water','SOUP,OYSTER STEW,CND,PREP W/ EQ VOLUME H2O',6448,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, pea, green, canned, prepared with equal volume water','SOUP,PEA,GRN,CND,PREP W/ EQ VOLUME H2O',6449,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, pea, split with ham, canned, prepared with equal volume water','SOUP,PEA,SPLIT W/ HAM,CND,PREP W/ EQ VOLUME H2O',6451,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of potato, canned, prepared with equal volume water','SOUP,CRM OF POTATO,CND,PREP W/ EQ VOLUME H2O',6453,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of shrimp, canned, prepared with equal volume water','SOUP,CRM OF SHRIMP,CND,PREP W/ EQ VOLUME H2O',6456,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, tomato beef with noodle, canned, prepared with equal volume water','SOUP,TOMATO BF W/ NOODLE,CND,PREP W/ EQ VOLUME H2O',6461,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, tomato rice, canned, prepared with equal volume water','SOUP,TOMATO RICE,CND,PREP W/ EQ VOLUME H2O',6463,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, turkey noodle, canned, prepared with equal volume water','SOUP,TURKEY NOODLE,CND,PREP W/ EQ VOLUME H2O',6465,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, turkey vegetable, canned, prepared with equal volume water','SOUP,TURKEY VEG,CND,PREP W/ EQ VOLUME H2O',6466,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, vegetarian vegetable, canned, prepared with equal volume water','SOUP,VEGETARIAN VEG,CND,PREP W/ EQ VOLUME H2O',6468,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, vegetable beef, canned, prepared with equal volume water','SOUP,VEG BF,CND,PREP W/ EQ VOLUME H2O',6471,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, vegetable with beef broth, canned, prepared with equal volume water','SOUP,VEG W/ BF BROTH,CND,PREP W/ EQ VOLUME H2O',6472,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef broth or bouillon, powder, prepared with water','SOUP,BF BROTH OR BOUILLON,PDR,PREP W/H2O',6475,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef broth, cubed, prepared with water','SOUP,BF BROTH,CUBED,PREP W/H2O',6476,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken broth or bouillon, dry, prepared with water','SOUP,CHICK BROTH OR BOUILLON,DRY,PREP W/ H2O',6480,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken broth cubes, dry, prepared with water','SOUP,CHICK BROTH CUBES,DRY,PREP W/ H2O',6481,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of chicken, dry, mix, prepared with water','SOUP,CRM OF CHICK,DRY,MIX,PREP W/ H2O',6483,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, onion, dry, mix, prepared with water','SOUP,ONION,DRY,MIX,PREP W/ H2O',6494,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, tomato, dry, mix, prepared with water','SOUP,TOMATO,DRY,MIX,PREP W/ H2O',6498,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken noodle, dry, mix, prepared with water','SOUP,CHICK NOODLE,DRY,MIX,PREP W/ H2O',6528,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef mushroom, canned, prepared with equal volume water','SOUP,BF MUSHROOM,CND,PREP W/ EQ VOLUME H2O',6547,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken mushroom, canned, prepared with equal volume water','SOUP,CHICK MUSHROOM,CND,PREP W/ EQ VOLUME H2O',6549,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, tomato bisque, canned, prepared with equal volume water','SOUP,TOMATO BISQUE,CND,PREP W/ EQ VOLUME H2O',6558,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, tomato, canned, prepared with equal volume water, commercial','SOUP,TOMATO,CND,PREP W/EQ VOLUME H2O,COMM',6559,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, ramen noodle, any flavor, dry','SOUP,RAMEN NOODLE,ANY FLAVOR,DRY',6583,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, broccoli cheese, canned, condensed, commercial','SOUP,BROCCOLI CHS,CND,COND,COMM',6584,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, peanut, made from coconut, water, sugar, peanuts','SAUCE,PNUT,MADE FROM COCNT,H2O,SUGAR,PNUTS',6618,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, pesto, ready-to-serve, refrigerated','SAUCE,PESTO,RTS,REFR',6626,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, pesto, ready-to-serve, shelf stable','SAUCE,PESTO,RTS,SHELF STABLE',6627,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, vegetable broth, ready to serve','SOUP,VEG BROTH,READY TO SERVE',6700,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, cheese sauce mix, dry','SAUCE,CHS SAU MIX,DRY',6720,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken corn chowder, chunky, ready-to-serve, single brand','SOUP,CHICK CORN CHOWDER,CHUNKY,RTS,SINGLE BRAND',6725,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, bean with bacon, condensed, single brand','SOUP,BEAN W/BACON,COND,SINGLE BRAND',6731,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, vegetable beef, microwavable, ready-to-serve, single brand','SOUP,VEG BF,MICROWAVABLE,RTS,SINGLE BRAND',6742,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef and vegetables, canned, ready-to-serve','SOUP,BF & VEG,CND,RTS',6749,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, cheese, ready-to-serve','SAUCE,CHS,RTS',6930,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, pasta, spaghetti/marinara, ready-to-serve','SAUCE,PASTA,SPAGHETTI/MARINARA,RTS',6931,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of chicken, canned, condensed, reduced sodium','SOUP,CRM OF CHICK,CND,COND,RED NA',6955,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, tomato, canned, condensed, reduced sodium','SOUP,TOMATO,CND,COND,RED NA',6956,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, brown instant, dry','GRAVY,BROWN INST,DRY',6957,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, instant beef, dry','GRAVY,INST BF,DRY',6958,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, instant turkey, dry','GRAVY,INST TURKEY,DRY',6959,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, alfredo mix, dry','SAUCE,ALFREDO MIX,DRY',6960,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, peppers, hot, chili, mature red, canned','SAUCE,PEPPERS,HOT,CHILI,MATURE RED,CND',6961,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, chili, peppers, hot, immature green, canned','SAUCE,CHILI,PEPPERS,HOT,IMMAT GRN,CND',6962,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Fish broth','FISH BROTH',6963,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, tomato, low sodium, with water','SOUP,TOMATO,LO NA,W/H2O',6964,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, pea, low sodium, prepared with equal volume water','SOUP,PEA,LO NA,PREP W/ EQ VOLUME H2O',6965,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken noodle, low sodium, canned, prepared with equal volume water','SOUP,CHICK NOODLE,LO NA,CND,PREP W/ EQ VOLUME H2O',6966,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, vegetable soup, condensed, low sodium, prepared with equal volume water','SOUP,VEG SOUP,COND,LO NA,PREP W/ EQ VOLUME H2O',6967,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, cream of mushroom, low sodium, ready-to-serve, canned','SOUP,CRM OF MUSHROOM,LO NA,RTS,CND',6968,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Potato soup, instant, dry mix','POTATO SOUP,INST,DRY MIX',6969,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken broth, low sodium, canned','SOUP,CHICK BROTH,LO NA,CND',6970,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, worcestershire','SAUCE,WORCESTERSHIRE',6971,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, tomato chili sauce, bottled, with salt','SAUCE,TOMATO CHILI SAU,BTLD,W/SALT',6972,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, vegetable chicken, canned, prepared with water, low sodium','SOUP,VEG CHICK,CND,PREP W/ H2O,LO NA',6974,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, pasta, spaghetti/marinara, ready-to-serve, low sodium','SAUCE,PASTA,SPAGHETTI/MARINARA,RTS,LO NA',6976,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Gravy, meat or poultry, low sodium, prepared','GRAVY,MEAT OR POULTRY,LO NA,PREP',6977,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef and mushroom, low sodium, chunk style','SOUP,BF & MUSHROOM,LO NA,CHUNK STYLE',6978,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef stroganoff, canned, chunky style, ready-to-serve','SOUP,BF STROGANOFF,CND,CHUNKY STYLE,RTS',6980,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, bouillon cubes and granules, low sodium, dry','SOUP,BOUILLON CUBES&GRANULES,LO NA,DRY',6981,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, ramen noodle, beef flavor, dry','SOUP,RAMEN NOODLE,BF FLAVOR,DRY',6982,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, ramen noodle, chicken flavor, dry','SOUP,RAMEN NOODLE,CHICK FLAVOR,DRY',6983,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Barbecue loaf, pork, beef','BARBECUE LOAF,PORK,BEEF',7001,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Beerwurst, beer salami, pork and beef','BEERWURST,BEER SALAMI,PORK & BF',7002,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Beerwurst, beer salami, pork','BEERWURST,BEER SALAMI,PORK',7003,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, Berliner, pork, beef','SAUSAGE  BERLINER  PORK  BF',7004,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Blood sausage','BLOOD SAUSAGE',7005,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bockwurst, pork, veal, raw','BOCKWURST  PORK  VEAL  RAW',7006,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bologna, beef','BOLOGNA,BF',7007,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bologna, beef and pork','BOLOGNA,BF & PORK',7008,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bologna, pork','BOLOGNA,PORK',7010,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bologna, turkey','BOLOGNA  TURKEY',7011,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bratwurst, pork, cooked','BRATWURST,PORK,CKD',7013,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Braunschweiger (a liver sausage), pork','BRAUNSCHWEIGER (A LIVER SAUSAGE),PORK',7014,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bratwurst, pork, beef, link','BRATWURST,PORK,BF,LINK',7015,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Cheesefurter, cheese smokie, pork, beef','CHEESEFURTER,CHS SMOKIE,PORK,BF',7016,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Chicken spread','CHICKEN SPRD',7018,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, pork, chorizo, link or ground, raw','SAUSAGE,PORK,CHORIZO,LINK OR GROUND,RAW',7019,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Corned beef loaf, jellied','CORNED BEEF LOAF,JELLIED',7020,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Dutch brand loaf, chicken, pork and beef','DUTCH BRAND LOAF,CHICK,PORK & BF',7021,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Frankfurter, beef, unheated','FRANKFURTER,BF,UNHTD',7022,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Frankfurter, chicken','FRANKFURTER,CHICKEN',7024,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Frankfurter, turkey','FRANKFURTER,TURKEY',7025,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Ham, chopped, canned','HAM,CHOPPED,CANNED',7026,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Ham, chopped, not canned','HAM,CHOPPED,NOT CANNED',7027,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Ham, sliced, pre-packaged, deli meat (96%fat free, water added)','HAM,SLICED,PRE-PACKAGED,DELI MEAT (96%FAT FREE,H2O ADDED)',7028,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Ham, sliced, regular (approximately 11% fat)','HAM,SLICED,REG (APPROX 11% FAT)',7029,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Ham, minced','HAM,MINCED',7030,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Ham salad spread','HAM SALAD SPREAD',7031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Ham and cheese loaf or roll','HAM&CHS LOAF OR ROLL',7032,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Ham and cheese spread','HAM AND CHEESE SPREAD',7033,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Headcheese, pork','HEADCHEESE,PORK',7034,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, Italian, pork, mild, raw','SAUSAGE,ITALIAN,PORK,MILD,RAW',7036,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Knackwurst, knockwurst, pork, beef','KNACKWURST  KNOCKWURST  PORK  BF',7038,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Lebanon bologna, beef','LEBANON BOLOGNA  BF',7039,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Liver cheese, pork','LIVER CHEESE,PORK',7040,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Liver sausage, liverwurst, pork','LIVER SAUSAGE,LIVERWURST,PORK',7041,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Roast beef, deli style, prepackaged, sliced','ROAST BF,DELI STYLE,PREPACKAGED,SLICED',7043,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Luncheon meat, pork, canned','LUNCHEON MEAT,PORK,CANNED',7045,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Turkey breast, low salt, prepackaged or deli, luncheon meat','TURKEY BREAST,LO SALT,PREPACKAGED OR DELI,LUNCHEON MEAT',7046,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Mortadella, beef, pork','MORTADELLA,BEEF,PORK',7050,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Olive loaf, pork','OLIVE LOAF,PORK',7051,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pastrami, turkey','PASTRAMI,TURKEY',7052,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pate, chicken liver, canned','PATE,CHICKEN LIVER,CANNED',7053,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pate, goose liver, smoked, canned','PATE,GOOSE LIVER,SMOKED,CND',7054,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pate, liver, not specified, canned','PATE,LIVER,NOT SPECIFIED,CND',7055,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Peppered loaf, pork, beef','PEPPERED LOAF  PORK  BF',7056,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pepperoni, beef and pork, sliced','PEPPERONI,BF & PORK,SLICED',7057,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pickle and pimiento loaf, pork','PICKLE&PIMIENTO LOAF,PORK',7058,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Polish sausage, pork','POLISH SAUSAGE,PORK',7059,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Luxury loaf, pork','LUXURY LOAF,PORK',7060,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Mother''s loaf, pork','MOTHER''S LOAF,PORK',7061,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Picnic loaf, pork, beef','PICNIC LOAF,PORK,BEEF',7062,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pork sausage, link/patty, unprepared','PORK SAUSAGE,LINK/PATTY,UNPREP',7063,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pork sausage, link/patty, cooked, pan-fried','PORK SAUSAGE,LINK/PATTY,CKD,PAN-FRIED',7064,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, pork and beef, fresh, cooked','SAUSAGE,PORK & BF,FRSH,CKD',7065,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, turkey, reduced fat, brown and serve, cooked','SAUSAGE,TURKEY,RED FAT,BROWN & SERVE,CKD',7066,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Poultry salad sandwich spread','POULTRY SALAD SNDWCH SPRD',7067,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Salami, cooked, beef','SALAMI  CKD  BF',7068,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Salami, cooked, beef and pork','SALAMI,CKD,BF&PORK',7069,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Salami, cooked, turkey','SALAMI,COOKED,TURKEY',7070,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Salami, dry or hard, pork','SALAMI,DRY OR HARD,PORK',7071,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Salami, dry or hard, pork, beef','SALAMI,DRY OR HARD,PORK,BF',7072,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sandwich spread, pork, beef','SANDWICH SPREAD,PORK,BEEF',7073,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, smoked link sausage, pork','SAUSAGE,SMOKED LINK SAUSAGE,PORK',7074,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, smoked link sausage, pork and beef','SAUSAGE,SMOKED LINK SAUSAGE,PORK & BF',7075,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, smoked link sausage, pork and beef (nonfat dry milk added)','SAUSAGE,SMOKED LINK SAUSAGE,PORK & BF (NONFAT DRY MLK ADDED)',7077,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Thuringer, cervelat, summer sausage, beef, pork','THURINGER,CERVELAT,SMMR SAUSAGE,BF,PORK',7078,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Turkey breast, sliced, prepackaged','TURKEY BREAST,SLICED,PREPACKAGED',7081,NULL,NULL,NULL,NULL,NULL,1,'1995-06-12','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, Vienna, canned, chicken, beef, pork','SAUSAGE,VIENNA,CND,CHICK,BF,PORK',7083,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Honey roll sausage, beef','HONEY ROLL SAUSAGE,BEEF',7088,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, Italian, pork, mild, cooked, pan-fried','SAUSAGE,ITALIAN,PORK,MILD,CKD,PAN-FRIED',7089,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Luncheon sausage, pork and beef','LUNCHEON SAUSAGE,PORK&BF',7090,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bacon, turkey, unprepared','BACON,TURKEY,UNPREP',7254,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, turkey, pork, and beef, low fat, smoked','SAUSAGE,TURKEY,PORK,& BF,LOFAT,SMOKED',7900,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Frankfurter, beef, pork, and turkey, fat free','FRANKFURTER,BF,PORK,& TURKEY,FAT FREE',7905,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Luncheon meat, pork, ham, and chicken, minced, canned, reduced sodium, added ascorbic acid, includes SPAM, 25% less sodium','LUNCHEON MEAT,PORK,HAM,&CHICK,MINCD,CND,RED NA,VIT C, (SPAM)',7906,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Luncheon meat, pork with ham, minced, canned, includes Spam (Hormel)','LUNCHEON MEAT,PORK W/ HAM,MINCED,CND,INCL SPAM (HORMEL)',7908,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Luncheon meat, pork and chicken, minced, canned, includes Spam Lite','LUNCHEON MEAT,PORK & CHICK,MINCED,CND,INCL SPAM LITE',7909,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bratwurst, veal, cooked','BRATWURST  VEAL  CKD',7910,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Liverwurst spread','LIVERWURST SPRD',7911,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Roast beef spread','ROAST BF SPRD',7912,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Salami, pork, beef, less sodium','SALAMI  PORK  BF  LESS NA',7913,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, Italian, sweet, links','SAUSAGE  ITALIAN  SWT  LINKS',7914,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, Polish, beef with chicken, hot','SAUSAGE  POLISH  BF W/ CHICK  HOT',7915,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, Polish, pork and beef, smoked','SAUSAGE  POLISH  PORK & BF  SMOKED',7916,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, pork and beef, with cheddar cheese, smoked','SAUSAGE  PORK & BF  W/ CHEDDAR CHS  SMOKED',7917,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, summer, pork and beef, sticks, with cheddar cheese','SAUSAGE  SMMR  PORK & BF  STKS  W/ CHEDDAR CHS',7918,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, turkey, breakfast links, mild, raw','SAUSAGE,TURKEY,BRKFST LINKS,MILD,RAW',7919,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bacon and beef sticks','BACON & BF STKS',7921,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bratwurst, beef and pork, smoked','BRATWURST  BF & PORK  SMOKED',7922,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pastrami, beef, 98% fat-free','PASTRAMI  BF  98% FAT-FREE',7925,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Salami, Italian, pork','SALAMI  ITALIAN  PORK',7926,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, Italian, turkey, smoked','SAUSAGE  ITALIAN  TURKEY  SMOKED',7927,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, chicken, beef, pork, skinless, smoked','SAUSAGE  CHICK  BF  PORK  SKINLESS  SMOKED',7928,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, turkey, hot, smoked','SAUSAGE  TURKEY  HOT  SMOKED',7929,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Yachtwurst, with pistachio nuts, cooked','YACHTWURST,W/ PISTACHIO NUTS,CKD',7930,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Beerwurst, pork and beef','BEERWURST  PORK & BF',7931,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Chicken breast, fat-free, mesquite flavor, sliced','CHICKEN BREAST  FAT-FREE  MESQ FLAVOR  SLICED',7932,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Chicken breast, oven-roasted, fat-free, sliced','CHICKEN BREAST  OVEN-ROASTED  FAT-FREE  SLICED',7933,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Kielbasa, Polish, turkey and beef, smoked','KIELBASA,POLISH,TURKEY & BF,SMOKED',7934,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Chicken breast, roll, oven-roasted','CHICKEN BREAST,ROLL,OVEN-ROASTED',7935,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bologna, pork and turkey, lite','BOLOGNA  PORK & TURKEY  LITE',7936,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bologna, pork, turkey and beef','BOLOGNA  PORK  TURKEY & BF',7937,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Ham, honey, smoked, cooked','HAM  HONEY  SMOKED  CKD',7938,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Frankfurter, pork','FRANKFURTER,PORK',7939,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Macaroni and cheese loaf, chicken, pork and beef','MACARONI & CHS LOAF  CHICK  PORK & BF',7940,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Salami, Italian, pork and beef, dry, sliced, 50% less sodium','SALAMI  ITALIAN  PORK & BF  DRY  SLICED  50% LESS NA',7941,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pate, truffle flavor','PATE  TRUFFLE FLAVOR',7942,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Turkey, breast, smoked, lemon pepper flavor, 97% fat-free','TURKEY,BREAST,SMOKED,LEMON PEPPER FLAVOR,97% FAT-FREE',7943,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Turkey, white, rotisserie, deli cut','TURKEY  WHITE  ROTISSERIE  DELI CUT',7944,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Frankfurter, beef, heated','FRANKFURTER  BF  HTD',7945,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Frankfurter, meat, heated','FRANKFURTER  MEAT  HTD',7949,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Frankfurter, meat','FRANKFURTER  MEAT',7950,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Scrapple, pork','SCRAPPLE,PORK',7951,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bologna, chicken, turkey, pork','BOLOGNA,CHICK,TURKEY,PORK',7952,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pork sausage, link/patty, fully cooked, microwaved','PORK SAUSAGE,LINK/PATTY,FULLY CKD,MICROWAVED',7953,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, breakfast sausage, beef, pre-cooked, unprepared','SAUSAGE,BRKFST SAUSAGE,BF,PRE-COOKED,UNPREP',7954,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, turkey, fresh, raw','SAUSAGE,TURKEY,FRSH,RAW',7955,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, beef, fresh, cooked','SAUSAGE,BF,FRSH,CKD',7956,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, pork and turkey, pre-cooked','SAUSAGE,PORK & TURKEY,PRE-COOKED',7957,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, turkey, fresh, cooked','SAUSAGE,TURKEY,FRSH,CKD',7958,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bologna, chicken, pork, beef','BOLOGNA,CHICK,PORK,BF',7959,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bologna, chicken, pork','BOLOGNA,CHICK,PORK',7960,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Chicken breast, deli, rotisserie seasoned, sliced, prepackaged','CHICKEN BREAST,DELI,ROTISSERIE SEASONED,SLICED,PREPACKAGED',7961,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Frankfurter, meat and poultry, unheated','Frankfurter, meat and poultry, unheated',7962,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Frankfurter, meat and poultry, cooked, boiled','Frankfurter, meat and poultry, cooked, boiled',7963,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Frankfurter, meat and poultry, cooked, grilled','Frankfurter, meat and poultry, cooked, grilled',7964,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pork sausage, link/patty, reduced fat, unprepared','PORK SAUSAGE,LINK/PATTY,RED FAT,UNPREP',7965,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pork sausage, link/patty, reduced fat, cooked, pan-fried','PORK SAUSAGE,LINK/PATTY,RED FAT,CKD,PAN-FRIED',7966,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pork sausage, link/patty, fully cooked, unheated','PORK SAUSAGE,LINK/PATTY,FULLY CKD,UNHTD',7967,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Kielbasa, fully cooked, grilled','KIELBASA,FULLY CKD,GRILLED',7968,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Kielbasa, fully cooked, pan-fried','KIELBASA,FULLY CKD,PAN-FRIED',7969,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Kielbasa, fully cooked, unheated','KIELBASA,FULLY CKD,UNHTD',7970,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bologna, meat and poultry','BOLOGNA,MEAT & POULTRY',7971,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Meatballs, frozen, Italian style','MEATBALLS,FRZ,ITALIAN STYLE',7972,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bacon, turkey, microwaved','BACON,TURKEY,MICROWAVED',7973,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bacon, turkey, low sodium','BACON,TURKEY,LO NA',7974,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, chicken or turkey, Italian style,  lower sodium','SAUSAGE,CHICK OR TURKEY,ITALIAN STYLE,LOWER NA',7976,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Ham, smoked, extra lean, low sodium','HAM,SMOKED,EX LN,LO NA',7977,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pork sausage, reduced sodium, cooked','PORK SAUSAGE,RED NA,CKD',7978,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, pork, turkey, and beef, reduced sodium','SAUSAGE,PORK,TURKEY,& BF,RED NA',7979,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals ready-to-eat, granola, homemade','CEREALS RTE,GRANOLA,HOMEMADE',8037,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals ready-to-eat, wheat germ, toasted, plain','CEREALS RTE,WHEAT GERM,TSTD,PLN',8084,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, corn grits, white, regular and quick, enriched, dry','CEREALS,CORN GRITS,WHITE,REG & QUICK,ENR,DRY',8090,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, corn grits, white, regular and quick, enriched, cooked with water, without salt','CEREALS,CORN GRITS,WHITE,REG & QUICK,ENR,CKD W/ H2O,WO/ SALT',8091,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, oats, regular and quick, not fortified, dry','CEREALS,OATS,REG & QUICK,NOT FORT,DRY',8120,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, oats, regular and quick, unenriched, cooked with water (includes boiling and microwaving), without salt','CEREALS,OATS,REG & QUICK,UNENR,CKD W/ H2O,WO/ SALT',8121,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, oats, instant, fortified, plain, dry','CEREALS,OATS,INST,FORT,PLN,DRY',8122,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, oats, instant, fortified, plain, prepared with water (boiling water added or microwaved)','CEREALS,OATS,INST,FORT,PLN,PREP W/ H2O',8123,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, oats, instant, fortified, with cinnamon and spice, dry','CEREALS,OATS,INST,FORT,W/ CINN & SPICE,DRY',8128,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, oats, instant, fortified, with cinnamon and spice, prepared with water','CEREALS,OATS,INST,FORT,W/ CINN & SPICE,PREP W/ H2O',8129,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, oats, instant, fortified, with raisins and spice, prepared with water','CEREALS,OATS,INST,FORT,W/ RAISINS & SPICE,PREP W/ H2O',8133,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, whole wheat hot natural cereal, dry','CEREALS,WHL WHEAT HOT NAT CRL,DRY',8144,NULL,NULL,NULL,NULL,NULL,1,'1995-06-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, whole wheat hot natural cereal, cooked with water, without salt','CEREALS,WHL WHEAT HOT NAT CRL,CKD W/ H2O,WO/ SALT',8145,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals ready-to-eat, rice, puffed, fortified','CEREALS RTE,RICE,PUFFED,FORT',8156,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals ready-to-eat, wheat, puffed, fortified','CEREALS RTE,WHEAT,PUFFED,FORT',8157,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, corn grits, yellow, regular and quick, unenriched, dry','CEREALS,CORN GRITS,YEL,REG & QUICK,UNENR,DRY',8160,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, corn grits, white, regular and quick, enriched, cooked with water, with salt','CEREALS,CORN GRITS,WHITE,REG & QUICK,ENR,CKD W/ H2O,W/ SALT',8161,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, corn grits, yellow, regular and quick, enriched, cooked with water, without salt','CEREALS,CORN GRITS,YEL,REG & QUICK,ENR,CKD W/ H2O,WO/ SALT',8164,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, corn grits, yellow, regular, quick, enriched, cooked with water, with salt','CEREALS,CORN GRITS,YEL,REG,QUICK,ENR,CKD W/ H2O,W/ SALT',8165,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, farina, unenriched, dry','CEREALS,FARINA,UNENR,DRY',8172,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, farina, enriched, cooked with water, with salt','CEREALS,FARINA,ENR,CKD W/ H2O,W/ SALT',8173,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, oats, regular and quick and instant, unenriched, cooked with water (includes boiling and microwaving), with salt','CEREALS,OATS,REG & QUICK & INST,UNENR,CKD W/ H2O,W/ SALT',8180,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, whole wheat hot natural cereal, cooked with water, with salt','CEREALS,WHL WHEAT HOT NAT CRL,CKD W/ H2O,W/ SALT',8183,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals ready-to-eat, chocolate-flavored frosted puffed corn','CEREALS RTE,CHOCOLATE-FLAVORED FRSTD PUFFED CORN',8204,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Milk and cereal bar','MILK & CRL BAR',8510,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Rice and Wheat cereal bar','RICE & WHEAT CRL BAR',8546,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals, oats, instant, fortified, maple and brown sugar, dry','CEREALS,OATS,INST,FORT,MAPLE & BROWN SUGAR,DRY',8680,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Acerola, (west indian cherry), raw','ACEROLA,(WEST INDIAN CHERRY),RAW',9001,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Acerola juice, raw','ACEROLA JUICE,RAW',9002,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apples, raw, with skin (Includes foods for USDA''s Food Distribution Program)','APPLES,RAW,WITH SKIN',9003,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apples, raw, without skin','APPLES,RAW,WITHOUT SKIN',9004,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apples, raw, without skin, cooked, boiled','APPLES,RAW,WO/SKN,CKD,BLD',9005,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apples, raw, without skin, cooked, microwave','APPLES,RAW,WO/ SKN,CKD,MICROWAVE',9006,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apples, canned, sweetened, sliced, drained, heated','APPLES,CND,SWTND,SLICED,DRND,HTD',9008,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apples, dehydrated (low moisture), sulfured, uncooked','APPLES,DEHYD (LO MOIST),SULFURED,UNCKD',9009,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apples, dehydrated (low moisture), sulfured, stewed','APPLES,DEHYD (LO MOIST),SULFURED,STWD',9010,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apples, dried, sulfured, uncooked','APPLES,DRIED,SULFURED,UNCKD',9011,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apples, dried, sulfured, stewed, without added sugar','APPLES,DRIED,SULFURED,STWD,WO/ SUGAR',9012,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apples, dried, sulfured, stewed, with added sugar','APPLES,DRIED,SULFURED,STWD,W/ SUGAR',9013,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apples, frozen, unsweetened, unheated (Includes foods for USDA''s Food Distribution Program)','APPLES,FRZ,UNSWTND,UNHTD',9014,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apples, frozen, unsweetened, heated (Includes foods for USDA''s Food Distribution Program)','APPLES,FRZ,UNSWTND,HTD',9015,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apple juice, canned or bottled, unsweetened, without added ascorbic acid','APPLE JUC,CND OR BTLD,UNSWTND,WO/ ADDED VIT C',9016,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apple juice, frozen concentrate, unsweetened, undiluted, without added ascorbic acid','APPLE JUC,FRZ CONC,UNSWTND,UNDIL,WO/ VIT C',9017,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apple juice, frozen concentrate, unsweetened, diluted with 3 volume water without added ascorbic acid','APPLE JUC,FRZ CONC,UNSWTND,DIL W/3 VOLUME H2O WO/ VIT C',9018,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Applesauce, canned, unsweetened, without added ascorbic acid (Includes foods for USDA''s Food Distribution Program)','APPLESAUCE,CND,UNSWTND,WO/ ADDED VIT C',9019,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Applesauce, canned, sweetened, without salt','APPLESAUCE,CND,SWTND,WO/ SALT',9020,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, raw','APRICOTS,RAW',9021,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2007-03-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, canned, water pack, with skin, solids and liquids','APRICOTS,CND,H2O PK,W/SKN,SOL&LIQUIDS',9022,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, canned, water pack, without skin, solids and liquids','APRICOTS,CND,H2O PK,WO/SKN,SOL&LIQUIDS',9023,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, canned, juice pack, with skin, solids and liquids','APRICOTS,CND,JUC PK,W/SKN,SOL&LIQUIDS',9024,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, canned, extra light syrup pack, with skin, solids and liquids (Includes foods for USDA''s Food Distribution Program)','APRICOTS,CND,EX LT SYRUP PK,W/SKN,SOL&LIQUIDS',9025,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, canned, light syrup pack, with skin, solids and liquids','APRICOTS,CND,LT SYRUP PK,W/SKN,SOL&LIQUIDS',9026,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, canned, heavy syrup pack, with skin, solids and liquids','APRICOTS,CND,HVY SYRUP PK,W/SKN,SOL&LIQUIDS',9027,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, canned, heavy syrup pack, without skin, solids and liquids','APRICOTS,CND,HVY SYRUP PK,WO/SKN,SOL&LIQUIDS',9028,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, canned, extra heavy syrup pack, without skin, solids and liquids','APRICOTS,CND,EX HVY SYRUP PK,WO/SKN,SOL&LIQUIDS',9029,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, dehydrated (low-moisture), sulfured, uncooked','APRICOTS,DEHYD (LOW-MOISTURE),SULFURED,UNCKD',9030,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, dehydrated (low-moisture), sulfured, stewed','APRICOTS,DEHYD (LOW-MOISTURE),SULFURED,STWD',9031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, dried, sulfured, uncooked','APRICOTS,DRIED,SULFURED,UNCKD',9032,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, dried, sulfured, stewed, without added sugar','APRICOTS,DRIED,SULFURED,STWD,WO/ SUGAR',9033,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, dried, sulfured, stewed, with added sugar','APRICOTS,DRIED,SULFURED,STWD,W/ SUGAR',9034,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, frozen, sweetened','APRICOTS,FROZEN,SWEETENED',9035,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricot nectar, canned, with added ascorbic acid','APRICOT NECTAR,CND,W/ ADDED VIT C',9036,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Avocados, raw, all commercial varieties','AVOCADOS,RAW,ALL COMM VAR',9037,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Avocados, raw, California','AVOCADOS,RAW,CALIFORNIA',9038,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Avocados, raw, Florida','AVOCADOS,RAW,FLORIDA',9039,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Bananas, raw','BANANAS,RAW',9040,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Bananas, dehydrated, or banana powder','BANANAS,DEHYD,OR BANANA PDR',9041,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Blackberries, raw','BLACKBERRIES,RAW',9042,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Blackberry juice, canned','BLACKBERRY JUC,CND',9043,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cherries, tart, dried, sweetened (Includes foods for USDA''s Food Distribution Program)','CHERRIES,TART,DRIED,SWTND',9044,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Blackberries, canned, heavy syrup, solids and liquids','BLACKBERRIES,CND,HVY SYRUP,SOL&LIQUIDS',9046,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Blackberries, frozen, unsweetened','BLACKBERRIES,FRZ,UNSWTND',9048,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Blueberries, raw','BLUEBERRIES,RAW',9050,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Blueberries, canned, heavy syrup, solids and liquids','BLUEBERRIES,CND,HVY SYRUP,SOL&LIQUIDS',9052,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Blueberries, wild, frozen (Includes foods for USDA''s Food Distribution Program)','BLUEBERRIES,WILD,FRZ',9053,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Blueberries, frozen, unsweetened (Includes foods for USDA''s Food Distribution Program)','BLUEBERRIES,FRZ,UNSWTND',9054,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Blueberries, frozen, sweetened','BLUEBERRIES,FRZ,SWTND',9055,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Boysenberries, canned, heavy syrup','BOYSENBERRIES,CND,HVY SYRUP',9056,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Boysenberries, frozen, unsweetened','BOYSENBERRIES,FRZ,UNSWTND',9057,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Breadfruit, raw','BREADFRUIT,RAW',9059,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Carambola, (starfruit), raw','CARAMBOLA,(STARFRUIT),RAW',9060,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cherimoya, raw','CHERIMOYA,RAW',9062,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cherries, sour, red, raw','CHERRIES,SOUR,RED,RAW',9063,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cherries, sour, red, canned, water pack, solids and liquids','CHERRIES,SOUR,RED,CND,H2O PK,SOL&LIQUIDS',9064,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cherries, sour, red, canned, light syrup pack, solids and liquids','CHERRIES,SOUR,RED,CND,LT SYRUP PK,SOL&LIQUIDS',9065,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cherries, sour, red, canned, heavy syrup pack, solids and liquids','CHERRIES,SOUR,RED,CND,HVY SYRUP PK,SOL&LIQUIDS',9066,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cherries, sour, red, canned, extra heavy syrup pack, solids and liquids','CHERRIES,SOUR,RED,CND,EX HVY SYRUP PK,SOL&LIQUIDS',9067,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cherries, sour, red, frozen, unsweetened (Includes foods for USDA''s Food Distribution Program)','CHERRIES,SOUR,RED,FRZ,UNSWTND',9068,NULL,NULL,NULL,NULL,NULL,1,'1994-05-17','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cherries, sweet, raw','CHERRIES,SWEET,RAW',9070,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cherries, sweet, canned, water pack, solids and liquids','CHERRIES,SWT,CND,H2O PK,SOL&LIQUIDS',9071,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cherries, sweet, canned, juice pack, solids and liquids','CHERRIES,SWT,CND,JUC PK,SOL&LIQUIDS',9072,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cherries, sweet, canned, light syrup pack, solids and liquids','CHERRIES,SWT,CND,LT SYRUP PK,SOL&LIQUIDS',9073,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cherries, sweet, canned, pitted, heavy syrup pack, solids and liquids','CHERRIES,SWT,CND,PITTED,HVY SYRUP PK,SOL & LIQUIDS',9074,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cherries, sweet, canned, extra heavy syrup pack, solids and liquids','CHERRIES,SWT,CND,EX HVY SYRUP PK,SOL&LIQUIDS',9075,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Crabapples, raw','CRABAPPLES,RAW',9077,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cranberries, raw','CRANBERRIES,RAW',9078,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cranberries, dried, sweetened (Includes foods for USDA''s Food Distribution Program)','CRANBERRIES,DRIED,SWTND',9079,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cranberry sauce, canned, sweetened','CRANBERRY SAU,CND,SWTND',9081,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cranberry-orange relish, canned','CRANBERRY-ORANGE RELISH,CND',9082,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Currants, european black, raw','CURRANTS,EUROPEAN BLACK,RAW',9083,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Currants, red and white, raw','CURRANTS,RED&WHITE,RAW',9084,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Currants, zante, dried','CURRANTS,ZANTE,DRIED',9085,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Custard-apple, (bullock''s-heart), raw','CUSTARD-APPLE,(BULLOCK''S-HEART),RAW',9086,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Dates, deglet noor','DATES,DEGLET NOOR',9087,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Elderberries, raw','ELDERBERRIES,RAW',9088,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Figs, raw','FIGS,RAW',9089,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Figs, canned, water pack, solids and liquids','FIGS,CND,H2O PK,SOL&LIQUIDS',9090,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Figs, canned, light syrup pack, solids and liquids','FIGS,CND,LT SYRUP PK,SOL&LIQUIDS',9091,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Figs, canned, heavy syrup pack, solids and liquids','FIGS,CND,HVY SYRUP PK,SOL&LIQUIDS',9092,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Figs, canned, extra heavy syrup pack, solids and liquids','FIGS,CND,EX HVY SYRUP PK,SOL&LIQUIDS',9093,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Figs, dried, uncooked','FIGS,DRIED,UNCOOKED',9094,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Figs, dried, stewed','FIGS,DRIED,STEWED',9095,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Fruit cocktail, (peach and pineapple and pear and grape and cherry), canned, water pack, solids and liquids','FRUIT COCKTAIL,CND,H2O PK,SOL&LIQUIDS',9096,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Fruit cocktail, (peach and pineapple and pear and grape and cherry), canned, juice pack, solids and liquids','FRUIT COCKTAIL,CND,JUC PK,SOL&LIQUIDS',9097,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Fruit cocktail, (peach and pineapple and pear and grape and cherry), canned, extra light syrup, solids and liquids','FRUIT COCKTAIL,CND,EX LT SYRUP,SOL&LIQUIDS',9098,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Fruit cocktail, (peach and pineapple and pear and grape and cherry), canned, light syrup, solids and liquids','FRUIT COCKTAIL,CND,LT SYRUP,SOL&LIQUIDS',9099,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Fruit cocktail, (peach and pineapple and pear and grape and cherry), canned, heavy syrup, solids and liquids','FRUIT COCKTAIL,CND,HVY SYRUP,SOL&LIQUIDS',9100,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Fruit cocktail, (peach and pineapple and pear and grape and cherry), canned, extra heavy syrup, solids and liquids','FRUIT COCKTAIL,CND,EX HVY SYRUP,SOL&LIQUIDS',9101,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Fruit salad, (peach and pear and apricot and pineapple and cherry), canned, water pack, solids and liquids','FRUIT SALAD,CND,H2O PK,SOL&LIQUIDS',9102,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Fruit salad, (peach and pear and apricot and pineapple and cherry), canned, juice pack, solids and liquids','FRUIT SALAD,CND,JUC PK,SOL&LIQUIDS',9103,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Fruit salad, (peach and pear and apricot and pineapple and cherry), canned, light syrup, solids and liquids','FRUIT SALAD,CND,LT SYRUP,SOL&LIQUIDS',9104,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Fruit salad, (peach and pear and apricot and pineapple and cherry), canned, extra heavy syrup, solids and liquids','FRUIT SALAD,CND,EX HVY SYRUP,SOL&LIQUIDS',9106,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Gooseberries, raw','GOOSEBERRIES,RAW',9107,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Gooseberries, canned, light syrup pack, solids and liquids','GOOSEBERRIES,CND,LT SYRUP PK,SOL&LIQUIDS',9109,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Goji berries, dried','GOJI BERRIES,DRIED',9110,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit, raw, pink and red and white, all areas','GRAPEFRUIT,RAW,PINK&RED&WHITE,ALL AREAS',9111,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit, raw, pink and red, all areas','GRAPEFRUIT,RAW,PINK&RED,ALL AREAS',9112,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit, raw, pink and red, California and Arizona','GRAPEFRUIT,RAW,PINK&RED,CALIFORNIA&ARIZONA',9113,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit, raw, pink and red, Florida','GRAPEFRUIT,RAW,PINK & RED,FLORIDA',9114,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit, raw, white, all areas','GRAPEFRUIT,RAW,WHITE,ALL AREAS',9116,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit, raw, white, California','GRAPEFRUIT,RAW,WHITE,CALIFORNIA',9117,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit, raw, white, Florida','GRAPEFRUIT,RAW,WHITE,FLORIDA',9118,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit, sections, canned, water pack, solids and liquids','GRAPEFRUIT,SECTIONS,CND,H2O PK,SOL&LIQUIDS',9119,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit, sections, canned, juice pack, solids and liquids','GRAPEFRUIT,SECTIONS,CND,JUC PK,SOL&LIQUIDS',9120,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit, sections, canned, light syrup pack, solids and liquids','GRAPEFRUIT,SECTIONS,CND,LT SYRUP PK,SOL&LIQUIDS',9121,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit juice, white, canned or bottled, unsweetened','GRAPEFRUIT JUC,WHITE,CND OR BTLD,UNSWTND',9123,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit juice, white, canned, sweetened','GRAPEFRUIT JUC,WHITE,CND,SWTND',9124,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit juice, white, frozen concentrate, unsweetened, undiluted','GRAPEFRUIT JUC,WHITE,FRZ CONC,UNSWTND,UNDIL',9125,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit juice, white, frozen concentrate, unsweetened, diluted with 3 volume water','GRAPEFRUIT JUC,WHITE,FRZ CONC,UNSWTND,DIL W/ 3 VOLUME H2O',9126,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit juice, pink or red, with added calcium','GRAPEFRUIT JUC,PINK OR RED,W/ ADDED CA',9127,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit juice, white, raw','GRAPEFRUIT JUC,WHITE,RAW',9128,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grape juice, canned or bottled, unsweetened, with added ascorbic acid','GRAPE JUC,CND OR BTLD,UNSWTND,W/ ADDED VIT C',9130,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2009-01-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapes, american type (slip skin), raw','GRAPES,AMERICAN TYPE (SLIP SKN),RAW',9131,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapes, red or green (European type, such as Thompson seedless), raw','GRAPES,RED OR GRN (EURO TYPE,SUCH AS THOMPSON SEEDLESS),RAW',9132,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapes, canned, thompson seedless, water pack, solids and liquids','GRAPES,CND,THOMPSON SEEDLESS,H2O PK,SOL&LIQUIDS',9133,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapes, canned, thompson seedless, heavy syrup pack, solids and liquids','GRAPES,CND,THOMPSON SEEDLESS,HVY SYRUP PK,SOL&LIQUIDS',9134,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grape juice, canned or bottled, unsweetened, without added ascorbic acid','GRAPE JUC,CND OR BTLD,UNSWTND,WO/ ADDED VIT C',9135,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Guavas, common, raw','GUAVAS,COMMON,RAW',9139,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Guavas, strawberry, raw','GUAVAS,STRAWBERRY,RAW',9140,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Guava sauce, cooked','GUAVA SAUCE,COOKED',9143,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Jackfruit, raw','JACKFRUIT,RAW',9144,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Kiwifruit, green, raw','KIWIFRUIT,GRN,RAW',9148,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Kumquats, raw','KUMQUATS,RAW',9149,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Lemons, raw, without peel','LEMONS,RAW,WITHOUT PEEL',9150,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2007-03-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Lemon juice, raw','LEMON JUICE,RAW',9152,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Lemon juice from concentrate, canned or bottled','LEMON JUC FROM CONC,CND OR BTLD',9153,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Lemon peel, raw','LEMON PEEL,RAW',9156,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Limes, raw','LIMES,RAW',9159,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Lime juice, raw','LIME JUICE,RAW',9160,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Lime juice, canned or bottled, unsweetened','LIME JUC,CND OR BTLD,UNSWTND',9161,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Blueberries, dried, sweetened','BLUEBERRIES,DRIED,SWTND',9163,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Litchis, raw','LITCHIS,RAW',9164,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Litchis, dried','LITCHIS,DRIED',9165,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Loganberries, frozen','LOGANBERRIES,FROZEN',9167,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Loquats, raw','LOQUATS,RAW',9174,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Mammy-apple, (mamey), raw','MAMMY-APPLE,(MAMEY),RAW',9175,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Mangos, raw','MANGOS,RAW',9176,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Mango, dried, sweetened','MANGO,DRIED,SWTND',9178,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Melons, cantaloupe, raw','MELONS,CANTALOUPE,RAW',9181,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2007-03-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Melons, casaba, raw','MELONS,CASABA,RAW',9183,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Melons, honeydew, raw','MELONS,HONEYDEW,RAW',9184,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Melon balls, frozen','MELON BALLS,FROZEN',9185,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Mulberries, raw','MULBERRIES,RAW',9190,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Nectarines, raw','NECTARINES,RAW',9191,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Olives, ripe, canned (small-extra large)','OLIVES,RIPE,CND (SMALL-EXTRA LRG)',9193,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Olives, ripe, canned (jumbo-super colossal)','OLIVES,RIPE,CND (JUMBO-SUPER COLOSSAL)',9194,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Olives, pickled, canned or bottled, green','OLIVES,PICKLED,CND OR BTLD,GRN',9195,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Oranges, raw, all commercial varieties','ORANGES,RAW,ALL COMM VAR',9200,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Oranges, raw, California, valencias','ORANGES,RAW,CALIFORNIA,VALENCIAS',9201,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Oranges, raw, navels (Includes foods for USDA''s Food Distribution Program)','ORANGES,RAW,NAVELS',9202,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Oranges, raw, Florida','ORANGES,RAW,FLORIDA',9203,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Oranges, raw, with peel','ORANGES,RAW,WITH PEEL',9205,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Orange juice, raw (Includes foods for USDA''s Food Distribution Program)','ORANGE JUICE,RAW',9206,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Orange juice, canned, unsweetened','ORANGE JUC,CND,UNSWTND',9207,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Orange juice, chilled, includes from concentrate','ORANGE JUC,CHILLED,INCL FROM CONC',9209,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Orange juice, chilled, includes from concentrate, with added calcium and vitamin D','ORANGE JUC,CHILLED,INCL FROM CONC,W/ ADDED CA & VITAMIN D',9210,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Orange juice, chilled, includes from concentrate, with added calcium','ORANGE JUC,CHILLED,INCL FROM CONC,W/ ADDED CA',9211,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Orange juice, frozen concentrate, unsweetened, diluted with 3 volume water, with added calcium','ORANGE JUC,FRZ CONC,UNSWTND,DIL W/ 3 VOLUME H2O,W/ ADDED CA',9212,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Orange juice, frozen concentrate, unsweetened, undiluted, with added calcium','ORANGE JUC,FRZ CONC,UNSWTND,UNDIL,W/ ADDED CA',9213,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Orange juice, frozen concentrate, unsweetened, undiluted','ORANGE JUC,FRZ CONC,UNSWTND,UNDIL',9214,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Orange juice, frozen concentrate, unsweetened, diluted with 3 volume water','ORANGE JUC,FRZ CONC,UNSWTND,DIL W/3 VOLUME H2O',9215,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Orange peel, raw','ORANGE PEEL,RAW',9216,NULL,NULL,NULL,NULL,NULL,1,'1995-06-27','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Orange-grapefruit juice, canned or bottled, unsweetened','ORANGE-GRAPEFRUIT JUC,CND OR BTLD,UNSWTND',9217,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Tangerines, (mandarin oranges), raw','TANGERINES,(MANDARIN ORANGES),RAW',9218,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Tangerines, (mandarin oranges), canned, juice pack','TANGERINES,(MANDARIN ORANGES),CND,JUC PK',9219,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Tangerines, (mandarin oranges), canned, light syrup pack','TANGERINES,(MANDARIN ORANGES),CND,LT SYRUP PK',9220,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Tangerine juice, raw','TANGERINE JUICE,RAW',9221,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Papayas, raw','PAPAYAS,RAW',9226,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Papaya, canned, heavy syrup, drained','PAPAYA,CND,HVY SYRUP,DRND',9228,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Papaya nectar, canned','PAPAYA NECTAR,CANNED',9229,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Passion-fruit, (granadilla), purple, raw','PASSION-FRUIT,(GRANADILLA),PURPLE,RAW',9231,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Passion-fruit juice, purple, raw','PASSION-FRUIT JUC,PURPLE,RAW',9232,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Passion-fruit juice, yellow, raw','PASSION-FRUIT JUC,YEL,RAW',9233,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peaches, yellow, raw','PEACHES,YEL,RAW',9236,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peaches, canned, water pack, solids and liquids','PEACHES,CND,H2O PK,SOL&LIQUIDS',9237,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peaches, canned, juice pack, solids and liquids','PEACHES,CND,JUC PK,SOL&LIQUIDS',9238,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peaches, canned, extra light syrup, solids and liquids (Includes foods for USDA''s Food Distribution Program)','PEACHES,CND,EX LT SYRUP,SOL&LIQUIDS',9239,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peaches, canned, light syrup pack, solids and liquids','PEACHES,CND,LT SYRUP PK,SOL&LIQUIDS',9240,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peaches, canned, heavy syrup pack, solids and liquids','PEACHES,CND,HVY SYRUP PK,SOL&LIQUIDS',9241,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peaches, canned, extra heavy syrup pack, solids and liquids','PEACHES,CND,EX HVY SYRUP PK,SOL&LIQUIDS',9242,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peaches, spiced, canned, heavy syrup pack, solids and liquids','PEACHES,SPICED,CND,HVY SYRUP PK,SOL&LIQUIDS',9243,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peaches, dehydrated (low-moisture), sulfured, uncooked','PEACHES,DEHYD (LOW-MOISTURE),SULFURED,UNCKD',9244,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peaches, dehydrated (low-moisture), sulfured, stewed','PEACHES,DEHYD (LOW-MOISTURE),SULFURED,STWD',9245,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peaches, dried, sulfured, uncooked','PEACHES,DRIED,SULFURED,UNCKD',9246,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peaches, dried, sulfured, stewed, without added sugar','PEACHES,DRIED,SULFURED,STWD,WO/ SUGAR',9247,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peaches, dried, sulfured, stewed, with added sugar','PEACHES,DRIED,SULFURED,STWD,W/ SUGAR',9248,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peaches, frozen, sliced, sweetened','PEACHES,FRZ,SLICED,SWTND',9250,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peach nectar, canned, with sucralose, without added ascorbic acid','PEACH NECTAR,CND,W/ SUCRALOSE,WO/ ADDED VIT C',9251,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pears, raw','PEARS,RAW',9252,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pears, canned, water pack, solids and liquids','PEARS,CND,H2O PK,SOL&LIQUIDS',9253,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pears, canned, juice pack, solids and liquids','PEARS,CND,JUC PK,SOL&LIQUIDS',9254,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pears, canned, extra light syrup pack, solids and liquids (Includes foods for USDA''s Food Distribution Program)','PEARS,CND,EX LT SYRUP PK,SOL&LIQUIDS',9255,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pears, canned, light syrup pack, solids and liquids','PEARS,CND,LT SYRUP PK,SOL&LIQUIDS',9256,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pears, canned, heavy syrup pack, solids and liquids','PEARS,CND,HVY SYRUP PK,SOL&LIQUIDS',9257,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pears, canned, extra heavy syrup pack, solids and liquids','PEARS,CND,EX HVY SYRUP PK,SOL&LIQUIDS',9258,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pears, dried, sulfured, uncooked','PEARS,DRIED,SULFURED,UNCKD',9259,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pears, dried, sulfured, stewed, without added sugar','PEARS,DRIED,SULFURED,STWD,WO/ SUGAR',9260,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pears, dried, sulfured, stewed, with added sugar','PEARS,DRIED,SULFURED,STWD,W/ SUGAR',9261,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pear nectar, canned, without added ascorbic acid','PEAR NECTAR,CND,WO/ VIT C',9262,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Persimmons, japanese, raw','PERSIMMONS,JAPANESE,RAW',9263,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pineapple, raw, all varieties','PINEAPPLE,RAW,ALL VAR',9266,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pineapple, canned, water pack, solids and liquids','PINEAPPLE,CND,H2O PK,SOL&LIQUIDS',9267,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pineapple, canned, juice pack, solids and liquids','PINEAPPLE,CND,JUC PK,SOL&LIQUIDS',9268,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pineapple, canned, light syrup pack, solids and liquids','PINEAPPLE,CND,LT SYRUP PK,SOL&LIQUIDS',9269,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pineapple, canned, heavy syrup pack, solids and liquids','PINEAPPLE,CND,HVY SYRUP PK,SOL&LIQUIDS',9270,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pineapple, canned, extra heavy syrup pack, solids and liquids','PINEAPPLE,CND,EX HVY SYRUP PK,SOL&LIQUIDS',9271,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pineapple, frozen, chunks, sweetened','PINEAPPLE,FRZ,CHUNKS,SWTND',9272,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pineapple juice, canned or bottled, unsweetened, without added ascorbic acid','PINEAPPLE JUC,CND OR BTLD,UNSWTND,WO/ ADDED VIT C',9273,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pineapple juice, frozen concentrate, unsweetened, undiluted','PINEAPPLE JUC,FRZ CONC,UNSWTND,UNDIL',9274,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pineapple juice, frozen concentrate, unsweetened, diluted with 3 volume water','PINEAPPLE JUC,FRZ CONC,UNSWTND,DIL W/3 VOLUME H2O',9275,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plantains, yellow, raw','PLANTAINS,YEL,RAW',9277,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plantains, yellow, baked','PLANTAINS,YEL,BKD',9278,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plums, raw','PLUMS,RAW',9279,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plums, canned, purple, water pack, solids and liquids','PLUMS,CND,PURPLE,H2O PK,SOL&LIQUIDS',9281,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plums, canned, purple, juice pack, solids and liquids','PLUMS,CND,PURPLE,JUC PK,SOL&LIQUIDS',9282,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plums, canned, purple, light syrup pack, solids and liquids','PLUMS,CND,PURPLE,LT SYRUP PK,SOL&LIQUIDS',9283,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plums, canned, purple, heavy syrup pack, solids and liquids','PLUMS,CND,PURPLE,HVY SYRUP PK,SOL&LIQUIDS',9284,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plums, canned, purple, extra heavy syrup pack, solids and liquids','PLUMS,CND,PURPLE,EX HVY SYRUP PK,SOL&LIQUIDS',9285,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pomegranates, raw','POMEGRANATES,RAW',9286,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2013-06-15',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Prickly pears, raw','PRICKLY PEARS,RAW',9287,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Prunes, canned, heavy syrup pack, solids and liquids','PRUNES,CND,HVY SYRUP PK,SOL&LIQUIDS',9288,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Prunes, dehydrated (low-moisture), uncooked','PRUNES,DEHYD (LOW-MOISTURE),UNCKD',9289,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Prunes, dehydrated (low-moisture), stewed','PRUNES,DEHYD (LOW-MOISTURE),STWD',9290,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plums, dried (prunes), uncooked','PLUMS,DRIED (PRUNES),UNCKD',9291,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plums, dried (prunes), stewed, without added sugar','PLUMS,DRIED (PRUNES),STWD,WO/ ADDED SUGAR',9292,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plums, dried (prunes), stewed, with added sugar','PLUMS,DRIED (PRUNES),STWD,W/ ADDED SUGAR',9293,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Prune juice, canned','PRUNE JUICE,CANNED',9294,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Quinces, raw','QUINCES,RAW',9296,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Raisins, golden, seedless','RAISINS,GOLDEN,SEEDLESS',9297,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Raisins, dark, seedless (Includes foods for USDA''s Food Distribution Program)','RAISINS,DK,SEEDLESS (INCLUDES FOODS FOR USDA''S FD',9298,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Raisins, seeded','RAISINS,SEEDED',9299,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Raspberries, raw','RASPBERRIES,RAW',9302,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Raspberries, canned, red, heavy syrup pack, solids and liquids','RASPBERRIES,CND,RED,HVY SYRUP PK,SOL&LIQUIDS',9304,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Raspberries, frozen, red, sweetened','RASPBERRIES,FRZ,RED,SWTND',9306,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Rhubarb, raw','RHUBARB,RAW',9307,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Rhubarb, frozen, uncooked','RHUBARB,FROZEN,UNCOOKED',9309,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Rhubarb, frozen, cooked, with sugar','RHUBARB,FRZ,CKD,W/SUGAR',9310,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Sapodilla, raw','SAPODILLA,RAW',9313,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Sapote, mamey, raw','SAPOTE,MAMEY,RAW',9314,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Soursop, raw','SOURSOP,RAW',9315,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Strawberries, raw','STRAWBERRIES,RAW',9316,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Strawberries, canned, heavy syrup pack, solids and liquids','STRAWBERRIES,CND,HVY SYRUP PK,SOL&LIQUIDS',9317,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Strawberries, frozen, unsweetened (Includes foods for USDA''s Food Distribution Program)','STRAWBERRIES,FRZ,UNSWTND',9318,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Strawberries, frozen, sweetened, sliced','STRAWBERRIES,FRZ,SWTND,SLICED',9320,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Sugar-apples, (sweetsop), raw','SUGAR-APPLES,(SWEETSOP),RAW',9321,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Tamarinds, raw','TAMARINDS,RAW',9322,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Fruit salad, (pineapple and papaya and banana and guava), tropical, canned, heavy syrup, solids and liquids','FRUIT SALAD,TROPICAL,CND,HVY SYRUP,SOL&LIQUIDS',9325,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Watermelon, raw','WATERMELON,RAW',9326,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Maraschino cherries, canned, drained','MARASCHINO CHERRIES,CND,DRND',9328,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Feijoa, raw','FEIJOA,RAW',9334,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pears, asian, raw','PEARS,ASIAN,RAW',9340,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Fruit cocktail, canned, heavy syrup, drained','FRUIT COCKTAIL,CND,HVY SYRUP,DRND',9351,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Blueberries, canned, light syrup, drained','BLUEBERRIES,CND,LT SYRUP,DRND',9352,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pineapple, canned, juice pack, drained','PINEAPPLE,CND,JUC PK,DRND',9354,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apricots, canned, heavy syrup, drained','APRICOTS,CND,HVY SYRUP,DRND',9357,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cherries, sweet, canned, pitted, heavy syrup, drained','CHERRIES,SWT,CND,PITTED,HVY SYRUP,DRND',9367,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peaches, canned, heavy syrup, drained','PEACHES,CND,HVY SYRUP,DRND',9370,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pears, canned, heavy syrup, drained','PEARS,CND,HVY SYRUP,DRND',9374,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plums, canned, heavy syrup, drained','PLUMS,CND,HVY SYRUP,DRND',9379,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Tangerines, (mandarin oranges), canned, juice pack, drained','TANGERINES,(MANDARIN ORANGES),CND,JUC PK,DRND',9383,NULL,NULL,NULL,NULL,NULL,1,'1995-06-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apple juice, canned or bottled, unsweetened, with added ascorbic acid','APPLE JUC,CND OR BTLD,UNSWTND,W/ ADDED VIT C',9400,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Applesauce, canned, unsweetened, with added ascorbic acid','APPLESAUCE,CND,UNSWTND,W/ VIT C',9401,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Applesauce, canned, sweetened, with salt','APPLESAUCE,CND,SWTND,W/SALT',9402,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grapefruit juice, pink, raw','GRAPEFRUIT JUICE,PINK,RAW',9404,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Peach nectar, canned, with added ascorbic acid','PEACH NECTAR,CND,W/ VIT C',9407,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pear nectar, canned, with added ascorbic acid','PEAR NECTAR,CND,W/ VIT C',9408,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pineapple juice, canned or bottled, unsweetened, with added ascorbic acid','PINEAPPLE JUC,CND OR BTLD,UNSWTND,W/ ADDED VIT C',9409,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apple juice, frozen concentrate, unsweetened, undiluted, with added ascorbic acid','APPLE JUC,FRZ CONC,UNSWTND,UNDIL,W/ VIT C',9410,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apple juice, frozen concentrate, unsweetened, diluted with 3 volume water, with added ascorbic acid','APPLE JUC,FRZ CONC,UNSWTND,DIL W/3 VOLUME H2O,W/ VIT C',9411,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Prune puree','PRUNE PUREE',9423,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Candied fruit','CANDIED FRUIT',9426,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Abiyuch, raw','ABIYUCH,RAW',9427,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Rowal, raw','ROWAL,RAW',9428,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Guanabana nectar, canned','GUANABANA NECTAR,CND',9434,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Guava nectar, canned, with added ascorbic acid','GUAVA NECTAR,CND,W/ ADDED VIT C',9435,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Mango nectar, canned','MANGO NECTAR,CND',9436,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Pomegranate juice, bottled','POMEGRANATE JUC,BTLD',9442,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2009-01-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Juice, apple and grape blend, with added ascorbic acid','JUICE,APPL & GRAPE BLEND,W/ ADDED VIT C',9443,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Juice, apple, grape and pear blend, with added ascorbic acid and calcium','JUICE,APPL,GRAPE & PEAR BLEND,W/ ADDED VIT C & CA',9444,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plantains, green, fried','PLANTAINS,GRN,FRIED',9446,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plantains, yellow, fried, Latino restaurant','PLANTAINS,YEL,FRIED,LATINO RESTAURANT',9447,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Orange Pineapple Juice Blend','ORANGE PNAPPL JUC BLEND',9452,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Orange juice, chilled, includes from concentrate, with added calcium and vitamins A, D, E','ORANGE JUC,CHILLED,INCL FROM CONC,W/ ADD CA & VITAMINS A,D,E',9506,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Grape juice, canned or bottled, unsweetened, with added ascorbic acid and calcium','GRAPE JUC,CND OR BTLD,UNSWTND,W/ ADDED VIT C & CA',9512,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Apple juice, canned or bottled, unsweetened, with added ascorbic acid, calcium, and potassium','APPLE JUC,CND OR BTLD,UNSWTND,W/ ADDED VIT C,CA,& K',9517,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Raspberries, frozen, red, unsweetened','RASPBERRIES,FRZ,RED,UNSWTND',9518,NULL,NULL,NULL,NULL,NULL,1,'2019-02-13','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Guava nectar, with sucralose, canned','GUAVA NECTAR,W/ SUCRALOSE,CND',9519,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cranberry juice blend, 100% juice, bottled, with added vitamin C and calcium','CRANBERRY JUC BLEND,100% JUC,BTLD,W/ ADDED VIT C & CA',9522,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plantains, green, raw','PLANTAINS,GRN,RAW',9542,NULL,NULL,NULL,NULL,NULL,1,'2019-02-13','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Plantains, green, boiled','PLANTAINS,GRN,BLD',9543,NULL,NULL,NULL,NULL,NULL,1,'2019-02-13','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Baobab powder','BAOBAB PDR',9544,NULL,NULL,NULL,NULL,NULL,1,'2019-02-13','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Raspberries, puree, seedless','RASPBERRIES,PUREE,SEEDLESS',9552,NULL,NULL,NULL,NULL,NULL,1,'2019-02-13','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Raspberries, puree, with seeds','RASPBERRIES,PUREE,W/ SEEDS',9553,NULL,NULL,NULL,NULL,NULL,1,'2019-02-13','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Raspberry juice concentrate','RASPBERRY JUC CONC',9554,NULL,NULL,NULL,NULL,NULL,1,'2019-02-13','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, composite of separable fat, with added solution, cooked','PORK,FRSH,COMP OF FAT,W/ ADDED SOLN,CKD',10000,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, carcass, separable lean and fat, raw','PORK,FRSH,CARCASS,LN&FAT,RAW',10001,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, composite of trimmed retail cuts (leg, loin, shoulder), separable lean only, raw','PORK,FRSH,COMP OF RTL CUTS (LEG,LOIN,SHLDR),LN,RAW',10002,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, composite of trimmed leg, loin, shoulder, and spareribs, (includes cuts to be cured), separable lean and fat, raw','PORK,FRSH,COMP OF LEG,LOIN,SHLDR,& SPARERIBS,LN & FAT,RAW',10003,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, backfat, raw','PORK,FRESH,BACKFAT,RAW',10004,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, belly, raw','PORK,FRSH,BELLY,RAW',10005,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, separable fat, raw','PORK,FRSH,FAT,RAW',10006,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, separable fat, cooked','PORK,FRSH,FAT,CKD',10007,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, leg (ham), whole, separable lean and fat, raw','PORK,FRSH,LEG (HAM),WHL,LN&FAT,RAW',10008,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, leg (ham), whole, separable lean and fat, cooked, roasted','PORK,FRSH,LEG (HAM),WHL,LN&FAT,CKD,RSTD',10009,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, leg (ham), whole, separable lean only, raw','PORK,FRSH,LEG (HAM),WHL,LN,RAW',10010,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, leg (ham), whole, separable lean only, cooked, roasted','PORK,FRSH,LEG (HAM),WHL,LN,CKD,RSTD',10011,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, leg (ham), rump half, separable lean and fat, raw','PORK,FRSH,LEG (HAM),RUMP HALF,LN&FAT,RAW',10012,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, leg (ham), rump half, separable lean and fat, cooked, roasted','PORK,FRSH,LEG (HAM),RUMP HALF,LN&FAT,CKD,RSTD',10013,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, leg (ham), rump half, separable lean only, raw (Includes foods for USDA''s Food Distribution Program)','PORK,FRSH,LEG (HAM),RUMP HALF,LN,RAW',10014,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, leg (ham), rump half, separable lean only, cooked, roasted','PORK,FRSH,LEG (HAM),RUMP HALF,LN,CKD,RSTD',10015,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, leg (ham), shank half, separable lean and fat, raw','PORK,FRSH,LEG (HAM),SHANK HALF,LN&FAT,RAW',10016,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, leg (ham), shank half, separable lean and fat, cooked, roasted','PORK,FRSH,LEG (HAM),SHANK HALF,LN&FAT,CKD,RSTD',10017,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, leg (ham), shank half, separable lean only, raw','PORK,FRSH,LEG (HAM),SHANK HALF,LN,RAW',10018,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, leg (ham), shank half, separable lean only, cooked, roasted','PORK,FRSH,LEG (HAM),SHANK HALF,LN,CKD,RSTD',10019,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, whole, separable lean and fat, raw','PORK,FRSH,LOIN,WHL,LN&FAT,RAW',10020,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, whole, separable lean and fat, cooked, braised','PORK,FRSH,LOIN,WHL,LN&FAT,CKD,BRSD',10021,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, whole, separable lean and fat, cooked, broiled','PORK,FRSH,LOIN,WHL,LN&FAT,CKD,BRLD',10022,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, whole, separable lean and fat, cooked, roasted','PORK,FRSH,LOIN,WHL,LN&FAT,CKD,RSTD',10023,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, whole, separable lean only, raw','PORK,FRSH,LOIN,WHL,LN,RAW',10024,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, whole, separable lean only, cooked, braised','PORK,FRSH,LOIN,WHL,LN,CKD,BRSD',10025,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, whole, separable lean only, cooked, broiled','PORK,FRSH,LOIN,WHL,LN,CKD,BRLD',10026,NULL,NULL,NULL,NULL,NULL,1,'1994-03-16','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, whole, separable lean only, cooked, roasted','PORK,FRSH,LOIN,WHL,LN,CKD,RSTD',10027,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, blade (chops or roasts), bone-in, separable lean and fat, raw','PORK,FRSH,LOIN,BLADE (CHOPS OR ROASTS),BONE-IN,LN&FAT,RAW',10028,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, blade (chops), bone-in, separable lean and fat, cooked, braised','PORK,FRSH,LOIN,BLADE (CHOPS),BONE-IN,LN&FAT,CKD,BRSD',10029,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, blade (chops), bone-in, separable lean and fat, cooked, broiled','PORK,FRSH,LOIN,BLADE (CHOPS),BONE-IN,LN&FAT,CKD,BRLD',10030,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, blade (roasts), bone-in, separable lean and fat, cooked, roasted','PORK,FRSH,LOIN,BLADE (ROASTS),BONE-IN,LN&FAT,CKD,RSTD',10031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, blade (chops or roasts), bone-in, separable lean only, raw','PORK,FRSH,LOIN,BLADE (CHOPS OR ROASTS),BONE-IN,LN,RAW',10032,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, blade (chops), bone-in, separable lean only, cooked, braised','PORK,FRSH,LOIN,BLADE (CHOPS),BONE-IN,LN,CKD,BRSD',10033,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, blade (chops), bone-in, separable lean only, cooked, broiled','PORK,FRSH,LOIN,BLADE (CHOPS),BONE-IN,LN,CKD,BRLD',10034,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, blade (roasts), bone-in, separable lean only, cooked, roasted','PORK,FRSH,LOIN,BLADE (ROASTS),BONE-IN,LN,CKD,RSTD',10035,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center loin (chops), bone-in, separable lean and fat, raw','PORK,FRSH,LOIN,CNTR LOIN (CHOPS),BONE-IN,LN & FAT,RAW',10036,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center loin (chops), bone-in, separable lean and fat, cooked, braised','PORK,FRSH,LOIN,CNTR LOIN (CHOPS),BONE-IN,LN&FAT,CKD,BRSD',10037,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center loin (chops), bone-in, separable lean and fat, cooked, broiled','PORK,FRSH,LOIN,CNTR LOIN (CHOPS),BONE-IN,LN&FAT,CKD,BRLD',10038,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center loin (roasts), bone-in, separable lean and fat, cooked, roasted','PORK,FRSH,LOIN,CNTR LOIN (ROASTS),BONE-IN,LN&FAT,CKD,RSTD',10039,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center loin (chops), bone-in, separable lean only, raw','PORK,FRSH,LOIN,CNTR LOIN (CHOPS),BONE-IN,LN,RAW',10040,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center loin (chops), bone-in, separable lean only, cooked, braised','PORK,FRSH,LOIN,CNTR LOIN (CHOPS),BONE-IN,LN,CKD,BRSD',10041,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center loin (chops), bone-in, separable lean only, cooked, broiled','PORK,FRSH,LOIN,CNTR LOIN (CHOPS),BONE-IN,LN,CKD,BRLD',10042,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center loin (roasts), bone-in, separable lean only, cooked, roasted','PORK,FRSH,LOIN,CNTR LOIN (ROASTS),BONE-IN,LN,CKD,RSTD',10043,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops or roasts), bone-in, separable lean and fat, raw','PORK,FRSH,LOIN,CNTR RIB (CHOPS OR ROASTS),BONE-IN,LN&FAT,RAW',10044,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops), bone-in, separable lean and fat, cooked, braised','PORK,FRSH,LOIN,CNTR RIB (CHOPS),BONE-IN,LN&FAT,CKD,BRSD',10045,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops), bone-in, separable lean and fat, cooked, broiled','PORK,FRSH,LOIN,CNTR RIB (CHOPS),BONE-IN,LN&FAT,CKD,BRLD',10046,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (roasts), bone-in, separable lean and fat, cooked, roasted','PORK,FRSH,LOIN,CNTR RIB (ROASTS),BONE-IN,LN&FAT,CKD,RSTD',10047,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops or roasts), bone-in, separable lean only, raw','PORK,FRSH,LOIN,CNTR RIB (CHOPS OR ROASTS),BONE-IN,LN,RAW',10048,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops), bone-in, separable lean only, cooked, braised','PORK,FRSH,LOIN,CNTR RIB (CHOPS),BONE-IN,LN,CKD,BRSD',10049,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops), bone-in, separable lean only, cooked, broiled','PORK,FRSH,LOIN,CNTR RIB (CHOPS),BONE-IN,LN,CKD,BRLD',10050,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (roasts), bone-in, separable lean only, cooked, roasted','PORK,FRSH,LOIN,CNTR RIB (ROASTS),BONE-IN,LN,CKD,RSTD',10051,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, sirloin (chops or roasts), bone-in, separable lean and fat, raw','PORK,FRSH,LOIN,SIRLOIN (CHOPS OR ROASTS),BONE-IN,LN&FAT,RAW',10052,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, sirloin (chops), bone-in, separable lean and fat, cooked, braised','PORK,FRSH,LOIN,SIRLOIN (CHOPS),BONE-IN,LN&FAT,CKD,BRSD',10053,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, sirloin (chops), bone-in, separable lean and fat, cooked, broiled','PORK,FRSH,LOIN,SIRLOIN (CHOPS),BONE-IN,LN&FAT,CKD,BRLD',10054,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, sirloin (roasts), bone-in, separable lean and fat, cooked, roasted','PORK,FRSH,LOIN,SIRLOIN (ROASTS),BONE-IN,LN&FAT,CKD,RSTD',10055,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, sirloin (chops), bone-in, separable lean only, cooked, braised','PORK,FRSH,LOIN,SIRLOIN (CHOPS),BONE-IN,LN,CKD,BRSD',10057,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, sirloin (chops), bone-in, separable lean only, cooked, broiled','PORK,FRSH,LOIN,SIRLOIN (CHOPS),BONE-IN,LN,CKD,BRLD',10058,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, sirloin (roasts), bone-in, separable lean only, cooked, roasted','PORK,FRSH,LOIN,SIRLOIN (ROASTS),BONE-IN,LN,CKD,RSTD',10059,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, tenderloin, separable lean only, raw','PORK  FRSH  LOIN  TENDERLOIN   LN ONLY  RAW',10060,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, tenderloin, separable lean only, cooked, roasted','PORK,FRSH,LOIN,TENDERLOIN,LN,CKD,RSTD',10061,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (chops), boneless, separable lean and fat, raw','PORK,FRSH,LOIN,TOP LOIN (CHOPS),BNLESS,LN & FAT,RAW',10062,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (chops), boneless, separable lean and fat, cooked, braised','PORK,FRSH,LOIN,TOP LOIN (CHOPS),BNLESS,LN & FAT,CKD,BRSD',10063,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (chops), boneless, separable lean and fat, cooked, broiled','PORK,FRSH,LOIN,TOP LOIN (CHOPS),BNLESS,LN & FAT,CKD,BRLD',10064,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (roasts), boneless, separable lean and fat, cooked, roasted','PORK,FRSH,LOIN,TOP LOIN (ROASTS),BNLESS,LN&FAT,CKD,RSTD',10065,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (chops), boneless, separable lean only, raw','PORK,FRSH,LOIN,TOP LOIN (CHOPS),BNLESS,LN,RAW',10066,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (chops), boneless, separable lean only, cooked, braised','PORK,FRSH,LOIN,TOP LOIN (CHOPS),BNLESS,LN,CKD,BRSD',10067,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (chops), boneless, separable lean only, cooked, broiled','PORK,FRSH,LOIN,TOP LOIN (CHOPS),BNLESS,LN,CKD,BRLD',10068,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (roasts), boneless, separable lean only, cooked, roasted','PORK,FRSH,LOIN,TOP LOIN (ROASTS),BNLESS,LN,CKD,RSTD',10069,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, whole, separable lean and fat, raw','PORK,FRSH,SHLDR,WHL,LN&FAT,RAW',10070,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, whole, separable lean and fat, cooked, roasted','PORK,FRSH,SHLDR,WHL,LN&FAT,CKD,RSTD',10071,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, whole, separable lean only, raw','PORK,FRSH,SHLDR,WHL,LN,RAW',10072,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, whole, separable lean only, cooked, roasted','PORK,FRSH,SHLDR,WHL,LN,CKD,RSTD',10073,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, arm picnic, separable lean and fat, raw','PORK,FRSH,SHLDR,ARM PICNIC,LN&FAT,RAW',10074,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, arm picnic, separable lean and fat, cooked, braised','PORK,FRSH,SHLDR,ARM PICNIC,LN&FAT,CKD,BRSD',10075,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, arm picnic, separable lean and fat, cooked, roasted','PORK,FRSH,SHLDR,ARM PICNIC,LN&FAT,CKD,RSTD',10076,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, arm picnic, separable lean only, raw','PORK,FRSH,SHLDR,ARM PICNIC,LN,RAW',10077,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, arm picnic, separable lean only, cooked, braised','PORK,FRSH,SHLDR,ARM PICNIC,LN,CKD,BRSD',10078,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, arm picnic, separable lean only, cooked, roasted','PORK,FRSH,SHLDR,ARM PICNIC,LN,CKD,RSTD',10079,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, (Boston butt), blade (steaks), separable lean and fat, raw','PORK,FRSH,SHLDR,(BOSTON BUTT),BLADE (STEAKS),LN & FAT,RAW',10080,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, (Boston butt), blade (steaks), separable lean and fat, cooked, braised','PORK,FRSH,SHLDR,(BOSTON BUTT),BLADE (STKS),LN & FAT,CKD,BRSD',10081,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, blade, boston (steaks), separable lean and fat, cooked, broiled','PORK,FRSH,SHLDR,BLADE,BOSTON (STEAKS),LN&FAT,CKD,BRLD',10082,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, blade, boston (roasts), separable lean and fat, cooked, roasted','PORK,FRSH,SHLDR,BLADE,BOSTON (ROASTS),LN&FAT,CKD,RSTD',10083,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, (Boston butt), blade (steaks), separable lean only, raw','PORK,FRSH,SHLDR,(BOSTON BUTT),BLADE (STEAKS),LN,RAW',10084,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, (Boston butt), blade (steaks), separable lean only, cooked, braised','PORK,FRSH,SHLDR,(BOSTON BUTT),BLADE (STEAKS),LN,CKD,BRSD',10085,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, blade, boston (steaks), separable lean only, cooked, broiled','PORK,FRSH,SHLDR,BLADE,BOSTON (STEAKS),LN,CKD,BRLD',10086,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, blade, boston (roasts), separable lean only, cooked, roasted','PORK,FRSH,SHLDR,BLADE,BOSTON (ROASTS),LN,CKD,RSTD',10087,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, spareribs, separable lean and fat, raw','PORK,FRSH,SPARERIBS,LN&FAT,RAW',10088,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, spareribs, separable lean and fat, cooked, braised','PORK,FRSH,SPARERIBS,LN&FAT,CKD,BRSD',10089,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, composite of trimmed retail cuts (leg, loin, and shoulder), separable lean only, cooked','PORK,FRSH,COMP OF RTL CUTS (LEG,LOIN,&SHLDR),LN,CKD',10093,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center loin (chops), boneless, separable lean only, raw','PORK,FRSH,LOIN,CNTR LOIN (CHOPS),BNLESS,LN,RAW',10094,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, brain, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,BRAIN,RAW',10096,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, brain, cooked, braised','PORK,FRSH,VAR MEATS&BY-PRODUCTS,BRAIN,CKD,BRSD',10097,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, chitterlings, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,CHITTERLINGS,RAW',10098,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, chitterlings, cooked, simmered','PORK,FRSH,VAR MEATS&BY-PRODUCTS,CHITTERLINGS,CKD,SIMMRD',10099,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, ears, frozen, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,EARS,FRZ,RAW',10100,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, ears, frozen, cooked, simmered','PORK,FRSH,VAR MEATS&BY-PRODUCTS,EARS,FRZ,CKD,SIMMRD',10101,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, feet, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,FEET,RAW',10102,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, heart, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,HEART,RAW',10103,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, heart, cooked, braised','PORK,FRSH,VAR MEATS&BY-PRODUCTS,HEART,CKD,BRSD',10104,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, jowl, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,JOWL,RAW',10105,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, kidneys, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,KIDNEYS,RAW',10106,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, kidneys, cooked, braised','PORK,FRSH,VAR MEATS&BY-PRODUCTS,KIDNEYS,CKD,BRSD',10107,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, leaf fat, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,LEAF FAT,RAW',10109,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, liver, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,LIVER,RAW',10110,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, liver, cooked, braised','PORK,FRSH,VAR MEATS&BY-PRODUCTS,LIVER,CKD,BRSD',10111,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, lungs, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,LUNGS,RAW',10112,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, lungs, cooked, braised','PORK,FRSH,VAR MEATS&BY-PRODUCTS,LUNGS,CKD,BRSD',10113,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, mechanically separated, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,MECHANICALLY SEPARATED,RAW',10114,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, pancreas, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,PANCREAS,RAW',10115,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, pancreas, cooked, braised','PORK,FRSH,VAR MEATS&BY-PRODUCTS,PANCREAS,CKD,BRSD',10116,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, spleen, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,SPLEEN,RAW',10117,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, spleen, cooked, braised','PORK,FRSH,VAR MEATS&BY-PRODUCTS,SPLEEN,CKD,BRSD',10118,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, stomach, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,STOMACH,RAW',10119,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, blade (chops), bone-in, separable lean only, cooked, pan-fried','PORK,FRSH,LOIN,BLADE (CHOPS),BONE-IN,LN,CKD,PAN-FRIED',10120,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, tongue, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,TONGUE,RAW',10121,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, tongue, cooked, braised','PORK,FRSH,VAR MEATS&BY-PRODUCTS,TONGUE,CKD,BRSD',10122,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, bacon, unprepared','PORK,CURED,BACON,UNPREP',10123,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, breakfast strips, raw or unheated','PORK,CURED,BRKFST STRIPS,RAW OR UNHTD',10128,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Canadian bacon, unprepared','CANADIAN BACON,UNPREP',10130,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, feet, pickled','PORK,CURED,FEET,PICKLED',10132,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, boneless, extra lean (approximately 5% fat), roasted','PORK,CURED,HAM,BNLESS,EX LN (APPROX 5% FAT),RSTD',10134,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, boneless, regular (approximately 11% fat), roasted','PORK,CURED,HAM,BNLESS,REG (APPROX 11% FAT),RSTD',10136,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, extra lean (approximately 4% fat), canned, unheated','PORK,CURED,HAM,EX LN (APPROX 4% FAT),CND,UNHTD',10137,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, extra lean (approximately 4% fat), canned, roasted','PORK,CURED,HAM,EX LN (APPROX 4% FAT),CND,RSTD',10138,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, regular (approximately 13% fat), canned, roasted','PORK,CURED,HAM,REG (APPROX 13% FAT),CND,RSTD',10140,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, center slice, country-style, separable lean only, raw','PORK,CURED,HAM,CNTR SLICE,COUNTRY-STYLE,LN,RAW',10141,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, center slice, separable lean and fat, unheated','PORK,CURED,HAM,CNTR SLICE,LN&FAT,UNHTD',10142,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, patties, unheated','PORK,CURED,HAM,PATTIES,UNHTD',10146,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, steak, boneless, extra lean, unheated','PORK,CURED,HAM,STEAK,BNLESS,EX LN,UNHTD',10149,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, whole, separable lean and fat, unheated','PORK,CURED,HAM,WHL,LN&FAT,UNHTD',10150,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, whole, separable lean only, unheated','PORK,CURED,HAM,WHL,LN,UNHTD',10152,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, whole, separable lean only, roasted','PORK,CURED,HAM,WHL,LN,RSTD',10153,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center loin (chops), boneless, separable lean only, cooked, pan-broiled','PORK,FRSH,LOIN,CNTR LOIN (CHOPS),BNLESS,LN,CKD,PAN-BROILED',10163,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center loin (chops), boneless, separable lean and fat, raw','PORK,FRSH,LOIN,CNTR LOIN (CHOPS),BNLESS,LN & FAT,RAW',10164,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, salt pork, raw','PORK,CURED,SALT PORK,RAW',10165,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, separable fat (from ham and arm picnic), unheated','PORK,CURED,FAT (FROM HAM&ARM PICNIC),UNHTD',10166,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, separable fat (from ham and arm picnic), roasted','PORK,CURED,FAT (FROM HAM&ARM PICNIC),RSTD',10167,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, shoulder, arm picnic, separable lean and fat, roasted','PORK,CURED,SHLDR,ARM PICNIC,LN&FAT,RSTD',10168,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, shoulder, arm picnic, separable lean only, roasted','PORK,CURED,SHLDR,ARM PICNIC,LN,RSTD',10169,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, shoulder, blade roll, separable lean and fat, unheated','PORK,CURED,SHLDR,BLADE ROLL,LN&FAT,UNHTD',10170,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, shoulder, blade roll, separable lean and fat, roasted','PORK,CURED,SHLDR,BLADE ROLL,LN&FAT,RSTD',10171,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, feet, cooked, simmered','PORK,FRSH,VAR MEATS&BY-PRODUCTS,FEET,CKD,SIMMRD',10173,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, tail, raw','PORK,FRSH,VAR MEATS&BY-PRODUCTS,TAIL,RAW',10174,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, tail, cooked, simmered','PORK,FRSH,VAR MEATS&BY-PRODUCTS,TAIL,CKD,SIMMRD',10175,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center loin (chops), bone-in, separable lean only, cooked, pan-fried','PORK,FRSH,LOIN,CNTR LOIN (CHOPS),BONE-IN,LN,CKD,PAN-FRIED',10176,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops), bone-in, separable lean only, cooked, pan-fried','PORK,FRSH,LOIN,CNTR RIB (CHOPS),BONE-IN,LN,CKD,PAN-FRIED',10177,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, blade (chops), bone-in, separable lean and fat, cooked, pan-fried','PORK,FRSH,LOIN,BLADE (CHOPS),BONE-IN,LN&FAT,CKD,PAN-FRIED',10178,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center loin (chops), bone-in, separable lean and fat, cooked, pan-fried','PORK,FRSH,LOIN,CNTR LOIN CHOPS,BONE-IN,LN&FAT,CKD,PAN-FRIED',10179,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops), bone-in, separable lean and fat, cooked, pan-fried','PORK,FRSH,LOIN,CNTR RIB (CHOPS),BONE-IN,LN&FAT,CKD,PAN-FRIED',10180,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (chops), boneless, separable lean only, cooked, pan-fried','PORK,FRSH,LOIN,TOP LOIN (CHOPS),BNLESS,LN,CKD,PAN-FRIED',10181,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, boneless, extra lean and regular, unheated','PORK,CURED,HAM,BNLESS,EX LN&REG,UNHTD',10182,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, boneless, extra lean and regular, roasted','PORK,CURED,HAM,BNLESS,EX LN&REG,RSTD',10183,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, extra lean and regular, canned, unheated','PORK,CURED,HAM,EX LN&REG,CND,UNHTD',10184,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, extra lean and regular, canned, roasted','PORK,CURED,HAM,EX LN&REG,CND,RSTD',10185,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (chops), boneless, separable lean and fat, cooked, pan-fried','PORK,FRSH,LOIN,TOP LOIN (CHOPS),BNLESS,LN&FAT,CKD,PAN-FRIED',10186,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, composite of trimmed retail cuts (leg, loin, shoulder, and spareribs), separable lean and fat, raw','PORK,FRSH,COMP (LEG,LOIN,SHLDR,&SPARERIBS),LN&FAT,RAW',10187,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, composite of trimmed retail cuts (leg, loin, shoulder, and spareribs), separable lean and fat, cooked','PORK,FRSH,COMP (LEG,LOIN,SHLDR,&SPARERIBS),LN&FAT,CKD',10188,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center loin (chops), boneless, separable lean and fat, cooked, pan-broiled','PORK,FRSH,LOIN,CNTR LON (CHPS),BNLESS,LN & FAT,CKD,PAN-BRLED',10189,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, backribs, separable lean and fat, raw','PORK,FRSH,BACKRIBS,LN&FAT,RAW',10192,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, backribs, separable lean and fat, cooked, roasted','PORK,FRSH,BACKRIBS,LN&FAT,CKD,RSTD',10193,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops or roasts), boneless, separable lean and fat, raw','PORK,FRSH,LOIN,CNTR RIB (CHOPS OR ROASTS),BNLESS,LN&FAT,RAW',10194,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops), boneless, separable lean and fat, cooked, braised','PORK,FRSH,LOIN,CNTR RIB (CHOPS),BNLESS,LN&FAT,CKD,BRSD',10195,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops), boneless, separable lean and fat, cooked, broiled','PORK,FRSH,LOIN,CNTR RIB (CHOPS),BNLESS,LN&FAT,CKD,BRLD',10196,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops), boneless, separable lean and fat, cooked, pan-fried','PORK,FRSH,LOIN,CNTR RIB (CHOPS),BNLESS,LN&FAT,CKD,PAN-FRIED',10197,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (roasts), boneless, separable lean and fat, cooked, roasted','PORK,FRSH,LOIN,CNTR RIB (ROASTS),BNLESS,LN&FAT,CKD,RSTD',10198,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops or roasts), boneless, separable lean only, raw','PORK,FRSH,LOIN,CNTR RIB (CHOPS OR ROASTS),BNLESS,LN,RAW',10199,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops), boneless, separable lean only, cooked, braised','PORK,FRSH,LOIN,CNTR RIB (CHOPS),BNLESS,LN,CKD,BRSD',10200,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops), boneless, separable lean only, cooked, broiled','PORK,FRSH,LOIN,CNTR RIB (CHOPS),BNLESS,LN,CKD,BRLD',10201,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (chops), boneless, separable lean only, cooked, pan-fried','PORK,FRSH,LOIN,CNTR RIB (CHOPS),BNLESS,LN,CKD,PAN-FRIED',10202,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, center rib (roasts), boneless, separable lean only, cooked, roasted','PORK,FRSH,LOIN,CNTR RIB (ROASTS),BNLESS,LN,CKD,RSTD',10203,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, country-style ribs, separable lean and fat, raw','PORK,FRSH,LOIN,COUNTRY-STYLE RIBS,LN&FAT,RAW',10204,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, country-style ribs, separable lean and fat, cooked, braised','PORK,FRSH,LOIN,COUNTRY-STYLE RIBS,LN&FAT,CKD,BRSD',10205,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, country-style ribs, separable lean and fat, bone-in, cooked, roasted','PORK,FRSH,LOIN,COUNTRY-STYLE RIBS,LN & FAT,BONE-IN,CKD,RSTD',10206,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, country-style ribs, separable lean only, raw','PORK,FRSH,LOIN,COUNTRY-STYLE RIBS,LN,RAW',10207,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, country-style ribs, separable lean only, cooked, braised','PORK,FRSH,LOIN,COUNTRY-STYLE RIBS,LN,CKD,BRSD',10208,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, country-style ribs, separable lean only, bone-in, cooked, roasted','PORK,FRSH,LOIN,COUNTRY-STYLE RIBS,LN,BONE-IN,CKD,RSTD',10209,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, sirloin (chops or roasts), boneless, separable lean and fat, raw','PORK,FRSH,LOIN,SIRLOIN (CHOPS OR ROASTS),BNLESS,LN&FAT,RAW',10210,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, sirloin (chops), boneless, separable lean and fat, cooked, braised','PORK,FRSH,LOIN,SIRLOIN (CHOPS),BNLESS,LN&FAT,CKD,BRSD',10211,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, sirloin (chops), boneless, separable lean and fat, cooked, broiled','PORK,FRSH,LOIN,SIRLOIN (CHOPS),BNLESS,LN&FAT,CKD,BRLD',10212,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, sirloin (roasts), boneless, separable lean and fat, cooked, roasted','PORK,FRSH,LOIN,SIRLOIN (ROASTS),BNLESS,LN&FAT,CKD,RSTD',10213,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, sirloin (chops or roasts), boneless, separable lean only, raw','PORK,FRSH,LOIN,SIRLOIN (CHOPS OR ROASTS),BNLESS,LN,RAW',10214,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, sirloin (chops), boneless, separable lean only, cooked, braised','PORK,FRSH,LOIN,SIRLOIN (CHOPS),BNLESS,LN,CKD,BRSD',10215,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, sirloin (chops), boneless, separable lean only, cooked, broiled','PORK,FRSH,LOIN,SIRLOIN (CHOPS),BNLESS,LN,CKD,BRLD',10216,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, sirloin (roasts), boneless, separable lean only, cooked, roasted','PORK,FRSH,LOIN,SIRLOIN (ROASTS),BNLESS,LN,CKD,RSTD',10217,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, tenderloin, separable lean and fat, raw','PORK,FRSH,LOIN,TENDERLOIN,LN&FAT,RAW',10218,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, ground, raw','PORK,FRESH,GROUND,RAW',10219,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, ground, cooked','PORK,FRESH,GROUND,COOKED',10220,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, tenderloin, separable lean and fat, cooked, broiled','PORK,FRSH,LOIN,TENDERLOIN,LN&FAT,CKD,BRLD',10221,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, tenderloin, separable lean and fat, cooked, roasted','PORK,FRSH,LOIN,TENDERLOIN,LN&FAT,CKD,RSTD',10222,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, tenderloin, separable lean only, cooked, broiled','PORK,FRSH,LOIN,TENDERLOIN,LN,CKD,BRLD',10223,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (roasts), boneless, separable lean and fat, raw','PORK,FRSH,LOIN,TOP LOIN (ROASTS),BNLESS,LN&FAT,RAW',10224,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (roasts), boneless, separable lean only, raw','PORK,FRSH,LOIN,TOP LOIN (ROASTS),BNLESS,LN,RAW',10225,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, composite of trimmed retail cuts (loin and shoulder blade), separable lean and fat, raw','PORK,FRSH,COMP OF RTL CUTS (LOIN & SHLDR BLADE),LN & FAT,RAW',10226,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, composite of trimmed retail cuts (loin and shoulder blade), separable lean and fat, cooked','PORK,FRSH,COMP OF RTL CUTS (LOIN&SHLDR BLADE),LN&FAT,CKD',10227,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, composite of trimmed retail cuts (loin and shoulder blade), separable lean only, raw','PORK,FRSH,COMP OF RTL CUTS (LOIN&SHLDR BLADE),LN,RAW',10228,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, composite of trimmed retail cuts (loin and shoulder blade), separable lean only, cooked','PORK,FRSH,COMP OF RTL CUTS (LOIN&SHLDR BLADE),LN,CKD',10229,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (chops), boneless, separable lean only, with added solution, cooked, pan-broiled','PORK,FRSH,LN,TP LN (CHPS),BNLESS,LN,W/ ADDED SLN,CKD,PN-BRLD',10858,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (chops), boneless, separable lean and fat, with added solution, cooked, pan-broiled','PORK,FRSH,LN,TPLN(CHPS),BNLS,LN & FT,W/ADDED SLN,CKD,PN-BRLD',10859,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, bacon, cooked, baked','PORK,CURED,BACON,CKD,BKD',10860,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, bacon, cooked, microwaved','PORK,CURED,BACON,CKD,MICROWAVED',10861,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, bacon, pre-sliced, cooked, pan-fried','PORK,CURED,BACON,PRE-SLICED,CKD,PAN-FRIED',10862,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, variety meats and by-products, stomach, cooked, simmered','PORK,FRSH,VAR MEATS & BY-PRODUCTS,STOMACH,CKD,SIMMRD',10863,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, bacon, rendered fat, cooked','PORK,BACON,RENDERED FAT,CKD',10864,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, rump, bone-in, separable lean only, heated, roasted','PORK,CURED,HAM -- H2O ADDED,RUMP,BONE-IN,LN,HTD,RSTD',10865,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, rump, bone-in, separable lean only, unheated','PORK,CURED,HAM -- H2O ADDED,RUMP,BONE-IN,LN,UNHTD',10866,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, shank, bone-in, separable lean only, heated, roasted','PORK,CURED,HAM -- H2O ADDED,SHANK,BONE-IN,LN,HTD,RSTD',10867,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, slice, bone-in, separable lean only, heated, pan-broil','PORK,CURED,HAM -- H2O ADDED,SLICE,BONE-IN,LN,HTD,PAN-BROIL',10868,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, slice, bone-in, separable lean only, heated, pan-broil','PORK,CURED,HAM & H2O PRODUCT,SLICE,BONE-IN,LN,HTD,PAN-BROIL',10869,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, slice, boneless, separable lean only, heated, pan-broil','PORK,CURED,HAM & H2O PRODUCT,SLICE,BNLESS,LN,HTD,PAN-BROIL',10870,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, whole, boneless, separable lean only, heated, roasted','PORK,CURED,HAM & H2O PRODUCT,WHL,BNLESS,LN,HTD,RSTD',10871,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, whole, boneless, separable lean only, unheated','PORK,CURED,HAM & H2O PRODUCT,WHL,BNLESS,LN,UNHTD',10872,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, rump, bone-in, separable lean only, heated, roasted','PORK,CURED,HAM W/ NAT JUICES,RUMP,BONE-IN,LN,HTD,RSTD',10873,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, shank, bone-in, separable lean only, heated, roasted','PORK,CURED,HAM W/ NAT JUICES,SHANK,BONE-IN,LN,HTD,RSTD',10874,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, slice, bone-in, separable lean only, heated, pan-broil','PORK,CURED,HAM W/ NAT JUICES,SLICE,BONE-IN,LN,HTD,PAN-BROIL',10875,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, spiral slice, meat only, boneless, separable lean only, heated, roasted','PRK,CRD,HAM W/ NAT JUCS,SPRL SLC,MEAT ONLY,BNLES,LN,HTD,RSTD',10876,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, rump, bone-in, separable lean only, heated, roasted','PORK,CURED,HAM & H2O PRODUCT,RUMP,BONE-IN,LN,HTD,RSTD',10877,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, slice, boneless, separable lean only, heated, pan-broil','PORK,CURED,HAM -- H2O ADDED,SLICE,BNLESS,LN,HTD,PAN-BROIL',10878,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, whole, boneless, separable lean only, heated, roasted','PORK,CURED,HAM -- H2O ADDED,WHL,BNLESS,LN,HTD,RSTD',10879,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, whole, boneless, separable lean only, unheated','PORK,CURED,HAM -- H2O ADDED,WHL,BNLESS,LN,UNHTD',10880,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, shank, bone-in, separable lean only, heated, roasted','PORK,CURED,HAM & H2O PRODUCT,SHANK,BONE-IN,LN,HTD,RSTD',10881,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, slice, boneless, separable lean only, heated, pan-broil','PORK,CURED,HAM W/ NAT JUICES,SLICE,BNLESS,LN,HTD,PAN-BROIL',10882,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, whole, boneless, separable lean only, heated, roasted','PORK,CURED,HAM W/ NAT JUICES,WHL,BNLESS,LN,HTD,RSTD',10883,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, whole, boneless, separable lean only, unheated','PORK,CURED,HAM W/ NAT JUICES,WHL,BNLESS,LN,UNHTD',10884,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, shank, bone-in, separable lean only, unheated','PORK,CURED,HAM -- H2O ADDED,SHANK,BONE-IN,LN,UNHTD',10885,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, slice, bone-in, separable lean only, unheated','PORK,CURED,HAM -- H2O ADDED,SLICE,BONE-IN,LN,UNHTD',10886,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, rump, bone-in, separable lean only, unheated','PORK,CURED,HAM & H2O PRODUCT,RUMP,BONE-IN,LN,UNHTD',10887,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, slice, bone-in, separable lean only, unheated','PORK,CURED,HAM & H2O PRODUCT,SLICE,BONE-IN,LN,UNHTD',10888,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, shank, bone-in, unheated, separable lean only','PORK,CURED,HAM & H2O PRODUCT,SHANK,BONE-IN,UNHTD,LN',10889,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, rump, bone-in, separable lean only, unheated','PORK,CURED,HAM W/ NAT JUICES,RUMP,BONE-IN,LN,UNHTD',10890,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, shank, bone-in, separable lean only, unheated','PORK,CURED,HAM W/ NAT JUICES,SHANK,BONE-IN,LN,UNHTD',10891,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, slice, bone-in, separable lean only, unheated','PORK,CURED,HAM W/ NAT JUICES,SLICE,BONE-IN,LN,UNHTD',10892,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, spiral slice, boneless, separable lean only, unheated','PORK,CURED,HAM W/ NAT JUICES,SPIRAL SLICE,BNLESS,LN,UNHTD',10893,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, separable fat, boneless, heated','PORK,CURED,HAM,FAT,BNLESS,HTD',10894,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, separable fat, boneless, unheated','PORK,CURED,HAM,FAT,BNLESS,UNHTD',10895,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, pickled pork hocks','PORK,PICKLED PORK HOCKS',10898,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, slice, bone-in, separable lean only, heated, pan-broil','PORK,CURED,HAM,SLICE,BONE-IN,LN,HTD,PAN-BROIL',10899,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, whole, boneless, separable lean and fat, unheated','PORK,CURED,HAM W/ NAT JUICES,WHL,BNLESS,LN & FAT,UNHTD',10900,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, spiral slice, boneless, separable lean and fat, unheated','PORK,CURED,HAM W/ NAT JUICES,SPIRL SLCE,BNLES,LN & FAT,UNHTD',10901,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, slice, bone-in, separable lean and fat, unheated','PORK,CURED,HAM W/ NAT JUICES,SLICE,BONE-IN,LN & FAT,UNHTD',10902,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, shank, bone-in, separable lean and fat, unheated','PORK,CURED,HAM W/ NAT JUICES,SHANK,BONE-IN,LN & FAT,UNHTD',10903,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, rump, bone-in, separable lean and fat, unheated','PORK,CURED,HAM W/ NAT JUICES,RUMP,BONE-IN,LN & FAT,UNHTD',10904,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, whole, boneless, separable lean and fat, unheated','PORK,CURED,HAM & H2O PRODUCT,WHL,BNLESS,LN & FAT,UNHTD',10905,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, slice, bone-in, separable lean and fat, unheated','PORK,CURED,HAM & H2O PRODUCT,SLICE,BONE-IN,LN & FAT,UNHTD',10906,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, shank, bone-in, separable lean and fat, unheated','PORK,CURED,HAM & H2O PRODUCT,SHANK,BONE-IN,LN & FAT,UNHTD',10907,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, rump, bone-in, separable lean and fat, unheated','PORK,CURED,HAM & H2O PRODUCT,RUMP,BONE-IN,LN & FAT,UNHTD',10908,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, whole, boneless, separable lean and fat, unheated','PORK,CURED,HAM -- H2O ADDED,WHL,BNLESS,LN & FAT,UNHTD',10909,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, slice, bone-in, separable lean and fat, unheated','PORK,CURED,HAM -- H2O ADDED,SLICE,BONE-IN,LN & FAT,UNHTD',10910,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, shank, bone-in, separable lean and fat, unheated','PORK,CURED,HAM -- H2O ADDED,SHANK,BONE-IN,LN & FAT,UNHTD',10911,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, rump, bone-in, separable lean and fat, unheated','PORK,CURED,HAM -- H2O ADDED,RUMP,BONE-IN,LN & FAT,UNHTD',10912,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, rump, bone-in, separable lean and fat, heated, roasted','PORK,CURED,HAM -- H2O ADDED,RUMP,BONE-IN,LN & FAT,HTD,RSTD',10913,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, shank, bone-in, separable lean and fat, heated, roasted','PORK,CURED,HAM -- H2O ADDED,SHANK,BONE-IN,LN & FAT,HTD,RSTD',10914,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, slice, bone-in, separable lean and fat, heated, pan-broil','PORK,CURED,HAM -- H2O ADDED,SLCE,BNE-IN,LN & FAT,HTD,PAN-BRL',10915,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, slice, boneless, separable lean and fat, heated, pan-broil','PORK,CURED,HAM -- H2O ADDED,SLCE,BNLESS,LN & FAT,HTD,PAN-BRL',10916,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham -- water added, whole, boneless, separable lean and fat, heated, roasted','PORK,CURED,HAM -- H2O ADDED,WHL,BNLESS,LN & FAT,HTD,RSTD',10917,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, rump, bone-in, separable lean and fat, heated, roasted','PORK,CURED,HAM & H2O PRODUCT,RUMP,BONE-IN,LN & FAT,HTD,RSTD',10918,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, shank, bone-in, separable lean and fat, heated, roasted','PORK,CURED,HAM & H2O PRODUCT,SHANK,BONE-IN,LN & FAT,HTD,RSTD',10919,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, slice, bone-in, separable lean and fat, heated, pan-broil','PORK,CURED,HAM & H2O PRDCT,SLCE,BNE-IN,LN & FAT,HTD,PAN-BRL',10920,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, slice, boneless, separable lean and fat, heated, pan-broil','PORK,CURED,HAM & H2O PRDCT,SLICE,BNLESS,LN & FAT,HTD,PAN-BRL',10921,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham and water product, whole, boneless, separable lean and fat, heated, roasted','PORK,CURED,HAM & H2O PRODUCT,WHL,BNLESS,LN & FAT,HTD,RSTD',10922,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, rump, bone-in, separable lean and fat, heated, roasted','PORK,CURED,HAM W/ NAT JUICES,RUMP,BONE-IN,LN & FAT,HTD,RSTD',10923,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, shank, bone-in, separable lean and fat, heated, roasted','PORK,CURED,HAM W/ NAT JUICES,SHANK,BONE-IN,LN & FAT,HTD,RSTD',10924,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, slice, bone-in, separable lean and fat, heated, pan-broil','PORK,CURED,HAM W/ NAT JUICS,SLCE,BNE-IN,LN & FAT,HTD,PAN-BRL',10925,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, slice, boneless, separable lean and fat, heated, pan-broil','PORK,CURED,HAM W/ NAT JUICS,SLICE,BNLES,LN & FAT,HTD,PAN-BRL',10926,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, spiral slice, boneless, separable lean and fat, heated, roasted','PORK,CURED,HAM W/ NAT JUCS,SPRL SLCE,BNLES,LN & FAT,HTD,RSTD',10927,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham with natural juices, whole, boneless, separable lean and fat, heated, roasted','PORK,CURED,HAM W/ NAT JUICES,WHL,BNLESS,LN & FAT,HTD,RSTD',10928,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, rump, bone-in, separable lean and fat, heated, roasted','PORK,CURED,HAM,RUMP,BONE-IN,LN & FAT,HTD,RSTD',10929,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, rump, bone-in, separable lean only, heated, roasted','PORK,CURED,HAM,RUMP,BONE-IN,LN,HTD,RSTD',10931,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, rump, bone-in, separable lean only, unheated','PORK,CURED,HAM,RUMP,BONE-IN,LN,UNHTD',10932,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, shank, bone-in, separable lean only, heated, roasted','PORK,CURED,HAM,SHANK,BONE-IN,LN,HTD,RSTD',10933,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, shank, bone-in, separable lean only, unheated','PORK,CURED,HAM,SHANK,BONE-IN,LN,UNHTD',10934,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, shank, bone-in, separable lean and fat, heated, roasted','PORK,CURED,HAM,SHANK,BONE-IN,LN & FAT,HTD,RSTD',10935,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, shank, bone-in, separable lean and fat, unheated','PORK,CURED,HAM,SHANK,BONE-IN,LN & FAT,UNHTD',10936,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, slice, bone-in, separable lean and fat, heated, pan-broil','PORK,CURED,HAM,SLICE,BONE-IN,LN & FAT,HTD,PAN-BROIL',10937,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, slice, bone-in, separable lean only, unheated','PORK,CURED,HAM,SLICE,BONE-IN,LN,UNHTD',10938,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, slice, bone-in, separable lean and fat, unheated','PORK,CURED,HAM,SLICE,BONE-IN,LN & FAT,UNHTD',10939,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, spareribs, separable lean and fat, cooked, roasted','PORK,FRSH,SPARERIBS,LN & FAT,CKD,RSTD',10940,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, composite of separable fat, with added solution, raw','PORK,FRSH,COMP OF FAT,W/ ADDED SOLN,RAW',10942,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, tenderloin, separable lean only, with added solution, cooked, roasted','PORK,FRSH,LOIN,TNDERLN,LN,W/ ADDED SLN,CKD,RSTD',10943,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, enhanced, loin, tenderloin, separable lean only, raw','PORK,FRSH,ENHANCED,LOIN,TENDERLOIN,LN,RAW',10944,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, (Boston butt), blade (steaks), separable lean only, with added solution cooked, braised','PORK,FRSH,SHLDR,(BSTN BTT),BLDE (STKS),LN,W/ADDEDSLNCKD,BRSD',10945,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, (Boston butt), blade (steaks), separable lean only, with added solution, raw','PORK,FRSH,SHLDR,(BSTN BUTT),BLDE (STKS),LN,W/ ADDED SOLN,RAW',10946,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (chops), boneless, separable lean only, with added solution, cooked, broiled','PORK,FRSH,LN,TOP LN (CHPS),BNLESS,LN,W/ ADDED SLN,CKD,BRLD',10947,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (chops), boneless, separable lean only, with added solution, raw','PORK,FRSH,LN,TOP LIN (CHOPS),BNLSS,LN,W/ ADDED SLN,RAW',10948,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (chops), boneless, separable lean and fat, with added solution, raw','PORK,FRSH,LOIN,TP LN (CHPS),BNLSS,LN & FT,W/ ADDED SLN,RAW',10949,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, top loin (chops), boneless, separable lean and fat, with added solution, cooked, broiled','PORK,FRSH,LN,TP LN (CHPS),BNLSS,LN & FT,W/ADDED SLN,CKD,BRLD',10950,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, tenderloin, separable lean and fat, with added solution, raw','PORK,FRSH,LOIN,TENDERLOIN,LN & FAT,W/ ADDED SLN,RAW',10951,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, tenderloin, separable lean and fat, with added solution, cooked, roasted','PORK,FRSH,LOIN,TNDERLN,LN & FT,W/ ADDED SLN,CKD,RSTD',10952,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, (Boston butt), blade (steaks), separable lean and fat,with added solution, raw','PORK,FRSH,SHDR,(BSTN BTT),BLDE(STKS),LN & FT,W/ADDED SLN,RAW',10953,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, shoulder, (Boston butt), blade (steaks), separable lean and fat, with added solution, cooked, braised','PORK,FRSH,SHDR,(BSTN BT),BLDE(STKS),LN&FT,WADDEDSLN,CKD,BRSD',10954,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, rump, bone-in, separable lean and fat, unheated','PORK,CURED,HAM,RUMP,BONE-IN,LN & FAT,UNHTD',10955,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, loin, leg cap steak, boneless, separable lean and fat, cooked, broiled','PORK,LOIN,LEG CAP STEAK,BNLESS,LN & FAT,CKD,BRLD',10956,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2009-01-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, Leg Cap Steak, boneless, separable lean and fat, raw','PORK,LEG CAP STEAK,BNLESS,LN & FAT,RAW',10957,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, Shoulder breast, boneless, separable lean and fat, raw','PORK,SHLDR BREAST,BNLESS,LN & FAT,RAW',10958,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, Shoulder breast, boneless, separable lean and fat, cooked, broiled','PORK,SHLDR BREAST,BNLESS,LN & FAT,CKD,BRLD',10959,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2009-01-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, shoulder, petite tender, boneless, separable lean and fat, cooked, broiled','PORK,SHLDR,PETITE TENDER,BNLESS,LN & FAT,CKD,BRLD',10960,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2009-01-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, Shoulder petite tender, boneless, separable lean and fat, raw','PORK,SHLDR PETITE TENDER,BNLESS,LN & FAT,RAW',10961,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, Leg sirloin tip roast, boneless, separable lean and fat, cooked, braised','PORK,LEG SIRLOIN TIP RST,BNLESS,LN & FAT,CKD,BRSD',10962,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2009-01-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, Leg sirloin tip roast, boneless, separable lean and fat, raw','PORK,LEG SIRLOIN TIP RST,BNLESS,LN & FAT,RAW',10963,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, ground, 84% lean / 16% fat, raw','PORK,GROUND,84% LN / 16% FAT,RAW',10972,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, ground, 96% lean / 4% fat, raw','PORK,GROUND,96% LN / 4% FAT,RAW',10973,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, ground, 72% lean / 28% fat, cooked, crumbles','PORK,GROUND,72% LN / 28% FAT,CKD,CRUMBLES',10974,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, ground, 84% lean / 16% fat, cooked, crumbles','PORK,GROUND,84% LN / 16% FAT,CKD,CRUMBLES',10975,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, ground, 96% lean / 4% fat, cooked, crumbles','PORK,GROUND,96% LN / 4% FAT,CKD,CRUMBLES',10976,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, ground, 72% lean / 28% fat, cooked, pan-broiled','PORK,GROUND,72% LN / 28% FAT,CKD,PAN-BROILED',10977,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, ground, 84% lean / 16% fat, cooked, pan-broiled','PORK,GROUND,84% LN / 16% FAT,CKD,PAN-BROILED',10978,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, ground, 96% lean / 4% fat, cooked, pan-broiled','PORK,GROUND,96% LN / 4% FAT,CKD,PAN-BROILED',10979,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork loin, fresh, backribs, bone-in, raw, lean only','PORK LOIN,FRSH,BACKRIBS,BONE-IN,RAW,LN',10980,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork loin, fresh, backribs, bone-in, cooked-roasted, lean only','PORK LOIN,FRSH,BACKRIBS,BONE-IN,COOKED-ROASTED,LN',10981,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, blade (chops or roasts), boneless, separable lean only, raw','PORK,FRSH,LOIN,BLADE (CHOPS OR ROASTS),BNLESS,LN,RAW',10982,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, blade (roasts), boneless, separable lean only, cooked, roasted','PORK,FRSH,LOIN,BLADE (ROASTS),BNLESS,LN,CKD,RSTD',10983,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, blade (chops), boneless, separable lean only, boneless, cooked, broiled','PORK,FRSH,LOIN,BLADE (CHOPS),BNLESS,LN,BNLESS,CKD,BRLD',10984,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, country-style ribs, separable lean only, boneless, cooked, broiled','PORK,FRSH,LOIN,COUNTRY-STYLE RIBS,LN,BNLESS,CKD,BRLD',10985,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, country-style ribs, separable lean only, bone-in, cooked, broiled','PORK,FRSH,LOIN,COUNTRY-STYLE RIBS,LN,BONE-IN,CKD,BRLD',10986,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, country-style ribs, separable lean only, boneless, cooked, roasted','PORK,FRSH,LOIN,COUNTRY-STYLE RIBS,LN,BNLESS,CKD,RSTD',10987,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, blade, (chops), boneless, separable lean and fat, cooked, broiled','PORK,FRSH,BLADE,(CHOPS),BNLESS,LN & FAT,CKD,BRLD',10988,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, blade (chops or roasts), boneless, separable lean and fat only, raw','PORK,FRSH,LOIN,BLDE (CHOPS OR ROAST),BNLESS,LN & FAT OLY,RAW',10989,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, blade (roasts), boneless, separable lean and fat, cooked, roasted','PORK,FRSH,LOIN,BLADE (ROASTS),BNLESS,LN & FAT,CKD,RSTD',10990,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, country-style ribs, separable lean and fat, boneless, cooked, broiled','PORK,FRSH,LOIN,COUNTRY-STYLE RIBS,LN & FAT,BNLESS,CKD,BRLD',10991,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, country-style ribs, separable lean and fat, bone-in, cooked, broiled','PORK,FRSH,LOIN,COUNTRY-STYLE RIBS,LN & FAT,BONE-IN,CKD,BRLD',10992,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, fresh, loin, country-style ribs, separable lean and fat, boneless, cooked, roasted','PORK,FRSH,LOIN,COUNTRY-STYLE RIBS,LN & FAT,BNLESS,CKD,RSTD',10993,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Canadian bacon, cooked, pan-fried','CANADIAN BACON,CKD,PAN-FRIED',10998,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Alfalfa seeds, sprouted, raw','ALFALFA SEEDS,SPROUTED,RAW',11001,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Amaranth leaves, raw','AMARANTH LEAVES,RAW',11003,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Amaranth leaves, cooked, boiled, drained, without salt','AMARANTH LEAVES,CKD,BLD,DRND,WO/SALT',11004,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Artichokes, (globe or french), raw','ARTICHOKES,(GLOBE OR FRENCH),RAW',11007,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Artichokes, (globe or french), cooked, boiled, drained, without salt','ARTICHOKES,(GLOBE OR FRENCH),CKD,BLD,DRND,WO/SALT',11008,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Artichokes, (globe or french), frozen, unprepared','ARTICHOKES,(GLOBE OR FRENCH),FRZ,UNPREP',11009,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Artichokes, (globe or french), frozen, cooked, boiled, drained, without salt','ARTICHOKES,(GLOBE OR FRENCH),FRZ,CKD,BLD,DRND,WO/SALT',11010,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Asparagus, raw','ASPARAGUS,RAW',11011,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Asparagus, cooked, boiled, drained','ASPARAGUS,CKD,BLD,DRND',11012,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Asparagus, canned, regular pack, solids and liquids','ASPARAGUS,CND,REG PK,SOL&LIQUIDS',11013,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Asparagus, canned, drained solids','ASPARAGUS,CND,DRND SOL',11015,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Asparagus, frozen, unprepared','ASPARAGUS,FRZ,UNPREP',11018,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Asparagus, frozen, cooked, boiled, drained, without salt','ASPARAGUS,FRZ,CKD,BLD,DRND,WO/SALT',11019,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Balsam-pear (bitter gourd), leafy tips, cooked, boiled, drained, without salt','BALSAM-PEAR (BITTER GOURD),LEAFY TIPS,CKD,BLD,DRND,WO/SALT',11023,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Balsam-pear (bitter gourd), pods, cooked, boiled, drained, without salt','BALSAM-PEAR (BITTER GOURD),PODS,CKD,BLD,DRND,WO/SALT',11025,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Bamboo shoots, raw','BAMBOO SHOOTS,RAW',11026,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Bamboo shoots, cooked, boiled, drained, without salt','BAMBOO SHOOTS,CKD,BLD,DRND,WO/SALT',11027,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Bamboo shoots, canned, drained solids','BAMBOO SHOOTS,CND,DRND SOL',11028,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, kidney, mature seeds, sprouted, raw','BEANS,KIDNEY,MATURE SEEDS,SPROUTED,RAW',11029,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, kidney, mature seeds, sprouted, cooked, boiled, drained, without salt','BEANS,KIDNEY,MATURE SEEDS,SPROUTED,CKD,BLD,DRND,WO/SALT',11030,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lima beans, immature seeds, raw','LIMA BNS,IMMAT SEEDS,RAW',11031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lima beans, immature seeds, cooked, boiled, drained, without salt','LIMA BNS,IMMAT SEEDS,CKD,BLD,DRND,WO/SALT',11032,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lima beans, immature seeds, canned, regular pack, solids and liquids','LIMA BNS,IMMAT SEEDS,CND,REG PK,SOL & LIQUIDS',11033,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lima beans, immature seeds, frozen, fordhook, unprepared','LIMA BNS,IMMAT SEEDS,FRZ,FORDHOOK,UNPREP',11037,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lima beans, immature seeds, frozen, fordhook, cooked, boiled, drained, without salt','LIMA BNS,IMMAT SEEDS,FRZ,FORDHOOK,CKD,BLD,DRND,WO/SALT',11038,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lima beans, immature seeds, frozen, baby, unprepared','LIMA BNS,IMMAT SEEDS,FRZ,BABY,UNPREP',11039,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lima beans, immature seeds, frozen, baby, cooked, boiled, drained, without salt','LIMA BNS,IMMAT SEEDS,FRZ,BABY,CKD,BLD,DRND,WO/SALT',11040,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mung beans, mature seeds, sprouted, raw','MUNG BNS,MATURE SEEDS,SPROUTED,RAW',11043,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mung beans, mature seeds, sprouted, cooked, boiled, drained, without salt','MUNG BNS,MATURE SEEDS,SPROUTED,CKD,BLD,DRND,WO/SALT',11044,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mung beans, mature seeds, sprouted, cooked, stir-fried','MUNG BNS,MATURE SEEDS,SPROUTED,CKD,STIR-FRIED',11045,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, navy, mature seeds, sprouted, raw','BEANS,NAVY,MATURE SEEDS,SPROUTED,RAW',11046,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, navy, mature seeds, sprouted, cooked, boiled, drained, without salt','BEANS,NAVY,MATURE SEEDS,SPROUTED,CKD,BLD,DRND,WO/SALT',11047,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, pinto, immature seeds, frozen, unprepared','BEANS,PINTO,IMMAT SEEDS,FRZ,UNPREP',11048,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, pinto, immature seeds, frozen, cooked, boiled, drained, without salt','BEANS,PINTO,IMMAT SEEDS,FRZ,CKD,BLD,DRND,WO/SALT',11049,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, shellie, canned, solids and liquids','BEANS,SHELLIE,CND,SOL & LIQUIDS',11050,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, green, raw','BEANS,SNAP,GREEN,RAW',11052,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, green, cooked, boiled, drained, without salt','BEANS,SNAP,GRN,CKD,BLD,DRND,WO/SALT',11053,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, green, canned, regular pack, solids and liquids','BEANS,SNAP,GRN,CND,REG PK,SOL & LIQUIDS',11054,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, green, canned, regular pack, drained solids','BEANS,SNAP,GRN,CND,REG PK,DRND SOL',11056,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, canned, all styles, seasoned, solids and liquids','BEANS,SNAP,CND,ALL STYLES,SEASONED,SOL&LIQUIDS',11058,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, green, frozen, all styles, unprepared (Includes foods for USDA''s Food Distribution Program)','BEANS,SNAP,GRN,FRZ,ALL STYLES,UNPREP',11060,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, green, frozen, cooked, boiled, drained without salt','BEANS,SNAP,GRN,FRZ,CKD,BLD,DRND WO/SALT',11061,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, green, frozen, all styles, microwaved','BEANS,SNAP,GRN,FRZ,ALL STYLES,MICROWAVED',11062,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beets, raw','BEETS,RAW',11080,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beets, cooked, boiled, drained','BEETS,CKD,BLD,DRND',11081,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beets, canned, regular pack, solids and liquids','BEETS,CND,REG PK,SOL&LIQUIDS',11082,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beets, canned, drained solids','BEETS,CND,DRND SOL',11084,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beet greens, raw','BEET GREENS,RAW',11086,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beet greens, cooked, boiled, drained, without salt','BEET GRNS,CKD,BLD,DRND,WO/SALT',11087,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broadbeans, immature seeds, raw','BROADBEANS,IMMAT SEEDS,RAW',11088,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broadbeans, immature seeds, cooked, boiled, drained, without salt','BROADBEANS,IMMAT SEEDS,CKD,BLD,DRND,WO/SALT',11089,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli, raw','BROCCOLI,RAW',11090,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli, cooked, boiled, drained, without salt','BROCCOLI,CKD,BLD,DRND,WO/SALT',11091,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli, frozen, chopped, unprepared','BROCCOLI,FRZ,CHOPD,UNPREP',11092,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli, frozen, chopped, cooked, boiled, drained, without salt','BROCCOLI,FRZ,CHOPD,CKD,BLD,DRND,WO/SALT',11093,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli, frozen, spears, unprepared (Includes foods for USDA''s Food Distribution Program)','BROCCOLI,FRZ,SPEARS,UNPREP',11094,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli, frozen, spears, cooked, boiled, drained, without salt','BROCCOLI,FRZ,SPEARS,CKD,BLD,DRND,WO/SALT',11095,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli raab, raw','BROCCOLI RAAB,RAW',11096,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli raab, cooked','BROCCOLI RAAB,CKD',11097,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Brussels sprouts, raw','BRUSSELS SPROUTS,RAW',11098,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Brussels sprouts, cooked, boiled, drained, without salt','BRUSSELS SPROUTS,CKD,BLD,DRND,WO/SALT',11099,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Brussels sprouts, frozen, unprepared','BRUSSELS SPROUTS,FRZ,UNPREP',11100,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Brussels sprouts, frozen, cooked, boiled, drained, without salt','BRUSSELS SPROUTS,FRZ,CKD,BLD,DRND,WO/SALT',11101,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Burdock root, raw','BURDOCK ROOT,RAW',11104,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Burdock root, cooked, boiled, drained, without salt','BURDOCK ROOT,CKD,BLD,DRND,WO/SALT',11105,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, raw','CABBAGE,RAW',11109,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, cooked, boiled, drained, without salt','CABBAGE,CKD,BLD,DRND,WO/SALT',11110,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, red, raw','CABBAGE,RED,RAW',11112,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, red, cooked, boiled, drained, without salt','CABBAGE,RED,CKD,BLD,DRND,WO/SALT',11113,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, savoy, raw','CABBAGE,SAVOY,RAW',11114,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, savoy, cooked, boiled, drained, without salt','CABBAGE,SAVOY,CKD,BLD,DRND,WO/SALT',11115,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, chinese (pak-choi), raw','CABBAGE,CHINESE (PAK-CHOI),RAW',11116,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, chinese (pak-choi), cooked, boiled, drained, without salt','CABBAGE,CHINESE (PAK-CHOI),CKD,BLD,DRND,WO/SALT',11117,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, kimchi','CABBAGE,KIMCHI',11118,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, chinese (pe-tsai), raw','CABBAGE,CHINESE (PE-TSAI),RAW',11119,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, chinese (pe-tsai), cooked, boiled, drained, without salt','CABBAGE,CHINESE (PE-TSAI),CKD,BLD,DRND,WO/SALT',11120,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cardoon, raw','CARDOON,RAW',11122,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cardoon, cooked, boiled, drained, without salt','CARDOON,CKD,BLD,DRND,WO/SALT',11123,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Carrots, raw','CARROTS,RAW',11124,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Carrots, cooked, boiled, drained, without salt','CARROTS,CKD,BLD,DRND,WO/SALT',11125,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Carrots, canned, regular pack, solids and liquids','CARROTS,CND,REG PK,SOL&LIQUIDS',11126,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Carrots, canned, regular pack, drained solids','CARROTS,CND,REG PK,DRND SOL',11128,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Carrots, frozen, unprepared (Includes foods for USDA''s Food Distribution Program)','CARROTS,FROZEN,UNPREPARED',11130,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Carrots, frozen, cooked, boiled, drained, without salt','CARROTS,FRZ,CKD,BLD,DRND,WO/SALT',11131,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cassava, raw','CASSAVA,RAW',11134,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cauliflower, raw','CAULIFLOWER,RAW',11135,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cauliflower, cooked, boiled, drained, without salt','CAULIFLOWER,CKD,BLD,DRND,WO/SALT',11136,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cauliflower, frozen, unprepared','CAULIFLOWER,FRZ,UNPREP',11137,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cauliflower, frozen, cooked, boiled, drained, without salt','CAULIFLOWER,FRZ,CKD,BLD,DRND,WO/SALT',11138,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Celeriac, raw','CELERIAC,RAW',11141,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Celery, raw','CELERY,RAW',11143,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Celery, cooked, boiled, drained, without salt','CELERY,CKD,BLD,DRND,WO/SALT',11144,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Chard, swiss, raw','CHARD,SWISS,RAW',11147,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Chard, swiss, cooked, boiled, drained, without salt','CHARD,SWISS,CKD,BLD,DRND,WO/SALT',11148,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Chayote, fruit, raw','CHAYOTE,FRUIT,RAW',11149,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Chayote, fruit, cooked, boiled, drained, without salt','CHAYOTE,FRUIT,CKD,BLD,DRND,WO/SALT',11150,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Chicory, witloof, raw','CHICORY,WITLOOF,RAW',11151,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Chicory greens, raw','CHICORY GREENS,RAW',11152,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Chicory roots, raw','CHICORY ROOTS,RAW',11154,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Chives, raw','CHIVES,RAW',11156,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Chrysanthemum, garland, cooked, boiled, drained, without salt','CHRYSANTHEMUM,GARLAND,CKD,BLD,DRND,WO/SALT',11158,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Collards, raw','COLLARDS,RAW',11161,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Collards, cooked, boiled, drained, without salt','COLLARDS,CKD,BLD,DRND,WO/SALT',11162,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Collards, frozen, chopped, unprepared','COLLARDS,FRZ,CHOPD,UNPREP',11163,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Collards, frozen, chopped, cooked, boiled, drained, without salt','COLLARDS,FRZ,CHOPD,CKD,BLD,DRND,WO/SALT',11164,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Coriander (cilantro) leaves, raw','CORIANDER (CILANTRO) LEAVES,RAW',11165,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, raw','CORN,SWT,YEL,RAW',11167,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, cooked, boiled, drained, without salt','CORN,SWT,YEL,CKD,BLD,DRND,WO/SALT',11168,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, canned, brine pack, regular pack, solids and liquids','CORN,SWT,YEL,CND,BRINE PK,REG PK,SOL&LIQUIDS',11170,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, canned, whole kernel, drained solids','CORN,SWT,YEL,CND,WHL KERNEL,DRND SOL',11172,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, canned, cream style, regular pack','CORN,SWT,YEL,CND,CRM STYLE,REG PK',11174,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, canned, vacuum pack, regular pack','CORN,SWT,YEL,CND,VACUUM PK,REG PK',11176,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, canned, drained solids, rinsed with tap water','CORN,SWT,YEL,CND,DRND SOL,RINSED W/ TAP H2O',11177,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, frozen, kernels cut off cob, unprepared (Includes foods for USDA''s Food Distribution Program)','CORN,SWT,YEL,FRZ,KRNLS CUT OFF COB,UNPREP',11178,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, frozen, kernels cut off cob, boiled, drained, without salt','CORN,SWT,YEL,FRZ,KRNLS CUT OFF COB,BLD,DRND,WO/SALT',11179,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, frozen, kernels on cob, unprepared','CORN,SWT,YEL,FRZ,KRNLS ON COB,UNPREP',11180,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, frozen, kernels on cob, cooked, boiled, drained, without salt','CORN,SWT,YEL,FRZ,KRNLS ON COB,CKD,BLD,DRND,WO/SALT',11181,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, yellow, whole kernel, frozen, microwaved','CORN,YEL,WHL KERNEL,FRZ,MICROWAVED',11182,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn with red and green peppers, canned, solids and liquids','CORN W/RED&GRN PEPPERS,CND,SOL&LIQUIDS',11184,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cowpeas (blackeyes), immature seeds, raw','COWPEAS (BLACKEYES),IMMAT SEEDS,RAW',11191,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cowpeas (blackeyes), immature seeds, cooked, boiled, drained, without salt','COWPEAS (BLACKEYES),IMMAT SEEDS,CKD,BLD,DRND,WO/ SALT',11192,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cowpeas (blackeyes), immature seeds, frozen, unprepared','COWPEAS (BLACKEYES),IMMAT SEEDS,FRZ,UNPREP',11195,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cowpeas (blackeyes), immature seeds, frozen, cooked, boiled, drained, without salt','COWPEAS (BLACKEYES),IMMTRE SEEDS,FRZ,CKD,BLD,DRND,WO/SALT',11196,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cowpeas, young pods with seeds, raw','COWPEAS,YOUNG PODS W/SEEDS,RAW',11197,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cowpeas, young pods with seeds, cooked, boiled, drained, without salt','COWPEAS,YOUNG PODS W/SEEDS,CKD,BLD,DRND,WO/SALT',11198,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Yardlong bean, raw','YARDLONG BEAN,RAW',11199,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Yardlong bean, cooked, boiled, drained, without salt','YARDLONG BEAN,CKD,BLD,DRND,WO/SALT',11200,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cowpeas, leafy tips, raw','COWPEAS,LEAFY TIPS,RAW',11201,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cowpeas, leafy tips, cooked, boiled, drained, without salt','COWPEAS,LEAFY TIPS,CKD,BLD,DRND,WO/SALT',11202,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cress, garden, raw','CRESS,GARDEN,RAW',11203,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cress, garden, cooked, boiled, drained, without salt','CRESS,GARDEN,CKD,BLD,DRND,WO/SALT',11204,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cucumber, with peel, raw','CUCUMBER,WITH PEEL,RAW',11205,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cucumber, peeled, raw','CUCUMBER,PEELED,RAW',11206,NULL,NULL,NULL,NULL,NULL,1,'1995-06-27','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Dandelion greens, raw','DANDELION GREENS,RAW',11207,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Dandelion greens, cooked, boiled, drained, without salt','DANDELION GRNS,CKD,BLD,DRND,WO/SALT',11208,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Eggplant, raw','EGGPLANT,RAW',11209,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Eggplant, cooked, boiled, drained, without salt','EGGPLANT,CKD,BLD,DRND,WO/SALT',11210,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Edamame, frozen, prepared','EDAMAME,FRZ,PREP',11212,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Endive, raw','ENDIVE,RAW',11213,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Escarole, cooked, boiled, drained, no salt added','ESCAROLE,CKD,BLD,DRND,NO SALT ADDED',11214,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Garlic, raw','GARLIC,RAW',11215,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Ginger root, raw','GINGER ROOT,RAW',11216,NULL,NULL,NULL,NULL,NULL,1,'1995-06-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Gourd, white-flowered (calabash), raw','GOURD,WHITE-FLOWERED (CALABASH),RAW',11218,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Gourd, white-flowered (calabash), cooked, boiled, drained, without salt','GOURD,WHITE-FLOWERED (CALABASH),CKD,BLD,DRND,WO/SALT',11219,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Gourd, dishcloth (towelgourd), raw','GOURD,DISHCLOTH (TOWELGOURD),RAW',11220,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Gourd, dishcloth (towelgourd), cooked, boiled, drained, without salt','GOURD,DISHCLOTH (TOWELGOURD),CKD,BLD,DRND,WO/SALT',11221,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Drumstick leaves, cooked, boiled, drained, without salt','DRUMSTICK LEAVES,CKD,BLD,DRND,WO/ SALT',11223,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Hyacinth-beans, immature seeds, raw','HYACINTH-BEANS,IMMAT SEEDS,RAW',11224,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Hyacinth-beans, immature seeds, cooked, boiled, drained, without salt','HYACINTH-BEANS,IMMAT SEEDS,CKD,BLD,DRND,WO/SALT',11225,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Jerusalem-artichokes, raw','JERUSALEM-ARTICHOKES,RAW',11226,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Jute, potherb, raw','JUTE,POTHERB,RAW',11231,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Jute, potherb, cooked, boiled, drained, without salt','JUTE,POTHERB,CKD,BLD,DRND,WO/SALT',11232,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Kale, raw','KALE,RAW',11233,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Kale, cooked, boiled, drained, without salt','KALE,CKD,BLD,DRND,WO/SALT',11234,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Kale, frozen, unprepared','KALE,FROZEN,UNPREPARED',11235,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Kale, frozen, cooked, boiled, drained, without salt','KALE,FRZ,CKD,BLD,DRND,WO/SALT',11236,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Kanpyo, (dried gourd strips)','KANPYO,(DRIED GOURD STRIPS)',11237,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, morel, raw','MUSHROOMS,MOREL,RAW',11240,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Kohlrabi, raw','KOHLRABI,RAW',11241,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Kohlrabi, cooked, boiled, drained, without salt','KOHLRABI,CKD,BLD,DRND,WO/SALT',11242,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, portabella, grilled','MUSHROOMS,PORTABELLA,GRILLED',11243,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lambsquarters, raw','LAMBSQUARTERS,RAW',11244,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lambsquarters, cooked, boiled, drained, without salt','LAMBSQUARTERS,CKD,BLD,DRND,WO/SALT',11245,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Leeks, (bulb and lower leaf-portion), raw','LEEKS,(BULB&LOWER LEAF-PORTION),RAW',11246,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Leeks, (bulb and lower leaf-portion), cooked, boiled, drained, without salt','LEEKS,(BULB&LOWER LEAF-PORTION),CKD,BLD,DRND,WO/SALT',11247,NULL,NULL,NULL,NULL,NULL,1,'1998-03-27','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lentils, sprouted, raw','LENTILS,SPROUTED,RAW',11248,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lentils, sprouted, cooked, stir-fried, without salt','LENTILS,SPROUTED,CKD,STIR-FRIED,WO/SALT',11249,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lettuce, butterhead (includes boston and bibb types), raw','LETTUCE,BUTTERHEAD (INCL BOSTON&BIBB TYPES),RAW',11250,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lettuce, cos or romaine, raw','LETTUCE,COS OR ROMAINE,RAW',11251,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lettuce, iceberg (includes crisphead types), raw','LETTUCE,ICEBERG (INCL CRISPHEAD TYPES),RAW',11252,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lettuce, green leaf, raw','LETTUCE,GRN LEAF,RAW',11253,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lotus root, raw','LOTUS ROOT,RAW',11254,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lotus root, cooked, boiled, drained, without salt','LOTUS ROOT,CKD,BLD,DRND,WO/SALT',11255,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lettuce, red leaf, raw','LETTUCE,RED LEAF,RAW',11257,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mountain yam, hawaii, raw','MOUNTAIN YAM,HAWAII,RAW',11258,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mountain yam, hawaii, cooked, steamed, without salt','MOUNTAIN YAM,HAWAII,CKD,STMD,WO/SALT',11259,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, white, raw','MUSHROOMS,WHITE,RAW',11260,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, white, cooked, boiled, drained, without salt','MUSHROOMS,WHITE,CKD,BLD,DRND,WO/ SALT',11261,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, white, stir-fried','MUSHROOMS,WHITE,STIR-FRIED',11263,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, canned, drained solids','MUSHROOMS,CND,DRND SOL',11264,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, portabella, raw','MUSHROOMS,PORTABELLA,RAW',11265,NULL,NULL,NULL,NULL,NULL,1,'2002-06-08','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, brown, Italian, or Crimini, raw','MUSHROOMS,BROWN,ITALIAN,OR CRIMINI,RAW',11266,NULL,NULL,NULL,NULL,NULL,1,'2002-06-08','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, shiitake, stir-fried','MUSHROOMS,SHIITAKE,STIR-FRIED',11267,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, shiitake, dried','MUSHROOMS,SHIITAKE,DRIED',11268,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, shiitake, cooked, without salt','MUSHROOMS,SHIITAKE,CKD,WO/SALT',11269,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mustard greens, raw','MUSTARD GREENS,RAW',11270,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mustard greens, cooked, boiled, drained, without salt','MUSTARD GRNS,CKD,BLD,DRND,WO/SALT',11271,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mustard greens, frozen, unprepared','MUSTARD GRNS,FRZ,UNPREP',11272,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mustard greens, frozen, cooked, boiled, drained, without salt','MUSTARD GRNS,FRZ,CKD,BLD,DRND,WO/SALT',11273,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mustard spinach, (tendergreen), raw','MUSTARD SPINACH,(TENDERGREEN),RAW',11274,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'New Zealand spinach, raw','NEW ZEALAND SPINACH,RAW',11276,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'New Zealand spinach, cooked, boiled, drained, without salt','NEW ZEALAND SPINACH,CKD,BLD,DRND,WO/SALT',11277,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Okra, raw','OKRA,RAW',11278,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Okra, cooked, boiled, drained, without salt','OKRA,CKD,BLD,DRND,WO/SALT',11279,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Okra, frozen, unprepared','OKRA,FROZEN,UNPREPARED',11280,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Okra, frozen, cooked, boiled, drained, without salt','OKRA,FRZ,CKD,BLD,DRND,WO/SALT',11281,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onions, raw','ONIONS,RAW',11282,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onions, cooked, boiled, drained, without salt','ONIONS,CKD,BLD,DRND,WO/SALT',11283,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onions, dehydrated flakes','ONIONS,DEHYDRATED FLAKES',11284,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onions, canned, solids and liquids','ONIONS,CND,SOL&LIQUIDS',11285,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onions, yellow, sauteed','ONIONS,YEL,SAUTEED',11286,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onions, frozen, chopped, unprepared','ONIONS,FRZ,CHOPD,UNPREP',11287,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onions, frozen, chopped, cooked, boiled, drained, without salt','ONIONS,FRZ,CHOPD,CKD,BLD,DRND,WO/SALT',11288,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onions, frozen, whole, unprepared','ONIONS,FRZ,WHL,UNPREP',11289,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onions, frozen, whole, cooked, boiled, drained, without salt','ONIONS,FRZ,WHL,CKD,BLD,DRND,WO/SALT',11290,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onions, spring or scallions (includes tops and bulb), raw','ONIONS,SPRING OR SCALLIONS (INCL TOPS&BULB),RAW',11291,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onions, young green, tops only','ONIONS,YOUNG GRN,TOPS ONLY',11292,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onions, welsh, raw','ONIONS,WELSH,RAW',11293,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onion rings, breaded, par fried, frozen, unprepared','ONION RINGS,BREADED,PAR FR,FRZ,UNPREP',11295,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onion rings, breaded, par fried, frozen, prepared, heated in oven','ONION RINGS,BREADED,PAR FR,FRZ,PREP,HTD IN OVEN',11296,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Parsley, fresh','PARSLEY,FRSH',11297,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Parsnips, raw','PARSNIPS,RAW',11298,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Parsnips, cooked, boiled, drained, without salt','PARSNIPS,CKD,BLD,DRND,WO/SALT',11299,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, edible-podded, raw','PEAS,EDIBLE-PODDED,RAW',11300,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, edible-podded, boiled, drained, without salt','PEAS,EDIBLE-PODDED,BLD,DRND,WO/ SALT',11301,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, edible-podded, frozen, unprepared','PEAS,EDIBLE-PODDED,FRZ,UNPREP',11302,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, edible-podded, frozen, cooked, boiled, drained, without salt','PEAS,EDIBLE-PODDED,FRZ,CKD,BLD,DRND,WO/SALT',11303,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, green, raw','PEAS,GREEN,RAW',11304,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, green, cooked, boiled, drained, without salt','PEAS,GRN,CKD,BLD,DRND,WO/SALT',11305,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, green, canned, regular pack, solids and liquids','PEAS,GRN,CND,REG PK,SOL&LIQUIDS',11306,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, green (includes baby and lesuer types), canned, drained solids, unprepared','PEAS,GRN (INCLUDES BABY & LESUER TYPES),CND,DRND SOL,UNPREP',11308,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, green, canned, seasoned, solids and liquids','PEAS,GRN,CND,SEASONED,SOL&LIQUIDS',11310,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, green, canned, drained solids, rinsed in tap water','PEAS,GRN,CND,DRND SOL,RINSED IN TAP H2O',11311,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, green, frozen, unprepared (Includes foods for USDA''s Food Distribution Program)','PEAS,GRN,FRZ,UNPREP',11312,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, green, frozen, cooked, boiled, drained, without salt','PEAS,GRN,FRZ,CKD,BLD,DRND,WO/SALT',11313,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, mature seeds, sprouted, raw','PEAS,MATURE SEEDS,SPROUTED,RAW',11316,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, mature seeds, sprouted, cooked, boiled, drained, without salt','PEAS,MATURE SEEDS,SPROUTED,CKD,BLD,DRND,WO/SALT',11317,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas and carrots, canned, regular pack, solids and liquids','PEAS&CARROTS,CND,REG PK,SOL&LIQUIDS',11318,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas and carrots, frozen, unprepared','PEAS&CARROTS,FRZ,UNPREP',11322,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas and carrots, frozen, cooked, boiled, drained, without salt','PEAS&CARROTS,FRZ,CKD,BLD,DRND,WO/SALT',11323,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas and onions, canned, solids and liquids','PEAS&ONIONS,CND,SOL&LIQUIDS',11324,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas and onions, frozen, unprepared','PEAS&ONIONS,FRZ,UNPREP',11326,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas and onions, frozen, cooked, boiled, drained, without salt','PEAS&ONIONS,FRZ,CKD,BLD,DRND,WO/SALT',11327,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, hot chili, green, canned, pods, excluding seeds, solids and liquids','PEPPERS,HOT CHILI,GRN,CND,PODS,EXCLUDING SEEDS,SOL&LIQUIDS',11329,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, green, raw','PEPPERS,SWT,GRN,RAW',11333,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, green, cooked, boiled, drained, without salt','PEPPERS,SWT,GRN,CKD,BLD,DRND,WO/SALT',11334,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, green, canned, solids and liquids','PEPPERS,SWT,GRN,CND,SOL&LIQUIDS',11335,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, green, frozen, chopped, unprepared','PEPPERS,SWT,GRN,FRZ,CHOPD,UNPREP',11337,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, green, frozen, chopped, boiled, drained, without salt','PEPPERS,SWT,GRN,FRZ,CHOPD,BLD,DRND,WO/SALT',11338,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, green, sauteed','PEPPERS,SWT,GRN,SAUTEED',11339,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pigeonpeas, immature seeds, raw','PIGEONPEAS,IMMAT SEEDS,RAW',11344,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pigeonpeas, immature seeds, cooked, boiled, drained, without salt','PIGEONPEAS,IMMAT SEEDS,CKD,BLD,DRND,WO/SALT',11345,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Poi','POI',11349,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pokeberry shoots, (poke), cooked, boiled, drained, without salt','POKEBERRY SHOOTS,(POKE),CKD,BLD,DRND,WO/SALT',11351,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, flesh and skin, raw','POTATOES,FLESH & SKN,RAW',11352,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, russet, flesh and skin, raw (Includes foods for USDA''s Food Distribution Program)','POTATOES,RUSSET,FLESH & SKN,RAW',11353,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, white, flesh and skin, raw','POTATOES,WHITE,FLESH & SKN,RAW',11354,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, red, flesh and skin, raw','POTATOES,RED,FLESH & SKN,RAW',11355,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, Russet, flesh and skin, baked','POTATOES,RUSSET,FLESH & SKN,BKD',11356,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, white, flesh and skin, baked','POTATOES,WHITE,FLESH & SKN,BKD',11357,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, red, flesh and skin, baked','POTATOES,RED,FLESH & SKN,BKD',11358,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, french fried, crinkle or regular cut, salt added in processing, frozen, as purchased','POTATOES,FR FR,CRNKL OR REG,SALT ADDED IN PROC,FRZ,AS PURCH',11359,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, french fried, crinkle or regular cut, salt added in processing, frozen, oven-heated','POTATOES,FR FR,CRNKL/REG CUT,SALT ADDED IN PROC,FRZ,OVEN-HTD',11360,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, roasted, salt added in processing, frozen, unprepared','POTATOES,RSTD,SALT ADDED IN PROCESSING,FRZ,UNPREP',11361,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, raw, skin','POTATOES,RAW,SKIN',11362,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, baked, flesh, without salt','POTATOES,BKD,FLESH,WO/SALT',11363,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, baked, skin, without salt','POTATOES,BKD,SKN,WO/SALT',11364,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, boiled, cooked in skin, flesh, without salt','POTATOES,BLD,CKD IN SKN,FLESH,WO/SALT',11365,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, boiled, cooked in skin, skin, without salt','POTATOES,BLD,CKD IN SKN,SKN,WO/SALT',11366,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, boiled, cooked without skin, flesh, without salt','POTATOES,BLD,CKD WO/ SKN,FLESH,WO/ SALT',11367,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, microwaved, cooked in skin, flesh, without salt','POTATOES,MICROWAVED,CKD IN SKN,FLESH,WO/SALT',11368,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, microwaved, cooked in skin, skin, without salt','POTATOES,MICROWAVED,CKD IN SKN,SKN,WO/SALT',11369,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, hash brown, home-prepared','POTATOES,HASH BROWN,HOME-PREPARED',11370,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, mashed, home-prepared, whole milk and margarine added','POTATOES,MSHD,HOME-PREPARED,WHL MILK & MARGARINE ADDED',11371,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, scalloped, home-prepared with butter','POTATOES,SCALLPD,HOME-PREPARED W/BUTTER',11372,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, au gratin, home-prepared from recipe using butter','POTATOES,AU GRATIN,HOME-PREPARED FROM RECIPE USING BUTTER',11373,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, canned, solids and liquids','POTATOES,CND,SOL&LIQUIDS',11374,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, canned, drained solids','POTATOES,CND,DRND SOL',11376,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, mashed, dehydrated, flakes without milk, dry form','POTATOES,MSHD,DEHYD,FLAKES WO/MILK,DRY FORM',11378,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2007-03-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, mashed, dehydrated, prepared from flakes without milk, whole milk and butter added','POTATOES,MSHD,DEHYD,PREP FROM FLAKES WO/ MILK,WHL MILK & BUT',11379,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, mashed, dehydrated, granules without milk, dry form','POTATOES,MSHD,DEHYD,GRANULES WO/MILK,DRY FORM',11380,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, mashed, dehydrated, prepared from granules without milk, whole milk and butter added','POTATOES,MSHD,DEHYD,PREP FR GRNLS WO/MILK,WHL MILK&BUTTER',11381,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, mashed, dehydrated, granules with milk, dry form','POTATOES,MSHD,DEHYD,GRANULES W/MILK,DRY FORM',11382,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, mashed, dehydrated, prepared from granules with milk, water and margarine added','POTATOES,MSHD,DEHYD,PREP FROM GRAN W/ MILK,H2O & MARG ADDED',11383,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, au gratin, dry mix, unprepared','POTATOES,AU GRATIN,DRY MIX,UNPREP',11384,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, au gratin, dry mix, prepared with water, whole milk and butter','POTATOES,AU GRATIN,DRY MIX,PREP W/H2O,WHL MILK&BUTTER',11385,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, scalloped, dry mix, unprepared','POTATOES,SCALLPD,DRY MIX,UNPREP',11386,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, scalloped, dry mix, prepared with water, whole milk and butter','POTATOES,SCALLPD,DRY MIX,PREP W/H2O,WHL MILK&BUTTER',11387,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, hash brown, frozen, plain, unprepared','POTATOES,HASH BROWN,FRZ,PLN,UNPREP',11390,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, hash brown, frozen, plain, prepared, pan fried in canola oil','POTATOES,HASH BROWN,FRZ,PLN,PREP,PAN FRIED IN CANOLA OIL',11391,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, hash brown, frozen, with butter sauce, unprepared','POTATOES,HASH BROWN,FRZ,W/ BUTTER SAU,UNPREP',11392,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, hash brown, frozen, with butter sauce, prepared','POTATOES,HASH BROWN,FRZ,W/ BUTTER SAU,PREP',11393,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, french fried, shoestring, salt added in processing, frozen, as purchased','POTATOES,FRENCH FR,SHOESTRING,SALT ADDED IN PROC,FRZ,AS PRCH',11394,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, french fried, shoestring, salt added in processing, frozen, oven-heated','POTATOES,FRENCH FR,SHOESTRNG,SALT ADDED IN PROC,FRZ,OVEN-HTD',11395,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, o''brien, frozen, unprepared','POTATOES,O''BRIEN,FRZ,UNPREP',11396,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, o''brien, frozen, prepared','POTATOES,O''BRIEN,FRZ,PREP',11397,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potato puffs, frozen, unprepared','POTATO PUFFS,FRZ,UNPREP',11398,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potato puffs, frozen, oven-heated','POTATO PUFFS,FRZ,OVEN-HEATED',11399,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, frozen, whole, cooked, boiled, drained, without salt','POTATOES,FRZ,WHL,CKD,BLD,DRND,WO/SALT',11401,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, french fried, all types, salt added in processing, frozen, unprepared','POTATOES,FRENCH FR,ALL TYPES,SALT ADDED IN PROC,FRZ,UNPREP',11402,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, french fried, all types, salt added in processing, frozen, home-prepared, oven heated','POTATOES,FRENCH FR,ALL TYPES,SALT ADDED IN PROC,FRZ,OVEN HTD',11403,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, french fried, cottage-cut, salt not added in processing, frozen, as purchased','POTATOES,FRNCH FR,CTTG-CUT,SALT NOT ADDED,FRZ,AS PRCH',11406,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, french fried, cottage-cut, salt not added in processing, frozen, oven-heated','POTATOES,FRENCH FR,COTTAGE-CUT,SALT NOT ADDED,FRZ,OVEN-HTD',11407,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, frozen, french fried, par fried, extruded, unprepared','POTATOES,FRZ,FRENCH FR,PAR FR,EXTRUDED,UNPREP',11408,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, frozen, french fried, par fried, extruded, prepared, heated in oven, without salt','POTATOES,FRZ,FRCH FR,PAR FR,EXTRUDED,PREP,HTD OVEN,WO/SALT',11409,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potato wedges, frozen (Includes foods for USDA''s Food Distribution Program)','POTATO WEDGES,FRZ (INCL FOODS FOR USDA''S FD DISTR PGM)',11410,NULL,NULL,NULL,NULL,NULL,1,'1999-06-18','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, french fried, steak fries, salt added in processing, frozen, as purchased','POTATOES,FRENCH FR,STK FRIES,SALT ADDED IN PROC,FRZ,AS PRCH',11411,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, french fried, steak fries, salt added in processing, frozen, oven-heated','POTATOES,FRENCH FR,STK FRIES,SALT ADDED IN PROC,FRZ,OVEN-HTD',11412,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potato flour','POTATO FLOUR',11413,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potato salad, home-prepared','POTATO SALAD,HOME-PREPARED',11414,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pumpkin flowers, raw','PUMPKIN FLOWERS,RAW',11416,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pumpkin flowers, cooked, boiled, drained, without salt','PUMPKIN FLOWERS,CKD,BLD,DRND,WO/SALT',11417,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pumpkin leaves, raw','PUMPKIN LEAVES,RAW',11418,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pumpkin leaves, cooked, boiled, drained, without salt','PUMPKIN LEAVES,CKD,BLD,DRND,WO/SALT',11419,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pumpkin, raw','PUMPKIN,RAW',11422,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pumpkin, cooked, boiled, drained, without salt','PUMPKIN,CKD,BLD,DRND,WO/SALT',11423,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pumpkin, canned, without salt','PUMPKIN,CND,WO/SALT',11424,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pumpkin pie mix, canned','PUMPKIN PIE MIX,CANNED',11426,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Radishes, raw','RADISHES,RAW',11429,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Radishes, oriental, raw','RADISHES,ORIENTAL,RAW',11430,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Radishes, oriental, cooked, boiled, drained, without salt','RADISHES,ORIENTAL,CKD,BLD,DRND,WO/SALT',11431,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Radishes, oriental, dried','RADISHES,ORIENTAL,DRIED',11432,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Rutabagas, raw','RUTABAGAS,RAW',11435,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Rutabagas, cooked, boiled, drained, without salt','RUTABAGAS,CKD,BLD,DRND,WO/SALT',11436,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Salsify, cooked, boiled, drained, without salt','SALSIFY,CKD,BLD,DRND,WO/SALT',11438,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sauerkraut, canned, solids and liquids','SAUERKRAUT,CND,SOL&LIQUIDS',11439,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Seaweed, agar, raw','SEAWEED,AGAR,RAW',11442,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Seaweed, irishmoss, raw','SEAWEED,IRISHMOSS,RAW',11444,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Seaweed, kelp, raw','SEAWEED,KELP,RAW',11445,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Seaweed, laver, raw','SEAWEED,LAVER,RAW',11446,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Soybeans, green, raw','SOYBEANS,GREEN,RAW',11450,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Soybeans, green, cooked, boiled, drained, without salt','SOYBEANS,GRN,CKD,BLD,DRND,WO/SALT',11451,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Soybeans, mature seeds, sprouted, raw','SOYBEANS,MATURE SEEDS,SPROUTED,RAW',11452,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Soybeans, mature seeds, sprouted, cooked, steamed','SOYBEANS,MATURE SEEDS,SPROUTED,CKD,STMD',11453,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Soybeans, mature seeds, sprouted, cooked, stir-fried','SOYBEANS,MATURE SEEDS,SPROUTED,CKD,STIR-FRIED',11454,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Spinach, raw','SPINACH,RAW',11457,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Spinach, cooked, boiled, drained, without salt','SPINACH,CKD,BLD,DRND,WO/ SALT',11458,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Spinach, canned, regular pack, solids and liquids','SPINACH,CND,REG PK,SOL&LIQUIDS',11459,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Spinach, canned, regular pack, drained solids','SPINACH,CND,REG PK,DRND SOL',11461,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Spinach, frozen, chopped or leaf, unprepared (Includes foods for USDA''s Food Distribution Program)','SPINACH,FRZ,CHOPD OR LEAF,UNPREP',11463,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Spinach, frozen, chopped or leaf, cooked, boiled, drained, without salt','SPINACH,FRZ,CHOPD OR LEAF,CKD,BLD,DRND,WO/SALT',11464,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, crookneck and straightneck, raw','SQUASH,SMMR,CROOKNECK&STRAIGHTNECK,RAW',11467,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, crookneck and straightneck, cooked, boiled, drained, without salt','SQUASH,SMMR,CROOKNECK & STRAIGHTNECK,CKD,BLD,DRND,WO/ SALT',11468,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, crookneck and straightneck, canned, drained, solid, without salt','SQUASH,SMMR,CROOKNECK&STRAIGHTNECK,CND,DRND,SOLID,WO/SALT',11471,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, crookneck and straightneck, frozen, unprepared','SQUASH,SMMR,CROOKNECK&STRAIGHTNECK,FRZ,UNPREP',11473,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, crookneck and straightneck, frozen, cooked, boiled, drained, without salt','SQUASH,SMMR,CROOKNECK&STRAIGHTNECK,FRZ,CKD,BLD,DRND,WO/SALT',11474,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, scallop, raw','SQUASH,SUMMER,SCALLOP,RAW',11475,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, scallop, cooked, boiled, drained, without salt','SQUASH,SMMR,SCALLOP,CKD,BLD,DRND,WO/SALT',11476,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, zucchini, includes skin, raw','SQUASH,SMMR,ZUCCHINI,INCL SKN,RAW',11477,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, zucchini, includes skin, cooked, boiled, drained, without salt','SQUASH,SMMR,ZUCCHINI,INCL SKN,CKD,BLD,DRND,WO/SALT',11478,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, zucchini, includes skin, frozen, unprepared','SQUASH,SMMR,ZUCCHINI,INCL SKN,FRZ,UNPREP',11479,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, zucchini, includes skin, frozen, cooked, boiled, drained, without salt','SQUASH,SMMR,ZUCCHINI,INCL SKN,FRZ,CKD,BLD,DRND,WO/SALT',11480,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, zucchini, italian style, canned','SQUASH,SMMR,ZUCCHINI,ITALIAN STYLE,CND',11481,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, acorn, raw','SQUASH,WINTER,ACORN,RAW',11482,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, acorn, cooked, baked, without salt','SQUASH,WNTR,ACORN,CKD,BKD,WO/SALT',11483,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, acorn, cooked, boiled, mashed, without salt','SQUASH,WNTR,ACORN,CKD,BLD,MSHD,WO/SALT',11484,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, butternut, raw','SQUASH,WNTR,BUTTERNUT,RAW',11485,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, butternut, cooked, baked, without salt','SQUASH,WNTR,BUTTERNUT,CKD,BKD,WO/SALT',11486,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, butternut, frozen, unprepared','SQUASH,WNTR,BUTTERNUT,FRZ,UNPREP',11487,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, butternut, frozen, cooked, boiled, without salt','SQUASH,WNTR,BUTTERNUT,FRZ,CKD,BLD,WO/SALT',11488,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, hubbard, raw','SQUASH,WINTER,HUBBARD,RAW',11489,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, hubbard, baked, without salt','SQUASH,WNTR,HUBBARD,BKD,WO/ SALT',11490,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, hubbard, cooked, boiled, mashed, without salt','SQUASH,WNTR,HUBBARD,CKD,BLD,MSHD,WO/SALT',11491,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, spaghetti, raw','SQUASH,WNTR,SPAGHETTI,RAW',11492,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, spaghetti, cooked, boiled, drained, or baked, without salt','SQUASH,WNTR,SPAGHETTI,CKD,BLD,DRND,OR BKD,WO/SALT',11493,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Succotash, (corn and limas), raw','SUCCOTASH,(CORN&LIMAS),RAW',11495,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Succotash, (corn and limas), cooked, boiled, drained, without salt','SUCCOTASH,(CORN&LIMAS),CKD,BLD,DRND,WO/SALT',11496,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Succotash, (corn and limas), canned, with cream style corn','SUCCOTASH,(CORN&LIMAS),CND,W/CRM STYLE CORN',11497,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Succotash, (corn and limas), canned, with whole kernel corn, solids and liquids','SUCCOTASH,(CORN&LIMAS),CND,W/WHL KERNEL CORN,SOL&LIQUIDS',11499,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Succotash, (corn and limas), frozen, unprepared','SUCCOTASH,(CORN&LIMAS),FRZ,UNPREP',11501,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Succotash, (corn and limas), frozen, cooked, boiled, drained, without salt','SUCCOTASH,(CORN&LIMAS),FRZ,CKD,BLD,DRND,WO/SALT',11502,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Water convolvulus, cooked, boiled, drained, without salt','SWAMP CABBAGE (SKUNK CABBAGE),CKD,BLD,DRND,WO/ SALT',11504,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato leaves, raw','SWEET POTATO LEAVES,RAW',11505,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato leaves, cooked, steamed, without salt','SWEET POTATO LEAVES,CKD,STMD,WO/ SALT',11506,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato, raw, unprepared (Includes foods for USDA''s Food Distribution Program)','SWEET POTATO,RAW,UNPREP',11507,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato, cooked, baked in skin, flesh, without salt','SWEET POTATO,CKD,BKD IN SKN,FLESH,WO/ SALT',11508,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato, cooked, boiled, without skin','SWEET POTATO,CKD,BLD,WO/ SKN',11510,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato, canned, vacuum pack','SWEETPOTATO,CND,VACUUM PK',11512,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato, canned, mashed','SWEET POTATO,CND,MSHD',11514,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato, frozen, unprepared (Includes foods for USDA''s Food Distribution Program)','SWEET POTATO,FRZ,UNPREP',11516,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato, frozen, cooked, baked, without salt','SWEET POTATO,FRZ,CKD,BKD,WO/ SALT',11517,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Taro, raw','TARO,RAW',11518,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Taro, cooked, without salt','TARO,COOKED,WITHOUT SALT',11519,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Taro leaves, raw','TARO LEAVES,RAW',11520,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Taro leaves, cooked, steamed, without salt','TARO LEAVES,CKD,STMD,WO/SALT',11521,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Taro shoots, raw','TARO SHOOTS,RAW',11522,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Taro shoots, cooked, without salt','TARO SHOOTS,CKD,WO/SALT',11523,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Taro, tahitian, raw','TARO,TAHITIAN,RAW',11525,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Taro, tahitian, cooked, without salt','TARO,TAHITIAN,CKD,WO/SALT',11526,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomatoes, green, raw','TOMATOES,GREEN,RAW',11527,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomatoes, red, ripe, raw, year round average','TOMATOES,RED,RIPE,RAW,YEAR RND AVERAGE',11529,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomatoes, red, ripe, cooked','TOMATOES,RED,RIPE,CKD',11530,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomatoes, red, ripe, canned, packed in tomato juice','TOMATOES,RED,RIPE,CND,PACKED IN TOMATO JUC',11531,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomatoes, red, ripe, canned, stewed','TOMATOES,RED,RIPE,CND,STWD',11533,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomatoes, red, ripe, canned, with green chilies','TOMATOES,RED,RIPE,CND,W/GRN CHILIES',11537,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato juice, canned, with salt added','TOMATO JUC,CND,W/SALT',11540,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato products, canned, paste, without salt added (Includes foods for USDA''s Food Distribution Program)','TOMATO PRODUCTS,CND,PASTE,WO/ SALT ADDED',11546,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato products, canned, puree, without salt added','TOMATO PRODUCTS,CND,PUREE,WO/SALT',11547,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato powder','TOMATO POWDER',11548,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato products, canned, sauce','TOMATO PRODUCTS,CND,SAU',11549,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato products, canned, sauce, with mushrooms','TOMATO PRODUCTS,CND,SAU,W/MUSHROOMS',11551,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato products, canned, sauce, with onions','TOMATO PRODUCTS,CND,SAU,W/ONIONS',11553,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato products, canned, sauce, with herbs and cheese','TOMATO PRODUCTS,CND,SAU,W/HERBS&CHS',11555,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato products, canned, sauce, with onions, green peppers, and celery','TOMATO PRODUCTS,CND,SAU,W/ONIONS,GRN PEPPERS,&CELERY',11557,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato products, canned, sauce, with tomato tidbits','TOMATO PRODUCTS,CND,SAU,W/TOMATO TIDBITS',11559,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tree fern, cooked, without salt','TREE FERN,CKD,WO/SALT',11563,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnips, raw','TURNIPS,RAW',11564,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnips, cooked, boiled, drained, without salt','TURNIPS,CKD,BLD,DRND,WO/SALT',11565,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnips, frozen, unprepared','TURNIPS,FROZEN,UNPREPARED',11566,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnips, frozen, cooked, boiled, drained, without salt','TURNIPS,FRZ,CKD,BLD,DRND,WO/SALT',11567,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnip greens, raw','TURNIP GREENS,RAW',11568,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnip greens, cooked, boiled, drained, without salt','TURNIP GRNS,CKD,BLD,DRND,WO/SALT',11569,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnip greens, canned, solids and liquids','TURNIP GRNS,CND,SOL&LIQUIDS',11570,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnip greens, frozen, unprepared','TURNIP GRNS,FRZ,UNPREP',11574,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnip greens, frozen, cooked, boiled, drained, without salt','TURNIP GRNS,FRZ,CKD,BLD,DRND,WO/SALT',11575,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnip greens and turnips, frozen, unprepared','TURNIP GRNS&TURNIPS,FRZ,UNPREP',11576,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnip greens and turnips, frozen, cooked, boiled, drained, without salt','TURNIP GRNS&TURNIPS,FRZ,CKD,BLD,DRND,WO/SALT',11577,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Vegetable juice cocktail, canned','VEGETABLE JUC COCKTAIL,CND',11578,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Vegetables, mixed, canned, solids and liquids','VEGETABLES,MXD,CND,SOL&LIQUIDS',11579,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Vegetables, mixed, canned, drained solids','VEGETABLES,MXD,CND,DRND SOL',11581,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Vegetables, mixed, frozen, unprepared','VEGETABLES,MXD,FRZ,UNPREP',11583,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Vegetables, mixed, frozen, cooked, boiled, drained, without salt','VEGETABLES,MXD,FRZ,CKD,BLD,DRND,WO/SALT',11584,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Vegetable juice cocktail, low sodium, canned','VEGETABLE JUC COCKTAIL,LO NA,CND',11585,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Waterchestnuts, chinese, (matai), raw','WATERCHESTNUTS,CHINESE,(MATAI),RAW',11588,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Waterchestnuts, chinese, canned, solids and liquids','WATERCHESTNUTS,CHINESE,CND,SOL&LIQUIDS',11590,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Watercress, raw','WATERCRESS,RAW',11591,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Waxgourd, (chinese preserving melon), raw','WAXGOURD,(CHINESE PRESERVING MELON),RAW',11593,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Waxgourd, (chinese preserving melon), cooked, boiled, drained, without salt','WAXGOURD,(CHINESE PRESERVING MELON),CKD,BLD,DRND,WO/SALT',11594,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Winged beans, immature seeds, raw','WINGED BNS,IMMAT SEEDS,RAW',11595,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Winged beans, immature seeds, cooked, boiled, drained, without salt','WINGED BNS,IMMAT SEEDS,CKD,BLD,DRND,WO/SALT',11596,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Winged bean leaves, raw','WINGED BEAN LEAVES,RAW',11597,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Winged bean tuber, raw','WINGED BEAN TUBER,RAW',11599,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Yam, raw','YAM,RAW',11601,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Yam, cooked, boiled, drained, or baked, without salt','YAM,CKD,BLD,DRND,OR BKD,WO/SALT',11602,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Yambean (jicama), raw','YAMBEAN (JICAMA),RAW',11603,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beets, harvard, canned, solids and liquids','BEETS,HARVARD,CND,SOL&LIQUIDS',11605,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beets, pickled, canned, solids and liquids','BEETS,PICKLED,CND,SOL&LIQUIDS',11609,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Borage, raw','BORAGE,RAW',11613,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Borage, cooked, boiled, drained, without salt','BORAGE,CKD,BLD,DRND,WO/SALT',11614,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Chives, freeze-dried','CHIVES,FREEZE-DRIED',11615,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Drumstick pods, raw','DRUMSTICK PODS,RAW',11620,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Drumstick pods, cooked, boiled, drained, without salt','DRUMSTICK PODS,CKD,BLD,DRND,WO/ SALT',11621,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Leeks, (bulb and lower-leaf portion), freeze-dried','LEEKS,(BULB&LOWER-LEAF PORTION),FREEZE-DRIED',11624,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, mung, mature seeds, sprouted, canned, drained solids','BEANS,MUNG,MATURE SEEDS,SPROUTED,CND,DRND SOL',11626,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, jalapeno, canned, solids and liquids','PEPPERS,JALAPENO,CND,SOL&LIQUIDS',11632,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Radishes, white icicle, raw','RADISHES,WHITE ICICLE,RAW',11637,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Shallots, freeze-dried','SHALLOTS,FREEZE-DRIED',11640,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, all varieties, raw','SQUASH,SMMR,ALL VAR,RAW',11641,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, all varieties, cooked, boiled, drained, without salt','SQUASH,SMMR,ALL VAR,CKD,BLD,DRND,WO/SALT',11642,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, all varieties, raw','SQUASH,WNTR,ALL VAR,RAW',11643,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, all varieties, cooked, baked, without salt','SQUASH,WNTR,ALL VAR,CKD,BKD,WO/SALT',11644,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato, canned, syrup pack, solids and liquids','SWEET POTATO,CND,SYRUP PK,SOL & LIQUIDS',11645,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato, canned, syrup pack, drained solids','SWEET POTATO,CND,SYRUP PK,DRND SOL',11647,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato products, canned, sauce, spanish style','TOMATO PRODUCTS,CND,SAU,SPANISH STYLE',11649,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, pinto, mature seeds, sprouted, raw','BEANS,PINTO,MATURE SEEDS,SPROUTED,RAW',11653,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, pinto, mature seeds, sprouted, cooked, boiled, drained, without salt','BEANS,PINTO,MATURE SEEDS,SPROUTED,CKD,BLD,DRND,WO/SALT',11654,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Carrot juice, canned','CARROT JUICE,CANNED',11655,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn pudding, home prepared','CORN PUDD,HOME PREP',11656,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, mashed, home-prepared, whole milk added','POTATOES,MSHD,HOME-PREPARED,WHL MILK ADDED',11657,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Spinach souffle','SPINACH SOUFFLE',11658,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato, cooked, candied, home-prepared','SWEET POTATO,CKD,CANDIED,HOME-PREPARED',11659,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomatoes, red, ripe, cooked, stewed','TOMATOES,RED,RIPE,CKD,STWD',11660,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Seaweed, agar, dried','SEAWEED,AGAR,DRIED',11663,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Seaweed, spirulina, raw','SEAWEED,SPIRULINA,RAW',11666,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Seaweed, spirulina, dried','SEAWEED,SPIRULINA,DRIED',11667,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Seaweed, wakame, raw','SEAWEED,WAKAME,RAW',11669,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, hot chili, green, raw','PEPPERS,HOT CHILI,GRN,RAW',11670,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, o''brien, home-prepared','POTATOES,O''BRIEN,HOME-PREPARED',11671,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potato pancakes','POTATO PANCAKES',11672,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, baked, flesh and skin, without salt','POTATOES,BKD,FLESH & SKN,WO/ SALT',11674,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, microwaved, cooked in skin, flesh and skin, without salt','POTATOES,MICROWAVED,CKD IN SKN,FLESH&SKN,WO/SALT',11675,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Radish seeds, sprouted, raw','RADISH SEEDS,SPROUTED,RAW',11676,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Shallots, raw','SHALLOTS,RAW',11677,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Carrot, dehydrated','CARROT,DEHYDRATED',11683,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomatoes, crushed, canned','TOMATOES,CRUSHED,CANNED',11693,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomatoes, orange, raw','TOMATOES,ORANGE,RAW',11695,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomatoes, yellow, raw','TOMATOES,YELLOW,RAW',11696,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Arrowroot, raw','ARROWROOT,RAW',11697,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Amaranth leaves, cooked, boiled, drained, with salt','AMARANTH LEAVES,CKD,BLD,DRND,W/SALT',11700,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Artichokes, (globe or french), cooked, boiled, drained, with salt','ARTICHOKES,(GLOBE OR FRENCH),CKD,BLD,DRND,W/SALT',11702,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Artichokes, (globe or french), frozen, cooked, boiled, drained, with salt','ARTICHOKES,(GLOBE OR FRENCH),FRZ,CKD,BLD,DRND,W/SALT',11703,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Asparagus, cooked, boiled, drained, with salt','ASPARAGUS,CKD,BLD,DRND,W/SALT',11705,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Asparagus, canned, no salt added, solids and liquids','ASPARAGUS,CND,NO SALT,SOL&LIQUIDS',11707,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Asparagus, frozen, cooked, boiled, drained, with salt','ASPARAGUS,FRZ,CKD,BLD,DRND,W/SALT',11709,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Bamboo shoots, cooked, boiled, drained, with salt','BAMBOO SHOOTS,CKD,BLD,DRND,W/SALT',11712,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, kidney, mature seeds, sprouted, cooked, boiled, drained, with salt','BEANS,KIDNEY,MATURE SEEDS,SPROUTED,CKD,BLD,DRND,W/SALT',11713,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lima beans, immature seeds, cooked, boiled, drained, with salt','LIMA BNS,IMMAT SEEDS,CKD,BLD,DRND,W/SALT',11714,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lima beans, immature seeds, canned, no salt added, solids and liquids','LIMA BNS,IMMAT SEEDS,CND,NO SALT,SOL&LIQUIDS',11715,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lima beans, immature seeds, frozen, baby, cooked, boiled, drained, with salt','LIMA BNS,IMMAT SEEDS,FRZ,BABY,CKD,BLD,DRND,W/SALT',11716,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lima beans, immature seeds, frozen, fordhook, cooked, boiled, drained, with salt','LIMA BNS,IMMAT SEEDS,FRZ,FORDHOOK,CKD,BLD,DRND,W/SALT',11717,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mung beans, mature seeds, sprouted, cooked, boiled, drained, with salt','MUNG BNS,MATURE SEEDS,SPROUTED,CKD,BLD,DRND,W/SALT',11718,NULL,NULL,NULL,NULL,NULL,1,'1994-03-16','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, navy, mature seeds, sprouted, cooked, boiled, drained, with salt','BEANS,NAVY,MATURE SEEDS,SPROUTED,CKD,BLD,DRND,W/SALT',11719,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, pinto, immature seeds, frozen, cooked, boiled, drained, with salt','BEANS,PINTO,IMMAT SEEDS,FRZ,CKD,BLD,DRND,W/SALT',11720,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, pinto, mature seeds, sprouted, cooked, boiled, drained, with salt','BEANS,PINTO,MATURE SEEDS,SPROUTED,CKD,BLD,DRND,W/SALT',11721,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, yellow, raw','BEANS,SNAP,YELLOW,RAW',11722,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, green, cooked, boiled, drained, with salt','BEANS,SNAP,GRN,CKD,BLD,DRND,W/SALT',11723,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, yellow, cooked, boiled, drained, without salt','BEANS,SNAP,YEL,CKD,BLD,DRND,WO/SALT',11724,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, yellow, cooked, boiled, drained, with salt','BEANS,SNAP,YEL,CKD,BLD,DRND,W/SALT',11725,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, green, canned, no salt added, solids and liquids','BEANS,SNAP,GRN,CND,NO SALT,SOL&LIQUIDS',11726,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, yellow, canned, regular pack, solids and liquids','BEANS,SNAP,YEL,CND,REG PK,SOL&LIQUIDS',11727,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, yellow, canned, no salt added, solids and liquids','BEANS,SNAP,YEL,CND,NO SALT,SOL&LIQUIDS',11728,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, green, canned, no salt added, drained solids','BEANS,SNAP,GRN,CND,NO SALT,DRND SOL',11729,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, yellow, frozen, all styles, unprepared','BEANS,SNAP,YEL,FRZ,ALL STYLES,UNPREP',11730,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, green, frozen, cooked, boiled, drained, with salt','BEANS,SNAP,GRN,FRZ,CKD,BLD,DRND,W/SALT',11731,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, yellow, frozen, cooked, boiled, drained, without salt','BEANS,SNAP,YEL,FRZ,CKD,BLD,DRND,WO/SALT',11732,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, yellow, frozen, cooked, boiled, drained, with salt','BEANS,SNAP,YEL,FRZ,CKD,BLD,DRND,W/SALT',11733,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beets, cooked, boiled. drained, with salt','BEETS,CKD,BOILED. DRND,W/SALT',11734,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beets, canned, no salt added, solids and liquids','BEETS,CND,NO SALT,SOL&LIQUIDS',11735,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beet greens, cooked, boiled, drained, with salt','BEET GRNS,CKD,BLD,DRND,W/SALT',11736,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Borage, cooked, boiled, drained, with salt','BORAGE,CKD,BLD,DRND,W/SALT',11737,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broadbeans, immature seeds, cooked, boiled, drained, with salt','BROADBEANS,IMMAT SEEDS,CKD,BLD,DRND,W/SALT',11738,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli, leaves, raw','BROCCOLI,LEAVES,RAW',11739,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli, flower clusters, raw','BROCCOLI,FLOWER CLUSTERS,RAW',11740,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli, stalks, raw','BROCCOLI,STALKS,RAW',11741,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli, cooked, boiled, drained, with salt','BROCCOLI,CKD,BLD,DRND,W/SALT',11742,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli, frozen, chopped, cooked, boiled, drained, with salt','BROCCOLI,FRZ,CHOPD,CKD,BLD,DRND,W/SALT',11743,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli, frozen, spears, cooked, boiled, drained, with salt','BROCCOLI,FRZ,SPEARS,CKD,BLD,DRND,W/SALT',11744,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Brussels sprouts, cooked, boiled, drained, with salt','BRUSSELS SPROUTS,CKD,BLD,DRND,W/SALT',11745,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Brussels sprouts, frozen, cooked, boiled, drained, with salt','BRUSSELS SPROUTS,FRZ,CKD,BLD,DRND,W/SALT',11746,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, common (danish, domestic, and pointed types), freshly harvest, raw','CABBAGE,COMMON,FRESHLY HARVEST,RAW',11749,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, common (danish, domestic, and pointed types), stored, raw','CABBAGE,COMMON (DANISH,DOMESTIC,&POINTED TYPES),STORED,RAW',11750,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, common, cooked, boiled, drained, with salt','CABBAGE,COMMON,CKD,BLD,DRND,W/SALT',11751,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, red, cooked, boiled, drained, with salt','CABBAGE,RED,CKD,BLD,DRND,W/SALT',11752,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, savoy, cooked, boiled, drained, with salt','CABBAGE,SAVOY,CKD,BLD,DRND,W/SALT',11753,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, chinese (pak-choi), cooked, boiled, drained, with salt','CABBAGE,CHINESE (PAK-CHOI),CKD,BLD,DRND,W/SALT',11754,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, chinese (pe-tsai), cooked, boiled, drained, with salt','CABBAGE,CHINESE (PE-TSAI),CKD,BLD,DRND,W/SALT',11755,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cardoon, cooked, boiled, drained, with salt','CARDOON,CKD,BLD,DRND,W/SALT',11756,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Carrots, cooked, boiled, drained, with salt','CARROTS,CKD,BLD,DRND,W/SALT',11757,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Carrots, canned, no salt added, solids and liquids','CARROTS,CND,NO SALT,SOL&LIQUIDS',11758,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Carrots, canned, no salt added, drained solids','CARROTS,CND,NO SALT ,DRND SOL',11759,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Carrots, frozen, cooked, boiled, drained, with salt','CARROTS,FRZ,CKD,BLD,DRND,W/SALT',11760,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cauliflower, cooked, boiled, drained, with salt','CAULIFLOWER,CKD,BLD,DRND,W/SALT',11761,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cauliflower, frozen, cooked, boiled, drained, with salt','CAULIFLOWER,FRZ,CKD,BLD,DRND,W/SALT',11762,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Celery, cooked, boiled, drained, with salt','CELERY,CKD,BLD,DRND,W/SALT',11764,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Chayote, fruit, cooked, boiled, drained, with salt','CHAYOTE,FRUIT,CKD,BLD,DRND,W/SALT',11766,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Collards, cooked, boiled, drained, with salt','COLLARDS,CKD,BLD,DRND,W/SALT',11768,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Collards, frozen, chopped, cooked, boiled, drained, with salt','COLLARDS,FRZ,CHOPD,CKD,BLD,DRND,W/SALT',11769,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, cooked, boiled, drained, with salt','CORN,SWT,YEL,CKD,BLD,DRND,W/SALT',11770,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, canned, no salt added, solids and liquids (Includes foods for USDA''s Food Distribution Program)','CORN,SWT,YEL,CND,NO SALT,SOL&LIQUIDS',11771,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, canned, cream style, no salt added','CORN,SWT,YEL,CND,CRM STYLE,NO SALT',11772,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, canned, vacuum pack, no salt added','CORN,SWT,YEL,CND,VACUUM PK,NO SALT',11773,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, frozen, kernels, cut off cob, boiled, drained, with salt','CORN,SWT,YEL,FRZ,KRNLS,CUT OFF COB,BLD,DRND,W/SALT',11774,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, yellow, frozen, kernels on cob, cooked, boiled, drained, with salt','CORN,SWT,YEL,FRZ,KRNLS ON COB,CKD,BLD,DRND,W/SALT',11775,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cowpeas (blackeyes), immature seeds, cooked, boiled, drained, with salt','COWPEAS (BLACKEYES),IMMAT SEEDS,CKD,BLD,DRND,W/ SALT',11777,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cowpeas (blackeyes), immature seeds, frozen, cooked, boiled, drained, with salt','COWPEAS (BLACKEYES),IMMAT SEEDS,FRZ,CKD,BLD,DRND,W/ SALT',11778,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cowpeas, young pods with seeds, cooked, boiled, drained, with salt','COWPEAS,YOUNG PODS W/SEEDS,CKD,BLD,DRND,W/SALT',11779,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cowpeas, leafy tips, cooked, boiled, drained, with salt','COWPEAS,LEAFY TIPS,CKD,BLD,DRND,W/SALT',11780,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cress, garden, cooked, boiled, drained, with salt','CRESS,GARDEN,CKD,BLD,DRND,W/SALT',11781,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Eggplant, cooked, boiled, drained, with salt','EGGPLANT,CKD,BLD,DRND,W/SALT',11783,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Gourd, white-flowered (calabash), cooked, boiled, drained, with salt','GOURD,WHITE-FLOWERED (CALABASH),CKD,BLD,DRND,W/SALT',11784,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Gourd, dishcloth (towelgourd), cooked, boiled, drained, with salt','GOURD,DISHCLOTH (TOWELGOURD),CKD,BLD,DRND,W/SALT',11785,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Hyacinth-beans, immature seeds, cooked, boiled, drained, with salt','HYACINTH-BEANS,IMMAT SEEDS,CKD,BLD,DRND,W/SALT',11788,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Jute, potherb, cooked, boiled, drained, with salt','JUTE,POTHERB,CKD,BLD,DRND,W/SALT',11789,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Kale, cooked, boiled, drained, with salt','KALE,CKD,BLD,DRND,W/ SALT',11790,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Kale, frozen, cooked, boiled, drained, with salt','KALE,FRZ,CKD,BLD,DRND,W/SALT',11791,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Kohlrabi, cooked, boiled, drained, with salt','KOHLRABI,CKD,BLD,DRND,W/SALT',11793,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lambsquarters, cooked, boiled, drained, with salt','LAMBSQUARTERS,CKD,BLD,DRND,W/ SALT',11794,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Leeks, (bulb and lower leaf-portion), cooked, boiled, drained, with salt','LEEKS,(BULB&LOWER LEAF-PORTION),CKD,BLD,DRND,W/SALT',11795,NULL,NULL,NULL,NULL,NULL,1,'1998-03-27','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lotus root, cooked, boiled, drained, with salt','LOTUS ROOT,CKD,BLD,DRND,W/SALT',11796,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, white, cooked, boiled, drained, with salt','MUSHROOMS,WHITE,CKD,BLD,DRND,W/ SALT',11797,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, shiitake, cooked, with salt','MUSHROOMS,SHIITAKE,CKD,W/SALT',11798,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mustard greens, cooked, boiled, drained, with salt','MUSTARD GRNS,CKD,BLD,DRND,W/SALT',11799,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mustard greens, frozen, cooked, boiled, drained, with salt','MUSTARD GRNS,FRZ,CKD,BLD,DRND,W/SALT',11800,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'New zealand spinach, cooked, boiled, drained, with salt','NEW ZEALAND SPINACH,CKD,BLD,DRND,W/SALT',11802,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Okra, cooked, boiled, drained, with salt','OKRA,CKD,BLD,DRND,W/SALT',11803,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Okra, frozen, cooked, boiled, drained, with salt','OKRA,FRZ,CKD,BLD,DRND,W/ SALT',11804,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onions, cooked, boiled, drained, with salt','ONIONS,CKD,BLD,DRND,W/SALT',11805,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onions, frozen, chopped, cooked, boiled, drained, with salt','ONIONS,FRZ,CHOPD,CKD,BLD,DRND,W/SALT',11806,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Onions, frozen, whole, cooked, boiled, drained, with salt','ONIONS,FRZ,WHL,CKD,BLD,DRND,W/SALT',11807,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Parsnips, cooked, boiled, drained, with salt','PARSNIPS,CKD,BLD,DRND,W/SALT',11808,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, edible-podded, cooked, boiled, drained, with salt','PEAS,EDIBLE-PODDED,CKD,BLD,DRND,W/SALT',11809,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, edible-podded, frozen, cooked, boiled, drained, with salt','PEAS,EDIBLE-PODDED,FRZ,CKD,BLD,DRND,W/SALT',11810,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, green, cooked, boiled, drained, with salt','PEAS,GRN,CKD,BLD,DRND,W/SALT',11811,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, green, canned, no salt added, solids and liquids','PEAS,GRN,CND,NO SALT,SOL&LIQUIDS',11812,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, green, canned, no salt added, drained solids','PEAS,GRN,CND,NO SALT,DRND SOL',11813,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, green, frozen, cooked, boiled, drained, with salt','PEAS,GRN,FRZ,CKD,BLD,DRND,W/SALT',11814,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas, mature seeds, sprouted, cooked, boiled, drained, with salt','PEAS,MATURE SEEDS,SPROUTED,CKD,BLD,DRND,W/SALT',11815,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas and carrots, canned, no salt added, solids and liquids','PEAS&CARROTS,CND,NO SALT,SOL&LIQUIDS',11816,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas and carrots, frozen, cooked, boiled, drained, with salt','PEAS&CARROTS,FRZ,CKD,BLD,DRND,W/SALT',11817,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peas and onions, frozen, cooked, boiled, drained, with salt','PEAS&ONIONS,FRZ,CKD,BLD,DRND,W/SALT',11818,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, hot chili, red, raw','PEPPERS,HOT CHILI,RED,RAW',11819,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, hot chili, red, canned, excluding seeds, solids and liquids','PEPPERS,HOT CHILI,RED,CND,EXCLUDING SEEDS,SOL&LIQUIDS',11820,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, red, raw','PEPPERS,SWT,RED,RAW',11821,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, green, cooked, boiled, drained, with salt','PEPPERS,SWT,GRN,CKD,BLD,DRND,W/SALT',11822,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, red, cooked, boiled, drained, without salt','PEPPERS,SWT,RED,CKD,BLD,DRND,WO/SALT',11823,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, red, cooked, boiled, drained, with salt','PEPPERS,SWT,RED,CKD,BLD,DRND,W/SALT',11824,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, green, frozen, chopped, cooked, boiled, drained, with salt','PEPPERS,SWT,GRN,FRZ,CHOPD,CKD,BLD,DRND,W/SALT',11825,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pigeonpeas, immature seeds, cooked, boiled, drained, with salt','PIGEONPEAS,IMMAT SEEDS,CKD,BLD,DRND,W/SALT',11826,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, baked, flesh and skin, with salt','POTATOES,BKD,FLESH & SKN,W/ SALT',11828,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, baked, flesh, with salt','POTATOES,BKD,FLESH,W/SALT',11829,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, baked, skin only, with salt','POTATOES,BKD,SKN ONLY,W/ SALT',11830,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, boiled, cooked in skin, flesh, with salt','POTATOES,BLD,CKD IN SKN,FLESH,W/SALT',11831,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, boiled, cooked in skin, skin, with salt','POTATOES,BLD,CKD IN SKN,SKN,W/SALT',11832,NULL,NULL,NULL,NULL,NULL,1,'1994-09-21','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, boiled, cooked without skin, flesh, with salt','POTATOES,BLD,CKD WO/ SKN,FLESH,W/ SALT',11833,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, microwaved, cooked, in skin, flesh and skin, with salt','POTATOES,MICROWAVED,CKD,IN SKN,FLESH&SKN,W/SALT',11834,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, microwaved, cooked in skin, flesh, with salt','POTATOES,MICROWAVED,CKD IN SKN,FLESH,W/SALT',11835,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, microwaved, cooked, in skin, skin with salt','POTATOES,MICROWAVED,CKD,IN SKN,SKN W/SALT',11836,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, frozen, whole, cooked, boiled, drained, with salt','POTATOES,FRZ,WHL,CKD,BLD,DRND,W/SALT',11837,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, frozen, french fried, par fried, cottage-cut, prepared, heated in oven, with salt','POTATOES,FRZ,FRCH FR,PAR FR,CTTGE-CUT,PREP,HTD OVEN,W/SALT',11840,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, french fried, all types, salt not added in processing, frozen, oven-heated','POTATOES,FR FR,ALL TYPES,SALT NOT ADDED IN PROC,FRZ,OVN-HTD',11841,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, french fried, all types, salt not added in processing, frozen, as purchased','POTATOES,FR FR,ALL TYPES,SALT NOT ADDED IN PROC,FRZ,AS PURCH',11842,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, au gratin, home-prepared from recipe using margarine','POTATOES,AU GRATIN,HOME-PREPARED FROM RECIPE USING MARGARINE',11843,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, scalloped, home-prepared with margarine','POTATOES,SCALLPD,HOME-PREPARED W/MARGARINE',11844,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pumpkin, cooked, boiled, drained, with salt','PUMPKIN,CKD,BLD,DRND,W/SALT',11845,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pumpkin, canned, with salt','PUMPKIN,CANNED,WITH SALT',11846,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pumpkin, flowers, cooked, boiled, drained, with salt','PUMPKIN,FLOWERS,CKD,BLD,DRND,W/SALT',11847,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pumpkin leaves, cooked, boiled, drained, with salt','PUMPKIN LEAVES,CKD,BLD,DRND,W/ SALT',11848,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Radishes, oriental, cooked, boiled, drained, with salt','RADISHES,ORIENTAL,CKD,BLD,DRND,W/SALT',11850,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Rutabagas, cooked, boiled, drained, with salt','RUTABAGAS,CKD,BLD,DRND,W/SALT',11851,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Soybeans, green, cooked, boiled, drained, with salt','SOYBEANS,GRN,CKD,BLD,DRND,W/SALT',11853,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Spinach, cooked, boiled, drained, with salt','SPINACH,CKD,BLD,DRND,W/SALT',11854,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Spinach, canned, no salt added, solids and liquids','SPINACH,CND,NO SALT,SOL&LIQUIDS',11855,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Spinach, frozen, chopped or leaf, cooked, boiled, drained, with salt','SPINACH,FRZ,CHOPD OR LEAF,CKD,BLD,DRND,W/SALT',11856,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, all varieties, cooked, boiled, drained, with salt','SQUASH,SMMR,ALL VAR,CKD,BLD,DRND,W/SALT',11857,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, crookneck and straightneck, cooked, boiled, drained, with salt','SQUASH,SMMR,CROOKNECK&STRAIGHTNECK,CKD,BLD,DRND,W/SALT',11858,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, crookneck and straightneck, frozen, cooked, boiled, drained, with salt','SQUASH,SMMR,CROOKNECK&STRAIGHTNECK,FRZ,CKD,BLD,DRND,W/SALT',11859,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, scallop, cooked, boiled, drained, with salt','SQUASH,SMMR,SCALLOP,CKD,BLD,DRND,W/SALT',11860,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, zucchini, includes skin, cooked, boiled, drained, with salt','SQUASH,SMMR,ZUCCHINI,INCL SKN,CKD,BLD,DRND,W/SALT',11861,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, summer, zucchini, includes skin, frozen, cooked, boiled, drained, with salt','SQUASH,SMMR,ZUCCHINI,INCL SKN,FRZ,CKD,BLD,DRND,W/SALT',11862,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, all varieties, cooked, baked, with salt','SQUASH,WNTR,ALL VAR,CKD,BKD,W/SALT',11863,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, acorn, cooked, baked, with salt','SQUASH,WNTR,ACORN,CKD,BKD,W/SALT',11864,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, acorn, cooked, boiled, mashed, with salt','SQUASH,WNTR,ACORN,CKD,BLD,MSHD,W/SALT',11865,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, butternut, cooked, baked, with salt','SQUASH,WNTR,BUTTERNUT,CKD,BKD,W/SALT',11866,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, butternut, frozen, cooked, boiled, with salt','SQUASH,WNTR,BUTTERNUT,FRZ,CKD,BLD,W/SALT',11867,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, hubbard, baked, with salt','SQUASH,WNTR,HUBBARD,BKD,W/ SALT',11868,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, hubbard, cooked, boiled, mashed, with salt','SQUASH,WNTR,HUBBARD,CKD,BLD,MSHD,W/SALT',11869,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, winter, spaghetti, cooked, boiled, drained, or baked, with salt','SQUASH,WNTR,SPAGHETTI,CKD,BLD,DRND,OR BKD,W/SALT',11870,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Succotash, (corn and limas), cooked, boiled, drained, with salt','SUCCOTASH,(CORN&LIMAS),CKD,BLD,DRND,W/SALT',11871,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Succotash, (corn and limas), frozen, cooked, boiled, drained, with salt','SUCCOTASH,(CORN&LIMAS),FRZ,CKD,BLD,DRND,W/SALT',11872,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato leaves, cooked, steamed, with salt','SWEET POTATO LEAVES,CKD,STMD,W/ SALT',11874,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato, cooked, baked in skin, flesh, with salt','SWEET POTATO,CKD,BKD IN SKN,FLESH,W/ SALT',11875,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato, cooked, boiled, without skin, with salt','SWEET POTATO,CKD,BLD,WO/ SKN,W/ SALT',11876,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet potato, frozen, cooked, baked, with salt','SWEET POTATO,FRZ,CKD,BKD,W/ SALT',11877,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Taro, cooked, with salt','TARO,COOKED,WITH SALT',11878,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Taro, leaves, cooked, steamed, with salt','TARO,LEAVES,CKD,STMD,W/SALT',11879,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Taro, shoots, cooked, with salt','TARO,SHOOTS,CKD,W/SALT',11880,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Taro, tahitian, cooked, with salt','TARO,TAHITIAN,CKD,W/SALT',11881,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomatoes, red, ripe, cooked, with salt','TOMATOES,RED,RIPE,CKD,W/ SALT',11884,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomatoes, red, ripe, canned, packed in tomato juice, no salt added','TOMATOES,RED,RIPE,CND,PACKED IN TOMATO JUC,NO SALT ADDED',11885,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato juice, canned, without salt added','TOMATO JUC,CND,WO/ SALT ADDED',11886,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato products, canned, puree, with salt added','TOMATO PRODUCTS,CND,PUREE,W/SALT',11888,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnips, cooked, boiled, drained, with salt','TURNIPS,CKD,BLD,DRND,W/SALT',11889,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnips, frozen, cooked, boiled, drained, with salt','TURNIPS,FRZ,CKD,BLD,DRND,W/SALT',11890,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnip greens, cooked, boiled, drained, with salt','TURNIP GRNS,CKD,BLD,DRND,W/SALT',11891,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnip greens, frozen, cooked, boiled, drained, with salt','TURNIP GRNS,FRZ,CKD,BLD,DRND,W/SALT',11892,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnip greens and turnips, frozen, cooked, boiled, drained, with salt','TURNIP GRNS&TURNIPS,FRZ,CKD,BLD,DRND,W/SALT',11893,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Vegetables, mixed, frozen, cooked, boiled, drained, with salt','VEGETABLES,MXD,FRZ,CKD,BLD,DRND,W/SALT',11894,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Waxgourd, (chinese preserving melon), cooked, boiled, drained, with salt','WAXGOURD,(CHINESE PRESERVING MELON),CKD,BLD,DRND,W/SALT',11895,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Winged bean, immature seeds, cooked, boiled, drained, with salt','WINGED BEAN,IMMAT SEEDS,CKD,BLD,DRND,W/SALT',11896,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Yam, cooked, boiled, drained, or baked, with salt','YAM,CKD,BLD,DRND,OR BKD,W/SALT',11897,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Yardlong bean, cooked, boiled, drained, with salt','YARDLONG BEAN,CKD,BLD,DRND,W/SALT',11899,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, raw','CORN,SWEET,WHITE,RAW',11900,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, cooked, boiled, drained, without salt','CORN,SWT,WHITE,CKD,BLD,DRND,WO/SALT',11901,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, cooked, boiled, drained, with salt','CORN,SWT,WHITE,CKD,BLD,DRND,W/SALT',11902,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, canned, whole kernel, regular pack, solids and liquids','CORN,SWT,WHITE,CND,WHL KERNEL,REG PK,SOL&LIQUIDS',11903,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, canned, whole kernel, no salt added, solids and liquids','CORN,SWT,WHITE,CND,WHL KERNEL,NO SALT,SOL&LIQUIDS',11904,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, canned, whole kernel, drained solids','CORN,SWT,WHITE,CND,WHL KERNEL,DRND SOL',11905,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, canned, cream style, regular pack','CORN,SWT,WHITE,CND,CRM STYLE,REG PK',11906,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, canned, cream style, no salt added','CORN,SWT,WHITE,CND,CRM STYLE,NO SALT',11907,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, canned, vacuum pack, regular pack','CORN,SWT,WHITE,CND,VACUUM PK,REG PK',11908,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, canned, vacuum pack, no salt added','CORN,SWT,WHITE,CND,VACUUM PK,NO SALT',11909,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, frozen, kernels cut off cob, unprepared','CORN,SWT,WHITE,FRZ,KRNLS CUT OFF COB,UNPREP',11910,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, frozen, kernels cut off cob, boiled, drained, without salt','CORN,SWT,WHITE,FRZ,KRNLS CUT OFF COB,BLD,DRND,WO/SALT',11911,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, frozen, kernels cut off cob, boiled, drained, with salt','CORN,SWT,WHITE,FRZ,KRNLS CUT OFF COB,BLD,DRND,W/SALT',11912,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, frozen, kernels on cob, unprepared','CORN,SWT,WHITE,FRZ,KRNLS ON COB,UNPREP',11913,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, frozen, kernels on cob, cooked, boiled, drained, without salt','CORN,SWT,WHITE,FRZ,KRNLS ON COB,CKD,BLD,DRND,WO/SALT',11914,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn, sweet, white, frozen, kernels on cob, cooked, boiled, drained, with salt','CORN,SWT,WHITE,FRZ,KRNLS ON COB,CKD,BLD,DRND,W/SALT',11915,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, red, canned, solids and liquids','PEPPERS,SWT,RED,CND,SOL&LIQUIDS',11916,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, red, frozen, chopped, unprepared','PEPPERS,SWT,RED,FRZ,CHOPD,UNPREP',11917,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, red, frozen, chopped, boiled, drained, without salt','PEPPERS,SWT,RED,FRZ,CHOPD,BLD,DRND,WO/ SALT',11918,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, red, frozen, chopped, boiled, drained, with salt','PEPPERS,SWT,RED,FRZ,CHOPD,BLD,DRND,W/ SALT',11919,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, red, sauteed','PEPPERS,SWT,RED,SAUTEED',11921,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Soybeans, mature seeds, sprouted, cooked, steamed, with salt','SOYBEANS,MATURE SEEDS,SPROUTED,CKD,STMD,W/SALT',11923,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lentils, sprouted, cooked, stir-fried, with salt','LENTILS,SPROUTED,CKD,STIR-FRIED,W/SALT',11926,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mountain yam, hawaii, cooked, steamed, with salt','MOUNTAIN YAM,HAWAII,CKD,STMD,W/ SALT',11927,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, mashed, prepared from granules, without milk, whole milk and margarine','POTATOES,MSHD,PREP FROM GRANULES,WO/MILK,WHL MILK&MARGARINE',11929,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, mashed, dehydrated, prepared from flakes without milk, whole milk and margarine added','POTATOES,MSHD,DEHYD,PREP FRM FLKS WO/ MILK,WHL MILK&MARG ADD',11930,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, red, freeze-dried','PEPPERS,SWT,RED,FREEZE-DRIED',11931,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, yellow, canned, regular pack, drained solids','BEANS,SNAP,YEL,CND,REG PK,DRND SOL',11932,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, snap, yellow, canned, no salt added, drained solids','BEANS,SNAP,YEL,CND,NO SALT,DRND SOL',11933,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, mashed, home-prepared, whole milk and butter added','POTATOES,MSHD,HOME-PREPARED,WHL MILK & BUTTER ADDED',11934,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Catsup','CATSUP',11935,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, brown, italian, or crimini, exposed to ultraviolet light, raw','MUSHROOMS,BROWN,ITALIAN,OR CRIMINI,EXPOSED TO UV LT,RAW',11936,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pickles, cucumber, dill or kosher dill','PICKLES,CUCUMBER,DILL OR KOSHER DILL',11937,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushroom, white, exposed to ultraviolet light, raw','MUSHROOM,WHITE,EXPOSED TO UV LT,RAW',11938,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, portabella, exposed to ultraviolet light, grilled','MUSHROOMS,PORTABELLA,EXPOSED TO UV LT,GRILLED',11939,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pickles, cucumber, sweet (includes bread and butter pickles)','PICKLES,CUCUMBER,SWT (INCLUDES BREAD & BUTTER PICKLES)',11940,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pickles, cucumber, sour','PICKLES,CUCUMBER,SOUR',11941,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pimento, canned','PIMENTO,CANNED',11943,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pickle relish, hot dog','PICKLE RELISH,HOT DOG',11944,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pickle relish, sweet','PICKLE RELISH,SWEET',11945,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pickles, cucumber, sour, low sodium','PICKLES,CUCUMBER,SOUR,LO NA',11946,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pickles, cucumber, dill, reduced sodium','PICKLES,CUCUMBER,DILL,RED NA',11947,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pickles, cucumber, sweet, low sodium (includes bread and butter pickles)','PICKLES,CUCUMBER,SWT,LO NA (INCLUDES BREAD & BUTTER PICKLES)',11948,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Catsup, low sodium','CATSUP,LOW SODIUM',11949,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, enoki, raw','MUSHROOMS,ENOKI,RAW',11950,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, sweet, yellow, raw','PEPPERS,SWEET,YELLOW,RAW',11951,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Radicchio, raw','RADICCHIO,RAW',11952,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Squash, zucchini, baby, raw','SQUASH,ZUCCHINI,BABY,RAW',11953,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomatillos, raw','TOMATILLOS,RAW',11954,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomatoes, sun-dried','TOMATOES,SUN-DRIED',11955,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomatoes, sun-dried, packed in oil, drained','TOMATOES,SUN-DRIED,PACKED IN OIL,DRND',11956,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Fennel, bulb, raw','FENNEL,BULB,RAW',11957,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pickle relish, hamburger','PICKLE RELISH,HAMBURGER',11958,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Arugula, raw','ARUGULA,RAW',11959,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Carrots, baby, raw','CARROTS,BABY,RAW',11960,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Hearts of palm, canned','HEARTS OF PALM,CANNED',11961,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, hot chile, sun-dried','PEPPERS,HOT CHILE,SUN-DRIED',11962,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Nopales, raw','NOPALES,RAW',11963,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Nopales, cooked, without salt','NOPALES,CKD,WO/SALT',11964,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cauliflower, green, raw','CAULIFLOWER,GREEN,RAW',11965,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cauliflower, green, cooked, no salt added','CAULIFLOWER,GRN,CKD,NO SALT ADDED',11967,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cauliflower, green, cooked, with salt','CAULIFLOWER,GRN,CKD,W/ SALT',11968,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli, chinese, cooked','BROCCOLI,CHINESE,COOKED',11969,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Lemon grass (citronella), raw','LEMON GRASS (CITRONELLA),RAW',11972,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Beans, fava, in pod, raw','BEANS,FAVA,IN POD,RAW',11973,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Grape leaves, raw','GRAPE LEAVES,RAW',11974,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Grape leaves, canned','GRAPE LEAVES,CND',11975,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pepper, banana, raw','PEPPER,BANANA,RAW',11976,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, serrano, raw','PEPPERS,SERRANO,RAW',11977,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, ancho, dried','PEPPERS,ANCHO,DRIED',11978,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, jalapeno, raw','PEPPERS,JALAPENO,RAW',11979,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, chili, green, canned','PEPPERS,CHILI,GRN,CND',11980,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, hungarian, raw','PEPPERS,HUNGARIAN,RAW',11981,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pickles, chowchow, with cauliflower onion mustard, sweet','PICKLES,CHOWCHOW,W/CAULIFLOWER ONION MUSTARD,SWT',11983,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, oyster, raw','MUSHROOMS,OYSTER,RAW',11987,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, straw, canned, drained solids','MUSHROOMS,STRAW,CND,DRND SOL',11989,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Yautia (tannier), raw','YAUTIA (TANNIER),RAW',11991,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, white, microwaved','MUSHROOMS,WHITE,MICROWAVED',11992,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, maitake, raw','MUSHROOMS,MAITAKE,RAW',11993,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli, chinese, raw','BROCCOLI,CHINESE,RAW',11994,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mushrooms, portabella, exposed to ultraviolet light, raw','MUSHROOMS,PORTABELLA,EXPOSED TO ULTRAVIOLET LT,RAW',11998,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, breadfruit seeds, raw','BREADFRUIT SEEDS,RAW',12001,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, breadfruit seeds, boiled','BREADFRUIT SEEDS,BOILED',12003,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, breadnut tree seeds, raw','SEEDS,BREADNUT TREE SEEDS,RAW',12004,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, breadnut tree seeds, dried','SEEDS,BREADNUT TREE SEEDS,DRIED',12005,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, chia seeds, dried','CHIA SEEDS,DRIED',12006,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, cottonseed flour, partially defatted (glandless)','COTTONSEED FLR,PART DEFATTED (GLANDLESS)',12007,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, cottonseed flour, low fat (glandless)','COTTONSEED FLR,LOFAT (GLANDLESS)',12008,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, cottonseed meal, partially defatted (glandless)','COTTONSEED MEAL,PART DEFATTED (GLANDLESS)',12011,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, hemp seed, hulled','SEEDS,HEMP SD,HULLED',12012,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, lotus seeds, dried','LOTUS SEEDS,DRIED',12013,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, pumpkin and squash seed kernels, dried','PUMPKIN&SQUASH SD KRNLS,DRIED',12014,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, pumpkin and squash seed kernels, roasted, without salt','PUMPKIN&SQUASH SD KRNLS,RSTD,WO/SALT',12016,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, safflower seed kernels, dried','SAFFLOWER SD KRNLS,DRIED',12021,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, safflower seed meal, partially defatted','SAFFLOWER SD MEAL,PART DEFATTED',12022,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sesame seeds, whole, dried','SESAME SEEDS,WHOLE,DRIED',12023,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sesame seeds, whole, roasted and toasted','SESAME SEEDS,WHL,RSTD&TSTD',12024,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sesame seed kernels, toasted, without salt added (decorticated)','SESAME SD KRNLS,TSTD,WO/SALT (DECORT)',12029,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sesame flour, partially defatted','SESAME FLR,PART DEFATTED',12032,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sesame flour, low-fat','SESAME FLOUR,LOW-FAT',12033,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sesame meal, partially defatted','SESAME MEAL,PART DEFATTED',12034,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sunflower seed kernels, dried','SUNFLOWER SD KRNLS,DRIED',12036,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sunflower seed kernels, dry roasted, without salt','SUNFLOWER SD KRNLS,DRY RSTD,WO/SALT',12037,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sunflower seed kernels, oil roasted, without salt','SUNFLOWER SD KRNLS,OIL RSTD,WO/SALT',12038,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sunflower seed kernels, toasted, without salt','SUNFLOWER SD KRNLS,TSTD,WO/SALT',12039,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sunflower seed butter, without salt','SUNFLOWER SD BUTTER,WO/SALT',12040,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sunflower seed flour, partially defatted','SUNFLOWER SD FLR,PART DEFATTED',12041,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, acorns, raw','ACORNS,RAW',12058,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, acorns, dried','ACORNS,DRIED',12059,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, acorn flour, full fat','ACORN FLOUR,FULL FAT',12060,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, almonds','ALMONDS',12061,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2007-03-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, almonds, blanched','ALMONDS,BLANCHED',12062,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, almonds, dry roasted, without salt added','ALMONDS,DRY RSTD,WO/SALT',12063,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2007-03-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, almonds, oil roasted, without salt added','ALMONDS,OIL RSTD,WO/SALT',12065,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, almond paste','ALMOND PASTE',12071,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, beechnuts, dried','BEECHNUTS,DRIED',12077,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, brazilnuts, dried, unblanched','BRAZILNUTS,DRIED,UNBLANCHED',12078,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, butternuts, dried','BUTTERNUTS,DRIED',12084,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, cashew nuts, dry roasted, without salt added','CASHEW NUTS,DRY RSTD,WO/SALT',12085,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, cashew nuts, oil roasted, without salt added','CASHEW NUTS,OIL RSTD,WO/SALT',12086,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, cashew nuts, raw','NUTS,CASHEW NUTS,RAW',12087,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, cashew butter, plain, without salt added','CASHEW BUTTER,PLN,WO/SALT',12088,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, chestnuts, chinese, raw','CHESTNUTS,CHINESE,RAW',12093,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, chestnuts, chinese, dried','CHESTNUTS,CHINESE,DRIED',12094,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, chestnuts, chinese, boiled and steamed','CHESTNUTS,CHINESE,BLD&STMD',12095,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, chestnuts, chinese, roasted','CHESTNUTS,CHINESE,ROASTED',12096,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, chestnuts, european, raw, unpeeled','CHESTNUTS,EUROPEAN,RAW,UNPEELED',12097,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, chestnuts, european, raw, peeled','CHESTNUTS,EUROPEAN,RAW,PEELED',12098,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, chestnuts, european, dried, unpeeled','CHESTNUTS,EUROPEAN,DRIED,UNPEELED',12099,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, chestnuts, european, dried, peeled','CHESTNUTS,EUROPEAN,DRIED,PEELED',12100,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, chestnuts, european, boiled and steamed','CHESTNUTS,EUROPEAN,BLD&STMD',12101,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, coconut meat, raw','COCONUT MEAT,RAW',12104,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, coconut meat, dried (desiccated), not sweetened','COCONUT MEAT,DRIED (DESICCATED),NOT SWTND',12108,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, coconut meat, dried (desiccated), sweetened, flaked, packaged','COCONUT MEAT,DRIED (DESICCATED),SWTND,FLAKED,PACKAGED',12109,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, coconut meat, dried (desiccated), sweetened, flaked, canned','COCONUT MEAT,DRIED (DESICCATED),SWTND,FLAKED,CND',12110,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, coconut meat, dried (desiccated), toasted','COCONUT MEAT,DRIED (DESICCATED),TSTD',12114,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, coconut cream, raw (liquid expressed from grated meat)','COCONUT CRM,RAW (LIQ EXPRESSED FROM GRATED MEAT)',12115,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, coconut cream, canned, sweetened','NUTS,COCNT CRM,CND,SWTND',12116,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, coconut milk, raw (liquid expressed from grated meat and water)','COCONUT MILK,RAW (LIQ EXPRESSED FROM GRATED MEAT&H2O)',12117,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, coconut milk, canned (liquid expressed from grated meat and water)','COCONUT MILK,CND (LIQ EXPRESSED FROM GRATED MEAT&H2O)',12118,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, coconut water (liquid from coconuts)','COCONUT H2O (LIQ FROM COCONUTS)',12119,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, hazelnuts or filberts','HAZELNUTS OR FILBERTS',12120,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, hazelnuts or filberts, blanched','HAZELNUTS OR FILBERTS,BLANCHED',12121,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, hazelnuts or filberts, dry roasted, without salt added','HAZELNUTS OR FILBERTS,DRY RSTD,WO/SALT',12122,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, ginkgo nuts, raw','GINKGO NUTS,RAW',12127,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, ginkgo nuts, dried','GINKGO NUTS,DRIED',12128,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, ginkgo nuts, canned','GINKGO NUTS,CANNED',12129,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, hickorynuts, dried','HICKORYNUTS,DRIED',12130,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, macadamia nuts, raw','MACADAMIA NUTS,RAW',12131,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, macadamia nuts, dry roasted, without salt added','MACADAMIA NUTS,DRY RSTD,WO/SALT',12132,NULL,NULL,NULL,NULL,NULL,1,'2002-06-08','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, mixed nuts, dry roasted, with peanuts, without salt added','MIXED NUTS,DRY RSTD,W/PNUTS,WO/SALT',12135,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, mixed nuts, oil roasted, with peanuts, without salt added','MIXED NUTS,OIL RSTD,W/PNUTS,WO/SALT',12137,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, mixed nuts, oil roasted, without peanuts, without salt added','MIXED NUTS,OIL RSTD,WO/PNUTS,WO/SALT',12138,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, formulated, wheat-based, unflavored, with salt added','FORMULATED,WHEAT-BASED,UNFLAVORED,W/SALT',12140,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, pecans','PECANS',12142,NULL,NULL,NULL,NULL,NULL,1,'1995-06-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, pecans, dry roasted, without salt added','PECANS,DRY RSTD,WO/SALT',12143,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, pecans, oil roasted, without salt added','PECANS,OIL RSTD,WO/SALT',12144,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, pilinuts, dried','NUTS,PILINUTS,DRIED',12145,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, pine nuts, dried','NUTS,PINE NUTS,DRIED',12147,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, pine nuts, pinyon, dried','PINE NUTS,PINYON,DRIED',12149,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, pistachio nuts, raw','PISTACHIO NUTS,RAW',12151,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, pistachio nuts, dry roasted, without salt added','PISTACHIO NUTS,DRY RSTD,WO/SALT',12152,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, walnuts, black, dried','WALNUTS,BLACK,DRIED',12154,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, walnuts, english','WALNUTS,ENGLISH',12155,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2007-03-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, walnuts, glazed','NUTS,WALNUTS,GLAZED',12156,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, walnuts, dry roasted, with salt added','NUTS,WALNUTS,DRY RSTD,W/ SALT ADDED',12157,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, breadfruit seeds, roasted','BREADFRUIT SEEDS,ROASTED',12158,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, cottonseed kernels, roasted (glandless)','COTTONSEED KRNLS,RSTD (GLANDLESS)',12160,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, pumpkin and squash seeds, whole, roasted, without salt','PUMPKIN&SQUASH SEEDS,WHL,RSTD,WO/SALT',12163,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sesame butter, tahini, from roasted and toasted kernels (most common type)','SESAME BUTTER,TAHINI,FROM RSTD&TSTD KRNLS (MOST COMMON TYPE)',12166,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, chestnuts, european, roasted','CHESTNUTS,EUROPEAN,RSTD',12167,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sesame butter, paste','SESAME BUTTER,PASTE',12169,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sesame flour, high-fat','SESAME FLOUR,HIGH-FAT',12170,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sesame butter, tahini, from unroasted kernels (non-chemically removed seed coat)','SESAME BUTTER,TAHINI,FROM UNROASTED KRNLS',12171,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, watermelon seed kernels, dried','WATERMELON SD KRNLS,DRIED',12174,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, chestnuts, japanese, dried','CHESTNUTS,JAPANESE,DRIED',12175,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, coconut milk, frozen (liquid expressed from grated meat and water)','COCONUT MILK,FRZ (LIQ EXPRESSED FROM GRATED MEAT&H2O)',12176,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, coconut meat, dried (desiccated), creamed','COCONUT MEAT,DRIED (DESICCATED),CRMD',12177,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, coconut meat, dried (desiccated), sweetened, shredded','COCONUT MEAT,DRIED (DESICCATED),SWTND,SHREDDED',12179,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sisymbrium sp. seeds, whole, dried','SISYMBRIUM SP. SEEDS,WHL,DRIED',12193,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, almond butter, plain, without salt added','ALMOND BUTTER,PLN,WO/SALT',12195,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sesame butter, tahini, from raw and stone ground kernels','SESAME BUTTER,TAHINI,FROM RAW&STONE GROUND KRNLS',12198,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, formulated, wheat-based, all flavors except macadamia, without salt','FORMULATED,WHEAT-BASED,ALL FLAVORS XCPT MACADAMIA,WO/SALT',12200,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sesame seed kernels, dried (decorticated)','SESAME SD KRNLS,DRIED (DECORT)',12201,NULL,NULL,NULL,NULL,NULL,1,'1995-06-12','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, chestnuts, japanese, raw','CHESTNUTS,JAPANESE,RAW',12202,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, chestnuts, japanese, boiled and steamed','CHESTNUTS,JAPANESE,BLD&STMD',12203,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, chestnuts, japanese, roasted','CHESTNUTS,JAPANESE,RSTD',12204,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, lotus seeds, raw','LOTUS SEEDS,RAW',12205,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, almonds, honey roasted, unblanched','ALMONDS,HONEY RSTD,UNBLANCHED',12206,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, flaxseed','SEEDS,FLAXSEED',12220,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, pumpkin and squash seed kernels, roasted, with salt added','PUMPKIN&SQUASH SD KRNLS,RSTD,W/SALT',12516,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sesame seed kernels, toasted, with salt added (decorticated)','SESAME SD KRNLS,TSTD,W/SALT (DECORT)',12529,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sunflower seed kernels from shell, dry roasted, with salt added','SEEDS,SUNFLOWER SD KRNLS FROM SHELL,DRY RSTD,W/ SALT ADDED',12536,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sunflower seed kernels, dry roasted, with salt added','SUNFLOWER SD KRNLS,DRY RSTD,W/SALT',12537,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sunflower seed kernels, oil roasted, with salt added','SUNFLOWER SD KRNLS,OIL RSTD,W/SALT',12538,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sunflower seed kernels, toasted, with salt added','SUNFLOWER SD KRNLS,TSTD,W/SALT',12539,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sunflower seed butter, with salt added (Includes foods for USDA''s Food Distribution Program)','SUNFLOWER SD BUTTER,W/SALT',12540,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, almonds, dry roasted, with salt added','ALMONDS,DRY RSTD,W/SALT',12563,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, almonds, oil roasted, with salt added','ALMONDS,OIL RSTD,W/SALT',12565,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, almonds, oil roasted, with salt added, smoke flavor','NUTS,ALMONDS,OIL RSTD,W/ SALT ADDED,SMOKE FLAVOR',12567,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, cashew nuts, dry roasted, with salt added','CASHEW NUTS,DRY RSTD,W/SALT',12585,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, cashew nuts, oil roasted, with salt added','CASHEW NUTS,OIL RSTD,W/SALT',12586,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, cashew butter, plain, with salt added','CASHEW BUTTER,PLN,W/SALT',12588,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, macadamia nuts, dry roasted, with salt added','MACADAMIA NUTS,DRY RSTD,W/SALT',12632,NULL,NULL,NULL,NULL,NULL,1,'2002-06-08','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, mixed nuts, dry roasted, with peanuts, with salt added','MIXED NUTS,DRY RSTD,W/PNUTS,W/SALT',12635,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, mixed nuts, oil roasted, with peanuts, with salt added','NUTS,MXD NUTS,OIL RSTD,W/ PNUTS,W/ SALT ADDED',12637,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, mixed nuts, oil roasted, without peanuts, with salt added','NUTS,MXD NUTS,OIL RSTD,WO/ PNUTS,W/ SALT ADDED',12638,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, pecans, dry roasted, with salt added','PECANS,DRY RSTD,W/SALT',12643,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, pecans, oil roasted, with salt added','PECANS,OIL RSTD,W/SALT',12644,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, pistachio nuts, dry roasted, with salt added','PISTACHIO NUTS,DRY RSTD,W/SALT',12652,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, pumpkin and squash seeds, whole, roasted, with salt added','PUMPKIN&SQUASH SEEDS,WHL,RSTD,W/SALT',12663,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, almonds, oil roasted, lightly salted','NUTS,ALMONDS,OIL RSTD,LIGHTLY SALTED',12665,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, almond butter, plain, with salt added','ALMOND BUTTER,PLN,W/SALT',12695,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Seeds, sesame butter, tahini, type of kernels unspecified','SESAME BUTTER,TAHINI,KRNLS UNSPEC',12698,NULL,NULL,NULL,NULL,NULL,1,'2002-06-08','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, mixed nuts, oil roasted, with peanuts, lightly salted','NUTS,MXD NUTS,OIL RSTD,W/ PNUTS,LIGHTLY SALTED',12737,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (12,'Nuts, mixed nuts, oil roasted, without peanuts, lightly salted','NUTS,MXD NUTS,OIL RSTD,WO/ PNUTS,LIGHTLY SALTED',12738,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, grass-fed, strip steaks, lean only, raw','BEEF,GRASS-FED,STRIP STEAKS,LN,RAW',13000,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, carcass, separable lean and fat, choice, raw','BEEF,CARCASS,LN&FAT,CHOIC,RAW',13001,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, carcass, separable lean and fat, select, raw','BEEF,CARCASS,LN&FAT,SEL,RAW',13002,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, retail cuts, separable fat, raw','BEEF,RTL CUTS,FAT,RAW',13019,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, retail cuts, separable fat, cooked','BEEF,RTL CUTS,FAT,CKD',13020,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, whole, separable lean only, all grades, raw','BEEF,BRISKET,WHL,LN,ALL GRDS,RAW',13023,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, grass-fed, ground, raw','BEEF,GRASS-FED,GROUND,RAW',13047,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2009-01-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean and fat, trimmed to 1/8" fat, select, cooked, braised','BEEF,BRISKET,FLAT HALF,LN & FAT,1/8" FAT,SEL,CKD,BRSD',13055,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, flank, steak, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,FLANK,STEAK,LN & FAT,0" FAT,CHOIC,RAW',13065,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, flank, steak, separable lean and fat, trimmed to 0" fat, choice, cooked, braised','BEEF,FLANK,STEAK,LN & FAT,0" FAT,CHOIC,CKD,BRSD',13066,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, flank, steak, separable lean and fat, trimmed to 0" fat, choice, cooked, broiled','BEEF,FLANK,STEAK,LN & FAT,0" FAT,CHOIC,CKD,BRLD',13067,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, flank, steak, separable lean only, trimmed to 0" fat, choice, raw','BEEF,FLANK,STEAK,LN,0" FAT,CHOIC,RAW',13068,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, flank, steak, separable lean only, trimmed to 0" fat, choice, cooked, braised','BEEF,FLANK,STEAK,LN,0" FAT,CHOIC,CKD,BRSD',13069,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, flank, steak, separable lean only, trimmed to 0" fat, choice, cooked, broiled','BEEF,FLANK,STEAK,LN,0" FAT,CHOIC,CKD,BRLD',13070,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, eye, small end (ribs 10-12), separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,RIB,EYE,SML END (RIBS 10-12),LN&FAT,0"FAT,CHOIC,RAW',13095,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, eye, small end (ribs 10-12), separable lean and fat, trimmed to 0" fat, choice, cooked, broiled','BF,RIB,EYE,SML END (RIB 10-12),LN & FT,0" FAT,CHOIC,CKD,BRLD',13096,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, eye, small end (ribs 10-12), separable lean only, trimmed to 0" fat, choice, raw','BEEF,RIB,EYE,SML END (RIBS 10-12),LN,0"FAT,CHOIC,RAW',13097,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, eye, small end (ribs 10-12), separable lean only, trimmed to 0" fat, choice, cooked, broiled','BEEF,RIB,EYE,SML END (RIBS 10-12),LN,0"FAT,CHOIC,CKD,BRLD',13098,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, shortribs, separable lean and fat, choice, raw','BEEF,RIB,SHORTRIBS,LN&FAT,CHOIC,RAW',13147,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, shortribs, separable lean and fat, choice, cooked, braised','BEEF,RIB,SHORTRIBS,LN&FAT,CHOIC,CKD,BRSD',13148,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, shortribs, separable lean only, choice, raw','BEEF,RIB,SHORTRIBS,LN ONLY,CHOIC,RAW',13149,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, shortribs, separable lean only, choice, cooked, braised','BEEF,RIB,SHORTRIBS,LN,CHOIC,CKD,BRSD',13150,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, full cut, separable lean only, trimmed to 1/4" fat, choice, cooked, broiled','BEEF,RND,FULL CUT,LN,1/4"FAT,CHOIC,CKD,BRLD',13156,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, full cut, separable lean only, trimmed to 1/4" fat, select, cooked, broiled','BEEF,RND,FULL CUT,LN,1/4"FAT,SEL,CKD,BRLD',13158,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean and fat, trimmed to 0" fat, choice, cooked, braised','BEEF,BRISKET,FLAT HALF,LN & FAT,0" FAT,CHOIC,CKD,BRSD',13165,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shank crosscuts, separable lean only, trimmed to 1/4" fat, choice, raw','BEEF,SHANK CROSSCUTS,LN,1/4"FAT,CHOIC,RAW',13227,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shank crosscuts, separable lean only, trimmed to 1/4" fat, choice, cooked, simmered','BEEF,SHANK CROSSCUTS,LN,1/4"FAT,CHOIC,CKD,SIMMRD',13228,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,SHRT LOIN,PRTRHS STEAK,LN,1/8" FAT,CHOIC,RAW',13231,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean only, trimmed to 1/8" fat, choice, cooked, grilled','BEEF,SHRT LOIN,PRTRHS STEAK,LN,1/8" FAT,CHOIC,CKD,GRILLED',13232,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, bone-in, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,SHRT LOIN,T-BONE STEAK,BONE-IN,LN,1/8" FAT,CHOIC,RAW',13235,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, bone-in, separable lean only, trimmed to 1/8" fat, choice, cooked, grilled','BEEF,SHRT LN,T-BONE STK,BN-IN,LN,1/8" FAT,CHOIC,CKD,GRILLD',13236,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye, small end (ribs 10-12), separable lean only, trimmed to 0" fat, select, raw','BEEF,RIB EYE,SML END (RIBS 10-12),LN,0" FAT,SEL,RAW',13284,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade pot roast, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, braised','BEEF,CHUCK,UND BL POT RST,BNLESS,LN,0" FAT,ALL GRDS,CKD',13285,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade pot roast or steak, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,CHK,UND BL POT RST,BNLESS,LN,0" FAT,ALL GRDS,CKD, BRSD',13293,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade pot roast or steak, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,CHCK,UND BL POT RST OR STEAK,BNLESS,LN,0" FAT,CHOIC,RAW',13294,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, patties, frozen, cooked, broiled','BEEF,GROUND,PATTIES,FRZ,CKD,BRLD',13317,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, brain, raw','BEEF,VAR MEATS&BY-PRODUCTS,BRAIN,RAW',13318,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, brain, cooked, pan-fried','BEEF,VAR MEATS&BY-PRODUCTS,BRAIN,CKD,PAN-FRIED',13319,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, brain, cooked, simmered','BEEF,VAR MEATS&BY-PRODUCTS,BRAIN,CKD,SIMMRD',13320,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, heart, raw','BEEF,VAR MEATS&BY-PRODUCTS,HEART,RAW',13321,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, heart, cooked, simmered','BEEF,VAR MEATS&BY-PRODUCTS,HEART,CKD,SIMMRD',13322,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, kidneys, raw','BEEF,VAR MEATS&BY-PRODUCTS,KIDNEYS,RAW',13323,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, kidneys, cooked, simmered','BEEF,VAR MEATS&BY-PRODUCTS,KIDNEYS,CKD,SIMMRD',13324,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, liver, raw','BEEF,VAR MEATS&BY-PRODUCTS,LIVER,RAW',13325,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, liver, cooked, braised','BEEF,VAR MEATS & BY-PRODUCTS,LIVER,CKD,BRSD',13326,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, liver, cooked, pan-fried','BEEF, VAR MEATS&BY-PRODUCTS, LIVER, CKD, PAN-FRIED',13327,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, lungs, raw','BEEF,VAR MEATS&BY-PRODUCTS,LUNGS,RAW',13328,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, lungs, cooked, braised','BEEF,VAR MEATS&BY-PRODUCTS,LUNGS,CKD,BRSD',13329,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, mechanically separated beef, raw','BEEF,VAR MEATS&BY-PRODUCTS,MECHANICALLY SEPARATED BF,RAW',13330,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, pancreas, raw','BEEF,VAR MEATS&BY-PRODUCTS,PANCREAS,RAW',13331,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, pancreas, cooked, braised','BEEF,VAR MEATS&BY-PRODUCTS,PANCREAS,CKD,BRSD',13332,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, spleen, raw','BEEF,VAR MEATS&BY-PRODUCTS,SPLEEN,RAW',13333,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, spleen, cooked, braised','BEEF,VAR MEATS&BY-PRODUCTS,SPLEEN,CKD,BRSD',13334,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, suet, raw','BEEF,VAR MEATS & BY-PRODUCTS,SUET,RAW',13335,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, thymus, raw','BEEF,VAR MEATS&BY-PRODUCTS,THYMUS,RAW',13337,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, thymus, cooked, braised','BEEF,VAR MEATS&BY-PRODUCTS,THYMUS,CKD,BRSD',13338,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, tongue, raw','BEEF,VAR MEATS&BY-PRODUCTS,TONGUE,RAW',13339,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, tongue, cooked, simmered','BEEF,VAR MEATS&BY-PRODUCTS,TONGUE,CKD,SIMMRD',13340,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, tripe, raw','BEEF,VAR MEATS&BY-PRODUCTS,TRIPE,RAW',13341,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, sandwich steaks, flaked, chopped, formed and thinly sliced, raw','BEEF,SNDWCH STEAKS,FLAKED,CHOPD,FORMED & THINLY SLICED,RAW',13342,NULL,NULL,NULL,NULL,NULL,1,'2002-06-08','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean only, trimmed to 0" fat, choice, cooked, braised','BEEF,BRISKET,FLAT HALF,LN,0" FAT,CHOIC,CKD,BRSD',13343,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, cured, breakfast strips, raw or unheated','BEEF,CURED,BRKFST STRIPS,RAW OR UNHTD',13344,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, cured, breakfast strips, cooked','BEEF,CURED,BRKFST STRIPS,CKD',13345,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, cured, corned beef, brisket, raw','BEEF,CURED,CORNED BF,BRISKET,RAW',13346,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, cured, corned beef, brisket, cooked','BEEF,CURED,CORNED BF,BRISKET,CKD',13347,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Beef, cured, corned beef, canned','BEEF,CURED,CORNED BF,CND',13348,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade pot roast or steak, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,CHK,UND BLADE POT RST OR STK,BNLESS,LN,0" FAT,SEL, RAW',13349,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Beef, cured, dried','BEEF,CURED,DRIED',13350,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade center steak, boneless, Denver Cut, separable lean only, trimmed to 0" fat, all grades, cooked, grilled','BEEF,CHUCK,UNDER BLADE CNTR STEAK,BNLESS,DENVER CUT,LN,0" FA',13351,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade center steak, boneless, Denver Cut, separable lean only, trimmed to 0" fat, choice, cooked, grilled','BEEF,CHUCK,UNDER BLADE CNTR STEAK,BNLESS,DENVER CUT,LN,0" FA',13352,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Beef, cured, luncheon meat, jellied','BEEF,CURED,LUNCHEON MEAT,JELLIED',13353,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade center steak, boneless, Denver Cut, separable lean only, trimmed to 0" fat, select, cooked, grilled','BEEF,CHK,UND BL CNTR STK,BNLESS,DEN CUT,LN,0" FA, SEL, CKD',13354,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Beef, cured, pastrami','BEEF,CURED,PASTRAMI',13355,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade center steak, boneless, Denver Cut, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,CHK,UNDBL CNTR STK,BNLESS,DENCUT,LN,0" FA, ALL GRD, RAW',13356,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, beef, cured, cooked, smoked','SAUSAGE,BF,CURED,CKD,SMOKED',13357,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Beef, chopped, cured, smoked','BEEF,CHOPD,CURED,SMOKED',13358,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade center steak, boneless, Denver Cut, separable lean only, trimmed to 0" fat, choice, raw','BEEF,CHK,UND BLCNTR STK,BNLESS,DEN CUT,LN,0" FA, CHOICE, RAW',13359,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean and fat, trimmed to 0" fat, all grades, cooked','BEEF,COMP OF RTL CUTS,LN&FAT,0"FAT,ALL GRDS,CKD',13361,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean and fat, trimmed to 0" fat, choice, cooked','BEEF,COMP OF RTL CUTS,LN&FAT,0"FAT,CHOIC,CKD',13362,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean and fat, trimmed to 0" fat, select, cooked','BEEF,COMP OF RTL CUTS,LN&FAT,0"FAT,SEL,CKD',13363,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean only, trimmed to 0" fat, all grades, cooked','BEEF,COMP OF RTL CUTS,LN,0" FAT,ALL GRDS,CKD',13364,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean only, trimmed to 0" fat, choice, cooked','BEEF,COMP OF RTL CUTS,LN,0"FAT,CHOIC,CKD',13365,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean only, trimmed to 0" fat, select, cooked','BEEF,COMP OF RTL CUTS,LN,0"FAT,SEL,CKD',13366,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, whole, separable lean and fat, trimmed to 0" fat, all grades, cooked, braised','BEEF,BRISKET,WHL,LN&FAT,0"FAT,ALL GRDS,CKD,BRSD',13367,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, whole, separable lean only, trimmed to 0" fat, all grades, cooked, braised','BEEF,BRISKET,WHL,LN,0"FAT,ALL GRDS,CKD,BRSD',13368,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean and fat, trimmed to 0" fat, all grades, cooked, braised','BEEF,BRISKET,FLAT HALF,LN&FAT,0"FAT,ALL GRDS,CKD,BRSD',13369,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean only, trimmed to 0" fat, all grades, cooked, braised','BEEF,BRISKET,FLAT HALF,LN,0"FAT,ALL GRDS,CKD,BRSD',13370,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, point half, separable lean and fat, trimmed to 0" fat, all grades, cooked, braised','BEEF,BRISKET,POINT HALF,LN&FAT,0"FAT,ALL GRDS,CKD,BRSD',13371,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, point half, separable lean only, trimmed to 0" fat, all grades, cooked, braised','BEEF,BRISKET,POINT HALF,LN,0"FAT,ALL GRDS,CKD,BRSD',13372,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean and fat, trimmed to 0" fat, all grades, cooked, braised','BEEF,CHUCK,ARM POT RST,LN&FAT,0"FAT,ALL GRDS,CKD,BRSD',13373,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean and fat, trimmed to 0" fat, select, cooked, braised','BEEF,CHUCK,ARM POT RST,LN & FAT,0" FAT,SEL,CKD,BRSD',13375,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean only, trimmed to 0" fat, choice, cooked, braised','BEEF,CHUCK,ARM POT RST,LN,0"FAT,CHOIC,CKD,BRSD',13377,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean only, trimmed to 0" fat, select, cooked, braised','BEEF,CHUCK,ARM POT RST,LN,0"FAT,SEL,CKD,BRSD',13378,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, blade roast, separable lean and fat, trimmed to 0" fat, all grades, cooked, braised','BEEF,CHUCK,BLADE RST,LN&FAT,0"FAT,ALL GRDS,CKD,BRSD',13379,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade pot roast, boneless, separable lean and fat, trimmed to 0" fat, choice, cooked, braised','BEEF,CHCK,UNDR BLDE POT RST,BNLS,LN & FAT,0",CHC,CKD,BRSD',13380,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade pot roast, boneless, separable lean and fat, trimmed to 0" fat, select, cooked, braised','BEEF,CHCK,UNDR BLDE POT RST,BNLS,LN & FAT,0",SEL,CKD,BRSD',13381,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, blade roast, separable lean only, trimmed to 0" fat, all grades, cooked, braised','BEEF,CHUCK,BLADE RST,LN,0"FAT,ALL GRDS,CKD,BRSD',13382,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade pot roast, boneless, separable lean only, trimmed to 0" fat, choice, cooked, braised','BEEF,CHK,UNDER BLADE POT RST,BNLESS,LN,0" FAT,CHOIC,CKD,BRSD',13383,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade pot roast, boneless, separable lean only, trimmed to 0" fat, select, cooked, braised','BEEF,CHUCK,UNDER BLADE POT RST,BNLESS,LN,0" FAT,SEL,CKD,BRSD',13384,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean and fat, trimmed to 0" fat, choice, cooked, roasted','BEEF,RIB,LRG END (RIBS 6-9),LN&FAT,0"FAT,CHOIC,CKD,RSTD',13386,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean and fat, trimmed to 0" fat, select, cooked, roasted','BEEF,RIB,LRG END (RIBS 6-9),LN&FAT,0"FAT,SEL,CKD,RSTD',13387,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean only, trimmed to 0" fat, all grades, cooked, roasted','BEEF,RIB,LRG END (RIBS 6-9),LN,0"FAT,ALL GRDS,CKD,RSTD',13388,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean only, trimmed to 0" fat, choice, cooked, roasted','BEEF,RIB,LRG END (RIBS 6-9),LN,0"FAT,CHOIC,CKD,RSTD',13389,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean only, trimmed to 0" fat, select, cooked, roasted','BEEF,RIB,LRG END (RIBS 6-9),LN,0"FAT,SEL,CKD,RSTD',13390,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean and fat, trimmed to 0" fat, all grades, cooked, broiled','BEEF,RIB,SML END (RIBS 10-12),LN&FAT,0"FAT,ALL GRDS,CKD,BRLD',13391,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean and fat, trimmed to 0" fat, choice, cooked, broiled','BEEF,RIB,SML END (RIBS 10-12),LN&FAT,0"FAT,CHOIC,CKD,BRLD',13392,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean and fat, trimmed to 0" fat, select, cooked, broiled','BEEF,RIB,SML END (RIBS 10-12),LN&FAT,0"FAT,SEL,CKD,BRLD',13393,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean only, trimmed to 0" fat, all grades, cooked, broiled','BEEF,RIB,SML END (RIBS 10-12),LN,0"FAT,ALL GRDS,CKD,BRLD',13394,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean only, trimmed to 0" fat, choice, cooked, broiled','BEEF,RIB,SML END (RIBS 10-12),LN,0"FAT,CHOIC,CKD,BRLD',13395,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean only, trimmed to 0" fat, select, cooked, broiled','BEEF,RIB,SML END (RIBS 10-12),LN,0"FAT,SEL,CKD,BRLD',13396,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, steak, separable lean and fat, trimmed to 0" fat, all grades, cooked, braised','BEEF,RND,BTTM RND,STEAK,LN & FAT,0" FAT,ALL GRDS,CKD,BRSD',13398,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, roast, separable lean and fat, trimmed to 0" fat, all grades, cooked, roasted','BEEF,RND,BTTM RND,RST,LN & FAT,0" FAT,ALL GRDS,CKD,RSTD',13399,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, steak, separable lean and fat, trimmed to 0" fat, choice, cooked, braised','BEEF,RND,BTTM RND,STEAK,LN & FAT,0" FAT,CHOIC,CKD,BRSD',13401,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, roast, separable lean and fat, trimmed to 0" fat, choice, cooked, roasted','BEEF,RND,BTTM RND,RST,LN & FAT,0" FAT,CHOIC,CKD,RSTD',13402,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, steak, separable lean and fat, trimmed to 0" fat, select, cooked, braised','BEEF,RND,BTTM RND,STEAK,LN & FAT,0" FAT,SEL,CKD,BRSD',13404,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, roast, separable lean and fat, trimmed to 0" fat, select, cooked, roasted','BEEF,RND,BTTM RND,RST,LN & FAT,0" FAT,SEL,CKD,RSTD',13405,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, steak, separable lean only, trimmed to 0" fat, all grades, cooked, braised','BEEF,RND,BTTM RND,STEAK,LN,0" FAT,ALL GRDS,CKD,BRSD',13407,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, roast, separable lean only, trimmed to 0" fat, all grades, cooked, roasted','BEEF,RND,BTTM RND,RST,LN,0" FAT,ALL GRDS,CKD,RSTD',13408,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, steak, separable lean only, trimmed to 0" fat, choice, cooked, braised','BEEF,RND,BTTM RND,STEAK,LN,0" FAT,CHOIC,CKD,BRSD',13410,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, roast, separable lean only, trimmed to 0" fat, choice, cooked, roasted','Beef, bottom round, roast,lean only, 0" fat, choice, roasted',13411,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, steak, separable lean only, trimmed to 0" fat, select, cooked, braised','BEEF,RND,BTTM RND,STEAK,LN,0" FAT,SEL,CKD,BRSD',13413,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round roast, separable lean only, trimmed to 0" fat, select, cooked, roasted','BEEF,RND,BTTM RND RST,LN,0" FAT,SEL,CKD,RSTD',13414,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round roast, boneless, separable lean and fat, trimmed to 0" fat, all grades, cooked, roasted','BEEF,RND,EYE OF RND RST,BNLESS,L & F,0" FAT,A GRDS,CKD,RSTD',13415,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round roast, boneless, separable lean and fat, trimmed to 0" fat, choice, cooked, roasted','BEEF,RND,EYE OF RND RST,BNLESS,LN & FT,0" FAT,CHOIC,CKD,RSTD',13416,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round roast, boneless, separable lean and fat, trimmed to 0" fat, select, cooked, roasted','BEEF,RND,EYE OF RND RST,BNLESS,LN & FAT,0" FAT,SEL,CKD,RSTD',13417,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round roast, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, roasted','BEEF,RND,EYE OF RND RST,BNLESS,LN,0" FAT,ALL GRDS,CKD,RSTD',13418,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round roast, boneless, separable lean only, trimmed to 0" fat, choice, cooked, roasted','BEEF,RND,EYE OF RND RST,BNLESS,LN,0" FAT,CHOIC,CKD,RSTD',13419,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round roast, boneless, separable lean only, trimmed to 0" fat, select, cooked, roasted','BEEF,RND,EYE OF RND RST,BNLESS,LN,0" FAT,SEL,CKD,RSTD',13420,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, roast, separable lean and fat, trimmed to 0" fat, all grades, cooked, roasted','BEEF,RND,TIP RND,RST,LN & FAT,0" FAT,ALL GRDS,CKD,RSTD',13421,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, roast, separable lean and fat, trimmed to 0" fat, choice, cooked, roasted','BEEF,RND,TIP RND,RST,LN & FAT,0" FAT,CHOIC,CKD,RSTD',13422,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, roast, separable lean and fat, trimmed to 0" fat, select, cooked, roasted','BEEF,RND,TIP RND,RST,LN & FAT,0" FAT,SEL,CKD,RSTD',13423,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, roast, separable lean only, trimmed to 0" fat, all grades, cooked, roasted','BEEF,RND,TIP RND,RST,LN,0" FAT,ALL GRDS,CKD,RSTD',13424,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, roast, separable lean only, trimmed to 0" fat, choice, cooked, roasted','BEEF,RND,TIP RND,RST,LN,0" FAT,CHOIC,CKD,RSTD',13425,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, roast, separable lean only, trimmed to 0" fat, select, cooked, roasted','BEEF,RND,TIP RND,RST,LN,0" FAT,SEL,CKD,RSTD',13426,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, separable lean and fat, trimmed to 0" fat, all grades, cooked, braised','BEEF,RND,TOP RND,LN&FAT,0"FAT,ALL GRDS,CKD,BRSD',13428,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, separable lean and fat, trimmed to 0" fat, choice, cooked, braised','BEEF,RND,TOP RND,LN&FAT,0"FAT,CHOIC,CKD,BRSD',13430,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, separable lean and fat, trimmed to 0" fat, select, cooked, braised','BEEF,RND,TOP RND,LN&FAT,0"FAT,SEL,CKD,BRSD',13432,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, separable lean only, trimmed to 0" fat, choice, cooked, braised','BEEF,RND,TOP RND,LN,0"FAT,CHOIC,CKD,BRSD',13436,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, separable lean only, trimmed to 0" fat, select, cooked, braised','BEEF,RND,TOP RND,LN,0"FAT,SEL,CKD,BRSD',13438,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BEEF,LOIN,TNDRLN STEAK,BNLESS,L & F,0" F,A GRDS,CKD,GRILLED',13439,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin steak, boneless, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BEEF,LOIN,TENDERLOIN STK,BNLESS,L & F,0" F,CHOIC,CKD,GRLLED',13440,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin steak, boneless, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BEEF,LOIN,TENDERLOIN STK,BNLESS,L & F,0" FAT,SEL,CKD,GRILLED',13441,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin steak, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, grilled','BEEF,LOIN,TENDERLOIN STK,BNLESS,L,0" F,ALL GRDS,CKD,GRILLED',13442,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin steak, boneless, separable lean only, trimmed to 0" fat, choice, cooked, grilled','BEEF,LOIN,TENDERLOIN STEAK,BNLESS,LN,0" FAT,CHOIC,CKD,GRLLED',13443,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin steak, boneless, separable lean only, trimmed to 0" fat, select, cooked, grilled','BEEF,LOIN,TENDERLOIN STEAK,BNLESS,LN,0" FAT,SEL,CKD,GRILLED',13444,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip off, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BEEF,LOIN,TOPLOINSTK,BNLS,LIPOFF,LN FT,0" FT,ALLGRD,CKD,GRLD',13445,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip off, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BEEF,LOIN,TOPLOINSTK,BNLS,LIP OFF,LN FT,0" FT,CHC,CKD,GRLD',13446,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip off, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BEEF,LOIN,TOPLOINSTK,BNLS,LIP OFF,LN FAT,0" FT,SEL,CKD,GRLD',13447,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip off, separable lean only, trimmed to 0" fat, all grades, cooked, grilled','BEEF,LOIN,TOPLOINSTK,BNLS,LIP OFF,LN,0" FT,ALL GRD,CKD,GRLD',13448,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip off, separable lean only, trimmed to 0" fat, choice, cooked, grilled','BEEF,LOIN,TOP LOIN STK,BNLS,LIP OFF,LN,0" FAT,CHOIC,CKD,GRLD',13449,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip off, separable lean only, trimmed to 0" fat, select, cooked, grilled','BEEF,LOIN,TOP LOIN STK,BNLS,LIP OFF,LN,0" FAT,SEL,CKD,GRLD',13450,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean and fat, trimmed to 0" fat, all grades, cooked, broiled','BEEF,TOP SIRLOIN,STEAK,LN & FAT,0" FAT,ALL GRDS,CKD,BRLD',13451,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean and fat, trimmed to 0" fat, choice, cooked, broiled','BEEF,TOP SIRLOIN,STEAK,LN & FAT,0" FAT,CHOIC,CKD,BRLD',13452,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean and fat, trimmed to 0" fat, select, cooked, broiled','BEEF,TOP SIRLOIN,STEAK,LN & FAT,0" FAT,SEL,CKD,BRLD',13453,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean only, trimmed to 0" fat, all grades, cooked, broiled','BEEF,TOP SIRLOIN,STEAK,LN,0" FAT,ALL GRDS,CKD,BRLD',13454,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean only, trimmed to 0" fat, choice, cooked, broiled','BEEF,TOP SIRLOIN,STEAK,LN,0" FAT,CHOIC,CKD,BRLD',13455,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean only, trimmed to 0" fat, select, cooked, broiled','BEEF,TOP SIRLOIN,STEAK,LN,0" FAT,SEL,CKD,BRLD',13456,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean and fat, trimmed to 0" fat, all grades, cooked, broiled','BEEF,SHRT LOIN,PRTRHS STK,LN & FAT,0" FAT,ALL GRDS,CKD,BRLD',13459,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean and fat, trimmed to 0" fat, USDA choice, cooked, broiled','BEEF,LOIN,PRTRHS STK,LN & FAT,0" FAT,USDA CHOIC,CKD,BRLD',13460,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean and fat, trimmed to 0" fat, USDA select, cooked, broiled','BEEF,SHRT LOIN,PRTRHS STK,LN & FAT,0" FAT,USDA SEL,CKD,BRLD',13463,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,SHRT LOIN,PRTRHS STEAK,LN,1/8" FAT,ALL GRDS,RAW',13464,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean only,  trimmed to 1/8" fat, all grades, cooked, grilled','BEEF,SHRT LOIN,PRTRHS STEAK,LN,1/8" FAT,ALL GRDS,CKD,GRILLED',13465,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean only, trimmed to 0" fat, all grades, cooked, broiled','BEEF,SHRT LOIN,PRTRHS STEAK,LN,0" FAT,ALL GRDS,CKD,BRLD',13466,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean only, trimmed to 0" fat, choice, cooked, broiled','BEEF,SHRT LOIN,PRTRHS STEAK,LN,0" FAT,CHOIC,CKD,BRLD',13467,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,SHRT LOIN,PRTRHS STEAK,LN,1/8" FAT,SEL,RAW',13468,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean only, trimmed to 1/8" fat, select, cooked, grilled','BEEF,SHRT LOIN,PRTRHS STEAK,LN,1/8" FAT,SEL,CKD,GRILLED',13469,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean only, trimmed to 0" fat, select, cooked, broiled','BEEF,SHRT LOIN,PRTRHS STEAK,LN,0" FAT,SEL,CKD,BRLD',13470,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, separable lean and fat, trimmed to 0" fat, all grades, cooked, broiled','BEEF,SHRT LOIN,T-BONE STK,LN & FAT,0" FAT,ALL GRDS,CKD,BRLD',13473,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, separable lean and fat, trimmed to 0" fat, USDA choice, cooked, broiled','BEEF,LOIN,T-BONE STEAK,LN & FAT,0" FAT,USDA CHOIC,CKD,BRLD',13474,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, separable lean and fat, trimmed to 0" fat, USDA select, cooked, broiled','BEEF,SHRT LOIN,T-BONE STK,LN & FAT,0" FAT,USDA SEL,CKD,BRLD',13477,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, bone-in, separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,SHRT LOIN,T-BONE STEAK,BONE-IN,LN,1/8" FAT,ALL GRDS,RAW',13478,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, bone-in, separable lean only, trimmed to 1/8" fat, all grades, cooked, grilled','BEEF,SHRT LN,T-BN STK,BN-IN,LN,1/8" FAT,ALL GRDS,CKD,GRILLED',13479,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, separable lean only, trimmed to 0" fat, choice, cooked, broiled','BEEF,SHRT LOIN,T-BONE STEAK,LN,0" FAT,CHOIC,CKD,BRLD',13481,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, bone-in, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,SHRT LOIN,T-BONE STEAK,BONE-IN,LN,1/8" FAT,SEL,RAW',13482,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, bone-in, separable lean only, trimmed to 1/8" fat, select, cooked, grilled','BEEF,SHRT LN,T-BONE STK,BONE-IN,LN,1/8" FAT,SEL,CKD,GRILLED',13483,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, separable lean only, trimmed to 0" fat, select, cooked, broiled','BEEF,SHRT LOIN,T-BONE STEAK,LN,0" FAT,SEL,CKD,BRLD',13484,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean only, trimmed to 0" fat, select, cooked, braised','BEEF,BRISKET,FLAT HALF,LN,0" FAT,SEL,CKD,BRSD',13485,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, roast, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,RND,TIP RND,RST,LN & FAT,0" FAT,ALL GRDS,RAW',13486,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, roast, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,RND,TIP RND,RST,LN & FAT,0" FAT,CHOIC,RAW',13487,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, roast, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,RND,TIP RND,RST,LN & FAT,0" FAT,SEL,RAW',13488,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, eye, small end (ribs 10- 12) separable lean only, trimmed to 0" fat, select, cooked, broiled','BEEF,RIB,EYE,SML END (RIBS 10- 12) LN,0" FAT,SEL,CKD,BRLD',13490,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round steak, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, grilled','BEEF,RND,TOP RND STEAK,BNLESS,LN,0" FAT,ALL GRDS,CKD,GRILLED',13491,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round steak, boneless, separable lean only, trimmed to 0" fat, choice, cooked, grilled','BEEF,RND,TOP RND STEAK,BNLESS,LN,0" FAT,CHOIC,CKD,GRILLED',13492,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round steak, boneless, separable lean only, trimmed to 0" fat, select, cooked, grilled','BEEF,RND,TOP RND STEAK,BNLESS,LN,0" FAT,SEL,CKD,GRILLED',13493,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 70% lean meat / 30% fat, crumbles, cooked, pan-browned','BEEF,GROUND,70% LN MEAT / 30% FAT,CRUMBLES,CKD,PAN-BROWNED',13494,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 70% lean meat / 30% fat, loaf, cooked, baked','BEEF,GROUND,70% LN MEAT / 30% FAT,LOAF,CKD,BKD',13495,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 70% lean meat / 30% fat, patty cooked, pan-broiled','BEEF,GROUND,70% LN MEAT / 30% FAT,PATTY CKD,PAN-BROILED',13496,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 70% lean meat / 30% fat, patty, cooked, broiled','BEEF,GROUND,70% LN MEAT / 30% FAT,PATTY,CKD,BRLD',13497,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 70% lean meat / 30% fat, raw','BEEF,GROUND,70% LN MEAT / 30% FAT,RAW',13498,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade center steak, boneless, Denver Cut, separable lean only, trimmed to 0" fat, select, raw','BEEF,CHK,UND BL CNTR STK,BNLESS,DEN CUT,LN,0" FA, SEL, RAW',13499,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder top blade steak, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, grilled','BEEF,SHLDR TOP BLADE STEAK,BNLESS,LN,0" FAT,ALL GRDS,CKD,GRI',13500,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder top blade steak, boneless, separable lean only, trimmed to 0" fat, choice, cooked, grilled','BEEF,SHLDR TOP BLADE STEAK,BNLESS,LN,0" FAT,CHOIC,CKD,GRILLE',13501,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder top blade steak, boneless, separable lean only, trimmed to 0" fat, select, cooked, grilled','BEEF,SHLDR TOP BLADE STEAK,BNLESS,LN,0" FAT,SEL,CKD,GRILLED',13502,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder top blade steak, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,SHLDR TOP BLADE STEAK,BNLESS,LN,0" FAT,ALL GRDS,RAW',13519,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder top blade steak, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,SHLDR TOP BLADE STEAK,BNLESS,LN,0" FAT,CHOIC,RAW',13520,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder top blade steak, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,SHLDR TOP BLADE STEAK,BNLESS,LN,0" FAT,SEL,RAW',13523,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, boneless separable lean only, trimmed to 0" fat, all grades, raw','BEEF,BRISKET,FLAT HALF,BNLESS LN,0" FAT,ALL GRDS,RAW',13595,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,BRISKET,FLAT HALF,BNLESS LN,0" FAT,ALL CHOICE,RAW',13596,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,BRISKET,FLAT HALF,BNLESS,LN,0" FAT,SEL,RAW',13597,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder top blade steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BEEF,SHLDR TOP BLADE STK,BNLES,LN & FAT,0" ,ALL GRDS,CKD,G',13598,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder pot roast or steak, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,SHLDR POT RST OR STEAK,BNLESS,LN,0" FAT,ALL GRDS,RAW',13647,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder pot roast or steak, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,SHLDR POT RST OR STEAK,BNLESS,LN,0" FAT,CHOIC,RAW',13648,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder pot roast or steak, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,SHLDR POT RST OR STEAK,BNLESS,LN,0" FAT,SEL,RAW',13649,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder top blade steak, boneless, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BEEF,SHLDR TOP BLDE STK,BNS,LN & FAT,0" FAT,CHOIC,CKD,G',13650,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye roast, boneless, America''s Beef Roast, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,CHUCK EYE RST,BNLESS,A BF RST,LN & FAT,0",ALL G,RAW',13786,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye roast, boneless, America''s Beef Roast, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,CHUCK EYE RST,BNLS,A BF RST,LN & FAT,0" FAT,CHOIC,RAW',13788,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye roast, boneless, America''s Beef Roast, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,CHUCK EYE RST,BNLS,A BF RST,LN & FAT,0" FAT,SEL,RAW',13791,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,COMP OF RTL CUTS,LN&FAT,1/8"FAT,ALL GRDS,RAW',13795,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean and fat, trimmed to 1/8" fat, all grades, cooked','BEEF,COMP OF RTL CUTS,LN&FAT,1/8"FAT,ALL GRDS,CKD',13796,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,COMP OF RTL CUTS,LN&FAT,1/8"FAT,CHOIC,RAW',13797,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean and fat, trimmed to 1/8" fat, choice, cooked','BEEF,COMP OF RTL CUTS,LN&FAT,1/8"FAT,CHOIC,CKD',13798,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,COMP OF RTL CUTS,LN&FAT,1/8"FAT,SEL,RAW',13799,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean and fat, trimmed to 1/8" fat, select, cooked','BEEF,COMP OF RTL CUTS,LN&FAT,1/8"FAT,SEL,CKD',13800,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, whole, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,BRISKET,WHL,LN&FAT,1/8"FAT,ALL GRDS,RAW',13803,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, whole, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, braised','BEEF,BRISKET,WHL,LN&FAT,1/8"FAT,ALL GRDS,CKD,BRSD',13804,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,BRISKET,FLAT HALF,LN&FAT,1/8"FAT,ALL GRDS,RAW',13805,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, braised','BEEF,BRISKET,FLAT HALF,LN&FAT,1/8"FAT,ALL GRDS,CKD,BRSD',13806,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, point half, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,BRISKET,POINT HALF,LN&FAT,1/8"FAT,ALL GRDS,RAW',13807,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, point half, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, braised','BEEF,BRISKET,POINT HALF,LN&FAT,1/8"FAT,ALL GRDS,CKD,BRSD',13808,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,CHUCK,ARM POT RST,LN&FAT,1/8"FAT,ALL GRDS,RAW',13809,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, braised','BEEF,CHUCK,ARM POT RST,LN&FAT,1/8"FAT,ALL GRDS,CKD,BRSD',13810,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,CHUCK,ARM POT RST,LN&FAT,1/8"FAT,CHOIC,RAW',13811,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean and fat, trimmed to 1/8" fat, choice, cooked, braised','BEEF,CHUCK,ARM POT RST,LN&FAT,1/8"FAT,CHOIC,CKD,BRSD',13812,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,CHUCK,ARM POT RST,LN&FAT,1/8"FAT,SEL,RAW',13813,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean and fat, trimmed to 1/8" fat, select, cooked, braised','BEEF,CHUCK,ARM POT RST,LN&FAT,1/8"FAT,SEL,CKD,BRSD',13814,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, blade roast, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,CHUCK,BLADE RST,LN&FAT,1/8"FAT,ALL GRDS,RAW',13815,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, blade roast, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, braised','BEEF,CHUCK,BLADE RST,LN&FAT,1/8"FAT,ALL GRDS,CKD,BRSD',13816,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, blade roast, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,CHUCK,BLADE RST,LN&FAT,1/8"FAT,CHOIC,RAW',13817,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, blade roast, separable lean and fat, trimmed to 1/8" fat, choice, cooked, braised','BEEF,CHUCK,BLADE RST,LN&FAT,1/8"FAT,CHOIC,CKD,BRSD',13818,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, blade roast, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,CHUCK,BLADE RST,LN&FAT,1/8"FAT,SEL,RAW',13819,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, blade roast, separable lean and fat, trimmed to 1/8" fat, select, cooked, braised','BEEF,CHUCK,BLADE RST,LN&FAT,1/8"FAT,SEL,CKD,BRSD',13820,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye roast, boneless, America''s Beef Roast, separable lean only, trimmed to 0" fat, all grades, cooked, roasted','BEEF,CHK EYE RST,BNL,AMERICA''S BF RST,LN,0" FAT,ALL GRD, CKD',13821,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye roast, boneless, America''s Beef Roast, separable lean only, trimmed to 0" fat, choice, cooked, roasted','BEEF,CHK EYE RST,BNLESS,AMERICA''S BF RST,LN,0" FAT,CHOIC,CKD',13822,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye roast, boneless, America''s Beef Roast, separable lean only, trimmed to 0" fat, select, cooked, roasted','BEEF,CHUCK EYE RST,BNLESS,AMERICA''S BF RST,LN,0" FAT,SEL,CKD',13823,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, whole (ribs 6-12), separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,RIB,WHL (RIBS 6-12),LN&FAT,1/8"FAT,ALL GRDS,RAW',13824,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, whole (ribs 6-12), separable lean and fat, trimmed to 1/8" fat, all grades, cooked, broiled','BEEF,RIB,WHL (RIBS 6-12),LN&FAT,1/8"FAT,ALL GRDS,CKD,BRLD',13825,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, whole (ribs 6-12), separable lean and fat, trimmed to 1/8" fat, all grades, cooked, roasted','BEEF,RIB,WHL (RIBS 6-12),LN&FAT,1/8"FAT,ALL GRDS,CKD,RSTD',13826,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, whole (ribs 6-12), separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,RIB,WHL (RIBS 6-12),LN&FAT,1/8"FAT,CHOIC,RAW',13827,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, whole (ribs 6-12), separable lean and fat, trimmed to 1/8" fat, choice, cooked, broiled','BEEF,RIB,WHL (RIBS 6-12),LN&FAT,1/8"FAT,CHOIC,CKD,BRLD',13828,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, whole (ribs 6-12), separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','BEEF,RIB,WHL (RIBS 6-12),LN&FAT,1/8"FAT,CHOIC,CKD,RSTD',13829,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, whole (ribs 6-12), separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,RIB,WHL (RIBS 6-12),LN&FAT,1/8"FAT,SEL,RAW',13830,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, whole (ribs 6-12), separable lean and fat, trimmed to 1/8" fat, select, cooked, broiled','BEEF,RIB,WHL (RIBS 6-12),LN&FAT,1/8"FAT,SEL,CKD,BRLD',13831,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, whole (ribs 6-12), separable lean and fat, trimmed to 1/8" fat, select, cooked, roasted','BEEF,RIB,WHL (RIBS 6-12),LN&FAT,1/8"FAT,SEL,CKD,RSTD',13832,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, whole (ribs 6-12), separable lean and fat, trimmed to 1/8" fat, prime, raw','BEEF,RIB,WHL (RIBS 6-12),LN&FAT,1/8"FAT,PRIME,RAW',13833,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, whole (ribs 6-12), separable lean and fat, trimmed to 1/8" fat, prime, cooked, broiled','BEEF,RIB,WHL (RIBS 6-12),LN&FAT,1/8"FAT,PRIME,CKD,BRLD',13834,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, whole (ribs 6-12), separable lean and fat, trimmed to 1/8" fat, prime, cooked, roasted','BEEF,RIB,WHL (RIBS 6-12),LN&FAT,1/8"FAT,PRIME,CKD,RSTD',13835,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,RIB,LRG END (RIBS 6-9),LN&FAT,1/8"FAT,ALL GRDS,RAW',13838,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean and fat, trimmed to 1/8" fat, all grades, cooked, broiled','BEEF,RIB,LRG END (RIBS 6-9),LN&FAT,1/8"FAT,ALL GRDS,CKD,BRLD',13839,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean and fat, trimmed to 1/8" fat, all grades, cooked, roasted','BEEF,RIB,LRG END (RIBS 6-9),LN&FAT,1/8"FAT,ALL GRDS,CKD,RSTD',13840,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,RIB,LRG END (RIBS 6-9),LN&FAT,1/8"FAT,CHOIC,RAW',13841,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean and fat, trimmed to 1/8" fat, choice, cooked, broiled','BEEF,RIB,LRG END (RIBS 6-9),LN&FAT,1/8"FAT,CHOIC,CKD,BRLD',13842,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','BEEF,RIB,LRG END (RIBS 6-9),LN&FAT,1/8"FAT,CHOIC,CKD,RSTD',13843,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,RIB,LRG END (RIBS 6-9),LN&FAT,1/8"FAT,SEL,RAW',13844,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean and fat, trimmed to 1/8" fat, select, cooked, broiled','BEEF,RIB,LRG END (RIBS 6-9),LN&FAT,1/8"FAT,SEL,CKD,BRLD',13845,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean and fat, trimmed to 1/8" fat, select, cooked, roasted','BEEF,RIB,LRG END (RIBS 6-9),LN&FAT,1/8"FAT,SEL,CKD,RSTD',13846,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean and fat, trimmed to 1/8" fat, prime, raw','BEEF,RIB,LRG END (RIBS 6-9),LN&FAT,1/8"FAT,PRIME,RAW',13847,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean and fat, trimmed to 1/8" fat, prime, cooked, broiled','BEEF,RIB,LRG END (RIBS 6-9),LN&FAT,1/8"FAT,PRIME,CKD,BRLD',13848,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, large end (ribs 6-9), separable lean and fat, trimmed to 1/8" fat, prime, cooked, roasted','BEEF,RIB,LRG END (RIBS 6-9),LN&FAT,1/8"FAT,PRIME,CKD,RSTD',13849,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,RIB,SML END (RIBS 10-12),LN&FAT,1/8"FAT,ALL GRDS,RAW',13850,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean and fat, trimmed to 1/8" fat, all grades, cooked, broiled','BEEF,RIB,SML END (RIBS 10-12),LN&FAT,1/8"FAT,ALL GRDS,CKD,BR',13851,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean and fat, trimmed to 1/8" fat, all grades, cooked, roasted','BEEF,RIB,SML END (RIBS 10-12),LN&FAT,1/8"FAT,ALL GRDS,CKD,RS',13852,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,RIB,SML END (RIBS 10-12),LN&FAT,1/8"FAT,CHOIC,RAW',13853,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean and fat, trimmed to 1/8" fat, choice, cooked, broiled','BEEF,RIB,SML END (RIBS 10-12),LN&FAT,1/8"FAT,CHOIC,CKD,BRLD',13854,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','BEEF,RIB,SML END (RIBS 10-12),LN&FAT,1/8"FAT,CHOIC,CKD,RSTD',13855,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,RIB,SML END (RIBS 10-12),LN&FAT,1/8"FAT,SEL,RAW',13856,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean and fat, trimmed to 1/8" fat, select, cooked, broiled','BEEF,RIB,SML END (RIBS 10-12),LN&FAT,1/8"FAT,SEL,CKD,BRLD',13857,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean and fat, trimmed to 1/8" fat, select, cooked, roasted','BEEF,RIB,SML END (RIBS 10-12),LN&FAT,1/8"FAT,SEL,CKD,RSTD',13858,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean and fat, trimmed to 1/8" fat, prime, raw','BEEF,RIB,SML END (RIBS 10-12),LN&FAT,1/8"FAT,PRIME,RAW',13859,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean and fat, trimmed to 1/8" fat, prime, cooked, broiled','BEEF,RIB,SML END (RIBS 10-12),LN&FAT,1/8"FAT,PRIME,CKD,BRLD',13860,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean and fat, trimmed to 1/8" fat, prime, cooked, roasted','BEEF,RIB,SML END (RIBS 10-12),LN&FAT,1/8"FAT,PRIME,CKD,RSTD',13861,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder top blade steak, boneless, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BEEF,SHLDR TOP BLDE STK,BNLS,LN & FAT,0" FAT,SEL,CKD,G',13862,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder top blade steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,SHLDR TOP BLADE STEAK,BNLS,LN & FAT,0" FAT,ALL GRDS,RAW',13863,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, full cut, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,RND,FULL CUT,LN&FAT,1/8"FAT,CHOIC,RAW',13864,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, full cut, separable lean and fat, trimmed to 1/8" fat, choice, cooked, broiled','BEEF,RND,FULL CUT,LN&FAT,1/8"FAT,CHOIC,CKD,BRLD',13865,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, full cut, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,RND,FULL CUT,LN&FAT,1/8"FAT,SEL,RAW',13866,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, full cut, separable lean and fat, trimmed to 1/8" fat, select, cooked, broiled','BEEF,RND,FULL CUT,LN&FAT,1/8"FAT,SEL,CKD,BRLD',13867,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, steak, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,RND,BTTM RND,STEAK,LN & FAT,1/8" FAT,ALL GRDS,RAW',13868,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, steak, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, braised','BEEF,RND,BTTM RND,STEAK,LN & FAT,1/8" FAT,ALL GRDS,CKD,BRSD',13869,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, roast, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, roasted','BEEF,RND,BTTM RND,RST,LN & FAT,1/8" FAT,ALL GRDS,CKD,RSTD',13870,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, steak, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,RND,BTTM RND,STEAK,LN & FAT,1/8" FAT,CHOIC,RAW',13871,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, steak, separable lean and fat, trimmed to 1/8" fat, choice, cooked, braised','BEEF,RND,BTTM RND,STEAK,LN & FAT,1/8" FAT,CHOIC,CKD,BRSD',13872,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, roast, separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','BEEF,RND,BTTM RND,RST,LN & FAT,1/8" FAT,CHOIC,CKD,RSTD',13873,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, steak, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,RND,BTTM RND,STEAK,LN & FAT,1/8" FAT,SEL,RAW',13874,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, steak, separable lean and fat, trimmed to 1/8" fat, select, cooked, braised','BEEF,RND,BTTM RND,STEAK,LN & FAT,1/8" FAT,SEL,CKD,BRSD',13875,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, roast, separable lean and fat, trimmed to 1/8" fat, select, cooked, roasted','BEEF,RND,BTTM RND,RST,LN & FAT,1/8" FAT,SEL,CKD,RSTD',13876,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round, roast, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,RND,EYE OF RND,RST,LN & FAT,1/8" FAT,ALL GRDS,RAW',13877,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round, roast, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, roasted','BEEF,RND,EYE OF RND,RST,LN & FAT,1/8" FAT,ALL GRDS,CKD,RSTD',13878,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round, roast, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,RND,EYE OF RND,RST,LN & FAT,1/8" FAT,CHOIC,RAW',13879,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round, roast, separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','BEEF,RND,EYE OF RND,RST,LN & FAT,1/8" FAT,CHOIC,CKD,RSTD',13880,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round, roast, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,RND,EYE OF RND,RST,LN & FAT,1/8" FAT,SEL,RAW',13881,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round, roast, separable lean and fat, trimmed to 1/8" fat, select, cooked, roasted','BEEF,RND,EYE OF RND,RST,LN & FAT,1/8" FAT,SEL,CKD,RSTD',13882,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,RND,TIP RND,LN&FAT,1/8"FAT,ALL GRDS,RAW',13883,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, roast, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, roasted','BEEF,RND,TIP RND,RST,LN & FAT,1/8" FAT,ALL GRDS,CKD,RSTD',13884,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,RND,TIP RND,LN&FAT,1/8"FAT,CHOIC,RAW',13885,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, roast, separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','BEEF,RND,TIP RND,RST,LN & FAT,1/8" FAT,CHOIC,CKD,RSTD',13886,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,RND,TIP RND,LN&FAT,1/8"FAT,SEL,RAW',13887,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, roast, separable lean and fat, trimmed to 1/8" fat, select, cooked, roasted','BEEF,RND,TIP RND,RST,LN & FAT,1/8" FAT,SEL,CKD,RSTD',13888,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder top blade steak, boneless, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,SHLDR TOP BLADE STEAK,BNLESS,LN & FAT,0" FAT,CHOIC,RAW',13889,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, separable lean only, trimmed to 1/8" fat, choice, cooked, pan-fried','BEEF,RND,TOP RND,LN,1/8" FAT,CHOIC,CKD,PAN-FRIED',13890,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, steak, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,RND,TOP RND,STEAK,LN & FAT,1/8" FAT,ALL GRDS,RAW',13891,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, braised','BEEF,RND,TOP RND,LN&FAT,1/8"FAT,ALL GRDS,CKD,BRSD',13892,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round steak, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, broiled','BEEF,RND,TOP RND STEAK,LN & FAT,1/8" FAT,ALL GRDS,CKD,BRLD',13893,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, steak, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,RND,TOP RND,STEAK,LN & FAT,1/8" FAT,CHOIC,RAW',13894,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, separable lean and fat, trimmed to 1/8" fat, choice, cooked, braised','BEEF,RND,TOP RND,LN&FAT,1/8"FAT,CHOIC,CKD,BRSD',13895,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, steak, separable lean and fat, trimmed to 1/8" fat, choice, cooked, broiled','BEEF,RND,TOP RND,STEAK,LN & FAT,1/8" FAT,CHOIC,CKD,BRLD',13896,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, separable lean and fat, trimmed to 1/8" fat, choice, cooked, pan-fried','BEEF,RND,TOP RND,LN&FAT,1/8"FAT,CHOIC,CKD,PAN-FRIED',13897,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, steak, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,RND,TOP RND,STEAK,LN & FAT,1/8" FAT,SEL,RAW',13898,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, separable lean and fat, trimmed to 1/8" fat, select, cooked, braised','BEEF,RND,TOP RND,LN&FAT,1/8"FAT,SEL,CKD,BRSD',13899,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, steak, separable lean and fat, trimmed to 1/8" fat, select, cooked, broiled','BEEF,RND,TOP RND,STEAK,LN & FAT,1/8" FAT,SEL,CKD,BRLD',13900,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, separable lean and fat, trimmed to 1/8" fat, prime, raw','BEEF,RND,TOP RND,LN&FAT,1/8"FAT,PRIME,RAW',13901,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, steak, separable lean and fat, trimmed to 1/8" fat, prime, cooked, broiled','BEEF,RND,TOP RND,STEAK,LN & FAT,1/8" FAT,PRIME,CKD,BRLD',13902,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder top blade steak, boneless, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,SHLDR TOP BLADE STEAK,BNLESS,LN & FAT,0" FAT,SEL,RAW',13903,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, boneless, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,BRISKET,FLAT HALF,BNLESS,LN & FAT,0" FAT,ALL GRDS,RAW',13904,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,SHRT LOIN,PRTRHS STEAK,LN&FAT,1/8"FAT,CHOIC,RAW',13905,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean and fat, trimmed to 1/8" fat, choice, cooked, grilled','BEEF,SHRT LOIN,PRTRHS STK,LN & FAT,1/8" FAT,CHOIC,CKD,GRILLD',13906,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,SHRT LOIN,T-BONE STEAK,LN&FAT,1/8"FAT,CHOIC,RAW',13907,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, separable lean and fat, trimmed to 1/8" fat, choice, cooked, grilled','BEEF,SHRT LN,T-BONE STK,L & F,1/8" FAT,CHOIC,CKD,GRILLED',13908,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, top loin, steak, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,SHRT LOIN,TOP LOIN,STEAK,LN & FAT,1/8" FAT,ALL GRDS,RAW',13909,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, grilled','BEEF,LOIN,TOP LOIN,LN & FAT,1/8" FAT,ALL GRDS,CKD,GRILLED',13910,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,LOIN,TOP LOIN,LN & FAT,1/8" FAT,CHOIC,RAW',13911,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, top loin, steak, separable lean and fat, trimmed to 1/8" fat, choice, cooked, grilled','BEEF,SHRT LOIN,TOP LN,STK,LN & FAT,1/8" FAT,CHOIC,CKD,GRLLD',13912,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,LOIN,TOP LOIN,LN & FAT,1/8" FAT,SEL,RAW',13913,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin, separable lean and fat, trimmed to 1/8" fat, select, cooked, grilled','BEEF,LOIN,TOP LOIN,LN & FAT,1/8" FAT,SEL,CKD,GRILLED',13914,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, top loin, steak, separable lean and fat, trimmed to 1/8" fat, prime, raw','BEEF,SHRT LOIN,TOP LOIN,STEAK,LN & FAT,1/8" FAT,PRIME,RAW',13915,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, top loin, separable lean and fat, trimmed to 1/8" fat, prime, cooked, broiled','BEEF,SHRT LOIN,TOP LOIN,LN&FAT,1/8"FAT,PRIME,CKD,BRLD',13916,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, steak, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,TENDERLOIN,STEAK,LN & FAT,1/8" FAT,ALL GRDS,RAW',13917,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, steak, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, broiled','BEEF,TENDERLOIN,STEAK,LN & FAT,1/8" FAT,ALL GRDS,CKD,BRLD',13918,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, roast, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, roasted','BEEF,TENDERLOIN,RST,LN & FAT,1/8" FAT,ALL GRDS,CKD,RSTD',13919,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, steak, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,TENDERLOIN,STEAK,LN & FAT,1/8" FAT,CHOIC,RAW',13920,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, steak, separable lean and fat, trimmed to 1/8" fat, choice, cooked, broiled','BEEF,TENDERLOIN,STEAK,LN & FAT,1/8" FAT,CHOIC,CKD,BRLD',13921,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, roast, separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','BEEF,TENDERLOIN,RST,LN & FAT,1/8" FAT,CHOIC,CKD,RSTD',13922,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, steak, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,TENDERLOIN,STEAK,LN & FAT,1/8" FAT,SEL,RAW',13923,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, steak, separable lean and fat, trimmed to 1/8" fat, select, cooked, broiled','BEEF,TENDERLOIN,STEAK,LN & FAT,1/8" FAT,SEL,CKD,BRLD',13924,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, roast, separable lean and fat, trimmed to 1/8" fat, select, cooked, roasted','BEEF,TENDERLOIN,RST,LN & FAT,1/8" FAT,SEL,CKD,RSTD',13925,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, separable lean and fat, trimmed to 1/8" fat, prime, raw','BEEF,TENDERLOIN,LN&FAT,1/8"FAT,PRIME,RAW',13926,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, steak, separable lean and fat, trimmed to 1/8" fat, prime, cooked, broiled','BEEF,TENDERLOIN,STEAK,LN & FAT,1/8" FAT,PRIME,CKD,BRLD',13927,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, roast, separable lean and fat, trimmed to 1/8" fat, prime, cooked, roasted','BEEF,TENDERLOIN,RST,LN & FAT,1/8" FAT,PRIME,CKD,RSTD',13928,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,TOP SIRLOIN,STEAK,LN & FAT,1/8" FAT,ALL GRDS,RAW',13929,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, broiled','BEEF,TOP SIRLOIN,STEAK,LN & FAT,1/8" FAT,ALL GRDS,CKD,BRLD',13930,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,TOP SIRLOIN,STEAK,LN & FAT,1/8" FAT,CHOIC,RAW',13931,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean and fat, trimmed to 1/8" fat, choice, cooked, broiled','BEEF,TOP SIRLOIN,STEAK,LN & FAT,1/8" FAT,CHOIC,CKD,BRLD',13932,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean and fat, trimmed to 1/8" fat, choice, cooked, pan-fried','BEEF,TOP SIRLOIN,STEAK,LN & FAT,1/8" FAT,CHOIC,CKD,PAN-FRIED',13933,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,TOP SIRLOIN,STEAK,LN & FAT,1/8" FAT,SEL,RAW',13934,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean and fat, trimmed to 1/8" fat, select, cooked, broiled','BEEF,TOP SIRLOIN,STEAK,LN & FAT,1/8" FAT,SEL,CKD,BRLD',13935,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, clod roast, separable lean only, trimmed to 0" fat, choice, cooked, roasted','BEEF,CHUCK,CLOD RST,LN,0" FAT,CHOIC,CKD,RSTD',13937,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, clod roast, separable lean only, trimmed to 0" fat, select, cooked, roasted','BEEF,CHUCK,CLOD RST,LN,0" FAT,SEL,CKD,RSTD',13940,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder steak, boneless, separable lean only, trimmed to 0" fat, choice, cooked, grilled','Beef, shoulder steak, boneless, lean only, 0", choice, grill',13943,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder steak, boneless, separable lean only, trimmed to 0" fat, select, cooked, grilled','BEEF,SHLDR STEAK,BNLESS,LN,0" FAT,SEL,CKD,GRILLED',13946,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, flank, steak, separable lean and fat, trimmed to 0" fat, all grades, cooked, broiled','BEEF,FLANK,STEAK,LN & FAT,0" FAT,ALL GRDS,CKD,BRLD',13948,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, flank, steak, separable lean and fat, trimmed to 0" fat, select, cooked, broiled','BEEF,FLANK,STEAK,LN & FAT,0" FAT,SEL,CKD,BRLD',13949,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean and fat, trimmed to 0" fat, select, cooked, braised','BEEF,BRISKET,FLAT HALF,LN & FAT,0" FAT,SEL,CKD,BRSD',13950,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye, small end (ribs 10-12), separable lean and fat, trimmed to 0" fat, select, cooked, broiled','BEEF,RIB EYE,SML END (RIBS 10-12),LN & FAT,0",SEL,CKD,BRLD',13951,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye, small end (ribs 10-12), separable lean and fat, trimmed to 0" fat, all grades, cooked, broiled','BEEF,RIBEYE,SML END(RIBS 10-12),LN&FAT,0",ALL GRDS,CKD,BRLD',13952,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, bottom sirloin, tri-tip roast, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,BTTM SIRLOIN,TRI-TIP RST,LN & FAT,0" FAT,ALL GRDS,RAW',13954,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, bottom sirloin, tri-tip roast, separable lean and fat, trimmed to 0" fat, choice, cooked, roasted','BEEF,BTTM SIRLOIN,TRI-TIP RST,LN & FAT,0" FAT,CHOIC,CKD,RSTD',13955,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, bottom sirloin, tri-tip roast, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,BTTM SIRLOIN,TRI-TIP RST,LN & FAT,0" FAT,CHOIC,RAW',13956,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, bottom sirloin, tri-tip roast, separable lean and fat, trimmed to 0" fat, select, cooked, roasted','BEEF,BTTM SIRLOIN,TRI-TIP RST,LN & FAT,0" FAT,SEL,CKD,RSTD',13957,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, bottom sirloin, tri-tip roast, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,BTTM SIRLOIN,TRI-TIP RST,LN & FAT,0" FAT,SEL,RAW',13958,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BEEF,RND,TOP RND STK,BNLS,LN & FAT,0" FAT,ALL GRDS,CKD,GRLD',13959,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, separable lean only, trimmed to 0" fat, choice, cooked, broiled','BEEF,CHUCK,MOCK TENDER STEAK,LN,0" FAT,CHOIC,CKD,BRLD',13961,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, separable lean only, trimmed to 0" fat, select, cooked, broiled','BEEF,CHUCK,MOCK TENDER STEAK,LN,0" FAT,SEL,CKD,BRLD',13963,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, top blade, separable lean only, trimmed to 0" fat, choice, cooked, broiled','BEEF,CHUCK,TOP BLADE,LN,0" FAT,CHOIC,CKD,BRLD',13965,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, top blade, separable lean only, trimmed to 0" fat, select, cooked, broiled','BEEF,CHUCK,TOP BLADE,LN,0" FAT,SEL,CKD,BRLD',13967,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round steak, boneless, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BEEF,RND,TOP RND STK,BNLS,LN & FAT,0" FAT,CHOIC,CKD,GRLD',13968,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round steak, boneless, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BEEF,RND,TOP RND STEAK,BNLS,LN & FAT,0" FAT,SEL,CKD,GRLD',13969,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, flank, steak, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,FLANK,STEAK,LN & FAT,0" FAT,ALL GRDS,RAW',13970,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, flank, steak, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,FLANK,STEAK,LN & FAT,0" FAT,SEL,RAW',13971,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye roast, boneless, America''s Beef Roast, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,CHK EYE RST,BNL,AMERICA''S BF RST,LN,0" FAT,ALL GRD, RAW',13972,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye roast, boneless, America''s Beef Roast, separable lean only, trimmed to 0" fat, choice, raw','BEEF,CHK EYE RST,BNL,AMERICA''S BF RST,LN,0" FAT,CHOIC,RAW',13973,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye roast, boneless, America''s Beef Roast, separable lean only, trimmed to 0" fat, select, raw','BEEF,CHUCK EYE RST,BNLESS,AMERICA''S BF RST,LN,0" FAT,SEL,RAW',13974,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, boneless, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,BRISKET,FLAT HALF,BNLESS,LN & FAT,0" FAT,CHOIC,RAW',13975,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate, inside skirt steak, separable lean only, trimmed to 0" fat, all grades, cooked, broiled','BEEF,PLATE,INSIDE SKIRT STEAK,LN,0" FAT,ALL GRDS,CKD,BRLD',13977,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate, outside skirt steak, separable lean only, trimmed to 0" fat, all grades, cooked, broiled','BEEF,PLATE,OUTSIDE SKIRT STEAK,LN,0" FAT,ALL GRDS,CKD,BRLD',13979,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, short ribs, boneless, separable lean only, trimmed to 0" fat, choice, cooked, braised','BEEF, CHUCK, SHORT RIBS, BNL, 0" FAT, CHOICE, CKED, BR',13980,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, short ribs, boneless, separable lean only, trimmed to 0" fat, select, cooked, braised','BEEF,CHUCK,SHRT RIBS,BNLESS,LN,0" FAT,SEL,CKD,BRSD',13981,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, short ribs, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, braised','BEEF,CHUCK,SHRT RIBS,BNLESS,LN,0" FAT,ALL GRDS,CKD,BRSD',13982,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, boneless, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,BRISKET,FLAT HALF,BNLESS,LN & FAT,0" FAT,SEL,RAW',13983,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, bottom sirloin butt, tri-tip roast, separable lean only, trimmed to 0" fat, all grades, cooked, roasted','BF,LOIN,BTTM SIRLOIN BUTT,TRI-TIP,LN,0" FAT,ALL GRD,CKD,RSTD',13985,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages,  Energy drink, Citrus','BEVERAGES,ENERGY DRK,CITRUS',14021,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, water, bottled, yumberry, pomegranate with anti-oxidants, zero calories','BEV,H2O,BTLD,YUMBERRY,POMEGRANATE W/ ANTI-OXIDANTS, 0 CAL',14031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, almond milk, chocolate, ready-to-drink','BEVERAGES,ALMOND MILK,CHOC,RTD',14054,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Acai berry drink, fortified','BEVERAGES,ACAI BERRY DRK,FORT',14056,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Whey protein powder isolate','BEVERAGES,WHEY PROT PDR ISOLATE',14058,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Energy Drink with carbonated water and high fructose corn syrup','BEVERAGES,ENERGY DRK W/ CARB H2O & HI FRUCTOSE CORN SYRUP',14060,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Energy Drink, sugar free','BEVERAGES,ENERGY DRK,SUGAR FREE',14061,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, chocolate powder, no sugar added','BEVERAGES,CHOC PDR,NO SUGAR ADDED',14063,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Orange juice, light, No pulp','BEVERAGES,ORANGE JUC,LT,NO PULP',14064,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Protein powder whey based','BEVERAGES,PROT PDR WHEY BSD',14066,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Protein powder soy based','BEVERAGES,PROT PDR SOY BSD',14067,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, yellow green colored citrus soft drink with caffeine','BEVERAGES,YEL GRN COLORED CITRUS SOFT DRK W/ CAFFEINE',14079,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Chocolate malt, powder, prepared with fat free milk','BEVERAGES,CHOC MALT,PDR,PREP W/ FAT FREE MILK',14083,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Coconut water, ready-to-drink, unsweetened','BEVERAGES,COCNT H2O,RTD,UNSWTND',14090,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, almond milk, unsweetened, shelf stable','BEVERAGES,ALMOND MILK,UNSWTND,SHELF STABLE',14091,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, chocolate almond milk, unsweetened, shelf-stable, fortified with vitamin D2 and E','BEV,CHOC ALMOND MILK,UNSWTND,SHELF-STABLE,FORT W/ VIT D2 & E',14092,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Mixed vegetable and fruit juice drink, with added nutrients','BEVERAGES,MXD VEG & FRUIT JUC DRK,W/ ADDED NUTR',14119,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, club soda','BEVERAGES,CARB,CLUB SODA',14121,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Carbonated beverage, cream soda','CARBONATED BEV,CRM SODA',14130,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, ginger ale','BEVERAGES,CARB,GINGER ALE',14136,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, grape soda','BEVERAGES,CARB,GRAPE SODA',14142,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, low calorie, other than cola or pepper,  without caffeine','BEVERAGES,CARB,LO CAL,OTHER THAN COLA OR PEPPER,WO/ CAFFEINE',14143,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, lemon-lime soda, no caffeine','BEVERAGES,CARB,LEMON-LIME SODA,NO CAFFEINE',14144,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, low calorie, cola or pepper-type, with aspartame, without caffeine','BEVERAGES,CARB,LO CAL,COLA OR PEPPER-TYPE,W/ ASPRT,WO/ CAF',14146,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, cola, without caffeine','BEVERAGES,CARB,COLA,WO/ CAFFEINE',14147,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, cola, regular','BEVERAGES,CARB,COLA,REG',14148,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, reduced sugar, cola, contains caffeine and sweeteners','BEVERAGES,CARB,RED SUGAR,COLA,CONTAINS CAFFEINE & SWEETENERS',14149,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, orange','BEVERAGES,CARB,ORANGE',14150,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, low calorie, other than cola or pepper, with aspartame, contains caffeine','BEV,CARB,LO CAL,OTHER THAN COLA OR PEPPER,W/ ASPRT, CAFFEINE',14151,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, pepper-type, contains caffeine','BEVERAGES,CARB,PEPPER-TYPE,CONTAINS CAFFEINE',14153,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, tonic water','BEVERAGES,CARB,TONIC H2O',14155,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, root beer','BEVERAGES,CARB,ROOT BEER',14157,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Kiwi Strawberry Juice Drink','BEVERAGES,KIWI STRAWBERRY JUC DRK',14161,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, chocolate drink, milk and soy based, ready to drink, fortified','BEVERAGES,CHOC DRK,MILK & SOY BSD,READY TO DRK,FORT',14163,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, chocolate malt powder, prepared with 1% milk, fortified','BEVERAGES,CHOC MALT PDR,PREP W/ 1% MILK,FORT',14164,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, limeade, high caffeine','BEVERAGES,CARB,LIMEADE,HI CAFFEINE',14165,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, low calorie, cola or pepper-types, with sodium saccharin, contains caffeine','BEV,CARB,LO CAL,COLA OR PEPER-TYPE,W/ NA SACCHARIN, CAFFEINE',14166,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Carob-flavor beverage mix, powder','BEVERAGES,CAROB-FLAVOR BEV MIX,PDR',14168,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Carob-flavor beverage mix, powder, prepared with whole milk','BEVERAGES,CAROB-FLAVOR BEV MIX,PDR,PREP W/ WHL MILK',14169,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coconut milk, sweetened, fortified with calcium, vitamins A, B12, D2','BEVERAGES,COCNT MILK,SWTND,FORT W/ CA,VITAMINS A,B12,D2',14171,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, ready to drink, vanilla, light, milk based, sweetened','BEVERAGES,COFFEE,READY TO DRK,VANILLA,LT,MILK BSD,SWTND',14173,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Lemonade fruit juice drink light, fortified with vitamin E and C','BEVE,LEMONADE FRUIT JUC DRK LT,FORT W/ VIT E & C',14174,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, chocolate-flavor beverage mix, powder, prepared with whole milk','BEVERAGES,CHOCOLATE-FLAVOR BEV MIX,PDR,PREP W/ WHL MILK',14177,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, ready to drink, milk based, sweetened','BEVERAGES,COFFEE,READY TO DRK,MILK BSD,SWTND',14179,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, brewed, breakfast blend','BEVERAGES,COFFEE,BREWED,BRKFST BLEND',14180,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, chocolate syrup','BEVERAGES,CHOC SYRUP',14181,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, chocolate syrup, prepared with whole milk','BEVERAGES,CHOC SYRUP,PREP W/ WHL MILK',14182,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, ready to drink, iced, mocha, milk based','BEVERAGES,COFFEE,READY TO DRK,ICED,MOCHA,MILK BSD',14183,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, Oolong, brewed','BEVERAGES,TEA,OOLONG,BREWED',14185,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Clam and tomato juice, canned','BEVERAGES,CLAM & TOMATO JUC,CND',14187,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, green, ready to drink, ginseng and honey, sweetened','BEVERAGES,TEA,GRN,READY TO DRK,GINSENG & HONEY,SWTND',14188,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, green, ready-to-drink, diet','BEVERAGES,TEA,GRN,RTD,DIET',14190,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, green, ready-to-drink, citrus, diet, fortified with vitamin C','BEVERAGES,TEA,GRN,RTD,CITRUS,DIET,FORT W/ VIT C',14191,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Cocoa mix, powder','BEVERAGES,COCOA MIX,PDR',14192,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Cocoa mix, powder, prepared with water','BEVERAGES,COCOA MIX,PDR,PREP W/ H2O',14194,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Cocoa mix, no sugar added, powder','BEVERAGES,COCOA MIX,NO SUGAR ADDED,PDR',14196,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, black, ready-to-drink, lemon, sweetened','BEVERAGES,TEA,BLACK,RTD,LEMON,SWTND',14199,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, brewed, prepared with tap water, decaffeinated','BEVERAGES,COFFEE,BREWED,PREP W/ TAP H2O,DECAFFEINATED',14201,NULL,NULL,NULL,NULL,NULL,1,'2002-06-08','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, brewed, espresso, restaurant-prepared, decaffeinated','BEVERAGES,COFFEE,BREWED,ESPRESSO,REST-PREP,DECAFFEINATED',14202,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, instant, regular, half the caffeine','BEVERAGES,COFFEE,INST,REG,HALF THE CAFFEINE',14203,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee and cocoa, instant, decaffeinated, with whitener and low calorie sweetener','BEVERAGES,COFFEE&COCOA,INST,DECAFFEINATED,W/WHTNR&LOCALSWTNR',14204,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, green, ready-to-drink, sweetened','BEVERAGES,TEA,GRN,RTD,SWTND',14206,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, ready-to-drink, lemon, diet','BEVERAGES,TEA,RTD,LEMON,DIET',14207,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, brewed, prepared with tap water','BEVERAGES,COFFEE,BREWED,PREP W/ TAP H2O',14209,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, brewed, espresso, restaurant-prepared','BEVERAGES,COFFEE,BREWED,ESPRESSO,REST-PREP',14210,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, black, ready-to-drink, lemon, diet','BEVERAGES,TEA,BLACK,RTD,LEMON,DIET',14211,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, instant, regular, powder','BEVERAGES,COFFEE,INST,REG,PDR',14214,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, instant, regular, prepared with water','BEVERAGES,COFFEE,INST,REG,PREP W/ H2O',14215,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, aloe vera juice drink, fortified with Vitamin C','BEVERAGES,ALOE VERA JUC DRK,FORT W/ VIT C',14216,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, instant, decaffeinated, powder','BEVERAGES,COFFEE,INST,DECAFFEINATED,PDR',14218,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, instant, decaffeinated, prepared with water','BEVERAGES,COFFEE,INST,DECAFFEINATED,PREP W/ H2O',14219,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, instant, with chicory','BEVERAGES,COFFEE,INST,W/ CHICORY',14222,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, instant, chicory','BEVERAGES,COFFEE,INST,CHICORY',14223,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, instant, mocha, sweetened','BEVERAGES,COFFEE,INST,MOCHA,SWTND',14224,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee substitute, cereal grain beverage, powder','BEVERAGES,COFFEE SUB,CRL GRAIN BEV,PDR',14236,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee substitute, cereal grain beverage, prepared with water','BEVERAGES,COFFEE SUB,CRL GRAIN BEV,PREP W/ H2O',14237,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, cranberry-apple juice drink, bottled','BEVERAGES,CRANBERRY-APPLE JUC DRK,BTLD',14238,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, cranberry-apricot juice drink, bottled','BEVERAGES,CRANBERRY-APRICOT JUC DRK,BTLD',14240,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, cranberry-grape juice drink, bottled','BEVERAGES,CRANBERRY-GRAPE JUC DRK,BTLD',14241,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Cranberry juice cocktail, bottled','CRANBERRY JUC COCKTAIL,BTLD',14242,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Cranberry juice cocktail, bottled, low calorie, with calcium, saccharin and corn sweetener','CRANBERRY JUC COCKTAIL,BTLD,LO CAL,W/CA,SACCHARIN&CORN SWTNR',14243,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Eggnog-flavor mix, powder, prepared with whole milk','BEVERAGES,EGGNOG-FLAVOR MIX,PDR,PREP W/ WHL MILK',14245,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, green, instant, decaffeinated, lemon, unsweetened, fortified with vitamin C','BEVERAGES,TEA,GRN,INST,DECAFFEI,LEMON,UNSWTND,FORT W/ VIT C',14246,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, green, brewed, decaffeinated','BEVERAGES,TEA,GRN,BREWED,DECAFFEINATED',14260,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, green, ready to drink, unsweetened','BEVERAGES,TEA,GRN,READY TO DRK,UNSWTND',14261,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, citrus fruit juice drink, frozen concentrate','BEVERAGES,CITRUS FRUIT JUC DRK,FRZ CONC',14262,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, citrus fruit juice drink, frozen concentrate, prepared with water','BEVERAGES,CITRUS FRUIT JUC DRK,FRZ CONC,PREP W/ H2O',14263,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, fruit punch drink, without added nutrients, canned','BEVERAGES,FRUIT PUNCH DRK,WO/ ADDED NUTR,CND',14264,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Fruit punch drink, with added nutrients, canned','BEVERAGES,FRUIT PUNCH DRK,W/ ADDED NUTR,CND',14267,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Fruit punch drink, frozen concentrate','BEVERAGES,FRUIT PUNCH DRK,FRZ CONC',14268,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Fruit punch drink, frozen concentrate, prepared with water','BEVERAGES,FRUIT PUNCH DRK,FRZ CONC,PREP W/ H2O',14269,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, instant, vanilla, sweetened, decaffeinated, with non dairy creamer','BEVERAGES,COFFEE,INST,VANILA,SWTND,DECAFF,W/ NON DAIRY CREAM',14270,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, grape drink, canned','BEVERAGES,GRAPE DRK,CND',14277,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, green, brewed, regular','BEVERAGES,TEA,GRN,BREWED,REG',14278,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, black, ready-to-drink, peach, diet','BEVERAGES,TEA,BLACK,RTD,PEACH,DIET',14279,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, black, ready to drink, decaffeinated, diet','BEVERAGES,TEA,BLACK,READY TO DRK,DECAFFEINATED,DIET',14280,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, black, ready to drink, decaffeinated','BEVERAGES,TEA,BLACK,READY TO DRK,DECAFFEINATED',14281,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, grape juice drink, canned','BEVERAGES,GRAPE JUC DRK,CND',14282,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Lemonade, powder','BEVERAGES,LEMONADE,PDR',14287,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Lemonade, powder, prepared with water','LEMONADE,PDR,PREP W/H2O',14288,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Lemonade, frozen concentrate, white','LEMONADE,FRZ CONC,WHITE',14292,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Lemonade, frozen concentrate, white, prepared with water','LEMONADE,FRZ CONC,WHITE,PREP W/H2O',14293,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, lemonade-flavor drink, powder','BEVERAGES,LEMONADE-FLAVOR DRK,PDR',14296,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, lemonade-flavor drink, powder, prepared with water','BEVERAGES,LEMONADE-FLAVOR DRK,PDR,PREP W/ H2O',14297,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Limeade, frozen concentrate, prepared with water','LIMEADE,FRZ CONC,PREP W/H2O',14303,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Malt beverage, includes non-alcoholic beer','MALT BEV,INCL NON-ALCOHOLIC BEER',14305,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Malted drink mix, natural, with added nutrients, powder, prepared with whole milk','BEVERA,MALTED DRK MIX,NAT,W/ ADD NUTR,PDR,PREP W/ WHL MILK',14310,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Malted drink mix, natural, powder, dairy based.','BEVERAGES,MALTED DRK MIX,NAT,PDR,DAIRY BASED.',14311,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Malted drink mix, natural, powder, prepared with whole milk','BEVERAGES,MALTED DRK MIX,NAT,PDR,PREP W/ WHL MILK',14312,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Malted drink mix, chocolate, with added nutrients, powder, prepared with whole milk','BEVERAG,MALT DRK MIX,CHOC,W/ ADDED NUTR,PDR,PREP W/ WHL MILK',14316,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, malted drink mix, chocolate, powder','BEVERAGES,MALTED DRK MIX,CHOC,PDR',14317,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Malted drink mix, chocolate, powder, prepared with whole milk','BEVERAGES,MALTED DRK MIX,CHOC,PDR,PREP W/ WHL MILK',14318,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, orange drink, canned, with added vitamin C','BEVERAGES,ORANGE DRK,CND,W/ ADDED VIT C',14323,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, orange and apricot juice drink, canned','BEVERAGES,ORANGE & APRICOT JUC DRK,CND',14327,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, pineapple and grapefruit juice drink, canned','BEVERAGES,PNAPPL & GRAPEFRUIT JUC DRK,CND',14334,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, pineapple and orange juice drink, canned','BEVERAGES,PNAPPL & ORANGE JUC DRK,CND',14341,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Strawberry-flavor beverage mix, powder','STRAWBERRY-FLAVOR BEV MIX,PDR',14350,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Strawberry-flavor beverage mix, powder, prepared with whole milk','BEVERAGES,STRAWBERRY-FLAVOR BEV MIX,PDR,PREP W/ WHL MILK',14351,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, black, brewed, prepared with tap water, decaffeinated','BEVERAGES,TEA,BLACK,BREWED,PREP W/ TAP H2O,DECAFFEINATED',14352,NULL,NULL,NULL,NULL,NULL,1,'2002-06-08','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, instant, decaffeinated, unsweetened','BEVERAGES,TEA,INST,DECAFFEINATED,UNSWTND',14353,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, black, brewed, prepared with tap water','BEVERAGES,TEA,BLACK,BREWED,PREP W/ TAP H2O',14355,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, instant, decaffeinated, lemon, diet','BEVERAGES,TEA,INST,DECAFFEINATED,LEMON,DIET',14356,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, instant, decaffeinated, lemon, sweetened','BEVERAGES,TEA,INST,DECAFFEINATED,LEMON,SWTND',14357,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, instant, unsweetened, powder','BEVERAGES,TEA,INST,UNSWTND,PDR',14366,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, instant, unsweetened, prepared with water','BEVERAGES,TEA,INST,UNSWTND,PREP W/ H2O',14367,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, instant, lemon, unsweetened','BEVERAGES,TEA,INST,LEMON,UNSWTND',14368,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, instant, lemon, sweetened, powder','BEVERAGES,TEA,INST,LEMON,SWTND,PDR',14370,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, instant, lemon, sweetened, prepared with water','BEVERAGES,TEA,INST,LEMON,SWTND,PREP W/ H2O',14371,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, instant, sweetened with sodium saccharin, lemon-flavored, powder','BEVERAGES,TEA,INST,SWTND W/ NA SACCHARIN,LEMON-FLAVORED,PDR',14375,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, instant, lemon, diet','BEVERAGES,TEA,INST,LEMON,DIET',14376,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, herb, other than chamomile, brewed','BEVERAGES,TEA,HERB,OTHER THAN CHAMOMILE,BREWED',14381,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, cocoa mix, with aspartame, powder, prepared with water','BEVERAGES,COCOA MIX,W/ ASPRT,PDR,PREP W/ H2O',14390,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, cola, fast-food cola','BEVERAGES,CARB,COLA,FAST-FOOD COLA',14400,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, fruit punch juice drink, frozen concentrate','BEVERAGES,FRUIT PUNCH JUC DRK,FRZ CONC',14405,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, fruit punch juice drink, frozen concentrate, prepared with water','BEVERAGES,FRUIT PUNCH JUC DRK,FRZ CONC,PREP W/ H2O',14406,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, orange-flavor drink, breakfast type, powder','BEVERAGES,ORANGE-FLAVOR DRK,BRKFST TYPE,PDR',14407,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, orange-flavor drink, breakfast type, powder, prepared with water','BEVERAGES,ORANGE-FLAVOR DRK,BRKFST TYPE,PDR,PREP W/ H2O',14408,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Orange-flavor drink, breakfast type, low calorie, powder','BEVERAGES,ORANGE-FLAVOR DRK,BRKFST TYPE,LO CAL,PDR',14409,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, water, tap, drinking','BEVERAGES,H2O,TAP,DRINKING',14411,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, carbonated, low calorie, cola or pepper-type, with aspartame, contains caffeine','BEVERAGES,CARB,LO CAL,COLA OR PEPPER-TYPE,W/ ASPRT, CAFFEINE',14416,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee substitute, cereal grain beverage, powder, prepared with whole milk','BEVERAGES,COFFEE SUB,CRL GRAIN BEV,PDR,PREP W/ WHL MILK',14421,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Dairy drink mix, chocolate, reduced calorie, with low-calorie sweeteners, powder','BEV,DAIRY DRK MIX,CHOC,RED CAL,W/ LOW-CAL SWEETENERS,PDR',14422,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, dairy drink mix, chocolate, reduced calorie, with aspartame, powder, prepared with water and ice','BEVE,DARY DRK MIX,CHC,RED CAL,W/ ASPRT,PDR,PREP W/ H2O & ICE',14423,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Orange-flavor drink, breakfast type, with pulp, frozen concentrate.','BEV,ORANGE-FLAVO DRK,BRKFST TYPE,W/ PULP,FRZ CON. NOT MANUF.',14424,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Orange-flavor drink, breakfast type, with pulp, frozen concentrate, prepared with water','BEVE,ORANGE-FLAV DRK,BRKFST TYPE,W/ PULP,FRZ CONC,PRE W/ H2O',14425,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Orange drink, breakfast type, with juice and pulp, frozen concentrate','BEVERAGES,ORANGE DRK,BRKFST TYPE,W/ JUC & PULP,FRZ CONC',14426,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Orange drink, breakfast type, with juice and pulp, frozen concentrate, prepared with water','BEV,ORANGE DRK,BRKFST TYPE,W/ JUC & PULP,FRZ CONC,PRE W/ H2O',14427,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, water, tap, municipal','BEVERAGES,H2O,TAP,MUNICIPAL',14429,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Cranberry juice cocktail, frozen concentrate','CRANBERRY JUC COCKTAIL,FRZ CONC',14430,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Cranberry juice cocktail, frozen concentrate, prepared with water','CRANBERRY JUC COCKTAIL,FRZ CONC,PREP W/ H2O',14431,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, orange breakfast drink, ready-to-drink, with added nutrients','BEVERAGES,ORANGE BRKFST DRK,RTD,W/ ADDED NUTR',14436,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Carbonated beverage, low calorie, other than cola or pepper, with sodium saccharin, without caffeine','CARBONATED BEV,LOCAL,OTHR THAN COLA OR PEP,W/ NA SAC,WO/ CAF',14537,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Cocoa mix, low calorie, powder, with added calcium, phosphorus, aspartame, without added sodium or vitamin A','BEVE,COCA MIX,LO CAL,PDR,W/ ADD CA,P,ASPRT,WO/ ADD NA, VIT A',14538,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, fruit punch-flavor drink, powder, without added sodium, prepared with water','BEVERAGE,FRUIT PUNCH-FLAVOR DRK,PDR,WO/ ADDED NA,PREP W/ H2O',14541,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Lemonade, frozen concentrate, pink','LEMONADE,FRZ CONC,PINK',14542,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, lemonade, frozen concentrate, pink, prepared with water','BEVERAGES,LEMONADE,FRZ CONC,PINK,PREP W/ H2O',14543,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, black, brewed, prepared with distilled water','BEVERAGES,TEA,BLACK,BREWED,PREP W/ DISTILLED H2O',14544,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, herb, brewed, chamomile','BEVERAGES,TEA,HERB,BREWED,CHAMOMILE',14545,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, instant, lemon, with added ascorbic acid','BEVERAGES,TEA,INST,LEMON,W/ ADDED VIT C',14548,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Carbonated beverage, chocolate-flavored soda','CARBONATED BEV,CHOCOLATE-FLAVORED SODA',14552,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Water, bottled, generic','WATER,BTLD,GENERIC',14555,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, chocolate-flavor beverage mix for milk, powder, with added nutrients','BEVERAGE,CHOCOLATE-FLAVOR BEV MIX FOR MILK,PDR,W/ ADDED NUTR',14557,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, chocolate-flavor beverage mix for milk, powder, with added nutrients, prepared with whole milk','BEV,CHOCO-FLA BEV MIX , MLK,PDR,W/ ADD NUTR,PREP W/ WHL MILK',14558,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Water, non-carbonated, bottles, natural fruit flavors, sweetened with low calorie sweetener','WATER,NON-CARBONATED,FRUIT FLAVORS,SWTND W/ LO CAL SWTNR',14604,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Water with added vitamins and minerals, bottles, sweetened, assorted fruit flavors','BEV,H2O W/ ADDED VIT & MIN,BOTTLES,SWTND,AST FRUIT FLAVORS',14605,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Meal supplement drink, canned, peanut flavor','BEVERAGES,MEAL SUPP DRK,CND,PNUT FLAVOR',14632,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Vegetable and fruit juice drink, reduced calorie, with low-calorie sweetener, added vitamin C','BEVER,VEG & FRUIT JUC DRK,RED CAL,W/ LOW-CAL SWTNR,ADD VIT C',14633,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, milk beverage, reduced fat, flavored and sweetened, Ready-to-drink,  added calcium, vitamin A and vitamin D','BEV,MILK BEV,RED FAT,FLAV & SWTND,RTD,ADDED CA,VIT A &  D',14634,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, vegetable and fruit juice blend, 100% juice, with added vitamins A, C, E','BEVERAGES,VEG & FRUIT JUC BLEND,W/ ADDED VITAMINS A,C,E',14635,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, fruit juice drink, reduced sugar, with vitamin E added','BEVERAGES,FRUIT JUC DRK,RED SUGAR,W/ VITAMIN E ADDED',14636,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Water, with corn syrup and/or sugar and low calorie sweetener, fruit flavored','WATER,W/ CORN SYRUP AND/OR SUGAR & LO CAL SWTNR,FRUIT FLAV',14637,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, rice milk, unsweetened','BEVERAGES,RICE MILK,UNSWTND',14639,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Fruit flavored drink, less than 3% juice, not fortified with vitamin C','BEVERAGES,FRUIT FLAV DRK,LESS THAN 3% JUC,NOT FORT W/ VIT C',14645,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Fruit flavored drink containing less than 3% fruit juice, with high vitamin C','BEV,FRUIT FLAV DRK CONTAINING , 3% FRUIT JUC,W/ HI VIT C',14646,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Fruit flavored drink, reduced sugar, greater than 3% fruit juice, high vitamin C, added calcium','BEV,FRUIT FLAV DRK,RED SUGAR, > 3% FRUIT JUC,HI VIT C,ADD CA',14647,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, fruit juice drink, greater than 3% fruit juice, high vitamin C and added thiamin','BEV,FRUIT JUC DRK, MORE 3% FRUIT JUC,HI VIT C & ADD THIAMIN',14648,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, tea, hibiscus, brewed','BEVERAGES,TEA,HIBISCUS,BREWED',14649,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, fruit juice drink, greater than 3% juice, high vitamin C','BEVERAGES,FRUIT JUC DRK,GREATER THAN 3% JUC,HI VIT C',14651,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, nutritional shake mix, high protein, powder','BEVERAGES,NUTRITIONAL SHAKE MIX,HI PROT,PDR',14654,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, anchovy, european, raw','ANCHOVY,EUROPEAN,RAW',15001,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, anchovy, european, canned in oil, drained solids','ANCHOVY,EUROPEAN,CND IN OIL,DRND SOL',15002,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, bass, fresh water, mixed species, raw','BASS,FRSH H2O,MXD SP,RAW',15003,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, bass, striped, raw','BASS,STRIPED,RAW',15004,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, bluefish, raw','BLUEFISH,RAW',15005,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, burbot, raw','BURBOT,RAW',15006,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, butterfish, raw','BUTTERFISH,RAW',15007,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, carp, raw','CARP,RAW',15008,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, carp, cooked, dry heat','CARP,COOKED,DRY HEAT',15009,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, catfish, channel, wild, raw','CATFISH,CHANNEL,WILD,RAW',15010,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, catfish, channel, cooked, breaded and fried','CATFISH,CHANNEL,CKD,BREADED&FRIED',15011,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, caviar, black and red, granular','CAVIAR,BLACK&RED,GRANULAR',15012,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, cisco, raw','CISCO,RAW',15013,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, cisco, smoked','CISCO,SMOKED',15014,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, cod, Atlantic, raw','COD,ATLANTIC,RAW',15015,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, cod, Atlantic, cooked, dry heat','COD,ATLANTIC,CKD,DRY HEAT',15016,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, cod, Atlantic, canned, solids and liquid','COD,ATLANTIC,CND,SOL&LIQ',15017,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, cod, Atlantic, dried and salted','COD,ATLANTIC,DRIED&SALTED',15018,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, cod, Pacific, raw (may have been previously frozen)','FISH,COD,PACIFIC,RAW (MAY HAVE BEEN PREVIOUSLY FROZEN)',15019,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, croaker, Atlantic, raw','CROAKER,ATLANTIC,RAW',15020,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, croaker, Atlantic, cooked, breaded and fried','CROAKER,ATLANTIC,CKD,BREADED&FRIED',15021,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, cusk, raw','CUSK,RAW',15022,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, mahimahi, raw','FISH,MAHIMAHI,RAW',15023,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, drum, freshwater, raw','DRUM,FRESHWATER,RAW',15024,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, eel, mixed species, raw','EEL,MIXED SPECIES,RAW',15025,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, eel, mixed species, cooked, dry heat','EEL,MXD SP,CKD,DRY HEAT',15026,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, fish sticks, frozen, prepared','FISH,FISH STKS,FRZ,PREP',15027,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, flatfish (flounder and sole species), raw','FLATFISH (FLOUNDER&SOLE SP),RAW',15028,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, flatfish (flounder and sole species), cooked, dry heat','FLATFISH (FLOUNDER&SOLE SP),CKD,DRY HEAT',15029,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, gefiltefish, commercial, sweet recipe','GEFILTEFISH,COMM,SWT RECIPE',15030,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, grouper, mixed species, raw','GROUPER,MIXED SPECIES,RAW',15031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, grouper, mixed species, cooked, dry heat','GROUPER,MXD SP,CKD,DRY HEAT',15032,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, haddock, raw','HADDOCK,RAW',15033,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, haddock, cooked, dry heat','HADDOCK,COOKED,DRY HEAT',15034,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, haddock, smoked','HADDOCK,SMOKED',15035,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, halibut, Atlantic and Pacific, raw','HALIBUT,ATLANTIC&PACIFIC,RAW',15036,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, halibut, Atlantic and Pacific, cooked, dry heat','HALIBUT,ATLANTIC&PACIFIC,CKD,DRY HEAT',15037,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, halibut, Greenland, raw','HALIBUT,GREENLAND,RAW',15038,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, herring, Atlantic, raw','HERRING,ATLANTIC,RAW',15039,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, herring, Atlantic, cooked, dry heat','HERRING,ATLANTIC,CKD,DRY HEAT',15040,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, herring, Atlantic, pickled','HERRING,ATLANTIC,PICKLED',15041,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, herring, Atlantic, kippered','HERRING,ATLANTIC,KIPPERED',15042,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, herring, Pacific, raw','HERRING,PACIFIC,RAW',15043,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, ling, raw','LING,RAW',15044,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, lingcod, raw','LINGCOD,RAW',15045,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, mackerel, Atlantic, raw','MACKEREL,ATLANTIC,RAW',15046,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, mackerel, Atlantic, cooked, dry heat','MACKEREL,ATLANTIC,CKD,DRY HEAT',15047,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, mackerel, jack, canned, drained solids','MACKEREL,JACK,CND,DRND SOL',15048,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, mackerel, king, raw','MACKEREL,KING,RAW',15049,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, mackerel, Pacific and jack, mixed species, raw','MACKEREL,PACIFIC&JACK,MXD SP,RAW',15050,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, mackerel, spanish, raw','MACKEREL,SPANISH,RAW',15051,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, mackerel, spanish, cooked, dry heat','MACKEREL,SPANISH,CKD,DRY HEAT',15052,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, milkfish, raw','MILKFISH,RAW',15053,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, monkfish, raw','MONKFISH,RAW',15054,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, mullet, striped, raw','MULLET,STRIPED,RAW',15055,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, mullet, striped, cooked, dry heat','MULLET,STRIPED,CKD,DRY HEAT',15056,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, ocean perch, Atlantic, raw','OCEAN PERCH,ATLANTIC,RAW',15057,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, ocean perch, Atlantic, cooked, dry heat','OCEAN PERCH,ATLANTIC,CKD,DRY HEAT',15058,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, pout, ocean, raw','POUT,OCEAN,RAW',15059,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, perch, mixed species, raw','PERCH,MIXED SPECIES,RAW',15060,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, perch, mixed species, cooked, dry heat','PERCH,MXD SP,CKD,DRY HEAT',15061,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, pike, northern, raw','PIKE,NORTHERN,RAW',15062,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, pike, northern, cooked, dry heat','PIKE,NORTHERN,CKD,DRY HEAT',15063,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, pike, walleye, raw','PIKE,WALLEYE,RAW',15064,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, pollock, Atlantic, raw','POLLOCK,ATLANTIC,RAW',15065,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, pollock, Alaska, raw (may contain additives to retain moisture)','POLLOCK,ALASKA,RAW (CONTAIN ADDITIVES TO RETAIN MOISTURE)',15066,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, pollock, Alaska, cooked, dry heat (may contain additives to retain moisture)','POLLOCK,ALASKA,CKD (CONTAIN ADDITIVES TO RETAIN MOISTURE)',15067,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, pompano, florida, raw','POMPANO,FLORIDA,RAW',15068,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, pompano, florida, cooked, dry heat','POMPANO,FLORIDA,CKD,DRY HEAT',15069,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, rockfish, Pacific, mixed species, raw','ROCKFISH,PACIFIC,MXD SP,RAW',15070,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, rockfish, Pacific, mixed species, cooked, dry heat','ROCKFISH,PACIFIC,MXD SP,CKD,DRY HEAT',15071,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, roe, mixed species, raw','ROE,MIXED SPECIES,RAW',15072,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, roughy, orange, raw','ROUGHY,ORANGE,RAW',15073,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sablefish, raw','SABLEFISH,RAW',15074,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sablefish, smoked','SABLEFISH,SMOKED',15075,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, Atlantic, wild, raw','SALMON,ATLANTIC,WILD,RAW',15076,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, chinook, smoked','SALMON,CHINOOK,SMOKED',15077,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, chinook, raw','SALMON,CHINOOK,RAW',15078,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, chum, raw','SALMON,CHUM,RAW',15079,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, chum, canned, drained solids with bone','SALMON,CHUM,DRND SOL W/BONE',15080,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, coho, wild, raw','SALMON,COHO,WILD,RAW',15081,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, coho, wild, cooked, moist heat','SALMON,COHO,WILD,CKD,MOIST HEAT',15082,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, pink, raw','SALMON,PINK,RAW',15083,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, pink, canned, total can contents','FISH,SALMON,PINK,CND,TOTAL CAN CONTENTS',15084,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, sockeye, raw','FISH,SALMON,SOCKEYE,RAW',15085,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, sockeye, cooked, dry heat','FISH,SALMON,SOCKEYE,CKD,DRY HEAT',15086,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, sockeye, canned, drained solids','FISH,SALMON,SOCKEYE,CND,DRND SOL',15087,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sardine, Atlantic, canned in oil, drained solids with bone','SARDINE,ATLANTIC,CND IN OIL,DRND SOL W/BONE',15088,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sardine, Pacific, canned in tomato sauce, drained solids with bone','SARDINE,PACIFIC,CND IN TOMATO SAU,DRND SOL W/BONE',15089,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, scup, raw','SCUP,RAW',15090,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sea bass, mixed species, raw','SEA BASS,MXD SP,RAW',15091,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sea bass, mixed species, cooked, dry heat','SEA BASS,MXD SP,CKD,DRY HEAT',15092,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, seatrout, mixed species, raw','SEATROUT,MXD SP,RAW',15093,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, shad, american, raw','SHAD,AMERICAN,RAW',15094,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, shark, mixed species, raw','SHARK,MIXED SPECIES,RAW',15095,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, shark, mixed species, cooked, batter-dipped and fried','SHARK,MXD SP,CKD,BATTER-DIPPED&FRIED',15096,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sheepshead, raw','SHEEPSHEAD,RAW',15097,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sheepshead, cooked, dry heat','SHEEPSHEAD,CKD,DRY HEAT',15098,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, smelt, rainbow, raw','SMELT,RAINBOW,RAW',15099,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, smelt, rainbow, cooked, dry heat','SMELT,RAINBOW,CKD,DRY HEAT',15100,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, snapper, mixed species, raw','SNAPPER,MIXED SPECIES,RAW',15101,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, snapper, mixed species, cooked, dry heat','SNAPPER,MXD SP,CKD,DRY HEAT',15102,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, spot, raw','SPOT,RAW',15103,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sturgeon, mixed species, raw','STURGEON,MXD SP,RAW',15104,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sturgeon, mixed species, cooked, dry heat','STURGEON,MXD SP,CKD,DRY HEAT',15105,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sturgeon, mixed species, smoked','STURGEON,MXD SP,SMOKED',15106,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sucker, white, raw','SUCKER,WHITE,RAW',15107,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sunfish, pumpkin seed, raw','SUNFISH,PUMPKIN SEED,RAW',15108,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, surimi','SURIMI',15109,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, swordfish, raw','SWORDFISH,RAW',15110,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, swordfish, cooked, dry heat','SWORDFISH,COOKED,DRY HEAT',15111,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tilefish, raw','TILEFISH,RAW',15112,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tilefish, cooked, dry heat','TILEFISH,COOKED,DRY HEAT',15113,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, trout, mixed species, raw','TROUT,MIXED SPECIES,RAW',15114,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, trout, rainbow, wild, raw','TROUT,RAINBOW,WILD,RAW',15115,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, trout, rainbow, wild, cooked, dry heat','TROUT,RAINBOW,WILD,CKD,DRY HEAT',15116,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tuna, fresh, bluefin, raw','TUNA,FRESH,BLUEFIN,RAW',15117,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tuna, fresh, bluefin, cooked, dry heat','TUNA,FRSH,BLUEFIN,CKD,DRY HEAT',15118,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tuna, light, canned in oil, drained solids','TUNA,LT,CND IN OIL,DRND SOL',15119,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tuna, light, canned in water, drained solids (Includes foods for USDA''s Food Distribution Program)','FISH,TUNA,LT,CND IN H2O,DRND SOL',15121,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tuna, fresh, skipjack, raw','TUNA,FRESH,SKIPJACK,RAW',15123,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tuna, white, canned in oil, drained solids','TUNA,WHITE,CND IN OIL,DRND SOL',15124,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tuna, white, canned in water, drained solids','TUNA,WHITE,CND IN H2O,DRND SOL',15126,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tuna, fresh, yellowfin, raw','TUNA,FRESH,YELLOWFIN,RAW',15127,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tuna salad','TUNA SALAD',15128,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, turbot, european, raw','TURBOT,EUROPEAN,RAW',15129,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, whitefish, mixed species, raw','WHITEFISH,MXD SP,RAW',15130,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, whitefish, mixed species, smoked','WHITEFISH,MXD SP,SMOKED',15131,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, whiting, mixed species, raw','WHITING,MIXED SPECIES,RAW',15132,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, whiting, mixed species, cooked, dry heat','WHITING,MXD SP,CKD,DRY HEAT',15133,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, wolffish, Atlantic, raw','WOLFFISH,ATLANTIC,RAW',15134,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, yellowtail, mixed species, raw','YELLOWTAIL,MXD SP,RAW',15135,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, crab, alaska king, raw','CRAB,ALASKA KING,RAW',15136,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, crab, alaska king, cooked, moist heat','CRAB,ALASKA KING,CKD,MOIST HEAT',15137,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, crab, alaska king, imitation, made from surimi','CRAB,ALASKA KING,IMITN,MADE FROM SURIMI',15138,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, crab, blue, raw','CRAB,BLUE,RAW',15139,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, crab, blue, cooked, moist heat','CRAB,BLUE,CKD,MOIST HEAT',15140,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, crab, blue, canned','CRAB,BLUE,CANNED',15141,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, crab, blue, crab cakes, home recipe','CRUSTACEANS,CRAB,BLUE,CRAB CAKES,HOME RECIPE',15142,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, crab, dungeness, raw','CRAB,DUNGENESS,RAW',15143,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, crab, queen, raw','CRAB,QUEEN,RAW',15144,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, crayfish, mixed species, wild, raw','CRAYFISH,MXD SP,WILD,RAW',15145,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, crayfish, mixed species, wild, cooked, moist heat','CRAYFISH,MXD SP,WILD,CKD,MOIST HEAT',15146,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, lobster, northern, raw','LOBSTER,NORTHERN,RAW',15147,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, lobster, northern, cooked, moist heat','LOBSTER,NORTHERN,CKD,MOIST HEAT',15148,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, shrimp, mixed species, raw (may contain additives to retain moisture)','SHRIMP,MXD SP,RAW (CONTAIN ADDITIVES TO RETAIN MOISTURE)',15149,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, shrimp, mixed species, cooked, breaded and fried','SHRIMP,MXD SP,CKD,BREADED&FRIED',15150,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, shrimp, mixed species, cooked, moist heat (may contain additives to retain moisture)','SHRIMP,MXD SP,CKD (MAY CONTAIN ADDITIVES TO RETAIN MOISTURE)',15151,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, shrimp, mixed species, canned','SHRIMP,MXD SP,CND',15152,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, shrimp, mixed species, imitation, made from surimi','SHRIMP,MXD SP,IMITN,MADE FROM SURIMI',15153,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, spiny lobster, mixed species, raw','SPINY LOBSTER,MXD SP,RAW',15154,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, abalone, mixed species, raw','ABALONE,MIXED SPECIES,RAW',15155,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, abalone, mixed species, cooked, fried','ABALONE,MXD SP,CKD,FRIED',15156,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, clam, mixed species, raw','CLAM,MIXED SPECIES,RAW',15157,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, clam, mixed species, cooked, breaded and fried','CLAM,MXD SP,CKD,BREADED&FRIED',15158,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, clam, mixed species, cooked, moist heat','CLAM,MXD SP,CKD,MOIST HEAT',15159,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, clam, mixed species, canned, drained solids','CLAM,MXD SP,CND,DRND SOL',15160,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, clam, mixed species, canned, liquid','CLAM,MXD SP,CND,LIQ',15162,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, cuttlefish, mixed species, raw','CUTTLEFISH,MXD SP,RAW',15163,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, mussel, blue, raw','MUSSEL,BLUE,RAW',15164,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, mussel, blue, cooked, moist heat','MUSSEL,BLUE,CKD,MOIST HEAT',15165,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, octopus, common, raw','OCTOPUS,COMMON,RAW',15166,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, oyster, eastern, wild, raw','OYSTER,EASTERN,WILD,RAW',15167,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, oyster, eastern, cooked, breaded and fried','OYSTER,EASTERN,CKD,BREADED&FRIED',15168,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, oyster, eastern, wild, cooked, moist heat','OYSTER,EASTERN,WILD,CKD,MOIST HEAT',15169,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, oyster, eastern, canned','OYSTER,EASTERN,CANNED',15170,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, oyster, Pacific, raw','OYSTER,PACIFIC,RAW',15171,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, scallop, mixed species, raw','SCALLOP,MIXED SPECIES,RAW',15172,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, scallop, mixed species, cooked, breaded and fried','SCALLOP,MXD SP,CKD,BREADED&FRIED',15173,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, scallop, mixed species, imitation, made from surimi','SCALLOP,MXD SP,IMITN,MADE FROM SURIMI',15174,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, squid, mixed species, raw','SQUID,MIXED SPECIES,RAW',15175,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, squid, mixed species, cooked, fried','SQUID,MXD SP,CKD,FRIED',15176,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, whelk, unspecified, raw','WHELK,UNSPECIFIED,RAW',15177,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, whelk, unspecified, cooked, moist heat','WHELK,UNSPEC,CKD,MOIST HEAT',15178,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, chinook, smoked, (lox), regular','SALMON,CHINOOK,SMOKED,(LOX),REG',15179,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, chum, canned, without salt, drained solids with bone','SALMON,CHUM,CND,WO/SALT,DRND SOL W/BONE',15180,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, pink, canned, without salt, solids with bone and liquid','SALMON,PINK,CND,WO/SALT,SOL W/BONE&LIQ',15181,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, sockeye, canned, without salt, drained solids with bone','SALMON,SOCKEYE,CND,WO/SALT,DRND SOL W/BONE',15182,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tuna, light, canned in oil, without salt, drained solids','TUNA,LT,CND IN OIL,WO/SALT,DRND SOL',15183,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tuna, light, canned in water, without salt, drained solids','TUNA,LT,CND IN H2O,WO/SALT,DRND SOL',15184,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tuna, white, canned in oil, without salt, drained solids','TUNA,WHITE,CND IN OIL,WO/SALT,DRND SOL',15185,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tuna, white, canned in water, without salt, drained solids','TUNA,WHITE,CND IN H2O,WO/SALT,DRND SOL',15186,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, bass, freshwater, mixed species, cooked, dry heat','BASS,FRESHWATER,MXD SP,CKD,DRY HEAT',15187,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, bass, striped, cooked, dry heat','BASS,STRIPED,CKD,DRY HEAT',15188,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, bluefish, cooked, dry heat','BLUEFISH,COOKED,DRY HEAT',15189,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, burbot, cooked, dry heat','BURBOT,COOKED,DRY HEAT',15190,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, cod, Pacific, cooked, dry heat (may contain additives to retain moisture)','COD,PACIFIC,CKD (CONTAIN ADDITIVES TO RETAIN MOISTURE)',15192,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, mahimahi, cooked, dry heat','FISH,MAHIMAHI,CKD,DRY HEAT',15194,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, drum, freshwater, cooked, dry heat','DRUM,FRESHWATER,CKD,DRY HEAT',15195,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, halibut, greenland, cooked, dry heat','HALIBUT,GREENLAND,CKD,DRY HEAT',15196,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, herring, Pacific, cooked, dry heat','HERRING,PACIFIC,CKD,DRY HEAT',15197,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, lingcod, cooked, dry heat','LINGCOD,COOKED,DRY HEAT',15199,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, mackerel, king, cooked, dry heat','MACKEREL,KING,CKD,DRY HEAT',15200,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, mackerel, Pacific and jack, mixed species, cooked, dry heat','MACKEREL,PACIFIC&JACK,MXD SP,CKD,DRY HEAT',15201,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, pike, walleye, cooked, dry heat','PIKE,WALLEYE,CKD,DRY HEAT',15204,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, pollock, Atlantic, cooked, dry heat','POLLOCK,ATLANTIC,CKD,DRY HEAT',15205,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, pout, ocean, cooked, dry heat','POUT,OCEAN,CKD,DRY HEAT',15206,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, roe, mixed species, cooked, dry heat','ROE,MXD SP,CKD,DRY HEAT',15207,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sablefish, cooked, dry heat','SABLEFISH,COOKED,DRY HEAT',15208,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, Atlantic, wild, cooked, dry heat','SALMON,ATLANTIC,WILD,CKD,DRY HEAT',15209,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, chinook, cooked, dry heat','SALMON,CHINOOK,CKD,DRY HEAT',15210,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, chum, cooked, dry heat','SALMON,CHUM,CKD,DRY HEAT',15211,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, pink, cooked, dry heat','SALMON,PINK,CKD,DRY HEAT',15212,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, seatrout, mixed species, cooked, dry heat','SEATROUT,MXD SP,CKD,DRY HEAT',15214,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, spot, cooked, dry heat','SPOT,COOKED,DRY HEAT',15216,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sucker, white, cooked, dry heat','SUCKER,WHITE,CKD,DRY HEAT',15217,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, sunfish, pumpkin seed, cooked, dry heat','SUNFISH,PUMPKIN SD,CKD,DRY HEAT',15218,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, trout, mixed species, cooked, dry heat','TROUT,MXD SP,CKD,DRY HEAT',15219,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tuna, skipjack, fresh, cooked, dry heat','TUNA,SKIPJACK,FRSH,CKD,DRY HEAT',15220,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tuna, yellowfin, fresh, cooked, dry heat','TUNA,YELLOWFIN,FRSH,CKD,DRY HEAT',15221,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, whitefish, mixed species, cooked, dry heat','WHITEFISH,MXD SP,CKD,DRY HEAT',15223,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, wolffish, Atlantic, cooked, dry heat','WOLFFISH,ATLANTIC,CKD,DRY HEAT',15224,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, crab, dungeness, cooked, moist heat','CRAB,DUNGENESS,CKD,MOIST HEAT',15226,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, crab, queen, cooked, moist heat','CRAB,QUEEN,CKD,MOIST HEAT',15227,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, spiny lobster, mixed species, cooked, moist heat','SPINY LOBSTER,MXD SP,CKD,MOIST HEAT',15228,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, cuttlefish, mixed species, cooked, moist heat','CUTTLEFISH,MXD SP,CKD,MOIST HEAT',15229,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, octopus, common, cooked, moist heat','OCTOPUS,COMMON,CKD,MOIST HEAT',15230,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, oyster, Pacific, cooked, moist heat','OYSTER,PACIFIC,CKD,MOIST HEAT',15231,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, roughy, orange, cooked, dry heat','ROUGHY,ORANGE,CKD,DRY HEAT',15232,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, catfish, channel, wild, cooked, dry heat','CATFISH,CHANNEL,WILD,CKD,DRY HEAT',15233,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, catfish, channel, farmed, raw','CATFISH,CHANNEL,FARMED,RAW',15234,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, catfish, channel, farmed, cooked, dry heat','CATFISH,CHANNEL,FARMED,CKD,DRY HEAT',15235,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, Atlantic, farmed, raw','SALMON,ATLANTIC,FARMED,RAW',15236,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, Atlantic, farmed, cooked, dry heat','SALMON,ATLANTIC,FARMED,CKD,DRY HEAT',15237,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, coho, farmed, raw','SALMON,COHO,FARMED,RAW',15238,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, coho, farmed, cooked, dry heat','SALMON,COHO,FARMED,CKD,DRY HEAT',15239,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, trout, rainbow, farmed, raw','TROUT,RAINBOW,FARMED,RAW',15240,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, trout, rainbow, farmed, cooked, dry heat','TROUT,RAINBOW,FARMED,CKD,DRY HEAT',15241,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, crayfish, mixed species, farmed, raw','CRAYFISH,MXD SP,FARMED,RAW',15242,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, crayfish, mixed species, farmed, cooked, moist heat','CRAYFISH,MXD SP,FARMED,CKD,MOIST HEAT',15243,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, oyster, eastern, wild, cooked, dry heat','OYSTER,EASTERN,WILD,CKD,DRY HEAT',15244,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, oyster, eastern, farmed, raw','OYSTER,EASTERN,FARMED,RAW',15245,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, oyster, eastern, farmed, cooked, dry heat','OYSTER,EASTERN,FARMED,CKD,DRY HEAT',15246,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, coho, wild, cooked, dry heat','SALMON,COHO,WILD,CKD,DRY HEAT',15247,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, conch, baked or broiled','CONCH,BAKED OR BROILED',15250,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Salmon nuggets, breaded, frozen, heated','SALMON NUGGETS,BREADED,FRZ,HTD',15251,NULL,NULL,NULL,NULL,NULL,1,'1995-06-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Salmon nuggets, cooked as purchased, unheated','SALMON NUGGETS,CKD AS PURCHASED,UNHTD',15252,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Salmon, sockeye, canned, total can contents','SALMON,SOCKEYE,CND,TOTAL CAN CONTENTS',15253,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, salmon, pink, canned, drained solids','FISH,SALMON,PINK,CND,DRND SOL',15260,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tilapia, raw','FISH,TILAPIA,RAW',15261,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, tilapia, cooked, dry heat','FISH,TILAPIA,CKD,DRY HEAT',15262,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Salmon, sockeye, canned, drained solids, without skin and bones','SALMON,SOCKEYE,CND,DRND SOL,WO/ SKN & BONES',15264,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, Salmon, pink, canned, drained solids, without skin and bones','FISH,SALMON,PINK,CND,DRND SOL,WO/ SKN & BONES',15265,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, pollock, Alaska, raw','FISH,POLLOCK,ALASKA,RAW',15266,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, pollock, Alaska, cooked','FISH,POLLOCK,ALASKA,CKD',15267,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, cod, Pacific, cooked','FISH,COD,PACIFIC,CKD',15269,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, shrimp, raw','CRUSTACEANS,SHRIMP,RAW',15270,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Crustaceans, shrimp, cooked','CRUSTACEANS,SHRIMP,CKD',15271,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, trout, brook, raw, New York State','FISH,TROUT,BROOK,RAW,NEW YORK STATE',15274,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, adzuki, mature seeds, raw','BEANS,ADZUKI,MATURE SEEDS,RAW',16001,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, adzuki, mature seeds, cooked, boiled, without salt','BEANS,ADZUKI,MATURE SEEDS,CKD,BLD,WO/SALT',16002,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, adzuki, mature seeds, canned, sweetened','BEANS,ADZUKI,MATURE SEEDS,CND,SWTND',16003,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Yokan, prepared from adzuki beans and sugar','YOKAN,PREP FROM ADZUKI BNS & SUGAR',16004,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, baked, home prepared','BEANS,BAKED,HOME PREPARED',16005,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, baked, canned, plain or vegetarian','BEANS,BKD,CND,PLN OR VEGETARIAN',16006,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, baked, canned, with beef','BEANS,BKD,CND,W/BF',16007,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, baked, canned, with franks','BEANS,BKD,CND,W/FRANKS',16008,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, baked, canned, with pork','BEANS,BKD,CND,W/PORK',16009,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, baked, canned, with pork and sweet sauce','BEANS,BKD,CND,W/PORK&SWT SAU',16010,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, baked, canned, with pork and tomato sauce','BEANS,BKD,CND,W/PORK&TOMATO SAU',16011,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, black, mature seeds, raw','BEANS,BLACK,MATURE SEEDS,RAW',16014,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, black, mature seeds, cooked, boiled, without salt','BEANS,BLACK,MATURE SEEDS,CKD,BLD,WO/SALT',16015,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, black turtle, mature seeds, raw','BEANS,BLACK TURTLE,MATURE SEEDS,RAW',16016,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, black turtle, mature seeds, cooked, boiled, without salt','BEANS,BLACK TURTLE,MATURE SEEDS,CKD,BLD,WO/ SALT',16017,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, black turtle, mature seeds, canned','BEANS,BLACK TURTLE,MATURE SEEDS,CND',16018,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, cranberry (roman), mature seeds, raw','BEANS,CRANBERRY (ROMAN),MATURE SEEDS,RAW',16019,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, cranberry (roman), mature seeds, cooked, boiled, without salt','BEANS,CRANBERRY (ROMAN),MATURE SEEDS,CKD,BLD,WO/SALT',16020,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, cranberry (roman), mature seeds, canned','BEANS,CRANBERRY (ROMAN),MATURE SEEDS,CND',16021,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, french, mature seeds, raw','BEANS,FRENCH,MATURE SEEDS,RAW',16022,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, french, mature seeds, cooked, boiled, without salt','BEANS,FRENCH,MATURE SEEDS,CKD,BLD,WO/SALT',16023,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, great northern, mature seeds, raw (Includes foods for USDA''s Food Distribution Program)','BEANS,GREAT NORTHERN,MATURE SEEDS,RAW',16024,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, great northern, mature seeds, cooked, boiled, without salt','BEANS,GREAT NORTHERN,MATURE SEEDS,CKD,BLD,WO/SALT',16025,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, great northern, mature seeds, canned','BEANS,GREAT NORTHERN,MATURE SEEDS,CND',16026,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, all types, mature seeds, raw','BEANS,KIDNEY,ALL TYPES,MATURE SEEDS,RAW',16027,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, all types, mature seeds, cooked, boiled, without salt','BEANS,KIDNEY,ALL TYPES,MATURE SEEDS,CKD,BLD,WO/SALT',16028,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, all types, mature seeds, canned','BEANS,KIDNEY,ALL TYPES,MATURE SEEDS,CND',16029,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, california red, mature seeds, raw','BEANS,KIDNEY,CALIFORNIA RED,MATURE SEEDS,RAW',16030,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, california red, mature seeds, cooked, boiled, without salt','BEANS,KIDNEY,CALIFORNIA RED,MATURE SEEDS,CKD,BLD,WO/SALT',16031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, red, mature seeds, raw','BEANS,KIDNEY,RED,MATURE SEEDS,RAW',16032,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, red, mature seeds, cooked, boiled, without salt','BEANS,KIDNEY,RED,MATURE SEEDS,CKD,BLD,WO/SALT',16033,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, red, mature seeds, canned, solids and liquids','BEANS,KIDNEY,RED,MATURE SEEDS,CND,SOL & LIQUIDS',16034,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, royal red, mature seeds, raw','BEANS,KIDNEY,ROYAL RED,MATURE SEEDS,RAW',16035,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, royal red, mature seeds, cooked, boiled, without salt','BEANS,KIDNEY,ROYAL RED,MATURE SEEDS,CKD,BLD,WO/SALT',16036,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, navy, mature seeds, raw','BEANS,NAVY,MATURE SEEDS,RAW',16037,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, navy, mature seeds, cooked, boiled, without salt','BEANS,NAVY,MATURE SEEDS,CKD,BLD,WO/SALT',16038,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, navy, mature seeds, canned','BEANS,NAVY,MATURE SEEDS,CND',16039,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, pink, mature seeds, raw','BEANS,PINK,MATURE SEEDS,RAW',16040,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, pink, mature seeds, cooked, boiled, without salt','BEANS,PINK,MATURE SEEDS,CKD,BLD,WO/SALT',16041,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, pinto, mature seeds, raw (Includes foods for USDA''s Food Distribution Program)','BEANS,PINTO,MATURE SEEDS,RAW',16042,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, pinto, mature seeds, cooked, boiled, without salt','BEANS,PINTO,MATURE SEEDS,CKD,BLD,WO/SALT',16043,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, pinto, mature seeds, canned, solids and liquids','BEANS,PINTO,MATURE SEEDS,CND,SOL & LIQUIDS',16044,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, small white, mature seeds, raw','BEANS,SML WHITE,MATURE SEEDS,RAW',16045,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, small white, mature seeds, cooked, boiled, without salt','BEANS,SML WHITE,MATURE SEEDS,CKD,BLD,WO/SALT',16046,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, yellow, mature seeds, raw','BEANS,YEL,MATURE SEEDS,RAW',16047,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, yellow, mature seeds, cooked, boiled, without salt','BEANS,YEL,MATURE SEEDS,CKD,BLD,WO/SALT',16048,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, white, mature seeds, raw','BEANS,WHITE,MATURE SEEDS,RAW',16049,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, white, mature seeds, cooked, boiled, without salt','BEANS,WHITE,MATURE SEEDS,CKD,BLD,WO/SALT',16050,NULL,NULL,NULL,NULL,NULL,1,'1995-06-27','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, white, mature seeds, canned','BEANS,WHITE,MATURE SEEDS,CND',16051,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Broadbeans (fava beans), mature seeds, raw','BROADBEANS (FAVA BEANS),MATURE SEEDS,RAW',16052,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Broadbeans (fava beans), mature seeds, cooked, boiled, without salt','BROADBEANS (FAVA BNS),MATURE SEEDS,CKD,BLD,WO/SALT',16053,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Broadbeans (fava beans), mature seeds, canned','BROADBEANS (FAVA BNS),MATURE SEEDS,CND',16054,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Carob flour','CAROB FLOUR',16055,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Chickpeas (garbanzo beans, bengal gram), mature seeds, raw','CHICKPEAS (GARBANZO BNS,BENGAL GM),MATURE SEEDS,RAW',16056,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Chickpeas (garbanzo beans, bengal gram), mature seeds, cooked, boiled, without salt','CHICKPEAS ,MATURE SEEDS,CKD,BLD,WO/SALT',16057,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Chickpeas (garbanzo beans, bengal gram), mature seeds, canned, solids and liquids','CHICKPEAS (GARBANZO BNS,BENGAL GRAM),MATURE SDS,CND,SOL&LIQ',16058,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Chili with beans, canned','CHILI WITH BEANS,CANNED',16059,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Cowpeas, catjang, mature seeds, raw','COWPEAS,CATJANG,MATURE SEEDS,RAW',16060,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Cowpeas, catjang, mature seeds, cooked, boiled, without salt','COWPEAS,CATJANG,MATURE SEEDS,CKD,BLD,WO/SALT',16061,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Cowpeas, common (blackeyes, crowder, southern), mature seeds, raw','COWPEAS,COMMON (BLACKEYES,CROWDER,SOUTHERN),MTRE SEEDS,RAW',16062,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Cowpeas, common (blackeyes, crowder, southern), mature seeds, cooked, boiled, without salt','COWPEAS,COMMON (BLKEYES,CRWDR,STHRN),MTURE,CKD,BLD,WO/SALT',16063,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Cowpeas, common (blackeyes, crowder, southern), mature seeds, canned, plain','COWPEAS,COMMON,MATURE SEEDS,CND,PLN',16064,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Cowpeas, common (blackeyes, crowder, southern), mature seeds, canned with pork','COWPEAS,COMMON,MATURE SEEDS,CND W/PORK',16065,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Hyacinth beans, mature seeds, raw','HYACINTH BNS,MATURE SEEDS,RAW',16067,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Hyacinth beans, mature seeds, cooked, boiled, without salt','HYACINTH BNS,MATURE SEEDS,CKD,BLD,WO/SALT',16068,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Lentils, raw','LENTILS,RAW',16069,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Lentils, mature seeds, cooked, boiled, without salt','LENTILS,MATURE SEEDS,CKD,BLD,WO/SALT',16070,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Lima beans, large, mature seeds, raw','LIMA BNS,LRG,MATURE SEEDS,RAW',16071,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Lima beans, large, mature seeds, cooked, boiled, without salt','LIMA BNS,LRG,MATURE SEEDS,CKD,BLD,WO/SALT',16072,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Lima beans, large, mature seeds, canned','LIMA BNS,LRG,MATURE SEEDS,CND',16073,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Lima beans, thin seeded (baby), mature seeds, raw','LIMA BNS,THIN SEEDED (BABY),MATURE SEEDS,RAW',16074,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Lima beans, thin seeded (baby), mature seeds, cooked, boiled, without salt','LIMA BNS,THIN SEEDED (BABY),MATURE SEEDS,CKD,BLD,WO/SALT',16075,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Lupins, mature seeds, raw','LUPINS,MATURE SEEDS,RAW',16076,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Lupins, mature seeds, cooked, boiled, without salt','LUPINS,MATURE SEEDS,CKD,BLD,WO/ SALT',16077,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Mothbeans, mature seeds, raw','MOTHBEANS,MATURE SEEDS,RAW',16078,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Mothbeans, mature seeds, cooked, boiled, without salt','MOTHBEANS,MATURE SEEDS,CKD,BLD,WO/SALT',16079,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Mung beans, mature seeds, raw','MUNG BNS,MATURE SEEDS,RAW',16080,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Mung beans, mature seeds, cooked, boiled, without salt','MUNG BNS,MATURE SEEDS,CKD,BLD,WO/SALT',16081,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Noodles, chinese, cellophane or long rice (mung beans), dehydrated','NOODLES,CHINESE,CELLOPHANE OR LONG RICE (MUNG BNS),DEHYD',16082,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Mungo beans, mature seeds, raw','MUNGO BNS,MATURE SEEDS,RAW',16083,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Mungo beans, mature seeds, cooked, boiled, without salt','MUNGO BNS,MATURE SEEDS,CKD,BLD,WO/SALT',16084,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peas, green, split, mature seeds, raw','PEAS,GRN,SPLIT,MATURE SEEDS,RAW',16085,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peas, split, mature seeds, cooked, boiled, without salt','PEAS,SPLIT,MATURE SEEDS,CKD,BLD,WO/SALT',16086,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanuts, all types, raw','PEANUTS,ALL TYPES,RAW',16087,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanuts, all types, cooked, boiled, with salt','PEANUTS,ALL TYPES,CKD,BLD,W/SALT',16088,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanuts, all types, oil-roasted, with salt','PEANUTS,ALL TYPES,OIL-ROASTED,W/SALT',16089,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanuts, all types, dry-roasted, with salt','PEANUTS,ALL TYPES,DRY-ROASTED,W/SALT',16090,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanuts, spanish, raw','PEANUTS,SPANISH,RAW',16091,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanuts, spanish, oil-roasted, with salt','PEANUTS,SPANISH,OIL-ROASTED,W/SALT',16092,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanuts, valencia, raw','PEANUTS,VALENCIA,RAW',16093,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanuts, valencia, oil-roasted, with salt','PEANUTS,VALENCIA,OIL-ROASTED,W/SALT',16094,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanuts, virginia, raw','PEANUTS,VIRGINIA,RAW',16095,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanuts, virginia, oil-roasted, with salt','PEANUTS,VIRGINIA,OIL-ROASTED,W/SALT',16096,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanut butter, chunk style, with salt','PEANUT BUTTER,CHUNK STYLE,W/SALT',16097,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanut butter, smooth style, with salt (Includes foods for USDA''s Food Distribution Program)','PEANUT BUTTER,SMOOTH STYLE,W/ SALT',16098,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanut flour, defatted','PEANUT FLOUR,DEFATTED',16099,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanut flour, low fat','PEANUT FLOUR,LOW FAT',16100,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Pigeon peas (red gram), mature seeds, raw','PIGEON PEAS (RED GM),MATURE SEEDS,RAW',16101,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Pigeon peas (red gram), mature seeds, cooked, boiled, without salt','PIGEON PEAS (RED GM),MATURE SEEDS,CKD,BLD,WO/SALT',16102,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Refried beans, canned, traditional style','REFRIED BNS,CND,TRADITIONAL STYLE',16103,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Bacon, meatless','BACON,MEATLESS',16104,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Meat extender','MEAT EXTENDER',16106,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Sausage, meatless','SAUSAGE,MEATLESS',16107,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soybeans, mature seeds, raw','SOYBEANS,MATURE SEEDS,RAW',16108,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soybeans, mature cooked, boiled, without salt','SOYBEANS,MATURE CKD,BLD,WO/SALT',16109,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soybeans, mature seeds, roasted, salted','SOYBEANS,MATURE SEEDS,RSTD,SALTED',16110,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soybeans, mature seeds, dry roasted','SOYBEANS,MATURE SEEDS,DRY RSTD',16111,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Miso','MISO',16112,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Natto','NATTO',16113,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Tempeh','TEMPEH',16114,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soy flour, full-fat, raw','SOY FLOUR,FULL-FAT,RAW',16115,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soy flour, full-fat, roasted','SOY FLR,FULL-FAT,RSTD',16116,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soy flour, defatted','SOY FLOUR,DEFATTED',16117,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soy flour, low-fat','SOY FLOUR,LOW-FAT',16118,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soy meal, defatted, raw','SOY MEAL,DEFATTED,RAW',16119,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soymilk, original and vanilla, unfortified','SOYMILK,ORIGINAL & VANILLA,UNFORTIFIED',16120,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soy protein concentrate, produced by alcohol extraction','SOY PROT CONC,PRODUCED BY ALCOHOL EXTRACTION',16121,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soy protein isolate','SOY PROTEIN ISOLATE',16122,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soy sauce made from soy and wheat (shoyu)','SOY SAU MADE FROM SOY&WHEAT (SHOYU)',16123,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soy sauce made from soy (tamari)','SOY SAU MADE FROM SOY (TAMARI)',16124,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soy sauce made from hydrolyzed vegetable protein','SOY SAU MADE FROM HYDROLYZED VEG PROT',16125,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Tofu, firm, prepared with calcium sulfate and magnesium chloride (nigari)','TOFU,FIRM,PREP W/CA SULFATE&MAGNESIUM CHLORIDE (NIGARI)',16126,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Tofu, soft, prepared with calcium sulfate and magnesium chloride (nigari)','TOFU,SOFT,PREP W/CA SULFATE&MAGNESIUM CHLORIDE (NIGARI)',16127,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Tofu, dried-frozen (koyadofu)','TOFU,DRIED-FROZEN (KOYADOFU)',16128,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Tofu, fried','TOFU,FRIED',16129,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Okara','OKARA',16130,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Tofu, salted and fermented (fuyu)','TOFU,SALTED&FERMENTED (FUYU)',16132,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Yardlong beans, mature seeds, raw','YARDLONG BNS,MATURE SEEDS,RAW',16133,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Yardlong beans, mature seeds, cooked, boiled, without salt','YARDLONG BNS,MATURE SEEDS,CKD,BLD,WO/SALT',16134,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Winged beans, mature seeds, raw','WINGED BNS,MATURE SEEDS,RAW',16135,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Winged beans, mature seeds, cooked, boiled, without salt','WINGED BNS,MATURE SEEDS,CKD,BLD,WO/ SALT',16136,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Hummus, home prepared','HUMMUS,HOME PREP',16137,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Falafel, home-prepared','FALAFEL,HOME-PREPARED',16138,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soymilk, original and vanilla, with added calcium, vitamins A and D','SOYMILK,ORIGINAL & VANILLA,W/ ADDED CA,VITAMINS A & D',16139,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Lentils, pink or red, raw','LENTILS,PINK OR RED,RAW',16144,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, red, mature seeds, canned, drained solids','BEANS,KIDNEY,RED,MATURE SEEDS,CND,DRND SOL',16145,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, pinto, canned, drained solids','BEANS,PINTO,CND,DRND SOL',16146,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Veggie burgers or soyburgers, unprepared','VEGGIE BURGERS OR SOYBURGERS  UNPREP',16147,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanut spread, reduced sugar','PEANUT SPRD,RED SUGAR',16149,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanut butter, smooth, reduced fat','PEANUT BUTTER,SMOOTH,RED FAT',16150,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanut butter, smooth, vitamin and mineral fortified','PEANUT BUTTER,SMOOTH,VIT & MINERAL FORT',16155,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanut butter, chunky, vitamin and mineral fortified','PEANUT BUTTER,CHUNKY,VITAMIN&MINERAL FORT',16156,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Chickpea flour (besan)','CHICKPEA FLOUR (BESAN)',16157,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Hummus, commercial','HUMMUS,COMMERCIAL',16158,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Tofu, extra firm, prepared with nigari','TOFU,EX FIRM,PREP W/NIGARI',16159,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Tofu, hard, prepared with nigari','TOFU,HARD,PREP W/NIGARI',16160,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soymilk, chocolate, unfortified','SOYMILK,CHOC,UNFORTIFIED',16166,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanut Butter, smooth (Includes foods for USDA''s Food Distribution Program)','PEANUT BUTTER,SMOOTH (INCLFOODS FOR USDA''S FD DIST PGM)',16167,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soymilk, chocolate, with added calcium, vitamins A and D','SOYMILK,CHOC,W/ ADDED CA,VITAMINS A & D',16168,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Refried beans, canned, vegetarian','REFRIED BNS,CND,VEGETARIAN',16171,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Refried beans, canned, fat-free','REFRIED BNS,CND,FAT-FREE',16172,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Frijoles rojos volteados (Refried beans, red, canned)','FRIJOLES ROJOS VOLTEADOS (REFRIED BNS,RED,CANNED)',16173,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Tempeh, cooked','TEMPEH,CKD',16174,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soymilk (all flavors), unsweetened, with added calcium, vitamins A and D','SOYMILK (ALL FLAVORS),UNSWTND,W/ ADDED CA,VITAMINS A & D',16222,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soymilk (All flavors), enhanced','SOYMILK (ALL FLAVORS),ENHANCED',16223,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soymilk, original and vanilla, light, with added calcium, vitamins A and D','SOYMILK,ORIGINAL & VANILLA,LT,W/ ADDED CA,VITAMINS A & D',16225,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soymilk, chocolate and other flavors, light, with added calcium, vitamins A and D','SOYMILK,CHOC & OTHER FLAVORS,LT,W/ ADDED CA,VITAMINS A & D',16227,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soymilk, original and vanilla, light, unsweetened, with added calcium, vitamins A and D','SOYMILK,ORIGINAL & VANILLA,LT,UNSWTND,W/ ADDED CA,VIT A & D',16228,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soymilk (All flavors), lowfat, with added calcium, vitamins A and D','SOYMILK (ALL FLAVORS),LOWFAT,W/ ADDED CA,VITAMINS A & D',16229,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soymilk (all flavors), nonfat, with added calcium, vitamins A and D','SOYMILK (ALL FLAVORS),NONFAT,W/ ADDED CA,VITAMINS A & D',16230,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soymilk, chocolate, nonfat, with added calcium, vitamins A and D','SOYMILK,CHOC,NONFAT,W/ ADDED CA,VITAMINS A & D',16231,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, adzuki, mature seed, cooked, boiled, with salt','BEANS,ADZUKI,MATURE SD,CKD,BLD,W/SALT',16302,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, black, mature seeds, cooked, boiled, with salt','BEANS,BLACK,MATURE SEEDS,CKD,BLD,W/SALT',16315,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, black, mature seeds, canned, low sodium','BEANS,BLACK,MATURE SEEDS,CND,LO NA',16316,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, black turtle, mature seeds, cooked, boiled, with salt','BEANS,BLACK TURTLE,MATURE SEEDS,CKD,BLD,W/ SALT',16317,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, cranberry (roman), mature seeds, cooked, boiled, with salt','BEANS,CRANBERRY (ROMAN),MATURE SEEDS,CKD,BLD,W/SALT',16320,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, french, mature seeds, cooked, boiled, with salt','BEANS,FRENCH,MATURE SEEDS,CKD,BLD,W/SALT',16323,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, great northern, mature seeds, cooked, boiled, with salt','BEANS,GREAT NORTHERN,MATURE SEEDS,CKD,BLD,W/SALT',16325,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, great northern, mature seeds, canned, low sodium','BEANS,GREAT NORTHERN,MATURE SEEDS,CND,LO NA',16326,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, all types, mature seeds, cooked, boiled, with salt','BEANS,KIDNEY,ALL TYPES,MATURE SEEDS,CKD,BLD,W/SALT',16328,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, california red, mature seeds, cooked, boiled, with salt','BEANS,KIDNEY,CALIFORNIA RED,MATURE SEEDS,CKD,BLD,W/SALT',16331,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, red, mature seeds, cooked, boiled, with salt','BEANS,KIDNEY,RED,MATURE SEEDS,CKD,BLD,W/SALT',16333,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, red, mature seeds, canned, drained solids, rinsed in tap water','BEANS,KIDNEY,RED,MATURE SEEDS,CND,DRND SOL,RINSED IN TAP H2O',16335,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, royal red, mature seeds, cooked, boiled with salt','BEANS,KIDNEY,ROYAL RED,MATURE SEEDS,CKD,BLD W/SALT',16336,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, kidney, red, mature seeds, canned, solids and liquid, low sodium','BEANS,KIDNEY,RED,MATURE SEEDS,CND,SOL & LIQ,LO NA',16337,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, navy, mature seeds, cooked, boiled, with salt','BEANS,NAVY,MATURE SEEDS,CKD,BLD,W/SALT',16338,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, pink, mature seeds, cooked, boiled, with salt','BEANS,PINK,MATURE SEEDS,CKD,BLD,W/SALT',16341,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, pinto, mature seeds, cooked, boiled, with salt','BEANS,PINTO,MATURE SEEDS,CKD,BLD,W/SALT',16343,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, small white, mature seeds, cooked, boiled, with salt','BEANS,SML WHITE,MATURE SEEDS,CKD,BLD,W/SALT',16346,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, pinto, mature seeds, canned, solids and liquids, low sodium','BEANS,PINTO,MATURE SEEDS,CND,SOL & LIQUIDS,LO NA',16347,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, yellow, mature seeds, cooked, boiled, with salt','BEANS,YEL,MATURE SEEDS,CKD,BLD,W/SALT',16348,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, white, mature seeds, cooked, boiled, with salt','BEANS,WHITE,MATURE SEEDS,CKD,BLD,W/ SALT',16350,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Broadbeans (fava beans), mature seeds, cooked, boiled, with salt','BROADBEANS (FAVA BNS),MATURE SEEDS,CKD,BLD,W/SALT',16353,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Chickpeas (garbanzo beans, bengal gram), mature seeds, cooked, boiled, with salt','CHICKPEAS,MATURE SEEDS,CKD,BLD,W/SALT',16357,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Chickpeas (garbanzo beans, bengal gram), mature seeds, canned, drained solids','CHICKPEAS,MAT SEEDS,CND,DRND SOL',16358,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Chickpeas (garbanzo beans, bengal gram), mature seeds, canned, drained, rinsed in tap water','CHICKPEAS,MATURE SEEDS,CND,DRND,RINSED IN TAP H2O',16359,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Chickpeas (garbanzo beans, bengal gram), mature seeds, canned, solids and liquids, low sodium','CHICKPEAS,MATURE SEEDS,CND,SOL & LIQUIDS,LO NA',16360,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Cowpeas, catjang, mature seeds, cooked, boiled, with salt','COWPEAS,CATJANG,MATURE SEEDS,CKD,BLD,W/SALT',16361,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Cowpeas, common (blackeyes, crowder, southern), mature seeds, cooked, boiled, with salt','COWPEAS,COMMON,MATURE SEEDS,CKD,BLD,W/SALT',16363,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Hyacinth beans, mature seeds, cooked, boiled, with salt','HYACINTH BNS,MATURE SEEDS,CKD,BLD,W/SALT',16368,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Lentils, mature seeds, cooked, boiled, with salt','LENTILS,MATURE SEEDS,CKD,BLD,W/SALT',16370,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Lima beans, large, mature seeds, cooked, boiled, with salt','LIMA BNS,LRG,MATURE SEEDS,CKD,BLD,W/SALT',16372,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Lima beans, thin seeded (baby), mature seeds, cooked, boiled, with salt','LIMA BNS,THIN SEEDED (BABY),MATURE SEEDS,CKD,BLD,W/SALT',16375,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Lupins, mature seeds, cooked, boiled, with salt','LUPINS,MATURE SEEDS,CKD,BLD,W/SALT',16377,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Mothbeans, mature seeds, cooked, boiled, with salt','MOTHBEANS,MATURE SEEDS,CKD,BLD,W/SALT',16379,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Mung beans, mature seeds, cooked, boiled, with salt','MUNG BNS,MATURE SEEDS,CKD,BLD,W/SALT',16381,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Mungo beans, mature seeds, cooked, boiled, with salt','MUNGO BNS,MATURE SEEDS,CKD,BLD,W/SALT',16384,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peas, split, mature seeds, cooked, boiled, with salt','PEAS,SPLIT,MATURE SEEDS,CKD,BLD,W/SALT',16386,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanuts, all types, oil-roasted, without salt','PEANUTS,ALL TYPES,OIL-ROASTED,WO/ SALT',16389,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanuts, all types, dry-roasted, without salt','PEANUTS,ALL TYPES,DRY-ROASTED,WO/SALT',16390,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanuts, spanish, oil-roasted, without salt','PEANUTS,SPANISH,OIL-ROASTED,WO/SALT',16392,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanuts, valencia, oil-roasted, without salt','PEANUTS,VALENCIA,OIL-ROASTED,WO/SALT',16394,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanuts, virginia, oil-roasted, without salt','PEANUTS,VIRGINIA,OIL-ROASTED,WO/SALT',16396,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanut butter, chunk style, without salt','PEANUT BUTTER,CHUNK STYLE,WO/SALT',16397,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanut butter, smooth style, without salt','PEANUT BUTTER,SMOOTH STYLE,WO/SALT',16398,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanut butter with omega-3, creamy','PEANUT BUTTER W/ OMEGA-3,CREAMY',16399,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Pigeon peas (red gram), mature seeds, cooked, boiled, with salt','PIGEON PEAS (RED GM),MATURE SEEDS,CKD,BLD,W/SALT',16402,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Refried beans, canned, traditional, reduced sodium','REFRIED BNS,CND,TRADITIONAL,RED NA',16403,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soybeans, mature seeds, cooked, boiled, with salt','SOYBEANS,MATURE SEEDS,CKD,BLD,W/SALT',16409,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soybeans, mature seeds, roasted, no salt added','SOYBEANS,MATURE SEEDS,RSTED,NO SALT ADDED',16410,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soy protein concentrate, produced by acid wash','SOY PROT CONC,PRODUCED BY ACID WASH',16420,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soy protein isolate, potassium type','SOY PROT ISOLATE,K TYPE',16422,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soy sauce made from soy and wheat (shoyu), low sodium','SOY SAU MADE FROM SOY&WHEAT (SHOYU),LO NA',16424,NULL,NULL,NULL,NULL,NULL,1,'1995-06-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soy sauce, reduced sodium, made from hydrolyzed vegetable protein','SOY SAU,RED NA,MADE FROM HYDROLYZED VEG PROT',16425,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Tofu, raw, firm, prepared with calcium sulfate','TOFU,RAW,FIRM,PREP W/CA SULFATE',16426,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Tofu, raw, regular, prepared with calcium sulfate','TOFU,RAW,REG,PREP W/CA SULFATE',16427,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Tofu, dried-frozen (koyadofu), prepared with calcium sulfate','TOFU,DRIED-FROZEN (KOYADOFU),PREP W/CA SULFATE',16428,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Tofu, fried, prepared with calcium sulfate','TOFU,FRIED,PREP W/CA SULFATE',16429,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Tofu, salted and fermented (fuyu), prepared with calcium sulfate','TOFU,SALTED&FERMENTED (FUYU),PREP W/CA SULFATE',16432,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Yardlong beans, mature seeds, cooked, boiled, with salt','YARDLONG BNS,MATURE SEEDS,CKD,BLD,W/ SALT',16434,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Winged beans, mature seeds, cooked, boiled, with salt','WINGED BNS,MATURE SEEDS,CKD,BLD,W/ SALT',16436,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, Australian, rib, rib roast, separable lean only, raw','VEAL,AUSTRALIAN,RIB,RIB RST,LN,RAW',17000,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, composite of trimmed retail cuts, separable lean and fat, trimmed to 1/4" fat, choice, raw','LAMB,COMP OF RTL CUTS,LN & FAT,1/4" FAT,CHOIC,RAW',17001,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, composite of trimmed retail cuts, separable lean and fat, trimmed to 1/4" fat, choice, cooked','LAMB,COMP OF RTL CUTS,LN & FAT,1/4" FAT,CHOIC,CKD',17002,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, composite of trimmed retail cuts, separable lean only, trimmed to 1/4" fat, choice, raw','LAMB,COMP OF RTL CUTS,LN,1/4" FAT,CHOIC,RAW',17003,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, composite of trimmed retail cuts, separable lean only, trimmed to 1/4" fat, choice, cooked','LAMB,COMP OF RTL CUTS,LN,1/4" FAT,CHOIC,CKD',17004,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, composite of trimmed retail cuts, separable fat, trimmed to 1/4" fat, choice, raw','LAMB,COMP OF RTL CUTS,FAT,1/4" FAT,CHOIC,RAW',17005,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, composite of trimmed retail cuts, separable fat, trimmed to 1/4" fat, choice, cooked','LAMB,COMP OF RTL CUTS,FAT,1/4" FAT,CHOIC,CKD',17006,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, foreshank, separable lean and fat, trimmed to 1/4" fat, choice, raw','LAMB,FORESHANK,LN & FAT,1/4" FAT,CHOIC,RAW',17007,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, foreshank, separable lean and fat, trimmed to 1/4" fat, choice, cooked, braised','LAMB,FORESHANK,LN & FAT,1/4" FAT,CHOIC,CKD,BRSD',17008,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, foreshank, separable lean only, trimmed to 1/4" fat, choice, raw','LAMB,FORESHANK,LN,1/4" FAT,CHOIC,RAW',17009,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, foreshank, separable lean only, trimmed to 1/4" fat, choice, cooked, braised','LAMB,FORESHANK,LN,1/4" FAT,CHOIC,CKD,BRSD',17010,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, whole (shank and sirloin), separable lean and fat, trimmed to 1/4" fat, choice, raw','LAMB,LEG,WHL (SHK&SIRL),LN & FAT,1/4" FAT,CHOIC,RAW',17011,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, whole (shank and sirloin), separable lean and fat, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,LEG,WHL (SHK&SIRL),LN & FAT,1/4" FAT,CHOIC,CKD,RSTD',17012,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, whole (shank and sirloin), separable lean only, trimmed to 1/4" fat, choice, raw','LAMB,LEG,WHL (SHK&SIRL),LN,1/4" FAT,CHOIC,RAW',17013,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, whole (shank and sirloin), separable lean only, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,LEG,WHL (SHK&SIRL),LN,1/4" FAT,CHOIC,CKD,RSTD',17014,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, shank half, separable lean and fat, trimmed to 1/4" fat, choice, raw','LAMB,LEG,SHANK HALF,LN & FAT,1/4" FAT,CHOIC,RAW',17015,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, shank half, separable lean and fat, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,LEG,SHANK HALF,LN & FAT,1/4" FAT,CHOIC,CKD,RSTD',17016,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, shank half, separable lean only, trimmed to 1/4" fat, choice, raw','LAMB,LEG,SHANK HALF,LN,1/4" FAT,CHOIC,RAW',17017,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, shank half, separable lean only, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,LEG,SHANK HALF,LN,1/4" FAT,CHOIC,CKD,RSTD',17018,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, sirloin half, separable lean and fat, trimmed to 1/4" fat, choice, raw','LAMB,LEG,SIRLOIN HALF,LN & FAT,1/4" FAT,CHOIC,RAW',17019,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, sirloin half, separable lean and fat, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,LEG,SIRLOIN HALF,LN & FAT,1/4" FAT,CHOIC,CKD,RSTD',17020,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, sirloin half, separable lean only, trimmed to 1/4" fat, choice, raw','LAMB,LEG,SIRLOIN HALF,LN,1/4" FAT,CHOIC,RAW',17021,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, sirloin half, separable lean only, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,LEG,SIRLOIN HALF,LN,1/4" FAT,CHOIC,CKD,RSTD',17022,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, loin, separable lean and fat, trimmed to 1/4" fat, choice, raw','LAMB,LOIN,LN & FAT,1/4" FAT,CHOIC,RAW',17023,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, loin, separable lean and fat, trimmed to 1/4" fat, choice, cooked, broiled','LAMB,LOIN,LN & FAT,1/4" FAT,CHOIC,CKD,BRLD',17024,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, loin, separable lean and fat, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,LOIN,LN & FAT,1/4" FAT,CHOIC,CKD,RSTD',17025,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, loin, separable lean only, trimmed to 1/4" fat, choice, raw','LAMB,LOIN,LN,1/4" FAT,CHOIC,RAW',17026,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, loin, separable lean only, trimmed to 1/4" fat, choice, cooked, broiled','LAMB,LOIN,LN,1/4" FAT,CHOIC,CKD,BRLD',17027,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, loin, separable lean only, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,LOIN,LN,1/4" FAT,CHOIC,CKD,RSTD',17028,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, rib, separable lean and fat, trimmed to 1/4" fat, choice, raw','LAMB,RIB,LN & FAT,1/4" FAT,CHOIC,RAW',17029,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, rib, separable lean and fat, trimmed to 1/4" fat, choice, cooked, broiled','LAMB,RIB,LN & FAT,1/4" FAT,CHOIC,CKD,BRLD',17030,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, rib, separable lean and fat, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,RIB,LN & FAT,1/4" FAT,CHOIC,CKD,RSTD',17031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, rib, separable lean only, trimmed to 1/4" fat, choice, raw','LAMB,RIB,LN,1/4" FAT,CHOIC,RAW',17032,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, rib, separable lean only, trimmed to 1/4" fat, choice, cooked, broiled','LAMB,RIB,LN,1/4" FAT,CHOIC,CKD,BRLD',17033,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, rib, separable lean only, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,RIB,LN,1/4" FAT,CHOIC,CKD,RSTD',17034,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, whole (arm and blade), separable lean and fat, trimmed to 1/4" fat, choice, raw','LAMB,SHLDR,WHL (ARM&BLD),LN & FAT,1/4" FAT,CHOIC,RAW',17035,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, whole (arm and blade), separable lean and fat, trimmed to 1/4" fat, choice, cooked, braised','LAMB,SHLDR,WHL (ARM&BLD),LN & FAT,1/4" FAT,CHOIC,CKD,BRSD',17036,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, whole (arm and blade), separable lean and fat, trimmed to 1/4" fat, choice, cooked, broiled','LAMB,SHLDR,WHL (ARM&BLD),LN & FAT,1/4" FAT,CHOIC,CKD,BRLD',17037,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, whole (arm and blade), separable lean and fat, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,SHLDR,WHL (ARM&BLD),LN & FAT,1/4" FAT,CHOIC,CKD,RSTD',17038,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, whole (arm and blade), separable lean only, trimmed to 1/4" fat, choice, raw','LAMB,SHLDR,WHL (ARM&BLD),LN,1/4" FAT,CHOIC,RAW',17039,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, whole (arm and blade), separable lean only, trimmed to 1/4" fat, choice, cooked, braised','LAMB,SHLDR,WHL (ARM&BLD),LN,1/4" FAT,CHOIC,CKD,BRSD',17040,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, whole (arm and blade), separable lean only, trimmed to 1/4" fat, choice, cooked, broiled','LAMB,SHLDR,WHL (ARM&BLD),LN,1/4" FAT,CHOIC,CKD,BRLD',17041,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, whole (arm and blade), separable lean only, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,SHLDR,WHL (ARM&BLD),LN,1/4" FAT,CHOIC,CKD,RSTD',17042,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, arm, separable lean and fat, trimmed to 1/4" fat, choice, raw','LAMB,SHLDR,ARM,LN & FAT,1/4" FAT,CHOIC,RAW',17043,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, arm, separable lean and fat, trimmed to 1/4" fat, choice, cooked, braised','LAMB,SHLDR,ARM,LN & FAT,1/4" FAT,CHOIC,CKD,BRSD',17044,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, arm, separable lean and fat, trimmed to 1/4" fat, choice, cooked, broiled','LAMB,SHLDR,ARM,LN & FAT,1/4" FAT,CHOIC,CKD,BRLD',17045,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, arm, separable lean and fat, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,SHLDR,ARM,LN & FAT,1/4" FAT,CHOIC,CKD,RSTD',17046,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, arm, separable lean only, trimmed to 1/4" fat, choice, raw','LAMB,SHLDR,ARM,LN,1/4" FAT,CHOIC,RAW',17047,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, arm, separable lean only, trimmed to 1/4" fat, choice, cooked, braised','LAMB,SHLDR,ARM,LN,1/4" FAT,CHOIC,CKD,BRSD',17048,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, arm, separable lean only, trimmed to 1/4" fat, choice, cooked, broiled','LAMB,SHLDR,ARM,LN,1/4" FAT,CHOIC,CKD,BRLD',17049,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, arm, separable lean only, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,SHLDR,ARM,LN,1/4" FAT,CHOIC,CKD,RSTD',17050,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, blade, separable lean and fat, trimmed to 1/4" fat, choice, raw','LAMB,SHLDR,BLADE,LN & FAT,1/4" FAT,CHOIC,RAW',17051,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, blade, separable lean and fat, trimmed to 1/4" fat, choice, cooked, braised','LAMB,SHLDR,BLADE,LN & FAT,1/4" FAT,CHOIC,CKD,BRSD',17052,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, blade, separable lean and fat, trimmed to 1/4" fat, choice, cooked, broiled','LAMB,SHLDR,BLADE,LN & FAT,1/4" FAT,CHOIC,CKD,BRLD',17053,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, blade, separable lean and fat, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,SHLDR,BLADE,LN & FAT,1/4" FAT,CHOIC,CKD,RSTD',17054,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, blade, separable lean only, trimmed to 1/4" fat, choice, raw','LAMB,SHLDR,BLADE,LN,1/4" FAT,CHOIC,RAW',17055,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, blade, separable lean only, trimmed to 1/4" fat, choice, cooked, braised','LAMB,SHLDR,BLADE,LN,1/4" FAT,CHOIC,CKD,BRSD',17056,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, blade, separable lean only, trimmed to 1/4" fat, choice, cooked, broiled','LAMB,SHLDR,BLADE,LN,1/4" FAT,CHOIC,CKD,BRLD',17057,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, blade, separable lean only, trimmed to 1/4" fat, choice, cooked, roasted','LAMB,SHLDR,BLADE,LN,1/4" FAT,CHOIC,CKD,RSTD',17058,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, cubed for stew or kabob (leg and shoulder), separable lean only, trimmed to 1/4" fat, raw','LAMB,CUBED FOR STEW OR KABOB (LEG & SHOULDER),LN,1/4"FAT,RAW',17059,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, cubed for stew or kabob (leg and shoulder), separable lean only, trimmed to 1/4" fat, cooked, braised','LAMB,CUBED FOR STEW OR KABOB(LEG&SHLDER),LN,1/4"FAT,CKD,BRSD',17060,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, cubed for stew or kabob (leg and shoulder), separable lean only, trimmed to 1/4" fat, cooked, broiled','LAMB,CUBED FOR STEW OR KABOB(LEG&SHLDER),LN,1/4"FAT,CKD,BRLD',17061,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, composite of trimmed retail cuts, separable lean and fat, raw','LAMB,NZ,IMP,FRZ,COMP OF RTL CUTS,LN&FAT,RAW',17062,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, composite of trimmed retail cuts, separable lean and fat, cooked','LAMB,NZ,IMP,FRZ,COMP OF RTL CUTS,LN&FAT,CKD',17063,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, composite of trimmed retail cuts, separable lean only, raw','LAMB,NZ,IMP,FRZ,COMP OF RTL CUTS,LN,RAW',17064,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, composite of trimmed retail cuts, separable lean only, cooked','LAMB,NZ,IMP,FRZ,COMP OF RTL CUTS,LN,CKD',17065,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, composite of trimmed retail cuts, separable fat, raw','LAMB,NZ,IMP,FRZ,COMP OF RTL CUTS,FAT,RAW',17066,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, composite of trimmed retail cuts, separable fat, cooked','LAMB,NZ,IMP,FRZ,COMP OF RTL CUTS,FAT,CKD',17067,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, fore-shank, separable lean and fat, raw','LAMB,NZ,IMP,FORE-SHANK,LN & FAT,RAW',17068,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, fore-shank, separable lean and fat, cooked, braised','LAMB,NZ,IMP,FORE-SHANK,LN & FAT,CKD,BRSD',17069,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, fore-shank, separable lean only, raw','LAMB,NZ,IMP,FORE-SHANK,LN,RAW',17070,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, fore-shank, separable lean only, cooked, braised','LAMB,NZ,IMP,FORE-SHANK,LN,CKD,BRSD',17071,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, leg chop/steak, bone-in, separable lean and fat, raw','LAMB,NZ,IMP,LEG CHOP/STEAK,BONE-IN,LN & FAT,RAW',17072,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, leg, whole (shank and sirloin), separable lean and fat, cooked, roasted','LAMB,NZ,IMP,FRZ,LEG,WHL (SHK&SIRL),LN&FAT,CKD,RSTD',17073,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, leg chop/steak, bone-in, separable lean only, raw','LAMB,NZ,IMP,LEG CHOP/STEAK,BONE-IN,LN,RAW',17074,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, leg, whole (shank and sirloin), separable lean only, cooked, roasted','LAMB,NZ,IMP,FRZ,LEG,WHL (SHK&SIRL),LN,CKD,RSTD',17075,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, loin chop, separable lean and fat, raw','LAMB,NZ,IMP,LOIN CHOP,LN & FAT,RAW',17076,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, loin, separable lean and fat, cooked, broiled','LAMB,NZ,IMP,FRZ,LOIN,LN&FAT,CKD,BRLD',17077,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, loin chop, separable lean only, raw','LAMB,NZ,IMP,LOIN CHOP,LN,RAW',17078,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, loin, separable lean only, cooked, broiled','LAMB,NZ,IMP,FRZ,LOIN,LN,CKD,BRLD',17079,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, rack - partly frenched, separable lean and fat, raw','LAMB,NZ,IMP,RACK - PARTLY FRENCHED,LN & FAT,RAW',17080,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, rack - partly frenched, separable lean and fat, cooked, fast roasted','LAMB,NZ,IMP,RACK - PARTLY FRENCHED,LN & FAT,CKD,FAST RSTD',17081,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, rack - partly frenched, separable lean only, raw','LAMB,NZ,IMP,RACK - PARTLY FRENCHED,LN,RAW',17082,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, rack - partly frenched, separable lean only, cooked, fast roasted','LAMB,NZ,IMP,RACK - PARTLY FRENCHED,LN,CKD,FAST RSTD',17083,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, square-cut shoulder, separable lean and fat, raw','LAMB,NZ,IMP,SQUARE-CUT SHLDR,LN & FAT,RAW',17084,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, shoulder, whole (arm and blade), separable lean and fat, cooked, braised','LAMB,NZ,IMP,FRZ,SHLDR,WHL (ARM&BLD),LN&FAT,CKD,BRSD',17085,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, square-cut shoulder, separable lean only, raw','LAMB,NZ,IMP,SQUARE-CUT SHLDR,LN,RAW',17086,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, shoulder, whole (arm and blade), separable lean only, cooked, braised','LAMB,NZ,IMP,FRZ,SHLDR,WHL (ARM&BLD),LN,CKD,BRSD',17087,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, composite of trimmed retail cuts, separable lean and fat, raw','VEAL,COMP OF RTL CUTS,LN&FAT,RAW',17088,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, composite of trimmed retail cuts, separable lean and fat, cooked','VEAL,COMP OF RTL CUTS,LN&FAT,CKD',17089,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, composite of trimmed retail cuts, separable lean only, raw','VEAL,COMP OF RTL CUTS,LN,RAW',17090,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, composite of trimmed retail cuts, separable lean only, cooked','VEAL,COMP OF RTL CUTS,LN,CKD',17091,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, composite of trimmed retail cuts, separable fat, raw','VEAL,COMP OF RTL CUTS,FAT,RAW',17092,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, composite of trimmed retail cuts, separable fat, cooked','VEAL,COMP OF RTL CUTS,FAT,CKD',17093,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, leg (top round), separable lean and fat, raw','VEAL,LEG (TOP RND),LN&FAT,RAW',17094,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, leg (top round), separable lean and fat, cooked, braised','VEAL,LEG (TOP RND),LN&FAT,CKD,BRSD',17095,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, leg (top round), separable lean and fat, cooked, pan-fried, breaded','VEAL,LEG (TOP RND),LN&FAT,CKD,PAN-FRIED,BREADED',17096,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, leg (top round), separable lean and fat, cooked, pan-fried, not breaded','VEAL,LEG (TOP RND),LN&FAT,CKD,PAN-FRIED,NOT BREADED',17097,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, leg (top round), separable lean and fat, cooked, roasted','VEAL,LEG (TOP RND),LN&FAT,CKD,RSTD',17098,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, leg (top round), separable lean only, raw','VEAL,LEG (TOP RND),LN,RAW',17099,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, leg (top round), separable lean only, cooked, braised','VEAL,LEG (TOP RND),LN,CKD,BRSD',17100,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, leg (top round), separable lean only, cooked, pan-fried, breaded','VEAL,LEG (TOP RND),LN,CKD,PAN-FRIED,BREADED',17101,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, leg (top round), separable lean only, cooked, pan-fried, not breaded','VEAL,LEG (TOP RND),LN,CKD,PAN-FRIED,NOT BREADED',17102,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, leg (top round), separable lean only, cooked, roasted','VEAL,LEG (TOP RND),LN,CKD,RSTD',17103,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, loin, separable lean and fat, raw','VEAL,LOIN,LN&FAT,RAW',17104,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, loin, separable lean and fat, cooked, braised','VEAL,LOIN,LN&FAT,CKD,BRSD',17105,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, loin, separable lean and fat, cooked, roasted','VEAL,LOIN,LN&FAT,CKD,RSTD',17106,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, loin, separable lean only, raw','VEAL,LOIN,LN,RAW',17107,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, loin, separable lean only, cooked, braised','VEAL,LOIN,LN,CKD,BRSD',17108,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, loin, separable lean only, cooked, roasted','VEAL,LOIN,LN,CKD,RSTD',17109,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, rib, separable lean and fat, raw','VEAL,RIB,LN&FAT,RAW',17110,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, rib, separable lean and fat, cooked, braised','VEAL,RIB,LN&FAT,CKD,BRSD',17111,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, rib, separable lean and fat, cooked, roasted','VEAL,RIB,LN&FAT,CKD,RSTD',17112,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, rib, separable lean only, raw','VEAL,RIB,LN,RAW',17113,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, rib, separable lean only, cooked, braised','VEAL,RIB,LN,CKD,BRSD',17114,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, rib, separable lean only, cooked, roasted','VEAL,RIB,LN,CKD,RSTD',17115,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, whole (arm and blade), separable lean and fat, raw','VEAL,SHLDR,WHL (ARM&BLD),LN&FAT,RAW',17116,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, whole (arm and blade), separable lean and fat, cooked, braised','VEAL,SHLDR,WHL (ARM&BLD),LN&FAT,CKD,BRSD',17117,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, whole (arm and blade), separable lean and fat, cooked, roasted','VEAL,SHLDR,WHL (ARM&BLD),LN&FAT,CKD,RSTD',17118,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, whole (arm and blade), separable lean only, raw','VEAL,SHLDR,WHL (ARM&BLD),LN,RAW',17119,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, whole (arm and blade), separable lean only, cooked, braised','VEAL,SHLDR,WHL (ARM&BLD),LN,CKD,BRSD',17120,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, whole (arm and blade), separable lean only, cooked, roasted','VEAL,SHLDR,WHL (ARM&BLD),LN,CKD,RSTD',17121,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, arm, separable lean and fat, raw','VEAL,SHLDR,ARM,LN&FAT,RAW',17122,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, arm, separable lean and fat, cooked, braised','VEAL,SHLDR,ARM,LN&FAT,CKD,BRSD',17123,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, arm, separable lean and fat, cooked, roasted','VEAL,SHLDR,ARM,LN&FAT,CKD,RSTD',17124,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, arm, separable lean only, raw','VEAL,SHLDR,ARM,LN,RAW',17125,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, arm, separable lean only, cooked, braised','VEAL,SHLDR,ARM,LN,CKD,BRSD',17126,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, arm, separable lean only, cooked, roasted','VEAL,SHLDR,ARM,LN,CKD,RSTD',17127,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, blade chop, separable lean and fat, raw','VEAL,SHLDR,BLADE CHOP,LN & FAT,RAW',17128,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, blade, separable lean and fat, cooked, braised','VEAL,SHLDR,BLADE,LN&FAT,CKD,BRSD',17129,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, blade, separable lean and fat, cooked, roasted','VEAL,SHLDR,BLADE,LN&FAT,CKD,RSTD',17130,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, blade chop, separable lean only, raw','VEAL,SHLDR,BLADE CHOP,LN,RAW',17131,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, blade, separable lean only, cooked, braised','VEAL,SHLDR,BLADE,LN,CKD,BRSD',17132,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, blade, separable lean only, cooked, roasted','VEAL,SHLDR,BLADE,LN,CKD,RSTD',17133,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, sirloin, separable lean and fat, raw','VEAL,SIRLOIN,LN&FAT,RAW',17134,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, sirloin, separable lean and fat, cooked, braised','VEAL,SIRLOIN,LN&FAT,CKD,BRSD',17135,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, sirloin, separable lean and fat, cooked, roasted','VEAL,SIRLOIN,LN&FAT,CKD,RSTD',17136,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, sirloin, separable lean only, raw','VEAL,SIRLOIN,LN,RAW',17137,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, sirloin, separable lean only, cooked, braised','VEAL,SIRLOIN,LN,CKD,BRSD',17138,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, sirloin, separable lean only, cooked, roasted','VEAL,SIRLOIN,LN,CKD,RSTD',17139,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, cubed for stew (leg and shoulder), separable lean only, raw','VEAL,CUBED FOR STEW (LEG&SHLDR),LN,RAW',17140,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, cubed for stew (leg and shoulder), separable lean only, cooked, braised','VEAL,CUBED FOR STEW (LEG&SHLDR),LN,CKD,BRSD',17141,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, ground, raw','VEAL,GROUND,RAW',17142,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, ground, cooked, broiled','VEAL,GROUND,CKD,BRLD',17143,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, antelope, raw','GAME MEAT,ANTELOPE,RAW',17144,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, antelope, cooked, roasted','GAME MEAT,ANTELOPE,CKD,RSTD',17145,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, bear, cooked, simmered','GAME MEAT,BEAR,CKD,SIMMRD',17147,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Bison, ground, grass-fed, cooked','BISON,GROUND,GRASS-FED,CKD',17148,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2009-01-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Bison, ground, grass-fed, raw','BISON,GROUND,GRASS-FED,RAW',17149,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, beaver, cooked, roasted','GAME MEAT,BEAVER,CKD,RSTD',17151,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, beefalo, composite of cuts, raw','GAME MEAT,BEEFALO,COMP OF CUTS,RAW',17152,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, beefalo, composite of cuts, cooked, roasted','GAME MEAT,BEEFALO,COMP OF CUTS,CKD,RSTD',17153,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, Australian, separable fat, raw','VEAL,AUSTRALIAN,FAT,RAW',17154,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, Australian, rib, rib roast, separable lean and fat, raw','VEAL,AUSTRALIAN,RIB,RIB RST,LN & FAT,RAW',17155,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, bison, separable lean only, raw','GAME MEAT,BISON,LN,RAW',17156,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, bison, separable lean only, cooked, roasted','GAME MEAT,BISON,LN,CKD,RSTD',17157,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, boar, wild, cooked, roasted','GAME MEAT,BOAR,WILD,CKD,RSTD',17159,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, buffalo, water, raw','GAME MEAT,BUFFALO,H2O,RAW',17160,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, buffalo, water, cooked, roasted','GAME MEAT,BUFFALO,H2O,CKD,RSTD',17161,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, caribou, raw','GAME MEAT,CARIBOU,RAW',17162,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, caribou, cooked, roasted','GAME MEAT,CARIBOU,CKD,RSTD',17163,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, deer, raw','GAME MEAT,DEER,RAW',17164,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, deer, cooked, roasted','GAME MEAT,DEER,CKD,RSTD',17165,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, elk, raw','GAME MEAT,ELK,RAW',17166,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, elk, cooked, roasted','GAME MEAT,ELK,CKD,RSTD',17167,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, goat, raw','GAME MEAT,GOAT,RAW',17168,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, goat, cooked, roasted','GAME MEAT,GOAT,CKD,RSTD',17169,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, horse, raw','GAME MEAT,HORSE,RAW',17170,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, horse, cooked, roasted','GAME MEAT,HORSE,CKD,RSTD',17171,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, moose, raw','GAME MEAT,MOOSE,RAW',17172,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, moose, cooked, roasted','GAME MEAT,MOOSE,CKD,RSTD',17173,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, opossum, cooked, roasted','GAME MEAT,OPOSSUM,CKD,RSTD',17176,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, rabbit, domesticated, composite of cuts, raw','GAME MEAT,RABBIT,DOMESTICATED,COMP OF CUTS,RAW',17177,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, rabbit, domesticated, composite of cuts, cooked, roasted','GAME MEAT,RABBIT,DOMESTICATED,COMP OF CUTS,CKD,RSTD',17178,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, rabbit, domesticated, composite of cuts, cooked, stewed','GAME MEAT,RABBIT,DOMESTICATED,COMP OF CUTS,CKD,STWD',17179,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, rabbit, wild, raw','GAME MEAT,RABBIT,WILD,RAW',17180,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, rabbit, wild, cooked, stewed','GAME MEAT,RABBIT,WILD,CKD,STWD',17181,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, raccoon, cooked, roasted','GAME MEAT,RACCOON,CKD,RSTD',17182,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, squirrel, raw','GAME MEAT,SQUIRREL,RAW',17183,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, squirrel, cooked, roasted','GAME MEAT,SQUIRREL,CKD,RSTD',17184,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, brain, raw','LAMB,VAR MEATS&BY-PRODUCTS,BRAIN,RAW',17185,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, brain, cooked, braised','LAMB,VAR MEATS&BY-PRODUCTS,BRAIN,CKD,BRSD',17186,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, brain, cooked, pan-fried','LAMB,VAR MEATS&BY-PRODUCTS,BRAIN,CKD,PAN-FRIED',17187,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, brain, raw','VEAL,VAR MEATS&BY-PRODUCTS,BRAIN,RAW',17188,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, brain, cooked, braised','VEAL,VAR MEATS&BY-PRODUCTS,BRAIN,CKD,BRSD',17189,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, brain, cooked, pan-fried','VEAL,VAR MEATS&BY-PRODUCTS,BRAIN,CKD,PAN-FRIED',17190,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, heart, raw','LAMB,VAR MEATS&BY-PRODUCTS,HEART,RAW',17191,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, heart, cooked, braised','LAMB,VAR MEATS&BY-PRODUCTS,HEART,CKD,BRSD',17192,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, heart, raw','VEAL,VAR MEATS&BY-PRODUCTS,HEART,RAW',17193,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, heart, cooked, braised','VEAL,VAR MEATS&BY-PRODUCTS,HEART,CKD,BRSD',17194,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, kidneys, raw','LAMB,VAR MEATS&BY-PRODUCTS,KIDNEYS,RAW',17195,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, kidneys, cooked, braised','LAMB,VAR MEATS&BY-PRODUCTS,KIDNEYS,CKD,BRSD',17196,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, kidneys, raw','VEAL,VAR MEATS&BY-PRODUCTS,KIDNEYS,RAW',17197,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, kidneys, cooked, braised','VEAL,VAR MEATS&BY-PRODUCTS,KIDNEYS,CKD,BRSD',17198,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, liver, raw','LAMB,VAR MEATS&BY-PRODUCTS,LIVER,RAW',17199,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, liver, cooked, braised','LAMB,VAR MEATS&BY-PRODUCTS,LIVER,CKD,BRSD',17200,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, liver, cooked, pan-fried','LAMB,VAR MEATS&BY-PRODUCTS,LIVER,CKD,PAN-FRIED',17201,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, liver, raw','VEAL,VAR MEATS&BY-PRODUCTS,LIVER,RAW',17202,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, liver, cooked, braised','VEAL,VAR MEATS&BY-PRODUCTS,LIVER,CKD,BRSD',17203,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, liver, cooked, pan-fried','VEAL,VAR MEATS&BY-PRODUCTS,LIVER,CKD,PAN-FRIED',17204,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, lungs, raw','LAMB,VAR MEATS&BY-PRODUCTS,LUNGS,RAW',17205,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, lungs, cooked, braised','LAMB,VAR MEATS&BY-PRODUCTS,LUNGS,CKD,BRSD',17206,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, lungs, raw','VEAL,VAR MEATS&BY-PRODUCTS,LUNGS,RAW',17207,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, lungs, cooked, braised','VEAL,VAR MEATS&BY-PRODUCTS,LUNGS,CKD,BRSD',17208,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, mechanically separated, raw','LAMB,VAR MEATS&BY-PRODUCTS,MECHANICALLY SEPARATED,RAW',17209,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, pancreas, raw','LAMB,VAR MEATS&BY-PRODUCTS,PANCREAS,RAW',17210,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, pancreas, cooked, braised','LAMB,VAR MEATS&BY-PRODUCTS,PANCREAS,CKD,BRSD',17211,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, pancreas, raw','VEAL,VAR MEATS&BY-PRODUCTS,PANCREAS,RAW',17212,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, pancreas, cooked, braised','VEAL,VAR MEATS&BY-PRODUCTS,PANCREAS,CKD,BRSD',17213,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, spleen, raw','LAMB,VAR MEATS&BY-PRODUCTS,SPLEEN,RAW',17214,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, spleen, cooked, braised','LAMB,VAR MEATS&BY-PRODUCTS,SPLEEN,CKD,BRSD',17215,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, spleen, raw','VEAL,VAR MEATS&BY-PRODUCTS,SPLEEN,RAW',17216,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, spleen, cooked, braised','VEAL,VAR MEATS&BY-PRODUCTS,SPLEEN,CKD,BRSD',17217,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, thymus, raw','VEAL,VAR MEATS&BY-PRODUCTS,THYMUS,RAW',17218,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, thymus, cooked, braised','VEAL,VAR MEATS&BY-PRODUCTS,THYMUS,CKD,BRSD',17219,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, tongue, raw','LAMB,VAR MEATS&BY-PRODUCTS,TONGUE,RAW',17220,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, variety meats and by-products, tongue, cooked, braised','LAMB,VAR MEATS&BY-PRODUCTS,TONGUE,CKD,BRSD',17221,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, tongue, raw','VEAL,VAR MEATS&BY-PRODUCTS,TONGUE,RAW',17222,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, variety meats and by-products, tongue, cooked, braised','VEAL,VAR MEATS&BY-PRODUCTS,TONGUE,CKD,BRSD',17223,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, ground, raw','LAMB,GROUND,RAW',17224,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, ground, cooked, broiled','LAMB,GROUND,CKD,BRLD',17225,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, composite of trimmed retail cuts, separable lean and fat, trimmed to 1/8" fat, choice, raw','LAMB,COMP OF RTL CUTS,LN & FAT,1/8" FAT,CHOIC,RAW',17226,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, composite of trimmed retail cuts, separable lean and fat, trimmed to 1/8" fat, choice, cooked','LAMB,COMP OF RTL CUTS,LN & FAT,1/8" FAT,CHOIC,CKD',17227,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, foreshank, separable lean and fat, trimmed to 1/8" fat, choice, raw','LAMB,FORESHANK,LN & FAT,1/8" FAT,CHOIC,RAW',17228,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, foreshank, separable lean and fat, trimmed to 1/8" fat, cooked, braised','LAMB,FORESHANK,LN & FAT,1/8" FAT,CKD,BRSD',17229,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, whole (shank and sirloin), separable lean and fat, trimmed to 1/8" fat, choice, raw','LAMB,LEG,WHL (SHK&SIRL),LN & FAT,1/8" FAT,CHOIC,RAW',17230,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, whole (shank and sirloin), separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','LAMB,LEG,WHL (SHK&SIRL),LN & FAT,1/8" FAT,CHOIC,CKD,RSTD',17231,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, shank half, separable lean and fat, trimmed to 1/8" fat, choice, raw','LAMB,LEG,SHANK HALF,LN & FAT,1/8" FAT,CHOIC,RAW',17232,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, shank half, separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','LAMB,LEG,SHANK HALF,LN & FAT,1/8" FAT,CHOIC,CKD,RSTD',17233,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, sirloin half, separable lean and fat, trimmed to 1/8" fat, choice, raw','LAMB,LEG,SIRLOIN HALF,LN & FAT,1/8" FAT,CHOIC,RAW',17234,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, leg, sirloin half, separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','LAMB,LEG,SIRLOIN HALF,LN & FAT,1/8" FAT,CHOIC,CKD,RSTD',17235,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, loin, separable lean and fat, trimmed to 1/8" fat, choice, raw','LAMB,LOIN,LN & FAT,1/8" FAT,CHOIC,RAW',17236,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, loin, separable lean and fat, trimmed to 1/8" fat, choice, cooked, broiled','LAMB,LOIN,LN & FAT,1/8" FAT,CHOIC,CKD,BRLD',17237,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, loin, separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','LAMB,LOIN,LN & FAT,1/8" FAT,CHOIC,CKD,RSTD',17238,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, rib, separable lean and fat, trimmed to 1/8" fat, choice, raw','LAMB,RIB,LN & FAT,1/8" FAT,CHOIC,RAW',17239,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, rib, separable lean and fat, trimmed to 1/8" fat, choice, cooked, broiled','LAMB,RIB,LN & FAT,1/8" FAT,CHOIC,CKD,BRLD',17240,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, rib, separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','LAMB,RIB,LN & FAT,1/8" FAT,CHOIC,CKD,RSTD',17241,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, whole (arm and blade), separable lean and fat, trimmed to 1/8" fat, choice, raw','LAMB,SHLDR,WHL (ARM&BLD),LN & FAT,1/8" FAT,CHOIC,RAW',17242,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, whole (arm and blade), separable lean and fat, trimmed to 1/8" fat, choice, cooked, braised','LAMB,SHLDR,WHL (ARM&BLD),LN & FAT,1/8" FAT,CHOIC,CKD,BRSD',17243,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, whole (arm and blade), separable lean and fat, trimmed to 1/8" fat, choice, cooked, broiled','LAMB,SHLDR,WHL (ARM&BLD),LN & FAT,1/8" FAT,CHOIC,CKD,BRLD',17244,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, whole (arm and blade), separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','LAMB,SHLDR,WHL (ARM&BLD),LN & FAT,1/8" FAT,CHOIC,CKD,RSTD',17245,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, arm, separable lean and fat, trimmed to 1/8" fat, choice, raw','LAMB,SHLDR,ARM,LN & FAT,1/8" FAT,CHOIC,RAW',17246,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, arm, separable lean and fat, trimmed to 1/8" fat, choice, cooked, braised','LAMB,SHLDR,ARM,LN & FAT,1/8" FAT,CHOIC,CKD,BRSD',17247,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, arm, separable lean and fat, trimmed to 1/8" fat, cooked, broiled','LAMB,SHLDR,ARM,LN & FAT,1/8" FAT,CKD,BRLD',17248,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, arm, separable lean and fat, trimmed to 1/8" fat, choice, roasted','LAMB,SHLDR,ARM,LN & FAT,1/8" FAT,CHOIC,RSTD',17249,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, blade, separable lean and fat, trimmed to 1/8" fat, choice, raw','LAMB,SHLDR,BLADE,LN & FAT,1/8" FAT,CHOIC,RAW',17250,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, blade, separable lean and fat, trimmed to 1/8" fat, choice, cooked, braised','LAMB,SHLDR,BLADE,LN & FAT,1/8" FAT,CHOIC,CKD,BRSD',17251,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, blade, separable lean and fat, trimmed to 1/8" fat, choice, cooked, broiled','LAMB,SHLDR,BLADE,LN & FAT,1/8" FAT,CHOIC,CKD,BRLD',17252,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, shoulder, blade, separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','LAMB,SHLDR,BLADE,LN & FAT,1/8" FAT,CHOIC,CKD,RSTD',17253,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, composite of trimmed retail cuts, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,NZ,IMP,FRZ,COMP OF RTL CUTS,LN & FAT,1/8" FAT,RAW',17254,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, composite of trimmed retail cuts, separable lean and fat, trimmed to 1/8" fat, cooked','LAMB,NZ,IMP,FRZ,COMP OF RTL CUTS,LN & FAT,1/8" FAT,CKD',17255,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, foreshank, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,NZ,IMP,FRZ,FORESHANK,LN & FAT,1/8" FAT,RAW',17256,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, foreshank, separable lean and fat, trimmed to 1/8" fat, cooked, braised','LAMB,NZ,IMP,FRZ,FORESHANK,LN & FAT,1/8" FAT,CKD,BRSD',17257,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, leg, whole (shank and sirloin), separable lean and fat, trimmed to 1/8" fat, raw','LAMB,NZ,IMP,FRZ,LEG,WHL (SHK&SIRL),LN & FAT,1/8" FAT,RAW',17258,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, leg, whole (shank and sirloin), separable lean and fat, trimmed to 1/8" fat, cooked, roasted','LAMB,NZ,IMP,FRZ,LEG,WHL (SHK&SIRL),LN & FAT,1/8",CKD,RSTD',17259,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, loin, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,NZ,IMP,FRZ,LOIN,LN & FAT,1/8" FAT,RAW',17260,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, loin, separable lean and fat, trimmed to 1/8" fat, cooked, broiled','LAMB,NZ,IMP,FRZ,LOIN,LN & FAT,1/8" FAT,CKD,BRLD',17261,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, new zealand, imported, frozen, rib, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,NZ,IMP,FRZ,RIB,LN&FAT,1/8"FAT,RAW',17262,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, rib, separable lean and fat, trimmed to 1/8" fat, cooked, roasted','LAMB,NZ,IMP,FRZ,RIB,LN & FAT,1/8" FAT,CKD,RSTD',17263,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, shoulder, whole (arm and blade), separable lean and fat, trimmed to 1/8" fat, raw','LAMB,NZ,IMP,FRZ,SHLDR,WHL (ARM&BLD),LN & FAT,1/8",RAW',17264,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, frozen, shoulder, whole (arm and blade), separable lean and fat, trimmed to 1/8" fat, cooked, braised','LAMB,NZ,IMP,FRZ,SHDR,WHL (ARM&BLD),LN & FAT,1/8",CKD,BRSD',17265,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, bison, top sirloin, separable lean only, trimmed to 0" fat, raw','GAME MEAT,BISON,TOP SIRLOIN,LN,0"FAT,RAW',17267,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, bison, ribeye, separable lean only, trimmed to 0" fat, raw','GAME MEAT,BISON,RIBEYE,LN,0"FAT,RAW',17268,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, bison, shoulder clod, separable lean only, trimmed to 0" fat, raw','GAME MEAT,BISON,SHLDR CLOD,LN,0"FAT,RAW',17269,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, breast, separable fat, cooked','VEAL,BREAST,FAT,CKD',17270,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, breast, whole, boneless, separable lean and fat, raw','VEAL,BREAST,WHL,BNLESS,LN&FAT,RAW',17271,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, breast, whole, boneless, separable lean and fat, cooked, braised','VEAL,BREAST,WHL,BNLESS,LN&FAT,CKD,BRSD',17272,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, breast, plate half, boneless, separable lean and fat, cooked, braised','VEAL,BREAST,PLATE HALF,BNLESS,LN&FAT,CKD,BRSD',17273,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, breast, point half, boneless, separable lean and fat, cooked, braised','VEAL,BREAST,POINT HALF,BNLESS,LN&FAT,CKD,BRSD',17274,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, breast, whole, boneless, separable lean only, cooked, braised','VEAL,BREAST,WHL,BNLESS,LN,CKD,BRSD',17275,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shank (fore and hind), separable lean and fat, raw','VEAL,SHANK (FORE&HIND),LN&FAT,RAW',17276,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shank (fore and hind), separable lean and fat, cooked, braised','VEAL,SHANK (FORE&HIND),LN&FAT,CKD,BRSD',17277,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shank (fore and hind), separable lean only, raw','VEAL,SHANK (FORE&HIND),LN,RAW',17278,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shank (fore and hind), separable lean only, cooked, braised','VEAL,SHANK (FORE&HIND),LN,CKD,BRSD',17279,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, composite of trimmed retail cuts, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,COMP OF RTL CUTS,LN&FAT,1/8"FAT,RAW',17280,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, composite of trimmed retail cuts, separable lean and fat, trimmed to 1/8" fat, cooked','LAMB,AUS,IMP,FRSH,COMP OF RTL CUTS,LN&FAT,1/8"FAT,CKD',17281,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, composite of trimmed retail cuts, separable lean only, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,COMP OF RTL CUTS,LN,1/8"FAT,RAW',17282,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, composite of trimmed retail cuts, separable lean only, trimmed to 1/8" fat, cooked','LAMB,AUS,IMP,FRSH,COMP OF RTL CUTS,LN,1/8"FAT,CKD',17283,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, separable fat, raw','LAMB,AUS,IMP,FRSH,FAT,RAW',17284,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, separable fat, cooked','LAMB,AUS,IMP,FRSH,FAT,CKD',17285,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, foreshank, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,FORESHANK,LN&FAT,1/8"FAT,RAW',17286,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, foreshank, separable lean and fat, trimmed to 1/8" fat, cooked, braised','LAMB,AUS,IMP,FRSH,FORESHANK,LN&FAT,1/8"FAT,CKD,BRSD',17287,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, foreshank, separable lean only, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,FORESHANK,LN,1/8"FAT,RAW',17288,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, foreshank, separable lean only, trimmed to 1/8" fat, cooked, braised','LAMB,AUS,IMP,FRSH,FORESHANK,LN,1/8"FAT,CKD,BRSD',17289,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, whole (shank and sirloin), separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,LEG,WHL (SHK&SIRL),LN&FAT,1/8"FAT,RAW',17290,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, whole (shank and sirloin), separable lean and fat, trimmed to 1/8" fat, cooked, roasted','LAMB,AUS,IMP,FRSH,LEG,WHL (SHK&SIRL),LN&FAT,1/8"FAT,CKD,RSTD',17291,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, whole (shank and sirloin), separable lean only, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,LEG,WHL (SHK&SIRL),LN,1/8"FAT,RAW',17292,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, whole (shank and sirloin), separable lean only, trimmed to 1/8" fat, cooked, roasted','LAMB,AUS,IMP,FRSH,LEG,WHL (SHK&SIRL),LN,1/8"FAT,CKD,RSTD',17293,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, shank half, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,LEG,SHANK HALF,LN&FAT,1/8"FAT,RAW',17294,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, shank half, separable lean and fat, trimmed to 1/8" fat, cooked, roasted','LAMB,AUS,IMP,FRSH,LEG,SHANK HALF,LN&FAT,1/8"FAT,CKD,RSTD',17295,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, shank half, separable lean only, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,LEG,SHANK HALF,LN,1/8"FAT,RAW',17296,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, shank half, separable lean only, trimmed to 1/8" fat, cooked, roasted','LAMB,AUS,IMP,FRSH,LEG,SHANK HALF,LN,1/8"FAT,CKD,RSTD',17297,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, sirloin half, boneless, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,LEG,SIRLOIN HALF,BNLESS,LN&FAT,1/8"FAT,RAW',17298,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, sirloin half, boneless, separable lean and fat, trimmed to 1/8" fat, cooked, roasted','LAMB,AUS,IMP,FRSH,LEG,SIRL HLF,BNLESS,LN&FT,1/8"FAT,CKD,RSTD',17299,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, sirloin half, boneless, separable lean only, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,LEG,SIRLOIN HALF,BNLESS,LN,1/8"FAT,RAW',17300,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, sirloin half, boneless, separable lean only, trimmed to 1/8" fat, cooked, roasted','LAMB,AUS,IMP,FRSH,LEG,SIRL HALF,BNLESS,LN,1/8"FAT,CKD,RSTD',17301,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, sirloin chops, boneless, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,LEG,SIRL CHOPS,BNLESS,LN&FAT,1/8"FAT,RAW',17302,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, sirloin chops, boneless, separable lean and fat, trimmed to 1/8" fat, cooked, broiled','LAMB,AUS,IMP,FRSH,LEG,SIRL CHPS,BNLESS,LN&FT,1/8"FT,CKD,BRLD',17303,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, sirloin chops, boneless, separable lean only, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,LEG,SIRLOIN CHOPS,BNLESS,LN,1/8"FAT,RAW',17304,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, sirloin chops, boneless, separable lean only, trimmed to 1/8" fat, cooked, broiled','LAMB,AUS,IMP,FRSH,LEG,SIRL CHOPS,BNLESS,LN,1/8"FAT,CKD,BRLD',17305,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, center slice, bone-in, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,LEG,CNTR SLICE,BONE-IN,LN&FAT,1/8"FAT,RAW',17306,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, center slice, bone-in, separable lean and fat, trimmed to 1/8" fat, cooked, broiled','LAMB,AUS,IMP,FRSH,LEG,CNTR SLCE,BNE-IN,LN&FT,1/8"FT,CKD,BRLD',17307,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, center slice, bone-in, separable lean only, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,LEG,CNTR SLICE,BONE-IN,LN,1/8"FAT,RAW',17308,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, center slice, bone-in, separable lean only, trimmed to 1/8" fat, cooked, broiled','LAMB,AUS,IMP,FRSH,LEG,CNTR SLICE,BONE-IN,LN,1/8"FAT,CKD,BRLD',17309,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, loin, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,LOIN,LN&FAT,1/8"FAT,RAW',17310,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, loin, separable lean and fat, trimmed to 1/8" fat, cooked, broiled','LAMB,AUS,IMP,FRSH,LOIN,LN&FAT,1/8"FAT,CKD,BRLD',17311,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, loin, separable lean only, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,LOIN,LN,1/8"FAT,RAW',17312,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, loin, separable lean only, trimmed to 1/8" fat, cooked, broiled','LAMB,AUS,IMP,FRSH,LOIN,LN,1/8"FAT,CKD,BRLD',17313,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, rib chop/rack roast, frenched, bone-in, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,RIB CHOP/RACK RST,FRENCHED,BONE-IN,LN & FT,1/8",RAW',17314,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, rib chop, frenched, bone-in, separable lean and fat, trimmed to 1/8" fat, cooked, grilled','LAMB,AUS,FRSH,RIB CHOP,FRENCHED,BNE-IN,LN & FAT,1/8",GRILLED',17315,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, rib chop/rack roast, frenched, bone-in, separable lean only, trimmed to 1/8" fat, raw','LAMB,AUS,FRSH,RIB CHOP/RACK RST,FRENCHED,BONE-IN,LN,1/8",RAW',17316,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, rib chop, frenched, bone-in, separable lean only, trimmed to 1/8" fat, cooked, grilled','LAMB,AUS,FRSH,RIB CHOP,FRNCHED,BONE-IN,LN,1/8",CKD,GRILLED',17317,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, shoulder, whole (arm and blade), separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,SHLDR,WHL (ARM&BLD),LN&FAT,1/8"FAT,RAW',17318,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, shoulder, whole (arm and blade), separable lean and fat, trimmed to 1/8" fat, cooked','LAMB,AUS,IMP,FRSH,SHLDR,WHL (ARM&BLD),LN&FAT,1/8"FAT,CKD',17319,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, shoulder, whole (arm and blade), separable lean only,   trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,SHLDR,WHL (ARM&BLD),LN,1/8"FAT,RAW',17320,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, shoulder, whole (arm and blade), separable lean only, trimmed to 1/8" fat, cooked','LAMB,AUS,IMP,FRSH,SHLDR,WHL (ARM&BLD),LN,1/8"FAT,CKD',17321,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, shoulder, arm, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,SHLDR,ARM,LN&FAT,1/8"FAT,RAW',17322,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, shoulder, arm, separable lean and fat, trimmed to 1/8" fat, cooked, braised','LAMB,AUS,IMP,FRSH,SHLDR,ARM,LN&FAT,1/8"FAT,CKD,BRSD',17323,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, shoulder, arm, separable lean only, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,SHLDR,ARM,LN,1/8"FAT,RAW',17324,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, shoulder, arm, separable lean only,   trimmed to 1/8" fat, cooked, braised','LAMB,AUS,IMP,FRSH,SHLDR,ARM,LN,1/8"FAT,CKD,BRSD',17325,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, shoulder, blade, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,SHLDR,BLADE,LN&FAT,1/8"FAT,RAW',17326,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, shoulder, blade, separable lean and fat, trimmed to 1/8" fat, cooked, broiled','LAMB,AUS,IMP,FRSH,SHLDR,BLADE,LN&FAT,1/8"FAT,CKD,BRLD',17327,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, shoulder, blade, separable lean only, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,SHLDR,BLADE,LN,1/8"FAT,RAW',17328,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, shoulder ,blade, separable lean only, trimmed to 1/8" fat, cooked, broiled','LAMB,AUS,IMP,FRSH,SHLDR,BLADE,LN,1/8"FAT,CKD,BRLD',17329,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat , bison, ground, raw','GAME MEAT BISON,GROUND,RAW',17330,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, bison, ground, cooked, pan-broiled','GAME MEAT,BISON,GROUND,CKD,PAN-BROILED',17331,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat , bison, top sirloin, separable lean only, 1" steak, cooked, broiled','GAME MEAT BISON,TOP SIRLOIN,LN,1" STEAK,CKD,BRLD',17332,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, bison, chuck, shoulder clod, separable lean only, cooked, braised','GAME MEAT,BISON,CHUCK,SHLDR CLOD,LN,CKD,BRSD',17333,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, bison, chuck, shoulder clod, separable lean only, raw','GAME MEAT,BISON,CHUCK,SHLDR CLOD,LN,RAW',17334,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, bison, ribeye, separable lean only, 1" steak, cooked, broiled','GAME MEAT,BISON,RIBEYE,LN,1" STEAK,CKD,BRLD',17335,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, bison, top round, separable lean only, 1" steak, cooked, broiled','GAME MEAT,BISON,TOP RND,LN,1" STEAK,CKD,BRLD',17336,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, bison, top round, separable lean only, 1" steak, raw','GAME MEAT,BISON,TOP RND,LN,1" STEAK,RAW',17337,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, elk, ground, raw','GAME MEAT,ELK,GROUND,RAW',17338,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, elk, ground, cooked, pan-broiled','GAME MEAT,ELK,GROUND,CKD,PAN-BROILED',17339,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, elk, loin, separable lean only, cooked, broiled','GAME MEAT,ELK,LOIN,LN,CKD,BRLD',17340,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, elk, round, separable lean only, cooked, broiled','GAME MEAT,ELK,RND,LN,CKD,BRLD',17341,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, elk, tenderloin, separable lean only, cooked, broiled','GAME MEAT,ELK,TENDERLOIN,LN,CKD,BRLD',17342,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, deer, ground, raw','GAME MEAT,DEER,GROUND,RAW',17343,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, deer, ground, cooked, pan-broiled','GAME MEAT,DEER,GROUND,CKD,PAN-BROILED',17344,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, deer, loin, separable lean only, 1" steak, cooked, broiled','GAME MEAT,DEER,LOIN,LN,1" STEAK,CKD,BRLD',17345,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, deer, shoulder clod, separable lean only, cooked, braised','GAME MEAT,DEER,SHLDR CLOD,LN,CKD,BRSD',17346,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, deer, tenderloin, separable lean only, cooked, broiled','GAME MEAT,DEER,TENDERLOIN,LN,CKD,BRLD',17347,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Game meat, deer, top round, separable lean only, 1" steak, cooked, broiled','GAME MEAT,DEER,TOP RND,LN,1" STEAK,CKD,BRLD',17348,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, Australian, shank, fore, bone-in, separable lean only, raw','VEAL,AUSTRALIAN,SHANK,FORE,BONE-IN,LN,RAW',17349,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, Australian, shank, fore, bone-in, separable lean and fat, raw','VEAL,AUSTRALIAN,SHANK,FORE,BONE-IN,LN & FAT,RAW',17350,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, Australian, shank, hind, bone-in, separable lean only, raw','VEAL,AUSTRALIAN,SHANK,HIND,BONE-IN,LN,RAW',17351,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, Australian, shank, hind, bone-in, separable lean and fat, raw','VEAL,AUSTRALIAN,SHANK,HIND,BONE-IN,LN & FAT,RAW',17352,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, ground,  85% lean / 15% fat, raw','LAMB,AUSTRALIAN,GROUND,85% LN / 15% FAT,RAW',17353,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, Intermuscular fat, cooked','LAMB,NZ,IMP,INTERMUSCULAR FAT,CKD',17354,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, Intermuscular fat, raw','LAMB,NZ,IMP,INTERMUSCULAR FAT,RAW',17355,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, subcutaneous fat, raw','LAMB,NZ,IMP,SUBCUTANEOUS FAT,RAW',17356,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, brains, cooked, soaked and fried','LAMB,NZ,IMP,BRAINS,CKD,SOAKED & FRIED',17357,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, brains, raw','LAMB,NZ,IMP,BRAINS,RAW',17358,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, breast, separable lean only, cooked, braised','LAMB,NZ,IMP,BREAST,LN,CKD,BRSD',17359,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, breast, separable lean only, raw','LAMB,NZ,IMP,BREAST,LN,RAW',17360,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, chump, boneless, separable lean only, cooked, fast roasted','LAMB,NZ,IMP,CHUMP,BNLESS,LN,CKD,FAST RSTD',17361,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, subcutaneous fat, cooked','LAMB,NZ,IMP,SUBCUTANEOUS FAT,CKD',17362,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, chump, boneless, separable lean only, raw','LAMB,NZ,IMP,CHUMP,BNLESS,LN,RAW',17363,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, kidney, cooked, soaked and fried','LAMB,NZ,IMP,KIDNEY,CKD,SOAKED & FRIED',17364,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, flap, boneless, separable lean only, cooked, braised','LAMB,NZ,IMP,FLAP,BNLESS,LN,CKD,BRSD',17365,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, flap, boneless, separable lean only, raw','LAMB,NZ,IMP,FLAP,BNLESS,LN,RAW',17366,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, kidney, raw','LAMB,NZ,IMP,KIDNEY,RAW',17367,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, liver, cooked, soaked and fried','LAMB,NZ,IMP,LIVER,CKD,SOAKED & FRIED',17368,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, liver, raw','LAMB,NZ,IMP,LIVER,RAW',17369,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, ground lamb, cooked, braised','LAMB,NZ,IMP,GROUND LAMB,CKD,BRSD',17370,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, ground lamb, raw','LAMB,NZ,IMP,GROUND LAMB,RAW',17371,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, heart, cooked, soaked and simmered','LAMB,NZ,IMP,HEART,CKD,SOAKED & SIMMRD',17372,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, heart, raw','LAMB,NZ,IMP,HEART,RAW',17373,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, sweetbread, cooked, soaked and simmered','LAMB,NZ,IMP,SWEETBREAD,CKD,SOAKED & SIMMRD',17374,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, sweetbread, raw','LAMB,NZ,IMP,SWEETBREAD,RAW',17375,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, testes, cooked, soaked and fried','LAMB,NZ,IMP,TESTES,CKD,SOAKED & FRIED',17376,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, testes, raw','LAMB,NZ,IMP,TESTES,RAW',17377,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, tongue - swiss cut, cooked, soaked and simmered','LAMB,NZ,IMP,TONGUE - SWISS CUT,CKD,SOAKED & SIMMRD',17378,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, tongue - swiss cut, raw','LAMB,NZ,IMP,TONGUE - SWISS CUT,RAW',17379,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, tunnel-boned leg, chump off, shank off, separable lean only, cooked, slow roasted','LAMB,NZ,IMP,TUNNEL-BNED LG,CHMP OFF,SHNK OFF,LN,CKD,SLW RSTD',17380,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, tunnel-boned leg, chump off, shank off, separable lean only, raw','LAMB,NZ,IMP,TUNNEL-BONED LEG,CHUMP OFF,SHANK OFF,LN,RAW',17381,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, square-cut shoulder chops, separable lean only, cooked, braised','LAMB,NZ,IMP,SQUARE-CUT SHLDR CHOPS,LN,CKD,BRSD',17382,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, square-cut shoulder chops, separable lean only, raw','LAMB,NZ,IMP,SQUARE-CUT SHLDR CHOPS,LN,RAW',17383,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, tenderloin, separable lean only, cooked, fast fried','LAMB,NZ,IMP,TENDERLOIN,LN,CKD,FAST FRIED',17384,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, tenderloin, separable lean only, raw','LAMB,NZ,IMP,TENDERLOIN,LN,RAW',17385,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, loin saddle, separable lean only, cooked, fast roasted','LAMB,NZ,IMP,LOIN SADDLE,LN,CKD,FAST RSTD',17386,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, loin saddle, separable lean only, raw','LAMB,NZ,IMP,LOIN SADDLE,LN,RAW',17387,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, loin, boneless, separable lean only, cooked, fast roasted','LAMB,NZ,IMP,LOIN,BNLESS,LN,CKD,FAST RSTD',17388,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, loin, boneless, separable lean only, raw','LAMB,NZ,IMP,LOIN,BNLESS,LN,RAW',17389,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, hind-shank, separable lean only, cooked, braised','LAMB,NZ,IMP,HIND-SHANK,LN,CKD,BRSD',17390,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, hind-shank, separable lean only, raw','LAMB,NZ,IMP,HIND-SHANK,LN,RAW',17391,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, neck chops, separable lean only, raw','LAMB,NZ,IMP,NECK CHOPS,LN,RAW',17392,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, neck chops, separable lean only, cooked, braised','LAMB,NZ,IMP,NECK CHOPS,LN,CKD,BRSD',17393,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, netted shoulder, rolled, boneless, separable lean only, cooked, slow roasted','LAMB,NZ,IMP,NETTED SHLDR,ROLLED,BNLESS,LN,CKD,SLOW RSTD',17394,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, netted shoulder, rolled, boneless, separable lean only, raw','LAMB,NZ,IMP,NETTED SHLDR,ROLLED,BNLESS,LN,RAW',17395,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, rack - fully frenched, separable lean only, cooked, fast roasted','LAMB,NZ,IMP,RACK - FULLY FRENCHED,LN,CKD,FAST RSTD',17396,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, rack - fully frenched, separable lean only, raw','LAMB,NZ,IMP,RACK - FULLY FRENCHED,LN,RAW',17397,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, loin chop, separable lean only, cooked, fast fried','LAMB,NZ,IMP,LOIN CHOP,LN,CKD,FAST FRIED',17398,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, square-cut shoulder, separable lean only, cooked, slow roasted','LAMB,NZ,IMP,SQUARE-CUT SHLDR,LN,CKD,SLOW RSTD',17399,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, leg chop/steak, bone-in, separable lean only, cooked, fast fried','LAMB,NZ,IMP,LEG CHOP/STEAK,BONE-IN,LN,CKD,FAST FRIED',17400,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, flap, boneless, separable lean and fat, cooked, braised','LAMB,NZ,IMP,FLAP,BNLESS,LN & FAT,CKD,BRSD',17401,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, flap, boneless, separable lean and fat, raw','LAMB,NZ,IMP,FLAP,BNLESS,LN & FAT,RAW',17402,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, hind-shank, separable lean and fat, cooked, braised','LAMB,NZ,IMP,HIND-SHANK,LN & FAT,CKD,BRSD',17403,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, hind-shank, separable lean and fat, raw','LAMB,NZ,IMP,HIND-SHANK,LN & FAT,RAW',17404,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, leg chop/steak, bone-in, separable lean and fat, cooked, fast fried','LAMB,NZ,IMP,LEG CHOP/STEAK,BONE-IN,LN & FAT,CKD,FAST FRIED',17405,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, loin chop, separable lean and fat, cooked, fast fried','LAMB,NZ,IMP,LOIN CHOP,LN & FAT,CKD,FAST FRIED',17406,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, loin saddle, separable lean and fat, cooked, fast roasted','LAMB,NZ,IMP,LOIN SADDLE,LN & FAT,CKD,FAST RSTD',17407,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, loin saddle, separable lean and fat, raw','LAMB,NZ,IMP,LOIN SADDLE,LN & FAT,RAW',17408,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, loin, boneless, separable lean and fat, cooked, fast roasted','LAMB,NZ,IMP,LOIN,BNLESS,LN & FAT,CKD,FAST RSTD',17409,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, loin, boneless, separable lean and fat, raw','LAMB,NZ,IMP,LOIN,BNLESS,LN & FAT,RAW',17410,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, neck chops, separable lean and fat, cooked, braised','LAMB,NZ,IMP,NECK CHOPS,LN & FAT,CKD,BRSD',17411,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, neck chops, separable lean and fat, raw','LAMB,NZ,IMP,NECK CHOPS,LN & FAT,RAW',17412,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, netted shoulder, rolled, boneless, separable lean and fat, cooked, slow roasted','LAMB,NZ,IMP,NETTED SHLDR,ROLLED,BNLESS,L & F,CKD,SLOW RSTD',17413,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, netted shoulder, rolled, boneless, separable lean and fat, raw','LAMB,NZ,IMP,NETTED SHLDR,ROLLED,BNLESS,LN & FAT,RAW',17414,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, square-cut shoulder chops, separable lean and fat, cooked, braised','LAMB,NZ,IMP,SQUARE-CUT SHLDR CHOPS,LN & FAT,CKD,BRSD',17415,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, square-cut shoulder chops, separable lean and fat, raw','LAMB,NZ,IMP,SQUARE-CUT SHLDR CHOPS,LN & FAT,RAW',17416,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, square-cut shoulder, separable lean and fat, cooked, slow roasted','LAMB,NZ,IMP,SQUARE-CUT SHLDR,LN & FAT,CKD,SLOW RSTD',17417,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, tenderloin, separable lean and fat, cooked, fast fried','LAMB,NZ,IMP,TENDERLOIN,LN & FAT,CKD,FAST FRIED',17418,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, rack - fully frenched, separable lean and fat, cooked, fast roasted','LAMB,NZ,IMP,RACK - FULLY FRENCHED,LN & FAT,CKD,FAST RSTD',17419,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, rack - fully frenched, separable lean and fat, raw','LAMB,NZ,IMP,RACK - FULLY FRENCHED,LN & FAT,RAW',17420,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, tunnel-boned leg, chump off, shank off, separable lean and fat, cooked, slow roasted','LAMB,NZ,IMP,TUN-BND LG,CHMP OFF,SHNK OFF,L & F,CKD,SL RSTD',17421,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, tunnel-boned leg, chump off, shank off, separable lean and fat, raw','LAMB,NZ,IMP,TUNNEL-BONED LG,CHUMP OFF,SHANK OFF,LN & FAT,RAW',17422,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, New Zealand, imported, tenderloin, separable lean and fat, raw','LAMB,NZ,IMP,TENDERLOIN,LN & FAT,RAW',17423,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, ground, cooked, pan-fried','VEAL,GROUND,CKD,PAN-FRIED',17424,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, leg, top round, cap off, cutlet, boneless, cooked, grilled','VEAL,LEG,TOP RND,CAP OFF,CUTLET,BNLESS,CKD,GRILLED',17425,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, leg, top round, cap off, cutlet, boneless, raw','VEAL,LEG,TOP RND,CAP OFF,CUTLET,BNLESS,RAW',17426,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, loin, chop, separable lean only, cooked, grilled','VEAL,LOIN,CHOP,LN,CKD,GRILLED',17427,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shank, separable lean only, raw','VEAL,SHANK,LN,RAW',17428,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, foreshank, osso buco, separable lean only, cooked, braised','VEAL,FORESHANK,OSSO BUCO,LN,CKD,BRSD',17429,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, blade chop, separable lean only, cooked, grilled','VEAL,SHLDR,BLADE CHOP,LN,CKD,GRILLED',17430,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, external fat only, raw','VEAL,EXTERNAL FAT ONLY,RAW',17431,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, external fat only, cooked','VEAL,EXTERNAL FAT ONLY,CKD',17432,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, seam fat only, raw','VEAL,SEAM FAT ONLY,RAW',17433,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, seam fat only, cooked','VEAL,SEAM FAT ONLY,CKD',17434,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shank, separable lean and fat, raw','VEAL,SHANK,LN & FAT,RAW',17435,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, foreshank, osso buco, separable lean and fat, cooked, braised','VEAL,FORESHANK,OSSO BUCO,LN & FAT,CKD,BRSD',17436,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, loin, chop, separable lean and fat, cooked, grilled','VEAL,LOIN,CHOP,LN & FAT,CKD,GRILLED',17437,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Veal, shoulder, blade chop, separable lean and fat, cooked, grilled','VEAL,SHLDR,BLADE CHOP,LN & FAT,CKD,GRILLED',17438,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, bottom, boneless, separable lean only, trimmed to 1/8" fat, cooked, roasted','LAMB,AUS,IMP,FRSH,LEG,BTTM,BNLESS,LN,1/8" FAT,CKD,RSTD',17439,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, hindshank, heel on, bone-in, separable lean only, trimmed to 1/8" fat, cooked, braised','LAMB,AUS,FRSH,LEG,HINDSHANK,HEEL ON,BONE-IN,LN,1/8",BRSD',17440,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, hindshank, heel on, bone-in, separable lean only, trimmed to 1/8" fat, raw','LAMB,AUS,FRSH,LEG,HINDSHANK,HEEL ON,BONE-IN,LN,1/8" FAT,RAW',17441,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, tenderloin, boneless, separable lean only, trimmed to 1/8" fat, cooked, roasted','LAMB,AUS,IMP,FRSH,TENDERLOIN,BNLESS,LN,1/8" FAT,CKD,RSTD',17442,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, tenderloin, boneless, separable lean only, trimmed to 1/8" fat, raw','LAMB,AUSTRALIAN,IMP,FRSH,TENDERLOIN,BNLESS,LN,1/8" FAT,RAW',17443,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, bottom, boneless, separable lean only, trimmed to 1/8" fat, raw','LAMB,AUSTRALIAN,IMP,FRSH,LEG,BTTM,BNLESS,LN,1/8" FAT,RAW',17444,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, trotter off, bone-in, separable lean only, trimmed to 1/8" fat, cooked, roasted','LAMB,AUS,FRSH,LEG,TROTTER OFF,BONE-IN,LN,1/8" FAT,CKD,RSTD',17445,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, trotter off, bone-in, separable lean only, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,LEG,TROTTER OFF,BONE-IN,LN,1/8" FAT,RAW',17446,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, rack, roast, frenched, denuded, bone-in, separable lean only, trimmed to 0" fat, cooked, roasted','LAMB,AUS,FRSH,RACK,RST,FRNCHED,DNUDED,BONE-IN,LN,0",CKD,RSTD',17447,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, rack, roast, frenched, bone-in, separable lean only, trimmed to 1/8" fat, cooked, roasted','LAMB,AUS,FRSH,RACK,RST,FRENCHED,BONE-IN,LN,1/8" FAT,CKD,RSTD',17448,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, external fat, cooked','LAMB,AUSTRALIAN,IMP,FRSH,EXTERNAL FAT,CKD',17449,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, external fat, raw','LAMB,AUSTRALIAN,IMP,FRSH,EXTERNAL FAT,RAW',17450,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, seam fat, cooked','LAMB,AUSTRALIAN,IMP,FRSH,SEAM FAT,CKD',17451,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, seam fat, raw','LAMB,AUSTRALIAN,IMP,FRSH,SEAM FAT,RAW',17452,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, bottom, boneless, separable lean and fat, trimmed to 1/8" fat, cooked, roasted','LAMB,AUS,IMP,FRSH,LEG,BTTM,BNLESS,LN & FAT,1/8" FAT,CKD,RSTD',17453,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, bottom, boneless, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,LEG,BTTM,BNLESS,LN & FAT,1/8" FAT,RAW',17454,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, hindshank, heel on, bone-in, separable lean and fat, trimmed to 1/8" fat, cooked, braised','LAMB,AUS,FRSH,LEG,HINDSHANK,HEEL ON,BNE-IN,LN & FT,1/8",BRSD',17455,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, hindshank, heel on, bone-in, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,FRSH,LEG,HINDSHANK,HEEL ON,BNE-IN,LN & FAT,1/8",RAW',17456,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, trotter off, bone-in, separable lean and fat, trimmed to 1/8" fat, cooked, roasted','LAMB,AUS,FRSH,LEG,TROTTER OFF,BONE-IN,LN & FAT,1/8" FAT,RSTD',17457,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, leg, trotter off, bone-in, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,FRSH,LEG,TROTTER OFF,BONE-IN,LN & FAT,1/8" FAT,RAW',17458,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, tenderloin, boneless, separable lean and fat, trimmed to 1/8" fat, cooked, roasted','LAMB,AUS,IMP,FRSH,TENDERLOIN,BNLESS,LN & FAT,1/8" FAT,RSTD',17459,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, tenderloin, boneless, separable lean and fat, trimmed to 1/8" fat, raw','LAMB,AUS,IMP,FRSH,TENDERLOIN,BNLESS,LN & FAT,1/8" FAT,RAW',17460,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, rib chop, frenched, denuded, bone-in, separable lean only, trimmed to 0" fat, cooked, grilled','LAMB,AUS,FRSH,RIB CHOP,FRNCHED,DNUDED,BONE-IN,LN,0",GRILLED',17461,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, rack, roast, frenched, denuded, bone-in, separable lean and fat, trimmed to 0" fat, cooked, roasted','LAMB,AUS,FRSH,RACK,RST,FRNCHED,DNUDED,BNE-IN,LN & FT,0",RSTD',17462,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, rack, roast, frenched, bone-in, separable lean and fat, trimmed to 1/8" fat, cooked, roasted','LAMB,AUS,FRSH,RACK,RST,FRENCHED,BNE-IN,LN & FT,1/8",RSTD',17463,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (17,'Lamb, Australian, imported, fresh, rib chop, frenched, denuded, bone-in, separable lean and fat, trimmed to 0" fat, cooked, grilled','LAMB,AUS,IMP,FRSH,RIB CHOP,FRENCHED,DNUDED,BN-IN,L&F,0",GRLD',17464,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bagels, plain, enriched, with calcium propionate (includes onion, poppy, sesame)','BAGEL,PLN,TSTD, ENR W/CA PROP(INCLUDE ONION,POPPY,SESAME)',18001,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bagels, plain, enriched, with calcium propionate (includes onion, poppy, sesame), toasted','BAGELS,PLN,ENR,W/ CA PROP (INCLUDES ONION,POPPY,SESAME),TSTD',18002,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bagels, egg','BAGELS,EGG',18003,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bagels, cinnamon-raisin','BAGELS,CINNAMON-RAISIN',18005,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bagels, cinnamon-raisin, toasted','BAGELS,CINNAMON-RAISIN,TSTD',18006,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bagels, oat bran','BAGELS,OAT BRAN',18007,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Biscuits, plain or buttermilk, frozen, baked','BISCUITS,PLN OR BTTRMLK,FRZ,BKD',18009,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Biscuits, plain or buttermilk, dry mix','BISCUITS,PLN OR BTTRMLK,DRY MIX',18010,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Biscuits, plain or buttermilk, dry mix, prepared','BISCUITS,PLN OR BTTRMLK,DRY MIX,PREP',18011,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Biscuits, plain or buttermilk, refrigerated dough, lower fat','BISCUITS,PLN OR BTTRMLK,REFR DOUGH,LOWER FAT',18012,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Biscuits, plain or buttermilk, refrigerated dough, lower fat, baked','BISCUITS,PLN OR BTTRMLK,REFR DOUGH,LOWER FAT,BKD',18013,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Biscuits, plain or buttermilk, refrigerated dough, higher fat','BISCUIT, PLN OR BUTMLK, REFRI DOUGH, HIGHER FAT',18014,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Biscuits, plain or buttermilk, refrigerated dough, higher fat, baked','BISCUITS,PLN OR BTTRMLK,REFR DOUGH,HIGHER FAT,BKD',18015,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Biscuits, plain or buttermilk, prepared from recipe','BISCUITS,PLN OR BTTRMLK,PREP FROM RECIPE',18016,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Biscuits, mixed grain, refrigerated dough','BISCUITS,MXD GRAIN,REFR DOUGH',18017,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, banana, prepared from recipe, made with margarine','BREAD,BANANA,PREP FROM RECIPE,MADE W/MARGARINE',18019,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, boston brown, canned','BREAD,BOSTON BROWN,CANNED',18021,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, cornbread, dry mix, enriched (includes corn muffin mix)','BREAD,CORNBREAD,DRY MIX,ENR (INCL CORN MUFFIN MIX)',18022,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, cornbread, dry mix, prepared with 2% milk, 80% margarine, and eggs','BREAD,CORNBREAD,DRY MIX,PREP W/ 2% MILK,80% MARGARINE,& EGGS',18023,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, cornbread, prepared from recipe, made with low fat (2%) milk','BREAD,CORNBREAD,PREP FROM RECIPE,MADE W/LOFAT (2%) MILK',18024,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, cracked-wheat','BREAD,CRACKED-WHEAT',18025,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, egg','BREAD,EGG',18027,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, egg, toasted','BREAD,EGG,TOASTED',18028,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, french or vienna (includes sourdough)','Bread, french',18029,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, french or vienna, toasted (includes sourdough)','BREAD, FRENCH OR VIENNA, TSTD (IND SOURDOUGH)',18030,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, irish soda, prepared from recipe','BREAD,IRISH SODA,PREP FROM RECIPE',18032,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, italian','BREAD,ITALIAN',18033,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, Multi-Grain, toasted (includes whole-grain)','BREAD,MULTI-GRAIN,TSTD (INCLUDES WHOLE-GRAIN)',18036,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, oat bran','BREAD,OAT BRAN',18037,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, oat bran, toasted','BREAD,OAT BRAN,TOASTED',18038,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, oatmeal','BREAD,OATMEAL',18039,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, oatmeal, toasted','BREAD,OATMEAL,TOASTED',18040,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, pita, white, enriched','BREAD,PITA,WHITE,ENRICHED',18041,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, pita, whole-wheat','BREAD,PITA,WHOLE-WHEAT',18042,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, protein (includes gluten)','BREAD,PROT (INCL GLUTEN)',18043,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, pumpernickel','BREAD,PUMPERNICKEL',18044,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, raisin, enriched','BREAD,RAISIN,ENRICHED',18047,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, raisin, enriched, toasted','BREAD,RAISIN,ENR,TSTD',18048,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, reduced-calorie, oat bran','BREAD,RED-CAL,OAT BRAN',18049,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, reduced-calorie, oat bran, toasted','BREAD,RED-CAL,OAT BRAN,TSTD',18050,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, reduced-calorie, oatmeal','BREAD,RED-CAL,OATMEAL',18051,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, reduced-calorie, rye','BREAD,REDUCED-CALORIE,RYE',18053,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, reduced-calorie, wheat','BREAD,RED-CAL,WHEAT',18055,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, reduced-calorie, white','BREAD,RED-CAL,WHITE',18057,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, rice bran','BREAD,RICE BRAN',18059,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, rye','BREAD,RYE',18060,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, rye, toasted','BREAD,RYE,TOASTED',18061,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, wheat','BREAD,WHEAT',18064,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, wheat, toasted','BREAD, WHEAT, TSTD',18065,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, white, commercially prepared (includes soft bread crumbs)','BREAD,WHITE,COMMLY PREP (INCL SOFT BREAD CRUMBS)',18069,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, white, commercially prepared, toasted','BREAD,WHITE,COMMLY PREP,TSTD',18070,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, white, prepared from recipe, made with nonfat dry milk','BREAD,WHITE,PREP FROM RECIPE,MADE W/NONFAT DRY MILK',18071,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, white, prepared from recipe, made with low fat (2%) milk','BREAD,WHITE,PREP FROM RECIPE,MADE W/LOFAT (2%) MILK',18073,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, whole-wheat, commercially prepared','BREAD,WHOLE-WHEAT,COMM. PREPARED',18075,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, whole-wheat, commercially prepared, toasted','BREAD, WHOLE-WHEAT, COMMER PREP, TOASTED',18076,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, whole-wheat, prepared from recipe','BREAD,WHOLE-WHEAT,PREP FROM RECIPE',18077,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, whole-wheat, prepared from recipe, toasted','BREAD,WHOLE-WHEAT,PREP FROM RECIPE,TSTD',18078,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, crumbs, dry, grated, plain','BREAD,CRUMBS,DRY,GRATED,PLN',18079,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, sticks, plain','BREAD,STKS,PLN',18080,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, stuffing, dry mix','BREAD,STUFFING,DRY MIX',18081,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, stuffing, dry mix, prepared','BREAD,STUFFING,DRY MIX,PREP',18082,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, stuffing, cornbread, dry mix','BREAD,STUFFING,CORNBREAD,DRY MIX',18084,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, stuffing, cornbread, dry mix, prepared','BREAD,STUFFING,CORNBREAD,DRY MIX,PREP',18085,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, angelfood, commercially prepared','CAKE,ANGELFOOD,COMMLY PREP',18086,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, angelfood, dry mix, prepared','CAKE,ANGELFOOD,DRY MIX,PREP',18088,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, boston cream pie, commercially prepared','CAKE,BOSTON CRM PIE,COMMLY PREP',18090,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, pudding-type, carrot, dry mix','CAKE,PUDDING-TYPE,CARROT,DRY MIX',18092,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, cherry fudge with chocolate frosting','CAKE,CHERRY FUDGE W/CHOC FRSTNG',18095,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, chocolate, commercially prepared with chocolate frosting, in-store bakery','CAKE,CHOC,COMMLY PREP W/ CHOC FRSTNG,IN-STORE BAKERY',18096,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, pudding-type, chocolate, dry mix','CAKE,PUDDING-TYPE,CHOC,DRY MIX',18097,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, chocolate, prepared from recipe without frosting','CAKE,CHOC,PREP FROM RECIPE WO/FRSTNG',18101,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, white, prepared from recipe with coconut frosting','CAKE,WHITE,PREP FROM RECIPE W/COCNT FRSTNG',18102,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, coffeecake, cheese','CAKE,COFFEECAKE,CHS',18103,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, coffeecake, cinnamon with crumb topping, commercially prepared, enriched','CAKE,COFFEECAKE,CINN W/ CRUMB TOPPING,COMMLY PREP,ENR',18104,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, coffeecake, creme-filled with chocolate frosting','CAKE,COFFEECAKE,CREME-FILLED W/ CHOC FRSTNG',18105,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, coffeecake, fruit','CAKE,COFFEECAKE,FRUIT',18106,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, coffeecake, cinnamon with crumb topping, dry mix, prepared','CAKE,COFFEECAKE,CINN W/ CRUMB TOPPING,DRY MIX,PREP',18108,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, fruitcake, commercially prepared','CAKE,FRUITCAKE,COMMLY PREP',18110,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, gingerbread, dry mix','CAKE,GINGERBREAD,DRY MIX',18114,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, gingerbread, prepared from recipe','CAKE,GINGERBREAD,PREP FROM RECIPE',18116,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, pineapple upside-down, prepared from recipe','CAKE,PNAPPL UPSIDE-DOWN,PREP FROM RECIPE',18119,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, pound, commercially prepared, butter (includes fresh and frozen)','CAKE,POUND,COMMLY PREP,BUTTER (INCLUDES FRSH & FROZEN)',18120,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, pound, commercially prepared, other than all butter, enriched','CAKE,POUND,COMMLY PREP,OTHER THAN ALL BUTTER,ENR',18121,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, shortcake, biscuit-type, prepared from recipe','CAKE,SHORTCAKE,BISCUIT-TYPE,PREP FROM RECIPE',18126,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, snack cakes, creme-filled, chocolate with frosting','CAKE,SNACK CAKES,CREME-FILLED,CHOC W/ FRSTNG',18127,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, snack cakes, creme-filled, sponge','CAKE,SNACK CAKES,CREME-FILLED,SPONGE',18128,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, white, dry mix, special dietary (includes lemon-flavored)','CAKE,WHITE,DRY MIX,SPL DIETARY (INCL LEMON-FLAVORED)',18131,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, sponge, commercially prepared','CAKE,SPONGE,COMMLY PREP',18133,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, sponge, prepared from recipe','CAKE,SPONGE,PREP FROM RECIPE',18134,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, pudding-type, white, enriched, dry mix','CAKE,PUDDING-TYPE,WHITE,ENR,DRY MIX',18135,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, white, prepared from recipe without frosting','CAKE,WHITE,PREP FROM RECIPE WO/FRSTNG',18139,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, yellow, commercially prepared, with chocolate frosting, in-store bakery','CAKE,YEL,COMMLY PREP,W/ CHOC FRSTNG,IN-STORE BAKERY',18140,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, yellow, commercially prepared, with vanilla frosting','CAKE,YEL,COMMLY PREP,W/VANILLA FRSTNG',18141,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, pudding-type, yellow, dry mix','CAKE,PUDDING-TYPE,YEL,DRY MIX',18142,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, yellow, enriched, dry mix','CAKE,YEL,ENR,DRY MIX',18144,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, yellow, prepared from recipe without frosting','CAKE,YEL,PREP FROM RECIPE WO/FRSTNG',18146,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, cheesecake, commercially prepared','CAKE,CHEESECAKE,COMMLY PREP',18147,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, cheesecake, prepared from mix, no-bake type','CAKE,CHEESECAKE,PREP FROM MIX,NO-BAKE TYPE',18148,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, brownies, commercially prepared','COOKIES,BROWNIES,COMMLY PREP',18151,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, brownies, dry mix, regular','COOKIES,BROWNIES,DRY MIX,REG',18152,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, brownies, prepared from recipe','COOKIES,BROWNIES,PREP FROM RECIPE',18154,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, butter, commercially prepared, enriched','COOKIES,BUTTER,COMMLY PREP,ENR',18155,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, fudge, cake-type (includes trolley cakes)','COOKIES,FUDGE,CAKE-TYPE (INCL TROLLEY CAKES)',18156,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate wafers','COOKIES,CHOCOLATE WAFERS',18157,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate chip, commercially prepared, regular, lower fat','COOKIES,CHOC CHIP,COMMLY PREP,REG,LOWER FAT',18158,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate chip, commercially prepared, regular, higher fat, enriched','COOKIES,CHOC CHIP,COMMLY PREP,REG,HIGHER FAT,ENR',18159,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate chip, commercially prepared, soft-type','COOKIES,CHOC CHIP,COMMLY PREP,SOFT-TYPE',18160,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate chip, dry mix','COOKIES,CHOC CHIP,DRY MIX',18161,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate chip, refrigerated dough','COOKIES,CHOC CHIP,REFR DOUGH',18163,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate chip, refrigerated dough, baked','COOKIES,CHOC CHIP,REFR DOUGH,BKD',18164,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate chip, prepared from recipe, made with margarine','COOKIES,CHOC CHIP,PREP FROM RECIPE,MADE W/MARGARINE',18165,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate sandwich, with creme filling, regular','COOKIES,CHOC SNDWCH,W/CREME FILLING,REG',18166,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate sandwich, with creme filling, regular, chocolate-coated','COOKIES,CHOC SNDWCH,W/CREME FILLING,REG,CHOCOLATE-COATED',18167,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate sandwich, with extra creme filling','COOKIES,CHOC SNDWCH,W/EX CREME FILLING',18168,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, fig bars','COOKIES,FIG BARS',18170,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, fortune','COOKIES,FORTUNE',18171,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, gingersnaps','COOKIES,GINGERSNAPS',18172,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, graham crackers, plain or honey (includes cinnamon)','COOKIES,GRAHAM CRACKERS,PLN OR HONEY (INCL CINN)',18173,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, graham crackers, chocolate-coated','COOKIES,GRAHAM CRACKERS,CHOCOLATE-COATED',18174,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, ladyfingers, with lemon juice and rind','COOKIES,LADYFINGERS,W/LEMON JUC&RIND',18175,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, marshmallow, chocolate-coated (includes marshmallow pies)','COOKIES,MARSHMLLW,CHOCOLATE-COATED (INCL MARSHMLLW PIES)',18176,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, molasses','COOKIES,MOLASSES',18177,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, oatmeal, commercially prepared, regular','COOKIES,OATMEAL,COMMLY PREP,REG',18178,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, oatmeal, commercially prepared, soft-type','COOKIES,OATMEAL,COMMLY PREP,SOFT-TYPE',18179,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, oatmeal, dry mix','COOKIES,OATMEAL,DRY MIX',18180,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, oatmeal, refrigerated dough','COOKIES,OATMEAL,REFR DOUGH',18182,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, oatmeal, refrigerated dough, baked','COOKIES,OATMEAL,REFR DOUGH,BKD',18183,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, oatmeal, with raisins','COOKIES,OATMEAL,W/ RAISINS',18184,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, peanut butter, commercially prepared, regular','COOKIES,PNUT BUTTER,COMMLY PREP,REG',18185,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, peanut butter, commercially prepared, soft-type','COOKIES,PNUT BUTTER,COMMLY PREP,SOFT-TYPE',18186,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, peanut butter, refrigerated dough','COOKIES,PNUT BUTTER,REFR DOUGH',18187,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, peanut butter, refrigerated dough, baked','COOKIES,PNUT BUTTER,REFR DOUGH,BKD',18188,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, peanut butter, prepared from recipe','COOKIES,PNUT BUTTER,PREP FROM RECIPE',18189,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, peanut butter sandwich, regular','COOKIES,PNUT BUTTER SNDWCH,REG',18190,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, raisin, soft-type','COOKIES,RAISIN,SOFT-TYPE',18191,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, shortbread, commercially prepared, plain','COOKIES,SHORTBREAD,COMMLY PREP,PLN',18192,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, shortbread, commercially prepared, pecan','COOKIES,SHORTBREAD,COMMLY PREP,PECAN',18193,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, brownies, dry mix, sugar free','COOKIES,BROWNIES,DRY MIX,SUGAR FREE',18196,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate chip, commercially prepared, special dietary','COOKIES,CHOC CHIP,COMMLY PREP,SPL DIETARY',18198,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate sandwich, with creme filling, special dietary','COOKIES,CHOC SNDWCH,W/CREME FILLING,SPL DIETARY',18199,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, oatmeal, commercially prepared, special dietary','COOKIES,OATMEAL,COMMLY PREP,SPL DIETARY',18200,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, peanut butter sandwich, special dietary','COOKIES,PNUT BUTTER SNDWCH,SPL DIETARY',18201,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, sugar wafer, with creme filling, sugar free','COOKIES,SUGAR WAFER,W/ CREME FILLING,SUGAR FREE',18202,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, sugar, commercially prepared, regular (includes vanilla)','COOKIES,SUGAR,COMMLY PREP,REG (INCL VANILLA)',18204,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, sugar, refrigerated dough','COOKIES,SUGAR,REFR DOUGH',18205,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, sugar, refrigerated dough, baked','COOKIES,SUGAR,REFR DOUGH,BKD',18206,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, sugar wafers with creme filling, regular','COOKIES,SUGAR WAFERS W/CREME FILLING,REG',18209,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, vanilla sandwich with creme filling','COOKIES,VANILLA SNDWCH W/CREME FILLING',18210,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Puff pastry, frozen, ready-to-bake, baked','PUFF PASTRY,FRZ,RTB,BKD',18211,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, vanilla wafers, lower fat','COOKIES,VANILLA WAFERS,LOWER FAT',18212,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, vanilla wafers, higher fat','COOKIES,VANILLA WAFERS,HIGHER FAT',18213,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, cheese, regular','CRACKERS,CHEESE,REGULAR',18214,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, cheese, sandwich-type with peanut butter filling','CRACKERS,CHS,SANDWICH-TYPE W/PNUT BUTTER FILLING',18215,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, crispbread, rye','CRACKERS,CRISPBREAD,RYE',18216,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, matzo, plain','CRACKERS,MATZO,PLAIN',18217,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, matzo, egg','CRACKERS,MATZO,EGG',18218,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, matzo, whole-wheat','CRACKERS,MATZO,WHOLE-WHEAT',18219,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, melba toast, plain','CRACKERS,MELBA TOAST,PLN',18220,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, melba toast, rye (includes pumpernickel)','CRACKERS,MELBA TOAST,RYE (INCL PUMPERNICKEL)',18221,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, melba toast, wheat','CRACKERS,MELBA TOAST,WHEAT',18222,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, milk','CRACKERS,MILK',18223,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, rusk toast','CRACKERS,RUSK TOAST',18224,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, rye, sandwich-type with cheese filling','CRACKERS,RYE,SANDWICH-TYPE W/CHS FILLING',18225,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, rye, wafers, plain','CRACKERS,RYE,WAFERS,PLAIN',18226,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, rye, wafers, seasoned','CRACKERS,RYE,WAFERS,SEASONED',18227,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, saltines (includes oyster, soda, soup)','CRACKERS,SALTINES (INCL OYSTER,SODA,SOUP)',18228,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, standard snack-type, regular','CRACKERS,STD SNACK-TYPE,REG',18229,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, standard snack-type, sandwich, with cheese filling','CRACKERS,STD SNACK-TYPE,SNDWCH,W/CHS FILLING',18230,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, standard snack-type, sandwich, with peanut butter filling','CRACKERS,STD SNACK-TYPE,SNDWCH,W/PNUT BUTTER FILLING',18231,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, wheat, regular','CRACKERS,WHEAT,REGULAR',18232,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, wheat, sandwich, with cheese filling','CRACKERS,WHEAT,SNDWCH,W/CHS FILLING',18233,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, wheat, sandwich, with peanut butter filling','CRACKERS,WHEAT,SNDWCH,W/PNUT BUTTER FILLING',18234,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, whole-wheat','CRACKERS,WHOLE-WHEAT',18235,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cracker, meal','CRACKER,MEAL',18236,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cream puff shell, prepared from recipe','CREAM PUFF SHELL,PREP FROM RECIPE',18237,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Croissants, butter','CROISSANTS,BUTTER',18239,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Croissants, apple','CROISSANTS,APPLE',18240,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Croissants, cheese','CROISSANTS,CHEESE',18241,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Croutons, plain','CROUTONS,PLAIN',18242,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Croutons, seasoned','CROUTONS,SEASONED',18243,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Danish pastry, cinnamon, enriched','DANISH PASTRY,CINN,ENR',18244,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Danish pastry, cheese','DANISH PASTRY,CHEESE',18245,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Danish pastry, fruit, enriched (includes apple, cinnamon, raisin, lemon, raspberry, strawberry)','DANISH PASTRY,FRUIT,ENR',18246,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Doughnuts, cake-type, plain (includes unsugared, old-fashioned)','DOUGHNUTS,CAKE-TYPE,PLN (INCLUDES UNSUGARED,OLD-FASHIONED)',18248,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Doughnuts, cake-type, plain, chocolate-coated or frosted','DOUGHNUTS,CAKE-TYPE,PLN,CHOCOLATE-COATED OR FRSTD',18249,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Doughnuts, cake-type, plain, sugared or glazed','DOUGHNUTS,CAKE-TYPE,PLN,SUGARED OR GLAZED',18250,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Doughnuts, cake-type, chocolate, sugared or glazed','DOUGHNUTS,CAKE-TYPE,CHOC,SUGARED OR GLAZED',18251,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Doughnuts, french crullers, glazed','DOUGHNUTS,FRENCH CRULLERS,GLAZED',18253,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Doughnuts, yeast-leavened, with creme filling','DOUGHNUTS,YEAST-LEAVENED,W/CREME FILLING',18254,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Doughnuts, yeast-leavened, glazed, enriched (includes honey buns)','DOUGHNUTS, YEAST-LEAVENED, GLAZED, ENRICHED (INC HONEY BUNS)',18255,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Doughnuts, yeast-leavened, with jelly filling','DOUGHNUTS,YEAST-LEAVENED,W/JELLY FILLING',18256,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, English, plain, enriched, with ca prop (includes sourdough)','MUFFINS,ENG,PLN,ENR,W/ CA PROP (INCLUDES SOURDOUGH)',18258,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, English, plain, toasted, enriched, with calcium propionate (includes sourdough)','MUFFINS,ENG,PLN,TSTD,ENR,W/ CA PROP (INCLUDES SOURDOUGH)',18259,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, English, mixed-grain (includes granola)','MUFFINS,ENG,MIXED-GRAIN (INCLUDES GRANOLA)',18260,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, English, raisin-cinnamon (includes apple-cinnamon)','MUFFINS,ENG,RAISIN-CINNAMON (INCLUDES APPLE-CINNAMON)',18262,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, English, raisin-cinnamon, toasted (includes apple-cinnamon)','MUFFINS,ENG,RAISIN-CINNAMON,TSTD (INCLUDES APPLE-CINNAMON)',18263,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, English, wheat','MUFFINS,ENG,WHEAT',18264,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, English, whole-wheat','MUFFINS,ENG,WHOLE-WHEAT',18266,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'French toast, frozen, ready-to-heat','FRENCH TOAST,FRZ,RTH',18268,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'French toast, prepared from recipe, made with low fat (2%) milk','FRENCH TOAST,PREP FROM RECIPE,MADE W/LOFAT (2%) MILK',18269,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Hush puppies, prepared from recipe','HUSH PUPPIES,PREP FROM RECIPE',18270,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Ice cream cones, cake or wafer-type','ICE CRM CONES,CAKE OR WAFER-TYPE',18271,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Ice cream cones, sugar, rolled-type','ICE CRM CONES,SUGAR,ROLLED-TYPE',18272,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, plain, prepared from recipe, made with low fat (2%) milk','MUFFINS,PLN,PREP FROM RECIPE,MADE W/LOFAT (2%) MILK',18273,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, blueberry, commercially prepared (Includes mini-muffins)','MUFFINS,BLUEBERRY,COMMLY PREP (INCLUDES MINI-MUFFINS)',18274,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, blueberry, dry mix','MUFFINS,BLUEBERRY,DRY MIX',18275,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, blueberry, toaster-type','MUFFINS,BLUEBERRY,TOASTER-TYPE',18277,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, blueberry, prepared from recipe, made with low fat (2%) milk','MUFFINS,BLUEBERRY,PREP FROM RECIPE,MADE W/LOFAT (2%) MILK',18278,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, corn, commercially prepared','MUFFINS,CORN,COMMLY PREP',18279,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, corn, dry mix, prepared','MUFFINS,CORN,DRY MIX,PREP',18280,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, corn, toaster-type','MUFFINS,CORN,TOASTER-TYPE',18281,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, corn, prepared from recipe, made with low fat (2%) milk','MUFFINS,CORN,PREP FROM RECIPE,MADE W/LOFAT (2%) MILK',18282,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, oat bran','MUFFINS,OAT BRAN',18283,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, wheat bran, dry mix','MUFFINS,WHEAT BRAN,DRY MIX',18284,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes plain, frozen, ready-to-heat (includes buttermilk)','PANCAKES PLN,FRZ,RTH (INCLUDES BUTTERMILK)',18288,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes, plain, dry mix, complete (includes buttermilk)','PANCAKES,PLN,DRY MIX,COMPLETE (INCL BTTRMLK)',18289,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes, plain, dry mix, complete, prepared','PANCAKES,PLN,DRY MIX,COMPLETE,PREP',18290,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes, plain, dry mix, incomplete (includes buttermilk)','PANCAKES,PLN,DRY MIX,INCOMPLETE (INCL BTTRMLK)',18291,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes, plain, dry mix, incomplete, prepared','PANCAKES,PLN,DRY MIX,INCOMPLETE,PREP',18292,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes, plain, prepared from recipe','PANCAKES,PLN,PREP FROM RECIPE',18293,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes, blueberry, prepared from recipe','PANCAKES,BLUEBERRY,PREP FROM RECIPE',18294,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes, buckwheat, dry mix, incomplete','PANCAKES,BUCKWHEAT,DRY MIX,INCOMPLETE',18295,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes, special dietary, dry mix','PANCAKES,SPL DIETARY,DRY MIX',18297,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes, whole-wheat, dry mix, incomplete','PANCAKES,WHOLE-WHEAT,DRY MIX,INCOMPLETE',18299,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes, whole-wheat, dry mix, incomplete, prepared','PANCAKES,WHOLE-WHEAT,DRY MIX,INCOMPLETE,PREP',18300,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, apple, commercially prepared, enriched flour','PIE,APPL,COMMLY PREP,ENR FLR',18301,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, apple, prepared from recipe','PIE,APPL,PREP FROM RECIPE',18302,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, banana cream, prepared from mix, no-bake type','PIE,BANANA CRM,PREP FROM MIX,NO-BAKE TYPE',18303,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, banana cream, prepared from recipe','PIE,BANANA CRM,PREP FROM RECIPE',18304,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, blueberry, commercially prepared','PIE,BLUEBERRY,COMMLY PREP',18305,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, blueberry, prepared from recipe','PIE,BLUEBERRY,PREP FROM RECIPE',18306,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, cherry, commercially prepared','PIE,CHERRY,COMMLY PREP',18308,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, cherry, prepared from recipe','PIE,CHERRY,PREP FROM RECIPE',18309,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, chocolate creme, commercially prepared','PIE,CHOC CREME,COMMLY PREP',18310,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, chocolate mousse, prepared from mix, no-bake type','PIE,CHOC MOUSSE,PREP FROM MIX,NO-BAKE TYPE',18312,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, coconut creme, commercially prepared','PIE,COCNT CREME,COMMLY PREP',18313,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, coconut cream, prepared from mix, no-bake type','PIE,COCNT CRM,PREP FROM MIX,NO-BAKE TYPE',18314,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, coconut custard, commercially prepared','PIE,COCNT CUSTARD,COMMLY PREP',18316,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, egg custard, commercially prepared','PIE,EGG CUSTARD,COMMLY PREP',18317,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, fried pies, fruit','PIE,FRIED PIES,FRUIT',18319,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, lemon meringue, commercially prepared','PIE,LEMON MERINGUE,COMMLY PREP',18320,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, lemon meringue, prepared from recipe','PIE,LEMON MERINGUE,PREP FROM RECIPE',18321,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, mince, prepared from recipe','PIE,MINCE,PREP FROM RECIPE',18322,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, peach','PIE,PEACH',18323,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, pecan, commercially prepared','PIE,PECAN,COMMLY PREP',18324,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, pecan, prepared from recipe','PIE,PECAN,PREP FROM RECIPE',18325,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, pumpkin, commercially prepared','PIE,PUMPKIN,COMMLY PREP',18326,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, pumpkin, prepared from recipe','PIE,PUMPKIN,PREP FROM RECIPE',18327,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, vanilla cream, prepared from recipe','PIE,VANILLA CRM,PREP FROM RECIPE',18328,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie crust, standard-type, dry mix','PIE CRUST,STANDARD-TYPE,DRY MIX',18332,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie crust, standard-type, dry mix, prepared, baked','PIE CRUST,STANDARD-TYPE,DRY MIX,PREP,BKD',18333,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie crust, standard-type, frozen, ready-to-bake, enriched','PIE CRUST,STANDARD-TYPE,FRZ,RTB,ENR',18334,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie crust, standard-type, frozen, ready-to-bake, enriched, baked','PIE CRUST,STANDARD-TYPE,FRZ,RTB,ENR,BKD',18335,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie crust, standard-type, prepared from recipe, baked','PIE CRUST,STANDARD-TYPE,PREP FROM RECIPE,BKD',18336,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Puff pastry, frozen, ready-to-bake','PUFF PASTRY,FRZ,RTB',18337,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Phyllo dough','PHYLLO DOUGH',18338,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Popovers, dry mix, enriched','POPOVERS,DRY MIX,ENRICHED',18339,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, dinner, plain, commercially prepared (includes brown-and-serve)','ROLLS, DINNER, PLN,COMM PREPARED (INC BROWN -N- SERVE)',18342,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, dinner, egg','ROLLS,DINNER,EGG',18344,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, dinner, oat bran','ROLLS,DINNER,OAT BRAN',18345,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, dinner, rye','ROLLS,DINNER,RYE',18346,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, dinner, wheat','ROLLS,DINNER,WHEAT',18347,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, dinner, whole-wheat','ROLLS,DINNER,WHOLE-WHEAT',18348,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, french','ROLLS,FRENCH',18349,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, hamburger or hotdog, plain','ROLLS,HAMBURGER OR HOTDOG,PLN',18350,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, hamburger or hotdog, mixed-grain','ROLLS,HAMBURGER OR HOTDOG,MIXED-GRAIN',18351,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, hard (includes kaiser)','ROLLS,HARD (INCL KAISER)',18353,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Strudel, apple','STRUDEL,APPLE',18354,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Sweet rolls, cheese','SWEET ROLLS,CHEESE',18355,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Sweet rolls, cinnamon, commercially prepared with raisins','SWEET ROLLS,CINN,COMMLY PREP W/RAISINS',18356,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Sweet rolls, cinnamon, refrigerated dough with frosting','SWEET ROLLS,CINN,REFR DOUGH W/FRSTNG',18357,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Sweet rolls, cinnamon, refrigerated dough with frosting, baked','SWEET ROLLS,CINN,REFR DOUGH W/FRSTNG,BKD',18358,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Taco shells, baked','TACO SHELLS, BAKED',18360,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Toaster pastries, fruit (includes apple, blueberry, cherry, strawberry)','TOASTER PASTRIES,FRUIT',18362,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Tortillas, ready-to-bake or -fry, corn','TORTILLAS,RTB OR -FRY,CORN',18363,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Tortillas, ready-to-bake or -fry, flour, refrigerated','TORTILLAS,RTB OR -FRY,FLR,REFR',18364,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Waffles, plain, frozen, ready-to-heat','WAFFLES,PLN,FRZ,RTH',18365,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Waffles, plain, prepared from recipe','WAFFLES,PLN,PREP FROM RECIPE',18367,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Wonton wrappers (includes egg roll wrappers)','WONTON WRAPPERS (INCL EGG ROLL WRAPPERS)',18368,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Leavening agents, baking powder, double-acting, sodium aluminum sulfate','LEAVENING AGENTS,BAKING PDR,DOUBLE-ACTING,NA AL SULFATE',18369,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Leavening agents, baking powder, double-acting, straight phosphate','LEAVENING AGENTS,BAKING PDR,DOUBLE-ACTING,STRAIGHT PO4',18370,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Leavening agents, baking powder, low-sodium','LEAVENING AGENTS,BAKING PDR,LOW-SODIUM',18371,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Leavening agents, baking soda','LEAVENING AGENTS,BAKING SODA',18372,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Leavening agents, cream of tartar','LEAVENING AGENTS,CRM OF TARTAR',18373,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Leavening agents, yeast, baker''s, compressed','LEAVENING AGENTS,YEAST,BAKER''S,COMPRESSED',18374,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Leavening agents, yeast, baker''s, active dry','LEAVENING AGENTS,YEAST,BAKER''S,ACTIVE DRY',18375,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, crumbs, dry, grated, seasoned','BREAD,CRUMBS,DRY,GRATED,SEASONED',18376,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, oatmeal, prepared from recipe, without raisins','COOKIES,OATMEAL,PREP FROM RECIPE,WO/RAISINS',18377,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate chip, prepared from recipe, made with butter','COOKIES,CHOC CHIP,PREP FROM RECIPE,MADE W/BUTTER',18378,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, protein, (includes gluten), toasted','BREAD,PROT,(INCLUDES GLUTEN),TSTD',18383,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, rice bran, toasted','BREAD,RICE BRAN,TOASTED',18384,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, blueberry, toaster-type, toasted','MUFFINS,BLUEBERRY,TOASTER-TYPE,TSTD',18386,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffins, wheat bran, toaster-type with raisins, toasted','MUFFINS,WHEAT BRAN,TOASTER-TYPE W/RAISINS,TSTD',18388,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes, buttermilk, prepared from recipe','PANCAKES,BTTRMLK,PREP FROM RECIPE',18390,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, dinner, plain, prepared from recipe, made with low fat (2%) milk','ROLLS,DINNER,PLN,PREP FROM RECIPE,MADE W/LOFAT (2%) MILK',18396,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie crust, cookie-type, prepared from recipe, graham cracker, chilled','PIE CRUST,COOKIE-TYPE,PREP FR RECIPE,GRAHAM CRACKER,CHILLED',18399,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, matzo, egg and onion','CRACKERS,MATZO,EGG&ONION',18400,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie crust, cookie-type, prepared from recipe, vanilla wafer, chilled','PIE CRUST,COOKIE-TYPE,PREP FROM RECIPE,VANILLA WAFER,CHILLED',18401,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie crust, standard-type, prepared from recipe, unbaked','PIE CRUST,STANDARD-TYPE,PREP FROM RECIPE,UNBAKED',18402,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Waffles, plain, frozen, ready -to-heat, toasted','WAFFLES,PLN,FRZ,READY -TO-HEAT,TSTD',18403,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bagels, plain, enriched, without calcium propionate (includes onion, poppy, sesame)','BAGELS,PLN,ENR,WO/CA PROP (INCL ONION,POPPY,SESAME)',18406,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bagels, plain, unenriched, with calcium propionate (includes onion, poppy, sesame)','BAGELS,PLN,UNENR,W/CA PROP (INCL ONION,POPPY,SESAME)',18407,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bagels, plain, unenriched, without calcium propionate(includes onion, poppy, sesame)','BAGELS,PLN,UNENR,WO/CA PROP (INCL ONION,POPPY,SESAME)',18408,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, cornbread, dry mix, unenriched (includes corn muffin mix)','BREAD,CORNBREAD,DRY MIX,UNENR (INCL CORN MUFFIN MIX)',18412,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, pita, white, unenriched','BREAD,PITA,WHITE,UNENR',18413,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, raisin, unenriched','BREAD,RAISIN,UNENRICHED',18414,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, white, commercially prepared, low sodium, no salt','BREAD,WHITE,COMMLY PREP,LO NA,NO SALT',18416,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, coffeecake, cinnamon with crumb topping, commercially prepared, unenriched','CAKE,COFFEECAKE,CINN W/ CRUMB TOPPING,COMMLY PREP,UNENR',18417,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, pound, commercially prepared, other than all butter, unenriched','CAKE,POUND,COMMLY PREP,OTHER THAN ALL BUTTER,UNENR',18418,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, pudding-type, white, unenriched, dry mix','CAKE,PUDDING-TYPE,WHITE,UNENR,DRY MIX',18419,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, yellow, unenriched, dry mix','CAKE,YEL,UNENR,DRY MIX',18420,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, butter, commercially prepared, unenriched','COOKIES,BUTTER,COMMLY PREP,UNENR',18421,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate chip, commercially prepared, regular, higher fat, unenriched','COOKIES,CHOC CHIP,COMMLY PREP,REG,HIGHER FAT,UNENR',18422,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, ladyfingers, without lemon juice and rind','COOKIES,LADYFINGERS,WO/LEMON JUC&RIND',18423,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, melba toast, plain, without salt','CRACKERS,MELBA TOAST,PLN,WO/SALT',18424,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, saltines, low salt (includes oyster, soda, soup)','CRACKERS,SALTINES,LO SALT (INCL OYSTER,SODA,SOUP)',18425,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, saltines, unsalted tops (includes oyster, soda, soup)','CRACKERS,SALTINES,UNSALTED TOPS (INCL OYSTER,SODA,SOUP)',18426,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, standard snack-type, regular, low salt','CRACKERS,STD SNACK-TYPE,REG,LO SALT',18427,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, wheat, low salt','CRACKERS,WHEAT,LOW SALT',18428,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, whole-wheat, low salt','CRACKERS,WHOLE-WHEAT,LO SALT',18429,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Danish pastry, cinnamon, unenriched','DANISH PASTRY,CINN,UNENR',18430,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Danish pastry, fruit, unenriched (includes apple, cinnamon, raisin, strawberry)','DANISH PASTRY,FRUIT,UNENR (INCL APPL,CINN,RAISIN,STRAWBERRY)',18431,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, white, commercially prepared, toasted, low sodium no salt','BREAD,WHITE,COMMLY PREP,TSTD,LO NA NO SALT',18432,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Danish pastry, lemon, unenriched','DANISH PASTRY,LEMON,UNENR',18433,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, cheese, low sodium','CRACKERS,CHS,LO NA',18434,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Danish pastry, raspberry, unenriched','DANISH PASTRY,RASPBERRY,UNENR',18435,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Doughnuts, yeast-leavened, glazed, unenriched (includes honey buns)','DOUGHNUTS,YEAST-LEAVENED,GLAZED,UNENR (INCL HONEY BUNS)',18436,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'English muffins, plain, enriched, without calcium propionate(includes sourdough)','ENGLISH MUFFINS,PLN,ENR,WO/CA PROP (INCL SOURDOUGH)',18437,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'English muffins, plain, unenriched, with calcium propionate (includes sourdough)','ENGLISH MUFFINS,PLN,UNENR,W/CA PROP (INCL SOURDOUGH)',18438,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'English muffins, plain, unenriched, without calcium propionate (includes sourdough)','ENGLISH MUFFINS,PLN,UNENR,WO/CA PROP (INCL SOURDOUGH)',18439,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, apple, commercially prepared, unenriched flour','PIE,APPL,COMMLY PREP,UNENR FLR',18443,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, fried pies, cherry','PIE,FRIED PIES,CHERRY',18444,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, fried pies, lemon','PIE,FRIED PIES,LEMON',18445,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie crust, standard-type, frozen, ready-to-bake, unenriched','PIE CRUST,STANDARD-TYPE,FRZ,RTB,UNENR',18446,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Popovers, dry mix, unenriched','POPOVERS,DRY MIX,UNENR',18447,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Taco shells, baked, without added salt','TACO SHELLS,BKD,WO/ SALT',18448,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Tortillas, ready-to-bake or -fry, corn, without added salt','TORTILLAS,RTB OR -FRY,CORN,WO/ SALT',18449,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Tortillas, ready-to-bake or -fry, flour, without added calcium','TORTILLAS,RTB OR -FRY,FLR,WO/ CA',18450,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, pound, commercially prepared, fat-free','CAKE,POUND,COMMLY PREP,FAT-FREE',18451,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, yellow, light, dry mix','CAKE,YEL,LT,DRY MIX',18453,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, saltines, fat-free, low-sodium','CRACKERS,SALTINES,FAT-FREE,LOW-SODIUM',18457,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Tart, breakfast, low fat','TART,BRKFST,LOFAT',18459,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Artificial Blueberry Muffin Mix, dry','ARTIFICIAL BLUEBERRY MUFFIN MIX,DRY',18566,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, cheese, sandwich-type with cheese filling','CRACKERS,CHS,SANDWICH-TYPE W/ CHS FILLING',18927,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Waffles, buttermilk, frozen, ready-to-heat','WAFFLES,BTTRMLK,FRZ,RTH',18932,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Waffle, buttermilk, frozen, ready-to-heat, toasted','WAFFLE,BTTRMLK,FRZ,RTH,TSTD',18933,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Waffle, buttermilk, frozen, ready-to-heat, microwaved','WAFFLE,BTTRMLK,FRZ,RTH,MICROWAVED',18934,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Waffle, plain, frozen, ready-to-heat, microwave','WAFFLE,PLN,FRZ,RTH,MICROWAVE',18935,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes, plain, frozen, ready-to-heat, microwave (includes buttermilk)','PANCAKES,PLN,FRZ,RTH,MICROWAVE(INC BUTTMLK)',18936,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Toaster Pastries, fruit, frosted (include apples, blueberry, cherry, strawberry)','TOASTER PASTRIES,FRUIT,FRSTD',18938,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Toaster pastries, fruit, toasted (include apple, blueberry, cherry, strawberry)','TSTR PSTRS,FRT,TSTD (INCL APPL,BLUEBERRY,CHERRY,STRAWBERRY)',18939,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Muffin, blueberry, commercially prepared, low-fat','MUFFIN,BLUEBERRY,COMMLY PREP,LOW-FAT',18940,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie Crust, Cookie-type, Graham Cracker, Ready Crust','PIE CRUST,COOKIE-TYPE,GRAHAM CRACKER,READY CRUST',18942,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2009-01-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie Crust, Cookie-type, Chocolate, Ready Crust','PIE CRUST,COOKIE-TYPE,CHOC,READY CRUST',18943,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2009-01-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie, Dutch Apple, Commercially Prepared','PIE,DUTCH APPL,COMMLY PREP',18944,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2009-01-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie crust, deep dish, frozen, unbaked, made with enriched flour','PIE CRUST,DEEP DISH,FRZ,UNBAKED,MADE W/ ENR FLR',18945,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie crust, refrigerated, regular, baked','PIE CRUST,REFR,REG,BKD',18946,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie crust, deep dish, frozen, baked, made with enriched flour','PIE CRUST,DEEP DISH,FRZ,BKD,MADE W/ ENR FLR',18947,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pie crust, refrigerated, regular, unbaked','PIE CRUST,REFR,REG,UNBAKED',18948,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, whole-wheat, reduced fat','CRACKERS,WHOLE-WHEAT,RED FAT',18949,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, wheat, reduced fat','CRACKERS,WHEAT,RED FAT',18950,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Waffles, chocolate chip, frozen, ready-to-heat','WAFFLES,CHOC CHIP,FRZ,RTH',18951,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Tostada shells, corn','TOSTADA SHELLS,CORN',18952,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, salvadoran sweet cheese (quesadilla salvadorena)','BREAD,SALVADORAN SWT CHS (QUESADILLA SALVADORENA)',18953,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, pound cake type, pan de torta salvadoran','BREAD,POUND CAKE TYPE,PAN DE TORTA SALVADORAN',18954,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, pan dulce, sweet yeast bread','BREAD,PAN DULCE,SWT YEAST BREAD',18955,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pastry, Pastelitos de Guava (guava pastries)','PASTRY,PASTELITOS DE GUAVA (GUAVA PASTRIES)',18959,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Garlic bread, frozen','GARLIC BREAD,FRZ',18963,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cinnamon buns, frosted (includes honey buns)','CINNAMON BUNS,FRSTD (INCLUDES HONEY BUNS)',18964,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, cheese, reduced fat','CRACKERS,CHS,RED FAT',18965,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, saltines, whole wheat (includes multi-grain)','CRACKERS,SALTINES,WHL WHEAT (INCLUDES MULTI-GRAIN)',18966,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, white wheat','BREAD,WHITE WHEAT',18967,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bagels, wheat','BAGELS,WHEAT',18968,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cream puff, eclair, custard or cream filled, iced','CREAM PUFF,ECLAIR,CUSTARD OR CRM FILLED,ICED',18969,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Tortillas, ready-to-bake or -fry, flour, shelf stable','TORTILLAS,RTB OR -FRY,FLR,SHELF STABLE',18970,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, potato','BREAD,POTATO',18971,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, cheese','BREAD,CHS',18972,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Focaccia, Italian flatbread, plain','FOCACCIA,ITALIAN FLATBREAD,PLN',18973,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, beef jerky, chopped and formed','BEEF JERKY,CHOPD&FORMED',19002,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, corn-based, extruded, chips, plain','SNACKS,CORN-BASED,EXTRUDED,CHIPS,PLN',19003,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, corn-based, extruded, chips, barbecue-flavor','CORN-BASED,EXTRUDED,CHIPS,BARBECUE-FLAVOR',19004,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, corn-based, extruded, cones, plain','CORN-BASED,EXTRUDED,CONES,PLN',19005,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, corn-based, extruded, onion-flavor','SNACKS,CORN-BASED,EXTRUDED,ONION-FLAVOR',19007,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, corn-based, extruded, puffs or twists, cheese-flavor','CORN-BASED,EXTRUDED,PUFFS OR TWISTS,CHEESE-FLAVOR',19008,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, crisped rice bar, chocolate chip','CRISPED RICE BAR,CHOC CHIP',19010,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Snacks, fruit leather, pieces','FRUIT LEATHER,PIECES',19013,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Snacks, fruit leather, rolls','FRUIT LEATHER,ROLLS',19014,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bars, hard, plain','GRANOLA BARS,HARD,PLAIN',19015,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bars, hard, almond','GRANOLA BARS,HARD,ALMOND',19016,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bars, hard, chocolate chip','GRANOLA BARS,HARD,CHOC CHIP',19017,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Fruit syrup','FRUIT SYRUP',19018,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bars, soft, uncoated, plain','GRANOLA BARS,SOFT,UNCOATED,PLN',19020,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bars, soft, uncoated, peanut butter','GRANOLA BARS,SOFT,UNCOATED,PNUT BUTTER',19021,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bars, soft, uncoated, raisin','GRANOLA BARS,SOFT,UNCOATED,RAISIN',19022,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bars, soft, coated, milk chocolate coating, chocolate chip','GRANOLA BARS,SOFT,COATD,MILK CHOC COATING,CHOC CHIP',19024,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, honey-combed, with peanut butter','CANDIES,HONEY-COMBED,W/ PNUT BUTTER',19025,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bars, soft, coated, milk chocolate coating, peanut butter','GRANOLA BARS,SOFT,COATD,MILK CHOC COATING,PNUT BUTTER',19026,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bars, soft, uncoated, peanut butter and chocolate chip','GRANOLA BARS,SOFT,UNCOATED,PNUT BUTTER&CHOC CHIP',19027,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrup, fruit flavored','SYRUP,FRUIT FLAV',19030,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, oriental mix, rice-based','ORIENTAL MIX,RICE-BASED',19031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, popcorn, air-popped','POPCORN,AIR-POPPED',19034,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, popcorn, oil-popped, microwave, regular flavor, no trans fat','SNACKS,POPCORN,OIL-POPPED,MICROWAVE,REG FLAVOR,NO TRANS FAT',19035,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, popcorn, cakes','POPCORN,CAKES',19036,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, popcorn, caramel-coated, with peanuts','POPCORN,CARAMEL-COATED,W/PNUTS',19038,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, popcorn, caramel-coated, without peanuts','POPCORN,CARAMEL-COATED,WO/PNUTS',19039,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, popcorn, cheese-flavor','POPCORN,CHEESE-FLAVOR',19040,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, pork skins, plain','PORK SKINS,PLAIN',19041,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, barbecue-flavor','POTATO CHIPS,BARBECUE-FLAVOR',19042,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, sour-cream-and-onion-flavor','POTATO CHIPS,SOUR-CREAM-AND-ONION-FLAVOR',19043,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, made from dried potatoes, reduced fat','POTATO CHIPS,MADE FROM DRIED POTATOES,LT',19045,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, made from dried potatoes, sour-cream and onion-flavor','POTATO CHIPS,MADE FR DRIED POTATOES,SOUR-CREAM&ONION-FLAVOR',19046,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, pretzels, hard, plain, salted','PRETZELS,HARD,PLN,SALTED',19047,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, pretzels, hard, confectioner''s coating, chocolate-flavor','PRETZELS,HARD,CONFECTIONER''S COATING,CHOCOLATE-FLAVOR',19048,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, pretzels, hard, whole-wheat including both salted and unsalted','SNACKS,PRETZELS,HARD,WHOLE-WHEAT INCL BOTH SALTED & UNSALTED',19050,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, rice cracker brown rice, plain','SNACKS,RICE CRACKER BROWN RICE,PLN',19051,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, rice cakes, brown rice, buckwheat','RICE CAKES,BROWN RICE,BUCKWHEAT',19052,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, rice cakes, brown rice, sesame seed','RICE CAKES,BROWN RICE,SESAME SD',19053,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, tortilla chips, plain, white corn, salted','TORTILLA CHIPS,PLAIN',19056,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, tortilla chips, nacho cheese','Snacks, tortilla chips, nacho cheese',19057,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, tortilla chips, ranch-flavor','SNACKS,TORTILLA CHIPS,RANCH-FLAVOR',19058,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, trail mix, regular','TRAIL MIX,REGULAR',19059,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, trail mix, tropical','TRAIL MIX,TROPICAL',19061,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, trail mix, regular, with chocolate chips, salted nuts and seeds','TRAIL MIX,REG,W/CHOC CHIPS,SALTED NUTS&SEEDS',19062,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, tortilla chips, taco-flavor','TORTILLA CHIPS,TACO-FLAVOR',19063,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, butterscotch','CANDIES,BUTTERSCOTCH',19070,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, carob, unsweetened','CANDIES,CAROB,UNSWTND',19071,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, caramels','CANDIES,CARAMELS',19074,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, caramels, chocolate-flavor roll','CANDIES, CARAMELS, CHOCOLATE-FLAVOR ROLL',19076,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Baking chocolate, unsweetened, liquid','BAKING CHOC,UNSWTND,LIQ',19077,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Baking chocolate, unsweetened, squares','Baking chocolate, unsweetened, squares',19078,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, confectioner''s coating, yogurt','CANDIES,CONFECTIONER''S COATING,YOGURT',19079,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, semisweet chocolate','CANDIES,SEMISWEET CHOC',19080,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, sweet chocolate','CANDIES,SWEET CHOCOLATE',19081,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, sweet chocolate coated fondant','CANDIES,SWT CHOC COATD FONDANT',19083,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, confectioner''s coating, butterscotch','CANDIES,CONFECTIONER''S COATING,BUTTERSCOTCH',19085,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, confectioner''s coating, peanut butter','CANDIES,CONFECTIONER''S COATING,PNUT BUTTER',19086,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, white chocolate','CANDIES,WHITE CHOC',19087,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Ice creams, vanilla, light','ICE CREAMS,VANILLA,LT',19088,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Ice creams, vanilla, rich','ICE CREAMS,VANILLA,RICH',19089,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Ice creams, french vanilla, soft-serve','ICE CREAMS,FRENCH VANILLA,SOFT-SERVE',19090,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Desserts, flan, caramel custard, prepared-from-recipe','DESSERTS,FLAN,CARAMEL CUSTARD,PREPARED-FROM-RECIPE',19094,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Ice creams, vanilla','ICE CREAMS,VANILLA',19095,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Ice creams, vanilla, light, soft-serve','ICE CREAMS,VANILLA,LT,SOFT-SERVE',19096,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Sherbet, orange','SHERBET,ORANGE',19097,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, fondant, prepared-from-recipe','CANDIES,FONDANT,PREPARED-FROM-RECIPE',19099,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, fudge, chocolate, prepared-from-recipe','CANDIES,FUDGE,CHOC,PREPARED-FROM-RECIPE',19100,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, fudge, chocolate, with nuts, prepared-from-recipe','CANDIES,FUDGE,CHOC,W/ NUTS,PREPARED-FROM-RECIPE',19101,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, fudge, peanut butter, prepared-from-recipe','CANDIES,FUDGE,PNUT BUTTER,PREPARED-FROM-RECIPE',19102,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, fudge, vanilla, prepared-from-recipe','CANDIES,FUDGE,VANILLA,PREPARED-FROM-RECIPE',19103,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, fudge, vanilla with nuts','CANDIES,FUDGE,VANILLA W/ NUTS',19104,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, gumdrops, starch jelly pieces','CANDIES,GUMDROPS,STARCH JELLY PIECES',19106,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, hard','CANDIES,HARD',19107,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, jellybeans','CANDIES,JELLYBEANS',19108,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrups, table blends, pancake, with butter','SYRUPS,TABLE BLENDS,PANCAKE,W/BUTTER',19113,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Ice creams, chocolate, light','ICE CREAMS,CHOC,LT',19114,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, marshmallows','CANDIES,MARSHMALLOWS',19116,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, halavah, plain','CANDIES,HALAVAH,PLAIN',19117,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, milk chocolate','CANDIES,MILK CHOC',19120,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, banana, dry mix, instant, prepared with 2% milk','PUDDINGS,BANANA,DRY MIX,INST,PREP W/ 2% MILK',19121,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, banana, dry mix, regular, prepared with 2% milk','PUDDINGS,BANANA,DRY MIX,REG,PREP W/ 2% MILK',19122,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, chocolate, dry mix, instant, prepared with 2% milk','PUDDINGS,CHOC,DRY MIX,INST,PREP W/ 2% MILK',19123,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Baking chocolate, mexican, squares','BAKING CHOC,MEXICAN,SQUARES',19124,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Chocolate-flavored hazelnut spread','CHOCOLATE-FLAVORED HAZELNUT SPRD',19125,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, milk chocolate coated peanuts','CANDIES,MILK CHOC COATD PNUTS',19126,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, milk chocolate coated raisins','CANDIES,MILK CHOC COATD RAISINS',19127,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrups, table blends, pancake, reduced-calorie','SYRUPS,TABLE BLENDS,PANCAKE,RED-CAL',19128,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrups, table blends, pancake','SYRUPS,TABLE BLENDS,PANCAKE',19129,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, milk chocolate, with almonds','CANDIES,MILK CHOC,W/ALMONDS',19132,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, milk chocolate, with rice cereal','CANDIES,MILK CHOC,W/RICE CRL',19134,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Toppings, strawberry','TOPPINGS,STRAWBERRY',19137,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, truffles, prepared-from-recipe','CANDIES,TRUFFLES,PREPARED-FROM-RECIPE',19138,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, peanut bar','CANDIES,PEANUT BAR',19147,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, peanut brittle, prepared-from-recipe','CANDIES,PNUT BRITTLE,PREPARED-FROM-RECIPE',19148,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, sesame crunch','CANDIES,SESAME CRUNCH',19154,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Chewing gum','CHEWING GUM',19163,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Cocoa, dry powder, unsweetened','COCOA,DRY PDR,UNSWTND',19165,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Cocoa, dry powder, unsweetened, processed with alkali','COCOA,DRY PDR,UNSWTND,PROC W/ALKALI',19166,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Desserts, egg custard, baked, prepared-from-recipe','DESSERTS,EGG CUSTARD,BKD,PREPARED-FROM-RECIPE',19168,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Egg custards, dry mix','EGG CUSTARDS,DRY MIX',19169,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Egg custards, dry mix, prepared with whole milk','EGG CUSTARDS,DRY MIX,PREP W/ WHL MILK',19170,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Gelatin desserts, dry mix','GELATIN DSSRT,DRY MIX',19172,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Gelatin desserts, dry mix, prepared with water','GELATIN DSSRT,DRY MIX,PREP W/ H2O',19173,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Gelatin desserts, dry mix, reduced calorie, with aspartame','GELATIN DSSRT,DRY MIX,RED CAL,W/ ASPRT',19175,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Gelatin desserts, dry mix, reduced calorie, with aspartame, prepared with water','GELATIN DSSRT,DRY MIX,RED CAL,W/ ASPRT,PREP W/ H2O',19176,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Gelatins, dry powder, unsweetened','GELATINS,DRY PDR,UNSWTND',19177,NULL,NULL,NULL,NULL,NULL,1,'1994-03-16','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Desserts, mousse, chocolate, prepared-from-recipe','DESSERTS,MOUSSE,CHOC,PREPARED-FROM-RECIPE',19182,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, chocolate, ready-to-eat','PUDDINGS,CHOC,RTE',19183,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, chocolate, dry mix, instant','PUDDINGS,CHOC,DRY MIX,INST',19184,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, chocolate, dry mix, instant, prepared with whole milk','PUDDINGS,CHOC,DRY MIX,INST,PREP W/ WHL MILK',19185,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Desserts, apple crisp, prepared-from-recipe','DESSERTS,APPL CRISP,PREPARED-FROM-RECIPE',19186,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, chocolate, dry mix, regular','DESSERTS,PUDD,CHOC,DRY MIX,REG',19188,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, chocolate, dry mix, regular, prepared with whole milk','PUDDINGS,CHOC,DRY MIX,INST,PREP W/ WHOLE MILK',19189,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, chocolate, dry mix, regular, prepared with 2% milk','PUDDINGS,CHOC,DRY MIX,REG,PREP W/ 2% MILK',19190,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, coconut cream, dry mix, instant, prepared with 2% milk','PUDDINGS,COCNT CRM,DRY MIX,INST,PREP W/ 2% MILK',19191,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, rice, ready-to-eat','Puddings, rice, ready-to-eat',19193,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, rice, dry mix, prepared with whole milk','PUDDINGS,RICE,DRY MIX,PREP W/ WHL MILK',19195,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, tapioca, dry mix, prepared with whole milk','PUDDINGS,TAPIOCA,DRY MIX,PREP W/ WHL MILK',19199,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, vanilla, ready-to-eat','PUDDINGS,VANILLA,RTE',19201,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, vanilla, dry mix, instant','PUDDINGS,VANILLA,DRY MIX,INST',19202,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, vanilla, dry mix, instant, prepared with whole milk','PUDDINGS,VANILLA,DRY MIX,INST,PREP W/ WHL MILK',19203,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, lemon, dry mix, instant, prepared with 2% milk','PUDDINGS,LEMON,DRY MIX,INST,PREP W/ 2% MILK',19204,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Egg custards, dry mix, prepared with 2% milk','EGG CUSTARDS,DRY MIX,PREP W/ 2% MILK',19205,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, vanilla, dry mix, regular','PUDDINGS,VANILLA,DRY MIX,REG',19206,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, vanilla, dry mix, regular, prepared with whole milk','PUDDINGS,VANILLA,DRY MIX,REG,PREP W/ WHL MILK',19207,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, rice, dry mix, prepared with 2% milk','PUDDINGS,RICE,DRY MIX,PREP W/ 2% MILK',19208,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, tapioca, dry mix, prepared with 2% milk','PUDDINGS,TAPIOCA,DRY MIX,PREP W/ 2% MILK',19209,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, vanilla, dry mix, regular, prepared with 2% milk','PUDDINGS,VANILLA,DRY MIX,REG,PREP W/ 2% MILK',19212,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Rennin, chocolate, dry mix, prepared with 2% milk','RENNIN,CHOC,DRY MIX,PREP W/ 2% MILK',19213,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Rennin, vanilla, dry mix, prepared with 2% milk','RENNIN,VANILLA,DRY MIX,PREP W/ 2% MILK',19214,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, praline, prepared-from-recipe','CANDIES,PRALINE,PREPARED-FROM-RECIPE',19216,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen novelties, ice type, fruit, no sugar added','FROZEN NOVELTIES,ICE TYPE,FRUIT,NO SUGAR ADDED',19217,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, tapioca, ready-to-eat','PUDDINGS,TAPIOCA,RTE',19218,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, coconut cream, dry mix, regular, prepared with 2% milk','PUDDINGS,COCNT CRM,DRY MIX,REG,PREP W/ 2% MILK',19219,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Desserts, rennin, chocolate, dry mix','DESSERTS,RENNIN,CHOC,DRY MIX',19220,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Rennin, chocolate, dry mix, prepared with whole milk','RENNIN,CHOC,DRY MIX,PREP W/ WHL MILK',19221,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Rennin, vanilla, dry mix, prepared with whole milk','RENNIN,VANILLA,DRY MIX,PREP W/ WHL MILK',19223,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Desserts, rennin, tablets, unsweetened','DESSERTS,RENNIN,TABLETS,UNSWTND',19225,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frostings, chocolate, creamy, ready-to-eat','FROSTINGS,CHOC,CREAMY,RTE',19226,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frostings, coconut-nut, ready-to-eat','FROSTINGS,COCONUT-NUT,RTE',19227,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frostings, cream cheese-flavor, ready-to-eat','FROSTINGS,CRM CHEESE-FLAVOR,RTE',19228,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frostings, vanilla, creamy, ready-to-eat','FROSTINGS,VANILLA,CREAMY,RTE',19230,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Flan, caramel custard, dry mix, prepared with 2% milk','FLAN,CARAMEL CUSTARD,DRY MIX,PREP W/ 2% MILK',19231,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Flan, caramel custard, dry mix, prepared with whole milk','FLAN,CARAMEL CUSTARD,DRY MIX,PREP W/ WHL MILK',19232,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, vanilla, ready-to-eat, fat free','PUDDINGS,VANILLA,RTE,FAT FREE',19233,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, tapioca, ready-to-eat, fat free','PUDDINGS,TAPIOCA,RTE,FAT FREE',19234,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, chocolate, ready-to-eat, fat free','PUDDINGS,CHOC,RTE,FAT FREE',19235,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frostings, chocolate, creamy, dry mix, prepared with butter','FROSTINGS,CHOC,CREAMY,DRY MIX,PREP W/ BUTTER',19241,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frostings, white, fluffy, dry mix, prepared with water','FROSTINGS,WHITE,FLUFFY,DRY MIX,PREP W/H2O',19247,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Ice creams, vanilla, light, no sugar added','ICE CREAMS,VANILLA,LT,NO SUGAR ADDED',19260,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen novelties, fruit and juice bars','FROZEN NOVELTIES,FRUIT & JUC BARS',19263,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Ice creams, chocolate, light, no sugar added','ICE CREAMS,CHOC,LT,NO SUGAR ADDED',19265,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, dark chocolate coated coffee beans','CANDIES,DK CHOC COATD COFFEE BNS',19268,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Ice creams, chocolate','ICE CREAMS,CHOC',19270,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Ice creams, strawberry','ICE CREAMS,STRAWBERRY',19271,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, fruit leather, pieces, with vitamin C','SNACKS,FRUIT LEATHER,PIECES,W/VIT C',19274,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-12',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, milk chocolate coated coffee beans','CANDIES,MILK CHOC COATD COFFEE BNS',19279,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen novelties, ice type, lime','FROZEN NOVELTIES,ICE TYPE,LIME',19280,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen novelties, ice type, pop','FROZEN NOVELTIES,ICE TYPE,POP',19283,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen yogurts, vanilla, soft-serve','FROZEN YOGURTS,VANILLA,SOFT-SERVE',19293,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Fruit butters, apple','FRUIT BUTTERS,APPLE',19294,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Honey','HONEY',19296,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Jams and preserves','JAMS AND PRESERVES',19297,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Jellies','JELLIES',19300,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, fudge, chocolate marshmallow, with nuts, prepared-by-recipe','CANDIES,FUDGE,CHOC MARSHMLLW,W/ NUTS,PREPARED-BY-RECIPE',19301,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Marmalade, orange','MARMALADE,ORANGE',19303,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Molasses','MOLASSES',19304,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Pectin, unsweetened, dry mix','PECTIN,UNSWTND,DRY MIX',19310,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Pie fillings, apple, canned','PIE FILLINGS,APPL,CND',19312,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Pie fillings, canned, cherry','PIE FILLINGS,CND,CHERRY',19314,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, banana, dry mix, instant','PUDDINGS,BANANA,DRY MIX,INST',19318,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, banana, dry mix, instant, prepared with whole milk','PUDDINGS,BANANA,DRY MIX,INST,PREP W/ WHL MILK',19319,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, banana, dry mix, regular','PUDDINGS,BANANA,DRY MIX,REG',19320,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, banana, dry mix, regular, prepared with whole milk','PUDDINGS,BANANA,DRY MIX,REG,PREP W/ WHL MILK',19321,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, coconut cream, dry mix, instant','DESSERTS,PUDD,COCNT CRM,DRY MIX,INST',19322,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, coconut cream, dry mix, instant, prepared with whole milk','PUDDINGS,COCNT CRM,DRY MIX,INST,PREP W/ WHL MILK',19323,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, coconut cream, dry mix, regular','PUDDINGS,COCNT CRM,DRY MIX,REG',19324,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, coconut cream, dry mix, regular, prepared with whole milk','PUDDINGS,COCNT CRM,DRY MIX,REG,PREP W/ WHL MILK',19325,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, lemon, dry mix, instant','PUDDINGS,LEMON,DRY MIX,INST',19330,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, lemon, dry mix, instant, prepared with whole milk','PUDDINGS,LEMON,DRY MIX,INST,PREP W/ WHL MILK',19331,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Pudding, lemon, dry mix, regular, prepared with sugar, egg yolk and water','PUDDING,LEMON,DRY MIX,REG,PREP W/ SUGAR,EGG YOLK & H2O',19333,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Sugars, brown','SUGARS,BROWN',19334,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Sugars, granulated','SUGARS,GRANULATED',19335,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Sugars, powdered','SUGARS,POWDERED',19336,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Sugars, maple','SUGARS,MAPLE',19340,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrups, chocolate, fudge-type','SYRUPS,CHOC,FUDGE-TYPE',19348,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrups, corn, dark','SYRUPS,CORN,DK',19349,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrups, corn, light','SYRUPS,CORN,LT',19350,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrups, corn, high-fructose','SYRUPS,CORN,HIGH-FRUCTOSE',19351,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrups, malt','SYRUPS,MALT',19352,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrups, maple','SYRUPS,MAPLE',19353,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrups, sorghum','SYRUPS,SORGHUM',19355,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrups, table blends, pancake, with 2% maple','SYRUPS,TABLE BLENDS,PANCAKE,W/2% MAPLE',19360,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrups, table blends, corn, refiner, and sugar','SYRUPS,TABLE BLENDS,CORN,REFINER,&SUGAR',19362,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Toppings, butterscotch or caramel','TOPPINGS,BUTTERSCOTCH OR CARAMEL',19364,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Toppings, marshmallow cream','TOPPINGS,MARSHMLLW CRM',19365,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Toppings, pineapple','TOPPINGS,PINEAPPLE',19366,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Toppings, nuts in syrup','TOPPINGS,NUTS IN SYRUP',19367,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frostings, vanilla, creamy, dry mix, prepared with margarine','FROSTINGS,VANILLA,CREAMY,DRY MIX,PREP W/ MARGARINE',19371,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frostings, chocolate, creamy, dry mix, prepared with margarine','FROSTINGS,CHOC,CREAMY,DRY MIX,PREP W/ MARGARINE',19372,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frostings, glaze, prepared-from-recipe','FROSTINGS,GLAZE,PREPARED-FROM-RECIPE',19375,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, fudge, chocolate marshmallow, prepared-from-recipe','CANDIES,FUDGE,CHOC MARSHMLLW,PREPARED-FROM-RECIPE',19379,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, taffy, prepared-from-recipe','CANDIES,TAFFY,PREPARED-FROM-RECIPE',19382,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, toffee, prepared-from-recipe','CANDIES,TOFFEE,PREPARED-FROM-RECIPE',19383,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, divinity, prepared-from-recipe','CANDIES,DIVINITY,PREPARED-FROM-RECIPE',19384,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen novelties, ice type, pineapple-coconut','FROZEN NOVELTIES,ICE TYPE,PINEAPPLE-COCONUT',19387,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen yogurts, chocolate, soft-serve','FROZEN YOGURTS,CHOC,SOFT-SERVE',19393,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, banana chips','BANANA CHIPS',19400,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, cornnuts, barbecue-flavor','CORNNUTS,BARBECUE-FLAVOR',19401,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, crisped rice bar, almond','CRISPED RICE BAR,ALMOND',19403,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-12',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bars, soft, uncoated, chocolate chip','GRANOLA BARS,SOFT,UNCOATED,CHOC CHIP',19404,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bars, soft, uncoated, chocolate chip, graham and marshmallow','GRANOLA BARS,SOFT,UNCOATED,CHOC CHIP,GRAHAM&MARSHMLLW',19405,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bars, soft, uncoated, nut and raisin','GRANOLA BARS,SOFT,UNCOATED,NUT&RAISIN',19406,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, beef sticks, smoked','SNACKS,BF STKS,SMOKED',19407,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, pork skins, barbecue-flavor','PORK SKINS,BARBECUE-FLAVOR',19408,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snack, potato chips, made from dried potatoes, plain','POTATO CHIPS,MADE FROM DRIED POTATOES,PLN',19410,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, plain, salted','POTATO CHIPS,PLAIN,SALTED',19411,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, made from dried potatoes, cheese-flavor','POTATO CHIPS,MADE FROM DRIED POTATOES,CHEESE-FLAVOR',19412,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, rice cakes, brown rice, corn','SNACKS,RICE CAKES,BROWN RICE,CORN',19413,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, rice cakes, brown rice, multigrain','RICE CAKES,BROWN RICE,MULTIGRAIN',19414,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato sticks','SNACKS,POTATO STKS',19415,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, rice cakes, brown rice, rye','RICE CAKES,BROWN RICE,RYE',19416,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, sesame sticks, wheat-based, salted','SESAME STKS,WHEAT-BASED,SALTED',19418,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, corn cakes','CORN CAKES',19419,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bars, hard, peanut butter','GRANOLA BARS,HARD,PNUT BUTTER',19420,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, cheese-flavor','POTATO CHIPS,CHEESE-FLAVOR',19421,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, reduced fat','SNACKS,POTATO CHIPS,RED FAT',19422,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, fat-free, made with olestra','SNACKS,POTATO CHIPS,FAT-FREE,MADE W/OLESTRA',19423,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, tortilla chips, nacho-flavor, reduced fat','SNACKS,TORTILLA CHIPS,NACHO-FLAVOR,RED FAT',19424,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Tortilla chips, low fat, baked without fat','TORTILLA CHIPS,LOFAT,BKD WO/FAT',19433,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Cheese puffs and twists, corn based, baked, low fat','CHEESE PUFFS & TWISTS,CORN BSD,BKD,LOFAT',19434,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bar, fruit-filled, nonfat','SNACKS,GRANOLA BAR,FRUIT-FILLED,NONFAT',19435,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Popcorn, sugar syrup/caramel, fat-free','POPCORN,SUGAR SYRUP/CARAMEL,FAT-FREE',19436,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, fat free, salted','POTATO CHIPS,FAT FREE,SALTED',19437,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, tortilla chips, low fat, made with olestra, nacho cheese','SNACKS,TORTILLA CHIPS,LOFAT,MADE W/OLESTRA,NACHO CHS',19444,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, made from dried potatoes, fat-free, made with olestra','SNACKS,POTATO CHIPS,FRM DRIED POTATOES,FAT-FREE,W/ OLESTRA',19445,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, taro chips','TARO CHIPS',19524,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, semisweet chocolate, made with butter','CANDIES,SEMISWEET CHOC,MADE W/BUTTER',19701,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Gelatin desserts, dry mix, with added ascorbic acid, sodium-citrate and salt','GELATIN DSSRT,DRY MIX,W/ ADDED VIT C,SODIUM-CITRATE & SALT',19702,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Gelatin desserts, dry mix, reduced calorie, with aspartame, added phosphorus, potassium, sodium, vitamin C','GELATIN DSSRT,DRY MIX,RED CAL,W/ ASPRT,ADDED P,K,NA,VIT C',19703,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Gelatin desserts, dry mix, reduced calorie, with aspartame, no added sodium','GELATIN DSSRT,DRY MIX,RED CAL,W/ ASPRT,NO ADDED NA',19704,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, banana, dry mix, instant, with added oil','PUDDINGS,BANANA,DRY MIX,INST,W/ ADDED OIL',19705,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, banana, dry mix, regular, with added oil','PUDDINGS,BANANA,DRY MIX,REG,W/ ADDED OIL',19706,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, lemon, dry mix, regular, with added oil, potassium, sodium','PUDDINGS,LEMON,DRY MIX,REG,W/ ADDED OIL,K,NA',19708,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, vanilla, dry mix, regular, with added oil','PUDDINGS,VANILLA,DRY MIX,REG,W/ ADDED OIL',19710,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Jams and preserves, apricot','JAMS&PRESERVES,APRICOT',19719,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrups, table blends, pancake, with 2% maple, with added potassium','SYRUPS,TABLE BLENDS,PANCAKE,W/2% MAPLE,W/ K',19720,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, corn cakes, very low sodium','CORN CAKES,VERY LO NA',19800,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, corn-based, extruded, puffs or twists, cheese-flavor, unenriched','SNACKS,CORN-BASED,EXTRDD,PUFFS OR TWISTS,CHEESE-FLAVOR,UNENR',19802,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, corn-based, extruded, chips, barbecue-flavor, made with enriched masa flour','SNACKS,CORN-BASE,EXTRUD,CHIPS,BARBECUE-FLAVOR,W/ENR MASA FLR',19804,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, popcorn, air-popped (Unsalted)','SNACKS,POPCORN,AIR-POPPED (UNSALTED)',19806,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, popcorn, oil-popped, white popcorn, salt added','SNACKS,POPCORN,OIL-POPPED,WHITE POPCORN,SALT ADDED',19807,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, plain, made with partially hydrogenated soybean oil, salted','POTATO CHIPS,PLN,MADE W/PART HYDR SOYBN OIL,SALTED',19809,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, plain, made with partially hydrogenated soybean oil, unsalted','POTATO CHIPS,PLN,MADE W/PART HYDR SOYBN OIL,UNSALTED',19810,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, plain, unsalted','POTATO CHIPS,PLN,UNSALTED',19811,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, pretzels, hard, plain, made with unenriched flour, salted','PRETZELS,HARD,PLN,MADE W/UNENR FLR,SALTED',19812,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, pretzels, hard, plain, made with unenriched flour, unsalted','PRETZELS,HARD,PLN,MADE W/UNENR FLR,UNSALTED',19813,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, pretzels, hard, plain, made with enriched flour, unsalted','SNACKS,PRETZELS,HARD,PLN,MADE W/ ENR FLR,UNSALTED',19814,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, rice cakes, brown rice, plain, unsalted','RICE CAKES,BROWN RICE,PLN,UNSALTED',19816,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, rice cakes, brown rice, buckwheat, unsalted','RICE CAKES,BROWN RICE,BUCKWHEAT,UNSALTED',19817,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, rice cakes, brown rice, multigrain, unsalted','RICE CAKES,BROWN RICE,MULTIGRAIN,UNSALTED',19818,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, rice cakes, brown rice, sesame seed, unsalted','RICE CAKES,BROWN RICE,SESAME SD,UNSALTED',19819,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, sesame sticks, wheat-based, unsalted','SESAME STKS,WHEAT-BASED,UNSALTED',19820,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, trail mix, regular, unsalted','TRAIL MIX,REG,UNSALTED',19821,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, trail mix, regular, with chocolate chips, unsalted nuts and seeds','TRAIL MIX,REG,W/CHOC CHIPS,UNSALTED NUTS&SEEDS',19822,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Potato chips, without salt, reduced fat','POTATO CHIPS,WO/SALT,RED FAT',19823,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, tortilla chips, low fat, unsalted','TORTILLA CHIPS,LOFAT,UNSALTED',19833,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, tortilla chips, nacho-flavor, made with enriched masa flour','SNACKS,TORTILLA CHIPS,NACHO-FLAVOR,MADE W/ENR MASA FLR',19857,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, sugar-coated almonds','CANDIES,SUGAR-COATED ALMONDS',19858,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Cocoa, dry powder, hi-fat or breakfast, processed with alkali','COCOA,DRY PDR,HI-FAT OR BRKFST,PROC W/ALKALI',19860,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, soft fruit and nut squares','CANDIES,SOFT FRUIT & NUT SQUARES',19866,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Ice creams, vanilla, fat free','ICE CREAMS,VANILLA,FAT FREE',19867,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Ice creams, regular, low carbohydrate, vanilla','ICE CREAMS,REG,LO CARBOHYDRATE,VANILLA',19898,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Ice creams, regular, low carbohydrate, chocolate','ICE CREAMS,REG,LO CARBOHYDRATE,CHOC',19899,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Chocolate, dark, 45- 59% cacao solids','CHOCOLATE,DK,45- 59% CACAO SOL',19902,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Chocolate, dark, 60-69% cacao solids','CHOCOLATE,DK,60-69% CACAO SOL',19903,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Chocolate, dark, 70-85% cacao solids','CHOCOLATE,DK,70-85% CACAO SOL',19904,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, chocolate, dark, NFS (45-59% cacao solids 90%; 60-69% cacao solids 5%; 70-85% cacao solids 5%)','CANDIES,CHOC,DK,NFS (45-59% CACAO SOL 90%; 60-69% CACAO SOL',19905,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, crispy bar with peanut butter filling','CANDIES,CRISPY BAR W/ PNUT BUTTER FILLING',19910,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Sweetener, syrup, agave','Sweetener, syrup, agave',19912,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Sweetener, herbal extract powder from Stevia leaf','SWEETENER,HERBAL EXTRACT PDR FROM STEVIA LEAF',19918,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, fruit snacks, with high vitamin C','CANDIES,FRUIT SNACKS,W/ HI VIT C',19919,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Jams, preserves, marmalades, sweetened with fruit juice','JAMS,PRESERVES,MARMALADES,SWTND W/ FRUIT JUC',19920,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, Tamarind','CANDIES,TAMARIND',19921,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, coconut bar, not chocolate covered','CANDIES,COCNT BAR,NOT CHOC COVERED',19922,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Amaranth grain, uncooked','AMARANTH GRAIN,UNCKD',20001,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Arrowroot flour','ARROWROOT FLOUR',20003,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Barley, hulled','BARLEY,HULLED',20004,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Barley, pearled, raw','BARLEY,PEARLED,RAW',20005,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Barley, pearled, cooked','BARLEY,PEARLED,COOKED',20006,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Buckwheat','BUCKWHEAT',20008,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Buckwheat groats, roasted, dry','BUCKWHEAT GROATS,RSTD,DRY',20009,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Buckwheat groats, roasted, cooked','BUCKWHEAT GROATS,RSTD,CKD',20010,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Buckwheat flour, whole-groat','BUCKWHEAT FLR,WHOLE-GROAT',20011,NULL,NULL,NULL,NULL,NULL,1,'2005-12-28','2006-11-30',NULL,'as purchased',NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Bulgur, dry','BULGUR,DRY',20012,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Bulgur, cooked','BULGUR,COOKED',20013,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Corn grain, yellow','CORN GRAIN,YEL',20014,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Corn bran, crude','CORN BRAN,CRUDE',20015,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Corn flour, whole-grain, yellow','CORN FLR,WHOLE-GRAIN,YEL',20016,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Corn flour, masa, enriched, white','CORN FLR,MASA,ENR,WHITE',20017,NULL,NULL,NULL,NULL,NULL,1,'1995-06-23','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Corn flour, yellow, degermed, unenriched','CORN FLR,YEL,DEGERMED,UNENR',20018,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Corn flour, masa, unenriched, white','CORN FLR,MASA,UNENR,WHITE',20019,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Cornmeal, whole-grain, yellow','CORNMEAL,WHOLE-GRAIN,YEL',20020,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Cornmeal, degermed, enriched, yellow','CORNMEAL,DEGERMED,ENR,YEL',20022,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Cornmeal, yellow, self-rising, bolted, plain, enriched','CORNMEAL,YEL,SELF-RISING,BOLTED,PLN,ENR',20023,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Cornmeal, yellow, self-rising, bolted, with wheat flour added, enriched','CORNMEAL,YEL,SELF-RISING,BOLTED,W/ WHEAT FLR ADDED,ENR',20024,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Cornmeal, yellow, self-rising, degermed, enriched','CORNMEAL,YEL,SELF-RISING,DEGERMED,ENR',20025,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Cornstarch','CORNSTARCH',20027,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Couscous, dry','COUSCOUS,DRY',20028,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Couscous, cooked','COUSCOUS,COOKED',20029,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Hominy, canned, white','HOMINY,CANNED,WHITE',20030,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Millet, raw','MILLET,RAW',20031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Millet, cooked','MILLET,COOKED',20032,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Oat bran, raw','OAT BRAN,RAW',20033,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Oat bran, cooked','OAT BRAN,COOKED',20034,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Quinoa, uncooked','QUINOA,UNCKD',20035,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, brown, long-grain, raw (Includes foods for USDA''s Food Distribution Program)','RICE,BROWN,LONG-GRAIN,RAW',20036,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, brown, long-grain, cooked (Includes foods for USDA''s Food Distribution Program)','RICE,BROWN,LONG-GRAIN,CKD',20037,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Oats (Includes foods for USDA''s Food Distribution Program)','OATS',20038,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, brown, medium-grain, raw (Includes foods for USDA''s Food Distribution Program)','RICE,BROWN,MEDIUM-GRAIN,RAW',20040,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, brown, medium-grain, cooked (Includes foods for USDA''s Food Distribution Program)','RICE,BROWN,MEDIUM-GRAIN,CKD',20041,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, long-grain, regular, raw, enriched','RICE,WHITE,LONG-GRAIN,REG,RAW,ENR',20044,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, long-grain, regular, enriched, cooked','RICE,WHITE,LONG-GRAIN,REG,ENR,CKD',20045,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, long-grain, parboiled, enriched, dry','RICE,WHITE,LONG-GRAIN,PARBLD,ENR,DRY',20046,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, long-grain, parboiled, enriched, cooked','RICE,WHITE,LONG-GRAIN,PARBLD,ENR,CKD',20047,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, long-grain, precooked or instant, enriched, dry','RICE,WHITE,LONG-GRAIN,PRECKD OR INST,ENR,DRY',20048,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, long-grain, precooked or instant, enriched, prepared','RICE,WHITE,LONG-GRAIN,PRECKD OR INST,ENR,PREP',20049,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, medium-grain, raw, enriched','RICE,WHITE,MEDIUM-GRAIN,RAW,ENR',20050,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, medium-grain, enriched, cooked','RICE,WHITE,MEDIUM-GRAIN,ENR,CKD',20051,NULL,NULL,NULL,NULL,NULL,1,'1994-09-20','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, short-grain, enriched, uncooked','RICE,WHITE,SHORT-GRAIN,ENR,UNCKD',20052,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, short-grain, enriched, cooked','RICE,WHITE,SHORT-GRAIN,ENR,CKD',20053,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, glutinous, unenriched, uncooked','RICE,WHITE,GLUTINOUS,UNENR,UNCKD',20054,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, glutinous, unenriched, cooked','RICE,WHITE,GLUTINOUS,UNENR,CKD',20055,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice bran, crude','RICE BRAN,CRUDE',20060,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice flour, white, unenriched','RICE FLR,WHITE,UNENR',20061,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rye grain','RYE GRAIN',20062,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rye flour, dark','RYE FLOUR,DARK',20063,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rye flour, medium','RYE FLOUR,MEDIUM',20064,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rye flour, light','RYE FLOUR,LIGHT',20065,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Semolina, enriched','SEMOLINA,ENRICHED',20066,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Sorghum grain','SORGHUM GRAIN',20067,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Tapioca, pearl, dry','TAPIOCA,PEARL,DRY',20068,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Triticale','TRITICALE',20069,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Triticale flour, whole-grain','TRITICALE FLR,WHOLE-GRAIN',20070,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat, hard red spring','WHEAT,HARD RED SPRING',20071,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat, hard red winter','WHEAT,HARD RED WINTER',20072,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat, soft red winter','WHEAT,SOFT RED WINTER',20073,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat, hard white','WHEAT,HARD WHITE',20074,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat, soft white','WHEAT,SOFT WHITE',20075,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat, durum','WHEAT,DURUM',20076,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat bran, crude','WHEAT BRAN,CRUDE',20077,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat germ, crude','WHEAT GERM,CRUDE',20078,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, whole-grain (Includes foods for USDA''s Food Distribution Program)','WHEAT FLOUR,WHOLE-GRAIN',20080,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white, all-purpose, enriched, bleached','WHEAT FLR,WHITE,ALL-PURPOSE,ENR,BLEACHED',20081,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white, all-purpose, self-rising, enriched','WHEAT FLR,WHITE,ALL-PURPOSE,SELF-RISING,ENR',20082,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white, bread, enriched','WHEAT FLR,WHITE,BREAD,ENR',20083,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white, cake, enriched','WHEAT FLR,WHITE,CAKE,ENR',20084,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white, tortilla mix, enriched','WHEAT FLR,WHITE,TORTILLA MIX,ENR',20086,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat, sprouted','WHEAT,SPROUTED',20087,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wild rice, raw','WILD RICE,RAW',20088,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wild rice, cooked','WILD RICE,COOKED',20089,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice flour, brown','RICE FLOUR,BROWN',20090,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, gluten-free, corn, dry','PASTA,GLUTEN-FREE,CORN,DRY',20091,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, gluten-free, corn, cooked','PASTA,GLUTEN-FREE,CORN,CKD',20092,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, fresh-refrigerated, plain, as purchased','PASTA,FRESH-REFRIGERATED,PLN,AS PURCHASED',20093,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, fresh-refrigerated, plain, cooked','PASTA,FRESH-REFRIGERATED,PLN,CKD',20094,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, fresh-refrigerated, spinach, as purchased','PASTA,FRESH-REFRIGERATED,SPINACH,AS PURCHASED',20095,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, fresh-refrigerated, spinach, cooked','PASTA,FRESH-REFRIGERATED,SPINACH,CKD',20096,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, homemade, made with egg, cooked','PASTA,HOMEMADE,MADE W/EGG,CKD',20097,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, homemade, made without egg, cooked','PASTA,HOMEMADE,MADE WO/EGG,CKD',20098,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Macaroni, vegetable, enriched, dry','MACARONI,VEG,ENR,DRY',20105,NULL,NULL,NULL,NULL,NULL,1,'1998-03-27','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Macaroni, vegetable, enriched, cooked','MACARONI,VEG,ENR,CKD',20106,NULL,NULL,NULL,NULL,NULL,1,'1998-03-27','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Noodles, egg, dry, enriched','NOODLES,EGG,DRY,ENRICHED',20109,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Noodles, egg, enriched, cooked','NOODLES,EGG,ENR,CKD',20110,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Noodles, egg, spinach, enriched, dry','NOODLES,EGG,SPINACH,ENR,DRY',20111,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Noodles, egg, spinach, enriched, cooked','NOODLES,EGG,SPINACH,ENR,CKD',20112,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Noodles, chinese, chow mein','NOODLES,CHINESE,CHOW MEIN',20113,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Noodles, japanese, soba, dry','NOODLES,JAPANESE,SOBA,DRY',20114,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Noodles, japanese, soba, cooked','NOODLES,JAPANESE,SOBA,CKD',20115,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Noodles, japanese, somen, dry','NOODLES,JAPANESE,SOMEN,DRY',20116,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Noodles, japanese, somen, cooked','NOODLES,JAPANESE,SOMEN,CKD',20117,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Noodles, flat, crunchy, Chinese restaurant','NOODLES,FLAT,CRUNCHY,CHINESE RESTAURANT',20118,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, dry, enriched','PASTA,DRY,ENR',20120,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, cooked, enriched, without added salt','PASTA,CKD,ENR,WO/ ADDED SALT',20121,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, whole-wheat, dry (Includes foods for USDA''s Food Distribution Program)','PASTA,WHOLE-WHEAT,DRY',20124,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, whole-wheat, cooked (Includes foods for USDA''s Food Distribution Program)','PASTA,WHOLE-WHEAT,CKD',20125,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Spaghetti, spinach, dry','SPAGHETTI,SPINACH,DRY',20126,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Spaghetti, spinach, cooked','SPAGHETTI,SPINACH,COOKED',20127,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flours, bread, unenriched','WHEAT FLOURS,BREAD,UNENR',20129,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Barley flour or meal','BARLEY FLOUR OR MEAL',20130,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Barley malt flour','BARLEY MALT FLR',20131,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Oat flour, partially debranned','OAT FLR,PART DEBRANNED',20132,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice noodles, dry','RICE NOODLES,DRY',20133,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice noodles, cooked','RICE NOODLES,CKD',20134,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, whole grain, 51% whole wheat, remaining unenriched semolina, dry','PASTA,WHL GRAIN,51% WHL WHEAT,REMAINING UNENR SEMOLINA,DRY',20135,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, whole grain, 51% whole wheat, remaining unenriched semolina, cooked','PASTA,WHL GRAIN,51% WHL WHEAT,REMAINING UNENR SEMOLINA,CKD',20136,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Quinoa, cooked','QUINOA,CKD',20137,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Spelt, uncooked','SPELT,UNCKD',20140,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Teff, uncooked','TEFF,UNCKD',20142,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Noodles, egg, cooked, enriched, with added salt','NOODLES,EGG,CKD,ENR,W/ SALT',20310,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Corn grain, white','CORN GRAIN,WHITE',20314,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Corn flour, whole-grain, white','CORN FLR,WHOLE-GRAIN,WHITE',20316,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Corn flour, yellow, masa, enriched','CORN FLR,YEL,MASA,ENR',20317,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Cornmeal, whole-grain, white','CORNMEAL,WHOLE-GRAIN,WHITE',20320,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, cooked, enriched, with added salt','PASTA,CKD,ENR,W/ ADDED SALT',20321,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Cornmeal, degermed, enriched, white','CORNMEAL,DEGERMED,ENR,WHITE',20322,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Cornmeal, white, self-rising, bolted, plain, enriched','CORNMEAL,WHITE,SELF-RISING,BOLTED,PLN,ENR',20323,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Cornmeal, white, self-rising, bolted, with wheat flour added, enriched','CORNMEAL,WHITE,SELF-RISING,BOLTED,W/ WHEAT FLR ADDED,ENR',20324,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Cornmeal, white, self-rising, degermed, enriched','CORNMEAL,WHITE,SELF-RISING,DEGERMED,ENR',20325,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Hominy, canned, yellow','HOMINY,CANNED,YELLOW',20330,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, long-grain, regular, cooked, enriched, with salt','RICE,WHITE,LONG-GRAIN,REG,CKD,ENR,W/SALT',20345,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white, all-purpose, enriched, calcium-fortified','WHEAT FLR,WHITE,ALL-PURPOSE,ENR,CALCIUM-FORTIFIED',20381,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Noodles, egg, dry, unenriched','NOODLES,EGG,DRY,UNENR',20409,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Noodles, egg, unenriched, cooked, without added salt','NOODLES,EGG,UNENR,CKD,WO/ ADDED SALT',20410,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, dry, unenriched','PASTA,DRY,UNENR',20420,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, cooked, unenriched, without added salt','PASTA,CKD,UNENR,WO/ ADDED SALT',20421,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Cornmeal, degermed, unenriched, yellow','CORNMEAL,DEGERMED,UNENR,YEL',20422,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, long-grain, regular, raw, unenriched','RICE,WHITE,LONG-GRAIN,REG,RAW,UNENR',20444,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, long-grain, regular, unenriched, cooked without salt','RICE,WHITE,LONG-GRAIN,REG,UNENR,CKD WO/ SALT',20445,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, long-grain, parboiled, unenriched, dry','RICE,WHITE,LONG-GRAIN,PARBLD,UNENR,DRY',20446,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, long-grain, parboiled, unenriched, cooked','RICE,WHITE,LONG-GRAIN,PARBLD,UNENR,CKD',20447,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, medium-grain, raw, unenriched','RICE,WHITE,MEDIUM-GRAIN,RAW,UNENR',20450,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, medium-grain, cooked, unenriched','RICE,WHITE,MEDIUM-GRAIN,CKD,UNENR',20451,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, short-grain, raw, unenriched','RICE,WHITE,SHORT-GRAIN,RAW,UNENR',20452,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, short-grain, cooked, unenriched','RICE,WHITE,SHORT-GRAIN,CKD,UNENR',20453,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Semolina, unenriched','SEMOLINA,UNENRICHED',20466,NULL,NULL,NULL,NULL,NULL,1,'1996-09-30','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white, all-purpose, unenriched','WHEAT FLR,WHITE,ALL-PURPOSE,UNENR',20481,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Noodles, egg, cooked, unenriched, with added salt','NOODLES,EGG,CKD,UNENR,W/ SALT',20510,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, cooked, unenriched, with added salt','PASTA,CKD,UNENR,W/ ADDED SALT',20521,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Cornmeal, degermed, unenriched, white','CORNMEAL,DEGERMED,UNENR,WHITE',20522,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Spaghetti, protein-fortified, cooked, enriched (n x 6.25)','SPAGHETTI,PROTEIN-FORTIFIED,CKD,ENR (N X 6.25)',20523,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Rice, white, long-grain, regular, cooked, unenriched, with salt','RICE,WHITE,LONG-GRAIN,REG,CKD,UNENR,W/SALT',20545,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white, all-purpose, enriched, unbleached','WHEAT FLR,WHITE,ALL-PURPOSE,ENR,UNBLEACHED',20581,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Spaghetti, protein-fortified, dry, enriched (n x 6.25)','SPAGHETTI,PROTEIN-FORTIFIED,DRY,ENR (N X 6.25)',20622,NULL,NULL,NULL,NULL,NULL,1,'1994-01-31','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white (industrial), 9% protein, bleached, enriched','WHEAT FLR,WHITE (INDUSTRIAL),9% PROT,BLEACHED,ENR',20623,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white (industrial), 9% protein, bleached, unenriched','WHEAT FLR,WHITE (INDUSTRIAL),9% PROT,BLEACHED,UNENR',20624,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white (industrial), 10% protein, bleached, enriched','WHEAT FLR,WHITE (INDUSTRIAL),10% PROT,BLEACHED,ENR',20628,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white (industrial), 10% protein, bleached, unenriched','WHEAT FLR,WHITE (INDUSTRIAL),10% PROT,BLEACHED,UNENR',20629,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white (industrial), 10% protein, unbleached, enriched','WHEAT FLR,WHITE (INDUSTRIAL),10% PROT,UNBLEACHED,ENR',20630,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white (industrial), 11.5% protein, bleached, enriched','WHEAT FLR,WHITE (INDUSTRIAL),11.5% PROT,BLEACHED,ENR',20634,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white (industrial), 11.5% protein, bleached, unenriched','WHEAT FLR,WHITE (INDUSTRIAL),11.5% PROT,BLEACHED,UNENR',20635,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white (industrial), 11.5% protein, unbleached, enriched','WHEAT FLR,WHITE (INDUSTRIAL),11.5% PROT,UNBLEACHED,ENR',20636,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white (industrial), 13% protein, bleached, enriched','WHEAT FLR,WHITE (INDUSTRIAL),13% PROT,BLEACHED,ENR',20640,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white (industrial), 13% protein, bleached, unenriched','WHEAT FLR,WHITE (INDUSTRIAL),13% PROT,BLEACHED,UNENR',20641,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white (industrial), 15% protein, bleached, enriched','WHEAT FLR,WHITE (INDUSTRIAL),15% PROT,BLEACHED,ENR',20645,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, white (industrial), 15% protein, bleached, unenriched','WHEAT FLR,WHITE (INDUSTRIAL),15% PROT,BLEACHED,UNENR',20646,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Millet flour','MILLET FLR',20647,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Sorghum flour, whole-grain','SORGHUM FLR,WHOLE-GRAIN',20648,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Wheat flour, whole-grain, soft wheat','WHEAT FLR,WHOLE-GRAIN,SOFT WHEAT',20649,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Sorghum flour, refined, unenriched','SORGHUM FLR,REFINED,UNENR',20650,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Pasta, whole grain, 51% whole wheat, remaining enriched semolina, dry (Includes foods for USDA''s Food Distribution Program)','PASTA,WHL GRAIN,51% WHL WHEAT,REMAINING ENR SEMOLINA,DRY',20653,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (21,'Pizza, cheese topping, regular crust, frozen, cooked','PIZZA,CHS TOPPING,REG CRUST,FRZ,CKD',21224,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (21,'Pizza, cheese topping, rising crust, frozen, cooked','PIZZA,CHS TOPPING,RISING CRUST,FRZ,CKD',21225,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (21,'Pizza, meat and vegetable topping, regular crust, frozen, cooked','PIZZA,MEAT & VEG TOPPING,REG CRUST,FRZ,CKD',21226,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (21,'Pizza, meat and vegetable topping, rising crust, frozen, cooked','PIZZA,MEAT & VEG TOPPING,RISING CRUST,FRZ,CKD',21227,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (21,'Light Ice Cream, soft serve, blended with milk chocolate candies','LIGHT ICE CRM,SOFT SERVE,BLENDED W/ MILK CHOC CANDIES',21412,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (21,'Light Ice Cream, soft serve, blended with cookie pieces','LIGHT ICE CRM,SOFT SERVE,BLENDED W/ COOKIE PIECES',21413,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (21,'Yogurt parfait, lowfat, with fruit and granola','YOGURT PARFAIT,LOWFAT,W/ FRUIT & GRANOLA',21463,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (21,'Pizza, cheese topping, thin crust, frozen, cooked','PIZZA,CHS TOPPING,THIN CRUST,FRZ,CKD',21505,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Macaroni and Cheese, canned entree','MACARONI & CHS,CND ENTREE',22247,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Spaghetti with meat sauce, frozen entree','SPAGHETTI W/ MEAT SAU,FRZ ENTREE',22401,NULL,NULL,NULL,NULL,NULL,1,'1997-08-29','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Beef macaroni with tomato sauce, frozen entree, reduced fat','BEEF MACARONI W/ TOMATO SAU,FRZ ENTREE,RED FAT',22402,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Pasta with Sliced Franks in Tomato Sauce, canned entree','PASTA W/SLICED FRANKS IN TOMATO SAU,CND ENTREE',22522,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Turkey Pot Pie, frozen entree','TURKEY POT PIE,FRZ ENTREE',22528,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Beef Pot Pie, frozen entree, prepared','BEEF POT PIE,FRZ ENTREE,PREP',22529,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Ravioli, cheese-filled, canned','RAVIOLI,CHEESE-FILLED,CND',22899,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Ravioli, meat-filled, with tomato sauce or meat sauce, canned','RAVIOLI,MEAT-FILLED,W/ TOMATO SAU OR MEAT SAU,CND',22900,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Tortellini, pasta with cheese filling, fresh-refrigerated, as purchased','TORTELLINI,PASTA W/ CHS FILLING,FRESH-REFRIGERATED',22901,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (21,'Pizza, meat topping, thick crust, frozen, cooked','PIZZA,MEAT TOPPING,THICK CRUST,FRZ,CKD',22902,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (21,'Pizza, pepperoni topping, regular crust, frozen, cooked','PIZZA,PEPPERONI TOPPING,REG CRUST,FRZ,CKD',22903,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chili con carne with beans, canned entree','CHILI CON CARNE W/BNS,CND ENTREE',22904,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Beef stew, canned entree','BEEF STEW,CANNED ENTREE',22905,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken pot pie, frozen entree, prepared','CHICKEN POT PIE,FRZ ENTREE,PREP',22906,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Lasagna, cheese, frozen, prepared','LASAGNA,CHS,FRZ,PREP',22910,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chili, no beans, canned entree','CHILI,NO BNS,CND ENTREE',22911,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Spaghetti, with meatballs in tomato sauce, canned','SPAGHETTI,W/ MEATBALLS IN TOMATO SAU,CND',22912,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Pasta with tomato sauce, no meat, canned','PASTA W/ TOMATO SAU,NO MEAT,CND',22914,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Lasagna with meat & sauce, low-fat, frozen entree','LASAGNA W/ MEAT & SAU,LOW-FAT,FRZ ENTREE',22915,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Lasagna with meat & sauce, frozen entree','LASAGNA W/ MEAT & SAU,FRZ ENTREE',22916,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Burrito, beef and bean, frozen','BURRITO,BF & BEAN,FRZ',22917,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Burrito, bean and cheese, frozen','BURRITO, BEAN AND CHEESE, FROZEN',22918,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Macaroni and Cheese, canned, microwavable','MACARONI & CHS,CND,MICROWAVABLE',22919,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Burrito, beef and bean, microwaved','BURRITO,BF & BEAN,MICROWAVED',22928,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Egg rolls, pork, refrigerated, heated','EGG ROLLS,PORK,REFR,HTD',22953,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Egg rolls, chicken, refrigerated, heated','EGG ROLLS,CHICK,REFR,HTD',22954,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Egg rolls, vegetable, frozen, prepared','EGG ROLLS,VEG,FRZ,PREP',22955,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Lasagna, Vegetable, frozen, baked','LASAGNA,VEG,FRZ,BKD',22956,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Turkey, stuffing, mashed potatoes w/gravy, assorted vegetables, frozen, microwaved','TKY,STUFFING,MSHD POTATO W/GRAVY,ASSORTED VEG,FRZ,MICROWAVE',22957,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Rice bowl with chicken, frozen entree, prepared (includes fried, teriyaki, and sweet and sour varieties)','RICE BOWL W/ CHICK,FRZ ENTREE,PREP',22958,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2009-01-25',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Macaroni and cheese dinner with dry sauce mix, boxed, uncooked','MACARONI & CHS DINNER W/ DRY SAU MIX,BOXED,UNCKD',22959,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Macaroni and cheese, dry mix, prepared with 2% milk and 80% stick margarine from dry mix','MAC & CHS,DRY MIX,PREP W/ 2% MILK & 80% STK MARGARINE DRY MX',22960,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chili with beans, microwavable bowls','CHILI W/ BNS,MICROWAVABLE BOWLS',22969,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Macaroni and cheese, frozen entree','MACARONI & CHS,FRZ ENTREE',22970,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Potato salad with egg','POTATO SALAD W/ EGG',22971,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Pulled pork in barbecue sauce','PULLED PORK IN BARBECUE SAU',22972,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Corn dogs, frozen, prepared','CORN DOGS,FRZ,PREP',22973,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken, nuggets, dark and white meat, precooked, frozen, not reheated','CHICKEN,NUGGETS,DK & WHITE MEAT,PRECKD,FRZ,NOT REHTD',22974,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken, nuggets, white meat, precooked, frozen, not reheated','CHICKEN,NUGGETS,WHITE MEAT,PRECKD,FRZ,NOT REHTD',22975,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Ravioli, cheese with tomato sauce, frozen, not prepared, includes regular and light entrees','RAVIOLI,CHS W/ TOMATO SAU,FRZ,NOT PREP,INCL REG & LT ENTREES',22976,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Lasagna with meat sauce, frozen, prepared','LASAGNA W/ MEAT SAU,FRZ,PREP',22977,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken tenders, breaded, frozen, prepared','CHICKEN TENDERS,BREADED,FRZ,PREP',22978,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Rice and vermicelli mix, chicken flavor, prepared with 80% margarine','RICE & VERMICELLI MIX,CHICK FLAVOR,PREP W/ 80% MARGARINE',22999,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder pot roast or steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,SHLDR POT RST OR STK,BNLS,LN & FAT,0" FAT,ALL GRDS,R',23000,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,SHRT LOIN,PRTRHS STEAK,LN&FAT,1/8"FAT,ALL GRDS,RAW',23001,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, grilled','BEEF,SHRT LN,PRTRHS STK,LN & FAT,1/8" FAT,ALL GRDS,CKD,GRLLD',23002,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,SHRT LOIN,PRTRHS STEAK,LN&FAT,1/8"FAT,SEL,RAW',23003,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, porterhouse steak, separable lean and fat, trimmed to 1/8" fat, select, cooked, grilled','BEEF,SHRT LOIN,PRTRHS STK,L & F,1/8" F,SEL,CKD,GRILLED',23004,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,SHRT LOIN,T-BONE STEAK,LN&FAT,1/8"FAT,ALL GRDS,RAW',23005,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, grilled','BEEF,SHRT LN,T-BNE STEK,LN & FAT,1/8" FAT,ALL GRDS,CKD,GRLLD',23006,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,SHRT LOIN,T-BONE STEAK,LN&FAT,1/8"FAT,SEL,RAW',23007,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, t-bone steak, separable lean and fat, trimmed to 1/8" fat, select, cooked, grilled','BEEF,SHRT LOIN,T-BONE STEAK,LN & FAT,1/8" FAT,SEL,CKD,GRLLD',23008,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, knuckle, tip side, steak, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,RND,KNUCKLE,TIP SIDE,STEAK,LN & FAT,0" FAT,CHOIC,RAW',23030,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, knuckle, tip side, steak, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BF,RND,KNUCKLE,TIP SIDE,STEAK,LN & FAT,0" FAT,CH,CKD,GRILLED',23031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, knuckle, tip side, steak, separable lean and fat , trimmed to 0" fat, select, raw','BEEF,RND,KNUCKLE,TIP SIDE,STEAK,LN & FAT 0" FAT,SEL,RAW',23032,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, knuckle, tip side, steak, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BF,RND,KNUCKLE,TIP SIDE,STEAK,LN & FAT,0" FAT,SE,CKD,GRILLED',23033,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, shoulder tender, medallion, separable lean and fat, trimmed to 0" fat, choice, raw','BF,CHK,CLOD,SHLDR TENDER,MEDALLION,LN & FAT,0" FAT,CHOIC,RAW',23034,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, shoulder tender, medallion, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BF,CHK,CLOD,SHDR TNDR,MED,LN & FAT,0" FAT,CH,CKD,GRILLED',23035,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, shoulder tender, medallion, separable lean and fat, trimmed to 0" fat, select, raw','BF,CHK,CLOD,SHLDR TENDER,MEDALLION,LN & FAT,0" FAT,SEL,RAW',23036,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, shoulder top and center steaks, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,CHUCK,SHLDR CLOD,TOP & CNTR ,STK,LN & FAT,0" FAT,CH,RAW',23037,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, shoulder top and center steaks, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BF,CHK,SHLDR CLOD,TOP & CNTR,STK,LN & FAT,0" FAT,CH,CKD,GRLD',23038,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, shoulder top and center steaks, separable lean and fat, trimmed to 0" fat, select, raw','BF,CHUCK,SHLDR CLOD, TOP & CNTR,STK,LN & FAT,0" FAT,SEL,RAW',23039,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, shoulder top and center steaks, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BF,CHK, CLOD,TOP & CNTR,STK,LN & FAT,0" FAT,SEL,CKD,GRLD',23040,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, top blade, steak, separable lean and fat, trimmed to 0" fat, choice, raw','BF,CHK,SHLDR CLOD,TOP BLADE,STEAK,LN & FAT,0" FAT,CHOIC,RAW',23041,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, top blade, steak, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BF,CHK,CLOD,TOP BLADE,STEAK,LN & FAT,0" FAT,CH,CKD,GRILLED',23042,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, top blade, steak, separable lean and fat, trimmed to 0" fat, select, raw','BF,CHUCK,SHLDR CLOD,TOP BLADE,STEAK,LN & FAT,0" FAT,SEL,RAW',23043,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, top blade, steak, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BF,CHK,CLOD,TOP BLADE,STEAK,LN & FAT,0" FAT,SEL,CKD,GRILLED',23044,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, knuckle, tip center, steak, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,RND,KNUCKLE,TIP CNTR,STEAK,LN & FAT,0" FAT,CHOIC,RAW',23045,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, knuckle, tip center, steak, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BF,RND,KNUCKLE,TIP CNTR,STK,LN & FAT,0" FAT,CHOIC,CKD,GRLD',23046,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, knuckle, tip center, steak, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,RND,KNUCKLE,TIP CNTR,STEAK,LN & FAT,0" FAT,SEL,RAW',23047,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, knuckle, tip center, steak, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BF,RND,KNUCKLE,TIP CNTR,STEAK,LN & FAT,0" FAT,SE,CKD,GRILLED',23048,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, outside round, bottom round, steak, separable lean and fat, trimmed to 0" fat, choice, raw','BF,RND,OUTSIDE RND,BTTM RND,STEAK,LN & FAT,0" FAT,CHOIC,RAW',23049,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, outside round, bottom round, steak, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BF,RND,OUT RND,BTTM RND,STK,LN & FAT,0" FAT,CH,CKD,GRILLED',23050,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, outside round, bottom round, steak, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,RND,OUTSIDE RND,BTTM RND,STEAK,LN & FAT,0" FAT,SEL,RAW',23051,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, outside round, bottom round, steak, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BEEF,RND,OUT RND,BTTM RND,STK,LN & FAT,0" FAT,SEL,CKD,GRLD',23052,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, shoulder tender, medallion, separable lean and fat, trimmed to 0" fat, all grades, raw','BF,CHK,CLD,SHLDR TNDR,MEDALLION,LN & FAT,0" FAT,ALL GRDS,RAW',23053,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, shoulder tender, medallion, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BF,CHK,CLD,SHDR TNDR,MED,LN & FAT,0" FAT,ALL GRDS,CK,GRLD',23054,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, knuckle, tip side, steak, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,RND,KNUCKLE,TIP SIDE,STEAK,LN & FAT,0" FAT,ALL GRDS,RAW',23055,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, knuckle, tip side, steak, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BF,RND,KNUCK,TIP SIDE,STK,LN & FAT,0" FAT,ALL GRDS,CKD,GRLD',23056,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, shoulder top and center steaks, separable lean and fat, trimmed to 0" fat, all grades, raw','BF,CHUCK,CLOD,TOP & CNTR,STEAK,LN & FAT,0" FAT,ALL GRDS,RAW',23057,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, shoulder top and center steaks, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BEEF,CHCK,CLOD,SHLDR TOP&CNTR STKS,LN & FT,0",ALL GRDS,GRLD',23058,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, top blade, steak, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,CHUCK,CLOD,TOP BLADE,STEAK,LN & FAT,0" FAT,ALL GRDS,RAW',23059,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, top blade, steak, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BF,CHUCK,CLOD,TOP BLADE,STK,LN & FAT,0" FAT,ALL,CKD,GRLD',23060,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, knuckle, tip center, steak, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,RND,KNUCKLE,TIP CNTR,STEAK,LN & FAT,0" FAT,ALL GRDS,RAW',23061,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, knuckle, tip center, steak, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BF,RND,KNUCKLE,TIP CNTR,STK,LN & FAT,0" FAT,ALL,CKD,GRLD',23062,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, outside round, bottom round, steak, separable lean and fat, trimmed to 0" fat, all grades, raw','BF,RND,OUTSIDE RND,BTTM RND,STEAK,LN & FAT,0" FAT,ALL,RAW',23063,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, outside round, bottom round, steak, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BF,RND,OUT RND,BTTM RND,STK,LN & FAT,0" FAT,ALL GRDS,CK,GRLD',23064,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, shoulder clod, shoulder tender, medallion, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BF,CHK, CLOD,SHLDR TENDER,MED,LN & FAT,0" FAT,SE,CKD,GRILLED',23065,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, short ribs, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,CHUCK,SHRT RIBS,BNLESS,LN,0" FAT,CHOIC,RAW',23066,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, short ribs, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,CHUCK,SHRT RIBS,BNLESS,LN,0" FAT,SEL,RAW',23067,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, short ribs, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,CHUCK,SHRT RIBS,BNLESS,LN,0" FAT,ALL GRDS,RAW',23068,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye Country-Style ribs, boneless, separable lean only, trimmed to 0" fat, choice, cooked, braised','BEEF,CHUCK EYE COUNTRY-STYLE RIBS,BNLESS,LN,0" FAT,CHOIC,CKD',23069,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye Country-Style ribs, boneless, separable lean only, trimmed to 0" fat, select, cooked, braised','BEEF,CHUCK EYE COUNTRY-STYLE RIBS,BNLESS,LN,0" FAT,SEL,CKD,B',23070,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye Country-Style ribs, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, braised','BF,CHK EYE CNTRY-STL RIBS,BNLS,LN,0" FAT,ALL GRDS, CKD, BRSD',23071,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye Country-Style ribs, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,CHUCK EYE COUNTRY-STYLE RIBS,BNLESS,LN,0" FAT,CHOIC,RAW',23072,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye Country-Style ribs, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,CHUCK EYE COUNTRY-STYLE RIBS,BNLESS,LN,0" FAT,SEL,RAW',23073,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye Country-Style ribs, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,CHK EYE COUNTRY-STYLE RIBS,BNLS,LN,0" FAT,ALL GRDS, RAW',23074,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye steak, boneless, separable lean only, trimmed to 0" fat, choice, cooked, grilled','BEEF,CHUCK EYE STEAK,BNLESS,LN,0" FAT,CHOIC,CKD,GRILLED',23075,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye steak, boneless, separable lean only, trimmed to 0" fat, select, cooked, grilled','BEEF,CHUCK EYE STEAK,BNLESS,LN,0" FAT,SEL,CKD,GRILLED',23076,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye steak, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, grilled','BEEF,CHUCK EYE STEAK,BNLESS,LN,0" FAT,ALL GRDS,CKD,GRILLED',23077,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye steak, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,CHUCK EYE STEAK,BNLESS,LN,0" FAT,CHOIC,RAW',23078,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye steak, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,CHUCK EYE STEAK,BNLESS,LN,0" FAT,SEL,RAW',23079,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye steak, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,CHUCK EYE STEAK,BNLESS,LN,0" FAT,ALL GRDS,RAW',23080,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder pot roast, boneless, separable lean only, trimmed to 0" fat, choice, cooked, braised','BEEF,SHLDR POT RST,BNLESS,LN,0" FAT,CHOIC,CKD,BRSD',23081,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder pot roast, boneless, separable lean only, trimmed to 0" fat, select, cooked, braised','BEEF,SHLDR POT RST,BNLESS,LN,0" FAT,SEL,CKD,BRSD',23082,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder pot roast, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, braised','BEEF,SHLDR POT RST,BNLESS,LN,0" FAT,ALL GRDS,CKD,BRSD',23083,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, boneless, separable lean only, trimmed to 0" fat, choice, cooked, braised','BEEF,CHUCK,MOCK TENDER STEAK,BNLESS,LN,0" FAT,CHOIC,CKD,BRSD',23084,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, boneless, separable lean only, trimmed to 0" fat, select, cooked, braised','BEEF,CHUCK,MOCK TENDER STEAK,BNLESS,LN,0" FAT,SEL,CKD,BRSD',23085,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, braised','BEEF,CHK,MOCK TENDER STK,BNLS,LN,0" FAT,ALL GRDS,CKD,BRSD',23086,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,CHUCK,MOCK TENDER STEAK,BNLESS,LN,0" FAT,CHOIC,RAW',23087,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,CHUCK,MOCK TENDER STEAK,BNLESS,LN,0" FAT,SEL,RAW',23088,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,CHUCK,MOCK TENDER STEAK,BNLESS,LN,0" FAT,ALL GRDS,RAW',23089,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck for stew, separable lean and fat, all grades, cooked, braised','BEEF,CHUCK FOR STEW,LN & FAT,ALL GRDS,CKD,BRSD',23090,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck for stew, separable lean and fat, select, cooked, braised','BEEF,CHUCK FOR STEW,LN & FAT,SEL,CKD,BRSD',23091,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck for stew, separable lean and fat, choice, cooked, braised','BEEF,CHUCK FOR STEW,LN & FAT,CHOIC,CKD,BRSD',23092,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck for stew, separable lean and fat, all grades, raw','BEEF,CHUCK FOR STEW,LN & FAT,ALL GRDS,RAW',23093,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck for stew, separable lean and fat, select, raw','BEEF,CHUCK FOR STEW,LN & FAT,SEL,RAW',23094,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck for stew, separable lean and fat, choice, raw','BEEF,CHUCK FOR STEW,LN & FAT,CHOIC,RAW',23095,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade steak, boneless, separable lean only, trimmed to 0" fat, choice, cooked, braised','BEEF,CHUCK,UNDER BLADE STEAK,BNLESS,LN,0" FAT,CHOIC,CKD,BRSD',23096,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade steak, boneless, separable lean only, trimmed to 0" fat, select, cooked, braised','BEEF,CHUCK,UNDER BLADE STEAK,BNLESS,LN,0" FAT,SEL,CKD,BRSD',23097,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade steak, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, braised','BEEF,CHUCK,UND BL STEAK,BNLS,LN,0" FAT,ALL GRDS,CKD,BRSD',23098,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade pot roast, boneless, separable lean and fat, trimmed to 0" fat, all grades, cooked, braised','BEEF,CHK,UND BLD, POT RST,BNL,LN & FAT,0" FAT,ALL GR,CKD,BR',23099,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip-on, separable lean only, trimmed to 1/8" fat, all grades, cooked, grilled','BEEF,RIB EYE STK,BNLES,LIP-ON,LN,1/8" FAT,ALL GRDS,CKD,GRLD',23100,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye roast, bone-in, lip-on, separable lean only, trimmed to 1/8" fat, choice, cooked, roasted','BEEF,RIB EYE RST,BONE-IN,LIP-ON,LN,1/8" FAT,CHOIC,CKD,RSTD',23101,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade pot roast or steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,CHK,UND BL POT RST/STK,BNL,LN & FT,0" FT, All GR, raw',23102,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade pot roast or steak, boneless, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,CHK,UND BL POT RST OR STK,BNL,LN & FAT,0" FAT, CH, RAW',23103,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade pot roast or steak, boneless, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,CHK,UND BL POT RST/STEAK,BNL,LN & FAT,0" FAT, SEL, RAW',23104,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade center steak, boneless, Denver Cut, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BEEF,CHK,UND BL CNTR STK,BNL,DEN CUT,LN & FAT, ALL GR, CKD',23105,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade center steak, boneless, Denver Cut, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BEEF,CHK,UND BLE CNTR STK,BNL,DEN CT,LN&FT, 0" FT,CH,CKD,GLD',23106,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade center steak, boneless, Denver Cut, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BEEF,CHK,UNDBL CNTR STK,BNL,DEN CT,LN&FAT, 0" FT,SEL,CKD,GLD',23107,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade center steak, boneless, Denver Cut, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,CHK,UND BL CNTR STK,BNL,DEN CUT,LN & FT,0"FT,All Gr, RW',23108,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade center steak, boneless, Denver Cut, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,CHK,UNDBLE CNTR STK,BNL,DENR CUT,LN & FAT,0"FAT, CH, RW',23109,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade center steak, boneless, Denver Cut, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,CHK,UND BLE CNTR STK,BNL,DEN CUT,LN & FT,0"FT, SEL,RW',23110,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder pot roast or steak, boneless, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,SHLDR POT RST OR STEAK,BNLESS,LN & FAT,0" FAT,CHOIC,RAW',23111,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder pot roast or steak, boneless, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,SHLDR POT RST OR STEAK,BNLESS,LN & FAT,0" FAT,SEL,RAW',23112,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye roast, boneless, America''s Beef Roast, separable lean and fat, trimmed to 0" fat, all grades, cooked, roasted','BEEF,CHK EYE RST,BNLS,A BF RST,LN & FAT,0",ALL GRD,CKD,RSTD',23113,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye roast, boneless, America''s Beef Roast, separable lean and fat, trimmed to 0" fat, choice, cooked, roasted','BEEF,CHK EYE RST,BNLS,A BF RST,LN & FAT,0",CH,CKD,RSTD',23114,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye roast, boneless, America''s Beef Roast, separable lean and fat, trimmed to 0" fat, select, cooked, roasted','BEEF,CHCK EYE RST,BNLS,A BF RST,LN & FAT,0",SEL,C,RSTD',23115,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, cooked, braised','BEEF,CHUCK,UNDER BLADE STEAK,BNLESS,LN & FAT,0" FAT,ALL GRDS',23116,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade steak, boneless, separable lean and fat, trimmed to 0" fat, choice, cooked, braised','BEEF,CHUCK,UNDER BLADE STEAK,BNLESS,LN & FAT,0" FAT,CHOIC,CK',23117,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, under blade steak, boneless, separable lean and fat, trimmed to 0" fat, select, cooked, braised','BEEF,CHUCK,UNDER BLADE STEAK,BNLESS,LN & FAT,0" FAT,SEL,CKD,',23118,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, cooked, braised','BEEF,CHK,MOCK TNDR STK,BNL,LN & FAT,0" FAT,ALL GRDS, CKD',23119,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, boneless, separable lean and fat, trimmed to 0" fat, choice, cooked, braised','BEEF,CHUCK,MOCK TENDER STEAK,BNLESS,LN & FAT,0" FAT,CHOIC,CK',23120,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, boneless, separable lean and fat, trimmed to 0" fat, select, cooked, braised','BEEF,CHUCK,MOCK TENDER STEAK,BNLESS,LN & FAT,0" FAT,SEL,CKD,',23121,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,CHK,MOCK TEN STK,BNL,LN & FAT,0" FAT,ALL GRDS, CKD',23122,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, boneless, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,CHK,MOCK TENDER STEAK,BNLESS,LN & FAT,0" FAT,CHOIC,RAW',23123,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, boneless, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,CHUCK,MOCK TENDER STEAK,BNLESS,LN & FAT,0" FAT,SEL,RAW',23124,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, short ribs, boneless, separable lean and fat, trimmed to 0" fat, all grades, cooked, braised','BEEF,CHUCK,SHRT RIBS,BNLESS,LN & FAT,0" FAT,ALL GRDS,CKD,BRS',23125,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, short ribs, boneless, separable lean and fat, trimmed to 0" fat, choice, cooked, braised','BEEF,CHUCK,SHRT RIBS,BNLESS,LN & FAT,0" FAT,CHOIC,CKD,BRSD',23126,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, short ribs, boneless, separable lean and fat, trimmed to 0" fat, select, cooked, braised','BEEF,CHUCK,SHRT RIBS,BNLESS,LN & FAT,0" FAT,SEL,CKD,BRSD',23127,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, short ribs, boneless, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,CHUCK,SHRT RIBS,BNLESS,LN & FAT,0" FAT,ALL GRDS,RAW',23128,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, short ribs, boneless, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,CHUCK,SHRT RIBS,BNLESS,LN & FAT,0" FAT,CHOIC,RAW',23129,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, short ribs, boneless, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,CHUCK,SHRT RIBS,BNLESS,LN & FAT,0" FAT,SEL,RAW',23130,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder pot roast, boneless, separable lean and fat, trimmed to 0" fat, all grades, cooked, braised','BEEF,SHLDR POT RST,BNLESS,LN & FAT,0" FAT,ALL GRDS,CKD,BRSD',23131,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder pot roast, boneless, separable lean and fat, trimmed to 0" fat, choice, cooked, braised','BEEF,SHLDR POT RST,BNLESS,LN & FAT,0" FAT,CHOIC,CKD,BRSD',23132,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder pot roast, boneless, separable lean and fat, trimmed to 0" fat, select, cooked, braised','BEEF,SHLDR POT RST,BNLESS,LN & FAT,0" FAT,SEL,CKD,BRSD',23133,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye Country-Style ribs, boneless, separable lean and fat, trimmed to 0" fat, all grades, cooked, braised','BEEF,CHK EYE CTRY-STYLE RIBS,BNL,LN & FAT,0" FAT,ALL GR, CKD',23134,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye Country-Style ribs, boneless, separable lean and fat, trimmed to 0" fat, choice, cooked, braised','BEEF,CHK EYE CNTRY-STYL RIBS,BNL,LN & FAT,0" FAT,CHOICE, CKD',23135,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye Country-Style ribs, boneless, separable lean and fat, trimmed to 0" fat, select, cooked, braised','BEEF,CHK EYE CNTRY-STYLE RIBS,BNL,LN & FAT,0" FAT,SEL, CKD',23136,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye Country-Style ribs, boneless, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,CHK EYE CNTRY-STYLE RIBS,BNL,LN & FAT,0" FAT,ALL GR,RAW',23137,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye Country-Style ribs, boneless, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,CHK EYE CNTRY-STYLE RIBS,BNL,LN & FAT,0" FAT,CHOICE,RAW',23138,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye Country-Style ribs, boneless, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,CHK EYE CNTRY-STYLE RIBS,BNL,LN & FAT,0" FAT,SEL,RAW',23139,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BEEF,CHUCK EYE STEAK,BNLESS,LN & FAT,0" FAT,ALL GRDS,CKD,GR',23140,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye steak, boneless, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BEEF,CHK EYE STEAK,BNLESS,LN & FAT,0" FAT,CHOIC,CKD,GRILLED',23141,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye steak, boneless, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BEEF,CHUCK EYE STEAK,BNLESS,LN & FAT,0" FAT,SEL,CKD,GRILLED',23142,NULL,NULL,NULL,NULL,NULL,1,'2011-01-18','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,CHUCK EYE STEAK,BNLESS,LN & FAT,0" FAT,ALL GRDS,RAW',23143,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye steak, boneless, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,CHUCK EYE STEAK,BNLESS,LN & FAT,0" FAT,CHOIC,RAW',23144,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck eye steak, boneless, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,CHUCK EYE STEAK,BNLESS,LN & FAT,0" FAT,SEL,RAW',23145,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye roast, bone-in, lip-on, separable lean only, trimmed to 1/8" fat, all grades, cooked, roasted','BEEF,RIB EYE RST,BNE-IN,LIP-ON,LN,1/8" FT,ALL GRDS,CKD,RSTD',23146,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye roast, bone-in, lip-on, separable lean only, trimmed to 1/8" fat, select, cooked, roasted','BEEF,RIB EYE RST,BONE-IN,LIP-ON,LN,1/8" FAT,SEL,CKD,RSTD',23147,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip-on, separable lean only, trimmed to 1/8" fat, choice, cooked, grilled','BEEF,RIB EYE STEAK,BNLES,LIP-ON,LN,1/8" FAT,CHOIC,CKD,GRILD',23148,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip-on, separable lean only, trimmed to 1/8" fat, select, cooked, grilled','BEEF,RIB EYE STEAK,BNLESS,LIP-ON,LN,1/8" FAT,SEL,CKD,GRILLED',23149,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak/roast, bone-in, lip-on, separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,RIB EYE STK/RST,BONE-IN,LIP-ON,LN,1/8" FAT,ALL GRDS,RAW',23150,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak/roast, bone-in, lip-on, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,RIB EYE STEAK/RST,BONE-IN,LIP-ON,LN,1/8" FAT,CHOIC,RAW',23151,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak/roast, bone-in, lip-on, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,RIB EYE STEAK/ROAST,BONE-IN,LIP-ON,LN,1/8" FAT,SEL,RAW',23152,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak/roast, boneless, lip-on, separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,RIB EYE STK/RST,BNLESS,LIP-ON,LN,1/8" FAT,ALL GRDS,RAW',23153,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak/roast, boneless, lip-on, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,RIB EYE STEAK/ROAST,BNLESS,LIP-ON,LN,1/8" FAT,CHOIC,RAW',23154,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak/roast, boneless, lip-on, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,RIB EYE STEAK/ROAST,BNLESS,LIP-ON,LN,1/8" FAT,SEL,RAW',23155,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, bone-in, lip-on, separable lean only, trimmed to 1/8" fat, all grades, cooked, grilled','BEEF,RIB EYE STK,BNE-IN,LIP-ON,LN,1/8" FAT,ALL GRDS,CKD,GRLD',23156,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, bone-in, lip-on, separable lean only, trimmed to 1/8" fat, choice, cooked, grilled','BEEF,RIB EYE STEAK,BONE-IN,LIP-ON,LN,1/8" FAT,CHOIC,CKD,GRLD',23157,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, bone-in, lip-on, separable lean only, trimmed to 1/8" fat, select, cooked, grilled','BEEF,RIB EYE STEAK,BONE-IN,LIP-ON,LN,1/8" FAT,SEL,CKD,GRILD',23158,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye roast, boneless, lip-on, separable lean only, trimmed to 1/8" fat, all grades, cooked, roasted','BEEF,RIB EYE RST,BNLESS,LIP-ON,LN,1/8" FAT,ALL GRDS,CKD,RSTD',23159,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye roast, boneless, lip-on, separable lean only, trimmed to 1/8" fat, choice, cooked, roasted','BEEF,RIB EYE RST,BNLESS,LIP-ON,LN,1/8" FAT,CHOIC,CKD,RSTD',23160,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye roast, boneless, lip-on, separable lean only, trimmed to 1/8" fat, select, cooked, roasted','BEEF,RIB EYE RST,BNLESS,LIP-ON,LN,1/8" FAT,SEL,CKD,RSTD',23161,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, inside skirt, separable lean only, trimmed to 0" fat, all grades, cooked, grilled','BEEF,PLATE STK,BNLE,INSDE SKRT,LN,0" FAT,ALL GRDS,CKD,GRLD',23162,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, inside skirt, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,PLATE STEAK,BNLESS,INSIDE SKIRT,LN,0" FAT,ALL GRDS,RAW',23163,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, inside skirt, separable lean only, trimmed to 0" fat, choice, cooked, grilled','BEEF,PLATE STK,BNLES,INSIDE SKIRT,LN,0" FAT,CHOIC,CKD,GRLD',23164,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, inside skirt, separable lean only, trimmed to 0" fat, choice, raw','BEEF,PLATE STEAK,BNLESS,INSIDE SKIRT,LN,0" FAT,CHOIC,RAW',23165,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, inside skirt, separable lean only, trimmed to 0" fat, select, cooked, grilled','BEEF,PLATE STEAK,BNLESS,INSIDE SKIRT,LN,0" FAT,SEL,CKD,GRILD',23166,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, inside skirt, separable lean only, trimmed to 0" fat, select, raw','BEEF,PLATE STEAK,BNLESS,INSIDE SKIRT,LN,0" FAT,SEL,RAW',23167,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, outside skirt, separable lean only, trimmed to 0" fat, all grades, cooked, grilled','BEEF,PLATE STK,BNLES,OTSDE SKIRT,LN,0" FAT,ALL GRDS,CKD,GRLD',23168,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, outside skirt, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,PLATE STEAK,BNLESS,OUTSIDE SKIRT,LN,0" FAT,ALL GRDS,RAW',23169,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, outside skirt, separable lean only, trimmed to 0" fat, choice, cooked, grilled','BEEF,PLATE STEAK,BNLS,OUTSIDE SKIRT,LN,0" FAT,CHOIC,CKD,GRLD',23170,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, outside skirt, separable lean only, trimmed to 0" fat, choice, raw','BEEF,PLATE STEAK,BNLESS,OUTSIDE SKIRT,LN,0" FAT,CHOIC,RAW',23171,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, outside skirt, separable lean only, trimmed to 0" fat, select, cooked, grilled','BEEF,PLATE STEAK,BNLESS,OUTSIDE SKIRT,LN,0" FAT,SEL,CKD,GRLD',23172,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, outside skirt, separable lean only, trimmed to 0" fat, select, raw','BEEF,PLATE STEAK,BNLESS,OUTSIDE SKIRT,LN,0" FAT,SEL,RAW',23173,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip off, separable lean only, trimmed to 0" fat, all grades, cooked, grilled','BEEF,RIB EYE STEAK,BNLESS,LIP OFF,LN,0" FAT,ALL GRDS,CKD,GRI',23174,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip off, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,RIB EYE STEAK,BNLESS,LIP OFF,LN,0" FAT,ALL GRDS,RAW',23175,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip off, separable lean only, trimmed to 0" fat, choice, cooked, grilled','BEEF,RIB EYE STEAK,BNLESS,LIP OFF,LN,0" FAT,CHOIC,CKD,GRILLE',23176,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip off, separable lean only, trimmed to 0" fat, choice, raw','BEEF,RIB EYE STEAK,BNLESS,LIP OFF,LN,0" FAT,CHOIC,RAW',23177,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip off, separable lean only, trimmed to 0" fat, select, cooked, grilled','BEEF,RIB EYE STEAK,BNLESS,LIP OFF,LN,0" FAT,SEL,CKD,GRILLED',23178,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip off, separable lean only, trimmed to 0" fat, select, raw','BEEF,RIB EYE STEAK,BNLESS,LIP OFF,LN,0" FAT,SEL,RAW',23179,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, back ribs, bone-in, separable lean only, trimmed to 0" fat, all grades, cooked, braised','BEEF,RIB,BACK RIBS,BONE-IN,LN,0" FAT,ALL GRDS,CKD,BRSD',23180,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, back ribs, bone-in, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,RIB,BACK RIBS,BONE-IN,LN,0" FAT,ALL GRDS,RAW',23181,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, back ribs, bone-in, separable lean only, trimmed to 0" fat, choice, cooked, braised','BEEF,RIB,BACK RIBS,BONE-IN,LN,0" FAT,CHOIC,CKD,BRSD',23182,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, back ribs, bone-in, separable lean only, trimmed to 0" fat, choice, raw','BEEF,RIB,BACK RIBS,BONE-IN,LN,0" FAT,CHOIC,RAW',23183,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, back ribs, bone-in, separable lean only, trimmed to 0" fat, select, cooked, braised','BEEF,RIB,BACK RIBS,BONE-IN,LN,0" FAT,SEL,CKD,BRSD',23184,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, back ribs, bone-in, separable lean only, trimmed to 0" fat, select, raw','BEEF,RIB,BACK RIBS,BONE-IN,LN,0" FAT,SEL,RAW',23185,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, bone-in, lip-on, separable lean and fat, trimmed to 1/8" fat, choice, cooked, grilled','BEEF,RIB EYE STK,BNE-IN,LIP-ON,LN & FT,1/8" FAT,CHOC,CKD,GRL',23186,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, bone-in, lip-on, separable lean and fat, trimmed to 1/8" fat, select, cooked, grilled','BEEF,RIB EYE STK,BNE-IN,LIP-ON,LN & FT,1/8" FAT,SEL,CKD,GRLD',23187,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, bone-in, lip-on, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, grilled','BEEF,RIB EYE STK,BN-IN,LIP-ON,LN & FT,1/8" FT,AL GDS,CKD,GRL',23188,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye roast, bone-in, lip-on, separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','BEEF,RIB EYE RST,BNE-IN,LIP-ON,LN & FAT,1/8" FT,CHC,CKD,RST',23189,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye roast, bone-in, lip-on, separable lean and fat, trimmed to 1/8" fat, select, cooked, roasted','BEEF,RIB EYE RST,BNE-IN,LIP-ON,LN & FAT,1/8" FAT,SEL,CKD,RST',23190,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye roast, bone-in, lip-on, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, roasted','BEEF,RIB EYE RST,BNE-IN,LP-ON,LN & FT,1/8" FT,AL GRD,CKD,RST',23191,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak/roast, bone-in, lip-on, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,RIB EYE STK/RST,BNE-IN,IP-ON,LN & FT,1/8" FT,AL GRDS,RW',23192,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak/roast, bone-in, lip-on, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,RIB EYE STK/RST,BNE-IN,LIP-ON,LN & FAT,1/8" FAT,CHC,RAW',23193,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak/roast, bone-in, lip-on, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,RIB EYE STK/RST,BONE-IN,LIP-ON,LN & FAT,1/8" FAT,SEL,RW',23194,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip-on, separable lean and fat, trimmed to 1/8" fat, choice, cooked, grilled','BEEF,RIB EYE STEAK,BNLS,LIP-ON,LN & FAT,1/8" FAT,CHC,CKD,GRD',23195,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip-on, separable lean and fat, trimmed to 1/8" fat, select, cooked, grilled','BEEF,RIB EYE STK,BNLS,LIP-ON,LN & FAT,1/8" FAT,SEL,CKD,GILD',23196,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip-on, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, grilled','BEEF,RIB EYE STK,BNLS,LIP-ON,LN & FT,1/8" FT,AL GRD,CKD,GRLD',23197,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye roast, boneless, lip-on, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, roasted','BEEF,RIB EYE RST,BNLS,LP-ON,LN & FT,1/8" FT,ALL GRD,CKD,RSTD',23198,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye roast, boneless, lip-on, separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','BEEF,RIB EYE RST,BNLES,LIP-ON,LN & FAT,1/8" FAT,CHC,CKD,RSTD',23199,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye roast, boneless, lip-on, separable lean and fat, trimmed to 1/8" fat, select, cooked, roasted','BEEF,RIB EYE RST,BNLES,LIP-ON,LN & FAT,1/8" FAT,SEL,CKD,RSTD',23200,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak/roast, boneless, lip-on, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,RIB EYE STK/RST,BNLS,LIP-ON,LN & FAT,1/8" FAT,AL GRD,RW',23201,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak/roast, boneless, lip-on, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,RIB EYE STEAK/ROST,BNLS,LIP-ON,LN & FAT,1/8" FAT,CHC,RW',23202,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak/roast, boneless, lip-on, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,RIB EYE STEAK/ROST,BNLS,LIP-ON,LN & FAT,1/8" FAT,SEL,RW',23213,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, inside skirt, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BEEF,PLTE STK,BNLS,INSD SKRT,LN & FAT,0" FAT,ALL GRD,CKD,GRL',23214,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, inside skirt, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BEEF,PLATE STK,BNLSS,INSDE SKRT,LN & FAT,0" FAT,CHC,CKD,GRLD',23215,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, inside skirt, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BEEF,PLATE STK,BNLES,INSDE SKRT,LN & FAT,0" FAT,SEL,CKD,GRLD',23216,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, inside skirt, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,PLATE STEK,BNLS,INSDE SKRT,LN & FAT,0" FAT,ALL GRDS,RW',23217,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, inside skirt, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,PLATE STEAK,BNLESS,INSIDE SKIRT,LN & FAT,0" FAT,CHOC,RW',23218,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, inside skirt, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,PLATE STEAK,BNLESS,INSIDE SKIRT,LN & FAT,0" FAT,SEL,RAW',23219,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, unspecified fat content, cooked','BEEF,GROUND,UNSPEC FAT CONTENT,CKD',23220,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, outside skirt, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BEEF,PLTE STK,BNLS,OUTSD SKRT,LN & FAT,0" FT,AL GRD,CKD,GRLD',23221,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, outside skirt, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BEEF,PLATE STK,BNLS,OUTSD SKRT,LN & FAT,0" FT,CHC,CKD,GRLD',23222,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, outside skirt, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BEEF,PLATE STK,BNLS,OTSDE SKRT,LN & FAT,0" FAT,SEL,CKD,GRILD',23223,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, outside skirt, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,PLATE STEK,BNLS,OUTSDE SKRT,LN & FAT,0" FAT,ALL GRDS,RW',23224,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, outside skirt, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,PLATE STEAK,BNLS,OUTSIDE SKRT,LN & FAT,0" FAT,CHOIC,RAW',23225,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate steak, boneless, outside skirt, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,PLATE STEAK,BNLESS,OUTSIDE SKIRT,LN & FAT,0" FAT,SEL,RW',23226,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip off, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BEEF,RIB EYE STK,BNLS,LIP OF,LN & FAT,0" FT,AL GRDS,CKD,GRLD',23227,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip off, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BEEF,RIB EYE STEAK,BNLS,LIP OFF,LN & FAT,0" FAT,CHC,CKD,GRLD',23228,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip off, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BEEF,RIB EYE STEK,BNLES,LIP OFF,LN & FAT,0" FAT,SEL,CKD,GRLD',23229,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip off, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,RIB EYE STEAK,BNLESS,LIP OFF,LN & FAT,0" FAT,ALL GRD,RW',23230,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip off, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,RIB EYE STEAK,BNLESS,LIP OFF,LN & FAT,0" FAT,CHOIC,RAW',23231,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib eye steak, boneless, lip off, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,RIB EYE STEAK,BNLESS,LIP OFF,LN & FAT,0" FAT,SEL,RAW',23232,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, back ribs, bone-in, separable lean and fat, trimmed to 0" fat, all grades, cooked, braised','BEEF,RIB,BACK RIBS,BONE-IN,LN & FAT,0" FAT,ALL GRDS,CKD,BRSD',23233,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, back ribs, bone-in, separable lean and fat, trimmed to 0" fat, choice, cooked, braised','BEEF,RIB,BACK RIBS,BONE-IN,LN & FAT,0" FAT,CHOIC,CKD,BRSD',23234,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, back ribs, bone-in, separable lean and fat, trimmed to 0" fat, select, cooked, braised','BEEF,RIB,BACK RIBS,BONE-IN,LN & FAT,0" FAT,SEL,CKD,BRSD',23235,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, back ribs, bone-in, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,RIB,BACK RIBS,BONE-IN,LN & FAT,0" FAT,ALL GRDS,RAW',23236,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, back ribs, bone-in, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,RIB,BACK RIBS,BONE-IN,LN & FAT,0" FAT,CHOIC,RAW',23237,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, back ribs, bone-in, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,RIB,BACK RIBS,BONE-IN,LN & FAT,0" FAT,SEL,RAW',23238,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin petite roast, boneless, separable lean only, trimmed to 0" fat, choice, cooked, roasted','BEEF,LOIN,TOP SIRLIN PETITE RST,BNLS,LN,0" FAT,CHOC,CKD,RSTD',23239,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin petite roast/filet, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,LOIN,TOP SIRLOIN PETITE RST/FILET,BNLS,LN,0" FAT,CHC,RW',23240,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin cap steak, boneless, separable lean only, trimmed to 1/8" fat, all grades, cooked, grilled','BEEF,LOIN,TOP SIRLN CAP STK,BNLS,LN,1/8" FAT,AL GRDS,CKD,GLD',23241,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin cap steak, boneless, separable lean only, trimmed to 1/8" fat, choice, cooked, grilled','BEEF,LOIN,TOP SIRLON CAP STK,BNLS,LN,1/8" FAT,CHOIC,CKD,GRLD',23242,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin cap steak, boneless, separable lean only, trimmed to 1/8" fat, select, cooked, grilled','BEEF,LOIN,TOP SIRLOIN CAP STEK,BNLS,LN,1/8" FAT,SEL,CKD,GRLD',23243,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin cap steak, boneless, separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,LOIN,TOP SIRLOIN CAP STEK,BNLS,LN,1/8" FAT,ALL GRDS,RAW',23244,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin cap steak, boneless, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,LOIN,TOP SIRLOIN CAP STEAK,BNLESS,LN,1/8" FAT,CHOIC,RAW',23245,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin cap steak, boneless, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,LOIN,TOP SIRLOIN CAP STEAK,BNLESS,LN,1/8" FAT,SEL,RAW',23246,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin filet, boneless, separable lean only, trimmed to 1/8" fat, all grades, cooked, grilled','BEEF,TOP LOIN FILET,BNLESS,LN,1/8" FAT,ALL GRDS,CKD,GRILLED',23247,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin filet, boneless, separable lean only, trimmed to 1/8" fat, choice, cooked, grilled','BEEF,TOP LOIN FILET,BNLESS,LN,1/8" FAT,CHOIC,CKD,GRILLED',23248,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin filet, boneless, separable lean only, trimmed to 1/8" fat, select, cooked, grilled','BEEF,TOP LOIN FILET,BNLESS,LN,1/8" FAT,SEL,CKD,GRILLED',23249,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin petite roast, boneless, separable lean only, trimmed to 1/8" fat, all grades, cooked, roasted','BEEF,TOP LOIN PETITE RST,BNLSS,LN,1/8" FAT,ALL GRDS,CKD,RSTD',23250,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin petite roast, boneless, separable lean only, trimmed to 1/8" fat, choice, cooked, roasted','BEEF,TOP LOIN PETITE RST,BNLESS,LN,1/8" FAT,CHOIC,CKD,RSTD',23251,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin petite roast, boneless, separable lean only, trimmed to 1/8" fat, select, cooked, roasted','BEEF,TOP LOIN PETITE RST,BNLESS,LN,1/8" FAT,SEL,CKD,RSTD',23252,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin petite roast/filet, boneless, separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,TOP LOIN PETITE RST/FILET,BNLS,LN,1/8" FAT,ALL GRDS,RAW',23253,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin petite roast/filet, boneless, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,TOP LOIN PETITE ROAST/FILET,BNLESS,LN,1/8" FAT,CHOC,RAW',23254,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin petite roast/filet, boneless, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,TOP LOIN PETITE ROAST/FILET,BNLESS,LN,1/8" FAT,SEL,RAW',23255,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin filet, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, grilled','BEEF,LOIN,TOP SIRLOIN FILET,BNLS,LN,0" FAT,ALL GRDS,CKD,GRLD',23256,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin filet, boneless, separable lean only, trimmed to 0" fat, choice, cooked, grilled','BEEF,LOIN,TOP SIRLOIN FILET,BNLESS,LN,0" FAT,CHOIC,CKD,GRILD',23257,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin filet, boneless, separable lean only, trimmed to 0" fat, select, cooked, grilled','BEEF,LOIN,TOP SIRLOIN FILET,BNLESS,LN,0" FAT,SEL,CKD,GRILLED',23258,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin petite roast, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, roasted','BEEF,LOIN,TOP SIRLON PTIT RST,BLS,LN,0" FAT,AL GRDS,CKD,RSTD',23259,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin petite roast, boneless, separable lean only, trimmed to 0" fat, select, cooked, roasted','BEEF,LOIN,TOP SIRLOIN PETITE RST,BNLS,LN,0" FAT,SEL,CKD,RSTD',23260,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin petite roast/filet, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,LOIN,TOP SRLN PETIT RST/FILT,BNLS,LN,0" FAT,AL GRDS,RAW',23261,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin petite roast/filet, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,LOIN,TOP SIRLON PETITE RST/FILET,BNLS,LN,0" FAT,SEL,RAW',23262,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ribeye  petite roast/filet, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,RIBEYE PETITE ROAST/FILET,BNLESS,LN,0" FAT,ALL GRDS,RAW',23263,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ribeye  petite roast/filet, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,RIBEYE PETITE ROAST/FILET,BNLESS,LN,0" FAT,CHOIC,RAW',23264,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ribeye  petite roast/filet, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,RIBEYE PETITE ROAST/FILET,BNLESS,LN,0" FAT,SEL,RAW',23265,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ribeye cap steak, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, grilled','BEEF,RIBEYE CAP STEAK,BNLESS,LN,0" FAT,ALL GRDS,CKD,GRILLED',23266,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ribeye cap steak, boneless, separable lean only, trimmed to 0" fat, choice, cooked, grilled','BEEF,RIBEYE CAP STEAK,BNLESS,LN,0" FAT,CHOIC,CKD,GRILLED',23267,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ribeye cap steak, boneless, separable lean only, trimmed to 0" fat, select, cooked, grilled','BEEF,RIBEYE CAP STEAK,BNLESS,LN,0" FAT,SEL,CKD,GRILLED',23268,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ribeye cap steak, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,RIBEYE CAP STEAK,BNLESS,LN,0" FAT,ALL GRDS,RAW',23269,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ribeye cap steak, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,RIBEYE CAP STEAK,BNLESS,LN,0" FAT,CHOIC,RAW',23270,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ribeye cap steak, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,RIBEYE CAP STEAK,BNLESS,LN,0" FAT,SEL,RAW',23271,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ribeye filet, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, grilled','BEEF,RIBEYE FILET,BNLESS,LN,0" FAT,ALL GRDS,CKD,GRILLED',23272,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ribeye filet, boneless, separable lean only, trimmed to 0" fat, choice, cooked, grilled','BEEF,RIBEYE FILET,BNLESS,LN,0" FAT,CHOIC,CKD,GRILLED',23273,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ribeye filet, boneless, separable lean only, trimmed to 0" fat, select, cooked, grilled','BEEF,RIBEYE FILET,BNLESS,LN,0" FAT,SEL,CKD,GRILLED',23274,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ribeye petite roast, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, roasted','BEEF,RIBEYE PETITE RST,BNLESS,LN,0" FAT,ALL GRDS,CKD,RSTD',23275,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ribeye petite roast, boneless, separable lean only, trimmed to 0" fat, choice, cooked, roasted','BEEF,RIBEYE PETITE RST,BNLESS,LN,0" FAT,CHOIC,CKD,RSTD',23276,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ribeye petite roast, boneless, separable lean only, trimmed to 0" fat, select, cooked, roasted','BEEF,RIBEYE PETITE RST,BNLESS,LN,0" FAT,SEL,CKD,RSTD',23277,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin cap steak, boneless, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, grilled','BEEF,LOIN,TOP SRL CP STK,BNLS,LN & FT,1/8" FT,ALGDS,CKD,GRLD',23278,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin cap steak, boneless, separable lean and fat, trimmed to 1/8" fat, choice, cooked, grilled','BEEF,LOIN,TOP SRLN CAP STK,BLS,LN & FAT,1/8" FAT,CHC,CKD,GLD',23279,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin cap steak, boneless, separable lean and fat, trimmed to 1/8" fat, select, cooked, grilled','BEEF,LOIN,TOP SRLN CAP STK,BLS,LN & FAT,1/8" FAT,SEL,CKD,GLD',23280,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin cap steak, boneless, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,LOIN,TOP SIRLN CAP STK,BNLS,LN & FAT,1/8" FAT,AL GDS,RW',23281,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin cap steak, boneless, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,LOIN,TOP SIRLOIN CAP STK,BNLS,LN & FAT,1/8" FAT,CHC,RAW',23282,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top sirloin cap steak, boneless, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,LOIN,TOP SIRLOIN CAP STK,BNLS,LN & FAT,1/8" FAT,SEL,RAW',23283,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin filet, boneless, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, grilled','BEEF,TOP LOIN FILET,BNLS,LN & FAT,1/8" FAT,ALL GRDS,CKD,GRLD',23284,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin filet, boneless, separable lean and fat, trimmed to 1/8" fat, choice, cooked, grilled','BEEF,TOP LOIN FILET,BNLESS,LN & FAT,1/8" FAT,CHOIC,CKD,GRILD',23285,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin filet, boneless, separable lean and fat, trimmed to 1/8" fat, select, cooked, grilled','BEEF,TOP LOIN FILET,BNLESS,LN & FAT,1/8" FAT,SEL,CKD,GRILLED',23286,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin petite roast, boneless, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, roasted','BEEF,TOP LOIN PET RST,BNLS,LN & FAT,1/8" FAT,AL GDS,CKD,RSTD',23287,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin petite roast, boneless, separable lean and fat, trimmed to 1/8" fat, choice, cooked, roasted','BEEF,TOP LOIN PETI RST,BNLS,LN & FAT,1/8" FAT,CHOIC,CKD,RSTD',23288,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin petite roast, boneless, separable lean and fat, trimmed to 1/8" fat, select, cooked, roasted','BEEF,TOP LOIN PETITE RST,BNLS,LN & FAT,1/8" FAT,SEL,CKD,RSTD',23289,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin petite roast/filet, boneless, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,TOP LOIN PETIT RST/FILT,BNS,LN & FAT,1/8" FAT,AL GRD,RW',23290,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin petite roast/filet, boneless, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,TOP LOIN PETITE RST/FILET,BNLS,LN & FAT,1/8" FAT,CHC,RW',23291,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top loin petite roast/filet, boneless, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,TOP LOIN PETITE RST/FILET,BNLS,LN & FAT,1/8" FAT,SEL,RW',23292,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, grass-fed, ground, 85% lean / 15% fat, raw','BEEF,AUSTRALIAN,IMP,GRASS-FED,GROUND,85% LN / 15% FAT,RAW',23293,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, grass-fed, loin, tenderloin steak/roast, boneless, separable lean only, raw','BEEF,AUS,IMP,GRSS-FED,LOIN,TENDERLN STK/RST,BNLESS,RAW',23294,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, loin, tenderloin steak/roast, boneless, separable lean only, Aust. marble score 4/5, raw','BEEF,AUS,IMP,WGU,TENLN STK/RST,BNLESS,LN,MRB SCR 4/5,RAW',23295,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, grass-fed,  external fat, raw','BEEF,AUSTRALIAN,IMP,GRASS-FED,EXTERNAL FAT,RAW',23296,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, grass-fed, seam fat, raw','BEEF,AUSTRALIAN,IMP,GRASS-FED,SEAM FAT,RAW',23297,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, external fat, Aust. marble score 4/5, raw','BEEF,AUS,IMP,WAGYU,EXTERNAL FAT,AUST. MARBLE SCORE 4/5,RAW',23298,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, seam fat, Aust. marble score 4/5, raw','BEEF,AUST,IMP,WAGYU,SEAM FAT,AUST. MARBLE SCORE 4/5,RAW',23299,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, external fat, Aust. marble score 9, raw','BEEF,AUST,IMP,WAGYU,EXTERNAL FAT,AUST. MARBLE SCORE 9,RAW',23300,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, seam fat, Aust. marble score 9, raw','BEEF,AUSTRALIAN,IMP,WAGYU,SEAM FAT,AUST. MARBLE SCORE 9,RAW',23301,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, grass-fed, loin, tenderloin steak/roast, boneless, separable lean and fat, raw','BEEF,AUS,IMP,GRSS-FED,TNDERLN STK/RST,BNLESS,LN&FAT,RAW',23302,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, grass-fed, loin, top loin steak/roast, boneless, separable lean only, raw','BEEF,AUS,IMP,GRSS-FED,TOP LOIN STK/RST,BNLESS,LN,RAW',23303,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, loin, tenderloin steak/roast, boneless, separable lean and fat, Aust. marble score 4/5, raw','BEEF,AU,IMP,WGU,TDLN STK/RST,BNLES,LN & FAT, MRB SCR 4/5,RAW',23304,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, grass-fed, loin, top loin steak/roast, boneless, separable lean and fat, raw','BEEF,AUS,IMP,GRSS-FED, TOP LOIN STK/RST,BNLESS,LN FAT,RAW',23305,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, grass-fed, loin, top sirloin cap-off steak/roast, boneless, separable lean only, raw','BEEF,AUS,IMP,GRSS-FD,TOP SIRLN CP-OFF STK/RST,BNLESS,LN,RAW',23306,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, grass-fed, rib, ribeye steak/roast lip-on, boneless, separable lean only, raw','BEEF,AUS,IMP,GRSS-FD,RIBEYE STK/RST LIP-ON,BNLESS,LN,RAW',23307,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, grass-fed, round, bottom round steak/roast, boneless, separable lean only, raw','BEEF,AUS,IMP,GRSS-FD,BTTM RND STK/RST,BNLESS,LN,RAW',23308,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, grass-fed, round, top round cap-off steak/roast, boneless, separable lean only, raw','BEEF,AUS,IMP,GRSS-FD,RD,TP RND CAP-OFF STK/RST,BNLESS,LN,RAW',23309,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, loin, tenderloin steak/roast, boneless, separable lean only, Aust. marble score 9, raw','BEEF,AUS,IMP,WGU,LOIN,TENLN STK/RST,BNLESS,LN, MRB SCR 9,RAW',23310,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, loin, top loin steak/roast, boneless, separable lean only, Aust. marble score 4/5, raw','BEEF,AUS,IMP,WGU,TOP LN STK/RST,BNLESS,LN,MRB SCR 4/5,RAW',23311,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, loin, top loin steak/roast, boneless, separable lean only, Aust. marble score 9, raw','BEEF,AUS,IMP,WGU,TP LN STK/RST,BNLESS,LN,MARBLE SCORE 9,RAW',23312,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, rib, small end rib steak/roast, boneless, separable lean only, Aust. marble score 4/5, raw','BEEF,AUS,IMP,WGU,SMLENDRIB STK/RST,BNLESS, MRB SCR 4/5,RAW',23313,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, rib, small end rib steak/roast, boneless, separable lean only, Aust. marble score 9, raw','BEEF,AUS,IMP,WGU,SML END RIB STK/RST,BNLESS,MRB SCR 9,RAW',23314,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, grass-fed, loin, top sirloin cap-off steak/roast, boneless, separable lean and fat, raw','BEEF,AUS,IMP,GRSS-FD,TP SIRLN CP-OFFSTK/RST,BNLES,LN&FAT,RAW',23315,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, grass-fed, rib, ribeye steak/roast lip-on, boneless, separable lean and fat, raw','BEEF,AUS,IMP,GRSS-FD,RBEYE STK/RST LIP-ON,BNLESS,LN&FAT,RAW',23316,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, grass-fed, round, bottom round steak/roast, boneless, separable lean and fat, raw','BEEF,AUS,IMP,GRSS-FED,BTTM RND STK/RST,BNLESS,LN&FAT,RAW',23317,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, grass-fed, round, top round cap-off steak/roast, boneless, separable lean and fat, raw','BEEF,AUS,IMP,GRSS-FD,TP RNDCAP-OFF STK/RST,BNLESS,LN&FAT,RAW',23318,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, loin, top loin steak/roast, boneless, separable lean and fat, Aust. marble score 4/5, raw','BEEF,AUS,IMP,WGU,TP LN STK/RST,BNLES,LN & FAT,MRB SCR4/5,RAW',23319,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, loin, top loin steak/roast, separable lean and fat, Aust. marble score 9, raw','BEEF,AUS,IMP,WGU,TP LN STK/RST,LN & FAT,MARBLE SCORE9,RAW',23320,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, rib, small end rib steak/roast, boneless, separable lean and fat, Aust. marble score 4/5, raw','BEEF,AUS,IMP,WGU,SMLEDRIB STK/RST,BNLES,LN&FAT,MRBSCR4/5,RAW',23321,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, rib, small end rib steak/roast, boneless, separable lean and fat, Aust. marble score 9, raw','BEEF,AUS,IMP,WGU,SMLEDRIB STK/RST,BNLESS,LN&FAT,MRB SCR9,RAW',23322,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, Australian, imported, Wagyu, loin, tenderloin steak/roast, boneless, separable lean and fat, Aust. marble score 9, raw','BEEF,AU,IMP,WGU,TNLN, STK/RST,BNLESS,LN & FAT, MRB SCR 9,RAW',23323,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,RND,TOP RND STEAK,BNLESS,LN & FAT,0" FAT,ALL GRDS,RAW',23324,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round steak, boneless, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,RND,TOP RND STEAK,BNLESS,LN & FAT,0" FAT,CHOIC,RAW',23325,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round steak, boneless, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,RND,TOP RND STEAK,BNLESS,LN & FAT,0" FAT,SEL,RAW',23326,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round roast, boneless, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,RND,TOP RND RST,BNLESS,LN & FAT,0" FAT,ALL GRDS,RAW',23327,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round roast, boneless, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,RND,TOP RND RST,BNLESS,LN & FAT,0" FAT,CHOIC,RAW',23328,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round roast, boneless, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,RND,TOP RND RST,BNLESS,LN & FAT,0" FAT,SEL,RAW',23329,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round roast, boneless, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,RND,EYE OF RND RST,BNLESS,LN & FAT,0" FAT,ALL GRDS,RAW',23330,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round roast, boneless, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,RND,EYE OF RND RST,BNLESS,LN & FAT,0" FAT,CHOIC,RAW',23331,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round roast, boneless, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,RND,EYE OF RND RST,BNLESS,LN & FAT,0" FAT,SEL,RAW',23332,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,RND,EYE OF RND STEAK,BNLESS,LN & FT,0" FAT,ALL GRDS,RAW',23333,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round steak, boneless separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,RND,EYE OF RND STEAK,BNLESS LN & FAT,0" FAT,CHOIC,RAW',23334,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round steak, boneless, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,RND,EYE OF RND STEAK,BNLESS,LN & FAT,0" FAT,SEL,RAW',23335,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin roast, boneless, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,LOIN,TENDERLOIN RST,BNLESS,LN & FAT,0" FAT,ALL GRDS,RAW',23336,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin roast, boneless, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,LOIN,TENDERLOIN RST,BNLESS,LN & FAT,0" FAT,CHOIC,RAW',23337,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin roast, boneless, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,LOIN,TENDERLOIN RST,BNLESS,LN & FAT,0" FAT,SEL,RAW',23338,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip off, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,LOIN,TOP LOIN STK,BNLS,LIP OFF,LN & FAT,0" FT,ALLGRD,RW',23339,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip off, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,LOIN,TOP LOIN STK,BNLS,LIP OFF,LN & FAT,0" FT,CHOIC,RAW',23340,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip off, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,LOIN,TOP LOIN STEAK,BNLS,LIP OFF,LN & FAT,0" FAT,SEL,RW',23341,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,LOIN,TENDERLOIN STEAK,BNLESS,L & F,0" FAT,ALL GRDS,RAW',23342,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin steak, boneless, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,LOIN,TENDERLOIN STEAK,BNLESS,LN & FAT,0" FAT,CHOIC,RAW',23343,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin steak, boneless, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,LOIN,TENDERLOIN STEAK,BNLESS,LN & FAT,0" FAT,SEL,RAW',23344,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin roast, boneless, separable lean and fat, trimmed to 0" fat, all grades, cooked, roasted','BEEF,LOIN,TNDRLN RST,BNLESS,L & F,0" FAT,ALL GRDS,CKD,RSTD',23345,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin roast, boneless, separable lean and fat, trimmed to 0" fat, choice, cooked, roasted','BEEF,LOIN,TENDERLOIN RST,BNLESS,L & F,0" FAT,CHOIC,CKD,RSTD',23346,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin roast, boneless, separable lean and fat, trimmed to 0" fat, select, cooked, roasted','BEEF,LOIN,TENDERLOIN RST,BNLESS,LN & FAT,0" FAT,SEL,CKD,RSTD',23347,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round roast, boneless, separable lean and fat, trimmed to 0" fat, all grades, cooked, roasted','BEEF,RND,TOP RND RST,BNLS,LN&FAT,0" FAT,ALLGRD,CKD,RSTD',23348,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round roast, boneless, separable lean and fat, trimmed to 0" fat, choice, cooked, roasted','BEEF,RND,TOP RND RST,BNLESS,LN & FAT,0" FAT,CHOIC,CKD,RSTD',23349,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round roast, boneless, separable lean and fat, trimmed to 0" fat, select, cooked, roasted','BEEF,RND,TOP RND RST,BNLESS,LN & FAT,0" FAT,SEL,CKD,RSTD',23350,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BEEF,RND,EYE OF RND STK,BNLESS,L & F,0" F,A GRDS,CKD,GRILLED',23351,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round steak, boneless, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BEEF,RND,EYE OF RD STEAK,BNLESS,L & F,0" FT,CHOIC,CK,GRLLED',23352,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round steak, boneless, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BEEF,RND,EYE OF RND STEAK,BNLS,LN & FAT,0" FAT,SEL,CKD,GRLD',23353,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round steak, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,RND,TOP RND STEAK,BNLESS,LN,0" FAT,ALL GRDS,RAW',23354,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round steak, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,RND,TOP RND STEAK,BNLESS,LN,0" FAT,CHOIC,RAW',23355,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round steak, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,RND,TOP RND STEAK,BNLESS,LN,0" FAT,SEL,RAW',23356,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round roast, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,RND,TOP RND RST,BNLESS,LN,0" FAT,ALL GRDS,RAW',23357,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round roast, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,RND,TOP RND RST,BNLESS,LN,0" FAT,CHOIC,RAW',23358,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round roast, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,RND,TOP RND RST,BNLESS,LN,0" FAT,SEL,RAW',23359,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round roast, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,RND,EYE OF RND RST,BNLESS,LN,0" FAT,ALL GRDS,RAW',23360,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round roast, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,RND,EYE OF RND RST,BNLESS,LN,0" FAT,CHOIC,RAW',23361,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round roast, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,RND,EYE OF RND RST,BNLESS,LN,0" FAT,SEL,RAW',23362,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round steak, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,RND,EYE OF RND STEAK,BNLESS,LN,0" FAT,ALL GRDS,RAW',23363,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round steak, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,RND,EYE OF RND STEAK,BNLESS,LN,0" FAT,CHOIC,RAW',23364,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round steak, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,RND,EYE OF RND STEAK,BNLESS,LN,0" FAT,SEL,RAW',23365,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin roast, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,LOIN,TENDERLOIN RST,BNLESS,LN,0" FAT,ALL GRDS,RAW',23366,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin roast, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,LOIN,TENDERLOIN RST,BNLESS,LN,0" FAT,CHOIC,RAW',23367,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin roast, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,LOIN,TENDERLOIN RST,BNLESS,LN,0" FAT,SEL,RAW',23368,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip off, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,LOIN,TOP LOIN STK,BNLS,LIP OFF,LN,0" FAT,ALL GRDS,RAW',23369,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip off, separable lean only, trimmed to 0" fat, choice, raw','BEEF,LOIN,TOP LOIN STEAK,BNLESS,LIP OFF,LN,0" FAT,CHOIC,RAW',23370,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip off, separable lean only, trimmed to 0" fat, select, raw','BEEF,LOIN,TOP LOIN STEAK,BNLESS,LIP OFF,LN,0" FAT,SEL,RAW',23371,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin steak, boneless, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,LOIN,TENDERLOIN STEAK,BNLESS,LN,0" FAT,ALL GRDS,RAW',23372,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin steak, boneless, separable lean only, trimmed to 0" fat, choice, raw','BEEF,LOIN,TENDERLOIN STEAK,BNLESS,LN,0" FAT,CHOIC,RAW',23373,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin steak, boneless, separable lean only, trimmed to 0" fat, select, raw','BEEF,LOIN,TENDERLOIN STEAK,BNLESS,LN,0" FAT,SEL,RAW',23374,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin roast, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, roasted','BEEF,LOIN,TENDERLOIN RST,BNLESS,LN,0" FAT,ALL GRDS,CKD,RSTD',23375,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin roast, boneless, separable lean only, trimmed to 0" fat, choice, cooked, roasted','BEEF,LOIN,TENDERLOIN RST,BNLESS,LN,0" FAT,CHOIC,CKD,RSTD',23376,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, tenderloin roast, separable lean only, boneless, trimmed to 0" fat, select, cooked, roasted','BEEF,LOIN,TENDERLOIN RST,LN,BNLESS,0" FAT,SEL,CKD,RSTD',23377,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round roast, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, roasted','BEEF,RND,TOP RND RST,BNLESS,LN,0" FAT,ALL GRDS,CKD,RSTD',23378,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round roast, boneless, separable lean only, trimmed to 0" fat, choice, cooked, roasted','BEEF,RND,TOP RND RST,BNLESS,LN,0" FAT,CHOIC,CKD,RSTD',23379,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round roast, boneless, separable lean only, trimmed to 0" fat, select, cooked, roasted','BEEF,RND,TOP RND RST,BNLESS,LN,0" FAT,SEL,CKD,RSTD',23380,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round steak, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, grilled','BEEF,RND,EYE OF RND STEAK,BNLESS,LN,0" FT,A GRDS,CKD,GRILLED',23381,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round steak, boneless, separable lean only, trimmed to 0" fat, choice, cooked, grilled','BEEF,RND,EYE OF RND STEAK,BNLESS,LN,0" FAT,CHOIC,CKD,GRILLED',23382,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round steak, boneless, separable lean only, trimmed to 0" fat, select, cooked, grilled','BEEF,RND,EYE OF RND STEAK,BNLESS,LN,0" FAT,SEL,CKD,GRILLED',23383,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip-on, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,LOIN,TOP LOIN STEAK,BNLESS,LIP-ON,LN,1/8" FAT,SEL,RAW',23384,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip-on, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,LOIN,TOP LOIN STEAK,BNLESS,LIP-ON,LN,1/8" FAT,CHOIC,RAW',23385,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip-on, separable lean only, trimmed to 1/8" fat, all grades, raw','Beef, ln, top ln stk, bneless lip-on, 1/8" fat all grdes raw',23386,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip-on, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,LN,TP LN STEAK,BNLESS,LIP-ON,LN & FAT,1/8" FAT,SEL,RAW',23387,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip-on, separable lean and fat, trimmed to 1/8" fat, all grades, raw','BEEF,LN,TP LN STK,BNLESS,LIPON,LN & FAT,1/8" FAT,ALL GRDS,RW',23388,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip-on, separable lean and fat, trimmed to 1/8" fat, choice, cooked, grilled','BEEF,LN,TP LN STK,BNLESS,LIPON,L & F,1/8" FAT,CHOIC,GRILLED',23389,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip-on, separable lean and fat, trimmed to 1/8" fat, select, cooked, grilled','BEEF,LN,TP LN STK,BNLESS,LIPON,L & F,1/8" FAT,SeL, CK GRLED',23390,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip-on, separable lean and fat, trimmed to 1/8" fat, all grades, cooked, grilled','BEEF,LN,TP LN STK,BNLESS,LIPON,L & F,1/8 FAT,A GRDS, GRILLED',23391,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip-on, separable lean only, trimmed to 1/8" fat, choice, cooked, grilled','BEEF,LON,TP LON STK,BNLSS,LIP-ON,LN,1/8" FAT,CHC,CKD,GRILLD',23392,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip-on, separable lean only, trimmed to 1/8" fat, select, cooked, grilled','BEEF,LN,TOP LN STK,BNLESS,LIP-ON,LN,1/8" FAT,SEL,CKD,GRILLD',23393,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip-on, separable lean only, trimmed to 1/8" fat, all grades, cooked, grilled','BEEF,LN,TOP LN STK,BNLSS,LIP-ON,LN,1/8" FAT,ALL GRDS,,GRLLD',23394,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, top loin steak, boneless, lip-on, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,LOIN,TP LN STK,BNLESS,LIP-ON,L&F,1/8" FAT,CHOIC,RAW',23395,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, bolar blade, separable lean only, cooked, fast roasted','BEEF,NZ,IMP,BOLAR BLADE,LN,CKD,FAST RSTD',23397,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, bolar blade, separable lean only, raw','BEEF,NZ,IMP,BOLAR BLADE,LN,RAW',23398,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, brisket navel end, separable lean only, cooked, braised','BEEF,NZ,IMP,BRISKET NAVEL END,LN,CKD,BRSD',23399,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, brisket navel end, separable lean only, raw','BEEF,NZ,IMP,BRISKET NAVEL END,LN,RAW',23401,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, brisket point end, separable lean only, cooked, braised','BEEF,NZ,IMP,BRISKET POINT END,LN,CKD,BRSD',23402,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, brisket point end, separable lean only, raw','BEEF,NZ,IMP,BRISKET POINT END,LN,RAW',23403,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, chuck eye roll, separable lean only, raw','BEEF,NZ,IMP,CHUCK EYE ROLL,LN,RAW',23404,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, chuck eye roll, separable lean only, cooked, braised','BEEF,NZ,IMP,CHUCK EYE ROLL,LN,CKD,BRSD',23405,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, cube roll, separable lean only, cooked, fast roasted','BEEF,NZ,IMP,CUBE ROLL,LN,CKD,FAST RSTD',23406,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, cube roll, separable lean only, raw','BEEF,NZ,IMP,CUBE ROLL,LN,RAW',23407,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, eye round, separable lean only, cooked, slow roasted','BEEF,NZ,IMP,EYE RND,LN,CKD,SLOW RSTD',23408,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, eye round, separable lean only, raw','BEEF,NZ,IMP,EYE RND,LN,RAW',23409,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, flank, separable lean only, cooked, braised','BEEF,NZ,IMP,FLANK,LN,CKD,BRSD',23410,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, flank, separable lean only, raw','BEEF,NZ,IMP,FLANK,LN,RAW',23411,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, flat, separable lean only, cooked, braised','BEEF,NZ,IMP,FLAT,LN,CKD,BRSD',23412,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, flat, separable lean only, raw','BEEF,NZ,IMP,FLAT,LN,RAW',23413,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, variety meats and by-products, heart, cooked, boiled','BEEF,NZ,IMP,VAR MEATS & BY-PRODUCTS,HEART,CKD,BLD',23414,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, variety meats and by-products, heart, raw','BEEF,NZ,IMP,VAR MEATS & BY-PRODUCTS,HEART,RAW',23415,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, hind shin, separable lean only, cooked, braised','BEEF,NZ,IMP,HIND SHIN,LN,CKD,BRSD',23416,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, hind shin, separable lean only, raw','BEEF,NZ,IMP,HIND SHIN,LN,RAW',23417,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, inside, raw','BEEF,NZ,IMP,INSIDE,RAW',23418,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, intermuscular fat, cooked','BEEF,NZ,IMP,INTERMUSCULAR FAT,CKD',23419,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, intermuscular fat, raw','BEEF,NZ,IMP,INTERMUSCULAR FAT,RAW',23420,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, variety meats and by-products, kidney, cooked, boiled','BEEF,NZ,IMP,VAR MEATS & BY-PRODUCTS,KIDNEY,CKD,BLD',23421,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, knuckle, cooked, fast fried','BEEF,NZ,IMP,KNUCKLE,CKD,FAST FRIED',23422,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, variety meats and by-products, kidney, raw','BEEF,NZ,IMP,VAR MEATS & BY-PRODUCTS,KIDNEY,RAW',23423,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, variety meats and by-products liver, cooked, boiled','BEEF,NZ,IMP,VAR MEATS & BY-PRODUCTS LIVER,CKD,BLD',23424,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, variety meats and by-products, liver, raw','BEEF,NZ,IMP,VAR MEATS & BY-PRODUCTS,LIVER,RAW',23425,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, manufacturing beef, cooked, boiled','BEEF,NZ,IMP,MANUFACTURING BF,CKD,BLD',23426,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, manufacturing beef, raw','BEEF,NZ,IMP,MANUFACTURING BF,RAW',23427,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, oyster blade, separable lean only, cooked, braised','BEEF,NZ,IMP,OYSTER BLADE,LN,CKD,BRSD',23428,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, oyster blade, separable lean only, raw','BEEF,NZ,IMP,OYSTER BLADE,LN,RAW',23429,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, ribs prepared, cooked, fast roasted','BEEF,NZ,IMP,RIBS PREP,CKD,FAST RSTD',23430,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, ribs prepared, raw','BEEF,NZ,IMP,RIBS PREP,RAW',23431,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, rump centre, separable lean only, cooked, fast fried','BEEF,NZ,IMP,RUMP CENTRE,LN,CKD,FAST FRIED',23432,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, striploin, separable lean only, cooked, fast fried','BEEF,NZ,IMP,STRIPLOIN,LN,CKD,FAST FRIED',23433,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, striploin, separable lean only, raw','BEEF,NZ,IMP,STRIPLOIN,LN,RAW',23434,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, subcutaneous fat, cooked','BEEF,NZ,IMP,SUBCUTANEOUS FAT,CKD',23435,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, subcutaneous fat, raw','BEEF,NZ,IMP,SUBCUTANEOUS FAT,RAW',23436,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, sweetbread, cooked, boiled','BEEF,NZ,IMP,SWEETBREAD,CKD,BLD',23437,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, sweetbread, raw','BEEF,NZ,IMP,SWEETBREAD,RAW',23438,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, tenderloin, separable lean only, cooked, fast fried','BEEF,NZ,IMP,TENDERLOIN,LN,CKD,FAST FRIED',23439,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, oyster blade, separable lean and fat, raw','BEEF,NZ,IMP,OYSTER BLADE,LN & FAT,RAW',23440,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, tenderloin, separable lean only, raw','BEEF,NZ,IMP,TENDERLOIN,LN,RAW',23441,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, variety meats and by-products, tongue, cooked, boiled','BEEF,NZ,IMP,VAR MEATS & BY-PRODUCTS,TONGUE,CKD,BLD',23442,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, variety meats and by-products, tongue, raw','BEEF,NZ,IMP,VAR MEATS & BY-PRODUCTS,TONGUE,RAW',23443,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, variety meats and by-products, tripe cooked, boiled','BEEF,NZ,IMP,VAR MEATS & BY-PRODUCTS,TRIPE CKD,BLD',23444,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, variety meats and by-products, tripe uncooked, raw','BEEF,NZ,IMP,VAR MEATS & BY-PRODUCTS,TRIPE UNCKD,RAW',23445,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, bolar blade, separable lean and fat, cooked, fast roasted','BEEF,NZ,IMP,BOLAR BLADE,LN & FAT,CKD,FAST RSTD',23446,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, bolar blade, separable lean and fat, raw','BEEF,NZ,IMP,BOLAR BLADE,LN & FAT,RAW',23447,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, brisket navel end, separable lean and fat, cooked, braised','BEEF,NZ,IMP,BRISKET NAVEL END,LN & FAT,CKD,BRSD',23448,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, brisket navel end, separable lean and fat, raw','BEEF,NZ,IMP,BRISKET NAVEL END,LN & FAT,RAW',23449,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, brisket point end, separable lean and fat, cooked, braised','BEEF,NZ,IMP,BRISKET POINT END,LN & FAT,CKD,BRSD',23450,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, brisket point end, separable lean and fat, raw','BEEF,NZ,IMP,BRISKET POINT END,LN & FAT,RAW',23451,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, chuck eye roll, separable lean and fat, cooked, braised','BEEF,NZ,IMP,CHUCK EYE ROLL,LN & FAT,CKD,BRSD',23452,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, chuck eye roll, separable lean and fat, raw','BEEF,NZ,IMP,CHUCK EYE ROLL,LN & FAT,RAW',23453,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, cube roll, separable lean and fat, cooked, fast roasted','BEEF,NZ,IMP,CUBE ROLL,LN & FAT,CKD,FAST RSTD',23454,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, cube roll, separable lean and fat, raw','BEEF,NZ,IMP,CUBE ROLL,LN & FAT,RAW',23455,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, eye round, separable lean and fat, cooked, slow roasted','BEEF,NZ,IMP,EYE RND,LN & FAT,CKD,SLOW RSTD',23456,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, eye round, separable lean and fat, raw','BEEF,NZ,IMP,EYE RND,LN & FAT,RAW',23457,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, flank, separable lean and fat, cooked, braised','BEEF,NZ,IMP,FLANK,LN & FAT,CKD,BRSD',23458,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, flank, separable lean and fat, raw','BEEF,NZ,IMP,FLANK,LN & FAT,RAW',23459,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, flat, separable lean and fat, cooked, braised','BEEF,NZ,IMP,FLAT,LN & FAT,CKD,BRSD',23460,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, flat, separable lean and fat, raw','BEEF,NZ,IMP,FLAT,LN & FAT,RAW',23461,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, hind shin, separable lean and fat, cooked, braised','BEEF,NZ,IMP,HIND SHIN,LN & FAT,CKD,BRSD',23462,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, hind shin, separable lean and fat, raw','BEEF,NZ,IMP,HIND SHIN,LN & FAT,RAW',23463,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, oyster blade, separable lean and fat, cooked, braised','BEEF,NZ,IMP,OYSTER BLADE,LN & FAT,CKD,BRSD',23464,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, rump centre, separable lean and fat, cooked, fast fried','BEEF,NZ,IMP,RUMP CENTRE,LN & FAT,CKD,FAST FRIED',23465,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, rump centre, separable lean only, raw','BEEF,NZ,IMP,RUMP CENTRE,LN,RAW',23466,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, rump centre, separable lean and fat, raw','BEEF,NZ,IMP,RUMP CENTRE,LN & FAT,RAW',23467,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, striploin, separable lean and fat, cooked, fast fried','BEEF,NZ,IMP,STRIPLOIN,LN & FAT,CKD,FAST FRIED',23468,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, striploin, separable lean and fat, raw','BEEF,NZ,IMP,STRIPLOIN,LN & FAT,RAW',23469,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, tenderloin, separable lean and fat, cooked, fast fried','BEEF,NZ,IMP,TENDERLOIN,LN & FAT,CKD,FAST FRIED',23470,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, New Zealand, imported, tenderloin, separable lean and fat, raw','BEEF,NZ,IMP,TENDERLOIN,LN & FAT,RAW',23471,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 93% lean meat / 7% fat, raw','BEEF,GROUND,93% LN MEAT / 7% FAT',23472,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 93% lean meat / 7% fat, patty, cooked, broiled','BEEF,GROUND,93% LN MEAT / 7% FAT,PATTY,CKD,BRLD',23473,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 93% lean meat /7% fat, patty, cooked, pan-broiled','BEEF,GROUND,93% LN MEAT /7% FAT,PATTY,CKD,PAN-BROILED',23474,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 93% lean meat / 7% fat, loaf, cooked, baked','BEEF,GROUND,93% LN MEAT / 7% FAT,LOAF,CKD,BKD',23475,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 93% lean meat / 7% fat, crumbles, cooked, pan-browned','BEEF,GROUND,93% LN MEAT / 7% FAT,CRUMBLES,CKD,PAN-BROWNED',23476,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 97% lean meat / 3% fat, raw','BEEF,GROUND,97% LN MEAT / 3% FAT,RAW',23477,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 97% lean meat / 3% fat, patty, cooked, broiled','BEEF,GROUND,97% LN MEAT / 3% FAT,PATTY,CKD,BRLD',23478,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 97% lean meat /3% fat, patty, cooked, pan-broiled','BEEF,GROUND,97% LN MEAT /3% FAT,PATTY,CKD,PAN-BROILED',23479,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 97% lean meat / 3% fat, loaf, cooked, baked','BEEF,GROUND,97% LN MEAT / 3% FAT,LOAF,CKD,BKD',23480,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 97% lean meat / 3% fat, crumbles, cooked, pan-browned','BEEF,GROUND,97% LN MEAT / 3% FAT,CRUMBLES,CKD,PAN-BROWNED',23481,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean and fat, trimmed to 0" fat, all grades, raw','BEEF,COMP OF RTL CUTS,LN & FAT,0" FAT,ALL GRDS,RAW',23482,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,COMP OF RTL CUTS,LN,1/8" FAT,ALL GRDS,RAW',23483,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean only, trimmed to 1/8" fat, all grades, cooked','BEEF,COMP OF RTL CUTS,LN,1/8" FAT,ALL GRDS,CKD',23484,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,COMP OF RTL CUTS,LN,0" FAT,ALL GRDS,RAW',23485,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,COMP OF RTL CUTS,LN,1/8" FAT,CHOIC,RAW',23490,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef composite, separable lean only, trimmed to 1/8" fat, choice, cooked','BEEF COMP,LN,1/8" FAT,CHOIC,CKD',23491,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean and fat, trimmed to 0" fat, choice, raw','BEEF,COMP OF RTL CUTS,LN & FAT,0" FAT,CHOIC,RAW',23494,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean only, trimmed to 0" fat, choice, raw','BEEF,COMP OF RTL CUTS,LN,0" FAT,CHOIC,RAW',23495,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean only, trimmed to 0" fat, select, raw','BEEF,COMP OF RTL CUTS,LN,0" FAT,SEL,RAW',23496,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean and fat, trimmed to 0" fat, select, raw','BEEF,COMP OF RTL CUTS,LN & FAT,0" FAT,SEL,RAW',23497,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean only, trimmed to 1/8" fat, select, cooked','BEEF,COMP OF RTL CUTS,LN,1/8" FAT,SEL,CKD',23498,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, composite of trimmed retail cuts, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,COMP OF RTL CUTS,LN,1/8" FAT,SEL,RAW',23499,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, separable lean only, trimmed to 0" fat, all grades, cooked, broiled','BEEF,CHUCK,MOCK TENDER STK,LN,0" FAT,ALL GRDS,CKD,BRLD',23509,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, top blade, separable lean only, trimmed to 0" fat, all grades, cooked, broiled','BEEF,CHUCK,TOP BLADE,LN ONLY,TO 0" FAT,ALL GRDS,CKD,BRLD',23511,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, clod roast, separable lean only, trimmed to 1/4" fat, all grades, raw','BEEF,CHUCK,CLOD RST,LN,1/4" FAT,ALL GRDS,RAW',23513,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, clod roast, separable lean only, trimmed to 0" fat, all grades, cooked, roasted','BEEF,CHUCK,CLOD RST,LN,0" FAT,ALL GRDS,CKD,RSTD',23514,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, clod roast, separable lean only, trimmed to 1/4" fat, all grades, cooked, roasted','BEEF,CHUCK,CLOD RST,LN ONLY,TO 1/4" FAT,ALL GRDS,CKD,RSTD',23515,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder steak, boneless, separable lean only, trimmed to 0" fat, all grades, cooked, grilled','BEEF,SHLDR STEAK,BNLESS,LN,0" FAT,ALL GRDS,CKD,GRILLED',23516,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, clod steak, separable lean only, trimmed to 1/4" fat, all grades, cooked, braised','BEEF,CHUCK,CLOD STEAK,LN ONLY,TO 1/4" FAT,ALL GRDS,CKD,BRSD',23517,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, separable lean and fat, trimmed to 0" fat, USDA choice, cooked, broiled','BEEF,CHCK,MCK TENDER STK,LN & FAT,0" FAT,USDA CHOIC,CKD,BRLD',23519,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, separable lean and fat, trimmed to 0" fat, USDA select, cooked, broiled','BEEF,CHUCK,MOCK TENDER STK,LN & FAT,0" FAT,USDA SEL,CKD,BRLD',23521,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, top blade, separable lean and fat, trimmed to 0" fat, choice, cooked, broiled','BEEF,CHUCK,TOP BLADE,LN & FAT,0" FAT,CHOIC,CKD,BRLD',23523,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, top blade, separable lean and fat, trimmed to 0" fat, select, cooked, broiled','BEEF,CHUCK,TOP BLADE,LN & FAT,0" FAT,SEL,CKD,BRLD',23525,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, clod roast, separable lean and fat, trimmed to 0" fat, choice, cooked, roasted','BEEF,CHUCK,CLOD RST,LN & FAT,0" FAT,CHOIC,CKD,RSTD',23528,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, clod roast, separable lean and fat, trimmed to 0" fat, select, cooked, roasted','BEEF,CHUCK,CLOD RST,LN & FAT,0" FAT,SEL,CKD,RSTD',23531,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder steak, boneless, separable lean and fat, trimmed to 0" fat, choice, cooked, grilled','BEEF,SHLDR STEAK,BNLESS,LN & FAT,0" FAT,CHOIC,CKD,GRILLED',23533,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder steak, boneless, separable lean and fat, trimmed to 0" fat, select, cooked, grilled','BEEF,SHLDR STEAK,BNLESS,LN & FAT,0" FAT,SEL,CKD,GRILLED',23536,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate, inside skirt steak, separable lean and fat, trimmed to 0" fat, all grades, cooked, broiled','BEEF,PLATE,SKIRT STEAK,LN & FAT,0" FAT,ALL GRDS,CKD,BRLD',23540,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, plate, outside skirt steak, separable lean and fat, trimmed to 0" fat, all grades, cooked, broiled','BEEF,PLATE,OUTSIDE SKIRT,LN & FAT,0" FAT,ALL GRDS,CKD,BRLD',23541,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, loin, bottom sirloin butt, tri-tip steak, separable lean and fat, trimmed to 0" fat, all grades, cooked, broiled','BEEF,SIRLOIN,TRI-TIP STK,LN & FAT,0" FAT,ALL GRDS,CKD,BRLD',23545,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, mock tender steak, separable lean and fat, trimmed to 0" fat, all grades, cooked, broiled','BEEF,CHUCK,MOCK TENDER STK,LN & FAT,0" FAT,ALL GRDS,CKD,BRLD',23547,NULL,NULL,NULL,NULL,NULL,1,'2006-02-24','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, top blade, separable lean and fat, trimmed to 0" fat, all grades, cooked, broiled','BEEF,CHUCK,TOP BLADE,LN & FAT,0" FAT,ALL GRDS,CKD,BRLD',23549,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, clod roast, separable lean and fat, trimmed to 0" fat, all grades, cooked, roasted','BEEF,CHUCK,CLOD RST,LN & FAT,0" FAT,ALL GRDS,CKD,RSTD',23552,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, shoulder steak, boneless, separable lean and fat, trimmed to 0" fat, all grades, cooked, grilled','BEEF,SHLDR STEAK,BNLESS,LN & FAT,0" FAT,ALL GRDS,CKD,GRILLED',23554,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 95% lean meat / 5% fat, raw','BEEF,GROUND,95% LN MEAT / 5% FAT,RAW',23557,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 95% lean meat / 5% fat, patty, cooked, broiled','BEEF,GROUND,95% LN MEAT / 5% FAT,PATTY,CKD,BRLD',23558,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 95% lean meat / 5% fat, patty, cooked, pan-broiled','BEEF,GROUND,95% LN MEAT / 5% FAT,PATTY,CKD,PAN-BROILED',23559,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 95% lean meat / 5% fat, crumbles, cooked, pan-browned','BEEF,GROUND,95% LN MEAT / 5% FAT,CRUMBLES,CKD,PAN-BROWNED',23560,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 95% lean meat / 5% fat, loaf, cooked, baked','BEEF,GROUND,95% LN MEAT / 5% FAT,LOAF,CKD,BKD',23561,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 90% lean meat / 10% fat, raw','BEEF,GROUND,90% LN MEAT / 10% FAT,RAW',23562,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 90% lean meat / 10% fat, patty, cooked, broiled','BEEF,GROUND,90% LN MEAT / 10% FAT,PATTY,CKD,BRLD',23563,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 90% lean meat / 10% fat, patty, cooked, pan-broiled','BEEF,GROUND,90% LN MEAT / 10% FAT,PATTY,CKD,PAN-BROILED',23564,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 90% lean meat / 10% fat, crumbles, cooked, pan-browned','BEEF,GROUND,90% LN MEAT / 10% FAT,CRUMBLES,CKD,PAN-BROWNED',23565,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 90% lean meat / 10% fat, loaf, cooked, baked','BEEF,GROUND,90% LN MEAT / 10% FAT,LOAF,CKD,BKD',23566,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 85% lean meat / 15% fat, raw (Includes foods for USDA''s Food Distribution Program)','BEEF,GROUND,85% LN MEAT / 15% FAT,RAW',23567,NULL,NULL,NULL,NULL,NULL,1,'2002-09-06','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 85% lean meat / 15% fat, patty, cooked, broiled','BEEF,GROUND,85% LN MEAT / 15% FAT,PATTY,CKD,BRLD',23568,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 85% lean meat / 15% fat, patty, cooked, pan-broiled','BEEF,GROUND,85% LN MEAT / 15% FAT,PATTY,CKD,PAN-BROILED',23569,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 85% lean meat / 15% fat, crumbles, cooked, pan-browned','BEEF,GROUND,85% LN MEAT / 15% FAT,CRUMBLES,CKD,PAN-BROWNED',23570,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 85% lean meat / 15% fat, loaf, cooked, baked','BEEF,GROUND,85% LN MEAT / 15% FAT,LOAF,CKD,BKD',23571,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 80% lean meat / 20% fat, raw','BEEF,GROUND,80% LN MEAT / 20% FAT,RAW',23572,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 80% lean meat / 20% fat, patty, cooked, broiled','BEEF,GROUND,80% LN MEAT / 20% FAT,PATTY,CKD,BRLD',23573,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 80% lean meat / 20% fat, patty, cooked, pan-broiled','BEEF,GROUND,80% LN MEAT / 20% FAT,PATTY,CKD,PAN-BROILED',23574,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 80% lean meat / 20% fat, crumbles, cooked, pan-browned','BEEF,GROUND,80% LN MEAT / 20% FAT,CRUMBLES,CKD,PAN-BROWNED',23575,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 80% lean meat / 20% fat, loaf, cooked, baked','BEEF,GROUND,80% LN MEAT / 20% FAT,LOAF,CKD,BKD',23576,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 75% lean meat / 25% fat, raw','BEEF,GROUND,75% LN MEAT / 25% FAT,RAW',23577,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 75% lean meat / 25% fat, patty, cooked, broiled','BEEF,GROUND,75% LN MEAT / 25% FAT,PATTY,CKD,BRLD',23578,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 75% lean meat / 25% fat, patty, cooked, pan-broiled','BEEF,GROUND,75% LN MEAT / 25% FAT,PATTY,CKD,PAN-BROILED',23579,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 75% lean meat / 25% fat, crumbles, cooked, pan-browned','BEEF,GROUND,75% LN MEAT / 25% FAT,CRUMBLES,CKD,PAN-BROWNED',23580,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, ground, 75% lean meat / 25% fat, loaf, cooked, baked','BEEF,GROUND,75% LN MEAT / 25% FAT,LOAF,CKD,BKD',23581,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean only, trimmed to 1/8" fat, select, raw','BEEF,RIB,SML END (RIBS 10-12),LN,1/8" FAT,SEL,RAW',23582,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, steak, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,TENDERLOIN,STEAK,LN,1/8" FAT,SEL,RAW',23583,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,TOP SIRLOIN,STEAK,LN,1/8" FAT,SEL,RAW',23584,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, top loin, steak, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,SHRT LOIN,TOP LOIN,STEAK,LN,1/8" FAT,SEL,RAW',23585,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean only, trimmed to 1/8" fat, select, cooked, broiled','BEEF,RIB,SML END (RIBS 10-12),LN,1/8" FAT,SEL,CKD,BRLD',23586,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, steak, separable lean only, trimmed to 1/8" fat, select, cooked, broiled','BEEF,TENDERLOIN,STEAK,LN,1/8" FAT,SEL,CKD,BRLD',23587,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean only, trimmed to 1/8" fat, select, cooked, broiled','BEEF,TOP SIRLOIN,STEAK,LN,1/8" FAT,SEL,CKD,BRLD',23588,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, top loin, steak, separable lean only, trimmed to 1/8" fat, select, cooked, grilled','BEEF,SHRT LOIN,TOP LOIN,STEAK,LN,1/8" FAT,SEL,CKD,GRILLED',23589,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round , roast, separable lean only, trimmed to 1/8" fat, select, cooked, roasted','BEEF,RND,BTTM RND RST,LN,1/8" FAT,SEL,CKD,RSTD',23590,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round, roast, separable lean only, trimmed to 1/8" fat, select, cooked, roasted','BEEF,RND,EYE OF RND,RST,LN,1/8" FAT,SEL,CKD,RSTD',23591,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, steak, separable lean only, trimmed to 1/8" fat, select, cooked, broiled','BEEF,RND,TOP RND,STEAK,LN,1/8" FAT,SEL,CKD,BRLD',23592,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, steak, separable lean only, trimmed to 1/8" fat, select, cooked, braised','BEEF,RND,BTTM RND,STEAK,LN,1/8" FAT,SEL,CKD,BRSD',23593,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, roast, separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,RND,BTTM RND,RST,LN,1/8" FAT,ALL GRDS,RAW',23594,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean only, trimmed to 1/8" fat, all grades, cooked, braised','BEEF,BRISKET,FLAT HALF,LN,1/8" FAT,ALL GRDS,CKD,BRSD',23595,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,BRISKET,FLAT HALF,LN,1/8" FAT,ALL GRDS,RAW',23596,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round, roast, separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,RND,EYE OF RND,RST,LN,1/8" FAT,ALL GRDS,RAW',23597,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round, roast, separable lean only, trimmed to 1/8" fat, all grades, cooked, roasted','BEEF,RND,EYE OF RND,RST,LN,1/8" FAT,ALL GRDS,CKD,RSTD',23598,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,RIB,SML END (RIBS 10-12),LN,1/8" FAT,ALL GRDS,RAW',23599,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, steak, separable lean only, trimmed to 1/8" fat, all grades, cooked, broiled','BEEF,TENDERLOIN,STEAK,LN,1/8" FAT,ALL GRDS,CKD,BRLD',23600,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, steak, separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,TENDERLOIN,STEAK,LN,1/8" FAT,ALL GRDS,RAW',23601,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean only, trimmed to 1/8" fat, all grades, cooked, braised','BEEF,CHUCK,ARM POT RST,LN,1/8" FAT,ALL GRDS,CKD,BRSD',23602,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,CHUCK,ARM POT RST,LN,1/8" FAT,ALL GRDS,RAW',23603,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, roast, separable lean only, trimmed to 1/8" fat, all grades, cooked','BEEF,RND,BTTM RND,RST,LN,1/8" FAT,ALL GRDS,CKD',23604,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, steak, separable lean only, trimmed to 1/8" fat, all grades, cooked, braised','BEEF,RND,BTTM RND,STEAK,LN,1/8" FAT,ALL GRDS,CKD,BRSD',23605,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, top loin, steak, separable lean only, trimmed to 1/8" fat, all grades, cooked, broiled','BEEF,SHRT LOIN,TOP LOIN,STEAK,LN,1/8" FAT,ALL GRDS,CKD,BRLD',23606,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, top loin steak, separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,SHRT LOIN,TOP LOIN STEAK,LN,1/8" FAT,ALL GRDS,RAW',23607,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, steak, separable lean only, trimmed to 1/8" fat, all grades, cooked, broiled','BEEF,RND,TOP RND,STEAK,LN,1/8" FAT,ALL GRDS,CKD,BRLD',23608,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, steak, separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,RND,TOP RND,STEAK,LN,1/8" FAT,ALL GRDS,RAW',23609,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean only, trimmed to 1/8" fat, all grades, cooked, broiled','BEEF,TOP SIRLOIN,STEAK,LN,1/8" FAT,ALL GRDS,CKD,BRLD',23610,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean only, trimmed to 1/8" fat, all grades, raw','BEEF,TOP SIRLOIN,STEAK,LN,1/8" FAT,ALL GRDS,RAW',23611,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,CHUCK,ARM POT RST,LN,1/8" FAT,CHOIC,RAW',23612,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,BRISKET,FLAT HALF,LN,1/8" FAT,CHOIC,RAW',23613,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean only, trimmed to 1/8" fat, choice, cooked, braised','BEEF,CHUCK,ARM POT RST,LN,1/8" FAT,CHOIC,CKD,BRSD',23614,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean only, trimmed to 1/8" fat, choice, cooked, braised','BEEF,BRISKET,FLAT HALF,LN,1/8" FAT,CHOIC,CKD,BRSD',23615,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round, roast, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,RND,EYE OF RND,RST,LN,1/8" FAT,CHOIC,RAW',23616,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, steak, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,RND,TOP RND,STEAK,LN,1/8" FAT,CHOIC,RAW',23617,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, roast, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,RND,BTTM RND,RST,LN,1/8" FAT,CHOIC,RAW',23618,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, roast, separable lean only, trimmed to 1/8" fat, choice, cooked, roasted','BEEF,RND,BTTM RND,RST,LN,1/8" FAT,CHOIC,CKD,RSTD',23619,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round, roast, separable lean only, trimmed to 1/8" fat, choice, cooked, roasted','BEEF,RND,EYE OF RND,RST,LN,1/8" FAT,CHOIC,CKD,RSTD',23620,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, steak, separable lean only, trimmed to 1/8" fat, choice, cooked, broiled','BEEF,RND,TOP RND,STEAK,LN,1/8" FAT,CHOIC,CKD,BRLD',23621,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, steak, separable lean only, trimmed to 1/8" fat, choice, cooked, braised','BEEF,RND,BTTM RND,STEAK,LN,1/8" FAT,CHOIC,CKD,BRSD',23622,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,RIB,SML END (RIBS 10-12),LN,1/8" FAT,CHOIC,RAW',23623,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, steak, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,TENDERLOIN,STEAK,LN,1/8" FAT,CHOIC,RAW',23624,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,TOP SIRLOIN,STEAK,LN,1/8" FAT,CHOIC,RAW',23625,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2011-01-18',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean only, trimmed to 1/8"fat, choice, cooked, broiled','BEEF,RIB,SML END (RIBS 10-12),LN,1/8"FAT,CHOIC,CKD,BRLD',23626,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, top loin, steak, separable lean only, trimmed to 1/8" fat, choice, raw','BEEF,SHRT LOIN,TOP LOIN,STEAK,LN,1/8" FAT,CHOIC,RAW',23627,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, tenderloin, steak, separable lean only, trimmed to 1/8" fat, choice, cooked, broiled','BEEF,TENDERLOIN,STEAK,LN,1/8" FAT,CHOIC,CKD,BRLD',23628,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, top sirloin, steak, separable lean only, trimmed to 1/8" fat, choice, cooked, broiled','BEEF,TOP SIRLOIN,STEAK,LN,1/8" FAT,CHOIC,CKD,BRLD',23629,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, short loin, top loin, steak, separable lean only, trimmed to 1/8" fat, choice, cooked, broiled','BEEF,SHRT LOIN,TOP LOIN,STEAK,LN,1/8" FAT,CHOIC,CKD,BRLD',23630,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,CHUCK,ARM POT RST,LN,1/8" FAT,SEL,RAW',23631,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,BRISKET,FLAT HALF,LN,1/8" FAT,SEL,RAW',23632,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, chuck, arm pot roast, separable lean only, trimmed to 1/8" fat, select, cooked, braised','BEEF,CHUCK,ARM POT RST,LN,1/8" FAT,SEL,CKD,BRSD',23633,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean only, trimmed to 1/8" fat, select, cooked, braised','BEEF,BRISKET,FLAT HALF,LN,1/8" FAT,SEL,CKD,BRSD',23634,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, eye of round, roast, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,RND,EYE OF RND,RST,LN,1/8" FAT,SEL,RAW',23635,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, top round, steak, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,RND,TOP RND,STEAK,LN,1/8" FAT,SEL,RAW',23636,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, bottom round, roast, separable lean only, trimmed to 1/8" fat, select, raw','BEEF,RND,BTTM RND,RST,LN,1/8" FAT,SEL,RAW',23637,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, rib, small end (ribs 10-12), separable lean only, trimmed to 1/8" fat, all grades, cooked, broiled','BEEF,RIB,SML END (RIBS 10-12),LN,1/8" FAT,ALL GRDS,CKD,BRLD',23638,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, variety meats and by-products, tripe, cooked, simmered','BEEF,VAR MEATS & BY-PRODUCTS,TRIPE,CKD,SIMMRD',23640,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, bottom sirloin, tri-tip roast, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,BTTM SIRLOIN,TRI-TIP RST,LN,0" FAT,ALL GRDS,RAW',23646,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, bottom sirloin, tri-tip roast, separable lean only, trimmed to 0" fat, choice, cooked, roasted','BEEF,BTTM SIRLOIN,TRI-TIP RST,LN,0" FAT,CHOIC,CKD,RSTD',23647,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, bottom sirloin, tri-tip roast, separable lean only, trimmed to 0" fat, choice, raw','BEEF,BTTM SIRLOIN,TRI-TIP RST,LN,0" FAT,CHOIC,RAW',23648,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, bottom sirloin, tri-tip roast, separable lean only, trimmed to 0" fat, select, cooked, roasted','BEEF,BTTM SIRLOIN,TRI-TIP RST,LN,0" FAT,SEL,CKD,RSTD',23649,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, bottom sirloin, tri-tip roast, separable lean only, trimmed to 0" fat, select, raw','BEEF,BTTM SIRLOIN,TRI-TIP RST,LN,0" FAT,SEL,RAW',23650,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, roast, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,RND,TIP RND,RST,LN,0" FAT,ALL GRDS,RAW',23651,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, roast, separable lean only, trimmed to 0" fat, choice, raw','BEEF,RND,TIP RND,RST,LN,0" FAT,CHOIC,RAW',23652,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, round, tip round, roast, separable lean only, trimmed to 0" fat, select, raw','BEEF,RND,TIP RND,RST,LN,0" FAT,SEL,RAW',23653,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, flank, steak, separable lean only, trimmed to 0" fat, all grades, cooked, broiled','BEEF,FLANK,STEAK,LN,0" FAT,ALL GRDS,CKD,BRLD',23654,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, flank, steak, separable lean only, trimmed to 0" fat, select, cooked, broiled','BEEF,FLANK,STEAK,LN,0" FAT,SEL,CKD,BRLD',23655,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, flank, steak, separable lean only, trimmed to 0" fat, all grades, raw','BEEF,FLANK,STEAK,LN,0" FAT,ALL GRDS,RAW',23656,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, flank, steak, separable lean only, trimmed to 0" fat, select, raw','BEEF,FLANK,STEAK,LN,0" FAT,SEL,RAW',23657,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean and fat, trimmed to 1/8" fat, choice, raw','BEEF,BRISKET,FLAT HALF,LN & FAT,1/8" FAT,CHOIC,RAW',23658,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean and fat, trimmed to 1/8" fat, select, raw','BEEF,BRISKET,FLAT HALF,LN & FAT,1/8" FAT,SEL,RAW',23659,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (13,'Beef, brisket, flat half, separable lean and fat, trimmed to 1/8" fat, choice, cooked, braised','BEEF,BRISKET,FLAT HALF,LN & FAT,1/8" FAT,CHOIC,CKD,BRSD',23660,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, popcorn, microwave, 94% fat free','POPCORN,OIL-POPPED,LOFAT',25000,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, popcorn, microwave, low fat','POPCORN,OIL-POPPED,LOFAT',25001,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, candy rolls, yogurt-covered, fruit flavored with high vitamin C','SNACKS,CANDY ROLLS,YOGURT-COVERED,FRUIT FLAV W/ HI VIT C',25003,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, sweet potato chips, unsalted','SNACKS,SWT POTATO CHIPS,UNSALTED',25012,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, popcorn, microwave, regular (butter) flavor, made with partially hydrogenated oil','SNACKS,POPCORN,MICROWAVE,REG (BUTTER) FLAVOR, W/PARHYD OIL',25014,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Pretzels, soft, unsalted','PRETZELS,SOFT,UNSALTED',25024,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2007-12-03',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, soy chips or crisps, salted','SNACKS,SOY CHIPS OR CRISPS,SALTED',25025,NULL,NULL,NULL,NULL,NULL,1,'2007-12-03','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Popcorn, microwave, regular (butter) flavor, made with palm oil','Popcor, microwav, regula (butter) flavo, mad with pal oil',25026,NULL,NULL,NULL,NULL,NULL,1,'2009-01-25','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, plantain chips, salted','SNACKS,PLANTAIN CHIPS,SALTED',25027,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Tortilla chips, yellow, plain, salted','Tortilla chips, yellow, plain, salted',25028,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bar, chewy, reduced sugar, all flavors','SNACKS,GRANOLA BAR,CHEWY,RED SUGAR,ALL FLAVORS',25035,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bites, mixed flavors','SNACKS,GRANOLA BITES,MXD FLAVORS',25036,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, pita chips, salted','SNACKS,PITA CHIPS,SALTED',25037,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bars, soft, almond, confectioners coating','SNACKS,GRANOLA BARS,SOFT,ALMOND,CONFECTIONERS COATING',25038,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, vegetable chips, made from garden vegetables','SNACKS,VEG CHIPS,MADE FROM GARDEN VEG',25040,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, candy bits, yogurt covered with vitamin C','SNACKS,CANDY BITS,YOGURT COVERED W/ VIT C',25043,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Formulated bar, high fiber, chewy, oats and chocolate','Formulated bar, high fiber, chewy, oats and chocolate',25045,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, bagel chips, plain','SNACKS,BAGEL CHIPS,PLN',25046,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, yucca (cassava) chips, salted','SNACKS,YUCCA (CASSAVA) CHIPS,SALTED',25050,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, brown rice chips','Snacks, brown rice chips',25059,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snack, Pretzel, hard chocolate coated','SNACK,PRETZEL,HARD CHOC COATD',25060,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snack, Mixed Berry Bar','Snack, Mixed Berry Bar',25062,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, made from dried potatoes (preformed), multigrain','Snacks, potato chips, fr dried potatoes, multigrain',25063,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, lightly salted','SNACKS,POTATO CHIPS,LIGHTLY SALTED',25064,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, Pretzels, gluten- free made with cornstarch and potato flour','SNACKS,PRETZELS,GLUTEN- FREE MADE W/ CORNSTARCH & POTATO FLR',25065,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, peas, roasted, wasabi-flavored','SNACKS,PEAS,RSTD,WASABI-FLAVORED',25066,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, shrimp cracker','SNACKS,SHRIMP CRACKER',25070,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Rice crackers','RICE CRACKERS',25071,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, ramen noodle, dry, any flavor, reduced fat, reduced sodium','SOUP,RAMEN NOODLE,DRY,ANY FLAVOR,RED FAT,RED NA',27035,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2010-01-04',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, clam chowder, new england, reduced sodium, canned, ready-to-serve','SOUP,CLAM CHOWDER,NEW ENGLAND,RED NA,CND,RTS',27043,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chicken noodle, reduced sodium, canned, ready-to-serve','SOUP,CHICK NOODLE,RED NA,CND,RTS',27044,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, duck, ready-to-serve','SAUCE,DUCK,RTS',27046,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, salsa, verde, ready-to-serve','SAUCE,SALSA,VERDE,RTS',27047,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, steak, tomato based','SAUCE,STEAK,TOMATO BSD',27048,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, tartar, ready-to-serve','SAUCE,TARTAR,RTS',27049,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, sweet and sour, ready-to-serve','SAUCE,SWT & SOUR,RTS',27050,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, cocktail, ready-to-serve','SAUCE,COCKTAIL,RTS',27051,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Dip, salsa con queso, cheese and salsa- medium','DIP,SALSA CON QUESO,CHS & SALSA- MED',27052,NULL,NULL,NULL,NULL,NULL,1,'2012-03-02','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, peanut, made from peanut butter, water, soy sauce','SAUCE,PNUT,MADE FROM PNUT BUTTER,H2O,SOY SAU',27059,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, chunky vegetable, reduced sodium, canned, ready-to-serve','SOUP,CHUNKY VEG,RED NA,CND,RTS',27060,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Soup, beef barley, ready to serve','SOUP,BF BARLEY,READY TO SERVE',27062,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, enchilada, red, mild, ready to serve','SAUCE,ENCHILADA,RED,MILD,READY TO SERVE',27063,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Wasabi','WASABI',27064,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Dip, bean, original flavor','DIP,BEAN,ORIGINAL FLAVOR',27065,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Sauce, horseradish','SAUCE,HORSERADISH',27066,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, chapati or roti, whole wheat, commercially prepared, frozen','BREAD,CHAPATI OR ROTI,WHL WHEAT,COMMLY PREP,FRZ',28285,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, paratha, whole wheat, commercially prepared, frozen','BREAD,PARATHA,WHL WHEAT,COMMLY PREP,FRZ',28286,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, naan, whole wheat, commercially prepared, refrigerated','BREAD,NAAN,WHL WHEAT,COMMLY PREP,REFR',28287,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, roll, Mexican, bollilo','BREAD,ROLL,MEXICAN,BOLLILO',28288,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookie, vanilla with caramel, coconut, and chocolate coating','COOKIE,VANILLA W/ CARAMEL,COCNT,& CHOC COATING',28289,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookie, with peanut butter filling, chocolate-coated','COOKIE,W/ PNUT BUTTER FILLING,CHOCOLATE-COATED',28290,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, animal, with frosting or icing','COOKIES,ANIMAL,W/ FRSTNG OR ICING',28291,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, multigrain','CRACKERS,MULTIGRAIN',28292,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookie, butter or sugar, with chocolate icing or filling','COOKIE,BUTTER OR SUGAR,W/ CHOC ICING OR FILLING',28293,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookie, chocolate, with icing or coating','COOKIE,CHOC,W/ ICING OR COATING',28294,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Tortillas, ready-to-bake or -fry, whole wheat','TORTILLAS,RTB OR -FRY,WHL WHEAT',28295,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, snack cakes, creme-filled, chocolate with frosting, low-fat, with added fiber','CAKE,SNK CAKES,CREME-FILLED,CHOC W/ FRSTNG,L-F,W/ ADD FIBER',28296,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cake, snack cakes, not chocolate, with icing or filling, low-fat, with added fiber','CAKE,SNK CAKES,NOT CHOC,W/ ICING OR FILLING,L-F,W/ ADD FIBER',28297,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, brownies, commercially prepared, reduced fat, with added fiber','COOKIES,BROWNIES,COMMLY PREP,RED FAT,W/ ADDED FIBER',28298,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate sandwich, with creme filling, reduced fat','COOKIES,CHOC SNDWCH,W/ CREME FILLING,RED FAT',28299,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, oatmeal sandwich, with creme filling','COOKIES,OATMEAL SNDWCH,W/ CREME FILLING',28300,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, peanut butter, commercially prepared, sugar free','COOKIES,PNUT BUTTER,COMMLY PREP,SUGAR FREE',28301,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, graham crackers, plain or honey, lowfat','COOKIES,GRAHAM CRACKERS,PLN OR HONEY,LOWFAT',28302,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, cheese, whole grain','CRACKERS,CHS,WHL GRAIN',28303,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Waffles, whole wheat, lowfat, frozen, ready-to-heat','WAFFLES,WHL WHEAT,LOWFAT,FRZ,RTH',28304,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes, plain, reduced fat','PANCAKES,PLN,RED FAT',28305,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, chapati or roti, plain, commercially prepared','BREAD,CHAPATI OR ROTI,PLN,COMMLY PREP',28306,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, naan, plain, commercially prepared, refrigerated','BREAD,NAAN,PLN,COMMLY PREP,REFR',28307,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, standard snack-type, with whole wheat','CRACKERS,STD SNACK-TYPE,W/ WHL WHEAT',28308,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, coconut macaroon','COOKIES,COCNT MACAROON',28309,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, shortbread, reduced fat','COOKIES,SHORTBREAD,RED FAT',28310,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, sugar wafer, chocolate-covered','COOKIES,SUGAR WAFER,CHOCOLATE-COVERED',28311,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, hamburger or hot dog, wheat/cracked wheat','ROLLS,HAMBURGER OR HOT DOG,WHEAT/CRACKED WHEAT',28312,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, hamburger or hot dog, whole wheat','ROLLS,HAMBURGER OR HOT DOG,WHL WHEAT',28313,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, sandwich-type, peanut butter filled, reduced fat','CRACKERS,SANDWICH-TYPE,PNUT BUTTER FILLED,RED FAT',28314,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, cinnamon','BREAD,CINN',28315,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, wheat, sprouted','BREAD,WHEAT,SPROUTED',28316,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, wheat, sprouted, toasted','BREAD,WHEAT,SPROUTED,TSTD',28317,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, french or vienna, whole wheat','BREAD,FRENCH OR VIENNA,WHL WHEAT',28318,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bagels, whole grain white','BAGELS,WHL GRAIN WHITE',28319,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'English muffins, whole grain white','ENGLISH MUFFINS,WHL GRAIN WHITE',28320,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, hamburger, whole grain white, calcium-fortified','ROLLS,HAMBURGER,WHL GRAIN WHITE,CALCIUM-FORTIFIED',28321,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bagels, multigrain','BAGELS,MULTIGRAIN',28322,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes, whole wheat, dry mix, incomplete','PANCAKES,WHL WHEAT,DRY MIX,INCOMPLETE',28324,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, toast thins, low sodium','CRACKERS,TOAST THINS,LO NA',28325,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, whole grain, sandwich-type, with peanut butter filling','CRACKERS,WHL GRAIN,SANDWICH-TYPE,W/ PNUT BUTTER FILLING',28326,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, water biscuits','CRACKERS,H2O BISCUITS',28327,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate chip sandwich, with creme filling','COOKIES,CHOC CHIP SNDWCH,W/ CREME FILLING',28328,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate, made with rice cereal','COOKIES,CHOC,MADE W/ RICE CRL',28329,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, marshmallow, with rice cereal and chocolate chips','COOKIES,MARSHMLLW,W/ RICE CRL & CHOC CHIPS',28330,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, flavored, fish-shaped','CRACKERS,FLAV,FISH-SHAPED',28331,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, gluten-free, chocolate sandwich, with creme filling','COOKIES,GLUTEN-FREE,CHOC SNDWCH,W/ CREME FILLING',28332,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, gluten-free, chocolate wafer','COOKIES,GLUTEN-FREE,CHOC WAFER',28333,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, gluten-free, lemon wafer','COOKIES,GLUTEN-FREE,LEMON WAFER',28334,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, gluten-free, vanilla sandwich, with creme filling','COOKIES,GLUTEN-FREE,VANILLA SNDWCH,W/ CREME FILLING',28335,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, gluten-free, white, made with potato extract, rice starch, and rice flour','BREAD,GLUTEN-FREE,POTATO EXTRACT,RICE STARCH,& RICE FLOUR',28336,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, gluten-free, white, made with rice flour, corn starch, and/or tapioca','BREAD,GLUTEN-FREE,RICE FLOUR,CORN STARCH,AND/OR TAPIOCA',28337,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, gluten-free, white, made with tapioca starch and brown rice flour','BRD,GLUTEN-FREE,WHITE,MADE W/TAPIOCA STARCH & BRWN RICE FLR',28338,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, gluten-free, whole grain, made with tapioca starch and brown rice flour','BREAD,GLUTEN-FREE,WHL GRAIN,TAPIOCA STARCH & BROWN RICE FLR',28339,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, gluten-free, white, made with rice flour, rice starch, and corn starch','ROLLS,GLUTEN-FREE,RICE FLR,RICE STARCH,& CORN STARCH',28341,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, gluten-free, whole grain, made with tapioca starch and brown rice flour','ROLLS,GLUTEN-FREE,WHL GRAIN,TAPIOCA STARCH & BROWN RICE FLR',28343,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, gluten-free, multigrain and vegetable, made with corn starch and white rice flour','CRACKERS,GLUTEN-FREE,MULTIGRAIN & VEG,MADE W/ CORN STARCH &',28344,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Crackers, gluten-free, multi-seeded and multigrain','CRACKERS,GLUTEN-FREE,MULTI-SEEDED & MULTIGRAIN',28345,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Waffles, gluten-free, frozen, ready-to-heat','WAFFLES,GLUTEN-FREE,FRZ,RTH',28346,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes, gluten-free, frozen, ready-to-heat','PANCAKES,GLUTEN-FREE,FRZ,RTH',28347,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, dinner, sweet','ROLLS,DINNER,SWT',28348,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, oatmeal, reduced fat','COOKIES,OATMEAL,RED FAT',28349,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, chocolate cream covered biscuit sticks','COOKIES,CHOC CRM COVERED BISCUIT STKS',28350,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, Marie biscuit','COOKIES,MARIE BISCUIT',28351,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, vanilla sandwich with creme filling, reduced fat','COOKIES,VANILLA SNDWCH W/ CREME FILLING,RED FAT',28352,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Bread, multi-grain (includes whole-grain)','BREAD,MULTI-GRAIN (INCLUDES WHOLE-GRAIN)',28397,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cookies, animal crackers (includes arrowroot, tea biscuits)','COOKIES,ANIMAL CRACKERS (INCL ARROWROOT,TEA BISCUITS,)',28399,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, hash brown, refrigerated, prepared, pan-fried in canola oil','POTATOES,HASH BROWN,REFR,PREP,PAN-FRIED IN CANOLA OIL',31022,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet Potatoes, french fried, frozen as packaged, salt added in processing','SWEET POTATOES,FRENCH FR,FRZ AS PACKAGED,SALT ADDED',31023,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet Potatoes, french fried, crosscut, frozen, unprepared','SWEET POTATOES,FRENCH FR,CROSSCUT,FRZ,UNPREP',31024,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet Potato puffs, frozen, unprepared','SWEET POTATO PUFFS,FRZ,UNPREP',31025,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, yellow fleshed, roasted, salt added in processing, frozen, unprepared','POTATOES,YEL FLESHED,RSTD,SALT ADDED IN PROC,FRZ,UNPREP',31026,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, yellow fleshed, french fried, frozen, unprepared','POTATOES,YEL FLESHED,FRENCH FR,FRZ,UNPREP',31027,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, yellow fleshed, hash brown, shredded, salt added in processing, frozen, unprepared','POTATO,YEL FLSH,HASH BRN,SHRD,SALT ADDED IN PROC,FRZ,UNPREP',31028,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, french fried, wedge cut, frozen, unprepared','POTATOES,FRENCH FR,WEDGE CUT,FRZ,UNPREP',31029,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, french fried, steak cut, salt not added in processing, frozen, unprepared','POTATOES,FRENCH FR,STK CUT,SALT NOT ADDED IN PROC,FRZ,UNPREP',31030,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, french fried, cross cut, frozen, unprepared','POTATOES,FRENCH FR,CROSS CUT,FRZ,UNPREP',31031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Ginger root, pickled, canned, with artificial sweetener','GINGER ROOT,PICKLED,CND,W/ ART SWTNR',31033,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Peppers, hot pickled, canned','PEPPERS,HOT PICKLED,CND',31034,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, mashed, ready-to-eat','POTATOES,MSHD,RTE',31036,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Rice and vermicelli mix, beef flavor, unprepared','RICE & VERMICELLI MIX,BF FLAVOR,UNPREP',32000,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Rice and vermicelli mix, beef flavor, prepared with 80% margarine','RICE & VERMICELLI MIX,BF FLAVOR,PREP W/ 80% MARGARINE',32001,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Rice and vermicelli mix, rice pilaf flavor, unprepared','RICE & VERMICELLI MIX,RICE PILAF FLAVOR,UNPREP',32002,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Rice and vermicelli mix, rice pilaf flavor, prepared with 80% margarine','RICE & VERMICELLI MIX,RICE PILAF FLAVOR,PREP W/ 80% MARGARIN',32003,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-12-26',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Macaroni and cheese, box mix with cheese sauce, unprepared','MACARONI & CHS,BOX MIX W/ CHS SAU,UNPREP',32004,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Macaroni and cheese, box mix with cheese sauce, prepared','MACARONI & CHS,BOX MIX W/ CHS SAU,PREP',32005,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Taquitos, frozen, chicken and cheese, oven-heated','TAQUITOS,FRZ,CHICK & CHS,OVEN-HEATED',32006,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Taquitos, frozen, beef and cheese, oven-heated','TAQUITOS,FRZ,BF & CHS,OVEN-HEATED',32007,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Pasta mix, classic cheeseburger macaroni, unprepared','PASTA MIX,CLASSIC CHEESEBURGER MACARONI,UNPREP',32008,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Pasta mix, classic beef, unprepared','PASTA MIX,CLASSIC BF,UNPREP',32009,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Pasta mix, Italian lasagna, unprepared','PASTA MIX,ITALIAN LASAGNA,UNPREP',32010,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Yellow rice with seasoning, dry packet mix, unprepared','YELLOW RICE W/ SEASONING,DRY PACKET MIX,UNPREP',32011,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Pizza rolls, frozen, unprepared','PIZZA ROLLS,FRZ,UNPREP',32012,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Potsticker or wonton, pork and vegetable, frozen, unprepared','POTSTICKER OR WONTON,PORK & VEG,FRZ,UNPREP',32013,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Macaroni or noodles with cheese, made from reduced fat packaged mix, unprepared','MACARONI OR NOODLES W/ CHS,MADE FROM RED FAT PACKAGED MIX,UN',32014,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Turnover, cheese-filled, tomato-based sauce, frozen, unprepared','TURNOVER,CHEESE-FILLED,TOMATO-BASED SAU,FRZ,UNPREP',32015,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Macaroni or noodles with cheese, microwaveable, unprepared','MACARONI OR NOODLES W/ CHS,MICROWAVEABLE,UNPREP',32016,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Pasta mix, Italian four cheese lasagna, unprepared','PASTA MIX,ITALIAN FOUR CHS LASAGNA,UNPREP',32017,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Spanish rice mix, dry mix, unprepared','SPANISH RICE MIX,DRY MIX,UNPREP',32018,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Lasagna, cheese, frozen, unprepared','LASAGNA,CHS,FRZ,UNPREP',32019,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken, thighs, frozen, breaded, reheated','CHICKEN,THIGHS,FRZ,BREADED,REHTD',32020,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Spanish rice mix, dry mix, prepared (with canola/vegetable oil blend or diced tomatoes and margarine)','SPANISH RICE MIX,DRY MIX,PREP (WITH CANOLA/VEGETABLE OIL BLE',32021,NULL,NULL,NULL,NULL,NULL,1,'2015-01-06','2015-01-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Rice mix, cheese flavor, dry mix, unprepared','RICE MIX,CHS FLAVOR,DRY MIX,UNPREP',32024,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Dumpling, potato- or cheese-filled, frozen','DUMPLING,POTATO- OR CHEESE-FILLED,FRZ',32025,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Turnover, chicken- or turkey-, and vegetable-filled, reduced fat, frozen','TURNOVER,CHICKEN- OR TURKEY-,& VEGETABLE-FILLED,RED FAT,FRZ',32026,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Turnover, meat- and cheese-filled, tomato-based sauce, reduced fat, frozen','TURNOVER,MEAT- & CHEESE-FILLED,TOMATO-BASED SAU,RED FAT,FRZ',32027,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Turnover, filled with egg, meat and cheese, frozen','TURNOVER,FILLED W/ EGG,MEAT & CHS,FRZ',32028,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Rice mix, white and wild, flavored, unprepared','RICE MIX,WHITE & WILD,FLAV,UNPREP',32029,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Salisbury steak with gravy, frozen','SALISBURY STEAK W/ GRAVY,FRZ',32031,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Sausage, egg and cheese breakfast biscuit','SAUSAGE,EGG & CHS BRKFST BISCUIT',32032,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Agutuk, fish/berry with seal oil (Alaskan ice cream) (Alaska Native)','AGUTUK,FISH/BERRY W/ SEAL OIL (ICE CREAM) (ALASKA NATIVE)',35001,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Agutuk, meat-caribou (Alaskan ice cream) (Alaska Native)','AGUTUK,MEAT-CARIBOU (ALASKAN ICE CREAM) (ALASKA NATIVE)',35003,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Ascidians (tunughnak) (Alaska Native)','ASCIDIANS (TUNUGHNAK) (ALASKA NATIVE)',35004,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Whale, beluga, meat, dried (Alaska Native)','WHALE,BELUGA,MEAT,DRIED (ALASKA NATIVE)',35009,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Whale, beluga, meat, raw (Alaska Native)','Whale, beluga, meat, raw (Alaska Native)',35011,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Oil, beluga, whale (Alaska Native)','OIL,BELUGA,WHALE (ALASKA NATIVE)',35014,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Stew/soup, caribou (Alaska Native)','STEW/SOUP,CARIBOU (ALASKA NATIVE)',35024,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, herring eggs, Pacific, plain (Alaska Native)','FISH,HERRING EGGS,PACIFIC,PLN (ALASKA NATIVE)',35041,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Stew, moose (Alaska Native)','STEW,MOOSE (ALASKA NATIVE)',35048,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Moose, meat, raw (Alaska Native)','MOOSE,MEAT,RAW (ALASKA NATIVE)',35049,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Oil, bearded seal (Oogruk) (Alaska Native)','OIL,BEARDED SEAL (OOGRUK) (ALASKA NATIVE)',35057,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, salmon, king, chinook, smoked, brined (Alaska Native)','FISH,SALMON,KING,CHINOOK,SMOKED,BRINED (ALASKA NATIVE)',35067,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Seal, ringed, meat (Alaska Native)','SEAL,RINGED,MEAT (ALASKA NATIVE)',35071,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Soup, fish, homemade (Alaska Native)','SOUP,FISH,HOMEMADE (ALASKA NATIVE)',35073,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Tea, tundra, herb and laborador combination (Alaska Native)','TEA,TUNDRA,HERB & LABORADOR COMBINATION (ALASKA NATIVE)',35078,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, whitefish, mixed species, raw (Alaska Native)','FISH,WHITEFISH,MXD SP,RAW (ALASKA NATIVE)',35089,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Mush, blue corn with ash (Navajo)','MUSH,BLUE CORN W/ ASH (NAVAJO)',35130,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Cornmeal, blue (Navajo)','CORNMEAL,BLUE (NAVAJO)',35131,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Chilchen (Red Berry Beverage) (Navajo)','CHILCHEN (RED BERRY BEVERAGE) (NAVAJO)',35133,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Corn, dried (Navajo)','CORN,DRIED (NAVAJO)',35134,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Corn, white, steamed (Navajo)','CORN,WHITE,STMD (NAVAJO)',35135,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Cornmeal, white (Navajo)','CORNMEAL,WHITE (NAVAJO)',35136,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Cornmeal, yellow (Navajo)','CORNMEAL,YEL (NAVAJO)',35137,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Bread, kneel down (Navajo)','BREAD,KNEEL DOWN (NAVAJO)',35140,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Mutton, cooked, roasted (Navajo)','MUTTON,CKD,RSTD (NAVAJO)',35141,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Frybread, made with lard (Navajo)','FRYBREAD,MADE W/ LARD (NAVAJO)',35142,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Tortilla, includes plain and from mutton sandwich (Navajo)','TORTILLA,INCL PLN & FROM MUTTON SNDWCH (NAVAJO)',35143,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Stew, dumpling with mutton (Navajo)','STEW,DUMPLING W/ MUTTON (NAVAJO)',35144,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Stew, hominy with mutton (Navajo)','STEW,HOMINY W/ MUTTON (NAVAJO)',35145,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Stew, mutton, corn, squash (Navajo)','STEW,MUTTON,CORN,SQUASH (NAVAJO)',35146,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Tamales (Navajo)','TAMALES (NAVAJO)',35147,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Stew, steamed corn (Navajo)','STEW,STMD CORN (NAVAJO)',35148,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, halibut, raw, with skin (Alaska Native)','FISH,HALIBUT,RAW,W/ SKN (ALASKA NATIVE)',35149,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, salmon, coho (silver), raw (Alaska Native)','FISH,SALMON,COHO (SILVER),RAW (ALASKA NATIVE)',35150,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, salmon, sockeye (red), raw (Alaska Native)','FISH,SALMON,SOCKEYE (RED),RAW (ALASKA NATIVE)',35151,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, Salmon, Chum, raw (Alaska Native)','FISH,SALMON,CHUM,RAW (ALASKA NATIVE)',35152,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, salmon, king (chinook), raw (Alaska Native)','FISH,SALMON,KING (CHINOOK),RAW (ALASKA NATIVE)',35153,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Oil, spotted seal (Alaska Native)','OIL,SPOTTED SEAL (ALASKA NATIVE)',35156,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, salmon, red, canned, bones removed (Alaska Native)','FISH,SALMON,RED,CND,BONES REMOVED (ALASKA NATIVE)',35157,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, whitefish, eggs (Alaska Native)','FISH,WHITEFISH,EGGS (ALASKA NATIVE)',35158,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Caribou, rump meat, half dried (Alaska Native)','CARIBOU,RUMP MEAT,HALF DRIED (ALASKA NATIVE)',35160,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Caribou, shoulder meat, dried (Alaska Native)','CARIBOU,SHLDR MEAT,DRIED (ALASKA NATIVE)',35161,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Caribou, hind quarter meat, raw (Alaska Native)','CARIBOU,HIND QUARTER MEAT,RAW (ALASKA NATIVE)',35162,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Seal, bearded (Oogruk), meat, dried, in oil (Alaska Native)','SEAL,BEARDED (OOGRUK),MEAT,DRIED,IN OIL (ALASKA NATIVE)',35164,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, whitefish, dried (Alaska Native)','FISH,WHITEFISH,DRIED (ALASKA NATIVE)',35165,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, salmon, red, (sockeye), canned, smoked (Alaska Native)','FISH,SALMON,RED,(SOCKEYE),CND,SMOKED (ALASKA NATIVE)',35166,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, salmon, red, (sockeye), kippered (Alaska Native)','FISH,SALMON,RED,(SOCKEYE),KIPPERED (ALASKA NATIVE)',35167,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, salmon, king, with skin, kippered, (Alaska Native)','FISH,SALMON,KING,W/ SKN,KIPPERED,(ALASKA NATIVE)',35168,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, sheefish, raw (Alaska Native)','FISH,SHEEFISH,RAW (ALASKA NATIVE)',35169,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, salmon, chum, dried (Alaska Native)','FISH,SALMON,CHUM,DRIED (ALASKA NATIVE)',35171,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Elk, free range, ground, cooked patties (Shoshone Bannock)','ELK,FREE RANGE,GROUND,CKD PATTIES (SHOSHONE BANNOCK)',35172,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Elk, free range, ground, raw (Shoshone Bannock)','ELK,FREE RANGE,GROUND,RAW (SHOSHONE BANNOCK)',35173,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Buffalo, free range, top round steak, raw (Shoshone Bannock)','BUFFALO,FREE RANGE,TOP RND STEAK,RAW (SHOSHONE BANNOCK)',35174,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Buffalo, free range, top round steak, cooked (Shoshone Bannock)','BUFFALO,FREE RANGE,TOP RND STEAK,CKD (SHOSHONE BANNOCK)',35176,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Elk, free range, roast, eye of round, raw (Shoshone Bannock)','ELK,FREE RANGE,RST,EYE OF RND,RAW (SHOSHONE BANNOCK)',35177,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Elk, free range, roast, eye of round, cooked (Shoshone Bannock)','ELK,FREE RANGE,RST,EYE OF RND,CKD (SHOSHONE BANNOCK)',35178,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Steelhead trout, dried, flesh (Shoshone Bannock)','STEELHEAD TROUT,DRIED,FLESH (SHOSHONE BANNOCK)',35180,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Steelhead trout, boiled, canned (Alaska Native)','STEELHEAD TROUT,BLD,CND (ALASKA NATIVE)',35181,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Acorn stew (Apache)','ACORN STEW (APACHE)',35182,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Corn, dried, yellow (Northern Plains Indians)','CORN,DRIED,YEL (NORTHERN PLAINS INDIANS)',35183,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Smelt, dried (Alaska Native)','SMELT,DRIED (ALASKA NATIVE)',35184,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Frybread, made with lard (Apache)','FRYBREAD,MADE W/ LARD (APACHE)',35185,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Corned beef and potatoes in tortilla (Apache)','CORNED BF & POTATOES IN TORTILLA (APACHE)',35186,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Tennis Bread, plain (Apache)','TENNIS BREAD,PLN (APACHE)',35187,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Fish, halibut, cooked, with skin (Alaska Native)','FISH,HALIBUT,CKD,W/ SKN (ALASKA NATIVE)',35188,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Salmon, red (sockeye), filets with skin, smoked (Alaska Native)','SALMON,RED (SOCKEYE),FILETS W/ SKN,SMOKED (ALASKA NATIVE)',35190,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Pinon Nuts, roasted (Navajo)','PINON NUTS,RSTD (NAVAJO)',35207,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Caribou, hind quarter, meat, cooked (Alaska Native)','CARIBOU,HIND QUARTER,MEAT,CKD (ALASKA NATIVE)',35211,NULL,NULL,NULL,NULL,NULL,1,'2010-01-04','2011-03-28',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Agutuk, fish with shortening (Alaskan ice cream) (Alaska Native)','AGUTUK,FISH W/ SHORTENING (ALASKAN ICE CREAM) (ALASKA NATIVE',35225,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Sea lion, Steller, liver (Alaska Native)','SEA LION,STELLER,LIVER (ALASKA NATIVE)',35226,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Sea lion, Steller, kidney (Alaska Native)','SEA LION,STELLER,KIDNEY (ALASKA NATIVE)',35227,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Sea lion, Steller, meat with fat (Alaska Native)','SEA LION,STELLER,MEAT W/ FAT (ALASKA NATIVE)',35230,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Wocas, dried seeds, Oregon, yellow pond lily (Klamath)','WOCAS,DRIED SEEDS,OREGON,YEL POND LILY (KLAMATH)',35232,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Piki bread, made from blue cornmeal (Hopi)','PIKI BREAD,MADE FROM BLUE CORNMEAL (HOPI)',35234,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Wocas, tuber, cooked, Oregon, yellow pond lily (Klamath)','WOCAS,TUBER,CKD,OREGON,YEL POND LILY (KLAMATH)',35235,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Stew, pinto bean and hominy, badufsuki (Hopi)','STEW,PINTO BEAN & HOMINY,BADUFSUKI (HOPI)',35236,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Tamales, masa and pork filling (Hopi)','TAMALES,MASA & PORK FILLING (HOPI)',35237,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Tortilla, blue corn, Sakwavikaviki (Hopi)','TORTILLA,BLUE CORN,SAKWAVIKAVIKI (HOPI)',35239,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (35,'Bread, blue corn, somiviki (Hopi)','BREAD,BLUE CORN,SOMIVIKI (HOPI)',35240,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrups, grenadine','SYRUPS,GRENADINE',42040,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, fruit-flavored drink, dry powdered mix, low calorie, with aspartame','BEVERAGES,FRUIT-FLAVORED DRK,DRY PDR MIX,LO CAL,W/ ASPRT',42055,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Pectin, liquid','PECTIN,LIQUID',42063,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen novelties, ice cream type, vanilla ice cream, light, no sugar added, chocolate coated','FROZ NOVLT,ICE CRM,VAN ICE CRM,LT,NO SUGAR ADDED,CHOC COATD',42074,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Creamy dressing, made with sour cream and/or buttermilk and oil, reduced calorie','CREAMY DRSNG,MADE W/SOUR CRM AND/OR BTTRMLK&OIL,RED CAL',42116,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Imitation cheese, american or cheddar, low cholesterol','IMITATION CHS,AMERICAN OR CHEDDAR,LO CHOL',42117,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, banana juice with low fat yogurt','BABYFOOD,BANANA JUC W/LOFAT YOGURT',42119,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, mixed fruit juice with low fat yogurt','BABYFOOD,MXD FRUIT JUC W/LOFAT YOGURT',42120,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Ham, turkey, sliced, extra lean, prepackaged or deli','HAM,TURKEY,SLICED,EX LN,PREPACKAGED OR DELI',42128,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bologna, beef and pork, low fat','BOLOGNA,BF&PORK,LOFAT',42129,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Milk dessert, frozen, milk-fat free, chocolate','MILK DSSRT,FRZ,MILK-FAT FREE,CHOC',42131,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Whipped topping, frozen, low fat','WHIPPED TOPPING,FRZ,LOFAT',42135,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream substitute, powdered, light','CREAM SUB,PDR,LT',42136,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, peppercorn dressing, commercial, regular','SALAD DRSNG,PEPPERCORN DRSNG,COMM,REG',42137,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Mayonnaise, reduced-calorie or diet, cholesterol-free','MAYONNAISE,RED-CAL OR DIET,CHOL-FREE',42138,NULL,NULL,NULL,NULL,NULL,1,'2011-03-09','2011-03-09',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Granola bar, soft, milk chocolate coated, peanut butter','GRANOLA BAR,SOFT,MILK CHOC COATD,PNUT BUTTER',42139,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, italian dressing, reduced calorie','SALAD DRSNG,ITALIAN DRSNG,RED CAL',42140,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cream substitute, liquid, light','CREAM SUB,LIQ,LT',42141,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, apple yogurt dessert, strained','BABYFOOD,APPL YOGURT DSSRT,STR',42150,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Vegetable oil-butter spread, reduced calorie','VEGETABLE OIL-BUTTER SPRD,RED CAL',42151,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, blue or roquefort cheese dressing, light','SALAD DRSNG,BLUE OR ROQUEFORT CHS DRSNG,LT',42153,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, monterey, low fat','CHEESE,MONTEREY,LOW FAT',42155,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2006-11-30',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Creamy dressing, made with sour cream and/or buttermilk and oil, reduced calorie, fat-free','CRMY DRSG,MDE W/ SOUR CRM AND/OR BTRMLK & OIL,RED CAL,FTFREE',42157,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Creamy dressing, made with sour cream and/or buttermilk and oil, reduced calorie, cholesterol-free','CREAMY DRSNG,W/SOUR CRM AND/OR BTTRMLK&OIL,RED CAL,CHOL-FREE',42158,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Bologna, beef, low fat','BOLOGNA,BEEF,LOW FAT',42161,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, french dressing, reduced calorie','SALAD DRSNG,FRENCH DRSNG,RED CAL',42171,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Sausage, turkey and pork, fresh, bulk, patty or link, cooked','SAUSAGE,TURKEY & PORK,FRSH,BULK,PATTY OR LINK,CKD',42173,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Mayonnaise, made with tofu','MAYONNAISE,MADE WITH TOFU',42178,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Frankfurter, beef, low fat','FRANKFURTER,BF,LO FAT',42179,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen yogurts, chocolate, nonfat milk, sweetened without sugar','YOGURT,FRZ,CHOC,NON-FAT MILK,W/LO CAL SWTNR',42185,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen yogurts, chocolate','FROZEN YOGURTS,CHOC',42186,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen yogurts, flavors other than chocolate','FROZEN YOGURTS,FLAVORS OTHER THAN CHOC',42187,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, buttermilk, fluid, cultured, reduced fat','MILK,BTTRMLK,FLUID,CULTURED,RED FAT',42189,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Pork sausage rice links, brown and serve, cooked','PORK SAUSAGE RICE LINKS,BROWN&SERVE,CKD',42190,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, blue or roquefort cheese dressing, fat-free','SALAD DRSNG,BLUE OR ROQUEFORT CHS DRSNG,FAT-FREE',42192,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad Dressing, mayonnaise-like, fat-free','SALAD DRSNG,MAYONNAISE-LIKE,FAT-FREE',42193,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Papad','PAPAD',42200,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Rice cake, cracker (include hain mini rice cakes)','RICE CAKE,CRACKER (INCL HAIN MINI RICE CAKES)',42204,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad Dressing, coleslaw, reduced fat','SALAD DRSNG,COLESLAW,RED FAT',42230,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, flaxseed, cold pressed','OIL,FLAXSEED,COLD PRESSED',42231,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cottage, lowfat, 1% milkfat, lactose reduced','CHEESE,COTTAGE,LOWFAT,1% MILKFAT,LACTOSE RED',42235,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals ready-to-eat, frosted oat cereal with marshmallows','CEREALS RTE,FRSTD OAT CRL W/MARSHMALLOWS',42236,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, vegetable oil spread, stick or tub, sweetened','MARGARINE-LIKE,VEG OIL SPRD,STK OR TUB,SWTND',42256,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, popcorn, home-prepared, oil-popped, unsalted','SNACKS,POPCORN,HOME-PREPARED,OIL-POPPED,UNSALTED',42259,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice, apple-sweet potato','BABYFOOD,JUC,APPLE-SWEET POTATO',42266,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice, orange-carrot','BABYFOOD,JUC,ORANGE-CARROT',42267,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Orange juice drink','BEVERAGES,ORANGE JUC DRK',42270,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, granola bar, with coconut, chocolate coated','GRANOLA BAR,W/COCNT,CHOC COATD',42272,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, vegetable and brown rice, strained','BABYFOOD,VEG&BROWN RICE,STR',42278,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, peas and brown rice','BABYFOOD,PEAS&BROWN RICE',42279,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Frankfurter, meat and poultry, low fat','FRANKFURTER,MEAT & POULTRY,LO FAT',42280,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Gums, seed gums (includes locust bean, guar)','GUMS,SD GUMS (INCL LOCUST BEAN,GUAR)',42281,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, potato chips, white, restructured, baked','POTATO CHIPS,WHITE,RESTRUCTURED,BKD',42283,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, baked product, finger snacks cereal fortified','BABYFOOD,BKD PRODUCT,FINGER SNACKS CRL FORT',42284,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, brown rice, dry, instant','BABYFOOD,CRL,BROWN RICE,DRY,INST',42285,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, green beans and turkey, strained','BABYFOOD,GRN BNS&TURKEY,STR',42286,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, corn and canola','OIL,CORN AND CANOLA',42289,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, fluid, nonfat, calcium fortified (fat free or skim)','MILK,FLUID,NONFAT,CA FORT (FAT FREE OR SKIM)',42290,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Peanut butter, reduced sodium','PEANUT BUTTER,RED NA',42291,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, muenster, low fat','CHEESE,MUENSTER,LOW FAT',42303,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, mozzarella, nonfat','CHEESE,MOZZARELLA,NON-FAT',42304,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, butter-margarine blend, 80% fat, stick, without salt','MARGARINE-LIKE,BUTTER-MARGARINE BLEND,80% FAT,STK,WO/ SALT',42307,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Margarine-like, vegetable oil-butter spread, reduced calorie, tub, with salt','MARGARINE-LIKE,VEG OIL-BUTTER SPRD,RED CAL,TUB,W/ SALT',42309,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, carrots, toddler','BABYFOOD,CARROTS,TODDLER',42316,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, banana pudding, strained','BABYFOOD,DSSRT,BANANA PUDD,STR',43004,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, tutti frutti, strained','BABYFOOD,FRUIT,TUTTI FRUTTI,STR',43006,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit, tutti frutti, junior','BABYFOOD,FRUIT,TUTTI FRUTTI,JR',43007,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, chicken and rice','BABYFOOD,DINNER,CHICK&RICE',43008,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, caesar dressing, regular','SALAD DRSNG,CAESAR DRSNG,REG',43015,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, coleslaw','Salad dressing, coleslaw',43016,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, green goddess, regular','SALAD DRSNG,GRN GODDESS,REG',43017,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, sweet and sour','SALAD DRSNG,SWT&SOUR',43019,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, blue or roquefort cheese, low calorie','SALAD DRSNG,BLUE OR ROQUEFORT CHS,LO CAL',43020,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, caesar, low calorie','SALAD DRSNG,CAESAR,LO CAL',43021,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrups, sugar free','SYRUPS,SUGAR FREE',43026,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Jellies, no sugar (with sodium saccharin), any flavors','JELLIES,NO SUGAR (WITH NA SACCHARIN),ANY FLAVORS',43027,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Jams and preserves, no sugar (with sodium saccharin), any flavor','JAMS & PRESERVES,NO SUGAR (WITH NA SACCHARIN),ANY FLAVOR',43028,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, chocolate covered, caramel with nuts','CANDIES,CHOC COVERED,CARAMEL W/NUTS',43031,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, nougat, with almonds','CANDIES,NOUGAT,W/ ALMONDS',43046,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, gum drops, no sugar or low calorie (sorbitol)','CANDIES,GUM DROPS,NO SUGAR OR LO CAL (SORBITOL)',43057,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, hard, dietetic or low calorie (sorbitol)','CANDIES,HARD,DIETETIC OR LO CAL (SORBITOL)',43058,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Candies, chocolate covered, low sugar or low calorie','CANDIES,CHOC COVERED,LO SUGAR OR LO CAL',43059,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Chewing gum, sugarless','CHEWING GUM,SUGARLESS',43060,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Fluid replacement, electrolyte solution (include PEDIALYTE)','FLUID REPLCMNT,ELECTROLYTE SOLN (INCLUDE PEDIALYTE)',43075,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Pie fillings, cherry, low calorie','PIE FILLINGS,CHERRY,LO CAL',43098,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Breakfast bars, oats, sugar, raisins, coconut (include granola bar)','BREAKFAST BARS,OATS,SUGAR,RAISINS,COCNT (INCL GRANOLA BAR)',43100,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Pretzels, soft','PRETZELS,SOFT',43109,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, chili, barbecue, ranch style, cooked','BEANS,CHILI,BARBECUE,RANCH STYLE,CKD',43112,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Vermicelli, made from soy','VERMICELLI,MADE FROM SOY',43114,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, liquid from stewed kidney beans','BEANS,LIQ FROM STWD KIDNEY BNS',43125,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Chicken, meatless','CHICKEN,MEATLESS',43128,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Frankfurter, meatless','FRANKFURTER,MEATLESS',43130,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Luncheon slices, meatless','LUNCHEON SLICES,MEATLESS',43131,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Meatballs, meatless','MEATBALLS,MEATLESS',43132,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Vegetarian fillets','VEGETARIAN FILLETS',43134,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Sandwich spread, meatless','SANDWICH SPREAD,MEATLESS',43135,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Vegetarian meatloaf or patties','VEGETARIAN MEATLOAF OR PATTIES',43137,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Radishes, hawaiian style, pickled','RADISHES,HAWAIIAN STYLE,PICKLED',43142,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, japanese style, fresh, pickled','CABBAGE,JAPANESE STYLE,FRSH,PICKLED',43143,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Cabbage, mustard, salted','CABBAGE,MUSTARD,SALTED',43144,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Eggplant, pickled','EGGPLANT,PICKLED',43146,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Alcoholic beverage, wine, cooking','ALCOHOLIC BEV,WINE,COOKING',43154,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Sweeteners, tabletop, saccharin (sodium saccharin)','SWEETENERS,TABLETOP,SACCHARIN (SODIUM SACCHARIN)',43158,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Beverage, instant breakfast powder, chocolate, not reconstituted','BEVERAGE,INST BRKFST PDR,CHOC,NOT RECON',43205,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Bacon bits, meatless','BACON BITS,MEATLESS',43212,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Butter replacement, without fat, powder','BUTTER REPLCMNT,WO/FAT,PDR',43214,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, buttermilk, lite','SALAD DRSNG,BTTRMLK,LITE',43215,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Sweeteners, tabletop, fructose, dry, powder','SWEETENERS,TABLETOP,FRUCTOSE,DRY,PDR',43216,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato sauce, canned, no salt added','TOMATO SAU,CND,NO SALT ADDED',43217,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Cereals ready-to-eat, wheat and bran, presweetened with nuts and fruits','CEREALS RTE,WHEAT&BRAN,PRESWEETENED W/NUTS&FRUITS',43245,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Beverage, instant breakfast powder, chocolate, sugar-free, not reconstituted','BEVERAGE,INST BRKFST PDR,CHOC,SUGAR-FREE,NOT RECON',43260,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Yogurt, fruit variety, nonfat','YOGURT,FRUIT VAR,NON-FAT',43261,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Whipped cream substitute, dietetic, made from powdered mix','WHIPPED CRM SUB,DIETETIC,MADE FROM PDR MIX',43268,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen novelties, ice cream type, sundae, prepackaged','FROZEN NOVELTIES,ICE CRM TYPE,SUNDAE,PREPACKAGED',43269,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cottage, with vegetables','CHEESE,COTTAGE,W/VEG',43273,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cream, low fat','CHEESE,CREAM,LOW FAT',43274,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, pasteurized process, American, low fat','CHEESE,PAST PROCESS,AMERICAN,LOFAT',43275,NULL,NULL,NULL,NULL,NULL,1,'2004-07-15','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese spread, cream cheese base','CHEESE SPRD,CRM CHS BASE',43276,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, american cheddar, imitation','CHEESE,AMERICAN CHEDDAR,IMITN',43278,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Quail, cooked, total edible','QUAIL,COOKED,TOTAL EDIBLE',43282,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Pheasant, cooked, total edible','PHEASANT,CKD,TOTAL EDIBLE',43283,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Eggs, scrambled, frozen mixture','EGGS,SCRMBLD,FRZ MIXTURE',43285,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Dove, cooked (includes squab)','DOVE,CKD (INCL SQUAB)',43287,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, oriental style, dehydrated','PORK,ORIENTAL STYLE,DEHYD',43297,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Soybean, curd cheese','SOYBEAN,CURD CHEESE',43299,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes, canned, drained solids, no salt added','POTATOES,CND,DRND SOL,NO SALT',43311,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Vegetables, mixed (corn, lima beans, peas, green beans, carrots) canned, no salt added','VEGETABLES,MXD (CORN,LIMA BNS,PEAS,GRN BNS,CRRT) CND,NO SALT',43312,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, boneless, low sodium, extra lean and regular, roasted','PORK,CURED,HAM,BNLESS,LO NA,EX LN & REG,RSTD',43325,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, low sodium, lean and fat, cooked','PORK,CURED,HAM,LO NA,LN & FAT,CKD',43326,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, ham, boneless, low sodium, extra lean (approximately 5% fat), roasted','PORK,CURED,HAM,BNLESS,LO NA,EX LN (APPROXIMATLY 5% FAT),RSTD',43327,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, mayonnaise and mayonnaise-type, low calorie','SALAD DRSNG,MAYO & MAYONNAISE-TYPE,LO CAL',43329,NULL,NULL,NULL,NULL,NULL,1,'2011-03-28','2011-03-28',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Salad dressing, bacon and tomato','SALAD DRSNG,BACON&TOMATO',43331,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, parmesan, low sodium','CHEESE,PARMESAN,LO NA',43340,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Jams, preserves, marmalade, reduced sugar','JAMS,PRESERVES,MARMALADE,RED SUGAR',43344,NULL,NULL,NULL,NULL,NULL,1,'2016-02-06','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, fruit-flavored drink, powder, with high vitamin C with other added vitamins, low calorie','BEVER,FRUIT-FLAV DRK,PDR,W/ HI VIT C W/ OTHER ADD VIT,LO CAL',43345,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen novelties, juice type, orange','FROZEN NOVELTIES,JUC TYPE,ORANGE',43346,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cottage, lowfat, 1% milkfat, no sodium added','CHEESE,COTTAGE,LOWFAT,1% MILKFAT,NO NA',43352,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Mayonnaise, low sodium, low calorie or diet','MAYONNAISE,LO NA,LO CAL OR DIET',43355,NULL,NULL,NULL,NULL,NULL,1,'2011-03-09','2011-03-09',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, tortilla chips, unsalted, white corn','SNACKS,TORTILLA CHIPS,UNSALTED,WHITE CORN',43364,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato and vegetable juice, low sodium','TOMATO&VEG JUC,LO NA',43365,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, wing, smoked, cooked, with skin, bone removed','TURKEY,WING,SMOKED,CKD,W/SKN,BONE REMOVED',43366,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, drumstick, smoked, cooked, with skin, bone removed','TURKEY,DRUMSTK,SMOKED,CKD,W/SKN,BONE REMOVED',43367,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, Chocolate-flavored drink, whey and milk based','BEVERAGES,CHOCOLATE-FLAVORED DRK,WHEY & MILK BSD',43369,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (10,'Pork, cured, bacon, cooked, broiled, pan-fried or roasted, reduced sodium','PORK,CURED,BACON,CKD,BRLD,PAN-FRIED OR RSTD,RED NA',43378,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Cranberry juice, unsweetened','CRANBERRY JUC,UNSWTND',43382,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Beef, bologna, reduced sodium','BEEF,BOLOGNA,RED NA',43384,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Turnip greens, canned, no salt added','TURNIP GRNS,CND,NO SALT',43387,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, light or dark meat, smoked, cooked, with skin, bone removed','TURKEY,LT OR DK MEAT,SMOKED,CKD,W/SKN,BONE REMOVED',43390,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (5,'Turkey, light or dark meat, smoked, cooked, skin and bone removed','TURKEY,LT OR DK MEAT,SMOKED,CKD,SKN & BONE REMOVED',43391,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Hearts of palm, raw','HEARTS OF PALM,RAW',43392,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2015-01-07',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, cottage, lowfat, 1% milkfat, with vegetables','CHEESE,COTTAGE,LOWFAT,1% MILKFAT,W/VEG',43396,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, pasteurized process, cheddar or American, low sodium','CHEESE,PAST PROCESS,CHEDDAR OR AMERICAN,LO NA',43398,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, coffee, instant, with whitener, reduced calorie','BEVERAGES,COFFEE,INST,W/ WHTNR,RED CAL',43401,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (14,'Beverages, cranberry-apple juice drink, low calorie, with vitamin C added','BEVERAGES,CRANBERRY-APPLE JUC DRK,LO CAL,W/ VIT C ADDED',43404,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, swiss, low sodium','CHEESE,SWISS,LOW SODIUM',43405,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Yeast extract spread','YEAST EXTRACT SPREAD',43406,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice, pear','BABYFOOD,JUICE,PEAR',43408,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Chicken, meatless, breaded, fried','CHICKEN,MEATLESS,BREADED,FRIED',43410,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, meat, beef with vegetables, toddler','BABYFOOD,MEAT,BF W/ VEG,TODD',43417,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2019-02-13',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dinner, macaroni, beef and tomato sauce, toddler','BABYFOOD,DINNER,MACARONI,BF&TOMATO SAU,TODD',43432,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Rolls, pumpernickel','ROLLS,PUMPERNICKEL',43441,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, corn-based, extruded, chips, unsalted','SNACKS,CORN-BASED,EXTRUDED,CHIPS,UNSALTED',43447,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Beans, baked, canned, no salt added','BEANS,BKD,CND,NO SALT ADDED',43449,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen novelties, juice type, juice with cream','FROZEN NOVELTIES,JUC TYPE,JUC W/ CRM',43450,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Tofu yogurt','TOFU YOGURT',43476,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Millet, puffed','MILLET,PUFFED',43483,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Jellyfish, dried, salted','JELLYFISH,DRIED,SALTED',43497,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen novelties, ice cream type, chocolate or caramel covered, with nuts','ICE CRM BAR,CHOC OR CARAMEL COVERED,W/NUTS',43506,NULL,NULL,NULL,NULL,NULL,1,'2006-02-23','2012-03-02',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (7,'Frankfurter, low sodium','FRANKFURTER,LO NA',43507,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Frozen novelties, ice type, pop, with low calorie sweetener','FROZEN NOVELTIES,ICE TYPE,POP,W/ LO CAL SWTNR',43514,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, mixed fruit yogurt, strained','BABYFOOD,MXD FRUIT YOGURT,STR',43523,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, rice and apples, dry','BABYFOOD,RICE&APPLS,DRY',43529,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, juice, apple - cherry','BABYFOOD,JUC,APPL - CHERRY',43535,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, peach yogurt','BABYFOOD,DSSRT,PEACH YOGURT',43536,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, blueberry yogurt, strained','BABYFOOD,DSSRT,BLUEBERRY YOGURT,STR',43537,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, dessert, banana yogurt, strained','BABYFOOD,DSSRT,BANANA YOGURT,STR',43539,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Ice creams, chocolate, rich','ICE CREAMS,CHOC,RICH',43541,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Milk, imitation, non-soy','MILK,IMITATION,NON-SOY',43543,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, cereal, rice with pears and apple, dry, instant fortified','BABYFOOD,CRL,RICE W/ PEARS & APPL,DRY,INST FORT',43544,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2016-02-06',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, banana no tapioca, strained','BABYFOOD,BANANA NO TAPIOCA,STR',43546,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, banana apple dessert, strained','BABYFOOD,BANANA APPL DSSRT,STR',43550,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Snacks, tortilla chips, light (baked with less oil)','SNACKS,TORTILLA CHIPS,LT (BAKED W/ LESS OIL)',43566,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Popcorn, microwave, low fat and sodium','POPCORN,MICROWAVE,LOFAT&NA',43572,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, fruit supreme dessert','BABYFOOD,FRUIT SUPREME DSSRT',43585,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, swiss, low fat','CHEESE,SWISS,LOW FAT',43589,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (25,'Breakfast bar, corn flake crust with fruit','BREAKFAST BAR,CORN FLAKE CRUST W/FRUIT',43595,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Cheese, mozzarella, low sodium','CHEESE,MOZZARELLA,LO NA',43597,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Mayonnaise dressing, no cholesterol','MAYONNAISE DRSNG,NO CHOL',43598,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Oil, corn, peanut, and olive','OIL,CORN,PEANUT,AND OLIVE',44005,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Sweeteners, tabletop, fructose, liquid','SWEETENERS,TABLETOP,FRUCTOSE,LIQ',44018,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, chocolate flavor, low calorie, instant, dry mix','PUDDINGS,CHOC FLAVOR,LO CAL,INST,DRY MIX',44061,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (3,'Babyfood, grape juice, no sugar, canned','BABYFOOD,GRAPE JUC,NO SUGAR,CND',44074,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Jellies, reduced sugar, home preserved','JELLIES,RED SUGAR,HOME PRESERVED',44110,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Pie fillings, blueberry, canned','PIE FILLINGS,BLUEBERRY,CND',44158,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, chocolate flavor, low calorie, regular, dry mix','PUDDINGS,CHOC FLAVOR,LO CAL,REG,DRY MIX',44258,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, all flavors except chocolate, low calorie, regular, dry mix','PUDDINGS,ALL FLAVORS XCPT CHOC,LO CAL,REG,DRY MIX',44259,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Puddings, all flavors except chocolate, low calorie, instant, dry mix','PUDDINGS,ALL FLAVORS XCPT CHOC,LO CAL,INST,DRY MIX',44260,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Vital wheat gluten','VITAL WHEAT GLUTEN',48052,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chic'' Penne with multi-grain penne pasta, broccoli, diced chicken, low-sodium chicken broth, nonfat milk, flour, reduced-fat shredded cheddar cheese, low-fat shredded mozzarella cheese USDA Recipe for Schools','CHIC'' PENNE',51385,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Bok Choy Wrappers with brown rice, bok choy, canned pineapple tidbits in 100% juice, chicken strips, sweet and sour sauce, low-sodium soy sauce, romaine lettuce USDA Recipe for Schools','BOK CHOY WRAPPERS',51386,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Aztec Grain Salad with quinoa, Granny Smith apples, butternut squash, canola oil, frozen orange juice concentrate, extra virgin olive oil, honey, cilantro, dried cranberries, golden seedless raisins USDA Recipe for Schools','AZTEC GRAIN SALAD',51387,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken Alfredo With a Twist with whole-grain rotini pasta, low-fat reduced-sodium condensed cream of chicken soup, fat-free half and half, parmesan cheese, diced chicken USDA Recipe for Schools','CHICKEN ALFREDO WITH A TWIST',51388,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken Curry Casserole with brown rice, canola oil, low-sodium chicken broth, carrots, celery, onions, low-fat plain yogurt, fajita chicken strips USDA Recipe for Schools','CHICKEN CURRY CASSEROLE',51389,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Confetti Soup with canola oil, onions, celery, carrots, low-sodium black-eyed peas, extra-lean turkey ham, kale, parsley USDA Recipe for Schools','CONFETTI SOUP',51390,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Crunchy Hawaiian Chicken Wrap with light mayonnaise, sugar, poppy seeds, broccoli, carrots, spinach, crushed pineapple in 100% juice, diced chicken, whole-wheat tortillas USDA Recipe for Schools','CRUNCHY HAWAIIAN CHICKEN WRAP',51391,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Eagle Pizza with spinach, romaine lettuce, low-sodium fat-free refried beans, green peppers, onions, low-sodium corn, tostada shells, reduced-fat shredded Mexican cheese blend, carrots, low-sodium salsa, fat-free sour cream USDA Recipe for Schools','EAGLE PIZZA',51392,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Fiesta Mexican Lasagna with canola oil, green bell peppers, low-sodium corn, onions, butternut squash, low-sodium black beans, low-sodium meatless spaghetti sauce, low-sodium mild salsa, low-sodium tortilla chips USDA Recipe for Schools','FIESTA MEXICAN LASAGNA',51393,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Fiesta Wrap with quinoa, low-sodium black beans, carrots, reduced-fat shredded white cheddar cheese, red bell peppers, red onions, lime juice, whole-wheat tortillas, vegetable oil USDA Recipe for Schools','FIESTA WRAP',51394,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Harvest Delight with carrots, sweet potatoes, butternut squash, red onions, extra virgin olive oil, green apples, maple syrup, spinach, dried cranberries USDA Recipe for Schools','HARVEST DELIGHT',51395,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Harvest Stew with onions, carrots, celery, flour, low-sodium chicken base, low-sodium diced tomatoes, sweet potatoes, red potatoes, diced chicken, low-sodium great northern beans, spinach USDA Recipe for Schools','HARVEST STEW',51396,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Lentils of the Southwest with brown or green lentils, onions, extra virgin olive oil, low-sodium diced tomatoes, cilantro USDA Recipe for Schools','LENTILS OF THE SOUTHWEST',51397,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Mediterranean Quinoa Salad with quinoa, low-sodium chicken broth, lemon juice, extra virgin olive oil, red bell peppers, green onions, red onions, cherry tomatoes, black olives, feta cheese, parsley USDA Recipe for Schools','MEDITERRANEAN QUINOA SALAD',51398,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Oodles of Noodles with whole-wheat penne pasta, extra virgin olive oil, grape tomatoes, whole-wheat flour, low-sodium vegetable broth, Swiss chard USDA Recipe for Schools','OODLES OF NOODLES',51399,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Peppy Quinoa with pepitas (pumpkin seeds), quinoa, low-sodium chicken base, onions, green chilies, cilantro, green onions, lime juice USDA Recipe for Schools','PEPPY QUINOA',51400,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Porcupine Sliders with brown rice, onions, celery, lean ground turkey, eggs, dried cranberries, spinach, mini whole-grain rolls USDA Recipe for Schools','PORCUPINE SLIDERS',51401,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Purple Power Bean Wrap with low-sodium great northern beans, avocadoes, lemons, extra virgin olive oil, purple cabbage, whole-wheat tortillas, romaine lettuce USDA Recipe for Schools','PURPLE POWER BEAN WRAP',51402,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Rainbow Rice with brown rice, brown and wild rice blend, quick pearl barley, quinoa, bulgur wheat, low-sodium chicken base, carrots, red bell pepper, extra virgin olive oil, diced chicken, spinach USDA Recipe for Schools','RAINBOW RICE',51403,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Roasted Fish Crispy Slaw Wrap with red cabbage, white cabbage, carrots, bok choy, cilantro, light Balsamic vinaigrette dressing, Tilapia filets, extra virgin olive oil, romaine lettuce, whole-grain tortillas, avocadoes, limes USDA Recipe for Schools','ROASTED FISH CRISPY SLAW WRAP',51404,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Smokin'' Powerhouse Chili with onions, low-sodium vegetable stock, carrots, red bell peppers, low-sodium diced tomatoes, low-sodium tomato sauce, cilantro, sweet potatoes, low-sodium black beans, corn, quinoa USDA Recipe for Schools','SMOKIN'' POWERHOUSE CHILI',51405,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Spanish Chickpea Stew with extra virgin olive oil, onions, spinach, low-sodium garbanzo beans, golden seedless raisins, low-sodium diced tomatoes, low-sodium chicken stock USDA Recipe for Schools','SPANISH CHICKPEA STEW',51406,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Squish Squash Lasagna with onions, canola oil, low-sodium diced tomatoes, whole-wheat no-boil lasagna sheets, butternut squash, spinach, low-fat shredded mozzarella cheese USDA Recipe for Schools','SQUISH SQUASH LASAGNA',51407,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Stir-Fried Green Rice, Eggs, and Ham (Turkey Ham) with brown rice, eggs, vegetable oil, extra-lean turkey ham, green onions, spinach, sesame oil, low-sodium soy sauce USDA Recipe for Schools','STIR-FRIED GREEN RICE, EGGS, AND HAM (TURKEY HAM)',51408,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Stir-Fry Fajita Chicken, Squash, and Corn with brown rice, cilantro, onions, fajita chicken strips, butternut squash, red bell peppers, corn, green chilies, low-sodium diced tomatoes USDA Recipe for Schools','STIR-FRY FAJITA CHICKEN, SQUASH, AND CORN',51409,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Sweet Potato and Black Bean Stew with dried New Mexican chili peppers, onions, sweet potatoes, low-sodium black beans, orange juice, low-sodium chicken stock, Swiss chard USDA Recipe for Schools','SWEET POTATO AND BLACK BEAN STEW',51410,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Tasty Tots with sweet potatoes, low-sodium garbanzo beans, vegetable oil, green onions, flour USDA Recipe for Schools','TASTY TOTS',51411,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Tuscan Smoked Turkey and Bean Soup with onions, celery, carrots, kale, low-sodium tomato paste, low-sodium Navy beans, smoked turkey breast, parsley USDA Recipe for Schools','TUSCAN SMOKED TURKEY AND BEAN SOUP',51412,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Vegetable Chili Boat w/ canola oil, onions, green peppers, low-sodium(LS) pinto, kidney, and black beans, diced tomatoes, chicken stock, & tomato paste, reduced fat cheddar & low-fat mozzarella shredded cheeses, LS tortilla chips USDA Recipe for Schools','VEGETABLE CHILI BOAT',51413,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Central Valley Harvest Bake with butternut squash, extra virgin olive oil, red onions, jalapeno peppers, red bell peppers, red quinoa, low-sodium black beans, sweetened applesauce, lime juice, low-fat no fruit granola USDA Recipe for Schools','CENTRAL VALLEY HARVEST BAKE',51414,NULL,NULL,NULL,NULL,NULL,2,'2013-04-30','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Cooking Rice USDA Recipe for Schools','COOKING RICE',51566,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Baking Powder Biscuits USDA Recipe for Schools','BAKING POWDER BISCUITS',51567,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Banana Bread Squares USDA Recipe for Schools','BANANA BREAD SQUARES',51568,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Cornbread USDA Recipe for Schools','CORNBREAD',51570,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Fried Rice USDA Recipe for Schools','FRIED RICE',51571,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Italian Bread USDA Recipe for Schools','ITALIAN BREAD',51572,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pumpkin Bread USDA Recipe for Schools','PUMPKIN BREAD',51573,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pancakes USDA Recipe for Schools','PANCAKES',51574,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pizza Crust USDA Recipe for Schools','PIZZA CRUST',51575,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Pourable Pizza Crust USDA Recipe for Schools','POURABLE PIZZA CRUST',51576,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Spanish Rice USDA Recipe for Schools','SPANISH RICE',51577,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Oatmeal Muffin Squares USDA Recipe for Schools','OATMEAL MUFFIN SQUARES',51578,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Orange Rice Pilaf USDA Recipe for Schools','ORANGE RICE PILAF',51579,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Brown Rice Pilaf USDA Recipe for Schools','BROWN RICE PILAF',51580,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Sweet Potato Bread Squares USDA Recipe for Schools','SWEET POTATO BREAD SQUARES',51581,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Jollof Rice USDA Recipe for Schools','JOLLOF RICE',51582,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Bread Stuffing USDA Recipe for Schools','BREAD STUFFING',51583,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Corn Bread Stuffing USDA Recipe for Schools','CORN BREAD STUFFING',51584,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Gingerbread USDA Recipe for Schools','GINGERBREAD',51585,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Beef or Pork Burrito USDA Recipe for Schools','BEEF OR PORK BURRITO',51587,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Beef or Pork Burrito With Canned Meats USDA Recipe for Schools','BEEF OR PORK BURRITO WITH CANNED MEATS',51588,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken Burrito USDA Recipe for Schools','CHICKEN BURRITO',51589,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Bean Tostada USDA Recipe for Schools','BEAN TOSTADA',51590,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken or Turkey Taco USDA Recipe for Schools','CHICKEN OR TURKEY TACO',51591,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Beef Tamale Pie USDA Recipe for Schools','BEEF TAMALE PIE',51593,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Beef and Bean Tamale Pie USDA Recipe for Schools','BEEF AND BEAN TAMALE PIE',51594,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken or Turkey Tamale Pie USDA Recipe for Schools','CHICKEN OR TURKEY TAMALE PIE',51595,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken or Turkey ala King USDA Recipe for Schools','CHICKEN OR TURKEY ALA KING',51596,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken or Turkey Noodles USDA Recipe for Schools','CHICKEN OR TURKEY NOODLES',51597,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken or Turkey Chop Suey USDA Recipe for Schools','CHICKEN OR TURKEY CHOP SUEY',51598,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken or Turkey Pot Pie USDA Recipe for Schools','CHICKEN OR TURKEY POT PIE',51599,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chili con Carne with Beans USDA Recipe for Schools','CHILI CON CARNE WITH BEANS',51600,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Ground Turkey and Beef Spanish Rice USDA Recipe for Schools','GROUND TURKEY AND BEEF SPANISH RICE',51601,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Ground Turkey and Beef Stroganoff USDA Recipe for Schools','GROUND TURKEY AND BEEF STROGANOFF',51602,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Macaroni and Cheese USDA Recipe for Schools','MACARONI AND CHEESE',51603,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Turkey Meatloaf USDA Recipe for Schools','TURKEY MEATLOAF',51604,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Meatball Madness USDA Recipe for Schools','MEATBALL MADNESS',51605,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Nachos with Diced Chicken USDA Recipe for Schools','NACHOS WITH DICED CHICKEN',51606,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Oven Fried Chicken USDA Recipe for Schools','OVEN FRIED CHICKEN',51607,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Vegetable Pizza USDA Recipe for Schools','VEGETABLE PIZZA',51608,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Pizza with Ground Turkey Topping USDA Recipe for Schools','PIZZA WITH GROUND TURKEY TOPPING',51609,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Pizza Cup with Ground Pork Topping USDA Recipe for Schools','PIZZA CUP WITH GROUND PORK TOPPING',51610,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Quiche with Self-Forming Crust USDA Recipe for Schools','QUICHE WITH SELF-FORMING CRUST',51611,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Salisbury Steak USDA Recipe for Schools','SALISBURY STEAK',51612,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Spaghetti and Meat Sauce USDA Recipe for Schools','SPAGHETTI AND MEAT SAUCE',51613,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Spaghetti and Meat Sauce (Ground Beef and Ground Pork USDA Recipe for Schools','SPAGHETTI AND MEAT SAUCE (GROUND BEEF AND GROUND PORK',51614,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Sweet and Sour Pork USDA Recipe for Schools','SWEET AND SOUR PORK',51615,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Tuna and Noodles USDA Recipe for Schools','TUNA AND NOODLES',51616,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Turkey and Dressing Supreme USDA Recipe for Schools','TURKEY AND DRESSING SUPREME',51617,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken Stir Fry USDA Recipe for Schools','CHICKEN STIR FRY',51618,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Beef Stir Fry USDA Recipe for Schools','BEEF STIR FRY',51619,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Pork Stir Fry USDA Recipe for Schools','PORK STIR FRY',51620,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken Fajitas USDA Recipe for Schools','CHICKEN FAJITAS',51621,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken Tomato Bake USDA Recipe for Schools','CHICKEN TOMATO BAKE',51622,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken Tetrazzini USDA Recipe for Schools','CHICKEN TETRAZZINI',51623,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Beef Shepherd''s Pie USDA Recipe for Schools','BEEF SHEPHERD''S PIE',51624,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Beef Taco Pie USDA Recipe for Schools','BEEF TACO PIE',51625,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Taco Pie with Salad Topping USDA Recipe for Schools','TACO PIE WITH SALAD TOPPING',51627,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Taco Pie with Beans USDA Recipe for Schools','TACO PIE WITH BEANS',51628,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Arroz Con Queso (Rice With Cheese) USDA Recipe for Schools','ARROZ CON QUESO (RICE WITH CHEESE)',51629,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Vegetable Chili USDA Recipe for Schools','VEGETABLE CHILI',51630,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Cuban Black Beans and Rice USDA Recipe for Schools','CUBAN BLACK BEANS AND RICE',51631,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Turkey and Beef Macaroni USDA Recipe for Schools','TURKEY AND BEEF MACARONI',51632,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Hawaiian Ham Coconut Rice USDA Recipe for Schools','HAWAIIAN HAM COCONUT RICE',51633,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Mexicali Taco Boat USDA Recipe for Schools','MEXICALI TACO BOAT',51634,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Sesame Asian Noodle Chicken Salad USDA Recipe for Schools','SESAME ASIAN NOODLE CHICKEN SALAD',51635,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Sweet and Sassy Chicken USDA Recipe for Schools','SWEET AND SASSY CHICKEN',51636,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Volcanic Meatloaf USDA Recipe for Schools','VOLCANIC MEATLOAF',51637,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Rice Vegetable Casserole USDA Recipe for Schools','RICE VEGETABLE CASSEROLE',51638,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Kati Kati Chicken USDA Recipe for Schools','KATI KATI CHICKEN',51639,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Carrot Raisin Salad USDA Recipe for Schools','CARROT RAISIN SALAD',51640,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Barbecue Chicken or Turkey Salad USDA Recipe for Schools','BARBECUE CHICKEN OR TURKEY SALAD',51641,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Creamy Coleslaw USDA Recipe for Schools','CREAMY COLESLAW',51642,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Macaroni Salad USDA Recipe for Schools','MACARONI SALAD',51643,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Pasta Salad  USDA Recipe for Schools','PASTA SALAD',51644,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Roasted Potato Salad USDA Recipe for Schools','ROASTED POTATO SALAD',51645,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Taco Salad USDA Recipe for Schools','TACO SALAD',51646,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Three Bean Salad USDA Recipe for Schools','THREE BEAN SALAD',51647,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli Salad USDA Recipe for Schools','BROCCOLI SALAD',51648,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Marinated Black Bean Salad USDA Recipe for Schools','MARINATED BLACK BEAN SALAD',51649,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (20,'Tabouleh USDA Recipe for Schools','TABOULEH',51650,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Fruit Salsa USDA Recipe for Schools','FRUIT SALSA',51651,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Pico de Gallo USDA Recipe for Schools','PICO DE GALLO',51652,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Chicken or Turkey and Rice Soup USDA Recipe for Schools','CHICKEN OR TURKEY AND RICE SOUP',51653,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Curried Vegetable Soup USDA Recipe for Schools','CURRIED VEGETABLE SOUP',51654,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Beef Vegetable Soup USDA Recipe for Schools','BEEF VEGETABLE SOUP',51655,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Chicken or Turkey Vegetable Soup USDA Recipe for Schools','CHICKEN OR TURKEY VEGETABLE SOUP',51656,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Minestrone USDA Recipe for Schools','MINESTRONE',51657,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Taco Soup USDA Recipe for Schools','TACO SOUP',51658,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mashed Potatoes USDA Recipe for Schools','MASHED POTATOES',51660,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Creamed Spinach USDA Recipe for Schools','CREAMED SPINACH',51661,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Local Harvest Bake USDA Recipe for Schools','LOCAL HARVEST BAKE',51662,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Pizza Green Beans USDA Recipe for Schools','PIZZA GREEN BEANS',51663,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Baked Beans with Canned Vegetarian Beans USDA Recipe for Schools','BAKED BEANS WITH CANNED VEGETARIAN BEANS',51664,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Baked Sweet Potatoes and Apples USDA Recipe for Schools','BAKED SWEET POTATOES AND APPLES',51665,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Broccoli Bites USDA Recipe for Schools','BROCCOLI BITES',51666,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Chinese Style Vegetables USDA Recipe for Schools','CHINESE STYLE VEGETABLES',51667,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn Pudding USDA Recipe for Schools','CORN PUDDING',51668,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Green Beans with Potatoes and Smoked Turkey USDA Recipe for Schools','GREEN BEANS WITH POTATOES AND SMOKED TURKEY',51669,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Mexicali Corn USDA Recipe for Schools','MEXICALI CORN',51670,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Orange Glazed Sweet Potatoes USDA Recipe for Schools','ORANGE GLAZED SWEET POTATOES',51671,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Orange Glazed Carrots USDA Recipe for Schools','ORANGE GLAZED CARROTS',51672,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (16,'Black Bean Hummus USDA Recipe for Schools','BLACK BEAN HUMMUS',51673,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Collard Greens USDA Recipe for Schools','COLLARD GREENS',51674,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Hoppin John USDA Recipe for Schools','HOPPIN JOHN',51675,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Corn and Edamame Blend USDA Recipe for Schools','CORN AND EDAMAME BLEND',51676,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sauteed Spinach and Tomatoes USDA Recipe for Schools','SAUTEED SPINACH AND TOMATOES',51677,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Sweet Plantains USDA Recipe for Schools','SWEET PLANTAINS',51678,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Baby Potatoes Persillade USDA Recipe for Schools','BABY POTATOES PERSILLADE',51679,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Roasted Potatoes O''Brien USDA Recipe for Schools','ROASTED POTATOES O''BRIEN',51680,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Yucca USDA Recipe for Schools','YUCCA',51681,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Zucchini Sticks with Red Sauce USDA Recipe for Schools','ZUCCHINI STICKS WITH RED SAUCE',51682,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (1,'Scrambled Eggs USDA Recipe for Schools','SCRAMBLED EGGS',51683,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Pizza with Hashbrown Crust USDA Recipe for Schools','BREAKFAST PIZZA WITH HASHBROWN CRUST',51684,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Fun Fruit Breakfast Pizza USDA Recipe for Schools','FUN FRUIT BREAKFAST PIZZA',51685,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Fennel Turkey Sausage with Maple French Toast USDA Recipe for Schools','FENNEL TURKEY SAUSAGE WITH MAPLE FRENCH TOAST',51686,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Maple Baked French Toast Squares USDA Recipe for Schools','MAPLE BAKED FRENCH TOAST SQUARES',51687,NULL,NULL,NULL,NULL,NULL,2,'2017-05-01','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Bean Burrito Bowl  USDA Recipe for Schools','BEAN BURRITO BOWL',51688,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chinese Style Vegetables with Tofu USDA Recipe for Schools','CHINESE STYLE VEGETABLES WITH TOFU',51689,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Honey Lime Chicken USDA Recipe for Schools','HONEY LIME CHICKEN',51691,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Jerk Fish Wrap USDA Recipe for Schools','JERK FISH WRAP',51692,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Lasagna with Ground Turkey and Pork USDA Recipe for Schools','LASAGNA WITH GROUND TURKEY AND PORK',51693,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Lasagna with Ground Turkey USDA Recipe for Schools','LASAGNA WITH GROUND TURKEY',51694,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Oven Roasted Tilapia with Crema Sauce USDA Recipe for Schools','OVEN ROASTED TILAPIA WITH CREMA SAUCE',51695,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Pizza Cup with Cheese USDA Recipe for Schools','PIZZA CUP WITH CHEESE',51696,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Ropa Vieja (Shredded Beef over Rice) USDA Recipe for Schools','ROPA VIEJA (SHREDDED BEEF OVER RICE)',51697,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Salmon Patties USDA Recipe for Schools','SALMON PATTIES',51698,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Vegetable Frittata Bites USDA Recipe for Schools','VEGETABLE FRITTATA BITES',51699,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2024-12-19',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Vegetable Lasagna USDA Recipe for Schools','VEGETABLE LASAGNA',51700,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Vegetable Quesadilla USDA Recipe for Schools','VEGETABLE QUESADILLA',51701,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Butternut Squash Casserole USDA Recipe for Schools','BUTTERNUT SQUASH CASSEROLE',51702,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Instant Garlic Mashed Potatoes USDA Recipe for Schools','INSTANT GARLIC MASHED POTATOES',51703,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Potatoes Au Gratin USDA Recipe for Schools','POTATOES AU GRATIN',51704,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Quick Baked Sweet Potatoes USDA Recipe for Schools','QUICK BAKED SWEET POTATOES',51705,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Refried Beans USDA Recipe for Schools','REFRIED BEANS',51706,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Scalloped Potatoes (with Fresh Potatoes) USDA Recipe for Schools','SCALLOPED POTATOES (WITH FRESH POTATOES)',51707,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Spring Rolls USDA Recipe for Schools','SPRING ROLLS',51708,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Winter Greens USDA Recipe for Schools','WINTER GREENS',51709,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Asian Salad USDA Recipe for Schools','ASIAN SALAD',51710,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Creamy Dip for Fresh Vegetables USDA Recipe for Schools','CREAMY DIP FOR FRESH VEGETABLES',51711,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (4,'Ranch Dressing USDA Recipe for Schools','RANCH DRESSING',51713,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Salad Shakers USDA Recipe for Schools','SALAD SHAKERS',51714,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (9,'Waldorf Fruit Salad USDA Recipe for Schools','WALDORF FRUIT SALAD',51715,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Bean Soup USDA Recipe for Schools','BEAN SOUP',51716,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Cream of Chicken Soup USDA Recipe for Schools','CREAM OF CHICKEN SOUP',51717,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Cream of Potato Soup USDA Recipe for Schools','CREAM OF POTATO SOUP',51718,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Tomato Soup USDA Recipe for Schools','TOMATO SOUP',51719,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Asian Tuna Burger USDA Recipe for Schools','ASIAN TUNA BURGER',51720,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Barbecued Turkey on a Roll USDA Recipe for Schools','BARBECUED TURKEY ON A ROLL',51721,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Chicken Slider with Honey Mustard Aioli USDA Recipe for Schools','CHICKEN SLIDER WITH HONEY MUSTARD AIOLI',51722,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Hash Brown Stacker USDA Recipe for Schools','HASH BROWN STACKER',51723,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Jerk Fish in  a Pita Pocket USDA Recipe for Schools','JERK FISH IN  A PITA POCKET',51724,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Pizza Burger on a Roll USDA Recipe for Schools','PIZZA BURGER ON A ROLL',51725,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Sloppy Joe on a Roll USDA Recipe for Schools','SLOPPY JOE ON A ROLL',51726,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Tuna Salad on a Whole Grain Roll USDA Recipe for Schools','TUNA SALAD ON A WHOLE GRAIN ROLL',51727,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Tuscan Grill Cheese Sandwich USDA Recipe for Schools','TUSCAN GRILL CHEESE SANDWICH',51728,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Vegetable Wrap USDA Recipe for Schools','VEGETABLE WRAP',51729,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Orzo Pasta with Green Peas USDA Recipe for Schools','ORZO PASTA WITH GREEN PEAS',51730,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Whole-Grain Dinner Rolls USDA Recipe for Schools','WHOLE-GRAIN DINNER ROLLS',51731,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Burrito with Salsa USDA Recipe for Schools','BREAKFAST BURRITO WITH SALSA',51732,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (18,'Breakfast Muffins USDA Recipe for Schools','BREAKFAST MUFFINS',51733,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Granola with Dried Fruit USDA Recipe for Schools','GRANOLA WITH DRIED FRUIT',51735,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Mango Smoothie Bowl USDA Recipe for Schools','MANGO SMOOTHIE BOWL',51736,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (8,'Fruity Oatmeal USDA Recipe for Schools','FRUITY OATMEAL',51738,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Roasted Potatoes and Turkey Hash USDA Recipe for Schools','ROASTED POTATOES AND TURKEY HASH',51739,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Seasonal Fruit and Yogurt Parfaits USDA Recipe for Schools','SEASONAL FRUIT AND YOGURT PARFAITS',51740,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Southwest Tofu Scramble USDA Recipe for Schools','SOUTHWEST TOFU SCRAMBLE',51741,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'Turkey Breakfast Sausage USDA Recipe for Schools','TURKEY BREAKFAST SAUSAGE',51742,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Brown Gravy USDA Recipe for Schools','BROWN GRAVY',51761,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Cran-Orange Relish USDA Recipe for Schools','CRAN-ORANGE RELISH',51762,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Stir-Fry Sauce USDA Recipe for Schools','STIR-FRY SAUCE',51763,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2022-04-01',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'Teriyaki Sauce USDA Recipe for Schools','TERIYAKI SAUCE',51764,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (11,'Tomato Sauce USDA Recipe for Schools','TOMATO SAUCE',51765,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (6,'White Sauce USDA Recipe for Schools','WHITE SAUCE',51766,NULL,NULL,NULL,NULL,NULL,2,'2019-02-22','2020-02-21',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Frog legs, raw','FROG LEGS,RAW',80200,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Fish, mackerel, salted','MACKEREL,SALTED',83110,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, scallop, (bay and sea), cooked, steamed','SCALLOP,(BAY&SEA),CKD,STMD',90240,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (19,'Syrup, cane','SYRUP,CANE',90480,NULL,NULL,NULL,NULL,NULL,1,'2013-02-22','2013-02-22',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Mollusks, snail, raw','SNAIL,RAW',90560,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (15,'Turtle, green, raw','TURTLE,GREEN,RAW',93600,NULL,NULL,NULL,NULL,NULL,1,'2013-12-23','2013-12-23',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S BREAKFAST WG SAUSAGE NET WT 26.48LBS 8-16PK CN','TN BK WG SAUS',119936,NULL,'10072180639124','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2025-03-20',NULL,'UNPREPARED',2723146,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S 3.2X5 BKFT TKY SAUS IW NET WT 22.94LBS 100CT CN','TN BKFT TKY SAUS',119937,NULL,'10072180639131','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2024-12-19',NULL,'UNPREPARED',2718923,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S THICK CRUST WG CHEESE NET WT 30.60LBS 12-8PK CN','TN 4X6 THK CHS',119940,NULL,'10072180685213','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2024-12-19','2024-08-17','UNPREPARED',2718958,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS MINH TERIYAKI CHIC STIR FRY KIT NET WT 42.00LBS 12CT CN','MN TERI CKN SFRY',119951,NULL,'10072180690187','SCHWAN''S FOOD SERVICE INC','MINH',NULL,3,'2014-12-07','2024-10-31',NULL,'UNPREPARED',2716095,'50193200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS MINH ORANGE CHIC STIR FRY KIT NET WT 42.00LBS 12CT CN','MN ORG CHIC SFRY',119952,NULL,'10072180690200','SCHWAN''S FOOD SERVICE INC','MINH',NULL,3,'2014-12-07','2024-12-19','2024-11-10','UNPREPARED',2718997,'50193200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S FRENCH BREAD WG CHEESE 100% MZ NET WT 20.63LBS 60CT CN','TN FB WG CHS 100',119976,NULL,'10072180726718','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2024-12-19',NULL,'UNPREPARED',2719004,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S FRENCH BREAD WG PEPPERONI 100% MZ NET WT 20.25LBS 60CT CN','TN FB WG PEP 100',119977,NULL,'10072180726725','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2024-12-19',NULL,'UNPREPARED',2719005,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S ROLLED EDGE CHS 3-3PK NET WT 24.35LBS CN','BD RE CHS',119981,NULL,'10072180731422','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2014-12-07','2024-12-19',NULL,'UNPREPARED',2719006,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S ROLLED EDGE PEPP 3-3PK NET WT 24.49LBS CN','BD RE PEPP',119982,NULL,'10072180731439','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2014-12-07','2024-12-19',NULL,'UNPREPARED',2719007,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S SMART WG CHEESE 50-50 NET WT 27.60LBS 12-8PK CN','TN SMRT WG CHS',119983,NULL,'10072180731583','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2024-12-19',NULL,'UNPREPARED',2719009,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S SMART WG PEPPERONI 50-50 NET WT 26.88LBS 12-8PK CN','TN SMRT WG PEPP',119984,NULL,'10072180731590','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2024-12-19',NULL,'UNPREPARED',2719024,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BEACON STREET CAF 100% MOZ BRDSTX WG NET WT 26.25 LBS 200CT','BS STF BRDSTX',119989,NULL,'10072180733389','SCHWAN''S FOOD SERVICE INC','BEACON STREET CAF',NULL,3,'2014-12-07','2024-12-19',NULL,'UNPREPARED',2719010,'50192500');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S BREAKFAST WG SAUSAGE SQ WHITE SCE NET WT 24LBS8-16PK CN','TN BK WG SAUS SQ',119990,NULL,'10072180783520','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2025-01-23',NULL,'UNPREPARED',2722160,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S BREAKFAST WG BACON SCRAMBLE SQ NET WT 23.60LBS 8-16PK CN','TN BK WG BAC SCR',119991,NULL,'10072180783537','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2025-01-23',NULL,'UNPREPARED',2722578,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S FRENCH BREAD WG CHEESE NET WT 18.53LBS 60CT CN','TN FB WG CHS',119992,NULL,'10072180783568','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2024-12-19',NULL,'UNPREPARED',2719011,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S FRENCH BREAD WG PEPPERONI NET WT 18.49LBS 60CT CN','TN FB PEPP',119993,NULL,'10072180783575','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2025-03-20',NULL,'UNPREPARED',2723147,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S FRENCH BREAD WG MULTI CHEESE NET WT 16.09LBS 60CT CN','TN FB M CHS',119994,NULL,'10072180783599','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2024-12-19',NULL,'UNPREPARED',2719013,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S FRENCH BREAD WG MULTI CHEESE NET WT 16.09LBS - IW 60CT CN','TN FB M CHS IW',119996,NULL,'10072180783612','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2024-12-19','2025-03-22','UNPREPARED',2719014,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S GALAXY WG CHEESE 100% NET WT 20.07LBS 12-6PK CN','WG CHS 100% CN',119999,NULL,'10072180783643','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2025-01-23',NULL,'UNPREPARED',2722687,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S GALAXY WG PEPPERONI 100% NET WT 20.30LBS 12-6PK CN','WG PEPP 100% CN',120000,NULL,'10072180783650','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2025-01-23',NULL,'UNPREPARED',2723029,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S GALAXY WG CHEESE 100% NET WT 20.07LBS - IW 72CT CN','CHS 100% IW CN',120001,NULL,'10072180783667','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2025-01-23',NULL,'UNPREPARED',2722019,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S GALAXY WG PEPPERONI 100% NET WT 20.30LBS - IW 72CT CN','PEPP 100% IW CN',120002,NULL,'10072180783674','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2025-01-23',NULL,'UNPREPARED',2722966,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S DEEP DISH WG CHEESE 100% NET WT 18.68LBS 6-10PK CN','5" CHS 100% CN',120003,NULL,'10072180783681','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2025-01-23',NULL,'UNPREPARED',2722642,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S DEEP DISH WG PEPPERONI 100% NET WT 18.68LBS 6-10PK CN','5IN PEPP 100% CN',120004,NULL,'10072180783698','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2025-04-24',NULL,'UNPREPARED',2730340,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS COYOTE GRILL QUES WG CHEESE NET WT 26.40LBS  96 CT CN','CG QUES WG CHS',120007,NULL,'10072180783728','SCHWAN''S FOOD SERVICE INC','COYOTE GRILL',NULL,3,'2014-12-07','2024-11-14',NULL,'UNPREPARED',2717297,'50193300');
INSERT INTO `cndb_fdes` VALUES (22,'SFS COYOTE GRILL QUES WG CHICKEN NET WT 26.40LBS 96CT CN','CG QUES WG CHIC',120008,NULL,'10072180783735','SCHWAN''S FOOD SERVICE INC','COYOTE GRILL',NULL,3,'2014-12-07','2024-10-31',NULL,'UNPREPARED',2716047,'50193300');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S PRIMO CHEESE NET WT 23.34LBS 3-3PK CN','BD PRIMO CHS',120019,NULL,'10072180786378','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2014-12-07','2024-12-19',NULL,'UNPREPARED',2719015,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S PRIMO PEPPERONI 3-3PK NET WT 23.34LBS CN','BD PRIMO PEPP',120020,NULL,'10072180786385','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2014-12-07','2024-12-19',NULL,'UNPREPARED',2719016,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S WG SAUSAGE 100% NET WT 28.14LBS 12-8PK CN','TN 4X6 WG SAUS',120033,NULL,'10072180787719','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2014-12-07','2025-03-20',NULL,'UNPREPARED',2723148,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S BOLD 51% WG CHS NET WT 25.05LBS 3-3PK CN','BD BOLD CHS',120036,NULL,'10072180789850','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2014-12-07','2025-01-23',NULL,'UNPREPARED',2722432,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S BOLD 51% WG PEPP NET WT 25.19LBS 3-3PK CN','BD BOLD PEPP',120037,NULL,'10072180789867','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2014-12-07','2024-12-19',NULL,'UNPREPARED',2719020,'50182200');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Condensed Cream of Mushroom Soup, 50 Ounce Cans, 12-Pack','CAMPBELL''S CREAM OF MUSHROOM',120242,'1266','10051000012668','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2016-02-05','2024-07-11',NULL,'UNPREPARED',2696186,'50191500');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Condensed Healthy Request Cream of Chicken Soup, 50 Ounce Cans, 12-Pack','CAMPBELL''S HR CREAM OF CHICKEN',120256,'4143','10051000041439','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2016-02-05','2025-03-20',NULL,'UNPREPARED',2724156,'50191500');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Condensed Healthy Request Cream of Mushroom Soup, 50 Ounce Cans, 12-Pack','CAMPBELLS HR CREAM OF MUSHROOM',120257,'4144','10051000041446','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2016-02-05','2025-03-20',NULL,'UNPREPARED',2724157,'50191500');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Condensed Healthy Request Tomato Soup, 50 Ounce Cans, 12-Pack','CAMPBELL''S HR TOMATO SOUP',120258,'4145','10051000041453','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2016-02-05','2025-03-20',NULL,'UNPREPARED',2724158,'50191500');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Culinary Reserve Frozen Condensed Broccoli Cheese Soup, 4 Pound Trays, 3-Pack','CUL RES BROC CHS',120261,'8187','10051000081879','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2016-02-05','2024-07-11',NULL,'UNPREPARED',2696199,'50191500');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Culinary Reserve Frozen Condensed Cream of Potato Soup, 4 Pound Trays, 3-Pack','CUL RES CRM OF POT',120266,'8166','10051000081664','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2016-02-05','2024-07-11',NULL,'UNPREPARED',2696196,'50191500');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Culinary Reserve Frozen Condensed Healthy Request Harvest Tomato with Basil Soup, 4 Pound Trays, 3-Pack','CUL RES HR TOM W BAS',120287,'19120','10051000191202','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2016-02-05','2024-07-11',NULL,'UNPREPARED',2696205,'50191500');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Culinary Reserve Frozen Condensed Healthy Request Mediterranean Style Vegetable Soup, 4 Pound Trays, 3-Pack','CUL RES HR MED VEG',120289,'19123','10051000191233','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2016-02-05','2024-09-13',NULL,'UNPREPARED',2703837,'50191500');
INSERT INTO `cndb_fdes` VALUES (25,'Pepperidge Farm Goldfish Made with Whole Grain Snack Crackers, Xtra Cheddar, .75 Ounces, Pack of 300','PF GF WG XTRA CHEDDAR',120296,'23088','10014100230882','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2016-02-05','2024-07-11',NULL,'UNPREPARED',2697032,'50192100');
INSERT INTO `cndb_fdes` VALUES (25,'Pepperidge Farm Goldfish Baked with Whole Grain Cheddar Crackers, 0.75 oz. Bag','PF GF WG CHEDDAR',120297,'18105','10014100181054','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2016-02-05','2024-07-11',NULL,'UNPREPARED',2697062,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'Pepperidge Farm Goldfish Whole Grain Snack Crackers, Cheddar, 1 Ounce, Pack of 60','PF GF WG CHEDDAR',120298,'21680','10014100216800','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2016-02-05','2024-07-11',NULL,'UNPREPARED',2697033,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'Pepperidge Farm Goldfish Baked Snack Crackers Baked with Whole Grain Cheddar Cheese, 31 Ounces, Pack of 6','PF GF WG CHEDDAR BULK CARTON',120299,'20648','10014100206481','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2016-02-05','2023-10-26',NULL,'UNPREPARED',2649986,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'Pepperidge Farm Goldfish Made with Whole Grain Snack Crackers, Pretzel, .75 Ounces, Pack of 300','PF GF WG PRETZELS',120300,'14396','10014100143960','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2016-02-05','2024-07-11',NULL,'UNPREPARED',2697061,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'Pepperidge Farm Goldfish Made with Whole Grain 100 Calorie Snack Crackers, Cheddar, .75 Ounce, Pack of 100','PF GF WG CHEDDAR',120301,'18197','10014100181979','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2016-02-05','2024-07-11',NULL,'UNPREPARED',2697034,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'Pepperidge Farm Goldfish Whole Grain Giant Grahams, Cinnamon, .9 Ounces, Pack of 300','PF GF GIANT GRHMS CINN',120304,'26830','10014100268304','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2016-02-05','2024-07-11',NULL,'UNPREPARED',2697006,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'Pepperidge Farm Goldfish Whole Grain Giant Grahams, Vanilla, .9 Ounces, Pack of 300','PF GF GIANT GRHMS VAN',120306,'26828','10014100268281','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2016-02-05','2024-07-11',NULL,'UNPREPARED',2697005,'50182100');
INSERT INTO `cndb_fdes` VALUES (22,'Campbell''s Frozen Entrees Creamy Classic Macaroni and Cheese, 6 Pound Trays, 4-Pack','FS C''S MAC&CHEES',120347,'11213','10051000112139','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2016-02-05','2024-07-11',NULL,'UNPREPARED',2696201,'50193100');
INSERT INTO `cndb_fdes` VALUES (22,'Campbell''s Frozen Entrees Savory Salisbury Steak with Gravy, 4.3 Pound Trays, 4-Pack','SALISBURY STEAK',120348,'8151','10051000081510','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2016-02-05','2023-03-16',NULL,'UNPREPARED',2492786,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Libby''s Frozen Supersweet Cut Corn - 30lb carton','FZ CRN SSWT CUT',120447,'F003710045193','10037100451934','Seneca Foods Corp','Libby''s','100348',3,'2016-02-05','2024-12-19',NULL,'UNPREPARED',2719686,'50102100');
INSERT INTO `cndb_fdes` VALUES (11,'Stokely''s Pumpkin - 24 pack, 15oz cans','PUMPKIN',120453,'F007022252972','10070222529723','Seneca Foods Corp','STOKELY''S','100319',3,'2016-02-05','2024-12-19',NULL,'UNPREPARED',2718901,'50102100');
INSERT INTO `cndb_fdes` VALUES (9,'Zee Zees Applesauce Cup, Wild Watermelon, 4.5 oz.','Wild Watermelon Applesauce',120472,NULL,'00810358030235','National Food Group  Inc.','Zee Zees',NULL,3,'2016-02-05','2023-04-27',NULL,'READY_TO_EAT',2521535,'50102000');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S FIESTADA WG CHEESE BEEF NET WT 24.48LBS 72CT CN','WG FIESTADA',120601,NULL,'10072180685237','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2017-01-26','2025-01-23',NULL,'UNPREPARED',2723023,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S 16" PRIMO BUFFALO CHICKEN CN','BD PRIMO BUF CKN',120605,NULL,'10072180786392','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2017-01-26','2024-12-19',NULL,'UNPREPARED',2719017,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S 16" PRIMO  FOUR  MEAT CN','BD PRIMO 4MT',120607,NULL,'10072180786408','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2017-01-26','2025-01-23',NULL,'UNPREPARED',2722486,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S PRIMO CHS PRESLCD 8-CUT NET WT 23.34LBS CN','BD PRIMO CHS',120608,NULL,'10072180786538','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2017-01-26','2024-12-19',NULL,'UNPREPARED',2719018,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S PRIMO PEPP PRESLCD 8-CUT NET WT 23.34LBS CN','BD PRIMO PEPP',120609,NULL,'10072180786545','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2017-01-26','2024-12-19',NULL,'UNPREPARED',2719019,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'2.5 lb Bag of Whole Grain Corn Masa Nacho Lil Bites','Nacho Lil Bites',120612,NULL,'00010374770447','The Father''s Table','Lil'' Bites',NULL,3,'2017-01-27','2023-10-26',NULL,'BAKE',2650573,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Triple Berry Crunch Bars','Triple Berry Crunch Bars',120617,NULL,'00010374011946','The Father''s Table','The Father''s Table Dunkers',NULL,3,'2017-01-27','2024-07-11',NULL,'PREPARED',2697858,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cherry Apple Crunch Bar','Cherry Apple Crunch Bar',120618,NULL,'00010374011977','The Father''s Table','The Father''s Table Dunkers',NULL,3,'2017-01-27','2024-07-11',NULL,'PREPARED',2697859,'50192300');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S PRIMO PB CHS 3-3PK NET WT 23.09LBS CN','BD PRIMO PB CHS',120620,NULL,'10072180685916','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2017-01-30','2025-01-23',NULL,'UNPREPARED',2722510,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S PRIMO PB PEPP 3-3PK NET WT 23.09LBS CN','BD PRIMO PB PEPP',120622,NULL,'10072180685923','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2017-01-30','2025-01-23',NULL,'UNPREPARED',2722647,'50182200');
INSERT INTO `cndb_fdes` VALUES (25,'Goldfish Baked with Whole Grain Cheddar Crackers Colors','PF FS GF CLRS WG',120668,'4788','10014100047886','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2017-05-01','2024-07-11',NULL,'UNPREPARED',2697058,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Low Fat Brownie','WG Low Fat Brownie',120765,NULL,'00711341822205','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-06-29',NULL,'UNPREPARED',2558278,'50192300');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Low Fat Brownie Bite','WG Low Fat Brownie Bite',120766,NULL,'00711341833300','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-06-29',NULL,'PREPARED',2558279,'50192300');
INSERT INTO `cndb_fdes` VALUES (22,'Whole Grain Reduced Fat Three Cheese Calzone','WG RF Three Cheese Calzone',120767,NULL,'00711341502312','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-06-29',NULL,'UNPREPARED',2558228,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'Whole Grain Reduced Fat Three Cheese Calzone','WG RF Three Cheese Calzone',120768,NULL,'00711341502411','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-08-31',NULL,'UNPREPARED',2613844,'50182200');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Cinnamon Crumble','WG Cinnamon Crumble',120769,NULL,'00711341900293','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-11-16',NULL,'PREPARED',2663181,'50182000');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Reduced Fat Chocolate Chip Cookie Dough','WG RF Chocolate Chip Cookie Dough',120771,NULL,'00711341780109','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-06-29',NULL,'UNPREPARED',2558269,'50181700');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Reduced Fat Chocolate Chip Cookie Dough','WG RF Chocolate Chip Cookie Dough',120772,NULL,'00711341780154','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-11-16',NULL,'UNPREPARED',2663177,'50181700');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Party Cookie','WG Party Cookie',120783,NULL,'00711341723205','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-11-16',NULL,'PREPARED',2663173,'50192300');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Reduced Fat Chocolate Chip Cookie','WG RF Chocolate Chip Cookie',120785,NULL,'00711341790153','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-08-31',NULL,'PREPARED',2613853,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Chocolate Chip Cookie','WG Chocolate Chip Cookie',120786,NULL,'00711341791853','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-11-16',NULL,'PREPARED',2663180,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Reduced Fat Snickerdoodle Cookie','WG RF Snickerdoodle Cookie',120790,NULL,'00711341796155','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-06-29',NULL,'PREPARED',2558274,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Reduced Fat Sugar Cookie','WG RF Sugar Cookie',120792,NULL,'00711341798159','Buena Vista Food Products','Linda''s Cookies',NULL,3,'2017-05-01','2023-06-29',NULL,'PREPARED',2558276,'50182100');
INSERT INTO `cndb_fdes` VALUES (22,'Whole Grain Reduced Fat Pepperoni Calzone','WG RF Turkey Pepperoni Calzone',120803,NULL,'00711341507119','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-06-29',NULL,'UNPREPARED',2558230,'50182200');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Christmas Tree Cookie','WG Christmas Tree Cookie',120804,NULL,'00711341712209','Buena Vista Food Products','Linda''s Cookies',NULL,3,'2017-05-01','2023-06-29',NULL,'UNPREPARED',2558258,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Holiday Star Cookie','WG Holiday Star Cookie',120805,NULL,'00711341714210','Buena Vista Food Products','Linda''s Cookies',NULL,3,'2017-05-01','2023-08-31',NULL,'PREPARED',2613851,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Green Egg Cookie','WG Green Egg Cookie',120806,NULL,'00711341716207','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-06-29',NULL,'PREPARED',2558260,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Pumpkin Cookie','WG Pumpkin Cookie',120807,NULL,'00711341728200','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-06-29',NULL,'PREPARED',2558263,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Shamrock Cookie','WG Shamrock Cookie',120808,NULL,'00711341729207','Buena Vista Food Products','Linda''s Cookies',NULL,3,'2017-05-01','2023-11-16',NULL,'PREPARED',2663175,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Turkey Cookie','WG Turkey Cookie',120809,NULL,'00711341737202','Buena Vista Food Products','Linda''s Cookies',NULL,3,'2017-05-01','2023-11-16',NULL,'PREPARED',2663190,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Valentine''s Cookie','WG Valentine''s Cookie',120810,NULL,'00711341738209','Buena Vista Food Products','Linda''s Cookies',NULL,3,'2017-05-01','2023-06-29',NULL,'PREPARED',2558266,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Yellow Star Cookie','WG Yellow Star Cookie',120811,NULL,'00711341739206','Buena Vista Food Products','Linda''s Cookies',NULL,3,'2017-05-01','2023-06-29',NULL,'PREPARED',2558267,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Blueberry Muffin Top','WG Blueberry Muffin Top',120813,NULL,'00711341631364','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2025-03-20',NULL,'PREPARED',2723322,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Double Chocolate Chip Muffin Top','WG Double Chocolate Chip Muffin Top',120814,NULL,'00711341631869','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2025-03-20',NULL,'PREPARED',2723323,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Sweet Potato Chocolate Chip Muffin Top','WG Sweet Potato Chocolate Chip Muff',120815,NULL,'00711341632187','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2025-03-20',NULL,'PREPARED',2723324,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Banana Muffin','WG Banana Muffin',120818,NULL,'00711341602265','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2025-03-20',NULL,'PREPARED',2723321,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Blueberry Muffin','WG Blueberry Muffin',120819,NULL,'00711341603262','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-08-31',NULL,'PREPARED',2613846,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Cheesy Cornbread Muffin','WG Cheesy Cornbread Muffin',120820,NULL,'00711341605211','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-11-16',NULL,'PREPARED',2663165,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Double Chocolate Chip Muffin','WG Double Chocolate Chip Muffin',120821,NULL,'00711341609417','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-06-29',NULL,'PREPARED',2558247,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Cornbread Loaf','WG Cornbread Loaf',120831,NULL,'00711341641615','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-11-16',NULL,'PREPARED',2663170,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Cornbread Muffin','WG Cornbread Muffin',120832,NULL,'00711341641738','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-11-16',NULL,'PREPARED',2663171,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Blueberry Muffin Top','WG Blueberry Muffin Top',120837,NULL,'00711341631319','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-06-29',NULL,'PREPARED',2558250,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Double Chocolate Chip Muffin Top','WG Double Chocolate Chip Muffin Top',120838,NULL,'00711341631814','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-08-31',NULL,'UNPREPARED',2613848,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Sweet Potato Chocolate Chip Muffin Top','WG Sweet Potato Chocoalte Chip Muff',120839,NULL,'00711341632118','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-06-29',NULL,'PREPARED',2558254,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Blueberry Crumble','WG Blueberry Crumble',120858,NULL,'00711341900606','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2017-05-01','2023-11-16',NULL,'PREPARED',2663182,'50182000');
INSERT INTO `cndb_fdes` VALUES (11,'Hart Low Sodium Mixed Sieve Cut Green Beans - 6 pack, 101oz cans','GRN BNS CUT MX SV LOW SOD',120869,'F007022257260','10070222572606','Seneca Foods Corp','HART','100307',3,'2017-05-01','2024-12-19',NULL,'UNPREPARED',2718902,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hart Low Sodium Mixed Sieve Sweet Peas 106oz','SWEET PEAS MX SV LOW SOD',120873,'F007022257427','00070222074271','Seneca Foods Corp','HART','100315',3,'2017-05-01','2024-12-19',NULL,'UNPREPARED',2718519,'50102100');
INSERT INTO `cndb_fdes` VALUES (11,'Hart No Salt Whole Kernel Corn - 6 pack, 106oz cans','CORN WK N/S',120876,'F007022257377','10070222573771','Seneca Foods Corp','HART','100313',3,'2017-05-01','2024-12-19',NULL,'UNPREPARED',2718904,'50102100');
INSERT INTO `cndb_fdes` VALUES (11,'Hart Low Sodium Seasoned Refried Beans - 24 pack, 16oz cans','REFRD BNS',120884,'F007022207271','10070222072717','Seneca Foods Corp','HART','120884',3,'2017-05-01','2024-12-19',NULL,'UNPREPARED',2718896,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hart Low Sodium Seasoned Refried Beans 112oz','REFRD BNS SEASND',120885,'F007022207382','00070222073823','Seneca Foods Corp','HART','100362',3,'2017-05-01','2024-12-19',NULL,'UNPREPARED',2718518,'50102100');
INSERT INTO `cndb_fdes` VALUES (1,'Colby Cheese Omelet, 225/2.1 oz. Frozen, Bulk','COLBY CHS OMLT',120909,NULL,'10038057401768','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2017-05-01','2024-07-11',NULL,'PREPARED',2696376,'50132500');
INSERT INTO `cndb_fdes` VALUES (1,'Grilled Scrambled Egg Patty, 369/1.25 oz., Frozen, Bulk','Scrm EGGPTY GRILL',120916,NULL,'10038057407104','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2017-05-01','2024-07-11',NULL,'PREPARED',2696378,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tangerine Chicken','Tangerine Chicken',120931,NULL,'00856235005019','International Food Solutions, Inc.','GREEN DRAGON',NULL,3,'2017-05-01','2023-12-21',NULL,'PREPARED',2680804,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'General Tso''s Chicken','General Tso''s Chicken',120932,NULL,'00856235005026','International Food Solutions, Inc.','GREEN DRAGON',NULL,3,'2017-05-01','2024-08-15',NULL,'PREPARED',2701025,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Japanese Cherry Blossom Chicken','Japanese Cherry Blossom Chicken',120933,NULL,'00856235005033','International Food Solutions, Inc.','GREEN DRAGON',NULL,3,'2017-05-01','2023-12-21',NULL,'PREPARED',2680806,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sriracha Honey Chicken','Sriracha Honey Chicken',120935,NULL,'00856235005415','International Food Solutions, Inc.','GREEN DRAGON',NULL,3,'2017-05-01','2023-12-21',NULL,'PREPARED',2680807,'50240100');
INSERT INTO `cndb_fdes` VALUES (5,'Sliced, Oven Roasted Turkey Breast, Reduced Sodium, K-12','SBF Sld OR Tky Reduced Sodium',120942,NULL,'10642205011480','Cargill Incorporated/Honeysuckle White','Shady Brook Farms',NULL,3,'2017-05-01','2023-10-26',NULL,'PREPARED',2649525,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'1 OZ WG BREADED FORMED FISH NUGGETS, PAR FRIED, FROZEN, OVEN READY.','OC TREAS O/R PLK CN WG',121018,NULL,'00028029183009','Trident Seafoods Corp.','Ocean Treasures',NULL,3,'2017-05-01','2025-04-24',NULL,'UNPREPARED',2730766,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'ULTIMATE FISH STICK 1OZ ALL NATURAL WHOLE GRAIN CRUNCHY BREADED, FROZEN','ULTIM FISH STICK CN 1 0Z NAT WG',121019,NULL,'00028029183016','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2017-05-01','2025-04-24',NULL,'UNPREPARED',2730776,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'AK POLLOCK, CRUNCHY BREADED 3.6 OZ WHOLE GRAIN RECTANGLE PORTIONS PAR FRIED OVEN READY','POLLOCK, REC 3.6 Z ALSKN BRDD WG',121020,NULL,'00028029183023','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2017-05-01','2025-04-24',NULL,'UNPREPARED',2730767,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'POLLOCK, 1.5 OZ CRUNCHY WHOLE GRAIN, CORNMEAL BREADED FISH STRIPS, PAR FRIED','POLLOCK, STRIP 1.5 Z BRDD CRNM WG',121021,NULL,'00028029183030','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2017-05-01','2025-04-24',NULL,'UNPREPARED',2730768,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'POLLOCK OVEN READY 1 OZ WHOLE GRAIN BREADED BAJA FISH STICKS','CN PLK O/R 1OZ BAJA WG',121022,NULL,'00028029183047','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2017-05-01','2025-04-24',NULL,'UNPREPARED',2730769,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'POLLOCK WHOLE GRAIN BREADED NUGGET PARFRIED BONELESS OVEN READY FROZEN','POLLOCK, NGT BNLS BRD O/R CN WG',121023,NULL,'00028029183054','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2017-05-01','2025-04-24',NULL,'UNPREPARED',2730770,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'POLLOCK PORTION 4 OZ WEDGE BATTER DIPT, RAW, FROZEN','PLK O/R 4OZ BTRD PTN CN WG',121024,NULL,'00028029183061','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2017-05-01','2025-03-20',NULL,'UNPREPARED',2723867,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'POLLOCK, 3 OZ, WILD, WHOLE GRAIN BREADED PRECOOKED OVEN READY, CN','PLK 3Z PTN BRD O/R CN WG',121034,NULL,'00028029183177','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2017-05-01','2025-04-24',NULL,'PREPARED',2730771,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'DNU-ALASKA POLLOCK WG BREADED 3.6 OZ HOAGIE PORTIONS OVEN READY COOKED','POLLOCK, HOGIE 3.6 Z AK WG BRD',121035,NULL,'00028029183184','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2017-05-01','2025-04-24',NULL,'UNPREPARED',2730772,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'POLLOCK & CHEESE NUGGETS 1 OZ FORMED WHOLE GRAIN BREADED PARFRIED','TR CN PLK O/R HIDDEN TREAS WG',121036,NULL,'00028029183191','Trident Seafoods Corp.','Hidden Treasures',NULL,3,'2017-05-01','2024-06-13',NULL,'UNPREPARED',2694784,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'WHOLE GRAIN CRUNCHY BREADED WILD CAUGHT POLLOCK WEDGE 3.6 OZ PORTIONS','TR CN PLK O/R WDG 3.6OZ KRUNCH WG',121037,NULL,'00028029183207','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2017-05-01','2025-04-24',NULL,'UNPREPARED',2730773,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'POLLOCK OVEN READY WHOLE GRAIN BREADED 4 OZ PORTIONS','CN PLK O/R BRD PTN 4OZ WG',121038,NULL,'00028029183214','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2017-05-01','2025-04-24',NULL,'UNPREPARED',2730774,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'TR POLLOCK CRUNCHY NUGGETS 1OZ BREADED OVEN READY,  WHOLE GRAIN COATED, WILD ALASKA POLLOCK','PLK O/R NUGGET 1 OZ CN WG',121039,NULL,'00028029183221','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2017-05-01','2024-08-15',NULL,'UNPREPARED',2703261,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'POLLOCK 1 OZ CRUNCHY BREADED FISH STICKS, OVEN READY.','CN PLK O/R 1OZ BAJA WG',121040,NULL,'00028029183238','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2017-05-01','2024-08-15',NULL,'UNPREPARED',2703260,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'BREADED POLLOCK CN PORTIONS 3.6OZ RECTANCLE, WG, FROZEN.','PLK BRD WG CN 3.6OZ',121041,NULL,'00028029183245','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2017-05-01','2024-08-15',NULL,'UNPREPARED',2703259,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'COD, NUGGET 1 OZ WHOLE GRAIN CRUNCHY BREADED BONELESS-SKINLESS FROZEN OVEN READY','BRDD COD NUGT 1 OZ WG',121042,NULL,'00028029208382','Trident Seafoods Corp.','Interstate Seafoods',NULL,3,'2017-05-01','2024-10-31',NULL,'UNPREPARED',2716773,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'COD, BREADED 3.6 OZ WHOLE GRAIN RECTANGLE CN PORTIONS PAR FRIED OVEN READY','COD, REC 3.6 Z BRDD WG',121043,NULL,'00028029208399','Trident Seafoods Corp.','Interstate Seafoods',NULL,3,'2017-05-01','2024-08-15',NULL,'UNPREPARED',2703258,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'CRUNCHY POTATO BREADED FISH STICKS 1OZ, FROZEN. CHILD NUTRITION PRODUCT.','POTATO PLK STICKS OR CN',121044,NULL,'00028029220711','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2017-05-01','2024-12-19',NULL,'UNPREPARED',2721737,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'POTATO COATED POLLOCK WEDGE 3.6OZ PORTIONS,WILD CAUGHT, FROZEN, CHILD NUTRITION PRODUCT.','PLK WDGE POTATO 3.6OZ OR CN',121045,NULL,'00028029220728','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2017-05-01','2025-04-24',NULL,'UNPREPARED',2730775,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Biscuits, Buttermilk, Whole Grain, Frozen Dough','Biscuits, Btrmlk, WG, Frozen Dough',121111,NULL,'00737410102306','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701079,'50193300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Blueberry, Reduced Fat, Individually Wrapped, Retail','Muffins, WG, Blueberry, RF, IW, RTL',121114,NULL,'00737410120102','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701097,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Banana, Reduced Fat, Individually Wrapped, Retail','Muffins, WG, Banana, RF, IW, RTL',121115,NULL,'00737410120201','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701090,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Apple Cinnamon, Reduced Fat, Individually Wrapped, Retail','Muffins, WG, Apl Cinn, RF, IW, RTL',121116,NULL,'00737410120300','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701104,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Chocolate Chip, Reduced Fat, Individually Wrapped, Retail','Muffins, WG, Choc Chip, RF, IW, RTL',121117,NULL,'00737410120409','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701103,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Muffins, Whole Grain, Blueberry, Reduced Fat, Individually Wrapped','CLOSEOUT Muffins, WG, Blueb, RF, IW',121120,NULL,'00737410121109','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-06-29',NULL,'UNPREPARED',2558451,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Banana, Individually Wrapped','Muffins, Whole Grain, Banana, IW',121121,NULL,'00737410122205','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701102,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Muffins, Whole Grain, Chocolate Chip, Individually Wrapped','CLOSEOUT Muffins, WG, Choc Chip, IW',121122,NULL,'00737410122304','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-06-29',NULL,'UNPREPARED',2558453,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Blueberry, Individually Wrapped, 5.25" x 3.5"','Muffins, WG, Blueb, IW, 5.25"x3.5"',121124,NULL,'00737410122502','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-04-24',NULL,'UNPREPARED',2730169,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Cornbread, Individually Wrapped, 2.5" x 2"','Muffins, WG, Cornbread, IW, 2.5"x2"',121128,NULL,'00737410127705','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701099,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Cornbread, Individually Wrapped','Muffins, Whole Grain, Cornbread, IW',121129,NULL,'00737410127804','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701105,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Blueberry, Individually Wrapped','Muffins, Whole Grain, Blueberry, IW',121136,NULL,'00737410131405','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701096,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mini Loaf, Cornbread, Individually Wrapped, Retail, 3.25" x 1.5"','Mini Loaf Crnbrd IW RTL 3.25"x1.5"',121137,NULL,'10033547514058','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701265,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mini Loaf, Whole Grain, Cornbread, Tray Packed, 4/35s, 3.25" x 1.5"','Mini Loaf WG Crnbrd Tray Pk 4/35s',121138,NULL,'00737410131702','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701095,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Banana, Individually Wrapped','Muffins, Whole Grain, Banana, IW',121139,NULL,'00737410132402','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701094,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Chocolate Chocolate Chip, Individually Wrapped','Muffins, WG, Choc Choc Chip, IW',121140,NULL,'00737410132501','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-02-16',NULL,'UNPREPARED',2458096,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Apple Cinnamon, Individually Wrapped','Muffins, WG, Apple Cinnamon, IW',121141,NULL,'00737410133607','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701093,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Chocolate Chip, Individually Wrapped','Muffins, Chocolate Chip, IW',121144,NULL,'00737410134505','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701092,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Banana, Low Fat, Individually Wrapped','Muffins, Banana, Low Fat, IW',121147,NULL,'00737410136103','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2022-09-15',NULL,'UNPREPARED',2335764,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Orange Dream, Individually Wrapped','Muffins, WG, Orange Dream, IW',121152,NULL,'00737410138909','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701091,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Chocolate Chip, Individually Wrapped','Muffins, WG, Chocolate Chip, IW',121153,NULL,'00737410139203','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701106,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Golden Cornbread, Individually Wrapped','Muffins, Golden Cornbread, IW',121154,NULL,'00737410139401','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701143,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hoagie Rolls, Whole Grain, Split Top, Hinge Sliced, 5"','Hoagies, WG, Spl Top, Hinge Sl, 5"',121155,NULL,'00737410140100','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521407,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mini Loaf, Whole Grain, Chocolate Chocolate Chip, Reduced Fat, Individually Wrapped','Mini Loaf WG Choc Choc Chip RF IW',121156,NULL,'00737410141404','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-02-16',NULL,'UNPREPARED',2458150,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hoagie Rolls, Whole Grain, Split Top, Fully Sliced, 5.5"','Hoagies, WG, Spl Top, Flly Sl, 5.5"',121157,NULL,'00737410141503','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701178,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Waffles, Round, Bulk, 4"','Waffles, Round, Bulk, 4"',121158,NULL,'00737410143002','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701144,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pancakes, Buttermilk, Bulk, 4"','Pancakes, Buttermilk, Bulk, 4"',121159,NULL,'00737410143101','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-07-11',NULL,'UNPREPARED',2697068,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Waffles, Whole Grain, Wholesome Choice, Gourmet, Bulk, 4"','Waffles WG Wholesome Choice Gourmet',121161,NULL,'00737410145303','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701194,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Waffles, Whole Grain, Wholesome Choice, Gourmet, 2 Pack, 4"','Waffles WG Wholesome Choice Gourmet',121162,NULL,'00737410145402','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521409,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pancakes, Whole Grain, Wholesome Choice, Buttermilk, Bulk, 4"','Pancakes WG Wholesome Choice Btrmlk',121163,NULL,'00737410147505','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701193,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pancakes, Whole Grain, Wholesome Choice, Buttermilk, 2 Pack','Pancakes WG Wholesome Choice Btrmlk',121164,NULL,'00737410147604','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521410,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pancakes, Whole Grain, Wholesome Choice, Buttermilk, Maple Cinnamon, 2 Pack, 4"','Pancakes WG Wholesome Choice Btrmlk',121165,NULL,'00737410147802','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701192,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Mini Wild Blueberry, Tray Pack','Muffins, Mini Wild Blueb, Tray Pk',121168,NULL,'00737410154206','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521412,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Muffins, Banana, Tray Pack','CLOSEOUT Muffins, Banana, Tray Pack',121169,NULL,'00737410154602','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-06-29',NULL,'UNPREPARED',2558478,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Waffles, Whole Grain, Wholesome Choice, Maple, 4.25"','Waffles WG Wholesome Choice Mpl 4.2',121170,NULL,'00737410155609','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-09-13',NULL,'UNPREPARED',2704181,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Waffles, Whole Grain, Maple Blueberry, Bulk, 4"','CLOSEOUT Waffles WG Mpl Blueb Blk 4',121171,NULL,'00737410155807','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-06-29',NULL,'UNPREPARED',2558480,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Waffles, Whole Grain, Wholesome Choice, Maple, 2 Pack, 4"','Waffles WG Wholesome Choice Mpl 2 P',121174,NULL,'00737410156309','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-09-13',NULL,'UNPREPARED',2704180,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Waffles, Whole Grain, Wholesome Choice, Cinnamon, 2 Pack, 4"','Waffles WG Wholesome Choice Cinn 2',121175,NULL,'00737410156507','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521413,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pancakes, Whole Grain, Buttermilk, Blueberry, 2 Pack, 4"','Pancakes WG Btrmlk Blueb 2 Pk 4"',121176,NULL,'00737410156705','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-07-11',NULL,'UNPREPARED',2697069,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pancakes, Whole Grain, Wholesome Choice, Maple Chip Mini, 3", Bulk, approx 324','Pancakes WG Wholesome Choice Mpl Ch',121177,NULL,'00737410158105','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-10-31',NULL,'UNPREPARED',2716312,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Waffles, Whole Grain, Wholesome Choice, Maple Chip Mini, 3", Bulk','Waffles WG Wholesome Choice Mpl Chi',121179,NULL,'00737410015842','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-09-13',NULL,'UNPREPARED',2704189,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Waffles, Whole Grain, Wholesome Choice, Maple Chip Mini, 3", 4 Pack','Waffles WG Wholesome Choice Mpl Chi',121180,NULL,'00737410015897','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-09-13',NULL,'UNPREPARED',2704167,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Waffles, Whole Grain, Blueberry, 2 Pack','Waffles, WG, Blueberry, 2 Pk',121181,NULL,'00737410015910','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521349,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Texas Toast, Whole Grain, Garlic, Reduced Fat, Low Sodium, Bulk','Texas Toast, WG, Gar, RF, LS, Blk',121184,NULL,'00737410160504','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701188,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Texas Toast, Whole Grain, Margarine, Low Fat, Low Sodium, Bulk','Texas Toast, WG, Marg, LF, LS, Blk',121185,NULL,'00737410161105','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-07-11',NULL,'UNPREPARED',2697070,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Texas Toast, Whole Grain, Garlic, Reduced Fat, Individually Wrapped','Texas Toast, WG, Garlic, RF, IW',121187,NULL,'00737410161600','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701186,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bread Sticks, Whole Grain, Mozzarella Stuffed, Garlic, 7"','Brd Stks, WG, Mozz Stuffed, Gar, 7"',121188,NULL,'00737410016177','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521351,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bread Sticks, Whole Grain, Mozzarella Stuffed, Garlic, 5"','Brd Stks, WG, Mozz Stuffed, Gar, 5"',121190,NULL,'00737410016214','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521352,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Texas Toast, Whole Grain, Garlic, Low Fat, Low Sodium, Bulk, 4.5" x 3"','Texas Tst WG Gar LF LS Blk 4.5"x3"',121194,NULL,'00737410162706','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-07-11',NULL,'UNPREPARED',2697071,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bread Sticks, Whole Grain, Reduced Sodium, Garlic, Heat & Serve, 7"','Bread Stks, WG, RS, Gar, Ht&Srv, 7"',121195,NULL,'00737410163703','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-07-11',NULL,'UNPREPARED',2697072,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bread Sticks, Whole Grain, Low Sodium, Garlic, 5"','Bread Sticks, WG, LS, Garlic, 5"',121196,NULL,'00737410163802','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701185,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Dinner Rolls, Whole Grain, Low Sodium, Smooth Top','Dinner Rolls, WG, LS, Smooth Top',121197,NULL,'00737410164502','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-12-19',NULL,'UNPREPARED',2719706,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Texas Toast, Whole Grain, Garlic, Reduced Fat, Reduced Sodium, Bulk, 4.5" x 3"','Texas Tst WG Gar RF RS Blk 4.5"x3"',121198,NULL,'00737410164700','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521419,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Whole Grain, Margarine, Fully Curved, Sliced, 4" x 1.75"','Croiss, WG, Marg, FC, Sl, 4"x1.75"',121199,NULL,'00737410165103','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521420,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Margarine, Fully Curved, Sliced','Croissants, Marg, Fully Curved, Sl',121201,NULL,'00737410165608','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521421,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mini Breakfast Bites, Whole Grain, Apple, 4 Pack','Mini Breakfast Bites, WG, Apl, 4 Pk',121203,NULL,'00737410171609','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701183,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mini Breakfast Bites, Glazed, Whole Grain, 4 Pack','Mini Breakfast Bites, Glz, WG, 4 Pk',121204,NULL,'00737410171708','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701182,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'INACTIVE - Honey Bun, Capt''n Gregory Fortified, Individually Wrapped','Honey Bun, Capt''n Gregory Fort, IW',121209,NULL,'00737410180809','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521425,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'INACTIVE - Donuts, Powdered Sugar, Individually Wrapped','Donuts, Powdered Sugar, IW',121211,NULL,'00737410181004','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521426,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breakfast Buns, Individually Wrapped','Breakfast Buns, IW',121215,NULL,'00737410181608','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521428,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'INACTIVE - Donuts, Yeast, Glazed, Bulk','Donuts, Yeast, Glazed, Bulk',121226,NULL,'00737410185101','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521429,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breakfast Buns, Whole Grain, Reduced Fat, Fortified, Individually Wrapped','Breakfast Buns, WG, RF, Fort, IW',121228,NULL,'00737410185606','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521430,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Donuts, Whole Grain, Glazed Cake, Reduced Fat, Fortified, Individually Wrapped','Donuts, WG, Glz Cake, RF, Fort, IW',121229,NULL,'00737410187907','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521431,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'INACTIVE - Donuts, Whole Grain, Powdered Sugar Cake, Reduced Fat, Fortified, Individually Wrapped','Donuts WG Pwdred Sugar Cake RF Fort',121235,NULL,'00737410191508','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521432,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Donuts, Whole Grain, Powdered Sugar Cake, Reduced Fat, Fortified, Individually Wrapped','Donuts WG Pwdred Sugar Cake RF Fort',121237,NULL,'00737410192109','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-02-16',NULL,'UNPREPARED',2458102,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Donuts, Crispy King, Yeast Raised, Thaw & Finish','Donuts Crispy King Yeast Thaw&Fin',121238,NULL,'00737410192505','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-02-16',NULL,'UNPREPARED',2458088,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breakfast Buns, Whole Grain, Reduced Fat, Fortified, Individually Wrapped','Breakfast Buns, WG, RF, Fort, IW',121243,NULL,'00737410194905','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521433,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breakfast Buns, Whole Grain, Reduced Fat, Fortified, Individually Wrapped','Breakfast Buns, WG, RF, Fort, IW',121247,NULL,'00737410200309','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701181,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Biscuits, Honey Wheat, Whole Grain, Pillow Pack, Sliced, 3" x 1"','Biscs Hny Wht WG Pillow Pk Sl 3"x1"',121248,NULL,'00737410201504','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-10-31',NULL,'UNPREPARED',2716311,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Biscuits, Honey Wheat, Whole Grain, Low Sodium, Pillow Pack, Sliced, 2.25" x 1"','Biscs Hny Wht WG LS Pillow Pk Sl 2.',121250,NULL,'00737410201702','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-10-31',NULL,'UNPREPARED',2716310,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mini Loaf, Whole Grain, Cornbread, Individually Wrapped, 3.25" x 1.5"','Mini Loaf WG Crnbrd IW 3.25"x1.5"',121257,NULL,'00737410211107','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701205,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Orange Dream, Individually Wrapped','Muffins, WG, Orange Dream, IW',121258,NULL,'00737410211305','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701198,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Apple Fritter, Individually Wrapped','Apple Fritter, Individually Wrapped',121260,NULL,'00737410213408','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521437,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'INACTIVE - Donuts, Whole Grain, Yeast Raised, Reduced Fat, Fortified, Individually Wrapped','Donuts, WG, Yeast, RF, Fort, IW',121261,NULL,'00737410213903','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521438,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Chocolate Chocolate Chip, Reduced Fat, Individually Wrapped','Muffins, WG, Choc Choc Chip, RF, IW',121265,NULL,'00737410215600','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701212,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Blueberry, Individually Wrapped','Muffins, Whole Grain, Blueberry, IW',121266,NULL,'00737410216409','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701211,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Apple Cinnamon, Individually Wrapped','Muffins, WG, Apple Cinnamon, IW',121267,NULL,'00737410216508','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701210,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Banana, Individually Wrapped','Muffins, Whole Grain, Banana, IW',121268,NULL,'00737410216607','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701209,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Chocolate Chip, Individually Wrapped','Muffins, WG, Chocolate Chip, IW',121269,NULL,'00737410216706','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701208,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Cornbread, Individually Wrapped','Muffins, Whole Grain, Cornbread, IW',121271,NULL,'00737410217505','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701207,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Granola, Cinnamon, Whole Grain, Wholesome Choice, Individually Wrapped, Retail, 3" x 4"','Granola Cinn WG Wholesome Choice IW',121272,NULL,'00737410022642','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2699598,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Granola, Cinnamon, Whole Grain, Wholesome Choice, Bulk','CLOSEOUT Granola Cinn WG Wholesome',121273,NULL,'00737410022659','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-06-29',NULL,'UNPREPARED',2558365,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Whole Grain, Margarine, Reduced Fat, Round, Fully Sliced, 3.5" x 1.5"','Croiss WG Marg RF Rnd Flly Sl',121299,NULL,'00737410328409','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521440,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Margarine, Round, Fully Sliced, 3.9" x 1.8"','Croiss Marg Rnd Flly Sl 3.9"x1.8"',121300,NULL,'00737410328508','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521441,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Whole Grain, Margarine, Reduced Fat, Round, Fully Sliced, 3.9" x 1.8"','Croiss WG Marg RF Rnd Flly Sl',121301,NULL,'00737410328607','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521442,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Dinner Rolls, Whole Grain, Low Sodium, Smooth Top','CLOSEOUT Din Rls, WG, LS, Smth Top',121304,NULL,'00737410334301','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-01-23',NULL,'UNPREPARED',2722758,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hot Dog Buns, Whole Grain White, 6" Individually Wrapped','Hot Dog Buns, WG White, 6" IW',121305,NULL,'00737410334400','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521444,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pullman Bread, White, Sliced Loaf','Pullman Bread, White, Sliced Loaf',121306,NULL,'00737410334905','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-04-24',NULL,'UNPREPARED',2730170,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pullman Bread, Whole Grain, 1 Slice, Individually Wrapped','Pullman Bread, WG, 1 Slice, IW',121308,NULL,'00737410335100','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701203,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pullman Bread, Whole Grain, Sliced Loaf, 4" x 4"','Pullman Bread, WG, Sl Loaf, 4"x4"',121309,NULL,'00737410335209','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701202,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pullman Bread, Whole Grain White, 1/2 in. Sliced Loaf, 4" x 4"','Pullman Brd WG Whi 1/2 in. Sl Loaf ',121310,NULL,'00737410335704','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-04-24',NULL,'UNPREPARED',2730172,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mini Loaf, Banana, Individually Wrapped, 3.25" x 1.5"','Mini Loaf, Banana, IW, 3.25" x 1.5"',121313,NULL,'00737410346007','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521447,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hamburger Buns, Whole Grain, Sliced, 3"','Hamburger Buns, WG, Sliced, 3"',121315,NULL,'00737410347400','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701200,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hamburger Buns, Whole Grain White, Sliced, 3.75"','Hamburger Buns, WG Whi, Sl, 3.75"',121319,NULL,'00737410352206','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-03-20',NULL,'UNPREPARED',2724131,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Yeast Rolls, Whole Grain, Warm & Serve','Yeast Rolls, WG, Warm & Serve',121321,NULL,'00737410361604','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521448,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bread Sticks, Whole Grain, Low Sodium, Heat and Serve, 7"','Bread Stks, WG, LS, Ht&Srv, 7"',121323,NULL,'00737410400501','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-07-11',NULL,'UNPREPARED',2697073,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hoagie Roll, French Cut, Unsliced, 8"','Hoagie Roll, Fr Cut, Unsliced, 8"',121324,NULL,'00737410400600','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521450,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hoagie Rolls, White, Split Top, Unsliced, 12"','Hoagies, Whi, Split Top, Unsl, 12"',121326,NULL,'00737410401706','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-06-29',NULL,'UNPREPARED',2558514,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Dinner Rolls, Whole Grain, Split Top, Individually Wrapped','Dinner Rolls, WG, Split Top, IW',121328,NULL,'00737410402703','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-12-19',NULL,'UNPREPARED',2719708,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hoagie Rolls, White, Pan Baked, Split Top, Hinge Sliced, 6"','Hoagies Whi Pan Bkd SplTop HngSl 6"',121329,NULL,'00737410403007','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-12-19',NULL,'UNPREPARED',2719709,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hoagie Roll, Thin, Split Top, Unsliced, Hearth Baked, 7"','Hoagie Rl Thin SplTop Unsl Hrth Bkd',121333,NULL,'00737410404608','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-10-26',NULL,'UNPREPARED',2649077,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hoagie Rolls, Whole Grain, Split Top, Sliced, Pull Apart, 4" each','Hoagies WG SplTop Sl Pul-Aprt 4" ea',121334,NULL,'00737410404707','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-04-27',NULL,'UNPREPARED',2521454,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hoagie Rolls, Whole Grain, Pan Baked, Split Top, Hinge Sliced, 6"','Hoagies WG Pan Bkd SplTop HngSl 6"',121335,NULL,'00737410404806','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-12-19',NULL,'UNPREPARED',2719710,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hoagie Rolls, Whole Grain, Pan Baked, Sm Top, Hinge Sliced, 7"','Hoagies WG Pan Bkd Sm Top HngSl 7"',121336,NULL,'00737410404905','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-11-14',NULL,'UNPREPARED',2716945,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hoagie Roll, White, Split Top, Hinge Sliced, 12"','Hoagie Rl, Whi, Spl Top, HngSl, 12"',121337,NULL,'00737410405001','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-08-31',NULL,'UNPREPARED',2613894,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Dinner Rolls, Whole Grain, Split Top, Bulk','Dinner Rolls, WG, Split Top, Blk',121338,NULL,'00737410406107','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-12-19',NULL,'UNPREPARED',2719711,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hoagie Rolls, Whole Grain, Split Top, Hinge Sliced, 5.5"','Hoagies, WG, Spl Top, Hng Sl, 5.5"',121339,NULL,'00737410406206','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-12-19',NULL,'UNPREPARED',2719712,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Dinner Rolls, Whole Grain, Hearth Baked, Split Top','Dinner Rolls, WG, Hrth Bkd, Spl Top',121341,NULL,'00737410406404','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-12-19',NULL,'UNPREPARED',2719713,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kaiser Bun, Whole Grain White, Small, Sliced, 3.75"','Kaiser Bun WG Whi Small Sl 3.75"',121342,NULL,'00737410406701','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-12-19',NULL,'UNPREPARED',2719714,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hoagie Rolls, Wheat, Hearth Baked, Split Top, Hinge Sliced 12"','Hoagies Wheat Hrth Bkd SplTop HngSl',121352,NULL,'00737410409603','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-10-26',NULL,'UNPREPARED',2649081,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hoagie Rolls, White, Pan Baked, Split Top, Fully Sliced, 6"','Hoagies Whi Pan Bkd SplTop Flly Sl',121353,NULL,'00737410409702','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-08-31',NULL,'UNPREPARED',2613896,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hamburger Buns, Whole Grain, Hawaiian, Wholesome Choice, Fully Sliced, 3.5"','Hamb Buns WG Haw Wholesome Choice F',121356,NULL,'00737410041025','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-02-16',NULL,'UNPREPARED',2458089,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Slider Buns, Whole Grain, Hawaiian, Wholesome Choice, Fully Sliced, 2.5" x 2.5"','Sliders WG Haw Wholesome Choice Fll',121357,NULL,'00737410041032','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-12-19',NULL,'UNPREPARED',2719698,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mini Loaf, Whole Grain, Blueberry, Reduced Fat, Individually Wrapped','Mini Loaf, WG, Blueberry, RF, IW',121359,NULL,'00737410411002','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701154,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mini Loaf, Whole Grain, Banana, Reduced Fat, Individually Wrapped, 4.75" x 2.25"','Mini Loaf WG Ban RF IW 4.75"x2.25"',121360,NULL,'00737410412009','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701153,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Mini Loaf, Whole Grain, Apple Cinnamon, Reduced Fat, Individually Wrapped, 4.75" x 2.25"','CLOSEOUT Mini Loaf WG Apl Cinn RF I',121361,NULL,'00737410413006','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-01-23',NULL,'UNPREPARED',2722251,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hot Dog Buns, White, 6"','Hot Dog Buns, White, 6"',121362,NULL,'00737410423005','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-07-11',NULL,'UNPREPARED',2697074,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hot Dog Buns, Whole Grain White, 6"','Hot Dog Buns, Whole Grain White, 6"',121363,NULL,'00737410425009','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701152,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'French Toast Sticks, Whole Grain (approx. 140-150 pieces)','Fr Tst Stks WG (approx. 140-150 pie',121364,NULL,'00737410442006','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701150,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'French Toast Sticks, Whole Grain (approx. 105-111 pieces)','Fr Tst Stks WG (approx. 105-111 pie',121365,NULL,'00737410447001','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-10-31',NULL,'UNPREPARED',2716309,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'French Toast Sticks, Whole Grain, 2 Pack','French Toast Sticks, WG, 2 Pk',121366,NULL,'00737410449005','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-10-31',NULL,'UNPREPARED',2716308,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hamburger Buns, Whole Grain White, Sliced, 3.75"','Hamburger Buns, WG Whi, Sl, 3.75"',121367,NULL,'00737410453002','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701147,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'French Toast Sticks, Whole Grain, Wholesome Choice (approx. 140-150 pieces)','Fr Tst Stks WG Wholesome Choice (ap',121368,NULL,'00737410004549','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-03-20',NULL,'UNPREPARED',2724097,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Biscuit, Whole Grain, Chicken Sausage, Individually Wrapped','Sandwich, Biscuit, WG, Chkn Ssg, IW',121369,NULL,'00737410454603','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-07-11',NULL,'UNPREPARED',2697075,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'French Toast Sticks, Whole Grain, Wholesome Choice (approx. 105-111 pieces)','Fr Tst Stks WG Wholesome Choice (ap',121370,NULL,'00737410455006','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-03-20',NULL,'UNPREPARED',2724132,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'French Toast Sticks, Whole Grain, Wholesome Choice, Individually Wrapped','Fr Tst Stks WG Wholesome Choice IW',121371,NULL,'00737410456003','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-03-20',NULL,'UNPREPARED',2724133,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Biscuit, Honey Whole Grain, Chicken Sausage, Individually Wrapped','Sndwch Bisc Honey WG Chkn Ssg IW',121372,NULL,'00737410460208','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701151,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hot Dog Buns, Whole Grain White, 6"','Hot Dog Buns, Whole Grain White, 6"',121378,NULL,'00737410471006','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701161,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hamburger Buns, Whole Grain, Sliced, 3.75"','Hamburger Buns, WG, Sliced, 3.75"',121382,NULL,'00737410472003','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-07-11',NULL,'UNPREPARED',2697076,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hamburger Buns, White, 4", Sliced','Hamburger Buns, White, 4", Sliced',121388,NULL,'00737410487007','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-04-24',NULL,'UNPREPARED',2730197,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hamburger Buns, Whole Grain White, Sliced, 3.75"','Hamburger Buns, WG Whi, Sl, 3.75"',121390,NULL,'00737410492001','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-03-20',NULL,'UNPREPARED',2724134,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bread Sticks, Whole Grain, Low Sodium, Pan Baked, 7"','Bread Sticks, WG, LS, Pan Baked, 7"',121392,NULL,'00737410500904','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-07-11',NULL,'UNPREPARED',2697078,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bread Sticks, Whole Grain, Low Sodium, 5"','Bread Sticks, Whole Grain, LS, 5"',121393,NULL,'00737410501109','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-07-11',NULL,'UNPREPARED',2697079,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fun Buns/Slider, Whole Grain, Sliced, 2.5"','Fun Buns/Slider, WG, Sliced, 2.5"',121394,NULL,'00737410519005','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701162,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Snackables, Alphabet, Whole Grain, Packs','Snackables, Alphabet, WG, Pks',121395,NULL,'00737410525006','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-07-11',NULL,'UNPREPARED',2697080,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Snackables, Animal Crackers, Whole Grain, Packs','CLOSEOUT Snackables Animal Crackers',121396,NULL,'00737410526003','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-03-14',NULL,'UNPREPARED',2687865,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hamburger Buns, Whole Grain, Sliced, 3.75", Individually Wrapped','Hamburger Buns, WG, Sl, 3.75", IW',121398,NULL,'00737410530000','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701175,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Snackables, Pretzel Sticks, Whole Grain, Packs, 1"','Snackables Pretzel Stks WG Pks 1"',121401,NULL,'00737410571201','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-06-29',NULL,'UNPREPARED',2558554,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bagels, Honey Whole Grain, Sliced 6''s','Bagels, Honey WG, Sliced 6''s',121407,NULL,'00737410625003','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701173,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bagels, Whole Grain, Sliced, Bulk','Bagels, Whole Grain, Sliced, Bulk',121408,NULL,'00737410635002','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-02-16',NULL,'UNPREPARED',2458108,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, English Muffin, Whole Grain, Egg & Cheese, Individually Wrapped','Sndwch, Eng Mffn, WG, Egg & Chs, IW',121412,NULL,'00737410660400','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701172,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Biscuit, Whole Grain, Breaded Chicken, Individually Wrapped','Sandwich, Bisc, WG, Brded Chkn, IW',121413,NULL,'00737410662503','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701171,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Croissant, Whole Grain, Turkey Ham & Cheese, Individually Wrapped','Sndwch, Crois, WG, Trky Ham&Chs, IW',121414,NULL,'00737410663104','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2022-09-15',NULL,'UNPREPARED',2337284,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Slider, Whole Grain, Egg & Cheese, Individually Wrapped','Sandwich, Slider, WG, Egg & Chs, IW',121415,NULL,'00737410663302','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-02-16',NULL,'UNPREPARED',2458361,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Bun, Whole Grain, Turkey Ham & Cheese, Individually Wrapped','Sndwch, Bun, WG, Trky Ham & Chs, IW',121416,NULL,'00737410663401','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-02-16',NULL,'UNPREPARED',2458105,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Bun, Whole Grain, Turkey Breast & Cheese, Individually Wrapped','Sndwch Bun WG Trky Breast&Chs IW',121417,NULL,'00737410663500','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2022-09-15',NULL,'UNPREPARED',2337344,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Hoagie, Whole Grain, Turkey Breast & Cheese, Individually Wrapped, 5""','Hoagies WG Trky Breast&Chs IW 5""',121418,NULL,'00737410664804','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2022-09-15',NULL,'UNPREPARED',2337318,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Croissant, Whole Grain, Turkey Breast & Cheese, Individually Wrapped','Sndwch Crois WG Trky Breast&Chs IW',121419,NULL,'00737410664903','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2022-09-15',NULL,'UNPREPARED',2337544,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'INACTIVSandwich, Hoagie, Whole Grain, Turkey Ham, Turkey Pepperoni & Cheese Individually Wrapped','Hoagies WG Trky Ham Trky Pproni&Chs',121420,NULL,'00737410665306','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2022-04-01',NULL,'UNPREPARED',2236203,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Hoagie, Whole Grain, Turkey Ham & Cheese, Individually Wrapped, 5"" x 2.75""','Hoagies WG Trky Ham&Chs IW 5""x2.75""',121421,NULL,'00737410665405','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2022-09-15',NULL,'UNPREPARED',2337664,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Maple Waffle, Whole Grain, Breaded Chicken, Individually Wrapped','Sndwch Mpl Waffle WG Brded Chkn IW',121422,NULL,'00737410665603','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-10-31',NULL,'UNPREPARED',2716307,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Maple Waffle, Whole Grain, Chicken Sausage, Individually Wrapped','Sndwch Mpl Waffle WG Chkn Ssg IW',121423,NULL,'00737410665702','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-10-31',NULL,'UNPREPARED',2716306,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Whole Grain, Grilled Cheese, Individually Wrapped','Sandwich, WG, Grilled Cheese, IW',121424,NULL,'00737410665801','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701168,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Whole Grain, Grilled Cheese, Individually Wrapped','Sandwich, WG, Grilled Cheese, IW',121425,NULL,'00737410665900','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701167,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Whole Grain, Grilled Cheese, American & Mozzarella, Low Sodium, Individually Wrapped','Sndwch WG Grilled Chs American&Mozz',121428,NULL,'00737410066769','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701138,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bagels, Whole Grain, Sliced, Individually Wrapped','Bagels, Whole Grain, Sliced, IW',121429,NULL,'00737410669007','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-02-16',NULL,'UNPREPARED',2458091,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bagels, Whole Grain, Blueberry, Sliced, Individually Wrapped, 3.5" x 1.4"','Bagels WG Blueb Sl IW 3.5"x1.4"',121431,NULL,'00737410696003','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-01-23',NULL,'UNPREPARED',2723076,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bagels, Whole Grain, Blueberry, Sliced, Bulk, 3.5" x 1.4"','Bagels WG Blueb Sl Blk 3.5"x1.4"',121432,NULL,'00737410698007','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-01-23',NULL,'UNPREPARED',2722742,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Biscuits, Lower Sodium, Sliced, 3"','Biscuits, Lower Sodium, Sliced, 3"',121438,NULL,'00737410070452','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701124,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croffin, Cinnamon, Freezer-to-Oven, 3" x 2.5"','Croffin Cinn Freezer-to-Oven 3"x2.5',121461,NULL,'00737410072135','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-04-24',NULL,'UNPREPARED',2730167,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'INACTIVE - Dinner Rolls, Golden Honey Wheat, Gourmet, 3""','Din Rl, Golden Hny Wht, Gourmet, 3""',121481,NULL,'00737410735702','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2022-04-01',NULL,'UNPREPARED',2236105,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'French Toast Sticks, Original (approx. 190-210 pieces), 3.75" x 1"','Fr Tst Stks Original (approx. 190-2',121491,NULL,'00737410074429','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701077,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bagels, Whole Grain, Cinnamon Raisin, Sliced, Individually Wrapped, 3.5" x 1.4"','Bagels WG Cinn Raisin Sl IW 3.5x1.4',121492,NULL,'00737410746005','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-01-23',NULL,'UNPREPARED',2722494,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'English Muffins, Sliced, 3.5"','English Muffins, Sliced, 3.5"',121499,NULL,'00737410786001','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701163,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'English Muffins, Whole Grain White, Sliced, 3.5"','English Muffins, WG Whi, Sl, 3.5"',121501,NULL,'00737410802008','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701072,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Biscuits, Buttermilk, 3" Sliced, Tray Pack','CLOSEOUT Biscs Btrmlk 3" Sl Tray Pk',121502,NULL,'00737410849003','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-01-23',NULL,'UNPREPARED',2722179,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Maple Pancake, Whole Grain, Chicken Sausage, Individually Wrapped','Sndwch Mpl Pancake WG Chkn Ssg IW',121505,NULL,'00737410912509','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-10-31',NULL,'UNPREPARED',2716305,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Biscuits, Buttermilk, Whole Grain, Reduced Sodium, 3" Sliced, Tray Packed','Biscs Btrmlk WG RS 3" Sl Tray Pk',121506,NULL,'00737410923000','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2701034,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Biscuits, Buttermilk, Whole Grain, Reduced Sodium, Sliced, 3"','CLOSEOUT Biscs Btrmlk WG RS Sl 3"',121507,NULL,'00737410935003','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2023-06-29',NULL,'UNPREPARED',2558580,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bagels, Whole Grain, Sliced, Bulk, 4" x 1.5"','Bagels, WG, Sliced, Blk, 4"x1.5"',121508,NULL,'00737410936000','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-01-23',NULL,'UNPREPARED',2722789,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bagels, Whole Grain, Cinnamon Raisin, Sliced, Bulk','Bagels, WG, Cinn Raisin, Sl, Blk',121509,NULL,'00737410941004','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-01-23',NULL,'UNPREPARED',2722480,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bagels, Whole Grain White, Sliced, Bulk, 3.5" x 1.4"','Bagels, WG Whi, Sl, Blk, 3.5"x1.4"',121510,NULL,'00737410943008','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-01-23',NULL,'UNPREPARED',2722521,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bagels, Plain, Sliced, Bulk, 3.5" x 1.4"','Bagels, Plain, Sl, Blk, 3.5"x1.4"',121511,NULL,'00737410951003','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-01-23',NULL,'UNPREPARED',2722677,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bagels, Whole Grain, Sliced, Individually Wrapped, 3.5" x 1.4"','Bagels, WG, Sliced, IW, 3.5"x1.4"',121516,NULL,'00737410959009','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-01-23',NULL,'UNPREPARED',2722604,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Dinner Roll, Whole Grain, Yeast, Proof and Bake','Dinner Roll, WG, Yeast, Pf&Bk',121518,NULL,'00737410961408','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-08-15',NULL,'UNPREPARED',2700973,'50193300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mini Bagels, Whole Grain, Individually Wrapped','Mini Bagels, Whole Grain, IW',121520,NULL,'00737410980003','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-12-19',NULL,'UNPREPARED',2719756,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bagels, Whole Grain White, Sliced, Individually Wrapped','Bagels, WG White, Sliced, IW',121521,NULL,'00737410982007','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2025-01-23',NULL,'UNPREPARED',2722649,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mini Bagels, Whole Grain, 8-18s','Mini Bagels, Whole Grain, 8-18s',121522,NULL,'00737410996004','Bake Crafters Food Company','Bake Crafters',NULL,3,'2019-03-27','2024-12-19',NULL,'UNPREPARED',2719758,'50181900');
INSERT INTO `cndb_fdes` VALUES (13,'CE Red Sod Beef Mtbll 5=2 6/5# 30#','CE Red Sod Beef Mtbll 5=2',121523,NULL,'20049485050302','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-12-19',NULL,'PREPARED',2719195,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'C/E Red Sod Beef MB 4=2 6/5# 30#','C/E Red Sod Beef MB 4=2',121525,NULL,'20049485050357','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700840,'50240100');
INSERT INTO `cndb_fdes` VALUES (10,'Red Sod Pork Meatball 4=2 30# 6Bags','Red Sod Pork Meatball 4=2',121526,NULL,'20049485050364','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700821,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Soy Free Beef Meatball 6/5# 30#','Soy Free Beef Meatball',121527,NULL,'20049485050494','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716060,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'C/E Beef&Chicken Meatball 6/5# 30#','C/E Beef&Chicken Meatball',121531,NULL,'20049485050555','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-11-16',NULL,'PREPARED',2662589,'50171800');
INSERT INTO `cndb_fdes` VALUES (5,'Mini Turkey Corn Dogs 6/5# 30#','Mini Turkey Corn Dogs',121533,NULL,'00049485050902','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2702968,'50240100');
INSERT INTO `cndb_fdes` VALUES (6,'Creamy Tomato Soup 30# 6 Bags','Creamy Tomato Soup',121534,NULL,'00049485051138','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2715975,'50191500');
INSERT INTO `cndb_fdes` VALUES (22,'Cheeseburger Mac 6/5# 30#','Cheeseburger Mac',121536,NULL,'20049485051514','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700820,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'C/E Bf Cincy Style Chili 6/5# 30#','C/E Bf Cincy Style Chili',121537,NULL,'20049485005197','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-11-14',NULL,'PREPARED',2717282,'50240100');
INSERT INTO `cndb_fdes` VALUES (5,'Chicken Taco 6/5# 30#','Chicken Taco',121538,NULL,'20049485052016','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716059,'50240100');
INSERT INTO `cndb_fdes` VALUES (5,'Turkey Taco Filling 6/5# 30#','Turkey Taco Filling',121539,NULL,'00049485052029','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2715977,'50240100');
INSERT INTO `cndb_fdes` VALUES (10,'C/E Pork Drned Taco 6/5# 30#','C/E Pork Drned Taco',121540,NULL,'20049485052054','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716058,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Drained LF Taco 6/5# 30#','Beef Drained LF Taco',121543,NULL,'20049485052320','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700799,'50240100');
INSERT INTO `cndb_fdes` VALUES (5,'Turkey Taco Filling 6/5# 30#','Turkey Taco Filling',121544,NULL,'00049485052357','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2702939,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Taco Filling (drained) 6/5# 30#','Beef Taco Filling (drained)',121545,NULL,'20049485052498','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716057,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'C/E Red Sodium Beef Taco (drained) 6/5# 30#','C/E Red Sodium Beef Taco (drained)',121546,NULL,'20049485052504','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716056,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'CECulinaryBrandTcFillw/Bf 32# 6/5.333# Bags','CECulinaryBrandTcFillw/Bf',121547,NULL,'20049485052528','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2025-03-20',NULL,'PREPARED',2723178,'50240100');
INSERT INTO `cndb_fdes` VALUES (5,'CulinaryBrandTurkeyTaco 32# 4 Bags','CulinaryBrandTurkeyTaco',121548,NULL,'00049485052548','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2702940,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Drained Chili Sauce 6/5# 30#','Beef Drained Chili Sauce',121549,NULL,'20049485053204','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-11-14',NULL,'PREPARED',2717283,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Chili Con Carne w/o Beans 6/5# 30#','Chili Con Carne w/o Beans',121552,NULL,'20049485053389','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700793,'50240100');
INSERT INTO `cndb_fdes` VALUES (16,'Culinary Three Bean Chili 30# 6 Bags','Culinary Three Bean Chili',121555,NULL,'00049485053835','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2025-01-23',NULL,'PREPARED',2722815,'50191500');
INSERT INTO `cndb_fdes` VALUES (13,'C/E Beef Drned Sloppy Joe 6/5# 30#','C/E Beef Drned Sloppy Joe',121559,NULL,'20049485005456','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716062,'50240100');
INSERT INTO `cndb_fdes` VALUES (10,'C/E Pork Drained Spag Sce 6/5# 30#','C/E Pork Drained Spag Sce',121563,NULL,'20049485055215','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700790,'50240100');
INSERT INTO `cndb_fdes` VALUES (5,'Meat Sauce w/Turkey 6/5# 30#','Meat Sauce w/Turkey',121565,NULL,'00049485055327','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-12-19',NULL,'PREPARED',2718732,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'CECulinaryBrandSpgScew/Bf 32# 6/5.333# Bags','CECulinaryBrandSpgScew/Bf',121566,NULL,'20049485055338','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716054,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'C/E Beef Drained Spag Sce 6/5# 30#','C/E Beef Drained Spag Sce',121567,NULL,'20049485055789','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2025-01-23',NULL,'PREPARED',2722876,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Spaghetti w/Beef & Sauce 6/5# 30#','Spaghetti w/Beef & Sauce',121568,NULL,'20049485055901','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716053,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Spirals w/Beef & Sauce 6/5# 30#','Spirals w/Beef & Sauce',121569,NULL,'20049485055918','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716088,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'C/E Med Bf Pattyw/Mshrms 30#6Bg','C/E Med Bf Pattyw/Mshrms',121575,NULL,'20049485056373','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700802,'50240100');
INSERT INTO `cndb_fdes` VALUES (10,'OC Pork Sausage Patty 6/5# 30#','OC Pork Sausage Patty',121576,NULL,'20049485056465','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700810,'50240300');
INSERT INTO `cndb_fdes` VALUES (10,'C/E Sthrn Pork Ssg Patty 6/5# 30#','C/E Sthrn Pork Ssg Patty',121577,NULL,'20049485056496','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2025-03-20',NULL,'PREPARED',2723179,'50240300');
INSERT INTO `cndb_fdes` VALUES (13,'CE Med Bf Patty 6 BAGS','CE Med Bf Patty',121580,NULL,'20049485056595','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700817,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'CE Small Bf Patty 6 BAGS','CE Small Bf Patty',121581,NULL,'20049485056618','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700816,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'C/E Med Premium Bf Patty 6 BAGS','C/E Med Premium Bf Patty',121584,NULL,'20049485056700','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700815,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Medium Beef Patty 30# 6 Bags','Medium Beef Patty',121587,NULL,'20049485056793','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-06-29',NULL,'PREPARED',2559616,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'RS Beef Patty 30.375#6Bg','RS Beef Patty',121588,NULL,'20049485056823','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2025-01-23',NULL,'PREPARED',2722902,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Patty 29.25# 6 Bags','Beef Patty',121589,NULL,'20049485056830','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2025-01-23',NULL,'PREPARED',2722681,'50240100');
INSERT INTO `cndb_fdes` VALUES (10,'KF CE PorkRibPatW/Sce 2.8 168/2.8 oz. (29.4#)','KF CE PorkRibPatW/Sce 2.8',121591,NULL,'20049485056908','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-12-19',NULL,'PREPARED',2719196,'50240100');
INSERT INTO `cndb_fdes` VALUES (10,'KF BreadedPorkPatty 3.35 138/3.35oz (28.89#)','KF BreadedPorkPatty 3.35',121592,NULL,'20049485056946','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-12-19',NULL,'PREPARED',2719197,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'KF CE Brd Beef Patty 3.35 138/3.35oz (28.89#)','KF CE Brd Beef Patty 3.35',121593,NULL,'20049485056953','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700812,'50240100');
INSERT INTO `cndb_fdes` VALUES (6,'Marinara Sauce 6 bags/30#','Marinara Sauce',121594,NULL,'00049485057031','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-11-16',NULL,'PREPARED',2663244,'50171800');
INSERT INTO `cndb_fdes` VALUES (6,'Buffalo Sauce 6/5# 30#','Buffalo Sauce',121595,NULL,'00049485057048','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-11-16',NULL,'PREPARED',2663259,'50171800');
INSERT INTO `cndb_fdes` VALUES (1,'Cheddar Cheese Sauce 6/5# 30#','Cheddar Cheese Sauce',121596,NULL,'00049485057055','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-12-19',NULL,'PREPARED',2718733,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Jalapeno Cheese Sauce 6/5# 30#','Jalapeno Cheese Sauce',121598,NULL,'00049485057086','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-12-19',NULL,'PREPARED',2718734,'50131800');
INSERT INTO `cndb_fdes` VALUES (6,'BBQ Sauce 6/5# 30#','BBQ Sauce',121600,NULL,'00049485057116','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-11-16',NULL,'PREPARED',2663247,'50171800');
INSERT INTO `cndb_fdes` VALUES (1,'Reduced Fat Cheese Sauce 6/5# 30#','Reduced Fat Cheese Sauce',121601,NULL,'00049485057154','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-11-14',NULL,'PREPARED',2717527,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Queso Blanco 6/5# 30#','Queso Blanco',121602,NULL,'00049485057185','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-11-16',NULL,'PREPARED',2663249,'50131800');
INSERT INTO `cndb_fdes` VALUES (6,'Salsa Verde 4/5# 20#','Salsa Verde',121603,NULL,'20049485057196','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-11-16',NULL,'PREPARED',2662549,'50171800');
INSERT INTO `cndb_fdes` VALUES (1,'Alfredo Sauce 6/5# 30#','Alfredo Sauce',121604,NULL,'00049485057222','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-12-19',NULL,'PREPARED',2718735,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'RF Jalapeno Cheese Sauce 30# 6 Bags','RF Jalapeno Cheese Sauce',121605,NULL,'00049485057246','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2715992,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'RF Queso Blanco 30# 6 Bags','RF Queso Blanco',121606,NULL,'00049485057253','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2025-01-23',NULL,'PREPARED',2722200,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Three Cheese Sauce 6/5# 30#','Three Cheese Sauce',121607,NULL,'00049485057307','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2025-04-24',NULL,'PREPARED',2730789,'50171800');
INSERT INTO `cndb_fdes` VALUES (1,'Golden Queso 6/5# 30#','Golden Queso',121608,NULL,'00049485057314','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2025-01-23',NULL,'PREPARED',2722222,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Whole Grain Mac & Cheese 6/5# 30#','Whole Grain Mac & Cheese',121609,NULL,'00049485057567','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-11-16',NULL,'PREPARED',2663255,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Homestyle Orig Mac&Cheese 6/5# 30#','Homestyle Orig Mac&Cheese',121610,NULL,'00049485057574','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-08-31',NULL,'PREPARED',2613438,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Hmstyl RF Elbo Mac&Cheese 6/5# 30#','Hmstyl RF Elbo Mac&Cheese',121611,NULL,'00049485057581','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-11-16',NULL,'PREPARED',2663256,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Hmstyl Orig Str Mac&Chees 6/5# 30#','Hmstyl Orig Str Mac&Chees',121612,NULL,'00049485057598','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-11-16',NULL,'PREPARED',2663257,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Hmstyl RF Strt Mac&Cheese 6/5# 30#','Hmstyl RF Strt Mac&Cheese',121613,NULL,'00049485057611','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2025-04-24',NULL,'PREPARED',2730781,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Penne in Alfredo Sauce 30# 6 Bags','Penne in Alfredo Sauce',121614,NULL,'00049485057642','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2025-03-20',NULL,'PREPARED',2724242,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Whole Grain Mac & Cheese 30# 6 Bags','Whole Grain Mac & Cheese',121615,NULL,'00049485057659','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2025-04-24',NULL,'PREPARED',2730782,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'WGR Mac & Cheese LS 30# 6 Bags','WGR Mac & Cheese LS',121616,NULL,'00049485057673','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-04-18',NULL,'PREPARED',2688554,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'WGR Mac & Cheese 30# 6 BAGS','WGR Mac & Cheese',121617,NULL,'00049485057680','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-11-16',NULL,'PREPARED',2663295,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'WGR Mac & Cheese 30# 6 Bags','WGR Mac & Cheese',121618,NULL,'00049485057697','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2702949,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Three Cheese Mac and Cheese 6/5# 30#','Three Cheese Mac and Cheese',121619,NULL,'00049485057734','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-11-16',NULL,'PREPARED',2663331,'50171800');
INSERT INTO `cndb_fdes` VALUES (1,'Port Pk Mac & Cheese &NDM 30/6oz 11.25#','Port Pk Mac & Cheese &NDM',121621,NULL,'00049485057819','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-11-16',NULL,'PREPARED',2663332,'50171800');
INSERT INTO `cndb_fdes` VALUES (1,'PortPk Hmstyl RF Mac&Ches 30/6oz  11.25#','PortPk Hmstyl RF Mac&Ches',121622,NULL,'00049485057826','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-11-16',NULL,'PREPARED',2663333,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Port Pk Penne Alfredo Bowl 30/6oz 11.25#','Port Pk Penne Alfredo Bowl',121623,NULL,'00049485057833','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-11-16',NULL,'PREPARED',2663334,'50171800');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Chili w/Bean Drained 6/5# 30#','Beef Chili w/Bean Drained',121624,NULL,'20049485005791','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716061,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Crumble 6/5# 30#','Beef Crumble',121626,NULL,'20049485058681','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700818,'50240100');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain-Rich Pretzel Bites','Whole Grain-Rich Pretzel Bites',121628,NULL,'00049485059110','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2023-11-16',NULL,'PREPARED',2663336,'50181900');
INSERT INTO `cndb_fdes` VALUES (13,'Red Sod Beef Meatball 5=2 6/5# 30#','Red Sod Beef Meatball 5=2',121632,NULL,'10049485050305','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700533,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Red Sod Beef Meatball 4=2 6/5# 30#','Red Sod Beef Meatball 4=2',121634,NULL,'10049485050350','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700532,'50240100');
INSERT INTO `cndb_fdes` VALUES (10,'Red Sod Pork Meatball 4=2 6/5# 30#','Red Sod Pork Meatball 4=2',121635,NULL,'10049485050367','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700523,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Soy Free Beef Meatball 6/5# 30#','Soy Free Beef Meatball',121636,NULL,'10049485050497','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716085,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Cheeseburger Mac w/DF Bf 6/5# 30#','Cheeseburger Mac w/DF Bf',121640,NULL,'10049485051517','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700501,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Cheeseburger Mac Bowl 30/6oz 11.25#','Cheeseburger Mac Bowl',121641,NULL,'10049485051630','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700502,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Cincy Style Chili 6/5# 30#','Beef Cincy Style Chili',121642,NULL,'10049485005190','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-11-14',NULL,'PREPARED',2717225,'50240100');
INSERT INTO `cndb_fdes` VALUES (10,'Pork Drained Taco Filling 6/5# 30#','Pork Drained Taco Filling',121644,NULL,'10049485052057','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716084,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Drained LF Taco 6/5# 30#','Beef Drained LF Taco',121646,NULL,'10049485052323','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700503,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Taco Filling 6/5# 30#','Beef Taco Filling',121647,NULL,'10049485052491','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700504,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Reduced Sodium Beef Taco 6/5# 30#','Reduced Sodium Beef Taco',121648,NULL,'10049485052507','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700505,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'CulinaryBrandTacoFillw/Bf 32# 6/5.333# Bags','CulinaryBrandTacoFillw/Bf',121649,NULL,'10049485052521','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700506,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Drained Chili Sauce 6/5# 30#','Beef Drained Chili Sauce',121651,NULL,'10049485053207','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-11-14',NULL,'PREPARED',2717227,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Drnd Chili w/o Bean 6/5# 30#','Beef Drnd Chili w/o Bean',121652,NULL,'10049485053337','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716082,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Drained Sloppy Joe 6/5# 30#','Beef Drained Sloppy Joe',121657,NULL,'10049485005459','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716107,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Port Pk Spirals w/Bf&Sce 30/8.0oz 15#','Port Pk Spirals w/Bf&Sce',121658,NULL,'10049485055010','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700513,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Port Pk Spag w/Beef & Sce 30/8.0oz 15#','Port Pk Spag w/Beef & Sce',121659,NULL,'10049485055027','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-12-19',NULL,'PREPARED',2718948,'50240100');
INSERT INTO `cndb_fdes` VALUES (10,'Pork Drained Spag Sauce 6/5# 30#','Pork Drained Spag Sauce',121661,NULL,'10049485055218','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-11-14',NULL,'PREPARED',2717228,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'CulinaryBrandSpgSce w/Bf 32# 6/5.333# Bags','CulinaryBrandSpgSce w/Bf',121663,NULL,'10049485055331','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716080,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Drained Spag Sauce 6/5# 30#','Beef Drained Spag Sauce',121664,NULL,'10049485055782','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2025-01-23',NULL,'PREPARED',2722981,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'CP Spaghetti w/Beef & Sauce 6/5# 30#','CP Spaghetti w/Beef & Sauce',121665,NULL,'10049485055904','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716079,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Spirals w Beef & Sauce 6/5# 30#','Spirals w Beef & Sauce',121666,NULL,'10049485055911','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716078,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Patty 30# 6Bags','Beef Patty',121669,NULL,'10049485056109','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700528,'50240100');
INSERT INTO `cndb_fdes` VALUES (10,'OC Pork Sausage Patties 6/5# 30#','OC Pork Sausage Patties',121678,NULL,'10049485056468','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700527,'50240300');
INSERT INTO `cndb_fdes` VALUES (10,'OC Sthrn Pork Ssg Patties 6/5# 30#','OC Sthrn Pork Ssg Patties',121679,NULL,'10049485056499','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700526,'50240300');
INSERT INTO `cndb_fdes` VALUES (13,'CP Med Beef Patty 6 BAGS','CP Med Beef Patty',121682,NULL,'10049485056598','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700525,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'CP Small Bf Patty 6 BAGS','CP Small Bf Patty',121683,NULL,'10049485056611','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700531,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Medium Premium Beef Patty 6 BAGS','Medium Premium Beef Patty',121686,NULL,'10049485056703','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700524,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Medium Beef Patty 30# 6 Bags','Medium Beef Patty',121690,NULL,'10049485056796','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700522,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'RS Beef Patty 30.375#6Bg','RS Beef Patty',121691,NULL,'10049485056826','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2025-01-23',NULL,'PREPARED',2722034,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Patty 6 Bags (29.25#)','Beef Patty',121692,NULL,'10049485056833','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700520,'50240100');
INSERT INTO `cndb_fdes` VALUES (10,'KF PorkRibPatty w/Sce 2.8 168/2.8 oz. (29.4#)','KF PorkRibPatty w/Sce 2.8',121693,NULL,'10049485056901','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-12-19',NULL,'PREPARED',2718949,'50240100');
INSERT INTO `cndb_fdes` VALUES (10,'KF Brded Pork Patty 3.35 138/3.35oz (28.89#)','KF Brded Pork Patty 3.35',121694,NULL,'10049485056949','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-12-19',NULL,'PREPARED',2718950,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'KF Brded Beef Patty 3.35 138/3.35oz (28.89#)','KF Brded Beef Patty 3.35',121695,NULL,'10049485056956','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700517,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Drained Chili w/Bean 6/5# 30#','Beef Drained Chili w/Bean',121696,NULL,'10049485005794','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-10-31',NULL,'PREPARED',2716086,'50240100');
INSERT INTO `cndb_fdes` VALUES (13,'Beef Crumble 6/5# 30#','Beef Crumble',121699,NULL,'10049485058684','JTM Food Group','JTM Food Group',NULL,3,'2019-03-27','2024-08-15',NULL,'PREPARED',2700550,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG BBQ Calzone, Meatless, Vegan','WG BBQ Calzone, Meatless,',121766,NULL,'00711341509632','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2022-04-01',NULL,'UNPREPARED',2237822,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Blazin'' Buffalo Calzone, Meatless','WG Blazin'' Buffalo Calzone, Meatles',121767,NULL,'00711341509700','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2023-06-29',NULL,'UNPREPARED',2558235,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Blazin'' Buffalo Calzone, Meatless, Bulk','WG Blazin'' Buffalo Calzone',121768,NULL,'00711341509731','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2023-06-29',NULL,'UNPREPARED',2558236,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Blazin'' Buffalo Calzone, Meatless, Vegan','WG Blazin'' Buffalo Calzone, Meatles',121769,NULL,'00711341509809','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2023-06-29',NULL,'UNPREPARED',2558237,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Spicy Bean & Cheese Bowl','Spicy Bean & Cheese Bowl',121773,NULL,'00711341559101','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2023-06-29',NULL,'UNPREPARED',2558238,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bean & Cheese Bowl','Bean & Cheese Bowl',121774,NULL,'00711341559996','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2023-06-29',NULL,'UNPREPARED',2558239,'50182200');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Banana Loaf','WG Banana Loaf',121775,NULL,'00711341600117','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2023-06-29',NULL,'UNPREPARED',2558240,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'WG Blueberry Loaf','WG Blueberry Loaf',121776,NULL,'00711341600131','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2023-06-29',NULL,'UNPREPARED',2558241,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Chocolate Chip Muffin','WG Chocolate Chip Muffin',121778,NULL,'00711341608267','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2023-11-16',NULL,'PREPARED',2663166,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Banana Muffin','WG Banana Muffin',121780,NULL,'00711341641219','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2023-11-16',NULL,'PREPARED',2663168,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Blueberry Muffin','WG Blueberry Muffin',121781,NULL,'00711341641318','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2023-04-27',NULL,'PREPARED',2521286,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Patriotic Cookie','WG Patriotic Cookie',121783,NULL,'00711341724202','Buena Vista Food Products','Linda''s Cookies',NULL,3,'2019-03-31','2023-06-29',NULL,'PREPARED',2558262,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Blue Star Cookie','WG Blue Star Cookie',121784,NULL,'00711341740400','Buena Vista Food Products','Linda''s Cookies',NULL,3,'2019-03-31','2023-11-16',NULL,'PREPARED',2663176,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Chocolate Chip Cookie Dough w/ Bags','WG Chocolate Chip Cookie Dough',121785,NULL,'00711341781854','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2023-11-16',NULL,'UNPREPARED',2663178,'50181700');
INSERT INTO `cndb_fdes` VALUES (18,'WG Cinnamon Crumble','WG Cinnamon Crumble',121789,NULL,'00711341900309','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2023-06-29',NULL,'UNPREPARED',2558282,'50182000');
INSERT INTO `cndb_fdes` VALUES (18,'WG Fruity Pancake Bowl, Apple','WG Fruity Pancake Bowl, Apple',121790,NULL,'00711341940107','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2023-06-29',NULL,'UNPREPARED',2558287,'50182200');
INSERT INTO `cndb_fdes` VALUES (18,'WG Fruity Pancake Bowl, Peach','WG Fruity Pancake Bowl, Peach',121791,NULL,'00711341940305','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2023-11-16',NULL,'UNPREPARED',2663183,'50182200');
INSERT INTO `cndb_fdes` VALUES (18,'WG Fruity Pancake Bowl, Strawberry','WG Fruity Pancake Bowl, Strawberry',121792,NULL,'00711341940404','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2019-03-31','2023-08-31',NULL,'UNPREPARED',2613856,'50182200');
INSERT INTO `cndb_fdes` VALUES (25,'Zee Zees Soft Baked Bar, Berry Apple Crisp, WG, I/W, 1.3 oz','Berry Apple Crisp Soft Baked bar',121868,NULL,'00854114007468','National Food Group','Zee Zees',NULL,3,'2019-04-01','2023-02-16',NULL,'READY_TO_EAT',2458141,'50221200');
INSERT INTO `cndb_fdes` VALUES (25,'Zee Zees Soft Baked Bar, Strawberry Crisp, 1.3 oz','Strawberry Crisp Soft Baked bar',121869,NULL,'00854114007499','National Food Group','Zee Zees',NULL,3,'2019-04-01','2023-04-27',NULL,'READY_TO_EAT',2521571,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S PRIMO PB PEP CL PSLCD 8CUT NET WT 23.09LBS CN','BD PRIMO PB PEP',121878,NULL,'10072180685824','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2019-04-02','2024-12-19',NULL,'UNPREPARED',2718959,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S PRIMO PB CHS PRESLCD 8-CUT NET WT 23.09LBS CN','BD PRIMO PB CHS',121879,NULL,'10072180685862','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2019-04-02','2024-12-19',NULL,'UNPREPARED',2718960,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S DEEP DISH WG PEPPERONI NET WT 18.68LBS - IW 60CT CN','TN 5" DD PEPP',121887,NULL,'10072180783148','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2019-04-02','2024-02-01',NULL,'UNPREPARED',2683427,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'324ct Ultra Loco Garlic & Herb Breadstick','Garlic Herb Breadstick',121893,NULL,'20045059011809','The Father''s Table','Ultra Loco',NULL,3,'2019-04-01','2024-12-19',NULL,'THAW',2719194,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'150ct Triple Chocolate Cookie','Triple Chocolate Cookie',121896,NULL,'10010374011844','The Father''s Table','The Father''s Table Dunker''s',NULL,3,'2019-04-01','2024-08-15',NULL,'THAW',2701471,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'WHOLE GRAIN BREADED POLLOCK FISH STICKS 1 OZ OVEN READY','PLK O/R STICK 1 OZ CN WG',121908,NULL,'00028029272031','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2019-04-02','2024-10-31',NULL,'PREPARED',2716772,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'CRUNCHY CORNMEAL BREADED ALASKA POLLOCK WEDGE 3.6 OZ PORTION CN ITEM','TR PLK O/R WDGE 3.6 OZ CN',121909,NULL,'00028029275872','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2019-04-02','2024-07-11',NULL,'UNPREPARED',2698755,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breaded Popcorn Chicken Nuggets','Breaded Popcorn Chicken Nuggets',121941,NULL,'00856235005491','International Food Solutions, Inc.','GREEN DRAGON',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2701018,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Wheat Yakisoba Noodles','Yakisoba Noodles',121943,NULL,'00856235005514','International Food Solutions, Inc.','GREEN DRAGON',NULL,3,'2020-02-21','2023-07-13',NULL,'PREPARED',2594175,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Waffles, Maple Chip Mini, 3" Bulk','Waffles, Maple Chip Mini, 3" Bulk',121954,NULL,'00737410015958','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2023-03-16',NULL,'UNPREPARED',2492495,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Waffles, Mini, 3", Bulk','Waffles, Mini, 3", Bulk',121955,NULL,'00737410015965','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2023-04-27',NULL,'UNPREPARED',2521350,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Waffles, Whole Grain, Wholesome Ch, Gourmet, 100% Whole Wheat, Bulk, 4"','CLOSEOUT Waffles WG Wholesome Ch Go',121956,NULL,'00737410015989','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2023-06-29',NULL,'UNPREPARED',2558342,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Pancakes, Whole Grain, Wholesome Ch, Buttermilk, 100% Whole Wheat, Bulk, 3.75"','CLOSEOUT Pancakes WG Wholesome Ch B',121957,NULL,'00737410015996','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2023-06-29',NULL,'UNPREPARED',2558343,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pancakes, Whole Grain, Strawberry, Bulk, 4"','Pancakes, WG, Strawberry, Blk, 4"',121958,NULL,'00737410017013','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2023-04-27',NULL,'UNPREPARED',2521357,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pancakes, Whole Grain, Strawberry, 2 Pack','Pancakes, WG, Strawberry, 2 Pk',121959,NULL,'00737410017020','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2023-02-16',NULL,'UNPREPARED',2458350,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Waffles, Whole Grain, Strawberry 2 Pack','Waffles, WG, Strawberry 2 Pk',121961,NULL,'00737410017044','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2023-02-16',NULL,'UNPREPARED',2458616,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Donuts, Whole Grain, Glazed Yeast Ring, Reduced Fat, Fortified, Individually Wrapped','Donuts WG Glz Yeast Ring RF Fort IW',121962,NULL,'00737410020013','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2023-04-27',NULL,'UNPREPARED',2521363,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Donuts, Glazed Yeast Ring, Individually Wrapped','Donuts, Glazed Yeast Ring, IW',121963,NULL,'00737410020051','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2023-04-27',NULL,'UNPREPARED',2521364,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cornbread Bowl, Whole Grain, Fully Baked, Thaw & Serve, 2.5 oz., 3.25" x 2.33"','Crnbrd Bowl WG Flly Bkd Thaw&Serve ',121965,NULL,'00737410021782','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2024-08-15',NULL,'UNPREPARED',2699585,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Granola, Chocolate, Whole Grain, Wholesome Choice, Individually Wrapped, Ret, 3" x 4"','Granola Choc WG Wholesome Choice IW',121966,NULL,'00737410022666','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2025-01-23',NULL,'UNPREPARED',2722130,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Biscuit, Honey Whole Grain, Chicken Sausage, Cheese, Individually Wrapped','Sndwch Bisc Honey WG Chkn Ssg Chs I',121972,NULL,'00737410046037','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2024-08-15',NULL,'UNPREPARED',2701125,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Sandwich, Slider, Whole Grain, 100% Beef Hamburger, 2 Pack, 2.5"','CLOSEOUT Sndwch Slider WG 100% Beef',121985,NULL,'00737410066912','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2023-06-29',NULL,'UNPREPARED',2558411,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Slider, Whole Grain, 100% Beef Cheeseburger, 2 Pack, 2.5""','Sndwch Slider WG 100% Beef Chsburge',121986,NULL,'00737410066929','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2022-09-15',NULL,'UNPREPARED',2337650,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Slider, Whole Grain, 100% Beef Hamburger, 2 Pack, Commodity, 2.5"','Sndwch Slider WG 100% Beef Hamb 2 P',121987,NULL,'00737410066936','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2023-02-16',NULL,'UNPREPARED',2458120,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Slider, Whole Grain, 100% Beef Cheeseburger, 2 Pack, Comm, 2.5"','Sndwch Slider WG 100% Beef Chsburge',121988,NULL,'00737410066943','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2024-03-14',NULL,'UNPREPARED',2687851,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'French Toast Sticks, Cinnamon (approx. 135-140 pieces), 3.75" x 1.33"','Fr Tst Stks Cinn (approx. 135-140 p',121989,NULL,'00737410074436','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2024-08-15',NULL,'UNPREPARED',2701076,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Maple Pancake, Whole Grain, Chicken Sausage & Cheese, Individually Wrapped','Sndwch Mpl Pancake WG Chkn Ssg&Chs ',121990,NULL,'00737410091266','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2024-10-31',NULL,'UNPREPARED',2716259,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Chocolate Chip, Individually Wrapped, 3.25"','Muffins, Chocolate Chip, IW, 3.25"',121992,NULL,'00737410154503','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2024-08-15',NULL,'UNPREPARED',2701191,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Biscuits, Whole Grain, Honey Wheat, Tops, 3"','Biscuits, WG, Honey Wheat, Tops, 3"',121993,NULL,'00737410202907','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2023-02-16',NULL,'UNPREPARED',2459066,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Biscuits, Whole Grain, Honey Wheat, Bottoms, 3"','Biscuits, WG, Hny Wht, Bottoms, 3"',121994,NULL,'00737410203003','Bake Crafters Food Company','Bake Crafters',NULL,3,'2020-02-21','2023-02-16',NULL,'UNPREPARED',2458803,'50181900');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Pasteurized Blended Low Moisture Part Skim Mozzarella Cheese Slice - 160 P - 4/5#','4/5# Blended LM PartSkim Mozzarella',122011,NULL,'10071078104454','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2023-03-16',NULL,'PREPARED',2492816,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Yellow Process American Loaf - 6/5#','6/5# Y Pr Am Lf',122013,NULL,'10071078105024','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2700577,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards White Process American Loaf - 6/5#','6/5# W Pr Am Lf',122016,NULL,'10071078202648','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2700591,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Reduced Fat Cheddar Cheese Stick - 168/1 oz','168/1 Rd Ft/Sd Chd Stck',122017,NULL,'10071078402925','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2700589,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Reduced Fat Marble Jack Cheese Stick - 168/1 oz','168/1oz  33% RFt Mrbl Jk Ch Stk',122018,NULL,'10071078402949','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2700499,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Low Moisture Part Skim Mozzarella String Cheese Stick - 168/1 oz','168/1oz Mz Stng Stck',122019,NULL,'10071078402956','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2700604,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Reduced Fat Low Moisture Part Skim Mozzarella String Cheese Stick - 168/1 oz','168/1oz Rd Ft Stng Stck',122020,NULL,'10071078402994','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2700498,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Cheddar Cheese Stick - 168/1 oz','168/1oz Y Chd Stck',122023,NULL,'10071078700007','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2023-10-26',NULL,'PREPARED',2649624,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Marble Cheese Stick - 168/1 oz','168/1oz Mrbl Jk Stck',122024,NULL,'10071078700106','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2700461,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Cheddar Slices - 32 SOS - 8/1.5#','8/1.5# Md Chd 32 Sl',122025,NULL,'10071078752457','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2700405,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Provolone Slices - 32 SOS - 8/1.5#','8/1.5# Smkd Prv 32 Sl',122027,NULL,'10071078752471','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2700404,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Swiss Slices - 32 SOS - 8/1.5#','Swiss Cheese Slices - 32 SOS 8/1.5#',122028,NULL,'10071078752488','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2700403,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Pepper Jack Slices - 32 SOS - 8/1.5#','8/1.5# Pep Jk 32 Sl',122029,NULL,'10071078752525','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2700402,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Low Moisture Part Skim Mozzarella Feather Shred - 4/5#','4/5# LMPS Mz Fthr Shd',122031,NULL,'10071078755076','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2023-10-26',NULL,'PREPARED',2649608,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Yellow Cheddar Feather Shred - 4/5#','4/5# Y Chd Fthr Shd',122032,NULL,'10071078755199','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2700401,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Low Moisture Part Skim Mozzarella Feather Shred - 6/5#','6/5# LMPS Mz Fthr Shd',122036,NULL,'10071078755533','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2700397,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Yellow Reduced Fat Cheddar Feather Shred - 4/5#','4/5# Y Rd Ft Chd Fthr Shd',122037,NULL,'10071078755717','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2700396,'50131800');
INSERT INTO `cndb_fdes` VALUES (1,'Bongards Monterey Jack and Cheddar Fancy Shred - 4/5#','4/5# Chd Mon Jk Fncy Shd',122039,NULL,'10071078771021','Bongards Creameries','Bongards',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2700393,'50131800');
INSERT INTO `cndb_fdes` VALUES (22,'Whole Grain Nacho Pretzel Pocket','WG Nacho Pretzel Pocket',122040,NULL,'00711341508215','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2020-02-21','2023-06-29',NULL,'UNPREPARED',2558232,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'Whole Grain Nacho Pretzel Pocket','WG Nacho Pretzel Pocket',122041,NULL,'00711341508314','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2020-02-21','2023-11-16',NULL,'UNPREPARED',2663164,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'Whole Grain Cheesy Pretzel Pocket','WG Cheesy Pretzel Pocket',122042,NULL,'00711341508321','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2020-02-21','2023-04-27',NULL,'UNPREPARED',2525854,'50182200');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Double Chocolate Muffin','WG Double Chocolate Muffin',122052,NULL,'00711341641417','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2020-02-21','2023-11-16',NULL,'PREPARED',2663169,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Red Velvet Cookie','WG Red Velvet Cookie',122063,NULL,'00711341799156','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2020-02-21','2023-01-26',NULL,'PREPARED',2443940,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'WG Brookee','WG Brookee',122065,NULL,'00711341844405','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2020-02-21','2023-06-29',NULL,'UNPREPARED',2558280,'50181700');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Cherry Muffin','WG Cherry Muffin',122068,NULL,'00711341604252','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2020-02-21','2023-06-29',NULL,'PREPARED',2558244,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'WG Sweet Potato Choc Chip Muffin','WG Sweet Potato Choc Chip Muffin',122070,NULL,'00711341641516','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2020-02-21','2023-04-27',NULL,'PREPARED',2521288,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Red Velvet Cookie','WG Red Velvet Cookie',122075,NULL,'00711341799200','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2020-02-21','2023-06-29',NULL,'UNPREPARED',2558277,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'WG Fruity Pancake Bowl, Blueberry','WG Fruity Pancake Bowl, Blueberry',122076,NULL,'00711341940206','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2020-02-21','2023-08-31',NULL,'UNPREPARED',2613855,'50182200');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Culinary Reserve Frozen Ready to Eat Reduced Sodium Chicken Noodle Soup, 4 Pound Pouches, 4-Pack','CUL RES RDNA CKN NDL',122077,'27443','10051000274431','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2020-02-21','2025-03-20',NULL,'UNPREPARED',2724159,'50191500');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Signature Frozen Ready to Eat Reduced Sodium Tomato Basil Soup, 4 Pound Pouches, 4-Pack','CPB SIG RDNA TOM BAS',122079,'24444','10051000274448','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2020-02-21','2023-08-31',NULL,'UNPREPARED',2614064,'50191500');
INSERT INTO `cndb_fdes` VALUES (25,'Goldfish Baked with Whole Grain Cheddar Crackers - Disney''s Mickey Mouse','PF FS GF MCKY WG CHED',122080,'27516','10014100275166','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2020-02-21','2024-07-11',NULL,'UNPREPARED',2697007,'50182100');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Ready to Serve Chicken Noodle Soup, 7.25 Ounce Cans, 24-Pack','CAMPBELL''S CHICKEN NOODLE',122081,'444','10051000004441','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2020-02-21','2024-07-11',NULL,'UNPREPARED',2696243,'50191500');
INSERT INTO `cndb_fdes` VALUES (25,'PEPPERIDGE FARM GOLDFISH WHOLE GRAIN GRAHAMS, FRENCH TOAST','PF GF FRNCH TST GRHMS',122089,'25082','10014100250828','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2020-02-21','2024-07-11',NULL,'UNPREPARED',2697031,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'PEPPERIDGE FARM GOLDFISH WHOLE GRAIN GRAHAMS, HONEY BUN','PF GF HNY BUN GRHMS',122090,'25083','10014100250835','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2020-02-21','2024-07-11',NULL,'UNPREPARED',2697004,'50182100');
INSERT INTO `cndb_fdes` VALUES (6,'CAMPBELL''S SIGNATURE FROZEN SOUP REDUCED SODIUM VEGAN VEGETABLE','CPB SIG RDNA VEGAN VEG',122092,'27445','10051000274455','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2020-02-21','2023-06-29',NULL,'UNPREPARED',2559242,'50191500');
INSERT INTO `cndb_fdes` VALUES (6,'Prego No Salt Added Pasta Sauce with Classic Italian Flavor and Homemade Taste, 106 Ounce Pouches, 6-Pack','PREGO NO SALT ADDED TOMATO',122096,'5013','10051000050134','CAMPBELL SOUP COMPANY','PREGO',NULL,3,'2020-02-21','2024-07-11','2024-06-14','UNPREPARED',2696192,'50171800');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Cocoa Puffs ','Breakfast Kit Cocoa Puffs',122109,NULL,'10693392000078','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2025-04-24',NULL,'PREPARED',2730476,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit RS Trix','Breakfast Kit RS Trix',122110,NULL,'10693392000146','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2025-04-24',NULL,'PREPARED',2730478,'50221200');
INSERT INTO `cndb_fdes` VALUES (1,'Reduced Fat Cheese Sauce, Reduced Sodium','Red Fat & Sod Cheese Sauce',122111,NULL,'10693392000207','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2025-03-20',NULL,'HEAT_AND_SERVE',2724508,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Reduced Fat Nacho Cheese Sauce, Reduced Sodium','Red Fat & Sod Nacho Cheese Sauce',122112,NULL,'10693392000238','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2025-03-20',NULL,'HEAT_AND_SERVE',2724506,'50131800');
INSERT INTO `cndb_fdes` VALUES (22,'MEAL, STRAWBERRY YOGURT PROTEIN PLASTIC CUP REF','Refrigerated Kit Strawberry Yogurt',122113,NULL,'10693392000450','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2024-05-16',NULL,'PREPARED',2689977,'50193500');
INSERT INTO `cndb_fdes` VALUES (22,'WG Grilled Cheese Sandwich','WG Grilled Cheese Sandwich',122114,NULL,'10693392000498','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2024-05-16',NULL,'PREPARED',2689975,'50192500');
INSERT INTO `cndb_fdes` VALUES (22,'WG Macaroni & Cheese Pouch','Red Fat & Sodium Mac and Cheese WG',122115,NULL,'10693392001174','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2025-04-24',NULL,'HEAT_AND_SERVE',2730483,'50193200');
INSERT INTO `cndb_fdes` VALUES (22,'Meal Kit RRP Hummus','Meal Kit Hummus',122116,NULL,'10693392001587','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2025-04-24',NULL,'PREPARED',2730484,'50193400');
INSERT INTO `cndb_fdes` VALUES (22,'Meal Kit Cheese Cup with Salsa','Meal Kit Cheese Cup w/Salsa',122117,NULL,'10693392001600','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2025-04-24',NULL,'PREPARED',2730474,'50193400');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Apple Muffin Top TS','Breakfast Kit Apple Muffin Top TS',122118,NULL,'10693392001716','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2024-05-16',NULL,'PREPARED',2689984,'50192300');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Cheerios Cereal Bar','Breakfast Kit Cheerios Cereal Bar',122120,NULL,'10693392002973','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2025-04-24',NULL,'PREPARED',2730442,'50221200');
INSERT INTO `cndb_fdes` VALUES (25,'WG Wheat Cracker Snack Pack','Wheat Crackers WG',122123,NULL,'10693392003413','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2025-03-20',NULL,'PREPARED',2724484,'50192100');
INSERT INTO `cndb_fdes` VALUES (22,'WG Fat Reduced Pepperoni Pinwheel','WG Fat Reduced Pepperoni Pinwheel',122124,NULL,'10693392003710','ES Foods, Inc.','ES Foods',NULL,3,'2020-02-21','2025-04-24',NULL,'HEAT_AND_SERVE',2730449,'50192500');
INSERT INTO `cndb_fdes` VALUES (22,'Philly Steak & Cheese Pinwheel WG','Philly Steak & Cheese Pinwheel',122125,NULL,'10693392003727','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2025-04-24',NULL,'HEAT_AND_SERVE',2730451,'50192500');
INSERT INTO `cndb_fdes` VALUES (22,'Mozzarella Pinwheel WG','Mozzarella Pinwheel WG',122126,NULL,'10693392003734','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2025-04-24',NULL,'HEAT_AND_SERVE',2730461,'50192500');
INSERT INTO `cndb_fdes` VALUES (22,'Vegetable  Pinwheel WG','Vegetable Pinwheel WG',122127,NULL,'10693392003932','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2025-04-24',NULL,'HEAT_AND_SERVE',2730452,'50192500');
INSERT INTO `cndb_fdes` VALUES (22,'Meatball Pinwheel WG','Meatball Pinwheel WG',122128,NULL,'10693392003956','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2023-04-27',NULL,'PREPARED',2521995,'50192500');
INSERT INTO `cndb_fdes` VALUES (22,'Egg & Cheese Breakfast Bowtie WG','Egg & Cheese Breakfast Bowtie WG',122129,NULL,'10693392004458','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2023-04-27',NULL,'PREPARED',2521996,'50192500');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Chocolate Chip Muffin TS','Breakfast Kit Choco Chip Muffin TS',122130,NULL,'10693392004625','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2024-05-16',NULL,'PREPARED',2689993,'50192300');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Blueberry Muffin TS','Breakfast Kit Blueberry Muffin TS',122131,NULL,'10693392004632','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2024-05-16',NULL,'PREPARED',2689992,'50192300');
INSERT INTO `cndb_fdes` VALUES (25,'Strawberry Bites ','Strawberry Bites',122132,NULL,'10693392004694','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2025-03-20',NULL,'PREPARED',2724485,'50192100');
INSERT INTO `cndb_fdes` VALUES (22,'Ciabatta Cheese Melt WG','WG Ciabatta Cheese Melt',122133,NULL,'10693392004786','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2025-04-24',NULL,'PREPARED',2730454,'50192500');
INSERT INTO `cndb_fdes` VALUES (22,' Ciabatta Pepper Jack Melt WG','WG Ciabatta Pepper Jack Melt',122134,NULL,'10693392005141','East Side Entrees','ES Foods',NULL,3,'2020-02-21','2025-04-24',NULL,'HEAT_AND_SERVE',2730456,'50192500');
INSERT INTO `cndb_fdes` VALUES (5,'Mini Breakfast Bites 6/5#','Mini Breakfast Bites',122135,NULL,'00049485050919','JTM Food Group','JTM Food Group',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2702959,'50240300');
INSERT INTO `cndb_fdes` VALUES (5,'Turkey Breakfast Burr Filling 6/5# 30#','Turkey Breakfast Burr Filling',122136,NULL,'00049485051640','JTM Food Group','JTM Food Group',NULL,3,'2020-02-21','2024-08-15',NULL,'PREPARED',2702936,'50240100');
INSERT INTO `cndb_fdes` VALUES (11,'Zee Zees Hummus Cup, Taco, 3 oz.','Hummus Cup, Taco',122225,NULL,'20810358031328','National Food Group','Zee Zees',NULL,3,'2020-02-21','2024-08-15',NULL,'READY_TO_EAT',2700905,'50192100');
INSERT INTO `cndb_fdes` VALUES (9,'Zee Zees Raisins, IW, 1.33 oz box','Raisins',122226,NULL,'20810358031694','National Food Group','Zee Zees',NULL,3,'2020-02-21','2023-05-25',NULL,'READY_TO_EAT',2539908,'50221000');
INSERT INTO `cndb_fdes` VALUES (25,'Zee Zees Wheat Crackers 0.8 oz','Wheat Crackers',122227,NULL,'20810358031380','National Food Group  Inc.','Zee Zees',NULL,3,'2020-02-21','2024-08-15',NULL,'READY_TO_EAT',2700904,'50192100');
INSERT INTO `cndb_fdes` VALUES (11,'Zee Zees Bean Dipz Cup, Original, 3 oz.','Bean Dip Cup',122230,NULL,'20810358031823','National Food Group','Zee Zees',NULL,3,'2020-02-21','2024-12-19',NULL,'READY_TO_EAT',2719207,'50192100');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S PRIMO RC WG SR 3-3PK NET WT 18.68LBS CN','BD PRIMO WG CRST',122243,NULL,'10072180685947','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2020-02-21','2024-12-19',NULL,'UNPREPARED',2718994,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S DEEP DISH WG CHEESE NET WT 18.68LBS - IW 60CT CN','TN 5" DD CHS',122244,NULL,'10072180783155','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2020-02-21','2024-02-01',NULL,'UNPREPARED',2683426,'50182200');
INSERT INTO `cndb_fdes` VALUES (11,'Hart Low Sodium Mixed Vegetable - 24 pack, 15oz cans','MXD VEG LOW SOD',122245,'F007022204732','10070222047326','Seneca Foods Corp','HART','100320',3,'2020-02-21','2024-12-19',NULL,'UNPREPARED',2718895,'50102100');
INSERT INTO `cndb_fdes` VALUES (5,'Premium Thick-Cut Oven Roasted Turkey Breast','SBF Fz Thick Sld OR Tky Brst',122255,NULL,'10024292134257','Cargill Incorporated/Honeysuckle White','Shady Brook Farms',NULL,3,'2020-02-21','2023-10-26',NULL,'PREPARED',2650099,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'150CT ULTRA LOCO PERSONAL PAN BREAD','PERSONAL PAN BREAD',122266,NULL,'20045059011786','The Father''s Table','ULTRA LOCO',NULL,3,'2020-02-21','2023-08-31',NULL,'THAW',2614186,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'POLLOCK PORTION 1.33OZ WEDGE BUFFALO  BREADED. OVEN READY, FROZEN','PLK O/R 1.33Z BRD PTN CN WG BUFLO',122267,NULL,'00028029290776','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2020-02-21','2024-07-11',NULL,'UNPREPARED',2698756,'50121900');
INSERT INTO `cndb_fdes` VALUES (15,'Breaded Pollock Portion CN 1.33 oz Wedge Nacho Cheese, Raw, Frozen','PLK O/R 1.33Z BRD PTN CN WG NACHO',122268,NULL,'00028029290783','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2020-02-21','2024-06-13',NULL,'UNPREPARED',2694786,'50121900');
INSERT INTO `cndb_fdes` VALUES (5,'Fully Cooked Turkey Breast/Thigh Roast, K-12','SBF Fz Ckd Sknls Brst Thigh Rs',122271,NULL,'90642205015040','Cargill Incorporated/Honeysuckle White','Shady Brook Farms',NULL,3,'2020-03-20','2023-10-26',NULL,'PREPARED',2649726,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'French Toast Bites, Whole Grain, Wholesome Choice, Cinnamon, Individually Wrapped','Fr Tst Bites WG Wholesome Choice Ci',122348,NULL,'00737410004044','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-02-16',NULL,'UNPREPARED',2458124,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'French Toast Bites, Whole Grain, Wholesome Choice, Cinnamon, Bulk 54 Servings','Fr Tst Bites WG Wholesome Choice Ci',122349,NULL,'00737410004082','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2025-03-20',NULL,'UNPREPARED',2724096,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Snackables, Chocolate Chip Cookies, Whole Grain, Packs','Snackables Choc Chip Cookies WG Pks',122350,NULL,'00737410527000','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2024-08-15',NULL,'UNPREPARED',2701176,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Whole Grain, Apple Cinnamon, Individually Wrapped, 2.25" x 3.5"','Mffns, WG, Apl Cinn, IW, 2.25"x3.5"',122351,NULL,'00737410122403','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2024-08-15',NULL,'UNPREPARED',2701101,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breakfast Bun, Whole Grain, Glazed, Extended Shelf Life, Individually Wrapped, 3"','Breakfast Bun WG Glz Extended Shelf',122353,NULL,'00737410019987','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2024-08-15',NULL,'UNPREPARED',2699584,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Break Bar, Blueberry Pomegranate, Whole Grain, Individually Wrapped, 3.25" x 1.5"','CLOSEOUT Break Bar Blueb Pomegranat',122354,NULL,'00737410022314','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-06-29',NULL,'UNPREPARED',2558361,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Break Bar, Strawberry, Whole Grain, Individually Wrapped, 3.25" x 1.5"','Break Bar Strbry WG IW 3.25"x1.5"',122355,NULL,'00737410022321','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2024-09-13',NULL,'UNPREPARED',2704183,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Break Bar, Oatmeal Chocolate Chip, Whole Grain, Individually Wrapped, 3.25" x 1.5"','Break Bar Oatmeal Choc Chip WG IW',122356,NULL,'00737410022338','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-02-16',NULL,'UNPREPARED',2460021,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Break Bar, Apple Cinnamon, Whole Grain, Individually Wrapped, 3.25" x 1.5"','Break Bar Apl Cinn WG IW 3.25"x1.5"',122357,NULL,'00737410022345','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2024-07-11',NULL,'UNPREPARED',2697095,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Granola, Chocolate, Whole Grain, Wholesome Choice, Bulk','CLOSEOUT Granola Choc WG Wholesome',122358,NULL,'00737410022673','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-06-29',NULL,'UNPREPARED',2558367,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Granola, Golden Vanilla, Whole Grain, Wholesome Choice, Individually Wrapped, 3" x 4"','CLOSEOUT Granola Golden Vanilla WG ',122359,NULL,'00737410022680','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2025-01-23',NULL,'UNPREPARED',2722032,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Granola, Cinnamon, Whole Grain, Wholesome Choice, Individually Wrapped, 3" x 7"','CLOSEOUT Granola Cinn WG Wholesome ',122360,NULL,'00737410022819','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2024-08-15',NULL,'UNPREPARED',2699595,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Granola, Chocolate, Whole Grain, Wholesome Choice, Individually Wrapped, 3" x 7"','CLOSEOUT Granola Choc WG Wholesome ',122361,NULL,'00737410022826','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2025-01-23',NULL,'UNPREPARED',2722871,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Granola, Golden Vanilla, Whole Grain, Wholesome Choice, Individually Wrapped, 3" x 7"','CLOSEOUT Granola Golden Vanilla WG ',122362,NULL,'00737410022833','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2025-01-23',NULL,'UNPREPARED',2722960,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Granola, Golden Vanilla, Whole Grain, Wholesome Choice, Bulk','CLOSEOUT Granola Golden Vanilla WG',122363,NULL,'00737410022840','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-06-29',NULL,'UNPREPARED',2558372,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Meal Kit, Muffin Blueberry, Whole Grain, Animal Crackers, Apple Juice','Meal Kit Mffn Blueb WG Animal Crack',122364,NULL,'00737410029122','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-04-27',NULL,'UNPREPARED',2521371,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Meal Kit, Whole Grain Breakf Bun, Whole Grain Snackables, Alphabet, Apple Juice','Meal Kit WG Breakf Bun WG Snackable',122365,NULL,'00737410029139','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-02-16',NULL,'UNPREPARED',2458095,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Meal Kit, Whole Grain Donut, Whole Grain, Snackables, Animal Crackers, Juice','Meal Kit WG Donut WG Snackables Ani',122366,NULL,'00737410029146','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-04-27',NULL,'UNPREPARED',2521372,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Meal Kit, Whole Grain Breakfst Bun, Whole Grain, Alp Snack Applesauce, Juice','Meal Kit WG Breakfst Bun WG Alp Sna',122367,NULL,'00737410029153','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-04-27',NULL,'UNPREPARED',2521373,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Meal Kit, Muffins, Chocolate Chip, Whole Grain Animal Crac, App, Juice','Meal Kit Mffns Choc Chip WG Animal',122368,NULL,'00737410029160','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-04-27',NULL,'UNPREPARED',2521374,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pullman Bread, Whole Grain, 2 Slices, Individually Wrapped','Pullman Bread, WG, 2 Slices, IW',122369,NULL,'00737410033617','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2024-08-15',NULL,'UNPREPARED',2700354,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Hot Dog Bun, Whole Grain, New England Style, 5.6" x 1.75"','CLOSEOUT Hot Dog Bun WG New England',122370,NULL,'00737410034812','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2025-01-23',NULL,'UNPREPARED',2722011,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hoagie Rolls, Whole Grain, Pan Baked, Split Top, Fully Sliced 5.5"','Hoagies WG Pan Bkd SplTop Flly Sl 5',122371,NULL,'00737410406305','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-02-16',NULL,'UNPREPARED',2458211,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Dinner Rolls, Whole Grain, Smooth Top, 1 oz., Individually Wrapped','Din Rolls, WG, Smth Top, 1 oz., IW',122372,NULL,'00737410041186','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-04-27',NULL,'UNPREPARED',2521379,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Dinner Rolls, Whole Grain, Smooth Top, 2 oz., Individually Wrapped','Din Rolls, WG, Smth Top, 2 oz., IW',122373,NULL,'00737410041193','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-04-27',NULL,'UNPREPARED',2521380,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, English Muffin, Whole Grain, Chicken Sausage, Egg & Cheese, Individually Wrapped','Sndwch Eng Mffn WG Chkn Ssg Egg&Chs',122385,NULL,'00737410066677','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2024-08-15',NULL,'UNPREPARED',2701139,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Hoagie, Whole Grain, Turkey Breast & Cheese, Individually Wrapped, 1 M/MA & 2GR, 5.5"" x 2.75""','Hoagies WG Trky Breast&Chs IW 1 M/M',122386,NULL,'00737410066950','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2022-09-15',NULL,'UNPREPARED',2337267,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Hoagie, Whole Grain, Turkey Ham & Cheese, Individually Wrapped, 1 M/MA & 2 GR, 5.5" x 2.75"','Hoagies WG Trky Ham&Chs IW 1 M/MA&2',122387,NULL,'00737410066967','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-04-27',NULL,'UNPREPARED',2521384,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Bun, Whole Grain, Cheese & Turkey Breast, Individually Wrapped','Sndwch Bun WG Chs&Trky Breast IW',122391,NULL,'00737410067056','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-04-27',NULL,'UNPREPARED',2521385,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Bun, Whole Grain, 100% Beef Hamburger, Individually Wrapped, 3.75"','Sndwch Bun WG 100% Beef Hamb IW 3.7',122392,NULL,'00737410067063','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-02-16',NULL,'UNPREPARED',2458117,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Bun, Whole Grain, 100% Beef Cheeseburger, Individually Wrapped, 3.75""','Sndwch Bun WG 100% Beef Chsburger I',122393,NULL,'00737410067070','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2022-09-15',NULL,'UNPREPARED',2337699,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Whole Grain, Beef Meatball, Individually Wrapped, 5.6"','Sndwch, WG, Beef Meatball, IW, 5.6"',122394,NULL,'00737410067087','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2023-02-16',NULL,'UNPREPARED',2458118,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Croissant, Whole Grain, Mozzarella & American Cheese, Individually Wrapped','Sndwch Crois WG Mozz&American Chs I',122395,NULL,'00737410067094','Bake Crafters Food Company','Bake Crafters',NULL,3,'2021-04-01','2024-08-15',NULL,'UNPREPARED',2701136,'50192500');
INSERT INTO `cndb_fdes` VALUES (25,'Pepperidge Farm Goldfish Baked Snack Crackers, Cheddar Cheese, .75 Ounces, Pack of 300','PF GF CHEDDAR',122409,'14367','10014100143670','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2021-04-01','2024-07-11',NULL,'UNPREPARED',2697060,'50182100');
INSERT INTO `cndb_fdes` VALUES (22,'IW Egg & Pepper Jack Cheese Breakfast Bowtie','Egg & Pepper Jack Cheese Bowtie',122417,NULL,'10693392005189','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2522003,'50192500');
INSERT INTO `cndb_fdes` VALUES (22,'Meal Kit Beef Stick-Clean Label','Meal Kit Beef Stick-Clean Label',122420,NULL,'10693392005806','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730460,'50193400');
INSERT INTO `cndb_fdes` VALUES (22,'Meal Kit No Nut Butter','Meal Kit No Nut Butter',122421,NULL,'10693392005585','ES Foods','ES Foods',NULL,3,'2021-04-01','2023-10-26',NULL,'READY_TO_EAT',2649553,'50193400');
INSERT INTO `cndb_fdes` VALUES (22,'Meal Kit Turkey Stick','Meal Kit Turkey Stick ',122423,NULL,'10693392005226','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730457,'50193400');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit No Nut Butter','Breakfast Kit No Nut Butter',122424,NULL,'10693392005790','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2023-06-29',NULL,'PREPARED',2559417,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Nutri-Grain Bar Strawberry','Breakfast Kit Nutri Grain Bar Straw',122425,NULL,'10693392005677','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730459,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Fudge Pop-Tart','Breakfast Kit Fudge Pop-Tart',122426,NULL,'10693392003017','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730443,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Cocoa Puffs Cereal Bar','Breakfast Kit Cocoa Puffs CerealBar',122427,NULL,'10693392005042','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730455,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Trix Cereal Bar','Breakfast Kit Trix Cereal Bar',122428,NULL,'10693392005332','ES Foods, Inc','ES Foods',NULL,3,'2021-04-01','2024-05-16',NULL,'PREPARED',2689963,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit, Strawberry Pop-Tart','Breakfast Kit, Strawberry Pop-Tart',122429,NULL,'10693392005820','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730462,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Hot Meal Break-Macaroni  and Cheese with Carrots','Macaroni  & Cheese with Carrots',122430,NULL,'10693392003642','ES Foods, Inc.','ES Foods',NULL,3,'2021-04-01','2023-04-27',NULL,'HEAT_AND_SERVE',2521992,'50192900');
INSERT INTO `cndb_fdes` VALUES (22,'Vegetarian Chili w/Spanish Rice','Vegetarian Chili w/Spanish Rice',122431,NULL,'10693392004946','ES Foods, Inc.','ES Foods',NULL,3,'2021-04-01','2023-06-29',NULL,'HEAT_AND_SERVE',2559408,'50192900');
INSERT INTO `cndb_fdes` VALUES (22,'Penne Alfredo with Carrots and Peas','Penne Alfredo with Carrots and Peas',122432,NULL,'10693392005356','ES Foods, Inc.','ES Foods',NULL,3,'2021-04-01','2023-06-29',NULL,'BAKE',2559413,'50192900');
INSERT INTO `cndb_fdes` VALUES (22,'Hot Meal Break-Lasagna with Veggie Crumbles','Lasagna with Veggie Crumbles',122433,NULL,'10693392006063','ES Foods, Inc.','ES Foods',NULL,3,'2021-04-01','2023-04-27',NULL,'HEAT_AND_SERVE',2522020,'50192900');
INSERT INTO `cndb_fdes` VALUES (22,'Italian Combo Sandwich on WG Wrap','TSMB Italian Combo Wrap',122434,NULL,'10693392000825','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2023-08-31',NULL,'PREPARED',2614131,'50193800');
INSERT INTO `cndb_fdes` VALUES (22,'TSMB Tky Ham & Cheese Thin Sandwich','TSMB Tky Ham & Cheese Ciabatta',122435,NULL,'10693392005684','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2024-02-01',NULL,'PREPARED',2683452,'50193800');
INSERT INTO `cndb_fdes` VALUES (22,'TSMB Breaded Chick. Hamburger Sand','Breaded Chick. Hamburger Sand. Meal',122436,NULL,'10693392005752','ES Foods','ES Foods',NULL,3,'2021-04-01','2023-06-29',NULL,'THAW',2559415,'50193800');
INSERT INTO `cndb_fdes` VALUES (22,'TSMB Breaded Chicken On Waffle Sand.','Breaded Chick. On Waffle Sand. Meal',122437,NULL,'10693392005813','ES Foods','ES Foods',NULL,3,'2021-04-01','2023-06-29',NULL,'THAW',2559419,'50193800');
INSERT INTO `cndb_fdes` VALUES (22,'TSMB WG Pizza Sub Hoagie Sand.','Pizza Sub Hoagie Sandwich Meal',122438,NULL,'10693392005783','ES Foods','ES Foods',NULL,3,'2021-04-01','2023-06-29',NULL,'THAW',2559416,'50193800');
INSERT INTO `cndb_fdes` VALUES (22,'Meal Kit Chicken Salad','Meal Kit Chicken Salad',122440,NULL,'10693392003222','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730444,'50193400');
INSERT INTO `cndb_fdes` VALUES (22,'Meal Kit Peanut Butter & Jelly','Meal Kit Peanut Butter & Jelly',122441,NULL,'10693392003239','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730445,'50193400');
INSERT INTO `cndb_fdes` VALUES (22,'Meal Kit Cheese and Beef Stick','Meal Kit Cheese and Beef',122442,NULL,'10693392003253','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730446,'50193400');
INSERT INTO `cndb_fdes` VALUES (22,'Meal Kit Cheese Cup','Meal Kit Cheese Cup',122443,NULL,'10693392000764','ES Foods','ES Foods',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2521973,'50193400');
INSERT INTO `cndb_fdes` VALUES (22,'Meal Kit Sun Butter','Meal Kit Sun Butter',122444,NULL,'10693392000771','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730482,'50193400');
INSERT INTO `cndb_fdes` VALUES (22,'Meal Kit Cheese Stick w/ Marinara Sauce','Meal Kit Cheese Stick w/ Marinara S',122445,NULL,'10693392001594','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730464,'50193400');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Lucky Charms','Breakfast Kit Lucky Charms',122446,NULL,'10693392000092','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730477,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Honey Cheerios','Breakfast Kit Honey Cheerios',122447,NULL,'10693392000115','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2023-08-31',NULL,'PREPARED',2614125,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Frosted Flakes ','Breakfast Kit RS Frosted Flakes',122448,NULL,'10693392000122','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2024-05-16',NULL,'PREPARED',2689982,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Multigrain Cheerios','Breakfast Kit Multigrain Cheerios',122449,NULL,'10693392000474','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730481,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Golden Grahams ','Breakfast Kit Golden Grahams',122450,NULL,'10693392000153','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730479,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Fruity Cheerios','Breakfast Kit Fruity Cheerios',122451,NULL,'10693392000160','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2023-08-31',NULL,'PREPARED',2614127,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Apple Cinnamon Cheerios','Breakfast Kit Apple Cinn. Cheerios',122452,NULL,'10693392000177','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2023-06-29',NULL,'PREPARED',2559404,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Cinnamon Toast Crunch Reduced Sugar','Breakfast Kit RS Cinn. Toast Crunch',122453,NULL,'10693392000184','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730480,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit RS Cinnamon Toast Crunch','Breakfast Kit RS Cinn. Toast Cru',122454,NULL,'10693392001099','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2024-05-16',NULL,'PREPARED',2689971,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Cinnamon Pop-Tart','Breakfast Kit Cinnamon Por-Tart',122455,NULL,'10693392002607','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730450,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'Breakfast Kit Cinnamon Toast Crunch Cereal Bar','Breakfast Kit CTC Cereal Bar',122456,NULL,'10693392002614','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730441,'50221200');
INSERT INTO `cndb_fdes` VALUES (22,'TSBB Annies Graham Crackers w/Craisins Breakfast Breaks','Breakfast Kit  Grahams and Craisins',122457,NULL,'10693392005400','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2024-05-16',NULL,'PREPARED',2689941,'50192300');
INSERT INTO `cndb_fdes` VALUES (22,'Snack Kit, Animal Crackers WG','Snack Kit, Animal Crackers WG',122458,NULL,'10693392000962','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2024-05-16',NULL,'PREPARED',2689973,'50193400');
INSERT INTO `cndb_fdes` VALUES (22,'Snack Kit, Mini Cinnamon Grahams WG','Snack Kit, Mini Cinnamon Grahams WG',122459,NULL,'10693392000986','E S Foods','ES Foods',NULL,3,'2021-04-01','2024-05-16',NULL,'PREPARED',2689972,'50193400');
INSERT INTO `cndb_fdes` VALUES (22,'Snack kit, Cheez-It Crackers WG','Snack Kit, Cheez-It Crackers WG',122460,NULL,'10693392002867','E S Foods','ES Foods',NULL,3,'2021-04-01','2024-05-16',NULL,'PREPARED',2689987,'50193400');
INSERT INTO `cndb_fdes` VALUES (22,'Snack Kit Strawberry Bites WG','Snack Kit Strawberry Bites WG',122461,NULL,'10693392005240','E S Foods','ES Foods',NULL,3,'2021-04-01','2024-05-16',NULL,'PREPARED',2689965,'50193400');
INSERT INTO `cndb_fdes` VALUES (22,'Combo Hoagie Sandwich Meal Thaw & Serve Meal Breaks','TSMB Combo Hoagie Sandwich',122462,NULL,'10693392003567','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2521991,'50193800');
INSERT INTO `cndb_fdes` VALUES (22,'TSMB Crustless PB&J Grape Sandwich','TSMB Crustless PB&J Grape Sandwich',122463,NULL,'10693392003277','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730447,'50193800');
INSERT INTO `cndb_fdes` VALUES (22,'Turkey & Cheese Sand. Meal','TSMB Turkey & Cheese Sand. Meal',122464,NULL,'10693392003291','East Side Entrees','ES Foods',NULL,3,'2021-04-01','2025-04-24',NULL,'THAW',2730448,'50193800');
INSERT INTO `cndb_fdes` VALUES (16,'Zee Zees Hummus Cup, Taco, 4.5 oz.','Hummus Cup, Taco',122488,NULL,'20810358032493','National Food Group','Zee Zees',NULL,3,'2021-04-01','2024-08-15',NULL,'READY_TO_EAT',2700902,'50192100');
INSERT INTO `cndb_fdes` VALUES (16,'Zee Zees Roasted Chickpeas, Sea Salt, 0.75oz','Sea Salt Cruncherz Chickpeas',122493,NULL,'20810358032530','National Food Group  Inc.','Zee Zees',NULL,3,'2021-04-01','2024-07-11',NULL,'READY_TO_EAT',2696471,'50262200');
INSERT INTO `cndb_fdes` VALUES (16,'Zee Zees Roasted Chickpeas, Ranch, 0.75 oz','Ranch Flavored Cruncherz',122494,NULL,'20810358032547','National Food Group  Inc.','Zee Zees',NULL,3,'2021-04-01','2024-07-11',NULL,'READY_TO_EAT',2696472,'50192100');
INSERT INTO `cndb_fdes` VALUES (16,'Zee Zees Roasted Chickpeas, Chili Lime, 0.75oz','Chili Lime Cruncherz Chickpeas',122495,NULL,'20810358032554','National Food Group  Inc.','Zee Zees',NULL,3,'2021-04-01','2024-08-15',NULL,'READY_TO_EAT',2700901,'50192100');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S FIESTADA BF STF SAND WG IW NET WT 13.38LBS 48CT','BD BF FIESTADA',122533,NULL,'10072180552911','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2021-04-01','2023-10-26',NULL,'UNPREPARED',2649590,'50192500');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S BUF CHIC STF SAND WG IW NET WT 13.38LBS 48CT','BD BUF CHIC SAND',122534,NULL,'10072180552928','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2021-04-01','2023-10-26',NULL,'UNPREPARED',2649591,'50192500');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S PEPP STF SAND WG IW NET WT 13.38LBS 48CT','BD PEPP STF SAND',122535,NULL,'10072180552935','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2021-04-01','2023-10-26',NULL,'UNPREPARED',2649592,'50192500');
INSERT INTO `cndb_fdes` VALUES (22,'Whole Grain Bean & Cheese Empanada','WG Bean & Cheese Empanada',122546,NULL,'00711341504514','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2021-04-01','2023-04-27',NULL,'UNPREPARED',2525849,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'Whole Grain Cheesy Pretzel Pocket','WG Cheesy Pretzel Pocket',122547,NULL,'00711341508222','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2021-04-01','2023-04-27',NULL,'UNPREPARED',2525852,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'WG Philly Cheesesteak Calzone','WG Philly Cheesesteak Calzone',122548,NULL,'00711341509908','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2021-04-01','2023-03-16',NULL,'UNPREPARED',2492483,'50182200');
INSERT INTO `cndb_fdes` VALUES (18,'WG Pizza Empanada','WG Pizza Empanada',122549,NULL,'00711341533262','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2021-04-01','2023-03-16',NULL,'UNPREPARED',2492485,'50182200');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Apple Cinnamon Muffin Top','WG Apple Cinnamon  Muffin Top',122551,NULL,'00711341631166','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2021-04-01','2023-06-29',NULL,'UNPREPARED',2558249,'50181900');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Reduced Fat Chocolate Chip Cookie','WG RF Chocolate Chip Cookie',122552,NULL,'00711341791204','Buena Vista Food Products','Linda''s Cookies',NULL,3,'2021-04-01','2023-01-26',NULL,'PREPARED',2443785,'50182100');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Cinnamon Crumble','WG Cinnamon Crumble',122554,NULL,'00711341900408','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2021-04-01','2023-06-29',NULL,'UNPREPARED',2558283,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cowboy Bread','Cowboy Bread',122555,NULL,'00711341900903','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2021-04-01','2023-06-29',NULL,'PREPARED',2558286,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Alaska Pollock, Oven Ready Breaded Fish Sticks Frozen USDA','TR CN ULTIMATE FISH STICK  USDA',122558,NULL,'10028029250890','Trident Seafoods Corp.','Trident Seafoods',NULL,3,'2021-04-01','2024-08-15',NULL,'UNPREPARED',2701448,'50121900');
INSERT INTO `cndb_fdes` VALUES (15,'SURIMI SEAFOOD FLAKE STYLE','SL CN REAL SIMPLE FLAKE',122560,NULL,'10079468286742','Trident Seafoods Corp.','Sea Legs  Real Simple',NULL,3,'2021-04-01','2025-04-24',NULL,'PREPARED',2730465,'50121900');
INSERT INTO `cndb_fdes` VALUES (18,'Darlington Whole Grain 1.5 oz  Cinnamon Breakfast Squares, Individually Wrapped - 160ct','1.5oz WG Cinnamon Squares, IW',122630,NULL,'00675825242005','Darlington Cookie Company','Darlington',NULL,3,'2021-04-01','2024-02-01',NULL,'PREPARED',2683698,'50221200');
INSERT INTO `cndb_fdes` VALUES (25,'Crave-N-Rave Whole Grain 0.9 oz El Nacho Cheese WG Spikerz Cracker Bites, Individually Wrapped, 300 ct','0.9oz WG Nacho Chs Spikerz, IW',122631,NULL,'00675825511101','Darlington Cookie Company','Crave-N-Rave',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2525795,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'Crave-N-Rave Whole Grain 0.9 oz Heavenly Ranch Spikerz Cracker Bites, Individually Wrapped, 300 ct','0.9oz WG Ranch Spikerz, IW',122632,NULL,'00675825512108','Darlington Cookie Company','Crave-N-Rave',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2525796,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'Appleways Whole Grain 1.2 oz Soft Oatmeal Vanilla Celebration Bars, Individually Wrapped - 216ct','1.2oz WG Vanilla Bars, IW',122636,NULL,'00675825705005','Darlington Cookie Company','Appleways',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2525805,'50221200');
INSERT INTO `cndb_fdes` VALUES (25,'Appleways Whole Grain 1.2 oz Soft Oatmeal Blueberry Bars, Individually Wrapped - 216ct','1.2oz WG Blueberry Bars, IW',122637,NULL,'00675825706002','Darlington Cookie Company','Appleways',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2525807,'50221200');
INSERT INTO `cndb_fdes` VALUES (25,'Appleways Whole Grain 1.0 oz Cinnamon Crispy Bites, Individually Wrapped - 108ct','1.0oz WG Cinnamon Crispy Bites, IW',122638,NULL,'00675825710009','Darlington Cookie Company','Appleways',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2525808,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'Appleways Whole Grain 1.0 oz Cocoa Crispy Bites, Individually Wrapped - 108ct','1.0oz WG Cocoa Crispy Bites, IW',122639,NULL,'00675825713000','Darlington Cookie Company','Appleways',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2525810,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'Appleways Whole Grain 1.0 oz Blueberry Lemon Crispy Bites, Individually Wrapped - 108ct','1.0oz WG BB Lemon Crispy Bites, IW',122640,NULL,'00675825715004','Darlington Cookie Company','Appleways',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2525812,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'Appleways Whole Grain 1.0 oz Granola Crispy Bites, Individually Wrapped - 108ct','1.0oz WG Granola Crispy Bites, IW',122641,NULL,'00675825716001','Darlington Cookie Company','Appleways',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2525816,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'Appleways Whole Grain 1.4 oz Oatmeal Raisin Cookies, Individually Wrapped - 160ct','1.4oz WG SB OAT Raisin Cookies, IW',122644,NULL,'00675825730007','Darlington Cookie Company','Appleways',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2525821,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'Appleways Whole Grain 1.4 oz Chocolate Chip Cookies, Individually Wrapped - 160ct','1.4oz WG SB OAT ChocChip Cookies, I',122645,NULL,'00675825733008','Darlington Cookie Company','Appleways',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2525823,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'Appleways Whole Grain 2.4 oz Soft Oatmeal Apple Bars, Individually Wrapped - 160ct','2.4oz oz WG Apple Oatmeal Bars, IW',122646,NULL,'00675825751002','Darlington Cookie Company','Appleways',NULL,3,'2021-04-01','2023-05-25',NULL,'PREPARED',2539875,'50221200');
INSERT INTO `cndb_fdes` VALUES (25,'Appleways Whole Grain 2.4 oz Soft Oatmeal Chocolate Chip Bars, Individually Wrapped - 160ct','2.4oz WG Choc Chip Oatmeal Bars, IW',122647,NULL,'00675825753006','Darlington Cookie Company','Appleways',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2525827,'50221200');
INSERT INTO `cndb_fdes` VALUES (25,'Appleways Whole Grain 2.4 oz Soft Oatmeal Strawberry Bars, Individually Wrapped - 160ct','2.4oz WG Strawberry Oatmeal Bars, I',122648,NULL,'00675825754003','Darlington Cookie Company','Appleways',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2525829,'50221200');
INSERT INTO `cndb_fdes` VALUES (25,'Appleways Whole Grain 2.4 oz Soft Oatmeal Vanilla Celebration Bars, Individually Wrapped - 160ct','2.4oz WG Vanilla Bars, IW',122649,NULL,'00675825755000','Darlington Cookie Company','Appleways',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2525831,'50221200');
INSERT INTO `cndb_fdes` VALUES (25,'Appleways Whole Grain 2.4 oz Soft Oatmeal Blueberry Bars, Individually Wrapped - 160ct','2.4oz WG Blueberry Bars, IW',122650,NULL,'00675825756007','Darlington Cookie Company','Appleways',NULL,3,'2021-04-01','2023-05-25',NULL,'PREPARED',2539829,'50221200');
INSERT INTO `cndb_fdes` VALUES (25,'Appleways Whole Grain 0.9 oz Cheddar Cheese Crispy Crackers, Individually Wrapped, 108ct','0.9oz WG  Cheddar Chs Crackers, IW',122651,NULL,'00675825761001','Darlington Cookie Company','Appleways',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2525835,'50182100');
INSERT INTO `cndb_fdes` VALUES (25,'Appleways Whole Grain 1.0 oz Sweet Potato Crispy Crackers, Individually Wrapped, 108ct','1.0oz WG Sweet Potato Cracker, IW',122653,NULL,'00675825764002','Darlington Cookie Company','Appleways',NULL,3,'2021-04-01','2023-04-27',NULL,'PREPARED',2525843,'50182100');
INSERT INTO `cndb_fdes` VALUES (11,'Bella Vista; 6/#10 Tomato Sauce - Low Sodium','6/10 Tomato Sauc - Low Sodium',122684,NULL,'00041188108621','Furmano Foods','Bella Vista',NULL,3,'2021-04-01','2023-05-25',NULL,'UNPREPARED',2539718,'50102100');
INSERT INTO `cndb_fdes` VALUES (1,'Hispanic Scramble 6/5# 30#','Hispanic Scramble',122707,NULL,'00049485051657','JTM Food Group','JTM Food Group',NULL,3,'2021-04-01','2024-10-31',NULL,'PREPARED',2715976,'50390100');
INSERT INTO `cndb_fdes` VALUES (9,'Black Cherry Froot Jooce 100% Frozen Juice Cup','case of Black Cherry Froot Jooce',122708,NULL,'10815294000103','Lindy''s Homemade','Froot Jooce',NULL,3,'2021-04-01','2024-12-19',NULL,'READY_TO_EAT',2718830,'50192300');
INSERT INTO `cndb_fdes` VALUES (9,'Fruit Punch Froot Jooce 100% Frozen Juice Cup','case of Fruit Punch Froot Jooce',122709,NULL,'10815294000172','Lindy''s Homemade','Froot Jooce',NULL,3,'2021-04-01','2024-12-19',NULL,'READY_TO_EAT',2718831,'50192300');
INSERT INTO `cndb_fdes` VALUES (9,'Strawberry Froot Jooce 100% Frozen Juice Cup','case of Strawberry Froot Jooce',122710,NULL,'10815294000295','Lindy''s Homemade','Froot Jooce',NULL,3,'2021-04-01','2024-08-15',NULL,'READY_TO_EAT',2700453,'50192300');
INSERT INTO `cndb_fdes` VALUES (9,'Watermelon Froot Jooce 100% Frozen Juice Cup','case of Watermelon Froot Jooce',122711,NULL,'10815294000189','Lindy''s Homemade','Froot Jooce',NULL,3,'2021-04-01','2023-03-23',NULL,'READY_TO_EAT',2512232,'50192300');
INSERT INTO `cndb_fdes` VALUES (9,'Mango Froot Jooce 100% Frozen Juice Cup','case of Mango Froot Jooce',122712,NULL,'10815294000097','Lindy''s Homemade','Froot Jooce',NULL,3,'2021-04-01','2024-12-19',NULL,'READY_TO_EAT',2718829,'50192300');
INSERT INTO `cndb_fdes` VALUES (9,'Tangerine Froot Jooce 100% Frozen Juice Cup','case of Tangerine Froot Jooce',122713,NULL,'10815294000257','Lindy''s Homemade','Froot Jooce',NULL,3,'2021-04-01','2024-08-15',NULL,'READY_TO_EAT',2700460,'50192300');
INSERT INTO `cndb_fdes` VALUES (9,'Cherrymoji (Black Cherry) Froot Jooce 100% Frozen Juice Cup','case of Cherrymoji Froot Jooce',122714,NULL,'10815294000455','Lindy''s Homemade','Froot Jooce',NULL,3,'2021-04-01','2025-03-20',NULL,'READY_TO_EAT',2723176,'50192300');
INSERT INTO `cndb_fdes` VALUES (9,'HBD2U (Mango) Froot Jooce 100% Frozen Juice Cup','case of HBD2U Froot Jooce',122715,NULL,'10815294000462','Lindy''s Homemade','Froot Jooce',NULL,3,'2021-04-01','2024-08-15',NULL,'READY_TO_EAT',2700450,'50192300');
INSERT INTO `cndb_fdes` VALUES (9,'Tangerine Dragon Froot Jooce 100% Frozen Juice Cup','case of Tangerine DragonFroot Jooce',122716,NULL,'10815294000486','Lindy''s Homemade','Froot Jooce',NULL,3,'2021-04-01','2024-08-15',NULL,'READY_TO_EAT',2700448,'50192300');
INSERT INTO `cndb_fdes` VALUES (9,'Berry America (Strawberry) Froot Jooce 100% Frozen Juice Cup','case of Berry America Froot Jooce',122717,NULL,'10815294000479','Lindy''s Homemade','Froot Jooce',NULL,3,'2021-04-01','2024-08-15',NULL,'READY_TO_EAT',2700449,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'12" Self Rise Pizza Topped with Cheese Sauce, Mozzarella Cheese, Egg, and Bacon','12" Self-Rising Breakfast Pizza',122718,NULL,'00085541135824','Nardone Brothers Baking Co.  Inc.','Nardone Bros',NULL,3,'2021-04-01','2023-06-29',NULL,'BAKE',2558156,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'12" Self-Rising Breakfast Pizza w/ Bacon, Egg, Sausage, 100% Mozzarella Cheese, and Cheese Sauce','12" Self-Rising Breakfast Pizza',122719,NULL,'00085541133882','Nardone Brothers Baking Co.  Inc.','Nardone Bros',NULL,3,'2021-04-01','2025-01-23',NULL,'BAKE',2722537,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pizzeria Style Pizza Topped with Tomato Sauce and Mozzarella Cheese','Pizzeria Style Cheese Pizza',122722,NULL,'00085541133134','Nardone Brothers Baking Co.  Inc.','Nardone Bros',NULL,3,'2021-04-01','2023-06-29',NULL,'BAKE',2558119,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'16" Pizzeria Style Pizza Topped  with Mozzarella Cheese, Tomato Sauce, and Pepperoni','16" Pizzeria Style Pepperoni Pizza',122723,NULL,'00085541135336','Nardone Brothers Baking Co.  Inc.','Nardone Bros',NULL,3,'2021-04-01','2023-06-29',NULL,'BAKE',2558149,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'16" Pizzeria Style Pizza Topped with Tomato Sauce, Mozzarella Cheese, and Pepperoni','16" Pizzeria Style Pepperoni Pizza',122724,NULL,'00085541135343','Nardone Brothers Baking Co.  Inc.','Nardone Bros',NULL,3,'2021-04-01','2023-06-29',NULL,'BAKE',2558150,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Topped with Mozzarella Cheese, Robust Sauce and Turkey Pepperoni','16 Round Self-Rising Turkey Pepper',122725,NULL,'00085541133363','Nardone Brothers Baking Co.  Inc.','Nardone Bros',NULL,3,'2021-04-01','2023-06-29',NULL,'BAKE',2558126,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'8/2.25 lb. Cheesy Lil Bites','Cheesy Lil Bites',123144,NULL,'10010374770437','The Father''s Table','The Father''s Table',NULL,3,'2021-04-01','2023-06-29',NULL,'BAKE',2558699,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Strawberry Bites (70 count)','Strawberry Bites (70 count)',123146,NULL,'10010374011776','The Father''s Table','The Fathers Table Dunkers',NULL,3,'2021-04-01','2023-06-29',NULL,'THAW',2558692,'50192300');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Ready to Serve Low Sodium Vegetable Soup, 7.25 Ounce Cans, 24-Pack','CPB LOW SODIUM VEGETABLE SOUP',123169,'603','10051000006032','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2022-04-01','2024-07-11',NULL,'UNPREPARED',2696214,'50191500');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Ready to Serve Low Sodium Chicken Noodle Soup, 7.25 Ounce Cans, 24-Pack','CAMPBELL''S CHICKEN NOODLE',123170,'614','10051000006148','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2022-04-01','2024-07-11',NULL,'UNPREPARED',2696213,'50191500');
INSERT INTO `cndb_fdes` VALUES (22,'Campbell''s Frozen Entrees Garden Mixed Vegetable Lasagna, 5.75 Pound Trays, 4-Pack','VEG LASAGNA',123173,'8063','10051000080636','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2022-04-01','2024-07-11',NULL,'UNPREPARED',2696193,'50193100');
INSERT INTO `cndb_fdes` VALUES (22,'Campbell''s Frozen Entrees Traditional Stuffed Cabbage Rolls, 5.5 Pound Trays, 4-Pack','ST CABBAGE ROLL',123174,'8156','10051000081565','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2022-04-01','2024-07-11',NULL,'UNPREPARED',2696194,'50193100');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Signature Frozen Condensed Chicken Tortilla Soup, 4 Pound Trays, 3-Pack','CHICKEN TORTILLA',123178,'14894','10051000148947','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2022-04-01','2023-10-26',NULL,'UNPREPARED',2650058,'50191500');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Signature Frozen Condensed Healthy Request Portobello Mushroom and Barley Soup, 4 Pound Trays, 3-Pack','FS V8 VG MSRM BR',123180,'15357','10051000153576','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2022-04-01','2023-05-25',NULL,'UNPREPARED',2539623,'50191500');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Signature Frozen Condensed Healthy Request Rosemary Chicken and Dumpling Soup, 4 Pound Trays, 3-Pack','FS RSMRY CK&DUMP',123181,'16273','10051000162738','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2022-04-01','2023-03-16',NULL,'UNPREPARED',2492796,'50191500');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Signature Frozen Condensed Healthy Request Tuscan-Style White Bean with Chicken Soup, 4 Pound Trays, 3-Pack','TUSC WH BEAN W/C',123182,'16866','10051000168662','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2022-04-01','2023-03-16',NULL,'UNPREPARED',2492797,'50191500');
INSERT INTO `cndb_fdes` VALUES (6,'Campbell''s Condensed Beef Consomme, 50 Ounce Cans, 12-Pack','CPB BF CONSOMME',123189,'27513','10051000275131','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2022-04-01','2024-07-11',NULL,'UNPREPARED',2696281,'50191500');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S STF SAND WG PEPP 48CT CN SFS BIG DADDY''S STF SAND WG PEPP 48CT NET WT 13.38LBS CN','BD PEPP STF SAND',123198,'55290','10072180552904','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2718922,'50192500');
INSERT INTO `cndb_fdes` VALUES (22,'SFS BIG DADDY''S PRIMO RC WG BBQ CHIC 3-3PK NET WT 24.92LBS CN','BD PRIMO BBQ CHX',123200,'68638','10072180686388','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2718995,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S 51% WG BREAKFAST BAGEL WITH EGGS AND TURKEY BREAKFAST SAUSAGE - IW NET WT 16.98 LBS 96CT','BKFT BGL C/E/MT',123202,'67625','10072180676259','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2022-04-01','2024-02-01',NULL,'UNPREPARED',2683719,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'SFS TONY''S 51% WG BREAKFAST BAGEL WITH MOZZARELLA AND EGGS NET WT 16.80 LBS 96CT','BKFT BGL EGG CHS',123203,'67626','10072180676266','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2022-04-01','2024-02-01',NULL,'UNPREPARED',2683592,'50182200');
INSERT INTO `cndb_fdes` VALUES (22,'Whole Grain Reduced Fat Three Cheese Calzone','WG Spinach & Cheese Calzone',123204,NULL,'00711341501124','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2525846,'50182200');
INSERT INTO `cndb_fdes` VALUES (18,'Whole Grain Cornbread Muffin','WG Cornbread Muffin',123205,NULL,'00711341641752','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2022-04-01','2023-01-26',NULL,'PREPARED',2443999,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chicken Parmesan Tray','Chicken Parmesan Tray',123210,NULL,'10852777007532','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-09-14',NULL,'CONVECTION',2641412,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'12ct Ultra Loco Bread Round','Loco Bread Round',123211,NULL,'00045059011881','The Father''s Table','Ultra Loco',NULL,3,'2022-04-01','2024-12-19',NULL,'THAW',2718440,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'12ct Ultra Loco Bread Squared','Loco Bread Squared',123212,NULL,'00045059011911','The Father''s Table','Ultra Loco',NULL,3,'2022-04-01','2023-08-31',NULL,'THAW',2613401,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'24/2 Chefway Parboiled Long Grain Brown Rice','RICE BRN US#1 LONG PARBOILED PKG-24',123213,NULL,'10035200265673','Riceland Foods','Chefway','100500',3,'2022-04-01','2024-12-19',NULL,'DRY',2719683,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'300 LAKESIDE N/S WK GLD CRN','LK N/S WK CN',123214,NULL,'00033828078128','Lakeside Foods Inc.','LAKESIDE FOODS INC',NULL,3,'2022-04-01','2024-12-19',NULL,'READY_TO_EAT',2721067,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Biscuits, Honey Wheat, Whole Grain, Reduced Sodium, Sliced, Individually Wrapped','Biscuits, Hny Wht, WG, RS, Sl, IW',123215,NULL,'00737410007762','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2521346,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'8 / 5 lb. package contains (123)slices at .65 oz. Servings approved by the USDA.','Frozen, Cooked, Deli Style Turkey',123216,NULL,'10715001109030','ES Foods, Inc.','ES Foods',NULL,3,'2022-04-01','2023-04-27',NULL,'THAW',2522021,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'80ct CoCo Chip Bites','COCO CHIP BITES',123217,NULL,'10010374011837','The Father''s Table','The Father''s Table Dunkers',NULL,3,'2022-04-01','2023-06-29',NULL,'READY_TO_EAT',2558693,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Brakebush CN Whole Grain Breaded Breast Nuggets, Fully Cooked, Frozen, 0.8 oz.','FC CN Whole Grain Breast Nuggets',123218,NULL,'10038034565209','Brakebush Brothers','Brakebush',NULL,3,'2022-04-01','2024-09-13',NULL,'UNPREPARED',2703872,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Chicken Sausage Links, Skinless, .75 oz. , 1/10 lb., Fully Cooked , Certified Gluten- Free','Chkn Saus Link, FC, CN, .75oz, AN',123219,NULL,'00033900607383','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721136,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Brakebush SmartShapes CN Whole Grain Breaded Breast Strips, Fully Cooked, Frozen, 1.1 oz.','Whole Grain Strips CN',123220,NULL,'10038034584309','Brakebush Brothers','Brakebush',NULL,3,'2022-04-01','2024-10-31',NULL,'UNPREPARED',2716292,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Brakebush CN Whole Grain Breast Patties, Fully Cooked, Breaded, Frozen, 3.15 oz.','FC CN Whole Grain Breast Patties',123221,NULL,'10038034595206','Brakebush Brothers','Brakebush',NULL,3,'2022-04-01','2024-10-31',NULL,'UNPREPARED',2716285,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.2 oz Soft Oatmeal Blueberry Bar, Individually Wrapped - Each','1.2oz WG Blueberry Bar, Each',123222,NULL,'00675825706903','Darlington Cookie Company','Appleways',NULL,3,'2022-04-01','2022-04-01',NULL,'PREPARED',2236051,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bagels, Honey Wheat, Whole Grain, Sliced 6''s','Bagels, Honey Wheat, WG, Sliced 6''s',123223,NULL,'00737410658001','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2521470,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bagels, Whole Grain, Blueberry, Sliced 6''s, 4.5" x 1.75"','Bagels WG Blueb Sl 6''s 4.5"x1.75"',123224,NULL,'00737410611006','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2521468,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bagels, Whole Grain, Cinnamon Raisin, Sliced 6''s, 4.5" x 1.75"','Bagels WG Cinn Raisin Sl 6''s',123225,NULL,'00737410612003','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2521469,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bella Vista; 1/#10 Vegetarian Beans - Fancy','10 Vegetarian Bns - Fcy',123228,NULL,'00041188847100','Furmano Foods','Bella Vista',NULL,3,'2022-04-01','2023-05-25',NULL,'UNPREPARED',2539739,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Biscuits, Buttermilk, Frozen Dough, Lower Sodium','CLOSEOUT Biscs Btrmlk Frz Dgh Lower',123229,NULL,'00737410010281','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722389,'50193300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bread Sticks, Whole Grain, Low Sodium, 7"','Bread Sticks, Whole Grain, LS, 7"',123230,NULL,'00737410025728','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-02-15',NULL,'UNPREPARED',2684131,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Baby Butter Beans 16 oz','Bush''s Baby Butter Bn 16 oz',123231,NULL,'00039400016700','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722294,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Baked Beans with Onion 16 oz','Bush''s Baked Bn (Oni) 16 oz',123232,NULL,'00039400016014','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722120,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Baked Beans with Onion 28 oz','Bush''s Baked Bn (Oni) 28 oz',123233,NULL,'00039400016038','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722646,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Barbecue Baked Beans 16 oz','Bush''s Barbecue Baked Bns 16 oz',123234,NULL,'00039400012016','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2723083,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Barbecue Baked Beans 28 oz','Bush''s Barbecue Bkd Bns 28 oz',123235,NULL,'00039400011996','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722778,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Bean Pot Reduced Sodium Vegetarian Baked Beans 115 oz','Bush''s RS Veg Bn Pot Bkd Bn 115 oz',123237,NULL,'00039400016380','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722630,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Bean Pot Vegetarian Baked Beans 117 oz','Bush''s Bean Pot Vegetarian 117 oz',123238,NULL,'00039400016373','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722268,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Black Beans 15 oz','Bush''s Black Bn 15 oz',123240,NULL,'00039400018803','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721199,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Black Beans 26.5 oz','Bush''s Black Bn 26.5 oz',123241,NULL,'00039400018827','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722423,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Black Beans in a Mild Chili Sauce 15.5 oz','Bush''s Mld Black Chili Bn 15.5 oz',123243,NULL,'00039400015024','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722264,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Blackeye Peas 111 oz','Bush''s Blackeye Pea 111 oz',123244,NULL,'00039400016595','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722530,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Blackeye Peas 15.8 oz','Bush''s Blackeye Pea 15.8 oz',123245,NULL,'00039400013686','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722829,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Blackeye Peas with Bacon 15.5 oz','Bush''s Blackeye Pea (Bac) 15.5 oz',123246,NULL,'00039400013587','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722978,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Blackeye Peas with Snaps 15.8 oz','Bush''s Blackeye Pea Snp 15.8 oz',123247,NULL,'00039400013723','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722022,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Boston Recipe Baked Beans 16 oz','Bush''s Baked Bn (Bos) 16 oz',123248,NULL,'00039400019541','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2721973,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Boston Recipe Baked Beans 28 oz','Bush''s Baked Bn (Bos) 28 oz',123249,NULL,'00039400019565','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722766,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Bourbon and Brown Sugar Grillin'' Beans 22 oz','Bush''s Grillin B & BS 22 oz',123250,NULL,'00039400019107','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721200,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Brown Sugar Hickory Baked Beans 16 oz','Bush''s Baked Bn (Hic) 16 oz',123251,NULL,'00039400019763','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722656,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Brown Sugar Hickory Baked Beans 28 oz','Bush''s Baked Bn (Hic) 28 oz',123252,NULL,'00039400019770','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722997,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Brown Sugar Reduced Sodium & Sugar Baked Beans 15.7 oz','Bush''s Brown Sugar Bkd 15.7 oz',123253,NULL,'00039400103431','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2024-05-16',NULL,'UNPREPARED',2693790,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Cannellini Beans 15.5 oz','Bush''s Cannellini Bn 15.5 oz',123254,NULL,'00039400018704','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722847,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Country Style Baked Beans 16 oz','Bush''s Baked Bn (Cst) 16 oz',123255,NULL,'00039400019725','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722640,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Country Style Baked Beans 28 oz','Bush''s Baked Bn (Cst) 28 oz',123256,NULL,'00039400019749','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722255,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Country Style Baked Beans 8.3 oz','Bush''s Baked Bn (Cst) 8.3 oz',123257,NULL,'00039400019718','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722012,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Crowder Peas 15 oz','Bush''s Crowder Peas 15 oz',123258,NULL,'00039400013808','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722644,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Dark Red Kidney Beans 16 oz','Bush''s Dark Kidney Bn 16 oz',123260,NULL,'00039400017349','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722931,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Dark Red Kidney Beans 27 oz','Bush''s Dark Kidney Bn 27 oz',123261,NULL,'00039400017400','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722767,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Easy Entrees Texas Ranchero 108 oz','Bush''s Texas Ranchero 108 oz',123262,NULL,'00039400010715','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722774,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Fat Free Refried Beans 16 oz','Bush''s Refried Bn (FF) 16 oz',123263,NULL,'00039400018926','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722015,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Chick Peas 16 oz','Bush''s Chick Pea 16 oz',123266,NULL,'00039400017004','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2723055,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Golden Hominy 108 oz','Bush''s Golden Hominy 108 oz',123267,NULL,'00039400017172','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722349,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Golden Hominy 15.5 oz','Bush''s Golden Hominy 15.5 oz',123268,NULL,'00039400017127','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722661,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Golden Hominy 30 oz','Bush''s Golden Hominy 30 oz',123269,NULL,'00039400017165','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722715,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Great Northern Beans 111 oz','Bush''s Northern Bn 111 oz',123270,NULL,'00039400017882','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2721998,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Great Northern Beans 15.8 oz','Bush''s Northern Bn 15.8 oz',123271,NULL,'00039400017820','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722532,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Homestyle Baked Beans 16 oz','Bush''s Baked Bn (Hst) 16 oz',123272,NULL,'00039400015925','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2723093,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Homestyle Baked Beans 28 oz','Bush''s Baked Bn (Hst) 28 oz',123273,NULL,'00039400015949','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722125,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Homestyle Baked Beans 55 oz','Bush''s Baked Bn (Hst) 55 oz',123274,NULL,'00039400016298','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721197,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Homestyle Baked Beans 8.3 oz','Bush''s Baked Bn (Hst) 8.3 oz',123275,NULL,'00039400015901','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722968,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Honey Chipotle Grillin'' Beans 21.5 oz','Bush''s Hny Chip Grillin'' Bn 21.5 oz',123276,NULL,'00039400019251','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2024-05-16',NULL,'UNPREPARED',2693813,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Honey Sweet Baked Beans 16 oz','Bush''s Honey Swt Baked 16 oz',123277,NULL,'00039400019848','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722451,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Honey Sweet Baked Beans 28 oz','Bush''s Baked Bn (Hny) 28 oz',123278,NULL,'00039400019855','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2723005,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Kidney Beans in a Mild Chili Sauce 16 oz','Bush''s Chili Bn (Kid/Mld) 16 oz',123279,NULL,'00039400015031','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722655,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Kidney Beans in a Spicy Chili Sauce 16 oz','Bush''s Chili Bn (Kid/Spcy) 16 oz',123280,NULL,'00039400010463','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722915,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Large Butter Beans 16 oz','Bush''s Large Butter Bn 16 oz',123281,NULL,'00039400016731','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2721985,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Light Red Kidney Beans 111 oz','Bush''s Light Kidney Bn 111 oz',123282,NULL,'00039400017561','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722802,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Light Red Kidney Beans 16 oz','Bush''s Light Kidney Bn 16 oz',123283,NULL,'00039400017479','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722664,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Low Sodium Black Beans 108 oz','Bush''s Black Bn (LS) 108 oz',123284,NULL,'00039400018858','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2023-10-26',NULL,'UNPREPARED',2651333,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Low Sodium Cannellini Beans 111 oz','Bush''s LS Cannellini Beans 111 oz',123285,NULL,'00039400018735','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722469,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Low Sodium Dark Red Kidney Beans 111 oz','Bush''s Dark Kidney Bn (LS) 111 oz',123286,NULL,'00039400017455','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722594,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Low Sodium Chick Peas 111 oz','Bush''s Chick Pea (LS) 111 oz',123287,NULL,'00039400017011','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722874,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Low Sodium Pinto Beans 111 oz','Bush''s Pinto Bn (LS) 111 oz',123288,NULL,'00039400018193','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722045,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Low Sodium Pinto Beans in a Mild Chili Sauce 15 oz','Bush''s LS Pinto Chili 15 oz',123289,NULL,'00039400106739','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722204,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Low Sodium Red Beans in a Mild Chili Sauce 15 oz','Bush''s LS Red Chili Bns 15 oz',123290,NULL,'00039400106746','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722128,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Maple & Cured Bacon Baked Beans 16 oz','Bush''s Baked Bn (Mpl) 16 oz',123291,NULL,'00039400019695','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722445,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Maple & Cured Bacon Baked Beans 28 oz','Bush''s Baked Bn (Mpl) 28 oz',123292,NULL,'00039400019701','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722964,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Mixed Kidney & Pinto Beans in a Mild Chili Sauce 15.5 oz','Bush''s Chili Bn (Mix/Mld) 15.5 oz',123293,NULL,'00039400015048','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722218,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Navy Beans 16 oz','Bush''s Navy Bn 16 oz',123294,NULL,'00039400017745','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722403,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Baked Beans 16 oz','Bush''s Organic Baked Bn 16oz',123295,NULL,'00039400016427','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2023-06-29',NULL,'UNPREPARED',2556348,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Black Beans 110 oz','Bush''s Organic Black Bn 110 oz',123296,NULL,'00039400018889','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722195,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Black Beans 15 oz','Bush''s Organic Black Bn 15 oz',123297,NULL,'00039400018780','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722727,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Dark Red Kidney Beans 111 oz','Bush''s Organic Dk Kidney Bn 111 oz',123298,NULL,'00039400017431','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722834,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Dark Red Kidney Beans 15 oz','Bush''s Organic Dk Kidney Bn 15 oz',123299,NULL,'00039400017318','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2723013,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Chick Peas 110 oz','Bush''s Organic Chick Pea 110 oz',123300,NULL,'00039400017073','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2721968,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Garbanzo Beans 15 oz','Bush''s Organic Chick Peas 15 oz',123301,NULL,'00039400017080','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722235,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Pinto Beans 110 oz','Bush''s Organic Pinto Beans 110 oz',123302,NULL,'00039400010593','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722139,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Pinto Beans 15 oz','Bush''s Organic Pinto Bn 15 oz',123303,NULL,'00039400018056','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722824,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Original Baked Beans 117 oz','Bush''s Baked Bn (Org) 117 oz',123304,NULL,'00039400016281','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722973,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Original Baked Beans 16 oz','Bush''s Baked Bn (Org) 16 oz',123305,NULL,'00039400016120','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722634,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Original Baked Beans 21 oz','Bush''s Baked Bn (Org) 21 oz',123306,NULL,'00039400016137','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722226,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Original Baked Beans 28 oz','Bush''s Baked Bn (Org) 28 oz',123307,NULL,'00039400016144','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722185,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Original Baked Beans 55 oz','Bush''s Baked Bn (Org) 55 oz',123308,NULL,'00039400016175','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722523,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Original Baked Beans 8.3 oz','Bush''s Baked Bn (Org) 8.3 oz',123309,NULL,'00039400016069','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722390,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans 111 oz','Bush''s Pinto Bn 111 oz',123310,NULL,'00039400018186','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722749,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans 16 oz','Bush''s Pinto Bn 16 oz',123311,NULL,'00039400018100','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722540,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans 27 oz','Bush''s Pinto Bn 27 oz',123312,NULL,'00039400018148','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722482,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans 41 oz','Bush''s Pinto Beans 41 oz',123313,NULL,'00039400018162','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722928,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans 53 oz','Bush''s Pinto Bn 53 oz',123314,NULL,'00039400018179','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2723031,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans in a Hot Chili Sauce 16 oz','Bush''s Chili Bn (Pin/Hot) 16 oz',123315,NULL,'00039400016816','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722792,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans in a Medium Chili Sauce 16 oz','Bush''s Chili Bn (Pin/Med) 16 oz',123316,NULL,'00039400016809','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722066,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans in a Mild Chili Sauce 111 oz','Bush''s Chili Bn (Pin/Mld) 111 oz',123317,NULL,'00039400016960','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722737,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans in a Mild Chili Sauce 16 oz','Bush''s Chili Bn (Pin/Mld) 16 oz',123318,NULL,'00039400016908','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722422,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans in a Mild Chili Sauce 27 oz','Bush''s Chili Bn (Pin/Mld) 27 oz',123319,NULL,'00039400016878','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722228,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans with Bacon 15.5 oz','Bush''s Pinto Bn (Bac) 15.5 oz',123320,NULL,'00039400018216','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722155,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans with Jalapenos 16 oz','Bush''s Pinto Bn with Jal 16oz',123321,NULL,'00039400018049','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722806,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Purple Hull Peas 15.8 oz','Bush''s Purple Hull Pea 15.8 oz',123322,NULL,'00039400013921','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722814,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Red Beans 16 oz','Bush''s Red Bn 16 oz',123323,NULL,'00039400018643','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721198,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Red Beans in a Hot Chili Sauce 16 oz','Bush''s Chili Bn (Red/Hot) 16 oz',123324,NULL,'00039400016984','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722942,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Red Beans in a Medium Chili Sauce 16 oz','Bush''s Chili Bn (Red/Med) 16 oz',123325,NULL,'00039400016939','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722167,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Red Beans in a Mild Chili Sauce 16 oz','Bush''s Chili Bn (Red/Mld) 16 oz',123326,NULL,'00039400016922','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2723036,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Red Beans in a Mild Chili Sauce 27 oz','Bush''s Chili Bn (Red/Mld) 27 oz',123327,NULL,'00039400016991','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722958,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Reduced Sodium Black Beans 15 oz','Bush''s Black Bn (RS) 15 oz',123328,NULL,'00039400018834','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722623,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Reduced Sodium Cannellini Beans 15.5 oz','Bush''s RS Cannellini Bn 15.5 oz',123329,NULL,'00039400018728','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722761,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Reduced Sodium Dark Red Kidney Beans 16 oz','Bush''s Dark Kidney Bn (RS) 16 oz',123330,NULL,'00039400017301','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2723019,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Reduced Sodium Chick Peas 16 oz','Bush''s Chick Pea (RS) 16 oz',123331,NULL,'00039400017066','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722214,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Reduced Sodium Great Northern Beans 15.8 oz','Bush''s Northern Bn (RS) 15.8 oz',123332,NULL,'00039400017790','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722856,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Reduced Sodium Pinto Beans 16 oz','Bush''s Pinto Bn (RS) 16 oz',123333,NULL,'00039400018070','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722299,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Refried Black Beans 16 oz','Bush''s Refried Bn (Black) 16 oz',123334,NULL,'00039400018940','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722025,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Seasoned Recipe Black Beans 15 oz','Bush''s Black Bn (Sea) 15 oz',123335,NULL,'00039400018841','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722503,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Seasoned Recipe Pinto Beans 16 oz','Bush''s Pinto Bn (Sea) 16 oz',123337,NULL,'00039400018285','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722501,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Smokehouse Tradition Grillin'' Beans 22 oz','Bush''s Grillin Bn (Smo) 22 oz',123338,NULL,'00039400019121','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722711,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Southern Pit Barbecue Grillin'' Beans 22 oz','Bush''s Grillin Bn (BBQ) 22 oz',123339,NULL,'00039400019145','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722590,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Steakhouse Recipe Grillin'' Beans 22 oz','Bush''s Grillin Bn (Ste) 22 oz',123340,NULL,'00039400019169','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722641,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Sweet and Tangy Reduced Sodium & Sugar Baked Beans 15.7 oz','Bush''s Swt Tngy Baked 15.7 oz',123341,NULL,'00039400103394','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2024-05-16',NULL,'UNPREPARED',2693773,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Taco Fiesta Black Beans 108 oz','Bush''s Taco Fiesta Black Bn 108 oz',123342,NULL,'00039400015857','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2723054,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Traditional Refried Beans 16 oz','Bush''s Refried Bn (Trd) 16 oz',123343,NULL,'00039400018919','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722498,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Vegetarian Baked Beans 16 oz','Bush''s Veg Baked Bn 16 oz',123344,NULL,'00039400016335','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722565,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Vegetarian Baked Beans 28 oz','Bush''s Veg Baked 28 oz',123345,NULL,'00039400016359','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722660,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Vegetarian Baked Beans 8.3 oz','Bush''s Veg Baked Bn 8.3 oz',123346,NULL,'00039400016304','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722296,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s White Chili Beans in a Mild Chili Sauce 15.5 oz','Bush''s Mld White Chili Bn 15.5 oz',123347,NULL,'00039400015017','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722618,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s White Hominy 108 oz','Bush''s White Hominy 108 oz',123348,NULL,'00039400017288','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722683,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s White Hominy 15.5 oz','Bush''s White Hominy 15.5 oz',123349,NULL,'00039400017233','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2723086,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s White Hominy 30 oz','Bush''s White Hominy 30 oz',123350,NULL,'00039400017271','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722896,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bushs Campfire Style Chili Magic Chili Starter 15.5 oz','Bush''s Chili Magic (CFS) 15.5 oz',123351,NULL,'00039400019022','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2723091,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bushs Classic Homestyle Chili Magic Chili Starter 15.5 oz','Bush''s Chili Magic (HST) 15.5 oz',123352,NULL,'00039400019008','Bush Brothers & Company','Bush''s Best',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722233,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Clear Coat 1/4 Shoestring 12.2 Kg','Clear Coat Shoestring',123353,NULL,'10056210053111','Cavendish Farms','Cavendish Farms',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2718927,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cavendish Farms Golden Nuggets Ovenable 13.6 Kg','Cavendish Farms Golden Nuggets',123354,NULL,'10056210041019','CAVENDISH FARMS','Cavendish Farms',NULL,3,'2022-04-01','2024-12-19',NULL,'FREEZE',2718956,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cavendish Farms Potato Patties 13.6 Kg','Cavendish Farms Hashbrown Patties',123355,NULL,'10056210345001','Cavendish Farms','Cavendish Farms',NULL,3,'2022-04-01','2025-03-20',NULL,'UNPREPARED',2723143,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cheese, Reduced Fat Pepperoni made with Turkey & Beef with Italian Style Sauce in a Whole Grain Rich Crust.','LIL BITES CHEESE AND PEPPERONI',123356,NULL,'10010374770215','The Father''s Table','Lil'' Bites',NULL,3,'2022-04-01','2023-11-16',NULL,'BAKE',2662501,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chicken Egg Roll','Chicken Egg Roll',123357,NULL,'00856235005521','International Food Solutions, Inc.','GREEN DRAGON',NULL,3,'2022-04-01','2024-08-15',NULL,'PREPARED',2701032,'50193200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chicken Nuggets','Chicken Nuggets',123358,NULL,'10852777007136','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-04-27',NULL,'BAKE',2522117,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'sausage egg cheese sandwich','Sausage Egg Cheese Biscuit',123359,NULL,'10852777007341','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-04-27',NULL,'BAKE',2522120,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sausage Egg Cheese English Muffin','Sausage Egg Cheese English Muffin',123360,NULL,'10852777007334','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-04-27',NULL,'BAKE',2522119,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Brakebush CN Whole Grain Zoo Crew Nuggets, Fully Cooked, Breaded, Frozen, 1.1 oz.','FC CN Whole Grain Zoo Crew Nuggets',123361,NULL,'10038034564608','Brakebush Brothers','Brakebush',NULL,3,'2022-04-01','2024-09-13',NULL,'UNPREPARED',2703873,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cinnamon Swirls, Whole Grain, Individually Wrapped, 3.6" x 1.7"','Cinnamon Swirls, WG, IW, 3.6"x1.7"',123362,NULL,'00737410016870','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-09-13',NULL,'UNPREPARED',2704184,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cinnamon Swirls, Whole Grain, Individually Wrapped, 3.75" x 1.75"','Cinn Swirls, WG, IW, 3.75"x1.75"',123363,NULL,'00737410016634','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722930,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Clear Coat Straight Cut 3/8 Low Sodium 13.6 Kg','Cavendish Farms Clear Coat',123364,NULL,'10056210053074','Cavendish Farms','Cavendish Farms Clear Coat',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722707,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Clear Coat 3/8 Straight Cut 12.2 Kg','Clear Coat 3/8 Straight Cut',123365,NULL,'10056210053012','Cavendish Farms','Cavendish Farms Clear Coat',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722607,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'CN BARBECUE PORK AND BARBECUE SAUCE (Tomato Base)','CN Chopped Pork w/ Tomato Sauce',123366,NULL,'40079405165506','Chandler Foods, Inc.','Chandler Foods, Inc.',NULL,3,'2022-04-01','2024-11-14',NULL,'PREPARED',2717152,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'CN BARBECUE PORK AND VINEGAR SAUCE','CN Chopped Pork with Vinegar Sauce',123367,NULL,'40079405205004','Chandler Foods, Inc.','Chandler Foods, Inc.',NULL,3,'2022-04-01','2024-11-14',NULL,'PREPARED',2717153,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'CN BARBECUE SAUCE WITH COOKED CHICKEN AND TVP','CN Cooked Chicken w/ Tom Sce & TVP',123368,NULL,'40079405616008','Chandler Foods, Inc.','Chandler Foods, Inc.',NULL,3,'2022-04-01','2024-07-11',NULL,'PREPARED',2696466,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'CN BARBECUE SAUCE WITH PORK AND TVP (THRIFTY BRAND)','CN Thrifty Pork w/ Tom Sauce & TVP',123369,NULL,'40079405246007','Chandler Foods, Inc.','Chandler Foods, Inc.',NULL,3,'2022-04-01','2024-07-11',NULL,'PREPARED',2696494,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'CN CHICKEN (DARK MEAT) WITH MILD SAUCE','CN Chopped Chicken w/ Tomato Sauce',123370,NULL,'40079405535002','Chandler Foods, Inc.','Chandler Foods, Inc.',NULL,3,'2022-04-01','2024-11-14',NULL,'PREPARED',2717154,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'CN CHICKEN (DARK MEAT) WITH VINEGAR SAUCE','CN Pulled Chicken w/ Vinegar Sauce',123371,NULL,'40079405585007','Chandler Foods, Inc.','Chandler Foods, Inc.',NULL,3,'2022-04-01','2024-07-11',NULL,'PREPARED',2696467,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Brakebush CN Grilled Breast Patties, Fully Cooked, Unbreaded, Frozen, 2.62 oz.','FC CN Grilled Breast Patties',123372,NULL,'10038034599006','Brakebush Brothers','Brakebush',NULL,3,'2022-04-01','2024-10-31',NULL,'UNPREPARED',2716284,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Crisp To Go 3/8 Straight Cut 12.2 Kg','Crisp To Go 3/8 Straight Cut',123373,NULL,'10056210053616','Cavendish Farms','Cavendish Farms Crisp to Go',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722820,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Low Sodium, Margarine, Round, Sliced, 4" x 2.2"','Croiss, LS, Marg, Rnd, Sl, 4"x2.2"',123374,NULL,'00737410016597','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2699578,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Margarine, Round, Fully Sliced, 3.8" x 1.5"','Croiss Marg Rnd Flly Sl 3.8"x1.5"',123375,NULL,'00737410008530','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2699623,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Margarine, Round, Fully Sliced, 3.9" x 1.8"','Croiss Marg Rnd Flly Sl 3.9"x1.8"',123376,NULL,'00737410032955','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2521376,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Whole Grain, Margarine, Fully Curved, Sliced, 4" x 1.75"','Croiss, WG, Marg, FC, Sl, 4"x1.75"',123377,NULL,'00737410016610','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2521355,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Whole Grain, Margarine, Fully Curved, Sliced, 4" x 1.75"','Croiss, WG, Marg, FC, Sl, 4"x1.75"',123378,NULL,'00737410016627','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2521356,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Whole Grain, Margarine, Reduced Fat, Round, Fully Sliced, 3.5" x 1.5"','Croiss WG Marg RF Rnd Flly Sl',123379,NULL,'00737410032948','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2521375,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Whole Grain, Margarine, Reduced Fat, Round, Fully Sliced, 3.8" x 1.5"','Croiss WG Marg RF Rnd Flly Sl',123380,NULL,'00737410008691','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2699603,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Whole Grain, Margarine, Reduced Fat, Round, Fully Sliced, 3.8" x 1.5"','Croiss WG Marg RF Rnd Flly Sl',123381,NULL,'00737410008684','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2699622,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Whole Grain, Margarine, Reduced Fat, Round, Fully Sliced, 3.9" x 1.8"','Croiss WG Marg RF Rnd Flly Sl',123382,NULL,'00737410032962','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2521377,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Dinner Roll','Dinner Roll',123383,NULL,'10852777007174','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-04-27',NULL,'THAW',2522118,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Dinner Roll, Whole Grain, Low Sodium, 2.5"','Dinner Roll, Whole Grain, LS, 2.5"',123384,NULL,'00737410025742','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2699589,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Donut, Whole Grain, Cake Glazed, Individually Wrapped, 4.25" x 1.25"','Donut WG Cake Glz IW 4.25"x1.25"',123385,NULL,'00737410019437','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-07-11',NULL,'UNPREPARED',2697096,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Donut, Whole Grain, Chocolate Cake, Glazed, Individually Wrapped, 4.25" x 1.25"','Donut WG Choc Cake Glz IW 4.25x1.25',123386,NULL,'00737410019376','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-07-11',NULL,'UNPREPARED',2697125,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Donut, Whole Grain, Chocolate Enrobed, Individually Wrapped, 4.25" x 1.25"','Donut WG Choc Enrobed IW 4.25x1.25',123387,NULL,'00737410019390','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-07-11',NULL,'UNPREPARED',2697097,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Donut, Whole Grain, Powdered Sugar, Individually Wrapped, 4.25" x 1.25"','Donut WG Pwdred Sugar IW 4.25x1.25',123388,NULL,'00737410019321','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-07-11',NULL,'UNPREPARED',2697124,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Dubon Petit Pois Green Peas 15 oz','Dubon Petit Pois Grn Pea 15 oz',123389,NULL,'00039400202714','Bush Brothers & Company','DUBON',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722381,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Carnival Colored Chocolate Candy Frozen Cookie Dough Made With Whole Grain','Carnival Chocolate Candy Cookies',123390,NULL,'10013087556787','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2701494,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fine Coat 3/8 Straight Cut 13.6 Kg','Fine Coat 3/8 Straight Cut',123391,NULL,'10056210055023','Cavendish Farms','Cavendish Farms Fine Coat',NULL,3,'2022-04-01','2025-01-23',NULL,'FREEZE',2722141,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fine Coat 5/16 Thin Cut, Skin-On 13.6 Kg','Fine Coat 5/16 Thin Cut',123392,NULL,'10056210055054','Cavendish Farms','Cavendish Farms Fine Coat',NULL,3,'2022-04-01','2025-03-20',NULL,'UNPREPARED',2723142,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fine Coat 5/16 Thin Straight Cut 13.6 Kg','Fine Coat 5/16 Thin Cut',123393,NULL,'10056210055030','Cavendish Farms','Cavendish Farms',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2718957,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'FlavorCrisp Seasoned Diced Potatoes, Skin-On 13.6 Kg','Cavendish Farms FlavorCrisp',123394,NULL,'10056210052220','Cavendish Farms','FlavorCrisp',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722977,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Flavor Crisp 3/8 Select Spicy Straight Cut 12.2 Kg','Flavor Crisp 3/8 Straight Cut',123395,NULL,'10056210351019','Cavendish Farms','Cavendish Farms Flavor Crisp',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722932,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Chip Frozen Cookie Dough Made With Whole Grain','Chocolate Chip Cookies',123396,NULL,'10013087556800','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2022-04-01','2024-02-01',NULL,'UNPREPARED',2683820,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Natural Chocolate Flavored Brownie Frozen Cookie Dough Made With Whole Grain','Chocolate Flavored Brownie Cookies',123397,NULL,'10013087556893','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2022-04-01','2024-03-14',NULL,'UNPREPARED',2687830,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'FROZEN COOKIE DOUGH OATMEAL RAISIN MADE WITH 51% WHOLE GRAIN LAYERED PACK 1/384/1 OZ','FCD OATMEAL RAISIN W/ WHOLE GRAIN',123399,NULL,'10013087556732','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2022-04-01','2023-06-29',NULL,'UNPREPARED',2558715,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sugar Frozen Cookie Dough Made With Whole Grain','Sugar Cookies Made With Whole Grain',123400,NULL,'10013087556749','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2701495,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Carnival Colored Chocolate Candy Frozen Cookie Dough Made With Whole Grain','Carnival Chocolate Candy Cookies',123402,NULL,'10013087556886','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2022-04-01','2024-02-01',NULL,'UNPREPARED',2683818,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'General Tso''s Sauce Pouch','General Tso''s Sauce Pouch',123403,NULL,'00078895139242','International Food Solutions, Inc.','Red Dragon',NULL,3,'2022-04-01','2024-12-19',NULL,'READY_TO_EAT',2719458,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Chicken Sausage Patties, Antibiotic Free, No Sugar, 1.5 oz., 1/10 lb. , Fully Cooked , Certified Gluten- Free','Chkn Saus Patty, ABF, No Sugar, FC',123404,NULL,'00033900606485','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721131,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Chicken Sausage Patties, 1.5 oz., 1/10 lb., Fully Cooked, Certified Gluten-Free','Chkn Saus Patty, FC, CN, 1.5oz, AN',123405,NULL,'00033900609103','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2024-11-14',NULL,'UNPREPARED',2717660,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'4 Pepper Chicken Sausage Links, All Natural Ingredients in a Vegetable Based Casing,  1.4 oz., 1/10 lb. Fully Cooked , Certified Gluten- Free','Chkn Saus Link, FC, 1.4oz, All Nat.',123406,NULL,'00033900606454','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721130,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Pork Sausage Links, Lite, Lower Sodium, Skinless, CN .8 oz., 1/10 lb., Fully Cooked,  Certified Gluten-Free','Pork Saus Lnk, Lite, CN, .8oz, AN',123407,NULL,'00033900606249','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2518769,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Pork Sausage Links, Lower Sodium, Skinless, CN .1oz., 1/10lb. , Fully Cooked , Certified Gluten- Free','Pork Saus Link, LS, FC, CN, 1oz, AN',123408,NULL,'00033900606089','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2518767,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Pork Sausage Links, Mild, Skinless, CN, .8 oz., 1/10 lb., Fully Cooked , Certified Gluten- Free','Pork Saus Lnk, FC, CN, .8z, All Nat',123409,NULL,'00033900002058','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721033,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Pork Sausage Links, Mild, Skinless,  CN, 1.oz., 1/10 lb., Fully Cooked  , Certified Gluten- Free','Pork Saus Lnk, FC, CN, 1oz, All Nat',123410,NULL,'00033900606010','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721128,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Pork Sausge Patties, Lite, Lower Sodium, Skinless, CN,  1.6 oz., 1/10 lb., Fully Cooked, Certified Gluten-Free','Pork Saus Pty, Lite, CN, 1.6oz, AN',123411,NULL,'00033900608212','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2518782,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Pork Sausage Patties, Lower Sodium,  CN, 1.0 oz. , 1/10 lb. , Fully Cooked , Certified Gluten- Free','Pork Saus Pty, LS, FC, CN, 1oz, AN',123412,NULL,'00033900608779','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721141,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Pork sausage Patties, Mild, CN, 1.0 oz., 1/10 lb., Fully Cooked, Certified Gluten-Free','Pork Saus Pty, FC, CN, 1oz, All Nat',123414,NULL,'00033900002102','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721036,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Pork Sausage Patties, Mild, CN, 1.5 oz. 1/10 lb. Fully Cooked, Certified Gluten-Free','Pork Saus Patty, FC, CN, 1.5oz, AN',123415,NULL,'00033900002096','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721035,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Pork Sausage Patties, Mild, CN, 2.0 oz. 1/10 lb., Fully Cooked, Certified Gluten-Free','Pork Saus Pty, FC, CN, 2oz, All Nat',123416,NULL,'00033900002089','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721034,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Pork Sausage Patties ,  Lower Sodium, CN , 1.5 oz. , 1/10 lb. , Fully Cooked , Certified Gluten- Free','Pork Saus Patty, LS, CN, 1.5oz, AN',123417,NULL,'00033900608793','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721143,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Turkey Sausage Patties, CN, 1.5 oz., 1/10 lb. , Fully Cooked , Certified Gluten- Free','Turkey Saus Pty, FC, CN, 1.5oz, AN',123418,NULL,'00033900608397','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721140,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Turkey Sausage Links, Skinless, .75 oz. , CN, 1/10 lb. , Certified Gluten- Free','Turkey Saus Link, FC, CN, .75oz, AN',123419,NULL,'00033900607109','JONES DAIRY FARM','Jones Dairy Farm',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721150,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Hamburger Buns, Whole Grain, Low Sodium, Sliced, 3.75"','CLOSEOUT Hamb Buns WG LS Sl 3.75"',123420,NULL,'00737410025766','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2699587,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hamburger Buns, Whole Grain, Premium, 4.5", Sliced','Hamb Buns, WG, Premium, 4.5", Sl',123421,NULL,'00737410346700','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-06-29',NULL,'UNPREPARED',2558509,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hoagie Roll, Whole Grain, Low Sodium, Sliced, 5.5"','Hoagie Roll, WG, LS, Sliced, 5.5"',123423,NULL,'00737410025711','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2699591,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Hoagie, Whole Grain, Par-Baked, Split Top, Hinge Sliced, 6"','CLOSEOUT Hoagie WG Par-Bkd SplTop H',123424,NULL,'00737410041049','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722907,'50193300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hot Dog Buns, Whole Grain, Low Sodium, Sliced, 6"','Hot Dog Buns, WG, LS, Sliced, 6"',123425,NULL,'00737410025780','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2699586,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Jumbo Ravioli Tray with Marinara','Jumbo Ravioli Tray with Marinara',123426,NULL,'10852777007525','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-09-14',NULL,'CONVECTION',2641411,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kaiser Buns, Cornmeal Dusted 4.5"','Kaiser Buns, Cornmeal Dusted 4.5"',123427,NULL,'00737410352107','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-02-16',NULL,'UNPREPARED',2458109,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Klg Licensed Crackers Scooby-Doo Cinnamon Graham Bones 1oz','Klg Licensed Crackers',123428,NULL,'00030100215981','Kellogg Company US','Kellogg''s',NULL,3,'2022-04-01','2025-03-20',NULL,'UNPREPARED',2723883,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Lasagna Roll Up Tray with Marinara','Lasagna Roll Up Tray with Marinara',123429,NULL,'10852777007495','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-04-27',NULL,'CONVECTION',2522121,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Lemon Chip Crunch Bar','Lemon Chip Crunch Bar',123430,NULL,'00010374011861','The Father''s Table','The Father''s Table Dunkers',NULL,3,'2022-04-01','2024-08-15',NULL,'PREPARED',2702267,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mini Bread Stick, Whole Grain, Low Sodium, 4.5"','Mini Bread Stick, WG, LS, 4.5"',123432,NULL,'00737410025735','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2699590,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mini Cheese Ravioli Tray Bake','Mini Cheese Ravioli Tray Bake',123433,NULL,'10852777007518','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-04-27',NULL,'CONVECTION',2522123,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naturally Flavored Apple Cinnamon Muffin(s) With Other Natural Flavors Made With Whole Grain','Apple Cinnamon Muffin Whole Grain',123434,NULL,'00013087101461','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2022-04-01','2024-02-01',NULL,'PREPARED',2683170,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naturally Flavored Banana Muffin(s) Made With Whole Grain','Banana Muffin Made With Whole Grain',123435,NULL,'00013087101447','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2022-04-01','2024-02-01',NULL,'PREPARED',2683172,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffin Chocolate Chip Whole Grain Individually Wrapped 48/4 oz','MUFFIN CHOCOLATE CHIP WHOLE GRAIN',123436,NULL,'00013087241860','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2022-04-01','2024-02-01',NULL,'PREPARED',2683164,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naturally And Artificially Flavored Chocolate Chocolate Chip Muffin Made With Whole Grain','Choc Choc Chip Muffin Whole Grain',123437,NULL,'00013087101454','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2022-04-01','2024-02-01',NULL,'PREPARED',2683171,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'MUFFIN CORN MADE WITH 51% WHOLE GRAIN INDIVIDUALLY WRAPPED 48/4 OZ','MUFFIN CORN W/ WHOLE GRAIN',123438,NULL,'00013087216417','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2022-04-01','2023-06-29',NULL,'PREPARED',2554937,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Corn Muffin(S) Made With Whole Grain','Corn Muffin Made With Whole Grain',123439,NULL,'00013087216400','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essentials',NULL,3,'2022-04-01','2025-03-20',NULL,'PREPARED',2723741,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naturally Flavored Wild Blueberry Muffin Made With Whole Grain With Other Natural Flavor','Blueberry Muffin w/ Whole Grain',123440,NULL,'00013087101430','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2022-04-01','2024-02-01',NULL,'PREPARED',2683173,'50182300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffins, Blueberry, Low Fat, Individually Wrapped','Muffins, Blueberry, Low Fat, IW',123441,NULL,'00737410136004','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2521406,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Nacho style rectangular cheddar cheese calzone','NachoBoli',123442,NULL,'10852777007570','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-10-26',NULL,'BAKE',2649774,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Nacho style rectangular cheddar cheese calzone','53207 NachoBoli',123443,NULL,'10852777006993','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-08-31',NULL,'BAKE',2614177,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naturally Flavored Apple Cinnamon Muffin(s) With Other Natural Flavors Made With Whole Grain','Apple Cinnamon Muffin(s)',123444,NULL,'00013087101508','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2022-04-01','2024-02-01',NULL,'PREPARED',2683167,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pancakes, Whole Grain, Buttermilk Maple Chip, Bulk, 4"','Pancakes WG Btrmlk Mpl Chip Blk 4"',123445,NULL,'00737410017341','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-10-31',NULL,'UNPREPARED',2716207,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pancakes, Whole Grain, Wholesome Choice, Buttermilk, Bulk, 4"','Pancakes WG Wholesome Choice Btrmlk',123446,NULL,'00737410017211','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2699568,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'IW wrap Pizaboli','53206 Pizzaboli IW',123447,NULL,'10852777006559','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-08-31',NULL,'BAKE',2614176,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'PizzaBoli Bites','Pizzaboli Bites',123448,NULL,'10852777007907','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-08-31',NULL,'BAKE',2614184,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Prairie Select 1/2 Crinkle Cut Oven 13.6 Kg','Prairie Select 1/2 Crinkle Cut',123449,NULL,'10614869302167','Cavendish Farms','Prairie Select',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722569,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Raisins Box - 144/1.33 OZ','RAISINS',123450,NULL,'00076161001330','Lion Raisins','LION RAISINS','100293',3,'2022-04-01','2024-12-19',NULL,'READY_TO_EAT',2718044,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Bun, Whole Grain, 100% Beef Chburger, Individually Wrapped, Commodity, 3.75"','Sndwch Bun WG 100% Beef Chburger IW',123451,NULL,'00737410067223','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-07-11',NULL,'UNPREPARED',2697067,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Bun, Whole Grain, 100% Beef Cheeseburger, Individually Wrapped, Commodity, 3.75""','Sndwch Bun WG 100% Beef Chsburger I',123452,NULL,'00737410067179','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2022-09-15',NULL,'UNPREPARED',2337627,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Bun, Whole Grain, 100% Beef Hamburger, Individually Wrapped, Commodity, 3.75"','Sndwch Bun WG 100% Beef Hamb IW Com',123453,NULL,'00737410067162','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-02-16',NULL,'UNPREPARED',2458121,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Bun, Whole Grain, 100% Beef Hamburger, Individually Wrapped, Commodity, 3.75"','Sndwch Bun WG 100% Beef Hamb IW Com',123454,NULL,'00737410067216','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2701135,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Buttermilk Pancake, Whole Grain, Chicken Sausage & Cheese, Individually Wrapped','Sndwch Btrmlk Pancake WG Chkn Ssg&C',123455,NULL,'00737410067322','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2701128,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Maple Pancake, Whole Grain, Beef Sausage & Cheese, Individually Wrapped','Sndwch Mpl Pancake WG Beef Ssg&Chs',123456,NULL,'00737410067346','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2521392,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich Maple Pancake Whole Grain Beef Sausage & Cheese IWCommodity','Sndwch Mpl Pancake WG Beef Ssg&Chs',123457,NULL,'00737410067360','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2521394,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Maple Pancake, Whole Grain, Beef Sausage, Individually Wrapped','Sndwch Mpl Pancake WG Beef Ssg IW',123458,NULL,'00737410067339','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2521391,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Maple Pancake, Whole Grain, Beef Sausage, Individually Wrapped, Commodity','Sndwch Mpl Pancake WG Beef Ssg IW C',123459,NULL,'00737410067353','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2521393,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Sandwich, Maple Waffle, Whole Grain, Chicken Sausage, Individually Wrapped','CLOSEOUT Sndwch Mpl Waffle WG Chkn ',123460,NULL,'00737410067315','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722000,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Whole Grain, 100% Beef Meatball, Individually Wrapped, Commodity, 5.5"','Sndwch WG 100% Beef Meatball IW Com',123461,NULL,'00737410067230','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2701141,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Whole Grain, Beef Meatball, Individually Wrapped, Commodity, 5.6"','Sndwch WG Beef Meatball IW Commodit',123462,NULL,'00737410067186','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-02-16',NULL,'UNPREPARED',2458119,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Whole Grain, Grilled Cheese, Bulk','Sandwich, WG, Grilled Cheese, Blk',123463,NULL,'00737410066776','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2025-03-20',NULL,'UNPREPARED',2723330,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Sandwich, Whole Grain, Grilled Cheese, Garlic Mozzarella, Individually Wrapped','CLOSEOUT Sndwch WG Grilled Chs Gar ',123464,NULL,'00737410067278','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722346,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Whole Grain, Grilled Cheese, Lower Sodium, Individually Wrapped','Sndwch WG Grilled Chs Lower Sodium',123465,NULL,'00737410066714','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-02-16',NULL,'UNPREPARED',2458395,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Whole Grain, Grilled Cheese, Pepper Jack & Mozzarella, Individually Wrapped','Sndwch WG Grilled Chs Pepper Jack&M',123466,NULL,'00737410067261','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2024-08-15',NULL,'UNPREPARED',2701132,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Sandwich, Whole Grain, Grilled Cheese, Pepper Jack, Individually Wrapped','CLOSEOUT Sndwch WG Grilled Chs Pepp',123467,NULL,'00737410067254','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722809,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'SHOWBOAT Pork & Bean 15 oz','SHOWBOAT Pork & Bn 15 oz',123468,NULL,'00039400028345','Bush Brothers & Company','SHOWBOAT',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722580,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SHOWBOAT Pork & Bean 27.5 oz','SHOWBOAT Pork & Bn 27.5 oz',123469,NULL,'00039400028437','Bush Brothers & Company','SHOWBOAT',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722159,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SHOWBOAT Pork & Bean 53 oz','Showboat Pork & Bn  53 oz',123470,NULL,'00039400028482','Bush Brothers & Company','SHOWBOAT',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2722070,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SHOWBOAT Pork & Beans 112 oz','SHOWBOAT Pork & Beans 112 oz',123471,NULL,'00039400028499','Bush Brothers & Company','SHOWBOAT',NULL,3,'2022-04-01','2025-01-23',NULL,'UNPREPARED',2723042,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Slider Buns, Whole Grain, Low Sodium, Sliced, 2.5"','Slider Buns, WG, LS, Sliced, 2.5"',123472,NULL,'00737410025759','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2025-03-20',NULL,'UNPREPARED',2724101,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'StrawberryBoli','StrawberryBoli',123473,NULL,'10852777007594','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-09-14',NULL,'BAKE',2641413,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'StrawberryBoli','53205 StrawberryBoli',123474,NULL,'10852777006429','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2024-10-31',NULL,'BAKE',2716067,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stuffed Shells Tray Marinara Sauce','Stuffed Shells Tray Marinara Sauce',123475,NULL,'10852777007501','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-09-14',NULL,'CONVECTION',2641410,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'SURIMI SEAFOOD FLAKE STYLE','SL CN REAL SIMPLE FLAKE',123478,NULL,'00079468286745','Trident Seafoods Corp.','Sea Legs',NULL,3,'2022-04-01','2025-03-20',NULL,'PREPARED',2724082,'50121900');
INSERT INTO `cndb_fdes` VALUES (NULL,'CinnaBoli','CinnaBoli',123479,NULL,'10852777007587','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-10-26',NULL,'BAKE',2649776,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'SweetBoli','CinnaBoli',123480,NULL,'10852777006412','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-04-27',NULL,'BAKE',2522115,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fine Coat 1/4 Shoestring 12.2 Kg','Fine Coat Shoestring',123481,NULL,'10056210055016','Cavendish Farms','Cavendish Farms Fine Coat',NULL,3,'2022-04-01','2025-03-20',NULL,'UNPREPARED',2723141,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'INACTIVE - Breakfast Bun, French Toast, Whole Grain, Individually Wrapped, 3"','Breakfast Bun, Fr Toast, WG, IW, 3"',123482,NULL,'00737410019796','Bake Crafters Food Company','Bake Crafters',NULL,3,'2022-04-01','2023-04-27',NULL,'UNPREPARED',2521361,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Vegetable Egg Roll','Vegetable Egg Roll',123483,NULL,'00856235005538','International Food Solutions, Inc.','GREEN DRAGON',NULL,3,'2022-04-01','2024-08-15',NULL,'PREPARED',2701031,'50193200');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 10 FL OZ 100% JUICE - APPLE','10OZ 100% APPLE JUICE',123484,NULL,'00041800316007','WELCHS','Welchs',NULL,3,'2022-04-01','2025-01-23',NULL,'READY_TO_DRINK',2721960,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 10 FL OZ 100% JUICE - CONCORD GRAPE','10OZ 100% GRAPE JUICE',123485,NULL,'00041800354009','WELCHS','Welchs',NULL,3,'2022-04-01','2025-01-23',NULL,'READY_TO_DRINK',2722457,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 10 FL OZ 100% JUICE - ORANGE','10OZ 100% ORANGE JUICE',123486,NULL,'00041800344000','WELCHS','Welchs',NULL,3,'2022-04-01','2025-01-23',NULL,'READY_TO_DRINK',2721989,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 11.5 FL OZ 100% JUICE - APPLE','11.5OZ 100% APPLE JUICE',123487,NULL,'00041800382002','WELCH FOODS INC.','Welchs',NULL,3,'2022-04-01','2024-08-15',NULL,'READY_TO_DRINK',2702676,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 11.5 FL OZ 100% JUICE - ORANGE','11.5OZ 100% ORANGE JUICE',123488,NULL,'00041800379002','WELCH FOODS INC.','Welchs',NULL,3,'2022-04-01','2024-08-15',NULL,'READY_TO_DRINK',2702677,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 5.5 FL OZ 100% JUICE - APPLE','5.5OZ 100% APPLE JUICE',123489,NULL,'00041800283002','WELCH FOODS INC.','Welchs',NULL,3,'2022-04-01','2024-08-15',NULL,'READY_TO_DRINK',2702662,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 5.5 FL OZ 100% JUICE - CONCORD GRAPE','5.5OZ 100% PRPL GRP JCE',123490,NULL,'00041800214501','WELCH FOODS INC.','Welchs',NULL,3,'2022-04-01','2024-08-15',NULL,'READY_TO_DRINK',2702660,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 5.5 FL OZ 100% JUICE - ORANGE','5.5OZ 100% ORANGE JUICE',123491,NULL,'00041800281008','WELCH FOODS INC.','Welchs',NULL,3,'2022-04-01','2024-08-15',NULL,'READY_TO_DRINK',2702661,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Banana Muffin','WG Banana Muffin',123492,NULL,'00711341642414','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2022-04-01','2023-04-27',NULL,'PREPARED',2521289,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'LASAGNA, CHEESE WHOLE GRAIN PASTA TFF COOKED FROZEN BULK ROLLUP','Lasagna, Chs Whl Grain Pasta',123493,NULL,'10852777002506','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2022-04-01','2023-04-27',NULL,'PREPARED',2522113,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Anytimers Breaded Chicken Sticks w/ BBQ Sauce','Anytimers Breaded Chix Stix w/ BBQ',123494,NULL,'10852777004630','Tasty Brands','Tasty Brands',NULL,3,'2022-04-01','2023-04-27',NULL,'PREPARED',2522114,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Stuffed Rigatoni','WG Stuffed Rigatoni',123495,NULL,'00810089290052','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2022-04-01','2023-04-27',NULL,'PREPARED',2521531,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Double Stuffed Pasta Rolls','WG Double Stuffed Pasta Rolls',123496,NULL,'00810089290045','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2022-04-01','2023-04-27',NULL,'PREPARED',2521530,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Square Ravioli','00832WG Square Ravioli',123497,NULL,'00810089290069','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2022-04-01','2023-04-27',NULL,'PREPARED',2521532,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Sunflower Kernels, Honey Roasted, 1.2oz','Honey Roasted Sunflower Kernels',123498,NULL,'20810358032653','National Food Group  Inc.','Zee Zees',NULL,3,'2022-04-01','2024-12-19',NULL,'READY_TO_EAT',2719209,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Kellogg Cracker Brand Eggo Cinnamon French Toast 1.76oz','Kellogg Cracker Brand',123499,NULL,'00038000245558','Kellogg Company US','Kellogg''s',NULL,3,'2022-04-01','2024-07-11',NULL,'UNPREPARED',2698425,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Morningstar Farms Veggie Burgers Spicy Black Bean Child Nutrition 2.9oz 48ct','Veggie Burgers',123501,NULL,'00028989499387','Kellogg Company US','Morningstar Farms',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721787,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Gripz Crackers Cinnamon Grahams .9oz','Gripz Crackers',123502,NULL,'00030100000501','Kellogg Company US','Kellogg''s',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721800,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Rice Krispies Treats Squares Whole Grain .42oz','Rice Krispies Treats Squares',123505,NULL,'00038000145414','Kellogg Company US','Kellogg''s',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2720916,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Grahams Crackers Honey Graham With Calcium .78oz','Grahams Crackers',123506,NULL,'00030100918233','Kellogg Company US','Kellogg''s',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721775,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Grahams Crackers Original .78oz','Grahams Crackers',123507,NULL,'00030100918318','Kellogg Company US','Kellogg''s',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2721777,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Mini-Wheats Cereal Bite Size Frosted 1oz','Mini-Wheats Cereal',123508,NULL,'00038000049613','WK KELLOGG CO','Kellogg''s',NULL,3,'2022-04-01','2024-12-19',NULL,'UNPREPARED',2720941,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'6/10 LAKESIDE CUT GRN BNS','CT GRN BN',123513,NULL,'00033828013167','Lakeside Foods Inc.','Lakeside Foods','100307',3,'2022-04-01','2025-03-20',NULL,'READY_TO_EAT',2724829,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Hoagie, Whole Grain, Cheese & Turkey Breast, Individually Wrapped','Hoagies, WG, Chs & Trky Breast, IW',123515,NULL,'00737410066974','Bake Crafters Food Company','Bake Crafters',NULL,3,'2023-05-27','2022-09-15',NULL,'UNPREPARED',2336995,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mini Donuts, Whole Grain, Powdered Sugar, 6 Pack','Mini Donuts, WG, Pwdred Sugar, 6 Pk',123516,NULL,'00737410193106','Bake Crafters Food Company','Bake Crafters',NULL,3,'2023-05-27','2022-09-15',NULL,'UNPREPARED',2337247,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mini Donuts, Whole Grain, Chocolate Enrobed, 6 Pack','Mini Donuts, WG, Choc Enrobed, 6 Pk',123517,NULL,'00737410192901','Bake Crafters Food Company','Bake Crafters',NULL,3,'2023-05-27','2022-09-15',NULL,'UNPREPARED',2337374,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pizza, Cheese, Square, 11x17", uncut, 4.25" x 5.5"','Pizza Chs Sq 11x17 uncut 4.25x5.5',123520,NULL,'00737410036953','Bake Crafters Food Company','Bake Crafters',NULL,3,'2023-05-27','2022-12-07',NULL,'UNPREPARED',2371896,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pizza, White Garlic, Square, 11x17", uncut, 4.25" x 5.5"','Pizza Whi Gar Sq 11x17" uncut',123521,NULL,'00737410036984','Bake Crafters Food Company','Bake Crafters',NULL,3,'2023-05-27','2022-12-07',NULL,'UNPREPARED',2371993,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pizza, White Garlic, Round, 17", uncut, 8.5"','Pizza Whi Gar Rnd 17" uncut 8.5"',123522,NULL,'00737410036922','Bake Crafters Food Company','Bake Crafters',NULL,3,'2023-05-27','2022-12-07',NULL,'UNPREPARED',2372024,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Sweet Potato Chocolate Chip Muffin','WG Sweet Potato Choc Chip Muffin',123524,NULL,'00711341613414','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2023-05-27','2023-11-16',NULL,'PREPARED',2663167,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Star Sandwich Thin','WG Star Sandwich Thin',123525,NULL,'00039217050522','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2023-05-27','2023-11-16',NULL,'PREPARED',2662898,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mocha Crumble','Mocha Crumble',123526,NULL,'00711341900507','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2023-05-27','2023-01-26',NULL,'PREPARED',2443766,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Sugar Star Cookie','WG Sugar Star Cookie',123527,NULL,'00711341717204','Buena Vista Food Products','Linda''s Cookies',NULL,3,'2023-05-27','2023-11-16',NULL,'PREPARED',2663172,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cinnatwin','Cinnatwin',123528,NULL,'00711341902006','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2023-05-27','2023-01-26',NULL,'PREPARED',2443914,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Sugar Heart Cookie','WG Sugar Heart Cookie',123529,NULL,'00711341740608','Buena Vista Food Products','Linda''s Cookies',NULL,3,'2023-05-27','2023-01-26',NULL,'PREPARED',2443919,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'10ct/1lb Fresh Apple Slices','1lb Fresh Apple Slices',123531,NULL,'20882266100502','Peterson Farms Fresh, Inc.','Peterson Farms Treats',NULL,3,'2023-05-27','2023-10-26',NULL,'READY_TO_EAT',2649788,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cinnatwin','Cinnatwin',123532,NULL,'00711341902013','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2023-05-27','2023-01-26',NULL,'PREPARED',2444097,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Italian Sausage Calzone, Meatless','WG Italian Sausage Calzone, Meatles',123533,NULL,'00711341509519','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2023-05-27','2023-06-29',NULL,'UNPREPARED',2558234,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Reduced Fat Chocolate Chip Cookie','WG RF Chocolate Chip Cookie',123534,NULL,'00711341790108','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2023-05-27','2023-11-16',NULL,'PREPARED',2663179,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Super Sour Apple, 4.5 oz.','Super Sour Apple Applesauce',123538,NULL,'00810358030211','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2023-10-26',NULL,'READY_TO_EAT',2648874,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Very Strawberry, 4.5 oz.','Very Strawberry Applesauce',123543,NULL,'00810358030228','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2023-10-26',NULL,'READY_TO_EAT',2649924,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Mixed Fruit, 4.5 oz.','Mixed Fruit Applesauce',123546,NULL,'00810358030198','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2023-06-29',NULL,'READY_TO_EAT',2558609,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Nutrition Bar, Cinnamon Crisp, 2.2 oz.','Cinnamon Crisp ZeeZee Bar',123551,NULL,'20854114007158','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2023-02-16',NULL,'READY_TO_EAT',2458140,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Nutrition Bar, Campfire Smores, WG, I/W, 2.2 oz','Campfire Smores ZeeZee Bar',123552,NULL,'20854114007394','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2023-02-16',NULL,'READY_TO_EAT',2458144,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Natchitoches Louisiana Crawfish Pies (Empanadas) - Bulk - 48Ct','Crawfish Pies - Bulk',123554,NULL,'10038744064566','Natchitoches Meat Pie Co Inc','Our Famous Natchitoches Meat Pies',NULL,3,'2023-05-27','2023-02-16',NULL,'FRY',2458260,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Grahamz Strawberry, IW, WG 1oz','Strawberry Grahamz',123555,NULL,'20854114007721','National Food Group','Zee Zees',NULL,3,'2023-05-27','2024-08-15',NULL,'READY_TO_EAT',2700915,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Hummus Cup, Original, 4.5 oz.','Original Hummus Cup',123556,NULL,'20810358030314','National Food Group','Zee Zees',NULL,3,'2023-05-27','2025-03-20',NULL,'READY_TO_EAT',2723180,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cheerios(TM) Cereal Single Serve Bowlpak 1 oz','Cheerios Cereal',123559,NULL,'10016000322629','GENERAL MILLS SALES INC.','Cheerios',NULL,3,'2023-05-27','2025-04-24',NULL,'UNPREPARED',2730205,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Chocolate Candy Cookie','WG Chocolate Candy Cookie',123561,NULL,'00711341797152','Buena Vista Food Products','Linda''s Cookies',NULL,3,'2023-05-27','2023-06-29',NULL,'UNPREPARED',2558275,'50181700');
INSERT INTO `cndb_fdes` VALUES (NULL,'Biscuits, Buttermilk Classic Homestyle, 3", Sliced','Biscs Btrmlk Classic Homestyle 3" S',123568,NULL,'00737410010588','Bake Crafters Food Company','Bake Crafters',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649061,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Emerald Nuts, Natural Almonds, 100 Calorie Packs, 10 Ct, 6.2 Oz','EM NAT ALMONDS 100 CAL 6/.62 O',123579,NULL,'00010300894360','Snyder''s-Lance INC.','EMERALD',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2650566,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naturally Flavored Wild Blueberry Muffin(s) With Other Natural Flavor Made With Whole Grain','Wild Blueberry Muffin(s)',123584,NULL,'00013087101478','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2023-05-27','2024-02-01',NULL,'PREPARED',2683169,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naturally Flavored Banana Muffin(s) With Other Natural Flavor Made With Whole Grain','Banana Muffin',123585,NULL,'00013087101485','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2023-05-27','2024-02-01',NULL,'PREPARED',2683168,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'NATURALLY AND ARTIFICIALLY FLAVORED CHOCOLATE CHOCOLATE CHIP MUFFIN(S) MADE WITH WHOLE GRAIN','Chocolate Chocolate Chip Muffin(s)',123586,NULL,'00013087101492','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2023-05-27','2023-06-29',NULL,'PREPARED',2554934,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pepperidge Farm Goldfish Baked Snack Crackers Baked with Whole Grain Cheddar Cheese, 31 Ounces, Pack of 6','PF GF WG CHEDDAR BULK CARTON',123592,NULL,'00014100206484','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2650711,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Brown Gravy 30#6Bags 6/5# 30#','Brown Gravy 30#6Bags',123601,NULL,'00049485051152','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2023-11-16',NULL,'PREPARED',2663235,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'WGR Mac & Cheese 10/3#  30#','WGR Mac & Cheese',123608,NULL,'00049485057994','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2023-11-16',NULL,'PREPARED',2663335,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Korean BBQ Sauce 6/5# 30#','Korean BBQ Sauce',123609,NULL,'00049485734000','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2025-03-20',NULL,'PREPARED',2723921,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hunan Style Orange Sauce 6/5# 30#','Hunan Style Orange Sauce',123610,NULL,'00049485734208','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2025-03-20',NULL,'PREPARED',2723909,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Asian Base Sauce 6/5# 30#','Asian Base Sauce',123611,NULL,'00049485734307','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2025-03-20',NULL,'PREPARED',2723910,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'General Tso''s Sauce 6/5# 30#','General Tso''s Sauce',123612,NULL,'00049485734505','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2023-11-16',NULL,'PREPARED',2663339,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sweet and Sour Sauce 6/5# 30#','Sweet and Sour Sauce',123613,NULL,'00049485734604','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2025-03-20',NULL,'PREPARED',2723911,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Teriyaki Sauce 6/5# 30#','Teriyaki Sauce',123614,NULL,'00049485734703','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2025-03-20',NULL,'PREPARED',2723912,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Frozen Entrees Savory Salisbury Steak with Gravy, 4.3 Pound Trays, 4-Pack','FS SALISBURY STEAK',123626,NULL,'00051000081513','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2023-05-27','2023-03-16',NULL,'UNPREPARED',2491947,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Signature Frozen Condensed Chicken Tortilla Soup, 4 Pound Trays, 3-Pack','CHICKEN TORTILLA',123631,NULL,'00051000148940','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2651078,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Signature Frozen Condensed Healthy Request Rosemary Chicken and Dumpling Soup, 4 Pound Trays, 3-Pack','CRMY BROCCOLI',123632,NULL,'00051000162731','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2023-05-27','2023-03-16',NULL,'UNPREPARED',2492030,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Signature Frozen Condensed Healthy Request Tuscan-Style White Bean with Chicken Soup, 4 Pound Trays, 3-Pack','TUSCAN WH BEAN W/C',123633,NULL,'00051000168665','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2023-05-27','2023-03-16',NULL,'UNPREPARED',2492039,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Pasteurized Blended Low Moisture Part Skim Mozzarella Cheese Slice - 160 P - 5#','5# Blended LM PartSkim Mozzarella',123645,NULL,'00071078104457','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2023-03-16',NULL,'PREPARED',2492348,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Pizza Empanada','WG Pizza Empanada',123677,NULL,'00711341533217','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2023-05-27','2023-03-16',NULL,'UNPREPARED',2492484,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Chocolate Chip Crumble','WG Chocolate Chip Crumble',123678,NULL,'00711341900705','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2023-05-27','2023-06-29',NULL,'PREPARED',2558285,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'SunButter Creamy 2.2 oz cups - 140 ct case','SunButter Creamy 2.2oz cup - 140ct',123686,NULL,'07375391942684','SunButter','SunButter',NULL,3,'2023-05-27','2023-06-29',NULL,'READY_TO_EAT',2558691,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naturally Flavored Wild Blueberry Muffin(s) With Other Natural Flavor Made With Whole Grain','Wild Blueberry Muffin(s)',123687,NULL,'10013087101475','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2023-05-27','2024-02-01',NULL,'PREPARED',2683832,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naturally Flavored Banana Muffin(s) With Other Natural Flavor Made With Whole Grain','Banana Muffin',123688,NULL,'10013087101482','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2023-05-27','2024-02-01',NULL,'PREPARED',2683830,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'NATURALLY AND ARTIFICIALLY FLAVORED CHOCOLATE CHOCOLATE CHIP MUFFIN(S) MADE WITH WHOLE GRAIN','Chocolate Chocolate Chip Muffin(s)',123689,NULL,'10013087101499','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2023-05-27','2023-06-29',NULL,'PREPARED',2558707,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naturally Flavored Apple Cinnamon Muffin(s) With Other Natural Flavors Made With Whole Grain','Apple Cinnamon Muffin(s)',123690,NULL,'10013087101505','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2023-05-27','2024-02-01',NULL,'PREPARED',2683829,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Grilled Scrambled Egg Patty, 525/0.8 oz., Frozen, Bulk','Scrm EGGPTY GRILL',123691,NULL,'10038057302089','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696404,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Precooked Scrambled Eggs, Large Curd, 1/30 lb., Frozen, Bulk','PRECK SCR EGG',123692,NULL,'10038057309477','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-10-31',NULL,'PREPARED',2716183,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Precooked Scrambled Eggs Diced, 1/20 lb., Frozen, Bulk','SCR EGG DICED',123693,NULL,'10038057606354','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696385,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Honey Wheat Yeast Bakery Roll Dough, Layer Pack (Whole Grain) 6730','Wheat Rll Dgh',123694,NULL,'10047500003213','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719645,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Honey Wheat Yeast Bakery Roll, Layer Pack (Whole Grain) 6735','Wheat Rll Dgh',123695,NULL,'10047500003237','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719646,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Parkerhouse Honey Wheat Yeast Roll Dough, Tray Pack (Whole Grain) 6153','Wheat Roll Dgh',123696,NULL,'10047500005699','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719647,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Heat and Serve White Rolls, 1.5 oz, 6650','Heat and Srv Wht',123697,NULL,'10047500006795','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719648,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Honey Wheat Yeast Bakery Roll, Layer Pack (Whole Grain) 6736','Wheat Rll Dgh',123698,NULL,'10047500007259','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719649,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Honey Wheat Breadstick Dough, Layer Pack (Whole Grain) 6728','Wheat Brd Stck',123699,NULL,'10047500010785','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719653,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Honey Wheat Yeast Bakery Roll Dough, Layer Pack (Whole Grain) 6731','Wheat Rll Dgh',123700,NULL,'10047500010792','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719654,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Honey Whole Wheat Biscuits, Layer Pack (Whole Grain) 6285','Bisc heat and serv',123701,NULL,'10047500011034','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-11-14',NULL,'PREPARED',2717245,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Heat and Serve Honey Wheat Rolls, 1 oz (Whole Grain), 6611','Heat and Srv Wht',123702,NULL,'10047500011287','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719293,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Honey Whole Wheat Biscuits, Sliced, Layer Pack (Whole Grain) 6267','Bisc heat and serv',123703,NULL,'10047500012390','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719292,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Honey Whole Wheat Biscuits, Layer Pack (Whole Grain) 6293','Bisc heat and serv',123704,NULL,'10047500013212','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719158,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford White Whole Wheat Buttermilk Biscuits, Layer Pack (Whole Grain) 6296','Bisc heat and serv',123705,NULL,'10047500014011','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-11-14',NULL,'PREPARED',2717232,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Honey Wheat Sandwich Roll Dough, Layer Pack (Whole Grain) 6738','Wheat Rll Dgh',123706,NULL,'10047500014042','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718929,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Honey Whole Wheat Biscuits, Sliced, Layer Pack (Whole Grain) 6270','Bisc heat and serv',123707,NULL,'10047500014745','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718931,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Single Serve Individually Wrapped Buttermilk Biscuits, 6680','Bisc heat and serv',123708,NULL,'10047500016008','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718936,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Single Serve Individually Wrapped Honey Whole Wheat Biscuits (Whole Grain), 6681','Bisc heat and serv',123709,NULL,'10047500016015','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718937,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Single Serve Individually Wrapped Maple Flavored White Whole Wheat Biscuits (Whole Grain), 6682','Bisc heat and serv',123710,NULL,'10047500016022','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718938,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Single Serve Individually Wrapped White Whole Wheat Blueberry Flavored Biscuits (Whole Grain), 6683','Bisc heat and serv',123711,NULL,'10047500016039','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718939,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford White Whole Wheat Breadstick Dough, Layer Pack (Whole Grain) 6721','Wheat Brd Stck',123712,NULL,'10047500017050','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718940,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Heat and Serve White Whole Wheat Rolls, 1 oz (Whole Grain), 6672','Heat and Srv Wht Whl Wht',123713,NULL,'10047500017173','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2025-04-24',NULL,'PREPARED',2730214,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Heat and Serve White Whole Wheat Rolls, 1 oz (Whole Grain), 6673','Heat and Srv Wht Whl Wht',123714,NULL,'10047500017180','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-11-14',NULL,'PREPARED',2717224,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Grain Waiver Buttermilk Biscuits, Layer Pack 6284','Bisc heat and serv',123715,NULL,'10047500017401','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718942,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Heat and Serve White Whole Wheat Breadsticks (Whole Grain), Layer Pack 6621','Flly bkd brdstks',123716,NULL,'10047500017593','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718943,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Grain Waiver Cinnamon Roll Dough, 6717','Wheat Cin Rll',123717,NULL,'10047500018200','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718944,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Single Serve Individually Wrapped Honey Whole Wheat Biscuits (Whole Grain), 1.25 oz., 6685','Bisc heat and serv',123718,NULL,'10047500019399','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718946,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Single Serve Individually Wrapped White Whole Wheat Rolls (Whole Grain), 2 oz., 6689','Bisc heat and serv',123719,NULL,'10047500019412','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718947,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pork Sausage Gravy 6/5# 30#','Pork Sausage Gravy',123720,NULL,'10049485005527','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700534,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Reduced Sodium Beef Taco 6/5# 30#','Reduced Sodium Beef Taco',123721,NULL,'10049485052675','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2024-10-31',NULL,'PREPARED',2716083,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Beef Chili w Beans (drained) 6/5# 30#','Beef Chili w Beans (drained)',123722,NULL,'10049485053092','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2024-11-14',NULL,'PREPARED',2717226,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chili Con Carne w/o Beans 6/5# 30#','Chili Con Carne w/o Beans',123723,NULL,'10049485053382','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700511,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pork Drained Sloppy Joe 6/5# 30#','Pork Drained Sloppy Joe',123724,NULL,'10049485054013','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2024-10-31',NULL,'PREPARED',2716081,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Tomato Soup, 10.75 oz Can (48 Pack)','R&W TOMATO SOUP',123725,NULL,'10051000000115','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2023-05-27','2024-07-11',NULL,'UNPREPARED',2696241,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'V8 Original 100% Vegetable Juice, 12 FL OZ Bottle','V8 VEG JUICE',123726,NULL,'10051000138047','CAMPBELL SOUP COMPANY','V8',NULL,3,'2023-05-27','2023-03-16',NULL,'UNPREPARED',2492792,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'V8 Original 100% Vegetable Juice, 11.5 FL OZ Can (Pack of 24)','V8 VEG JCE 24CT',123727,NULL,'10051000153163','CAMPBELL SOUP COMPANY','V8',NULL,3,'2023-05-27','2023-03-16',NULL,'UNPREPARED',2492794,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Tomato Soup, 23.2 oz Family Size Can (12 Pack)','R&W TOM SOUP',123728,NULL,'10051000212396','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2023-05-27','2024-07-11',NULL,'UNPREPARED',2696229,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Heart Healthy Tomato Soup, 23.2 oz Family Size Can (12 Pack)','R&W HH TOM SOUP',123729,NULL,'10051000212402','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2023-05-27','2024-07-11',NULL,'UNPREPARED',2696246,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'SpaghettiOs Super Mario Bros Canned Pasta with Meatballs, 15.6 OZ Can (Pack of 12)','CPB SPAGO FUN SHP MB',123730,NULL,'10051000233155','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2023-05-27','2023-03-16',NULL,'UNPREPARED',2492808,'50193300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Process American Swiss Slice - 160 H - 4/5#','4/5# Pr Am Sw 160H Sl',123731,NULL,'10071078110431','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700587,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Process American Slice - 160 V - 4/5#','4/5# Y Pr Am 160V Sl',123732,NULL,'10071078110493','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696291,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards White Process American Slice - 160 V - 4/5#','4/5# W Pr Am 160V Sl',123733,NULL,'10071078110509','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700595,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Restricted Melt Process American Slice - 160 P - 4/5#','4/5# Y Pr Am RMLT 160P Sl',123734,NULL,'10071078110653','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700602,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Reduced Fat Process American Slice - 160 H - 6/5#','6/5# Y Pr Am Rd Ft 160H Sl',123735,NULL,'10071078111322','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696293,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Process American Slice - 160 V - 6/5#','6/5 Y Pr Am 160V Sl',123736,NULL,'10071078111377','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696307,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Reduced Fat & Sodium Process American Hoagie Slice - 486 - 8/5#','8/5 Y Pr Am Rd Ft/Sd 486 Sl',123737,NULL,'10071078112145','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700599,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Process Jalapeno American Slices - 120 H - 4/5#','4/5# Jal Am 120H Sl',123738,NULL,'10071078113418','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696294,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Process Jalapeno American Slices - 160 P - 4/5#','4/5# Pr Am Hot Pep 160P Sl',123739,NULL,'10071078113456','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700598,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Pasteurized Blended Yellow Cheddar Cheese Slice - 160 P - 4/5#','4/5# Blended Ched Cheese Yel 160 P',123740,NULL,'10071078114415','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700597,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Pasteurized Blended Reduced Fat Cheddar Cheese Slice - 160 P - 4/5#','4/5# Reduced Fat Blended Cheddar',123741,NULL,'10071078114422','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700603,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Pasteurized Blended Swiss Cheese Slice - 160 P - 4/5#','4/5# Blended Swiss Cheese 160 Slice',123742,NULL,'10071078114439','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700596,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Pasteurized Blended Pepper Jack Cheese Slice - 160 P - 4/5#','4/5# Blended Pepper Jack Cheese 160',123743,NULL,'10071078114446','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700594,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Pasteurized Blended Low Moisture Part Skim Mozzarella Cheese Slice - 160 P - 4/5#','4/5# Blended LM PartSkim Mozzarella',123744,NULL,'10071078114453','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700593,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Pasteurized Blended Provolone Cheese Slice - 160 P - 4/5#','4/5# Blended Provolone Cheese 160P',123745,NULL,'10071078114460','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700592,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Process American Cheese Spread Loaf - 6/5#','6/5# Y Pr Chs Sprd',123746,NULL,'10071078202747','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700590,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Cheddar Shred  400/1 oz','Mild Cheddar Deep V Shred  400/1oz',123747,NULL,'10071078753201','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2023-03-16',NULL,'PREPARED',2492848,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Low Moisture Part Skim Mozzarella Shred  400/1 oz','LMPS Mozz Deep V Shred  400/1oz',123748,NULL,'10071078753218','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2023-03-16',NULL,'PREPARED',2492849,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Mozzarella, Provolone, and Cheddar Feather Shred - 4/5#','4/5# 3 Chs Blnd Fthr Shd',123749,NULL,'10071078755267','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700400,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Mozzarella/Provolone Feather Shred - 4/5#','4/5# Moz/Prv Bl Fthr Shd',123750,NULL,'10071078755342','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700406,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Italian Blend Feather Shred - 4/5#','4/ 5# Itln Blnd Shd',123751,NULL,'10071078755366','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700399,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Super Melt Yellow Process American Feather Shred  4/5#','4/5# Prcss Amrcn Yllw Spr Mlt Shred',123752,NULL,'10071078755816','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700395,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Sharp Yellow Cheddar Cheese Feather Shred - 6/5#','6/5# Sh Y Chd Fthr Shd cheese',123753,NULL,'10071078755960','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700394,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'TSMB WG Crustless Sunbutter Grape & Jelly Sandwich','TSMB Sunbutter Grape & Jelly Sand',123754,NULL,'10693392005721','East Side Entrees','ES Foods',NULL,3,'2023-05-27','2023-10-26',NULL,'PREPARED',2649555,'50193800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Emerald Nuts, Natural Almonds, 100 Calorie Packs, 10 Ct, 6.2 Oz','EM NATURAL ALMONDS 100 CAL 4/1',123755,NULL,'20010300894364','Snyder''s-Lance INC.','EMERALD',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649784,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pork Sausage Gravy 6/5# 30#','Pork Sausage Gravy',123756,NULL,'20049485005524','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700842,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Beef Chili w Beans (drained) 30# 6/5#','Beef Chili w Beans (drained)',123757,NULL,'20049485053099','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700795,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'CE Beef Patty 30# 6Bags','CE Beef Patty',123758,NULL,'20049485056106','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700792,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Hummus Cup, Red Pepper, 4.5 oz.','Red Pepper Hummus Cup',123759,NULL,'20810358030345','National Food Group','Zee Zees',NULL,3,'2023-05-27','2024-07-11',NULL,'READY_TO_EAT',2696470,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Trail Mix, Sweet Heat, IW, 2.27 oz','Zee Zees Sweet Heat Trail Mix',123760,NULL,'20810358033964','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719210,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees, Raisins, 1.33 oz','Raisins',123761,NULL,'20810358034275','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719213,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'621354 Zee Zees Sour Raisins, Strawberry 1.45 oz','Sour Raisins',123762,NULL,'20810358034299','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-08-15',NULL,'READY_TO_EAT',2700898,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'621355 Zee Zees Sour Raisins, Raspberry 1.45 oz','Sour Raisins',123763,NULL,'20810358034305','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-08-15',NULL,'READY_TO_EAT',2700897,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Soft Baked Bar, Birthday Cake, 2.2 oz','Birthday Cake Soft Baked Bar',123764,NULL,'20810358034336','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-07-11',NULL,'READY_TO_EAT',2696479,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Soft Baked Bar, Campfire Smores, 2.2 oz','Campfire Smores Zee Zees Bar',123765,NULL,'20810358034350','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-07-11',NULL,'READY_TO_EAT',2696480,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Soft Baked Bar, Cinnamon Crisp, 2.2 oz.','Cinnamon Crisp Zee Zees Bar',123766,NULL,'20810358034367','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-08-15',NULL,'READY_TO_EAT',2700894,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Soft Baked Bar, Strawberry Crisp, 2.2 oz','Strawberry Crisp Zee Zees Bar',123767,NULL,'20810358034374','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719214,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Soft Baked Bar, Berry Apple Crisp, 1.3 oz','Berry Apple Crisp Soft Baked bar',123768,NULL,'20810358034398','National Food Group','Zee Zees',NULL,3,'2023-05-27','2024-08-15',NULL,'READY_TO_EAT',2700918,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Soft Baked Bar, Blueberry Lemon, 1.3 oz','Blueberry Lemon Soft Baked bar',123770,NULL,'20810358034411','National Food Group','Zee Zees',NULL,3,'2023-05-27','2024-08-15',NULL,'READY_TO_EAT',2700911,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Soft Baked Bar, Campfire Smores, 1.3 oz','Campfire S''mores Soft Baked Bar',123771,NULL,'20810358034428','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-07-11',NULL,'READY_TO_EAT',2696496,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Soft Baked Bar, Cinnamon Crisp, 1.3 oz.','Cinnamon Crisp Soft Baked bar',123772,NULL,'20810358034435','National Food Group','Zee Zees',NULL,3,'2023-05-27','2024-08-15',NULL,'READY_TO_EAT',2700925,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Soft Baked Bar, Strawberry Crisp, 1.3 oz.','Strawberry Crisp Soft Baked bar',123773,NULL,'20810358034442','National Food Group','Zee Zees',NULL,3,'2023-05-27','2024-07-11',NULL,'READY_TO_EAT',2696483,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Dried Pineapple, 1.45oz','Dried Fruit Mix',123774,NULL,'20810358034961','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719216,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cape Cod Less Fat Sweet Mesquite Barbeque Chips, 1.37 Oz Bag','CCPC RF SW MESQ BBQ 56C 1.375Z',123775,NULL,'30020685000776','Snyder''s-Lance INC.','CAPE COD',NULL,3,'2023-05-27','2025-04-24',NULL,'UNPREPARED',2730517,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Light Red Kidney Beans 16 oz','Bush''s Light Kidney Bn 12-16 oz',123779,NULL,'10039400017483','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722622,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Blackeye Peas 15.8 oz','Bush''s Blackeye Pea 12-15.8 oz',123782,NULL,'10039400013676','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2024-05-16',NULL,'UNPREPARED',2689608,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Bean Pot Vegetarian Baked Beans 117 oz','Bush''s Bean Pot Vegetarian 6-117 oz',123783,NULL,'10039400016370','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722513,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Reduced Sodium Pinto Beans 16 oz','Bush''s Pinto Bn (RS) 12-16 oz',123784,NULL,'10039400018077','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722124,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Barbecue Baked Beans 28 oz','Bush''s Barbecue Bkd Bns 12-28 oz',123785,NULL,'10039400011993','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722117,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Traditional Refried Beans 16 oz','BUSH''S Refried Bn (Trd) 12-16 oz',123788,NULL,'10039400018916','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722413,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Golden Hominy 108 oz','Bush''s Golden Hominy 6-108 oz',123789,NULL,'10039400017179','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722084,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Taco Fiesta Black Beans 108 oz','Bush''s Taco Fiesta Blk Bn 6-108 oz',123790,NULL,'10039400015854','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722461,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Red Beans in a Mild Chili Sauce 16 oz','Bush''s Chili Bn (Red/Mld) 16 oz',123791,NULL,'10039400016882','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722259,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Reduced Sodium Cannellini Beans 15.5 oz','Bush''s RS Cannellini Bn 15.5 oz',123792,NULL,'10039400018725','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2723003,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Purple Hull Peas 15.8 oz','Bush''s Purple Hull Pea 12-15.8 oz',123793,NULL,'10039400013911','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722140,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Navy Beans 16 oz','Bush''s Navy Bn 12-16 oz',123794,NULL,'10039400017735','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722539,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Reduced Sodium Great Northern Beans 15.8 oz','Bush''s Northern Bn (RS) 12-15.8 oz',123795,NULL,'10039400017797','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722738,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Refried Black Beans 12-16 oz','Bush''s Refried Bn (Black) 12-16 oz',123797,NULL,'10039400018947','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-03-20',NULL,'UNPREPARED',2724149,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans 16 oz','Bush''s Pinto Bn 12-16 oz',123798,NULL,'10039400018091','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722972,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SHOWBOAT Pork & Beans 112 oz','SHOWBOAT Pork & Beans 6-112 oz',123799,NULL,'10039400028496','Bush Brothers & Company','SHOWBOAT',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722589,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SHOWBOAT Pork & Bean 53 oz','Showboat Pork & Bn  6-53 oz',123801,NULL,'10039400026485','Bush Brothers & Company','SHOWBOAT',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722420,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Chick Peas 110 oz','Bush''s Organic Chick Pea 6-110 oz',123802,NULL,'10039400017070','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722754,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Homestyle Baked Beans 16 oz','Bush''s Baked Bn (Hst) 12-16 oz',123804,NULL,'10039400015939','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722823,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Reduced Sodium Chick Peas 16 oz','Bush''s Garbanzo Bn (RS) 12-16 oz',123805,NULL,'10039400017063','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722621,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Red Beans in a Hot Chili Sauce 16 oz','Bush''s Chili Bn (Red/Hot) 16 oz',123807,NULL,'10039400016912','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722913,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Pinto Beans 15 oz','Bush''s Organic Pinto Bn 12-15 oz',123808,NULL,'10039400018053','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722535,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Boston Recipe Baked Beans 16 oz','Bush''s Baked Bn (Bos) 12-16 oz',123809,NULL,'10039400019531','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722611,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans in a Mild Chili Sauce 27 oz','Bush''s Chili Bn (Pin/Mld) 12-27 oz',123810,NULL,'10039400016875','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722352,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Mixed Kidney & Pinto Beans in a Mild Chili Sauce 15.5 oz','Bush''s Chili Bn (Mix/Mld) 15.5 oz',123811,NULL,'10039400015045','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722063,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Vegetarian Baked Beans 16 oz','Bush''s Veg Baked Bn 12-16 oz',123813,NULL,'10039400016349','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722428,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Black Beans 26.5 oz','Bush''s Black Bn 12-26.5 oz',123814,NULL,'10039400018824','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722393,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Low Sodium Dark Red Kidney Beans 111 oz','Bush''s Dark Kidney Bn (LS) 6-111 oz',123819,NULL,'10039400017452','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722645,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Seasoned Recipe Pinto Beans 16 oz','Bush''s Pinto Bn (Sea) 16 oz',123820,NULL,'10039400018138','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722057,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Southern Pit Barbecue Grillin'' Beans 22 oz','Bush''s Grillin Bn (BBQ) 12-22 oz',123821,NULL,'10039400019142','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722975,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans 27 oz','Bush''s Pinto Bn 12-27 oz',123823,NULL,'10039400018145','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722036,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans 53 oz','Bush''s Pinto Bn 6-53 oz',123824,NULL,'10039400016431','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722884,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans with Jalapenos 16 oz','Bush''s Pinto Bn with Jal 12-16 oz',123825,NULL,'10039400018046','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2024-05-16',NULL,'UNPREPARED',2689747,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Low Sodium Chick Peas 111 oz','Bush''s Garbanzo Bn (LS) 6-111 oz',123826,NULL,'10039400017018','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722597,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Seasoned Recipe Black Beans 15 oz','Bush''s Black Bn (Sea) 12-15 oz',123827,NULL,'10039400018879','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722243,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Dark Red Kidney Beans 12-16 oz','Bush''s Dark Kidney Bn 12-16 oz',123830,NULL,'10039400017353','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-03-20',NULL,'UNPREPARED',2724147,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Steakhouse Recipe Grillin'' Beans 12-22 oz','Bush''s Grillin Bn (Ste) 12-22 oz',123831,NULL,'10039400019166','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-03-20',NULL,'UNPREPARED',2724151,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Fat Free Refried Beans 16 oz','Bush''s Refried Bn (FF) 12-16 oz',123832,NULL,'10039400018923','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722301,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Watermelon Froot Jooce 100% Frozen Juice Cup','Watermelon Froot Jooce cup',123833,NULL,'00815294000182','Lindy''s Homemade','Froot Jooce',NULL,3,'2023-05-27','2023-03-23',NULL,'READY_TO_EAT',2512009,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Black Beans 15 oz','Bush''s Black Bn 12-15 oz',123835,NULL,'10039400018817','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2024-12-19',NULL,'UNPREPARED',2719635,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Original Baked Beans 8.3 oz','Bush''s Baked Bn (Org) 12-8.3 oz',123836,NULL,'10039400016059','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722947,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Honey Sweet Baked Beans 28 oz','Bush''s Baked Bn (Hny) 12-28 oz',123837,NULL,'10039400019852','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722927,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Country Style Baked Beans 8.3 oz','Bush''s Baked Bn (Cst) 12-8.3 oz',123838,NULL,'10039400019715','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722380,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s White Hominy 30 oz','Bush''s White Hominy 12-30 oz',123839,NULL,'10039400017278','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722689,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Baby Butter Beans 16 oz','Bush''s Baby Butter Bn 12-16 oz',123840,NULL,'10039400016714','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722728,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Great Northern Beans 111 oz','Bush''s Northern Bn 6-111 oz',123841,NULL,'10039400017889','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722873,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Original Baked Beans 117 oz','Bush''s Baked Bn (Org) 6-117 oz',123842,NULL,'10039400016288','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722708,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Vegetarian Baked Beans 28 oz','Bush''s Veg Baked 12-28 oz',123843,NULL,'10039400016356','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722904,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Dark Red Kidney Beans 27 oz','Bush''s Dark Kidney Bn 12-27 oz',123845,NULL,'10039400017407','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722004,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Country Style Baked Beans 28 oz','Bush''s Baked Bn (Cst) 12-28 oz',123847,NULL,'10039400019746','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722757,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Light Red Kidney Beans 111 oz','Bush''s Light Kidney Bn 6-111 oz',123850,NULL,'10039400017568','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722470,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Bourbon and Brown Sugar Grillin'' Beans 22 oz','Bush''s Grillin B & BS 12-22 oz',123855,NULL,'10039400019104','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2024-12-19',NULL,'UNPREPARED',2719636,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans in a Hot Chili Sauce 16 oz','Bush''s Chili Bn (Pin/Hot) 16 oz',123856,NULL,'10039400016851','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722219,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Red Beans in a Mild Chili Sauce 27 oz','Bush''s Chili Bn (Red/Mld) 27 oz',123857,NULL,'10039400016998','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722519,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Baked Beans with Onion 16 oz','Bush''s Baked Bn (Oni) 12-16 oz',123858,NULL,'10039400016028','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722787,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Brakebush Kids Klassics CN Grilled Breast Nuggets, Fully Cooked, Unbreaded, Frozen, 0.59 oz.','FC CN Grilled Breast Nuggets',123859,NULL,'10038034569009','Brakebush Brothers','Brakebush',NULL,3,'2023-05-27','2024-09-13',NULL,'UNPREPARED',2703870,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Low Sodium Pinto Beans 111 oz','Bush''s Pinto Bn (LS) 6-111 oz',123861,NULL,'10039400018190','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722713,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Kidney Beans in a Spicy Chili Sauce 16 oz','Bush''s Chili Bn (Kid/Spcy) 16 oz',123863,NULL,'10039400010460','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722284,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Red Beans 16 oz','Bush''s Red Bn 12-16 oz',123864,NULL,'10039400018633','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2024-05-16',NULL,'UNPREPARED',2689716,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Honey Chipotle Grillin'' Beans 21.5 oz','Bush''s Hny Chptl Grillin 12-21.5 oz',123865,NULL,'10039400019258','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2024-05-16',NULL,'UNPREPARED',2689678,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Cannellini Beans 15.5 oz','Bush''s Cannellini Bn 12-15.5 oz',123866,NULL,'10039400018718','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722872,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Dried Cranberries','Dried Cranberries',123869,NULL,'10715001107234','Fig Garden Packing Inc.','Fig Garden Packing, Inc.','110723',3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2718881,'50251000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Blackeye Peas 111 oz','Bush''s Blackeye Pea 6-111 oz',123871,NULL,'10039400016592','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722499,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Brown Sugar Hickory Baked Beans 16 oz','Bush''s Baked Bn (Hic) 12-16 oz',123872,NULL,'10039400019760','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722696,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Homestyle Baked Beans 28 oz','Bush''s Baked Bn (Hst) 12-28 oz',123873,NULL,'10039400015946','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722944,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Original Baked Beans 28 oz','Bush''s Baked Bn (Org) 12-28 oz',123876,NULL,'10039400016141','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2721982,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Golden Hominy 15.5 oz','Bush''s Golden Hominy 12-15.5 oz',123877,NULL,'10039400017117','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2723090,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Brown Sugar Hickory Baked Beans 28 oz','Bush''s Baked Bn (Hic) 12-28 oz',123878,NULL,'10039400019777','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722764,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Dubon Petit Pois Green Peas 15 oz','Dubon Petit Pois Grn Pea 12-15 oz',123879,NULL,'10039400202704','Bush Brothers & Company','DUBON',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722553,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Garbanzo Beans 15 oz','Bush''s Organic Garbanzo Bn 15 oz',123880,NULL,'10039400017087','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2024-05-16',NULL,'UNPREPARED',2689724,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Golden Hominy 30 oz','Bush''s Golden Hominy 12-30 oz',123882,NULL,'10039400017162','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2723027,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Original Baked Beans 21 oz','Bush''s Baked Bn (Org) 12-21 oz',123883,NULL,'10039400016103','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722410,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Low Sodium Pinto Beans in a Mild Chili Sauce 15 oz','Bush''s LS Pinto Chili 12-15 oz',123886,NULL,'10039400106736','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722866,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s White Hominy 15.5 oz','Bush''s White Hominy 12-15.5 oz',123887,NULL,'10039400017209','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722190,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Easy Entrees Texas Ranchero 108 oz','Bush''s Texas Ranchero 108 oz',123889,NULL,'10039400010712','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722576,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Vegetarian Baked Beans 8.3 oz','Bush''s Veg Baked Bn 12-8.3 oz',123890,NULL,'10039400016301','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2723077,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Chick Peas 16 oz','Bush''s Garbanzo Bn 12-16 oz',123891,NULL,'10039400017056','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722452,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Crowder Peas 15 oz','Bush''s Crowder Peas 12-15 oz',123892,NULL,'10039400013805','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722784,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Country Style Baked Beans 16 oz','Bush''s Baked Bn (Cst) 12-16 oz',123893,NULL,'10039400019739','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2721955,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Blackeye Peas with Snaps 15.8 oz','Bush''s Blackeye Pea Snp 12-15.8 oz',123896,NULL,'10039400013713','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722994,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Homestyle Baked Beans 55 oz','Bush''s Baked Bn (Hst) 6-55 oz',123897,NULL,'10039400016493','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2024-12-19',NULL,'UNPREPARED',2719634,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Maple & Cured Bacon Baked Beans 16 oz','Bush''s Baked Bn (Mpl) 12-16 oz',123898,NULL,'10039400019685','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722921,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s White Chili Beans 12-15.5 oz','Bush''s Mld White Chili Bn 12-15.5oz',123899,NULL,'10039400015014','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-03-20',NULL,'UNPREPARED',2724144,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Dark Red Kidney Beans 15 oz','Bush''s Organic Dk Kidney Bn 15 oz',123900,NULL,'10039400017315','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722446,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Smokehouse Tradition Grillin'' Beans 12-22 oz','Bush''s Grillin Bn (Smo) 12-22 oz',123902,NULL,'10039400019128','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-03-20',NULL,'UNPREPARED',2724150,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Low Sodium Red Beans in a Mild Chili Sauce 15 oz','Bush''s LS Red Chili Bns 12-15 oz',123903,NULL,'10039400106743','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2721983,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Black Beans 110 oz','Bush''s Black Bn (OGN) 6-110 oz',123904,NULL,'10039400018886','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722969,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans 41 oz','Bush''s Pinto Bn 6-41 oz',123905,NULL,'10039400018169','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722527,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Brown Sugar Reduced Sodium & Sugar Baked Beans 15.7 oz','Bush''s Brown Sugar Bkd 12-15.7 oz',123907,NULL,'10039400103438','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2024-05-16',NULL,'UNPREPARED',2689701,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Dark Red Kidney Beans 111 oz','Bush''s Organic Dk Kidney Bn 111 oz',123908,NULL,'10039400017438','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2723071,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans with Bacon 15.5 oz','Bush''s Pinto Bn (Bac) 12-15.5 oz',123909,NULL,'10039400018114','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722925,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Low Sodium Black Beans 6-108 oz','Bush''s Black Bn (LS) 6-108 oz',123910,NULL,'10039400018855','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2650063,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Brakebush CN Whole Grain Popcorn Chicken, Breast Chunks, Fully Cooked, Frozen','FC CN Whole Grain Popcorn Chicken',123911,NULL,'10038034555705','Brakebush Brothers','Brakebush',NULL,3,'2023-05-27','2024-09-13',NULL,'UNPREPARED',2703887,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Sweet and Tangy Reduced Sodium & Sugar Baked Beans 15.7 oz','Bush''s Swt Tngy Baked 12-15.7 oz',123912,NULL,'10039400103391','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2024-05-16',NULL,'UNPREPARED',2689702,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Black Beans 15 oz','Bush''s Organic Black Bn 12-15 oz',123913,NULL,'10039400018787','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2024-05-16',NULL,'UNPREPARED',2689691,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Original Baked Beans 55 oz','Bush''s Baked Bn (Org) 6-55 oz',123914,NULL,'10039400016479','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722401,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Homestyle Baked Beans 8.3 oz','Bush''s Baked Bn (Hst) 12-8.3 oz',123915,NULL,'10039400015908','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2723011,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans in a Medium Chili Sauce 16 oz','Bush''s Chili Bn (Pin/Med) 16 oz',123916,NULL,'10039400016844','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722162,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Large Butter Beans 16 oz','Bush''s Large Butter Bn 12-16 oz',123917,NULL,'10039400016721','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722832,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Unsweetened Apple Sauce 6/10','Unsweetened Apple Sauce',123918,NULL,'50070283099034','CHERRY CENTRAL','Cherry Central Cooperative','110541',3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719161,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s White Hominy 108 oz','Bush''s White Hominy 6-108 oz',123919,NULL,'10039400017285','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722746,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Blackeye Peas with Bacon 15.5 oz','Bush''s Blackeye Pea (Bac) 15.5 oz',123920,NULL,'10039400013577','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722745,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Bean Pot Reduced Sodium Vegetarian Baked Beans 115 oz','Bush''s RS Veg Bn Pot Bkd Bn 115 oz',123921,NULL,'10039400016387','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722756,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Kidney Beans in a Mild Chili Sauce 12-16 oz','Bush''s Chili Bn (Kid/Mld) 16 oz',123922,NULL,'10039400015038','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-03-20',NULL,'UNPREPARED',2724146,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Baked Beans with Onion 28 oz','Bush''s Baked Bn (Oni) 12-28 oz',123923,NULL,'10039400016035','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722210,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Maple & Cured Bacon Baked Beans 28 oz','Bush''s Baked Bn (Mpl) 12-28 oz',123924,NULL,'10039400019708','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722476,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Black Beans in a Mild Chili Sauce 12-15.5 oz','Bush''s Mld Black Chili Bean 15.5 oz',123925,NULL,'10039400015021','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-03-20',NULL,'UNPREPARED',2724145,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans 111 oz','Bush''s Pinto Bn 6-111 oz',123928,NULL,'10039400018183','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722026,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SHOWBOAT Pork & Bean 27.5 oz','SHOWBOAT Pork & Bn 12-27.5 oz',123929,NULL,'10039400028434','Bush Brothers & Company','SHOWBOAT',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722119,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans in a Mild Chili Sauce 16 oz','Bush''s Chili Bn (Pin/Mld) 16 oz',123930,NULL,'10039400016837','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722790,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SHOWBOAT Pork & Bean 15 oz','SHOWBOAT Pork & Bn 12-15 oz',123931,NULL,'10039400028335','Bush Brothers & Company','SHOWBOAT',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722211,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Low Sodium Cannellini Beans 111 oz','Bush''s LS Cannellini Bn 6-111 oz',123932,NULL,'10039400018732','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722491,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Boston Recipe Baked Beans 28 oz','Bush''s Baked Bn (Bos) 12-28 oz',123933,NULL,'10039400019562','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2723046,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Reduced Sodium Black Beans 12-15 oz','Bush''s Black Bn (RS) 12-15 oz',123935,NULL,'10039400018831','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-03-20',NULL,'UNPREPARED',2724148,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Pinto Beans in a Mild Chili Sauce 111 oz','Bush''s Chili Bn (Pin/Mld) 6-111 oz',123936,NULL,'10039400016967','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722163,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Organic Pinto Beans 110 oz','Bush''s Organic Pinto Beans 110 oz',123939,NULL,'10039400010590','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722388,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Reduced Sodium Dark Red Kidney Beans 16 oz','Bush''s Dark Kidney Bn (RS) 12-16 oz',123940,NULL,'10039400017308','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722833,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Great Northern Beans 15.8 oz','Bush''s Northern Bn 12-15.8 oz',123941,NULL,'10039400017841','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722165,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Red Beans in a Medium Chili Sauce 16 oz','Bush''s Chili Bn (Red/Med) 16 oz',123944,NULL,'10039400016899','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722295,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Honey Sweet Baked Beans 16 oz','Bush''s Honey Swt Baked 12-16 oz',123945,NULL,'10039400019838','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722781,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Original Baked Beans 16 oz','Bush''s Baked Bn (Org) 12-16 oz',123946,NULL,'10039400016080','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722516,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Barbecue Baked Beans 16 oz','Bush''s Barbecue Bkd Bns 12-16 oz',123947,NULL,'10039400012013','Bush Brothers & Company','Bush''s Best',NULL,3,'2023-05-27','2025-01-23',NULL,'UNPREPARED',2722272,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'C/E Pork Undrained Sloppy Joe 6/5# 30#','C/E Pork Undrained Sloppy Joe',123949,NULL,'20049485054010','JTM Food Group','JTM Food Group',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700791,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Cheddar and Bacon Fries 1 ONZ','Shearer Ched & Bacon Fries 1 OZ',123961,NULL,'00037578619495','Shearer''s Foods LLC','SHEARER''S',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2518817,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SHEARER''S CHEESE BALLS 0.8 ONZ','SHEARER''S CHEESE BALLS 0.8 ONZ',123962,NULL,'00037578619501','Shearer''s Foods LLC','Shearer''s',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2518818,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Kettle Style Popcorn 1 ONZ','Shr''s Kettle Style Popcorn 1 ONZ',123963,NULL,'00037578619525','Shearers Foods LLC','Shearer''s',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2518819,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s White Popcorn 0.5 Oz','Shearer''s White Popcorn 0.5 Oz',123964,NULL,'00037578619655','Shearers Foods LLC','Shearer''s',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2518820,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Nacho Cheese Tortilla Taco in a Bag 2 ONZ','ShrsTaconBagNcho2oz',123966,NULL,'00037578620019','Shearers Foods LLC','Shearer''s',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2518822,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'New Orleans Style All Beef Meat Pies (Empanadas) - Bulk - 48CT','NOS All Beef Empanada',123967,NULL,'00038744323888','Natchitoches Meat Pie Co. Inc.','Our Famous Natchitoches Meat Pies',NULL,3,'2023-05-27','2023-04-27',NULL,'DEEP_FRY',2519051,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'ORIGINAL NATCHITOCHES MEAT PIE - BULK - 48CT','Natchitoches Meat Pies - Bulk',123968,NULL,'00038744323895','Natchitoches Meat Pie Co Inc','Our Famous Natchitoches Meat Pies',NULL,3,'2023-05-27','2023-04-27',NULL,'DEEP_FRY',2519052,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'NATCHITOCHES LOUISIANA ORIGINAL MEAT PIE - SPICY - BULK','ORIGINAL SPICY - BULK',123969,NULL,'00038744329996','Natchitoches Meat Pie Co Inc','Our Famous Natchitoches Meat Pies',NULL,3,'2023-05-27','2023-04-27',NULL,'DEEP_FRY',2519053,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chorizo, Egg and Jalapeno Breakfast Empanada - Bulk - 48CT','Chorizo, Egg & Jalapeno Empanada',123970,NULL,'00038744703895','Natchitoches Meat Pie Co Inc','Our Famous Natchitoches Meat Pies',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2519054,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Furmanos; 1/#10 Kidney Beans - Dark in Brine','10 Kdny Bns - Dk in Brine',123971,NULL,'00041188047180','Furmano Foods','Furmanos',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2519198,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Furmanos; 1/#10 Pinto Beans','10 Pinto Bns',123972,NULL,'00041188047241','Furmano Foods','Furmanos',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2519199,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Furmanos; 1/#10 Red Beans','10 Red Bns',123973,NULL,'00041188047265','Furmano Foods','Furmanos',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2519200,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Furmanos; 1/#10 Pink Beans - Low Sodium','10 Pink Bns LS',123974,NULL,'00041188047968','Furmano Foods','Furmanos',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2519202,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Furmanos; 6/#10 Pinto Beans','6/10 Pinto Bns',123975,NULL,'00041188111522','Furmano Foods','Furmanos',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2519205,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Furmanos; 6/#10 Red Beans','6/10 Red Bns',123976,NULL,'00041188111539','Furmano Foods','Furmanos',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2519206,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bella Vista; 6/#10 Chick Peas - Fancy (Garbanzo)','6/10 Chk Peas - Fcy (Garb)',123977,NULL,'00041188112055','Furmano Foods','Bella Vista',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2519209,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Furmanos; 6/#10 Pink Beans - Low Sodium','6/10 Pink Bns LS',123978,NULL,'00041188112970','Furmano Foods','Furmanos',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2519210,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Furmanos; 6/116OZ Pouch Baked Beans','6/116oz pch Bkd Bns',123979,NULL,'00041188115193','Furmano Foods','Furmanos',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2519212,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bella Vista; 1/#10 Chick Peas - Fancy (Garbanzo)','10 Chk Peas - Fcy (Garb)',123980,NULL,'00041188847179','Furmano Foods','Bella Vista',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2519217,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Dinner Rolls, Whole Grain, Low Sodium, Smooth Top, Individually Wrapped','Dinner Rolls, WG, LS, Smth Top, IW',123985,NULL,'00737410016481','Bake Crafters Food Company','Bake Crafters',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2521353,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'SunButter Creamy 44lb Pail','SunButter Creamy 44lb pail',123990,NULL,'00737539190222','Red River Commodities Sunbutter','SunButter','100935',3,'2023-05-27','2023-06-29',NULL,'READY_TO_EAT',2558590,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Double Chocolate Chip Mini Cookies, Gluten Free, Nut Free, 0.95oz Bag','CKIES, DBL CHOC CHIP, MINI, GF',123991,NULL,'00857313001947','Homefree','Homefree',NULL,3,'2023-05-27','2023-08-31',NULL,'READY_TO_EAT',2613929,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Mint Mini Cookies, Gluten Free, Single Serve, 0.95 Oz. Bag','CKIES, CHOC MINT, MINI, GF',123992,NULL,'00857488004354','Homefree','Homefree',NULL,3,'2023-05-27','2023-11-16',NULL,'READY_TO_EAT',2662428,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Organic Ginger Snap Mini Cookies, Gluten Free, Single Serve, 1/0.95 Oz.','CKIES, ORG GINGER SNAP, MINI, GF',123993,NULL,'00857488004620','Homefree','Homefree',NULL,3,'2023-05-27','2023-11-16',NULL,'READY_TO_EAT',2662429,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Chip Frozen Cookie Dough Made With Whole Grain','Chocolate Chip Cookies',123994,NULL,'10013087216490','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2023-05-27','2024-08-15',NULL,'UNPREPARED',2701499,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sugar Frozen Cookie Dough Made With Whole Grain','Sugar Cookies Made With Whole Grain',123995,NULL,'10013087216506','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2023-05-27','2024-08-15',NULL,'UNPREPARED',2701498,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Chip Naturally Flavored Chocolate Brownie Frozen Cookie Dough Made With Whole Grain','Chocolate Chip Brownie Cookies',123996,NULL,'10013087216520','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2023-05-27','2024-05-16',NULL,'UNPREPARED',2689890,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'FROZEN COOKIE DOUGH CARNIVAL MULTI-COLORED CANDY COATED SEMI-SWEET CHOCOLATE GEM MADE WITH 51% WHOLE GRAIN LAYERED PACK 1/180/1.85 O','FCD CARNIVAL W/ 51% WHOLE GRAIN',123997,NULL,'10013087216537','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2023-05-27','2023-06-29',NULL,'UNPREPARED',2558712,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Chip Frozen Cookie Dough Made With Whole Grain','Chocolate Chip Cookies Whole Grain',123998,NULL,'10013087556701','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2023-05-27','2024-08-15',NULL,'UNPREPARED',2701496,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Grilled Scrambled Egg Patty, 320/1.25 oz., Frozen, Bulk','Scrm EGGPTY GRILL',124006,NULL,'10038057409313','Cargill Poultry Products Div','Sunny Fresh','111751',3,'2023-05-27','2024-11-14',NULL,'PREPARED',2717265,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Old South Buttermilk Biscuits, Layer Pack 6185','Bisc heat and serv',124007,NULL,'10047500004685','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-11-14',NULL,'PREPARED',2717256,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Heat and Serve Honey Wheat Rolls, 1.5 oz (Whole Grain), 6668','Hear and Srv Wht',124008,NULL,'10047500007402','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719650,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford White Whole Wheat Maple Flavored Biscuits, Layer Pack (Whole Grain) 6245','Bisc heat and serv',124009,NULL,'10047500015780','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718933,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford White Whole Wheat Blueberry Flavored Biscuits, Layer Pack (Whole Grain) 6246','Bisc heat and serv',124010,NULL,'10047500015797','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718934,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Cheesy Jalapeno Biscuits, Sliced, Layer Pack 6292','Bridgford "Heat & Serve" Cheesy',124011,NULL,'10047500018453','Bridgford Foods Corporation','Bridgford',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718945,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breakfast Kit Honey Bunch of Oats Vanilla','Breakfast Kit Honey Bunch Vanilla',124012,NULL,'10693392005530','East Side Entrees','ES Foods',NULL,3,'2023-05-27','2023-08-31',NULL,'PREPARED',2614147,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Unsweetened Original Applesauce','Unsweetened Original Applesauce',124013,NULL,'10882266100642','Peterson Farms Fresh, Inc.','Peterson Farms Treats',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2522128,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Peterson Farms Treats Applesauce','Unsweetened Cinnamon Applesauce',124014,NULL,'10882266100659','Peterson Farms Fresh, Inc.','Peterson Farms Treats',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2522129,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Peterson Farms Treats Applesauce','Unsweetened Strawberry Applesauce',124015,NULL,'10882266100666','Peterson Farms Fresh, Inc.','Peterson Farms Treats',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2522130,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Peterson Farms Treats Applesauce','Unsweetened Peach Applesauce',124016,NULL,'10882266100680','Peterson Farms Fresh, Inc.','Peterson Farms Treats',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2522132,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Peterson Farms Treats Applesauce','Unsweetened Mixed Berries',124017,NULL,'10882266100703','Peterson Farms Fresh, Inc.','Peterson Farms Treats',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2522133,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fresh Red Apple Slices','Fresh Apple Slices 100ct/2oz',124018,NULL,'10882266110023','Peterson Farms Fresh, Inc.','Peterson Farms Treats',NULL,3,'2023-05-27','2023-11-16',NULL,'READY_TO_EAT',2662579,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Vine Ripe No Salt Added Diced Tomatoes, 14.5oz Can - CS of 24','Vine Ripe Diced Tomatoes NSA',124019,NULL,'20072940120043','Red Gold, Inc.','Vine Ripe','100328',3,'2023-05-27','2025-03-20',NULL,'UNPREPARED',2724495,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Hummus Cup, Original, 3 oz.','Original Hummus Cup',124020,NULL,'20810358030291','National Food Group','Zee Zees',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719205,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Hummus Cup, Red Pepper, 3 oz.','Red Pepper Hummus Cup',124021,NULL,'20810358030321','National Food Group','Zee Zees',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719206,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Grahamz, French Toast, IW, WG 1oz','French Toast Grahamz',124022,NULL,'20810358031243','National Food Group','Zee Zees',NULL,3,'2023-05-27','2024-08-15',NULL,'READY_TO_EAT',2700906,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Dried Fruit, Mixzees, IW, 1.33oz.','Dried Fruit',124023,NULL,'20810358031717','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2522160,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Sunflower Kernels, Roasted Salted, 1.2 oz','Roasted Sunflower Kernel',124024,NULL,'20810358032660','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-07-11',NULL,'READY_TO_EAT',2696474,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Sunflower Kernels, Spicy, 1.2 oz','Spicy Sunflower Kernels',124025,NULL,'20810358032677','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-07-11',NULL,'READY_TO_EAT',2696475,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees, Dried Fruit, Mixzees,1.33 oz','Dried Fruit Mix',124026,NULL,'20810358034268','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719212,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Soft Baked Bar, Blueberry Lemon, 2.2 oz','Blueberry Lemon Soft Baked Bar',124027,NULL,'20810358034343','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-08-15',NULL,'READY_TO_EAT',2700895,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Soft Baked Bar, Cocoa Cherry, 1.8 oz','Cocoa Cherry Soft Baked bar',124028,NULL,'20810358034688','National Food Group','Zee Zees',NULL,3,'2023-05-27','2024-08-15',NULL,'READY_TO_EAT',2700924,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees, Grahamz, Birthday Cake, IW, 1oz','Birthday Cake Grahamz',124029,NULL,'20854114007738','National Food Group','Zee Zees',NULL,3,'2023-05-27','2024-08-15',NULL,'READY_TO_EAT',2700914,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'COOKIES CARNIVAL COLORED CHOCOLATE CANDY MADE WITH WHOLE GRAIN INDIVIDUALLY WRAPPED 72/1.33 OZ','COOKIES CARNIVAL COLORED CHOC CANDY',124030,NULL,'00013087216486','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2023-05-27','2023-06-29',NULL,'PREPARED',2554938,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Doritos Reduced Fat Tortilla Chips Cool Ranch 1 Oz','Doritos Red Fat Cool Ranch 1z,72Ct',124032,NULL,'00028400360968','PepsiCo Inc. Brand Owner','Doritos',NULL,3,'2023-05-27','2023-11-16',NULL,'UNPREPARED',2662860,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tostitos Tortilla Chips Crispy Rounds 16 Oz','Tostitos Crispy Rounds 16 Oz, 8 Ct',124033,NULL,'00028400623995','PepsiCo Inc. Brand Owner','Tostitos',NULL,3,'2023-05-27','2023-12-21',NULL,'UNPREPARED',2681024,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Instant Oatmeal Maple & Brown Sugar 1.69 Oz','Quaker Maple&BrwnSugar 1.69z,24Ct',124037,NULL,'00030000319710','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2650330,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Instant Oatmeal Honey & Almonds 1.76 Oz','Quaker Honey & Almonds 1.76Oz, 12Ct',124038,NULL,'00030000562055','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2023-05-27','2023-12-21',NULL,'UNPREPARED',2681082,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Instant Quaker Oatmeal Express Cup Apple Cinnamon 1.51Z/12','QKR IQO EC AC 1.51Z',124039,NULL,'00030000562086','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2023-05-27','2023-12-21',NULL,'UNPREPARED',2681083,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Instant Quaker Oatmeal Express Cup Apple Cranberry 1.79Z/12','QKR IQO EC AC 1.79Z',124040,NULL,'00030000562116','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2023-05-27','2023-11-16',NULL,'UNPREPARED',2662864,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Furmanos; 6/#10 Kidney Beans - Dark in Brine','6/10 Kdny Bns - Dk in Brine',124041,NULL,'00041188112031','Furmano Foods','Furmanos',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525739,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 48/5.5 FL OZ 100% JUICE - CONCORD GRAPE','48/5.5OZ 100% PRPL GRP JCE',124042,NULL,'00041800206001','WELCH FOODS INC.','Welchs',NULL,3,'2023-05-27','2023-06-29',NULL,'READY_TO_DRINK',2556635,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Crave-N-Rave Whole Grain Simply Salted Spikerz Cracker Bites, 4-20 Ounce Bags in Box','WG Simply Salt Spikerz, 4-20oz BLK',124043,NULL,'00675825510302','Darlington Cookie Company','Crave-N-Rave',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525794,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Crave-N-Rave Whole Grain 0.9 oz Heavenly Ranch Spikerz Cracker Bites, 4-20 Ounce Bags in Box','WG Ranch Spikerz, 4-20oz BLK',124044,NULL,'00675825512306','Darlington Cookie Company','Crave-N-Rave',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525797,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Crave-N-Rave Whole Grain The Originals Champs Cracker Bites, 4-20 Ounce Bags in Box','WG OG Champs Crackers, 4-20oz BLK',124045,NULL,'00675825520301','Darlington Cookie Company','Crave-N-Rave',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525798,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.2 oz Soft Oatmeal Vanilla Celebration Bar, Individually Wrapped - Each','1.2oz WG Vanilla Bar, Each',124046,NULL,'00675825705906','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525806,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.0 oz Cinnamon Crispy Bites, Individually Wrapped - Each','1.0oz WG Cinnamon Crispy Bites, Eac',124047,NULL,'00675825710917','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525809,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.0 oz Cocoa Crispy Bites, Individually Wrapped - Each','1.0oz WG Cocoa Crispy Bites, Each',124048,NULL,'00675825713901','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525811,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.85 oz Blueberry Lemon Crispy Bites, Individually Wrapped - 180ct','1.85oz WG BB Lemon Bites, IW',124049,NULL,'00675825715028','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525813,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.0 oz Blueberry Lemon Crispy Bites, Individually Wrapped - Each','1.0oz WG BB Lemon Crispy Bites, Eac',124050,NULL,'00675825715912','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525814,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.85 oz Blueberry Lemon Crispy Bites, Individually Wrapped - Each','1.85oz WG BB Lemon Bites, Each',124051,NULL,'00675825715929','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525815,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.0 oz Granola Crispy Bites, Individually Wrapped - Each','1.0oz WG Granola Crispy Bites, Each',124052,NULL,'00675825716902','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525817,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.4 oz Oatmeal Raisin Cookie, Individually Wrapped - Each','1.4oz WG SB OAT Raisin Cookie, Each',124053,NULL,'00675825730908','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525822,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.4 oz Chocolate Chip Cookie, Individually Wrapped - Each','1.4oz WG SB OAT ChocChip Cookie, Ea',124054,NULL,'00675825733909','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525824,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 2.4 oz Soft Oatmeal Chocolate Chip Bar, Individually Wrapped - Each','2.4oz WG Choc Chip Oatmeal Bar, Eac',124055,NULL,'00675825753907','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525828,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 2.4 oz Soft Oatmeal Strawberry Bar, Individually Wrapped - Each','2.4oz WG Strawberry Oatmeal Bar, Ea',124056,NULL,'00675825754904','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525830,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 2.4 oz Soft Oatmeal Vanilla Celebration Bar, Individually Wrapped - Each','2.4oz WG Vanilla Bar, Each',124057,NULL,'00675825755901','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525832,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain Cheddar Cheese Crispy Crackers, 4-20 Ounce - Bulk','WG Cheddar Crackers, 4-20oz BULK',124058,NULL,'00675825761209','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525836,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 0.9 oz Cheddar Cheese Crispy Crackers, Individually Wrapped, Each','0.9oz WG  Cheddar Chs Crackers, Eac',124059,NULL,'00675825761902','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525837,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.0 oz Veggie Crispy Crackers, Individually Wrapped, 108ct','1.0oz WG Veggie Crackers, IW',124060,NULL,'00675825763012','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525838,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.85 oz Veggie Crispy Crackers, Individually Wrapped, 180ct','1.85oz WG Veggie Crackers, IW',124061,NULL,'00675825763029','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-06-29',NULL,'PREPARED',2558209,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain Veggie Crispy Crackers, 4-20 Ounce - Bulk','WG Veggie Crackers, 4-20oz BULK',124062,NULL,'00675825763203','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525840,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.0 oz Veggie Crispy Crackers, Individually Wrapped, Each','1.0oz WG Veggie Crackers, Each',124063,NULL,'00675825763913','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525841,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.85 oz Veggie Crispy Crackers, Individually Wrapped, Each','1.85oz WG Veggie Crackers, Each',124064,NULL,'00675825763920','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525842,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.0 oz Sweet Potato Crispy Crackers, 4-20 Ounce - Bulk','WG Swt Potato Cracker, 4-20oz BULK',124065,NULL,'00675825764200','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525844,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.0 oz Sweet Potato Crispy Crackers, Individually Wrapped, Each','1.0oz WG Sweet Potato Cracker, Each',124066,NULL,'00675825764903','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525845,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Spinach & Cheese Empanada','WG Spinach & Cheese Empanada',124067,NULL,'00711341501131','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525847,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Bean & Cheese Empanada','WG Bean & Cheese Empanada',124068,NULL,'00711341504521','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525850,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Jamaican Beef Patty','Jamaican Beef Patty',124069,NULL,'00711341509755','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525855,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Egg, Cheese & Potato Empanada','WG Egg, Cheese & Potato Empanada',124070,NULL,'00711341535518','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525856,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Granola, Golden Vanilla, Whole Grain, Wholesome Choice, Bulk','Granola Golden Vanilla WG Wholesome',124073,NULL,'00737410024844','Bake Crafters Food Company','Bake Crafters',NULL,3,'2023-05-27','2023-06-29',NULL,'UNPREPARED',2558374,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Maple Waffle','WG Maple Waffle',124074,NULL,'00810089290007','Tasty Brands','Tasty Brands LLC',NULL,3,'2023-05-27','2023-08-31',NULL,'THAW',2613902,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Chip Waffle','WG Chocolate Chip Waffle',124075,NULL,'00810089290014','Tasty Brands','Tasty Brands LLC',NULL,3,'2023-05-27','2023-08-31',NULL,'THAW',2613903,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain GarlicKnot','81002 NY Style WG Garlic Knot',124076,NULL,'00810089290120','Tasty Brands','Tasty Brands',NULL,3,'2023-05-27','2023-09-14',NULL,'BAKE',2641284,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Four Cheese Tortellini','00830WG Four Cheese Tortellini',124077,NULL,'00810089290212','Tasty rBands','Tasty Brands',NULL,3,'2023-05-27','2023-08-31',NULL,'PREPARED',2613905,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Chip Waffle','WG Chocolate Chip Waffle',124078,NULL,'00810089290427','Tasty Brands','Tasty Brands LLC',NULL,3,'2023-05-27','2023-08-31',NULL,'THAW',2613906,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Thai Sweet Chili Chicken - Gluten Free','Thai Sweet Chili Chicken - GF',124081,NULL,'00850002832518','International Food Solutions, Inc.','Green Dragon',NULL,3,'2023-05-27','2023-12-21',NULL,'PREPARED',2680803,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'OKRA, BREADED CUT TFF COOKED FROZEN APPETIZER','33500 Okra Breaded Frozen Appetizer',124082,NULL,'00852777002110','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2525879,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Lemon Chip Crunch Bars 120ct','Lemon Chip Crunch Bars',124083,NULL,'10010374011868','The Father''s Table','The Father''s Table Dunkers',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2701470,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Triple Berry Crunch Bars','Triple Berry Crunch Bars',124084,NULL,'10010374011943','The Father''s Table','The Father''s Table Dunkers',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719608,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cherry Apple Crunch Bar 120ct Case','Cherry Apple Crunch Bar',124085,NULL,'10010374011974','The Father''s Table','The Father''s Table Dunkers',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2697056,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'8/2.5 lb Whole Grain Corn Masa Nacho Lil Bites','Nacho Lil Bites',124086,NULL,'10010374770444','The Father''s Table','Lil'' Bites',NULL,3,'2023-05-27','2023-10-26',NULL,'BAKE',2649880,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naturally Flavored Wild Blueberry Muffin Made With Whole Grain With Other Natural Flavor','Blueberry Muffin w/ Whole Grain',124087,NULL,'10013087101437','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2023-05-27','2024-02-01',NULL,'PREPARED',2683835,'50182300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naturally Flavored Banana Muffin(s) Made With Whole Grain','Banana Muffin Made With Whole Grain',124088,NULL,'10013087101444','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2023-05-27','2024-02-01',NULL,'PREPARED',2683834,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naturally And Artificially Flavored Chocolate Chocolate Chip Muffin Made With Whole Grain','Choc Choc Chip Muffin Whole Grain',124089,NULL,'10013087101451','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2023-05-27','2024-02-01',NULL,'PREPARED',2683833,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naturally Flavored Apple Cinnamon Muffin(s) With Other Natural Flavors Made With Whole Grain','Apple Cinnamon Muffin Whole Grain',124090,NULL,'10013087101468','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2701485,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Corn Muffin(S) Made With Whole Grain','Corn Muffin Made With Whole Grain',124091,NULL,'10013087216407','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essentials',NULL,3,'2023-05-27','2025-03-20',NULL,'PREPARED',2723285,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'MUFFIN CORN MADE WITH 51% WHOLE GRAIN INDIVIDUALLY WRAPPED 48/4 OZ','MUFFIN CORN W/ WHOLE GRAIN',124092,NULL,'10013087216414','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2023-05-27','2023-06-29',NULL,'PREPARED',2558710,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'COOKIES CARNIVAL COLORED CHOCOLATE CANDY MADE WITH WHOLE GRAIN INDIVIDUALLY WRAPPED 72/1.33 OZ','COOKIES CARNIVAL COLORED CHOC CANDY',124093,NULL,'10013087216483','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2023-05-27','2023-06-29',NULL,'PREPARED',2558711,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Chip Muffin Made With Whole Grain','Chocolate Chip Muffin Made',124094,NULL,'10013087241850','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essentials',NULL,3,'2023-05-27','2024-09-13',NULL,'PREPARED',2704113,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffin Chocolate Chip Whole Grain Individually Wrapped 48/4 oz','MUFFIN CHOCOLATE CHIP WHOLE GRAIN',124095,NULL,'10013087241867','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2023-05-27','2024-02-01',NULL,'PREPARED',2683824,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'24/300 LAKESIDE N/S WK GLD CRN','N/S WK CORN',124096,NULL,'10033828078125','Lakeside Foods Inc.','LAKESIDE FOODS','100313',3,'2023-05-27','2024-03-14',NULL,'READY_TO_EAT',2687801,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Mini Rounds Tortilla Chips  60 / 2 ONZ Case (Yellow Corn) - Net Content 120 Ounces','Shrs Mini Rnds  60/2 Oz CS',124097,NULL,'10037578619171','Shearer’s Foods LLC','Shearer''s',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719687,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s No Salt Yellow Mini Rounds 60/2 ONZ - Ground Yellow Corn Mini Rounds Tortilla Chips No Salt','ShrerNoSal YellowMiniRnds 60/ 2 ONZ',124098,NULL,'10037578619218','Shearer’s Foods LLC','Shearer''s',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719688,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Cheddar and Bacon Fries 90 / 1 ONZ Case','ShearerChdarnBaconFries 90/1 ONZ CS',124099,NULL,'10037578619492','Shearers Foods LLC','SHEARER''S',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2525907,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SHEARER''S CHEESE BALLS 64 / 0.8 ONZ Case  -Net Content 51.2 Ounces','SHEARER''S CHEESE BALLS 64ct 0.8oz',124100,NULL,'10037578619508','Shearer''s Foods LLC','Shearer''s',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2525908,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Kettle Style Popcorn 90/1 ONZ Case','Shrs Kettle Popcorn 90/1 ONZ',124101,NULL,'10037578619522','Shearers Foods LLC','Shearer''s',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2525909,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s White Popcorn 60 / 0.5 ONZ - Net Content 30 Ounces','Shrs White Popcorn 60 / 0.5 ONZ',124102,NULL,'10037578619652','Shearers Foods LLC','Shearer''s',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2525910,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Precooked Scrambled Eggs, Medium Curd, 1/30 lb., Frozen, Bulk','PRECK SCR EGG',124103,NULL,'10038057309484','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696401,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Precooked Scrambled Eggs, Small Curd, 1/30 lb., Frozen, Bulk','PRECK SCR EGG',124104,NULL,'10038057309576','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696374,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Precooked Scrambled Eggs, Medium Curd, 1/30 lb., Frozen, Bulk','PRECK SCR EGG',124105,NULL,'10038057309583','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696375,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Egg Bake Bites with Turkey Sausage and Cheddar Cheese, 200/2 oz., Frozen, Bulk','Trky SSG w/ Chdr EGG BK BT',124106,NULL,'10038057402659','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696377,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Grilled Scrambled Egg Patty, 300/1.25 oz., Frozen, Bulk','Scrm EGGPTY GRILL',124107,NULL,'10038057407111','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696379,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Precooked Scrambled Eggs, Medium Curd, 4/5 lb. Frozen, Bag','PRECK SCR EGG',124108,NULL,'10038057409276','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696380,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bacon & Cheese Eggstravaganza, Medium Curd, 4/5 lb., Frozen, Bag','BCN CHZ EGG Mix',124109,NULL,'10038057409283','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696381,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cage Free Grilled Scrambled Egg Patty, 369/1.25 oz., Frozen, Bulk','CF Scrm EGGPTY GRILL',124111,NULL,'10038057417103','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696383,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cage Free Precooked Scrambled Eggs, Medium Curd, 4/5 lb., Frozen, Bag','CF PRECK SCR EGG',124112,NULL,'10038057419275','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696384,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'CookieTree Gourmet Whole Grain Chocolate Chip 1.3 oz. Thaw and Serve Cookie','CT GM WG Chocolate Chip 1.3 oz. T&S',124113,NULL,'10039225325107','C. H. Guenther and Son Inc.','CookieTree',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525928,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sun-Maid California Sun-Dried Raisins 6-Pack/1.33 oz. Cartons for USDA - Case of 24','SUNMAID RAISIN 6PK FOR USDA - CS/24',124114,NULL,'10041143020255','Sun-Maid Growers','Sun-Maid','100293',3,'2023-05-27','2024-03-14',NULL,'READY_TO_EAT',2687824,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 48/5.5 FL OZ 100% JUICE - ORANGE','48/5.5OZ 100% ORANGE JUICE',124115,NULL,'10041800281005','WELCH FOODS INC.','Welchs',NULL,3,'2023-05-27','2023-06-29',NULL,'READY_TO_DRINK',2559158,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 48/5.5 FL OZ 100% JUICE - APPLE','48/5.5OZ 100% APPLE JUICE',124116,NULL,'10041800283009','WELCH FOODS INC.','Welchs',NULL,3,'2023-05-27','2023-06-29',NULL,'READY_TO_DRINK',2559159,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 24/10 FL OZ 100% JUICE - APPLE','24/10OZ 100% APPLE JUICE',124117,NULL,'10041800316004','WELCH''S','Welchs',NULL,3,'2023-05-27','2024-02-01',NULL,'READY_TO_DRINK',2683734,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 24/10 FL OZ 100% JUICE - ORANGE','24/10OZ 100% ORANGE JUICE',124118,NULL,'10041800344007','WELCH''S','Welchs',NULL,3,'2023-05-27','2023-06-29',NULL,'READY_TO_DRINK',2559161,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 24/10 FL OZ 100% JUICE - CONCORD GRAPE','24/10OZ 100% GRAPE JUICE',124119,NULL,'10041800354006','WELCH''S','Welchs',NULL,3,'2023-05-27','2023-11-16',NULL,'READY_TO_DRINK',2662335,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 24/11.5 FL OZ 100% JUICE - ORANGE','24/11.5OZ 100% ORANGE JUICE',124120,NULL,'10041800379009','WELCH FOODS INC.','Welchs',NULL,3,'2023-05-27','2023-06-29',NULL,'READY_TO_DRINK',2559163,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 24/11.5 FL OZ 100% JUICE - APPLE','24/11.5OZ 100% APPL JCE',124121,NULL,'10041800382009','WELCH FOODS INC.','Welchs',NULL,3,'2023-05-27','2023-06-29',NULL,'READY_TO_DRINK',2559164,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'12/12ct Ultra Loco Bread Round','Loco Bread Round',124122,NULL,'10045059011888','The Father''s Table','Ultra Loco',NULL,3,'2023-05-27','2024-07-11',NULL,'THAW',2696394,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'12/12ct Ultra Loco Bread Squared','Loco Bread Squared',124123,NULL,'10045059011918','The Father''s Table','Ultra Loco',NULL,3,'2023-05-27','2023-08-31',NULL,'THAW',2614021,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'ENRICHED EGG ABC''S','ABC''s',124126,NULL,'10070753011667','A Zerega''s Sons Inc','COLUMBIA',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525943,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'LG EGG BOWS','Large Egg Bows Columbia',124127,NULL,'10070753012206','A. Zerega''s Sons, Inc.','COLUMBIA',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525944,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'JUMBO SHELLS (20 LB)','JUMBO SHELLS COLUMBIA',124128,NULL,'10070753012251','A. Zerega''s Sons, Inc.','COLUMBIA',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525945,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'COLUMBIA FINE EGG NOODLES','COL FINE EGG',124129,NULL,'10070753210060','A Zerega''s Sons Inc','COLUMBIA',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525946,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'COLUMBIA MEDIUM EGG NOODLE','COL MED EGG',124130,NULL,'10070753210268','A Zerega''s Sons Inc','COLUMBIA',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525947,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'COLUMBIA WIDE EGG NOODLE 12 X 12 OZ','COL WE NOODLE',124131,NULL,'10070753210466','A Zerega''s Sons Inc','COLUMBIA',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525948,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'COLUMBIA EGG FLAKES','COL FLAKES',124132,NULL,'10070753211463','A Zerega''s Sons Inc','COLUMBIA',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525949,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'COLUMBIA MIDGET EGG BOWS','COL EGG BOWS',124133,NULL,'10070753212262','A Zerega''s Sons Inc','COLUMBIA',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525950,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'COLUMBIA KLUSKI NOODLE','COL KLUSKI',124134,NULL,'10070753213269','A Zerega''s Sons Inc','COLUMBIA',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525951,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'COLUMBIA RUFFLED LASAGNE','COL RUFFLED LASAGNE',124135,NULL,'10070753252879','A Zerega''s Sons Inc','COLUMBIA',NULL,3,'2023-05-27','2023-04-27',NULL,'UNPREPARED',2525952,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Breaded Onion Rings','33504 Breaded Onion Rings',124136,NULL,'10652777002526','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2024-05-16',NULL,'PREPARED',2690090,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Northern Gold Quick Oats, 42oz','42oz NG Quick Oats',124137,NULL,'10695356670341','American Cereal','Northern Gold Foods','100465',3,'2023-05-27','2024-12-19',NULL,'UNPREPARED',2718879,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'SunButter Creamy 5 lb tubs - 6 ct case','SunButter Creamy 5 lb tubs - 6ct',124138,NULL,'10737539191257','Red River Commodities SunButter','SunButter','100935',3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2718890,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tickled Peaches','Freestone DIce',124139,NULL,'10817134020432','Palmetto Processing Solutions','Tickled Peaches','100241',3,'2023-05-27','2024-12-19',NULL,'THAW',2718832,'50270100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mixed Berry','Mixed Berry',124140,NULL,'10817134020449','Palmetto Processing Solutions','Tickled Berries','110859',3,'2023-05-27','2024-12-19',NULL,'THAW',2718833,'50270100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tickled Strawberries','Strawberries Dice',124141,NULL,'10817134020456','Palmetto Processing Solutions','Tickled Strawberries','100256',3,'2023-05-27','2024-12-19',NULL,'THAW',2718834,'50270100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Southern Sliced Peaches','Frozen Sliced Freestone Peaches',124142,NULL,'10817134025772','Palmetto Processing Solutions','Southern Sliced Peaches','100238',3,'2023-05-27','2024-12-19',NULL,'THAW',2718835,'50270100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Mini Cheese Ravioli','Whl Grain Mini Cheese Ravioli',124143,NULL,'10852777002292','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526085,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Mini Cheese Pizza Bagel','Whole Grain Mini Cheese Pizza Bagel',124144,NULL,'10852777002315','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526086,'50230100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Chicken Cheese & Pepperoni Mini Pizza Bagels','Cheese & Turkey Pep Pizza Bagels',124145,NULL,'10852777002322','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526087,'50230100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SANDWICH, TURKEY HAM & CHEESE WRAP WHOLE GRAIN IW FROZEN','Sandwich, Trky Ham & Chs Wrap',124146,NULL,'10852777002636','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526088,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Anytimers Turkey & Cheese Kits','10202 Turkey & Cheese Kits',124147,NULL,'10852777002667','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2024-05-16',NULL,'PREPARED',2690063,'50230100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Anytimers Turkey Ham & Cheese Kits','10206 Anytimers Trky Ham & Chs Kits',124148,NULL,'10852777002674','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2024-05-16',NULL,'PREPARED',2690062,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'LASAGNA, CHEESE 4 WAY PARCOOKED FROZEN TRAY WHOLE GRAIN','00822WG Lasagna, Chs 4 Tray',124149,NULL,'10852777002704','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526091,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Anytimers Cheese Pizza Kit','10101 Cheese Pizza Kit',124150,NULL,'10852777002919','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526092,'50230100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Anytimers Cheese & Turkey Pepperoni','10102 Pepperoni Pizza Lunch Kit',124151,NULL,'10852777002926','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2024-05-16',NULL,'PREPARED',2690061,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Italian Combo Sandwich','70014 WG Italian Combo Sandwich',124152,NULL,'10852777002964','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526094,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Turkey Ham & Cheese Sandwich','70016 Turkey Ham & Cheese Sandwich',124153,NULL,'10852777002988','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526095,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'LASAGNA, CHEESE WHOLE GRAIN PASTA COOKED IQF FROZEN BULK ROLL UP','Lasagna, Chs Whl Grain Pasta',124154,NULL,'10852777002995','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526096,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Stuffed Shells','00803WG Stuffed Shells',124155,NULL,'10852777003008','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526097,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'LASAGNA, TURKEY & CHEESE WHOLE GRAIN PASTA COOKED FROZEN BULK ROLLUP','Lasagna, Trky & Chs Whl Grain',124156,NULL,'10852777003039','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526098,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'LASAGNA, VEGETABLE & CHEESE 51% WHOLE GRAIN COOKED FROZEN BULK ROLLUP','00821WG Lasagna, Veg & Chs 51% Whl',124157,NULL,'10852777003053','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526099,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Chicken, Turkey Ham & 2 Cheese Wedge Sandwich','70013 WG Ckn, Tkry Ham, 2 Chs Wedge',124158,NULL,'10852777003176','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2024-10-31',NULL,'PREPARED',2716052,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Chicken, Turkey Pepperoni & Cheese','70015 WG Chix, Turkey Pepp & Cheese',124159,NULL,'10852777003510','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526101,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Mozzarella Filled Twisted Butter','WG Mozzarella Filled Twisted Bread',124160,NULL,'10852777003534','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526102,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Mozzarella Filled Twisted Buttery Breadstick','Mozzarella Filled Twist Bread Stick',124161,NULL,'10852777003541','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526103,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'70513 WG Tky Breast, Tky Ham & Chs Wedge Sandwich','WG Tky Breast, Tky Ham & Chs Wedge',124162,NULL,'10852777003824','Tasty Brands','Tasty Brands',NULL,3,'2023-05-27','2023-08-31',NULL,'PREPARED',2614172,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Turkey Ham & cheese Croissant Sandwich','Sandwich, Trky Ham & Chs Amer',124163,NULL,'10852777003978','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526105,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Turkey Ham & Cheese Croissant Sandwich, I/W','WG Tky Ham & Chs Croissant',124164,NULL,'10852777004036','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526106,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Turkey & 2 Chs Whole Grain Wedge, IW','Turkey & 2 Chs Whole Grain Wedge',124165,NULL,'10852777004265','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526107,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Twisted Topped Breadstick','WG Twisted Topped Breadstick',124166,NULL,'10852777004371','Tasty Brands','Tasty Brands',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526108,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Deli Combo Sandwich','71014 WG Deli Combo Sandwich',124167,NULL,'10852777004845','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-08-31',NULL,'PREPARED',2614173,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Peach Cobbler Biscuit, IW','22020 WG Peach Cobbler Biscuit, IW',124168,NULL,'10852777004906','Tasty Brands','Tasty Brands',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526110,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain GarlicKnot','Whole Grain GarlicKnot',124169,NULL,'10852777004944','Tasty Brands','Tasty Brands',NULL,3,'2023-05-27','2023-04-27',NULL,'BAKE',2526111,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Oven Ready Breaded Mini Cheese Ravioli','WG Breaded Mini Cheese Ravioli',124170,NULL,'10852777005767','Tasty Brands','Tasty Brands',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526112,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Oven Ready Breaded Mozzarella Sticks','41009 WG Breaded Mozzarella Sticks',124171,NULL,'10852777005798','Tasty Brands LLC','Tasty Brands',NULL,3,'2023-05-27','2023-08-31',NULL,'PREPARED',2614174,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain PizzaBoli','Whole Grain PizzaBoli',124172,NULL,'10852777005972','Tasty Brands LLC','Tasty Brands LLC',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526114,'50230100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Mini Bagel - Bulk','Whole Grain Mini Bagel - Bulk',124173,NULL,'10852777006085','Tasty Brands LLC','Tasty Brands LLC',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526115,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Anytimers Turkey Ham & Cheese Kits','10292',124174,NULL,'10852777007631','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526116,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Maple Waffle','WG Maple Waffle',124175,NULL,'10852777007648','Tasty Brands','Tasty Brands LLC',NULL,3,'2023-05-27','2023-08-31',NULL,'THAW',2614178,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Chip Waffle','WG Chocolate Chip Waffle',124176,NULL,'10852777007655','Tasty Brands','Tasty Brands LLC',NULL,3,'2023-05-27','2023-04-27',NULL,'THAW',2526118,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Turkey & Cheese','WG Turkey & Cheese Sub',124177,NULL,'10852777007679','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-08-31',NULL,'PREPARED',2614179,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Turkey Ham & Cheese','WG Turkey Ham & Cheese Sub',124178,NULL,'10852777007686','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-08-31',NULL,'PREPARED',2614180,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Cheese Croissant Sandwich','WG Cheese Croissant Sandwich',124179,NULL,'10852777007709','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-08-31',NULL,'PREPARED',2614181,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Turkey Ham, Tky Pep & Chs Sub','WG Turkey Ham, Tky Pep & Cheese Sub',124180,NULL,'10852777007723','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-08-31',NULL,'PREPARED',2614182,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Turkey Ham & cheese Croissant Sandwich','Sandwich, Trky & Chs Amer',124181,NULL,'10852777007730','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-08-31',NULL,'PREPARED',2614183,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Chicken, Turkey Pepperoni & Cheese','WG Chix, Turkey Pepperoni & Chees',124182,NULL,'10852777007808','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-04-27',NULL,'PREPARED',2526124,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Four Cheese Tortellini','Toteliini, Whole Grain Four Cheese',124183,NULL,'10852777708309','Tasty rBands','Tasty Brands',NULL,3,'2023-05-27','2023-06-29',NULL,'PREPARED',2559568,'50192900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Double Chocolate Chip Mini Cookies, Gluten Free, Nut Free, 10/0.95oz Tray','CKIES,DBL CHOC CHIP,MINI,GF,G&G',124184,NULL,'10857313001944','Homefree','Homefree',NULL,3,'2023-05-27','2023-11-16',NULL,'READY_TO_EAT',2662679,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Mint Mini Cookies, Gluten Free, Nut Free, 30/0.95 Oz. Bags','CKIES, CHOC MINT, MINI, GF',124185,NULL,'10857488004351','Homefree','Homefree',NULL,3,'2023-05-27','2023-11-16',NULL,'READY_TO_EAT',2662669,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Taco in a Bag Nacho 64 / 1.66 ONZ Case','ShrsTacoBagNch64/1.66OZCS',124186,NULL,'20037578619680','Shearer’s Foods LLC','Shearer''s',NULL,3,'2023-05-27','2024-08-15',NULL,'READY_TO_EAT',2700853,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Restaurant Yellow Rounds Tortilla Chips 48 / 2 ONZ Case','ShrsRestRndsTortChpsYellw48/2ozCS',124187,NULL,'20037578619703','Shearer’s Foods LLC','Shearer''s',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2718856,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s K12 White Mini Rounds 100/1oz','ShrsWhtMiniRnds100/1 ONZ',124188,NULL,'20037578619710','Shearer’s Foods LLC','Shearer''s',NULL,3,'2023-05-27','2024-08-15',NULL,'READY_TO_EAT',2700851,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Yellow Round Tortilla Chips 72 / 1.5 ONZ Case - Net Content 108 Ounces- chip, tortilla whole grain','ShearsRestRndTortYelCrn 72/1.5OZCS',124189,NULL,'20037578619727','Shearer’s Foods LLC','Shearer''s',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2718857,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s No Salt Yellow Mini Rounds 100 / 1 ONZ Case - Net Content 100 Ounces - Bite Size No Salt Tortilla Chips','ShrsNoSltYellwMiniRnds100/1 Oz',124190,NULL,'20037578619741','Shearer’s Foods LLC','Shearer''s',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719008,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s White Restaurant Round Tortilla Chips 10 / 16 ONZ Case Bulk','ShrsWhtRestRndTortChp 10/16 OZCS',124191,NULL,'20037578619765','Shearer’s Foods LLC','Shearer''s',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719025,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s No Salt Yellow Mini Round Tortilla Chips 10 / 16 ONZ Case - Bite Size Mini Round Tortillas No Salt','ShrsNoSaltYellMiniRndTort10/16 Oz',124192,NULL,'20037578619826','Shearer’s Foods LLC','Shearer''s',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719027,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Taco in a Bag Nacho 64 / 2 ONZ Case','ShrsTacoBagNch64/2OZCS',124193,NULL,'20037578620013','Shearers Foods LLC','Shearer''s',NULL,3,'2023-05-27','2023-04-27',NULL,'READY_TO_EAT',2526141,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Trail Mix, Honey Cran, IW, 2.16 oz','Zee Zees Trail Mix',124194,NULL,'20810358033971','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719211,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'621356 Zee Zees Roasted Chickpeas, Kettle Corn, 0.75oz','Kettle Corn Flavored Chickpeas',124195,NULL,'20810358034312','National Food Group','Zee Zees',NULL,3,'2023-05-27','2024-08-15',NULL,'READY_TO_EAT',2700896,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Double Chocolate Chip Mini Cookies, Gluten Free, Nut Free, 64/0.95 Oz. Bags','CKIES, DBL CHOC CHIP, MINI, GF',124196,NULL,'20857313001941','Homefree','Homefree',NULL,3,'2023-05-27','2023-08-31',NULL,'READY_TO_EAT',2614220,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Mint Mini Cookies, Gluten Free, Nut Free, 10/0.95 Oz. Bags','CKIES, CHOC MINT, MINI, GF, G & G',124197,NULL,'20857488004358','Homefree','Homefree',NULL,3,'2023-05-27','2023-08-31',NULL,'READY_TO_EAT',2614221,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Organic Ginger Snap Mini Cookies, Gluten Free, Nut Free, 30/.95 Oz. Bags','CKIES, ORG GINGER SNAP, MINI, GF',124198,NULL,'20857488004624','Homefree','Homefree',NULL,3,'2023-05-27','2023-11-16',NULL,'READY_TO_EAT',2662553,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Morningstar Farms Meal Solutions Sausage Style Crumbles','Meal Solutions',124199,NULL,'30028989102301','Kellogg Company US','Morningstar Farms',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649794,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Morningstar Farms Veggie Burgers Grillers Prime','Veggie Burgers',124200,NULL,'30028989104091','Kellogg Company US','Morningstar Farms',NULL,3,'2023-05-27','2024-03-14',NULL,'UNPREPARED',2687921,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Morningstar Farms Veggie Burgers Spicy Black Bean Child Nutrition','Veggie Burgers',124201,NULL,'30028989499388','Kellogg Company US','Morningstar Farms',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649804,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Gripz Crackers Cinnamon Grahams','Gripz Crackers',124202,NULL,'30030100456828','Kellogg Company US','Kellogg''s',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649798,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Klg Licensed Crackers Scooby-Doo Cinnamon Graham Bones','Klg Licensed Crackers',124203,NULL,'30030100506899','Kellogg Company US','Kellogg''s',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649799,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Klg Licensed Crackers Bug Bites','Klg Licensed Crackers',124204,NULL,'30030100556443','Kellogg Company US','Kellogg''s',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649800,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Gripz Crackers Chocolate Chip','Gripz Crackers',124205,NULL,'30030100807415','Kellogg Company US','Kellogg''s',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649801,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Grahams Crackers Honey Graham With Calcium','Grahams Crackers',124206,NULL,'30030100918227','Kellogg Company US','Kellogg''s',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649802,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Grahams Crackers Original','Grahams Crackers',124207,NULL,'30030100918296','Kellogg Company US','Kellogg''s',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649803,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Kellogg Cracker Brand Crunch Mania Cinnamon Bun','Kellogg Cracker Brand',124208,NULL,'30038000245184','Kellogg Company US','Kellogg''s',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649693,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Kellogg Cracker Brand Crunch Mania French Toast','Kellogg Cracker Brand',124209,NULL,'30038000245207','Kellogg Company US','Kellogg''s',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649694,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Double Chocolate Chip Mini Cookies, Gluten Free, Nut Free, 30/0.95 Oz. Bags','CKIES, DBL CHOC CHIP, MINI, GF',124210,NULL,'30857313001948','Homefree','Homefree',NULL,3,'2023-05-27','2023-11-16',NULL,'READY_TO_EAT',2662569,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Mint Mini Cookies, Gluten Free, 64 Single Serve 0.95 Oz. Bags','CKIES, CHOC MINT, MINI, GF',124211,NULL,'30857488004355','Homefree','Homefree',NULL,3,'2023-05-27','2023-11-16',NULL,'READY_TO_EAT',2662570,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Organic Ginger Snap Mini Cookies, Gluten Free, Nut Free, 64/.95 Oz. Bags','CKIES, ORG GINGER SNAP, MINI, GF',124212,NULL,'30857488004621','Homefree','Homefree',NULL,3,'2023-05-27','2023-12-21',NULL,'READY_TO_EAT',2681008,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Farmer Girl USDA Low Sodium Pinto Beans 6/10 Case','Low Sodium Pinto Beans',124213,NULL,'40028800146702','Hanover Foods Corp','Farmer Girl','100365',3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719223,'50320100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Unsweetened Apple Sauce Cups 96/4.5','Unsweetened Apple Sauce Cups',124214,NULL,'50041760091162','Cherry Central Cooperative','Cherry Central Cooperative','110361',3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719190,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 2.4 oz Soft Oatmeal Apple Bar, Individually Wrapped - Each','2.4oz oz WG Apple Oatmeal Bar, Each',124216,NULL,'00675825751903','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-05-25',NULL,'PREPARED',2539530,NULL);
INSERT INTO `cndb_fdes` VALUES (NULL,'Bean & Cheese Burrito YFT 72/4.76z','Bean & Cheese Burrito YFT 72/4.76z ',124217,NULL,'10706574675787','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703904,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'BURRITO BEAN, REDUCED FAT AMERICAN CHEESE BULK CN','Burrito Bean, RF AMER',124218,NULL,'10706574695433','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703936,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'BURRITO GRILLED CHICKEN, CHEESE, RICE IW CN','BURRITO GRILLED CHICKEN, CHEESE, ',124220,NULL,'10706574712635','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703933,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Reduced Fat & Sodium Process American Slice - 160 H - 6/5#','6/5# Y Pr Am Rd Ft/Sd 160H',124221,NULL,'10071078111353','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700600,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bean & Cheddar Cheese Burritos 36/6.75 oz','Bean & Cheddar Cheese Burritos 36/6',124222,NULL,'10706574676708','M.C.I. Foods, Inc.','CABO REAL',NULL,3,'2023-05-27','2023-05-25',NULL,'HEAT_AND_SERVE',2539538,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Egg, Cheese and Salsa Breakfast Burrito IW','Cheese & Egg Breakfast Burrito',124223,NULL,'10706574983349','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704440,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Reduced Sodium & Fat Process American Slice - 160 H - 5#','5# Y Pr Am Rd Ft/Sd 160H Sl',124224,NULL,'00071078111356','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2023-05-25',NULL,'PREPARED',2539543,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cheese Enchilada Kit with Sauce','Cheese Enchilada Kit with Sauce',124225,NULL,'10706574647029','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2023-05-27','2023-11-16',NULL,'HEAT_AND_SERVE',2662709,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Beef & American Cheese Taco Snack with Yellow Whole Wheat Flour IW','Beef & American Cheese Taco Snack',124228,NULL,'10706574946207','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704452,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Anytimers Turkey Ham & Cheese Kits','10292',124231,NULL,'00810089290557','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-05-25',NULL,'PREPARED',2539555,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'CKN/2 CHEESE BURRITO WG 96/4.65 OZ. IW','CKN/2 CHEESE BURRITO WG 96/4.65 OZ.',124233,NULL,'10706574712727','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2023-08-31',NULL,'PREPARED',2614153,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shredded Beef Chile Colorado Burrito','SHD BF CHILE COLORADO BURRITO  36/6',124234,NULL,'10706574616865','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703942,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'3 Cheese, Cooked Sausage Crumbles (Made with Turkey) & Egg Breakfast Burrito Individually Wrapped, Serving Size 6 Ounce, Individual Unit Max 36 per Case.','3 Cheese, Sausage & Egg Burrito',124235,NULL,'10706574716053','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703928,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.2 oz Soft Oatmeal Chocolate Chip Bar, Individually Wrapped - Each','1.2oz WG Choc Chip Oatmeal Bar, Eac',124236,NULL,'00675825703902','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-05-25',NULL,'PREPARED',2539563,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Egg, Cheese & Cooked Sausage Crumbles (Made with Turkey) IW','Egg, Cheese & Sausage Brkfst Wrap',124237,NULL,'10706574260341','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2025-01-23',NULL,'HEAT_AND_SERVE',2722086,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Egg/Chz/Pot/Sau/GC WRAP 72/2.50 oz Bulk','Egg/Chz/Pot/Sau/GC WRAP 72/2.50 oz ',124238,NULL,'10706574778693','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704458,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'QUESADILLA TWO CHEESE (RF CHD, RF MJ), CHICKEN, GRN CHILE IW CN','Two Chz, Ckn/GreenChile Quesadilla',124239,NULL,'10706574435619','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703975,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Egg, Cheese & Cooked Sausage Crumbles (Made with Turkey) Breakfast Wrap 72/2.50 oz IW','Egg, Cheese & Cooked Sausage Wrap I',124241,NULL,'10706574978673','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704445,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Furmanos; 6/#10 Black Beans - Brine','6/10 Blk Bns - Brine',124243,NULL,'00041188112062','Furmano Foods','Furmanos',NULL,3,'2023-05-27','2023-05-25',NULL,'UNPREPARED',2539576,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'BURRITO CHICKEN, TWO CHEESE; MOTZ & RF CHEDDAR  BULK CN','BURRITO CHICKEN, TWO CHS',124244,NULL,'10706574612737','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703970,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bean & Cheese Burritos IW 96/5.45OZ. IW','Bean & Cheese WG 96/5.45 OZ. IW',124245,NULL,'10706574934570','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704455,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'JACOBO PS MOZZ 8/6 LB AVG','JACOBO PS MOZZ 8/6 LB AVG',124247,NULL,'90070801000168','Dairy Farmers of America Inc.','DFA','100022',3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719226,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.2 oz Soft Oatmeal Strawberry Bar, Individually Wrapped - Each','1.2oz WG Strawberry Oatmeal Bar, Ea',124248,NULL,'00675825704909','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-05-25',NULL,'PREPARED',2539585,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pollo Verde Burritos','Pollo Verde Burritos',124249,NULL,'10706574616940','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703941,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'BURRITO, WHOLE GRAIN BEAN & CHEESE COOKED CHILD-NUTRITION IW FROZEN','BURRITO, WHL GRAIN BEAN & CHS IW',124250,NULL,'10706574613000','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703969,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Reduced Fat Cheddar Cheese Enchiladas Bulk','RF Cheddar Cheese Enchilada Bulk',124251,NULL,'10706574641430','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703915,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Beef Ckn Chs Taco Snack Burrito YFT 72/4.44z Bulk','Beef Ckn Chs Taco Snack Burrito YFT',124252,NULL,'10706574647814','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703897,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Furmanos; 24/15OZ Spaghetti Sauce - Low Sodium','24/15oz Spag Sauc',124253,NULL,'00041188118880','Furmano Foods','Furmanos',NULL,3,'2023-05-27','2023-05-25',NULL,'UNPREPARED',2539606,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cheese & Cooked Sausage Crumbles (Made with Turkey) with Green Chile Salsa Breakfast Burrito IW','Chs, Sausage, Green Chile Salsa Bur',124254,NULL,'10706574983752','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704464,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s 100% Tomato Juice, 5.5 fl oz Can (48 Pack)','TOMATO JUICE 6PK',124257,NULL,'10051000000078','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2023-05-27','2024-09-13',NULL,'UNPREPARED',2703838,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Ultra Bean & Cheese Burrito with Whole Wheat Flour Tortilla IW','Ultra Bean & Cheese Burrito IW',124259,NULL,'10706574715711','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703929,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bean & Two Cheeses Dip 48/3.35 oz. IW','Bean and 2 Cheeses Dip  48/3.35 oz ',124260,NULL,'10706574733425','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704140,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.2 oz Soft Oatmeal Apple Bar, Individually Wrapped - Each','1.2oz WG Apple Oatmeal Bar, Each',124261,NULL,'00675825701908','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-05-25',NULL,'PREPARED',2539622,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bean & Cheddar Cheese Organic Burrito w/o TVP Bulk Packed 48/5.75z','Bean & Cheddar Cheese Organic Burri',124262,NULL,'10706574676012','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703917,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bella Vista; 1/#10 Spaghetti Sauce - LS','10 Spag Sauc - ls',124263,NULL,'00041188847094','Furmano Foods','Bella Vista',NULL,3,'2023-05-27','2023-05-25',NULL,'UNPREPARED',2539625,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Wrap -Frozen Egg, Cheese and Turkey Sausage. Each 3.60 oz. Wrap provides 1.25 OZ EQV Meat/ Meat Alternate and 2.00 OZ EQV Grain towards the SBP, Whole Grain Rich Tortilla. CN labeled. Bulk','Burrito Bkfst Egg Tky Sausage Chs B',124264,NULL,'10706574778921','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704457,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Los Cabos Three Bean Chili Plant-based','Los Cabos Three Bean Chili',124266,NULL,'10706574733449','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704191,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'BURRITO BEAN, CHEDDAR CHS, GREEN CHILE BULK CN','BURRITO BEAN, CHS, GREEN CH',124267,NULL,'10706574675824','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703916,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'BEAN, CHEDDAR CHEESE 120/3.25oz IW','Bean, Cheddar Cheese IW',124269,NULL,'10706574133508','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703985,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 0.9 oz Mixed Berry Animal Crackers, Individually Wrapped - Each','0.9oz WG Mxd B Animal Cracker, Each',124270,NULL,'00675825724907','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-05-25',NULL,'PREPARED',2539638,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Beef Ckn Chs Taco Snack Burrito YFT 96/4.44z IW','Beef Ckn Chs Taco Snack Burrito YFT',124271,NULL,'10706574947815','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704451,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Burrito Beef & Bean 5.2 Oz Whlgrn I/W Fz','Burrito Beef & Bean 5.2 Oz IW',124273,NULL,'10706574935409','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704454,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bean & Cheese Burrito 48/5 Bulk','Bean & Cheese Burrito Bulk',124275,NULL,'10706574130507','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703986,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bean & Cheese Burritos IW','BURRITO, BEAN & CHS IW',124276,NULL,'10706574975757','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704450,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'V8 Spicy Hot 100% Vegetable Juice, 46 FL OZ Bottle (Pack of 6)','V8 HOT & SPICY',124277,NULL,'10051000206111','CAMPBELL SOUP COMPANY','V8',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2650053,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Brown Sugar Cinnamon','Pop-Tarts',124278,NULL,'30038000551223','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649697,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Fat Mont. Jack Ench WG Corn 144/2.0 oz Bulk','Red Fat Mont. Jack Enchiladas.',124279,NULL,'10706574641423','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703906,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'BEAN, CHEDDAR CHEESE 120/3.25oz IW','BEAN, CHEDDAR CHEESE IW',124280,NULL,'10706574603254','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703973,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chicken & Cheese Enchiladas Bulk','Chicken & Cheese Enchilada Bulk',124282,NULL,'10706574677798','M.C.I. Foods, Inc.','LOS CABOS',NULL,3,'2023-05-27','2023-06-29',NULL,'PREPARED',2559452,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Furmanos; 1/15OZ Tomato Sauce - Low Sodium','15oz Tomato Sauc - Low Sodium',124283,NULL,'00041188031660','Furmano Foods','Furmanos',NULL,3,'2023-05-27','2023-05-25',NULL,'UNPREPARED',2539663,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Macho Chili Beef & Chd Chs Burrito IW','Macho Chili Beef & Chd Chs IW',124286,NULL,'10706574716671','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703926,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bean & Cheese de Chile Relleno Burritos 36/7.66 oz IW','Bean & Cheese de Chile Relleno Burr',124287,NULL,'10706574716831','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703923,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'V8 Original 100% Vegetable Juice, 5.5 FL OZ Can (Pack of 6)','V8 VEG JC 5.5 6P',124289,NULL,'10051000174120','CAMPBELL SOUP COMPANY','V8',NULL,3,'2023-05-27','2023-06-29',NULL,'UNPREPARED',2559230,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'The BCR Beans Cheese Rice Burrito 64/6.55z IW','The BCR Beans Cheese Rice Burrito',124290,NULL,'10706574718835','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703920,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Reduced Fat & Sodium Process American Slice - 160 H - 6/5#','6/5# Pr Am Chs W 160H Sl',124291,NULL,'10071078111339','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700601,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shredded Beef Chile Colorado Burrito 36/6.45 OZ IW','Shd Beef Chile Colorado Burrito',124292,NULL,'10706574716862','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703922,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shredded Beef & Salsa Roja and Cheese Tamale Wrapped in a Sustainable Paper Husk','Shredded Beef Tamale',124293,NULL,'10706574997704','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704477,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cheese & Egg Green Chili Brkfst Burrito 120/3.75 IW','Chz & Egg Grn Chile Brkfst Burrito',124294,NULL,'10706574983394','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704486,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Vegan Bean and Green Chile Burrito IW','Vegan Bean and Green Chile Burrito',124295,NULL,'10706574138091','M.C.I. Foods, Inc.','LOS CABOS',NULL,3,'2023-05-27','2023-05-25',NULL,'HEAT_AND_SERVE',2539680,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pollo Verde Burrito  36/6.50 oz. IW','Pollo Verde Burrito  36/6.50 oz. IW',124296,NULL,'10706574716916','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2023-06-29',NULL,'PREPARED',2559468,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pepper Jack Cheese Enchiladas 144/2 oz. Bulk','ENCHILADA, CHS PPR JK WGR CN Bulk',124297,NULL,'10706574641508','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703905,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bean, Beef, Cheese, and Salsa Burrito IW','Bean, Beef, Cheese, and Salsa Burri',124298,NULL,'10706574713441','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703931,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Burrito Shredded Beef Green Chile Cheese Burrito IW 80/5.35z Preprinted dual ovenable film w high color graphics','Burrito Shredded Beef Green Chile C',124299,NULL,'10706574716770','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703924,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Los Cabos Taco Seasoned Impossible Plant-Based Beef Crumble Burrito','Los Cabos Impossible Beef Burrito',124300,NULL,'10706574138800','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703981,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bean & Cheese de Chile Relleno Burritos','BN/CHZ/Chile Relleno Burrito WG 36/',124301,NULL,'10706574616834','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703943,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Burrito Extrm Bean & Chse Whlgrn Flr Trtla Fz IW','Burrito, Xtreme Bean & Cheese IW',124302,NULL,'10706574716626','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703927,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Enchilada-Frozen- Cheddar Cheese only. Each 2.00 oz enchilada provides 1.00 OZ EQV Meat Alternate and 1.00 OZ EQV Grains towards the NSLP. 100% Whole Grain Corn Tortilla. CN labeled. Enchiladas are bu','Enchilada Cheddar Cheese Bulk',124303,NULL,'10706574641621','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703902,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Frosted Strawberry','Pop-Tarts',124305,NULL,'30038000551339','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649699,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cheese, Beef & Egg with Chorizo Seasoning Breakfast Wrap','Cheese, Beef & Egg Wrap.',124306,NULL,'10706574978635','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704446,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'BURRITO, BEAN & CHEESE COOKED CHILD-NUTRITION IW FROZEN','BURRITO, BEAN & CHS CKD CN IW',124307,NULL,'10706574975764','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2025-01-23',NULL,'HEAT_AND_SERVE',2723050,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Chicken, Turkey Pepperoni & Cheese','WG Chix, Turkey Pepperoni & Chees',124308,NULL,'00810089290526','Tasty Brands LLC','TASTY BRANDS',NULL,3,'2023-05-27','2023-08-31',NULL,'PREPARED',2613907,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Burrito Bf/Bean Whlgrn Bulk Fz','Beef & Bean Burritos',124309,NULL,'10706574634555','M.C.I. Foods, Inc.','CABO REAL',NULL,3,'2023-05-27','2023-05-25',NULL,'HEAT_AND_SERVE',2539705,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo Waffles Cinnamon Toast Minis','Waffles',124310,NULL,'30038000923136','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649703,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Beef, Bean, Red Chili and Textured Vegetable Protein Burrito IW','Beef, Bean, Red Chili Burrito',124312,NULL,'10706574945415','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704453,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Furmanos; 24/15OZ Tomato Sauce - Low Sodium','24/15oz Tomato Sauc - Low Sodium',124313,NULL,'00041188109789','Furmano Foods','Furmanos',NULL,3,'2023-05-27','2023-05-25',NULL,'UNPREPARED',2539712,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Reduced Sodium & Fat Process American Slice - 160 H - 4/5#','4/5# Y Pr Am Rd Ft/Sd 160H Sl',124314,NULL,'10071078110547','Bongards Creameries','Bongards',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700588,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cheese & Egg Green Chili Brkfst Burrito 72/3.75 Bulk','Cheese & Egg Grn Chili Brkfst Burri',124316,NULL,'10706574683348','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703938,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Beef & American Cheese Taco Snack Bulk','Beef & American Cheese Taco Snack B',124318,NULL,'10706574646206','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703899,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bean & Cheese Burrito YFT 96/4.76z IW','Bean & Cheese Burrito YFT 96/4.76z ',124319,NULL,'10706574975788','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704448,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Egg/Chz/Bacon Brkfst Burrito 24/3.4 oz. IW','Egg and Cheese Breakfast Burrito Fl',124321,NULL,'10706574260280','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703979,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Tomato Juice, 100% Tomato Juice, 11.5 oz Can','TOMATO JUICE',124322,NULL,'10051000012934','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2023-05-27','2023-11-16',NULL,'UNPREPARED',2662348,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Chocolate','Pop-Tarts',124323,NULL,'30038000120702','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649688,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Frosted Strawberry','Pop-Tarts',124324,NULL,'30038000551308','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649698,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Two Cheese & Green Chile Quesadilla','Two Chs & GC Quesadilla 48/4.40 OZ.',124326,NULL,'10706574452272','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703974,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bella Vista; 6/#10 Vegetarian Beans - Fancy','6/10 Vegetarian Bns - Fcy',124327,NULL,'00041188111997','Furmano Foods','Bella Vista',NULL,3,'2023-05-27','2023-05-25',NULL,'UNPREPARED',2539736,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'V8 Original 100% Vegetable Juice, 46 FL OZ Bottle (Pack of 12)','V8 VEG JUICE',124328,NULL,'10051000003369','CAMPBELL SOUP COMPANY','V8',NULL,3,'2023-05-27','2023-06-29',NULL,'UNPREPARED',2559213,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 0.9 oz Mixed Berry Animal Crackers, 4-20 Ounce Bags in Box','WG Mxd B Animal Crackers, 4-20oz BL',124329,NULL,'00675825724303','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-05-25',NULL,'PREPARED',2539741,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Los Cabos Bean & Green Chile Burrito Plant-Based Made with Fire Roasted Green Chiles','Los Cabos Bean/Green Chile Burrito',124330,NULL,'10706574138077','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703984,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Grilled Chicken & Cheese Burrito 80/5.70 oz IW','Grilled Chicken & Cheese Burrito IW',124331,NULL,'10706574712611','M.C.I. Foods, Inc.','CABO PRIMO',NULL,3,'2023-05-27','2023-06-29',NULL,'PREPARED',2559456,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Egg & Cheese Breakfast Wrap 72/ 2.5 oz IW','EGG & CHS BRFST WRAP IW',124332,NULL,'10706574978611','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704447,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Blueberry','Pop-Tarts',124333,NULL,'30038000171964','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649690,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'ENCHILADA CHICKEN, CHEESE 6" BULK CN','Chicken and Cheese Enchiladas',124335,NULL,'10706574619552','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703914,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'24/300 LAKESIDE GEN SWEET PEAS','24/300 LAKESIDE GEN SWEET PEAS',124336,NULL,'10033828000126','Lakeside Foods','LAKESIDE',NULL,3,'2023-05-27','2023-08-31',NULL,'READY_TO_EAT',2613947,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'4 Cheese Enchiladas 144/2 oz. Bulk','4 Chs Enchiladas Bulk',124337,NULL,'10706574641607','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703903,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Beef, Bean & Cheese Burrito IW','Beef, Bean & Cheese Burrito IW',124338,NULL,'10706574686608','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703937,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'BURRITO CHICKEN, TWO CHEESE; MOTZ & RF CHEDDAR IW CN','BURRITO CHICKEN, 2 CHS',124340,NULL,'10706574712734','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703932,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tamale Cheese, Grn Chile w Husk Indv Wrpd 60/5.3z Preprinted dual ovenable film w high color graphics','Cheese & Green Chile Tamale',124341,NULL,'10706574996653','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704480,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'V8 Spicy Hot 100% Vegetable Juice, 12 FL OZ Bottle','V8 VEG-SPICY HOT',124342,NULL,'10051000138023','CAMPBELL SOUP COMPANY','V8',NULL,3,'2023-05-27','2023-06-29',NULL,'UNPREPARED',2559228,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Los Cabos Shredded Beef Tamales 60ct/2.50oz Bulk Husk Only','Shredded Beef Tamale 60/4 oz Bulk',124343,NULL,'10706574994406','M.C.I. Foods, Inc.','LOS CABOS',NULL,3,'2023-05-27','2023-06-29',NULL,'PREPARED',2559493,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bean & Cheese Burritos Bulk','Bean & Cheese WG 48/5.45 OZ.',124344,NULL,'10706574634579','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703909,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Egg/Chz/Bacon Brkfst Burrito 120/3.4 oz. IW','Egg and Cheese Breakfast Burrito',124347,NULL,'10706574983363','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704461,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'ENCHILADA CHICKEN & TWO CHEESE; MOTZ & RFCHD 6" BULK CN','ENCHILADA CKN & 2 CHEESE',124349,NULL,'10706574677781','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703939,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'SpaghettiOs Original Canned Pasta, 22.4 oz Can (Pack of 12)','CPB SPAGOS',124355,NULL,'10051000212242','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2023-05-27','2024-09-13',NULL,'UNPREPARED',2703834,'50193300');
INSERT INTO `cndb_fdes` VALUES (NULL,'V8 Low Sodium Original 100% Vegetable Juice, 46 fl oz Bottle (6 Pack)','V8 LS PET',124356,NULL,'10051000206166','CAMPBELL SOUP COMPANY','V8',NULL,3,'2023-05-27','2024-09-13',NULL,'UNPREPARED',2703836,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Egg, Cheese & Cooked Sausage Crumbles (Made with Turkey) Breakfast Wrap 72/3.06 oz IW','Egg, Chs & Sausage Bkfst Wrap 72/3.',124357,NULL,'10706574978925','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704442,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chicken, Salsa Verde, Cheese Tamale','Chicken, Salsa Verde, Cheese Tamale',124358,NULL,'10706574997605','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704478,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'V8 Low Sodium Spicy Hot 100% Vegetable Juice, 46 fl oz Bottle (6 Pack)','V8 LS HOT & SPCY',124365,NULL,'10051000208078','CAMPBELL SOUP COMPANY','V8',NULL,3,'2023-05-27','2024-09-13',NULL,'UNPREPARED',2703835,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'BURRITO, BEAN & CHEESE COOKED CHILD-NUTRITION TFF BULK PACK FROZEN WHOLE GRAIN','BURRITO, BEAN & CHS CKD CN TFF',124366,NULL,'10706574675763','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703895,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'3 Cheese Enchiladas Bulk','3 Cheese Enchiladas Bulk',124367,NULL,'10706574677774','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703918,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bella Vista; 6/#10 Tomato Sauce - Low Sodium','6/10 Tomato Sauc - Low Sodium',124368,NULL,'00041188114615','Furmano Foods','Bella Vista',NULL,3,'2023-05-27','2023-05-25',NULL,'UNPREPARED',2539818,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Furmanos; 1/#10 Black Beans - Brine','10 Blk Bns - Brine',124369,NULL,'00041188047456','Furmano Foods','Furmanos',NULL,3,'2023-05-27','2023-05-25',NULL,'UNPREPARED',2539821,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chile Cheese Tamale Wrapped in Corn Husk 60/5.30 oz Bulk','Chile Cheese Tamale 60/5.30 oz Bulk',124371,NULL,'10706574996608','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704481,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Egg, Cheese, Potato & Cooked Sausage Crumbles (Made with Turkey) Breakfast Wrap IW','Egg, Cheese, Potato, Saus Breakf',124372,NULL,'10706574978697','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704444,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Chocolate','Pop-Tarts',124373,NULL,'30038000120733','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649689,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'V8 Original 100% Vegetable Juice, 11.5 FL OZ Can','V8 JUICE',124374,NULL,'00051000153159','CAMPBELL SOUP COMPANY','V8',NULL,3,'2023-05-27','2023-05-25',NULL,'UNPREPARED',2539842,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Beef & Bean Burrito IW 96/5.2oz','Beef & Bean Burrito IW 96/5.2oz',124377,NULL,'10706574935461','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2023-05-27','2023-06-29',NULL,'PREPARED',2559476,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'V8 Original 100% Vegetable Juice, 5.5 FL OZ Can (8 Packs of 6 Cans)','V8 VEG JUICE 6PK',124378,NULL,'10051000000207','CAMPBELL SOUP COMPANY','V8',NULL,3,'2023-05-27','2023-06-29',NULL,'UNPREPARED',2559212,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'6/10 LAKESIDE PEAS','PEAS',124379,NULL,'10033828006166','Lakeside Foods Inc.','LAKESIDE FOODS','100315',3,'2023-05-27','2023-10-26',NULL,'READY_TO_EAT',2650080,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Two Cheese, Chicken and Green Chile Quesadilla IW','Two Chz, Chicken & GC Quesadilla 48',124380,NULL,'10706574435602','M.C.I. Foods, Inc.','CABO PRIMO',NULL,3,'2023-05-27','2023-08-31',NULL,'PREPARED',2614149,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Signature Frozen Condensed Healthy Request Portobello Mushroom and Barley Soup, 4 Pound Trays, 3-Pack','FS V8 VG MSHRM BRL',124381,NULL,'00051000153579','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2023-05-27','2023-05-25',NULL,'UNPREPARED',2539850,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 2.4 oz Soft Oatmeal Blueberry Bars, Individually Wrapped - Each','2.4oz WG Blueberry Bar, Each',124382,NULL,'00675825756908','Darlington Cookie Company','Appleways',NULL,3,'2023-05-27','2023-05-25',NULL,'PREPARED',2539853,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Burrito Bf/Bean/Tvp Whlgrn 5.2 Oz Bulk Fz','Burrito Bf/Bean/Tvp Whlgrn Bulk',124383,NULL,'10706574635408','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703907,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chicken Tenders & Cheese Wrap 96/3.80 oz. IW','Chicken Tender & Chs Wrap 96/3.8OZ',124384,NULL,'10706574710129','M.C.I. Foods, Inc.','CABO PRIMO',NULL,3,'2023-05-27','2023-08-31',NULL,'PREPARED',2614152,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Two Cheese and Green Chile Quesadilla IW','Two Chs & GC Quesadilla 60/2.2 OZ. ',124386,NULL,'10706574431079','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703976,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bella Vista; 6/#10 Spaghetti Sauce - LS','6/10 Spag Sauc - ls',124387,NULL,'00041188112048','Furmano Foods','Bella Vista',NULL,3,'2023-05-27','2023-05-25',NULL,'UNPREPARED',2539858,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bean Chd Chs Bur Bulk 48/4.8oz','Bean Chd Chs Bur Bulk 48/4.8oz',124390,NULL,'10706574643458','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703900,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Furmanos; 1/15OZ Spaghetti Sauce - Low Sodium','15oz Spag Sauc',124391,NULL,'00041188032612','Furmano Foods','Furmanos',NULL,3,'2023-05-27','2023-05-25',NULL,'UNPREPARED',2539865,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Beef, Bean and Red Chili Burritos Bulk','Beef, Bean and Red Chili Burritos B',124393,NULL,'10706574634562','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703910,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'En Fuego Bean & Cheese Burrito 80/6.05 oz IW','En Fuego Bean & Cheese Burrito IW',124394,NULL,'10706574714714','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703930,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Burrito Southwest Black Bean & Cheese Burrito IW 80/6.05z Preprinted dual ovenable film w high color graphics','Burrito Southwest Black Bean & Chee',124397,NULL,'10706574716749','M.C.I. Foods, Inc.','Cabo Primo',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703925,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Two Cheese & Green Chile Tamale','Two Cheese & Green Chile Tamale',124398,NULL,'10706574997506','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704479,'50230100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Beef & Cheese Taco Snack','Beef & Cheese Taco Snack',124399,NULL,'10706574634609','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703908,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Egg, Cheese & Cooked Sausage Crumbles (Made with Turkey) Breakfast Wrap IW','Eggs, Chz, Sausage, Brkfs Wrap',124400,NULL,'10706574978918','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704443,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'BURRITO, WHOLE GRAIN BEAN & CHEESE COOKED CHILD-NUTRITION BULK FROZEN f3','BURRITO, WHL GRAIN BEAN&CHS Bulk f1',124403,NULL,'10706574643410','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703901,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bella Vista; 1/#10 Tomato Sauce - Low Sodium','10 Tomato Sauc - Low Sodium',124405,NULL,'00041188841634','Furmano Foods','Bella Vista',NULL,3,'2023-05-27','2023-05-25',NULL,'UNPREPARED',2539893,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cheese, Egg, & Cooked Sausage Crumbles (Made with Turkey) Breakfast Burrito IW','Cheese,Egg,&Cooked Sausage Crumbles',124406,NULL,'10706574983370','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2704463,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'ENCHILADA, BEEF CHILD-NUTRITION FROZEN BULK PACK','Beef Enchiladas',124408,NULL,'10706574618531','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703940,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Peterson Farms Treats Applesauce','Unsw Strawberry Banana Applesauce',124409,NULL,'10882266100673','Peterson Farms Fresh, Inc.','Peterson Farms Treats',NULL,3,'2023-05-27','2023-05-25',NULL,'READY_TO_EAT',2539898,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pollo Verde Burrito','Pollo Verde Burrito',124411,NULL,'10706574716947','M.C.I. Foods, Inc.','LOS CABOS',NULL,3,'2023-05-27','2024-09-13',NULL,'HEAT_AND_SERVE',2703921,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fried Over Easy Egg Patty, 390/1.4 oz., Frozen, Bulk','Frd EGG PATTIE',124448,NULL,'10038057303451','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-07-11',NULL,'PREPARED',2696403,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain French Toast Sticks, 3-Scored, 130/2.65 oz., Frozen, Bulk, K12','WG FRTST STK, 3Score',124449,NULL,'10038057404325','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700928,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Cinnamon Glazed French Toast, 130/2.9 oz., Frozen, Bulk','WG FR TST, CINN GLZ',124450,NULL,'10038057404905','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700927,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Cinnamon Glazed French Toast Sticks, 3-Scored, 110/2.9 oz., Frozen, Individually Wrapped','WG FRTST, CINNGLZ, 3Sd, IndWrp',124452,NULL,'10038057404943','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-05-16',NULL,'PREPARED',2689630,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Cinnamon Glazed French Toast Sticks, 100/2.9 oz., Frozen, Bulk','WG FR TST STK, CINN GLZ',124453,NULL,'10038057404974','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700548,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Honey Wheat Ranch Yeast Roll Dough, Tray Pack (Whole Grain) 6152','Wheat Roll Dgh',124455,NULL,'10047500002605','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719644,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Cracked Wheat Honey Roll Dough, Layer Pack (Whole Grain) 6755','Wheat Rll Dgh',124456,NULL,'10047500003787','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-08-15',NULL,'PREPARED',2700563,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Buttermilk Biscuit Dough, Bag Pack 6169','Bisc heat and serv',124457,NULL,'10047500007969','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'BAKE',2719651,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford Honey Wheat Cinnamon Roll Dough, Layer Pack (Whole Grain) 6718','Wheat Cin Rll',124458,NULL,'10047500010778','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719652,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford White Whole Wheat Honey Roll Dough, Layer Pack (Whole Grain) 6737','White Wheat Roll',124459,NULL,'10047500012512','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2719291,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford White Whole Wheat Sheet Dough, Layer Pack (Whole Grain) 6729','Sheet Dough',124460,NULL,'10047500013960','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718928,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford White Whole Wheat Cinnamon Roll Dough, Layer Pack (Whole Grain) 6719','Cinn Rll Dgh',124461,NULL,'10047500014318','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718930,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford White Whole Wheat Cheesy Garlic Breadstick Dough, Layer Pack (Whole Grain) 6787','Brd Stick',124462,NULL,'10047500015155','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2024-12-19',NULL,'PREPARED',2718932,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bridgford White Whole Wheat Honey Roll Dough (Whole Grain), 6734','White Wheat Roll',124463,NULL,'10047500015841','BRIDGFORD FOODS CORPORATION','BRIDGFORD',NULL,3,'2023-05-27','2025-04-24',NULL,'PREPARED',2730213,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Yellow Round Tortilla  WG Masa Chips 10/1 LBR (16 ONZ)','Shrs YellowRndTort10/1LBR (16 ONZ)',124464,NULL,'20037578619796','Shearer’s Foods LLC','Shearer''s',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719026,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Wild Watermelon, 4.5 oz.','Wild Watermelon Applesauce',124465,NULL,'20810358030239','National Food Group  Inc.','Zee Zees',NULL,3,'2023-05-27','2024-12-19',NULL,'READY_TO_EAT',2719204,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Cheez It Crackers Whole Grain','Cheez-It Crackers',124466,NULL,'30024100104803','Kellogg Company US','Kellogg''s Cheez It',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649792,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Cheez It Crackers Whole Grain','Cheez-It Crackers',124467,NULL,'30024100792635','Kellogg Company US','Kellogg''s Cheez It',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2649793,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Mini-Wheats Cereal Bite Size Frosted','Mini-Wheats Cereal',124468,NULL,'30038000049966','WK KELLOGG CO','Kellogg''s',NULL,3,'2023-05-27','2023-11-16',NULL,'UNPREPARED',2662559,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Frosted Flakes Cereal Multi Grain','Frosted Flakes Cereal',124469,NULL,'30038000114657','WK KELLOGG CO','Kellogg''s',NULL,3,'2023-05-27','2023-11-16',NULL,'UNPREPARED',2662574,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Froot Loops Cereal Reduced Sugar','Froot Loops Cereal',124470,NULL,'30038000114671','WK KELLOGG CO','Kellogg''s',NULL,3,'2023-05-27','2023-11-16',NULL,'UNPREPARED',2662560,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Apple Jacks Cereal Reduced Sugar','Apple Jacks Cereal',124471,NULL,'30038000114695','WK KELLOGG CO','Kellogg''s',NULL,3,'2023-05-27','2023-11-16',NULL,'UNPREPARED',2662561,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Rice Krispies Treats Squares Whole Grain','Rice Krispies Treats Squares',124472,NULL,'30038000145408','Kellogg Company US','Kellogg''s',NULL,3,'2023-05-27','2023-10-26',NULL,'UNPREPARED',2651414,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Frosted Flakes Cereal Multi Grain','Frosted Flakes Cereal',124473,NULL,'30038000241858','WK KELLOGG CO','Kellogg''s',NULL,3,'2023-05-27','2023-11-16',NULL,'UNPREPARED',2662562,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Frosted Flakes Cereal Multi Grain Cinnamon','Frosted Flakes Cereal',124474,NULL,'30038000241964','WK KELLOGG CO','Kellogg''s',NULL,3,'2023-05-27','2023-11-16',NULL,'UNPREPARED',2662563,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Mini-Wheats Cereal Frosted','Mini-Wheats Cereal',124475,NULL,'30038000270957','WK KELLOGG CO','Kellogg''s',NULL,3,'2023-05-27','2023-11-16',NULL,'UNPREPARED',2662564,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Frosted Flakes Cereal Reduced Sugar','Frosted Flakes Cereal',124476,NULL,'30038000549985','WK KELLOGG CO','Kellogg''s',NULL,3,'2023-05-27','2023-11-16',NULL,'UNPREPARED',2662565,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Frosted Flakes Cereal Multi Grain Cinnamon','Frosted Flakes Cereal',124477,NULL,'30038000787868','WK KELLOGG CO','Kellogg''s',NULL,3,'2023-05-27','2023-11-16',NULL,'UNPREPARED',2662566,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Apple Jacks Cereal Reduced Sugar','Apple Jacks Cereal',124478,NULL,'30038000787875','WK KELLOGG CO','Kellogg''s',NULL,3,'2023-05-27','2023-11-16',NULL,'UNPREPARED',2662567,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Froot Loops Cereal Reduced Sugar','Froot Loops Cereal',124479,NULL,'30038000787882','WK KELLOGG CO','Kellogg''s',NULL,3,'2023-05-27','2023-11-16',NULL,'UNPREPARED',2662568,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fully Cooked, Turkey Breast and Thigh Pot Roast, K-12','SBF fz F/C Tky Pot Rst Wh/Dk',124480,NULL,'90642205702674','Cargill Incorporated/Honeysuckle White','Shady Brook Farms',NULL,3,'2023-05-27','2023-10-26',NULL,'PREPARED',2651413,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Organic Ginger Snap Mini Cookies, Gluten Free, Grab & Go, 10/0.95 Oz. Tray','CKIES,ORG GINGER SNAP,MINI,GF,G&G',124483,NULL,'10857488004627','Homefree','Homefree',NULL,3,'2023-05-27','2023-12-21',NULL,'READY_TO_EAT',2681006,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Morningstar Farms Poultry Chikn Nuggets','Poultry',124484,NULL,'30028989977626','Kellogg Company US','Morningstar Farms',NULL,3,'2023-05-27','2024-02-01',NULL,'UNPREPARED',2683367,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.2 oz Soft Oatmeal Strawberry Bars, Individually Wrapped - 216ct','1.2oz WG Strawberry Oatmeal Bars, I',124485,NULL,'00675825704008','Darlington Cookie Company','Appleways',NULL,3,'2024-01-22','2023-05-25',NULL,'PREPARED',2539537,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.2 oz Soft Oatmeal Chocolate Chip Bars, Individually Wrapped - 216ct','1.2oz WG Choc Chip Oatmeal Bars, IW',124486,NULL,'00675825703001','Darlington Cookie Company','Appleways',NULL,3,'2024-01-22','2023-05-25',NULL,'PREPARED',2539541,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 0.9 oz Mixed Berry Animal Crackers, Individually Wrapped - 108ct','0.9oz WG Mxd B Animal Crackers, IW',124487,NULL,'00675825724006','Darlington Cookie Company','Appleways',NULL,3,'2024-01-22','2023-05-25',NULL,'PREPARED',2539824,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Appleways Whole Grain 1.2 oz Soft Oatmeal Apple Bars, Individually Wrapped - 216ct','1.2oz WG Apple Oatmeal Bars, IW',124488,NULL,'00675825701007','Darlington Cookie Company','Appleways',NULL,3,'2024-01-22','2023-05-25',NULL,'PREPARED',2539838,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Libby''s Frozen Supersweet Corn - 40oz','FZ CORN CT',124489,NULL,'00037100037018','Seneca Foods Corp','Libby''s','111053',3,'2024-01-22','2023-06-29',NULL,'PREPARED',2556099,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stokely''s Pumpkin 15oz','PUMPKIN',124490,NULL,'00070222029721','Seneca Foods Corp','STOKELY''S','100319',3,'2024-01-22','2023-06-29',NULL,'PREPARED',2557450,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Libby''s Frozen Whole Kernel Cut Corn - 12 Pack, 40oz Bags','FZ CORN CT',124491,NULL,'10037100836175','Seneca Foods Corp','Libby''s','111053',3,'2024-01-22','2023-06-29',NULL,'PREPARED',2558815,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Round Scrambled Egg Patty','Round Scrambled',124493,NULL,'10786294406397','Echo Lake Foods','Echo Lake Foods','110931',3,'2024-01-22','2024-12-19',NULL,'PREPARED',2718860,'50193500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Reduced Fat Pepperoni Calzone','WG RF Turkey Pepperoni Calzone',124495,NULL,'00711341507218','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2024-01-22','2023-08-31',NULL,'UNPREPARED',2613845,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Animal Crackers','Animal Crackers WG',124496,NULL,'10693392003314','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2025-03-20',NULL,'PREPARED',2724482,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Beef & Bean Burrito IW 96/5.2oz','Beef & Bean Burrito IW 96/5.2oz',124497,NULL,'10706574934563','M.C.I. Foods, Inc.','Cabo Real',NULL,3,'2024-01-22','2024-09-13',NULL,'HEAT_AND_SERVE',2704456,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Cherry Granola Bakes WG','Chocolate Cherry Granola Bakes WG',124498,NULL,'10693392007275','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2025-03-20',NULL,'PREPARED',2724487,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Oatmeal Cranberry Granola Bakes WG','Oatmeal Cranberry Granola Bakes WG',124499,NULL,'10693392007299','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2025-03-20',NULL,'PREPARED',2724489,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Plant-based Southwest-style Crumbles,  2.5 LB Bag - Qty 4','Southwest Style Plant Crumbles',124505,NULL,'10642205046468','Cargill Incorporated/Honeysuckle White','Crave House',NULL,3,'2024-01-22','2024-07-11',NULL,'UNPREPARED',2696677,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fully Cooked Ground Beef Patties, 2.2 oz., K12','FZ Ckd CN Bf Pty 2.2oz',124506,NULL,'10642205009296','Cargill Incorporated/Honeysuckle White','Cargill','110711',3,'2024-01-22','2023-10-26',NULL,'PREPARED',2649526,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breakfast Kit RS Trix','Choco Cherry Granola B w/Applesauce',124507,NULL,'10693392007374','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2023-10-26',NULL,'PREPARED',2649560,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kit Oatmeal Cranberry Granola Bakes','Kit Oatmeal Cranberry Granola Bakes',124508,NULL,'10693392007404','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2024-05-16',NULL,'PREPARED',2689931,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fully Cooked Diced Chicken IF','TYS FC DI WH DK CKN .5" IF',124509,NULL,'10715001015171','Tyson Foods Inc.','Tyson','100101',3,'2024-01-22','2025-03-20',NULL,'UNPREPARED',2724493,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'IW Pancake Sandwich with Glaze','IW Pancake Stacker',124510,NULL,'10693392003123','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2024-05-16',NULL,'PREPARED',2690002,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cinnamon Mini Animal Grahams','Cinnamon Mini Animal Grahams',124511,NULL,'10693392003321','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2025-03-20',NULL,'PREPARED',2724483,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stuffed Crust, Pepperoni, Reduced Fat, 4.87 oz','MAX NON WG STFD CRST PEPP 72/4.87Z',124512,NULL,'10077387124084','Conagra Brands, Inc','The MAX',NULL,3,'2024-01-22','2024-11-14',NULL,'BAKE',2717303,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'THE MAX Stuffed Crust Pepperoni Pizza Slice, 4.87 OZ','MAX NON WG STFD CRST PEPP 72/4.87Z',124513,NULL,'50077387124082','Conagra Brands, Inc','The MAX',NULL,3,'2024-01-22','2023-10-26',NULL,'BAKE',2649687,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bean Dipz Cup, Original, 4.5 oz.','Bean Dipz',124514,NULL,'20810358032509','National Food Group  Inc.','Zee Zees',NULL,3,'2024-01-22','2024-12-19',NULL,'READY_TO_EAT',2719208,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Very Strawberry, 4.5 oz.','Very Strawberry Applesauce',124515,NULL,'20810358030222','National Food Group  Inc.','Zee Zees',NULL,3,'2024-01-22','2024-12-19',NULL,'READY_TO_EAT',2719203,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Fruit Cup, Apple, Diced, Cinnamon, 4.5oz','Diced Apple Fruit Cup, Cinnamon',124516,NULL,'20810358035111','National Food Group  Inc.','Zee Zees',NULL,3,'2024-01-22','2024-08-15',NULL,'READY_TO_EAT',2700917,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Soft Baked Bar, Birthday Cake, 1.3 oz','Birthday Cake Soft Baked Bar',124517,NULL,'20810358034404','National Food Group  Inc.','Zee Zees',NULL,3,'2024-01-22','2024-12-19',NULL,'READY_TO_EAT',2719215,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Grahamz, Original, IW, WG, 1oz','Original Grahamz',124518,NULL,'20854114007066','National Food Group','Zee Zees',NULL,3,'2024-01-22','2024-08-15',NULL,'READY_TO_EAT',2700916,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Half Popped Popcorn, Salted, 1.28oz','Half Popped Corn',124519,NULL,'20810358035012','National Food Group  Inc.','Zee Zees',NULL,3,'2024-01-22','2024-08-15',NULL,'READY_TO_EAT',2700923,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Half Popped Popcorn, Salsa, 1.28oz','Half Popped Corn, Salsa',124520,NULL,'20810358035029','National Food Group  Inc.','Zee Zees',NULL,3,'2024-01-22','2024-08-15',NULL,'READY_TO_EAT',2700922,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Half Popped Popcorn, Cocoa Churro, 1.28oz','Half Popped Corn, Cocoa Churro',124521,NULL,'20810358035036','National Food Group  Inc.','Zee Zees',NULL,3,'2024-01-22','2024-08-15',NULL,'READY_TO_EAT',2700921,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Roasted Fava Bean Crisps, Buffalo Ranch 1.50oz','Fava Bean Crips, Buffalo Ranch',124522,NULL,'20810358035050','National Food Group  Inc.','Zee Zees',NULL,3,'2024-01-22','2024-07-11',NULL,'READY_TO_EAT',2696485,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Roasted Fava Bean Crisps, Churro 1.50oz','Fava Bean Crisps, Churro',124523,NULL,'20810358035067','National Food Group  Inc.','Zee Zees',NULL,3,'2024-01-22','2024-08-15',NULL,'READY_TO_EAT',2700926,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Vegetable Beef with Barley Soup, 4 Pound Trays, 3-Pack','CUL RES VEG BF',124527,NULL,'10051000081633','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-01-22','2024-07-11',NULL,'UNPREPARED',2696195,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Vegetarian Minestrone Soup, 4 Pound Trays, 3-Pack','CUL RES MINESTRN',124528,NULL,'10051000081671','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-01-22','2024-07-11',NULL,'UNPREPARED',2696197,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Homestyle Chicken Noodle Soup, 4 Pound Trays, 3-Pack','CUL RES HS CKN NDL',124529,NULL,'10051000081695','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-01-22','2024-07-11',NULL,'UNPREPARED',2696198,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Italian-Style Wedding Soup, 4 Pound Trays, 3-Pack','CUL RES ITL WED SOUP',124530,NULL,'10051000104288','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-01-22','2023-10-26',NULL,'UNPREPARED',2650055,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Pasta Fagioli Soup, 4 Pound Trays, 3-Pack','CUL RES PSTA FAGIOLI',124531,NULL,'10051000104295','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-01-22','2024-07-11',NULL,'UNPREPARED',2696200,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Healthy Request Chicken with Egg Noodles Soup, 4 Pound Trays, 3-Pack','CUL RES HR CKN W EGG NDL',124532,NULL,'10051000191219','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-01-22','2024-07-11',NULL,'UNPREPARED',2696206,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Healthy Request Mexican-Style Chicken Tortilla Soup, 4 Pound Trays, 3-Pack','CUL RES HR MEX CKN TORTLA',124533,NULL,'10051000191226','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-01-22','2024-12-19',NULL,'UNPREPARED',2718953,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Healthy Request Homestyle Sweet Pepper and Beef Soup, 4 Pound Trays, 3-Pack','CUL RES W&G CTRY SWT PEP&BF',124551,NULL,'10051000142235','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-01-22','2024-07-11',NULL,'UNPREPARED',2696202,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'MEAL, BLUEBERRY YOGURT KIT REF BREAKFAST BREAK','Refrigerated Kit Blueberry Yogurt',124552,NULL,'10693392000443','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2024-05-16',NULL,'PREPARED',2689978,'50193500');
INSERT INTO `cndb_fdes` VALUES (NULL,'TSMB WG Crustless Cocoa CPB Sandwich','TSMB WG Crustless Cocoa CPB Sand.',124553,NULL,'10693392006940','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2023-10-26',NULL,'PREPARED',2651426,'50193800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Blueberry Pomegra Granola Bakes WG','Blueberry Pomegra Granola Bakes WG',124554,NULL,'10693392007282','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2025-03-20',NULL,'PREPARED',2724488,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Apple Cinnamon','Nutri-Grain Cereal Bars',124555,NULL,'30038000356453','Kellogg Company US','Kellogg''s',NULL,3,'2024-01-22','2023-10-26',NULL,'UNPREPARED',2651429,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Blueberry','Nutri-Grain Cereal Bars',124556,NULL,'30038000357450','Kellogg Company US','Kellogg''s',NULL,3,'2024-01-22','2023-10-26',NULL,'UNPREPARED',2651430,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Raspberry','Nutri-Grain Cereal Bars',124557,NULL,'30038000358457','Kellogg Company US','Kellogg''s',NULL,3,'2024-01-22','2023-10-26',NULL,'UNPREPARED',2651431,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Strawberry','Nutri-Grain Cereal Bars',124558,NULL,'30038000359454','Kellogg Company US','Kellogg''s',NULL,3,'2024-01-22','2023-10-26',NULL,'UNPREPARED',2651432,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Mixed Fruit, 4.5 oz.','Mixed Fruit Cup',124569,NULL,'20810358030192','National Food Group  Inc.','Zee Zees',NULL,3,'2024-01-22','2024-12-19',NULL,'READY_TO_EAT',2719201,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Fruit Cup, Apple, Diced, Original, 4.5oz','Diced Apples Fruit Cup',124570,NULL,'20810358035104','National Food Group  Inc.','Zee Zees',NULL,3,'2024-01-22','2024-08-15',NULL,'READY_TO_EAT',2700919,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'C/E Beef UnDrnd Chili w/oBn 6/5# 30#','C/E Beef UnDrnd Chili w/oBn',124571,NULL,'20049485053334','JTM Food Group','JTM Food Group',NULL,3,'2024-01-22','2024-08-15',NULL,'PREPARED',2700800,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Broccoli & Cheese Soup 30# 6 Bags','Broccoli & Cheese Soup',124574,NULL,'00049485051145','JTM Food Group','JTM Food Group',NULL,3,'2024-01-22','2025-01-23',NULL,'PREPARED',2722055,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Reduced Fat Chocolate Chip Cookie Dough','WG RF Sugar Cooke Dough',124575,NULL,'00711341788150','Buena Vista Food Products','Buena Vista Foods',NULL,3,'2024-01-22','2023-11-16',NULL,'UNPREPARED',2663365,'50181700');
INSERT INTO `cndb_fdes` VALUES (NULL,'CE Beef Taco 6/5# 30#','CE Beef Taco',124576,NULL,'20049485052580','JTM Food Group','JTM Food Group',NULL,3,'2024-01-22','2024-08-15',NULL,'PREPARED',2700796,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sugar Frozen Cookie Dough Made with Whole Grain','Sugar Cookies Made With Whole Grain',124577,NULL,'10013087556848','ASPIRE BAKERIES','Otis Spunkmeyer',NULL,3,'2024-01-22','2023-12-21',NULL,'UNPREPARED',2680797,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'FC Turkey Breakfast Sausage Patties - CN','FC Turkey Sausage Patties-CN',124578,NULL,'90022655307733','Butterball, LLC','BUTTERBALL',NULL,3,'2024-01-22','2025-03-20',NULL,'PREPARED',2724422,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'HAM, TURKEY SMOKED FLAVOR COOKED FROZEN SLICED','Sliced Turkey Ham, Frozen',124579,NULL,'90022655639025','Butterball, LLC','BUTTERBALL',NULL,3,'2024-01-22','2024-08-15',NULL,'PREPARED',2700872,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'TURKEY, COMBO HAM BOLOGNA SALAMI .5 OZ','TURKEY, COMBO HAM BOLO SALMI',124580,NULL,'90022655695021','Butterball, LLC','BUTTERBALL',NULL,3,'2024-01-22','2024-08-15',NULL,'UNPREPARED',2700865,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Ground Turkey 20#; Clipless packaging','Ground Turkey 2/10 #',124581,NULL,'90022655700121','Butterball, LLC','Butterball',NULL,3,'2024-01-22','2025-03-20',NULL,'UNPREPARED',2724421,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'HAM, TURKEY 20% WATER-ADDED COOKED FROZEN','Turkey Ham, Frozen',124582,NULL,'90022655825305','Butterball, LLC','CAROLINA TURKEY',NULL,3,'2024-01-22','2024-08-15',NULL,'UNPREPARED',2700863,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'TURKEY, DICED CURED','Diced Cured Dark Turkey',124583,NULL,'90022655829228','Butterball, LLC','BUTTERBALL',NULL,3,'2024-01-22','2025-03-20',NULL,'PREPARED',2724420,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Thick Sliced Turkey Breast','Thick Sliced Turkey Breast',124584,NULL,'90022655852004','Butterball, LLC','BUTTERBALL',NULL,3,'2024-01-22','2024-11-14',NULL,'PREPARED',2717158,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SAUSAGE, TURKEY LINK BREAKFAST 22-24:1 MILD COOKED CHILD-NUTRITION BREAKFAS','SAUSAGE, TRKY LNK BKFST',124585,NULL,'90022655306767','Butterball, LLC','BUTTERBALL',NULL,3,'2024-01-22','2025-03-20',NULL,'PREPARED',2724505,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Ready to Cook Turkey Breast Roast','Frozen RTC Turkey Breast Roast',124586,NULL,'90022655891041','Butterball, LLC','Butterball',NULL,3,'2024-01-22','2024-05-16',NULL,'FREEZE',2690070,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sliced Turkey Ham','Sliced Turkey Ham',124587,NULL,'90022655892024','Butterball, LLC','BUTTERBALL',NULL,3,'2024-01-22','2023-12-21',NULL,'PREPARED',2680910,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sliced Turkey Variety Pack','Sliced Turkey Variety Pack',124588,NULL,'90022655892031','Butterball, LLC','BUTTERBALL',NULL,3,'2024-01-22','2025-04-24',NULL,'PREPARED',2730518,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Turkey Thigh Roast Frozen','Turkey Thigh Roast Frozen',124589,NULL,'90022655892048','Butterball, LLC','BUTTERBALL',NULL,3,'2024-01-22','2024-08-15',NULL,'UNPREPARED',2700860,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Frozen Turkey Franks','All Natural Turkey Frank 6"',124590,NULL,'90022655892062','Butterball, LLC','BUTTERBALL',NULL,3,'2024-01-22','2024-10-31',NULL,'UNPREPARED',2716149,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fullly Cooked Breakfast Sausage LInks','FC AN Breakfast Sausage Links',124591,NULL,'90022655892079','Butterball LLC','Butterball',NULL,3,'2024-01-22','2024-08-15',NULL,'HEAT_AND_SERVE',2700859,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breakfast Sausage Patty','FC AN Breakfast sausage patty',124592,NULL,'90022655892086','Butterball LLC','Butterball',NULL,3,'2024-01-22','2024-05-16',NULL,'HEAT_AND_SERVE',2690087,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Turkey Tenderloin Medallions, 6/5 pound packages','Turkey Tenderloin Medallions',124593,NULL,'90022655892093','Butterball, LLC','Butterball',NULL,3,'2024-01-22','2025-04-24',NULL,'UNPREPARED',2730519,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sliced Turkey Breast','Sliced Turkey Breast',124594,NULL,'90022655892017','Butterball, LLC','BUTTERBALL',NULL,3,'2024-01-22','2024-08-15',NULL,'PREPARED',2700861,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Roasted Fava Bean Crisps, Pizza 1.50oz','Fava Bean Crisps, Pizza',124595,NULL,'20810358035043','National Food Group  Inc.','Zee Zees',NULL,3,'2024-01-22','2024-08-15',NULL,'READY_TO_EAT',2700920,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Oatmeal Real Medley Apple Walnut Cup 2.46z/12','QOM ApWN 2.46z/12',124598,NULL,'10030000315504','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2024-01-22','2023-12-21',NULL,'UNPREPARED',2680924,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'QUAKER OATMEAL STEEL CUT REGULAR  25Z /12','QOM SC REG  25Z /12',124599,NULL,'10030000320935','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2024-01-22','2023-12-21',NULL,'UNPREPARED',2680925,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Oatmeal Steam Table Kettle Hearty Oats  REGULAR 47Z12PK/12','QOM ST REG   47Z12PK',124600,NULL,'10030000432690','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2024-01-22','2023-12-21',NULL,'UNPREPARED',2680926,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'QUAKER OATMEAL QUICKOATS REGULAR   42Z/12','QOM QKO REG   42Z/12',124601,NULL,'10030000432850','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2024-01-22','2023-12-21',NULL,'UNPREPARED',2680927,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'QUAKER OATMEAL OLDFASHION REGULAR   42Z/12','QOM OF REG   42Z/12',124602,NULL,'10030000432935','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2024-01-22','2023-12-21',NULL,'UNPREPARED',2680929,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'SFS TONY''S FRENCH BREAD WG GARLIC CHEESE 100% NET WT 16.09LBS 60CT CN','TN FB CHSY GAR',124603,NULL,'10072180687248','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2024-01-22','2024-12-19',NULL,'UNPREPARED',2718996,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Lay''s Baked Potato Crisps BBQ 1.125oz/64','LAY''S BAR-B-QUE',124604,NULL,'00028400443951','Pepsi-Cola US','Lay''s',NULL,3,'2024-01-22','2023-12-21',NULL,'UNPREPARED',2681014,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'CN Turkey Franks','Turkey Frank CN 8/1',124611,NULL,'90022655892123','Butterball LLC','Butterball',NULL,3,'2024-01-22','2024-10-31',NULL,'HEAT_AND_SERVE',2716148,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Slice-N-Tact Golden Roasted Turkey Breast','SNT Oil Browned Turkey Breast',124612,NULL,'90074308897023','Butterball, LLC','BUTTERBALL',NULL,3,'2024-01-22','2025-03-20',NULL,'UNPREPARED',2724339,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fritos Corn Chips Regular 16 Oz','Fritos Corn Chips Regular 16 Oz,8Ct',124622,NULL,'00028400122481','PepsiCo Inc. Brand Owner','Fritos',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2681972,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'V8 Splash Tropical Blend Flavored Juice Beverage, 12 fl oz Bottle (12 Pack)','V8 SPL TROP BLD',124626,NULL,'10051000283440','CAMPBELL SOUP COMPANY','V8',NULL,3,'2024-01-22','2024-07-11',NULL,'UNPREPARED',2696282,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Land O Lakes American Cheese Slices, White, 160','4/5# LOL FS PPAC W 40R 160 SL',124627,NULL,'10034500460320','LAND O''LAKES','LAND O LAKES',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2682366,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Land O Lakes 25% RS, 50% RF American, Slices, Yellow, 160','4/5# LOLFS PPAC Y 25RS50RF 160',124628,NULL,'10034500460313','LAND O''LAKES','LAND O LAKES',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2682367,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Land O Lakes  Reduced Fat American, Slices, Yellow, 160','4/5# LOLFS PPAC Y 50RF 40R 160',124629,NULL,'10034500460306','LAND O''LAKES','LAND O LAKES',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2682368,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Land O Lakes 50% Reduced Sodium, 50% Reduced Fat American,Slices, Yellow, 160','4/5# LOLFS PPAC Y 50RS50RF 160',124630,NULL,'10034500460184','LAND O''LAKES','LAND O LAKES',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2682369,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Land O Lakes American, Slices, Yellow, 160','4/5# LOL FS PPAC Y 40R 160 SL',124631,NULL,'10034500460160','LAND O''LAKES','LAND O LAKES',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2682370,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Land O Lakes American Cheese, Slices, Yellow, 184','4/5# LOL FS PPAC Y 46R 184 SL',124632,NULL,'10034500460153','LAND O''LAKES','LAND O LAKES',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2682371,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo Waffles Maple','Waffles',124633,NULL,'30038000923150','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2682474,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Blueberry','Nutri-Grain Cereal Bars',124634,NULL,'30038000908195','Kellogg Company US','Kellogg''s',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2682475,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo French Toast Original French Toast Minis','French Toast',124635,NULL,'30038000806934','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2682476,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Apple Cinnamon','Nutri-Grain Cereal Bars',124636,NULL,'30038000597795','Kellogg Company US','Kellogg''s',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2682477,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Strawberry','Nutri-Grain Cereal Bars',124637,NULL,'30038000597726','Kellogg Company US','Kellogg''s',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2682478,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo Pancakes Confetti','Pancakes',124638,NULL,'30038000185749','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2682479,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Raisin Bran Cereal','Raisin Bran Cereal',124639,NULL,'30038000008963','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2682480,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Morningstar Farms Breakfast Sausage Patties','Breakfast',124640,NULL,'30028989971525','Kellogg Company US','Morningstar Farms',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2682481,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SunButter Chocolate 5 lb tubs - 2 ct case','SunButter Chocolate 5 lb tubs - 2ct',124641,NULL,'10737539196610','Red River Commodities Sunbutter','SunButter','100935',3,'2024-01-22','2024-12-19',NULL,'READY_TO_EAT',2718861,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'SunButter Chocolate 1.4oz cups - 200 ct case','SunButter Chocolate1.1oz cups-200ct',124642,NULL,'10737539196405','SunButter LLC','SunButter',NULL,3,'2024-01-22','2024-08-15',NULL,'PREPARED',2700430,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Oatmeal Cranberry Granola Bakes WG','OatmealCranberry Granola Bake 2 oeg',124643,NULL,'10693392007350','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2025-03-20',NULL,'PREPARED',2724492,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Cherry Granola Bakes WG','Chocolate Cherry Granola Bakes',124644,NULL,'10693392007312','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2025-03-20',NULL,'PREPARED',2724491,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Blueberry Pomegra Granola Bakes WG','Blue Pomegranate Granola Bakes 2oeg',124645,NULL,'10693392007305','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2025-03-20',NULL,'PREPARED',2724490,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'IW WG Crustless Cocoa CPB Sandwich','IW WG Crustless Cocoa CPB Sandwich',124646,NULL,'10693392006933','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2025-04-24',NULL,'THAW',2730513,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breakfast Kit RS Fruit Loops','Breakfast Kit Froot Loops',124647,NULL,'10693392001785','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2025-04-24',NULL,'PREPARED',2730463,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo Pancakes Blueberry','Pancakes',124665,NULL,'30038000925604','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2682823,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'NAKED JUICE  GREEN   10Z/8','NJ  GREEN  MACHINE 10Z/8',124688,NULL,'10082592630763','PepsiCo Inc. Brand Owner','Naked',NULL,3,'2024-01-22','2024-02-01',NULL,'UNPREPARED',2683409,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Plant-based Italian-style Crumbles,  2.5 LB Bag - Qty 4','Italian-style Plant Crumbles',124689,NULL,'10642205036001','Cargill Incorporated/Honeysuckle White','Crave House',NULL,3,'2024-01-22','2024-07-11',NULL,'PREPARED',2696676,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kit Blueberry Pome Granola Bakes','Kit Blueberry Pome Granola Bakes',124690,NULL,'10693392007367','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2024-05-16',NULL,'PREPARED',2689932,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Turkey Pretzel Dog WG','Turkey Pretzel Dog WG',124691,NULL,'10693392006827','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2025-04-24',NULL,'PREPARED',2730487,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breakfast Kit Honey Bunches of Oats Honey Crunch w/Apple Juice','Kit Honey Bunches of Oats w/ Juice',124692,NULL,'10693392006711','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2025-04-24',NULL,'PREPARED',2730486,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Meal Kit Sweet BBQ Bites and Sunflower Seeds','Meal Kit Sweet BBQ Bites and Seeds',124693,NULL,'10693392005318','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2025-04-24',NULL,'PREPARED',2730458,'50193400');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breakfast Kit Apple Cinnamon Cheerios','Breakfast Kit Apple Jacks',124694,NULL,'10693392004151','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2025-04-24',NULL,'PREPARED',2730453,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breakfast Kit Honey Cheerios','Breakfast Kit Honey Cheerios',124695,NULL,'10693392006841','East Side Entrees','ES Foods',NULL,3,'2024-01-22','2025-04-24',NULL,'READY_TO_EAT',2730488,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Darlington Whole Grain 1.5 oz  Apple Breakfast Squares, Individually Wrapped - 160ct','1.5oz WG Apple Squares, IW',124697,NULL,'00675825241008','Darlington Cookie Company','Darlington',NULL,3,'2024-01-22','2024-02-01',NULL,'PREPARED',2683699,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'6/10 LAKESIDE CUT GRN BNS','CT GRN BN',124698,NULL,'10033828013164','Lakeside Foods Inc.','LAKESIDE FOODS',NULL,3,'2024-01-22','2024-02-15',NULL,'READY_TO_EAT',2684001,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hart Low Sodium Seasoned Refried Beans 6 count, 112oz cans','REFRD BNS SEASND',124699,NULL,'10070222973823','Seneca Foods Corp','HART','100362',3,'2024-01-22','2024-12-19',NULL,'UNPREPARED',2718907,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stokely''s Mixed Vegetable - 24 pack, 15oz cans','MIXED VEG',124700,NULL,'10070222639583','Seneca Foods Corp','STOKELY''S','100320',3,'2024-01-22','2024-12-19',NULL,'UNPREPARED',2718906,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hart Low Sodium Mixed Sieve Sweet Peas - 6 pack, 106oz cans','SWEET PEAS MX SV LOW SOD',124701,NULL,'10070222574273','Seneca Foods Corp','HART','100315',3,'2024-01-22','2024-12-19',NULL,'UNPREPARED',2718905,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stokely''s Diced Carrots - 6 pack, 105oz cans','CARROTS DICED CY',124702,NULL,'10070222528139','Seneca Foods Corp','STOKELY''S','100309',3,'2024-01-22','2024-12-19',NULL,'UNPREPARED',2718900,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stokely''s No Salt Cut Green Beans - 24 pack, 14.5oz cans','BNS GRN CT NS CY',124703,NULL,'10070222526531','Seneca Foods Corp','STOKELY''S','100306',3,'2024-01-22','2024-12-19',NULL,'PREPARED',2718899,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stokely No Salt Mixed Vegetables - 12 pack, 15oz cans','MIX VEG NS',124704,NULL,'10070222339582','Seneca Foods Corp','Stokely','111491',3,'2024-01-22','2024-12-19',NULL,'UNPREPARED',2718898,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stokley''s No Salt Cut Green Beans - 12 pack, 14.5oz cans','BNS GRN CT NS',124705,NULL,'10070222226530','Seneca Foods Corp','Stokley''s','111426',3,'2024-01-22','2024-12-19',NULL,'UNPREPARED',2718897,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stokely''s Double Diced No Salt Mixed Vegetable - 24 pack, 15oz cans','MX VEG DBL DCD NS',124706,NULL,'10070222039581','Seneca Foods Corp','STOKELY''S','100320',3,'2024-01-22','2024-12-19',NULL,'UNPREPARED',2718924,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hart Low Sodium Medium Sliced Carrots - 6 pack, 105oz cans','CARROTS SL MED LOW SODIUM',124707,NULL,'10070222573733','Seneca Foods Corp','HART','100309',3,'2024-01-22','2024-12-19',NULL,'UNPREPARED',2718903,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Oatmeal Raisin Frozen Cookie Dough Made With Whole Grain','Oatmeal Raisin Cookies',124708,NULL,'10013087556831','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essential',NULL,3,'2024-01-22','2024-06-13',NULL,'UNPREPARED',2694275,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'All Natural Sliced Turkey Breast','All Natural Sliced Turkey Breast',124709,NULL,'90022655892000','Butterball, LLC','BUTTERBALL',NULL,3,'2024-01-22','2024-05-16',NULL,'PREPARED',2690089,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked All Natural* Low Sodium Diced Chicken, Natural Proportion 60 White/40 Dark Meat, 0.5"','TYS LSDM FC 1/2 INCH DI CKN NT PROP',124710,NULL,'00023700048516','Tyson Foods Inc.','Tyson','100103',3,'2024-12-19','2025-04-24',NULL,'UNPREPARED',2730904,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Unsweetened Apple Sauce Cups 96/4.5','Unsweetened Apple Sauce Cups',124711,NULL,'00041760091167','CHERRY CENTRAL','Cherry Central Cooperative','110361',3,'2024-12-19','2025-03-20',NULL,'READY_TO_EAT',2723859,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Strawberry 24.8oz 96ct','Nutri-Grain Cereal Bars',124712,NULL,'00038000597725','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721409,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'AdvancePierre Fully Cooked, All Natural Beef Meatballs, 0.93 oz.','APF CN CMDT FC ALL NT BF MTBL 6/5 L',124713,NULL,'00880760096877','Tyson Foods Inc.','Advance Pierre','100154',3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2723284,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'TONYS TURKEY SAUSAGE EGG AND CHEESE STUFFED SANDWICH 96CT CN','BKFT SSND TEC IW',124714,NULL,'00072180702579','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719289,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'TONYS TURKEY SAUSAGE EGG AND CHEESE STUFFED SANDWICH 96CT CN','BKFT SSAND T E C',124715,NULL,'10072180702545','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719002,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'AdvancePierre Loaded Cheeseburger Mini Patty, 1.33 oz.','APF CN CMDT FC MTLF CDR CHSE KCHP 2',124716,NULL,'00071421976939','Tyson Foods Inc.','Advance Pierre','100155',3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2723226,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'SFS TONY''S 51% WG BREAKFAST BAGEL WITH EGGS AND TURKEY BREAKFAST SAUSAGE - IW NET WT 16.98 LBS 96CT','BKFT BGL C/E/MT',124717,NULL,'00072180676252','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2717978,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'SFS TONY''S 51% WG BREAKFAST BAGEL WITH MOZZARELLA AND EGGS NET WT 16.80 LBS 96CT','BKFT BGL EGG CHS',124718,NULL,'00072180676269','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2723232,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Cheddar Slice - 32 SOS - 1.5#','1.5# Md Chd 32 Sl',124719,NULL,'00071078752450','Bongards Creameries','Bongards',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2717738,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Cheddar and Monterey Jack Fancy Shred - 5# (K-12)','Chd Mon Jk Fncy Shd 5#',124720,NULL,'00071078771024','Bongards Creameries','Bongards',NULL,3,'2024-12-19','2025-01-23',NULL,'READY_TO_EAT',2721962,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Pasteurized Blended Low Moisture Part Skim Mozzarella Slice - 160 P - 5#','5# Blended LM PartSkim Mozzarella',124721,NULL,'00071078114456','Bongards Creameries','Bongards',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2717736,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Pasteurized Blended Pepper Jack Slice - 160 P - 5#','5# Blended Pepper Jack Cheese 160',124722,NULL,'00071078114449','Bongards Creameries','Bongards',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2717735,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Pasteurized Blended Provolone Slice - 160 P - 5#','5# Blended Provolone Cheese 160P',124723,NULL,'00071078114463','Bongards Creameries','Bongards',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2717737,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Pasteurized Blended Reduced Fat Cheddar Slice - 160 P - 5#','5# Reduced Fat Blended Cheddar',124724,NULL,'00071078114425','Bongards Creameries','Bongards',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2717733,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Pasteurized Blended Swiss Slice - 160 P - 5#','5# Blended Swiss Cheese 160 Slice',124725,NULL,'00071078114432','Bongards Creameries','Bongards',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2717734,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Pasteurized Blended Yellow Cheddar Slice - 160 P - 5#','5# Blended Ched Cheese Yel 160 P',124726,NULL,'00071078114418','Bongards Creameries','Bongards',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2717763,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Pepper Jack Slice - 32 SOS - 1.5#','1.5# Pep Jk 32 Sl',124727,NULL,'00071078752528','Bongards Creameries','Bongards',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2717741,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Provolone Slice - 32 SOS - 1.5#','1.5# Smkd Prv 32H Sl',124728,NULL,'00071078752474','Bongards Creameries','Bongards',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2717739,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Swiss Cheese Slice - 32 SOS - 1.5#','Swiss Cheese Slices - 32 SOS - 1.5#',124729,NULL,'00071078752481','Bongards Creameries','Bongards',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2717740,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Process American Loaf - 5#','5# Y Pr Am Lf',124730,NULL,'00071078105027','Bongards Creameries','Bongards',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2717829,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Low Moisture Part Skim Mozzarella Feather Shred - 5# (K-12)','LMPS Mz Fthr Shd 5#',124731,NULL,'00071078755079','Bongards Creameries','Bongards',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2717742,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Cheddar Feather Shred - 5# (K-12)','Y Chd Fthr Shd 5#',124732,NULL,'00071078755192','Bongards Creameries','Bongards',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2717743,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Huy Fong Sriracha Hot Chili Sauce Ketchup, 20 oz Bottle','Huy Fong Sriracha Hot Chili Sce Ket',124733,NULL,'00072940112075','Red Gold, Inc.','Huy Fong',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718065,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Huy Fong Sriracha Hot Chili Sauce Ketchup, 20 oz Bottle - Case of 6','Huy Fong Sriracha Hot Chili Sce Ket',124734,NULL,'30072940112076','Red Gold, Inc.','Huy Fong',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719138,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Cheez It Crackers Whole Grain .75oz 175ct','Cheez-It Crackers',124735,NULL,'00024100792634','Kellogg Company US','Kellogg''s Cheez It',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721832,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Land O Lakes 50% Reduced Sodium, 50% Reduced Fat American,160 Slices, Yellow, 5 lb.','5# LOL FS PPAC Y 50RS 50RF 160',124736,NULL,'00034500460187','LAND O''LAKES','LAND O LAKES',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721092,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Migliore Whole Peeled Tomatoes, 102oz Can - Case of 6','Migliore Whole Peeled Tomatoes',124737,NULL,'30072940811016','Red Gold, Inc.','Migliore',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719222,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Crushed Ground Tomatoes in Puree, 105oz Pouch - Case of 6','Red Gold Crushed Tomatoes',124738,NULL,'30072940750650','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719221,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Mild Salsa, 1.5oz Dipping Cups - CS of 264','Red Gold Mild Salsa',124739,NULL,'60072940110578','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719164,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Healthy Request Mexican-Style Chicken Tortilla Soup, 4 Pound Trays, 3-Pack','CUL RES HR MEX CKN TORTLA',124740,NULL,'00051000191229','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718722,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Ready to Eat Reduced Sodium Chicken Noodle Soup, 4 Pound Pouches, 4-Pack','CUL RES RDNA CKN NDL',124741,NULL,'00051000274434','CAMPBELL SOUP COMPANY','CAMPBELL SIGNATURE FROZEN',NULL,3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2724198,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Glorietta Tomato Juice, 46oz Can - Case of 12','Glorietta Tomato Juice',124742,NULL,'10072940770005','Red Gold, Inc.','Glorietta',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719049,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Huy Fong Hot Chili Sauce Sriracha Packets, 7 gram Packets - CS of 500','Huy Fong Chili Sauce Sriracha Hot',124743,NULL,'60072940997094','Red Gold, Inc.','Huy Fong',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719115,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mama Selita''s Jalapeno Ketchup, 20oz Bottle - Case of 6','Mama Selita''s Jalapeno Ketchup',124744,NULL,'30072940001172','Red Gold, Inc.','Mama Selita''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719052,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Barbecue Sauce Naturally Balanced 114oz w/Pump - CS of 6','Red Gold Barbecue Sce Naturally Bal',124745,NULL,'80072940747396','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719122,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Barbecue Sauce, 1oz Dip Cup - CS of 250','Red Gold Barbecue Sauce Dip Cup',124746,NULL,'80072940115805','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719120,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Colts Ketchup, 20oz Bottle - Case of 16','Red Gold Ketchup',124747,NULL,'60072940115313','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719166,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Crushed Tomatoes, 105oz Can - Case of 6','Red Gold Crushed Tomatoes',124748,NULL,'30072940110133','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719129,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Diced Tomatoes with Green Chilies, 28oz Can - CS of 12','Red Gold Diced Tom w/Green Chilies',124749,NULL,'10072940113239','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719046,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Diced Tomatoes, 102oz Can - CS of 6','Red Gold Diced Tomatoes',124750,NULL,'30072940110157','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719131,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Extra Heavy Pizza Sauce with Basil, 105oz Can - Case of 6','Red Gold Pizza Sauce w/Basil',124751,NULL,'30072940110096','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719092,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup with Natural Sugar Low Sodium 1.5 Gallon - Case of 2','Red Gold Ketchup LoSodium Real Sug',124752,NULL,'60072940115504','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719107,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup with Natural Sugar Low Sodium, 112.5oz Tub - Case of 6','Red Gold Ketchup Naturally Balanced',124753,NULL,'80072940747372','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719121,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup with Natural Sugar, 3 Gal Bag in Box- Case of 1','Red Gold Ketchup with Natural Sugar',124754,NULL,'80072940001139','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719116,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup with Sugar, 7lb 2oz Pouch - Case of 6','Red Gold Ketchup with Sugar',124755,NULL,'30072940115855','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719142,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup with Sugar, 9g Packet - Case of 1000','Red Gold Ketchup with Sugar',124756,NULL,'60072940115955','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719113,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 1.5 Gallon Pouch - Case of 2','Red Gold Ketchup Pouch',124757,NULL,'60072940115634','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719110,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 114oz Jug - Case of 6','Red Gold Ketchup',124758,NULL,'30072940115749','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719219,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 115oz Can - Case of 6','Red Gold Ketchup',124759,NULL,'30072940110027','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719054,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 14oz Bottle - Case of 24','Red Gold Ketchup',124760,NULL,'20072940000079','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719198,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 1oz Dip Cups - Case of 250','Red Gold Ketchup Dip Cups',124761,NULL,'80072940115799','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719119,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 1oz Dip Cups - CS of 250','Red Gold Ketchup Dip Cup',124762,NULL,'80072940749543','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721949,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 20oz Bottle - Case of 16','Red Gold Ketchup',124763,NULL,'60072940115214','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719165,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 20oz Bottle - Case of 25','Red Gold Ketchup',124764,NULL,'60072940115191','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719106,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 3 Gallon - Case of 1','Red Gold Ketchup',124765,NULL,'60072940115603','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719108,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 64oz Bottle - Case of 9','Red Gold Ketchup',124766,NULL,'50072940115644','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719163,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 7lb 2oz Pouch - Case of 6','Red Gold Ketchup Pouch',124767,NULL,'30072940115619','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719139,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 9 gram Packet - Case of 1000','Red Gold Ketchup Packets',124768,NULL,'60072940115818','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719112,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 9 gram Packet - Case of 1500','Red Gold Ketchup Packets',124769,NULL,'80072940748331','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719823,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Low Sodium Ketchup with Natural Sugar, 114oz - Case of 6','Red Gold Ketchup w Natl Sug Lw Sod',124770,NULL,'30072940115831','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719140,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Low Sodium Sugar Ketchup, 3 Gallon Bag in Box - Case of 1','Red Gold Low Sodium Sugar Ketchup',124771,NULL,'60072940115771','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719111,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Marinara Sauce, 1.25oz Dip Cup - Case of 264','Red Gold Marinara Sauce Dip Cup',124772,NULL,'60072940110585','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719105,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Marinara Sauce, 105oz Can - Case of 6','Red Gold Marinara Sauce',124773,NULL,'30072940110041','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719055,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Marinara Sauce, 1oz Dip Cup - Case of 250','Red Gold Marinara Sauce Dip Cup',124774,NULL,'80072940111357','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719118,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Mild Salsa, 103oz Can - CS of 6','Red Gold Mild Salsa',124775,NULL,'30072940110058','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719056,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Mild Salsa, 3oz Dip Cup - Case of 168','Red Gold Mild Salsa Dip Cup',124776,NULL,'40072940111397','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719192,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Mild Salsa, 3oz Dip Cup - Case of 84','Red Gold Mild Salsa Dip Cup',124777,NULL,'80072940111395','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719167,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Mustard 13oz - CS of 16','Red Gold Mustard',124778,NULL,'60072940749785','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719114,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Plant Based Bolognese Pasta Sauce, 105oz Can - Case of 6','Red Gold PltBsd Bolog Pasta Sauce',124779,NULL,'30072940111420','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719137,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Cocktail Sauce, 115oz Can - Case of 6','Red Gold Cocktail Sauce',124780,NULL,'30072940110195','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2723182,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Stewed Tomatoes, 102oz Can - CS of 6','Red Gold Stewed Tomatoes',124781,NULL,'30072940110140','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719130,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Sweet Fancy Ketchup, 115oz Can - Case of 6','Red Gold Sweet Fancy Ketchup',124782,NULL,'30072940116005','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719143,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Tomato Juice No Salt Added, 46oz Can - Case of 12','Red Gold Tomato Juice NSA',124783,NULL,'10072940143205','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719021,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Tomato Paste, 111oz Can - CS of 6','Red Gold Tomato Paste',124784,NULL,'30072940110164','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719132,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Tomato Sauce, 106oz Can - Case of 6','Red Gold Tomato Sauce',124785,NULL,'30072940110102','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719093,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Tomatoes Diced No Salt Added, 102oz Can - CS of 6','Red Gold Diced Tomatoes NSA',124786,NULL,'30072940146101','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719145,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Traditional Spaghetti Sauce, 106oz Can - CS of 6','Red Gold Spaghetti Sauce',124787,NULL,'30072940110119','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719127,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Traditional Spaghetti Sauce, Deluxe 106oz Can - CS of 6','Red Gold Spaghetti Sauce',124788,NULL,'30072940110379','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719135,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Whole Peeled Tomatoes, 102oz Can - CS of 6','Red Gold Whole Peeled Tomatoes',124789,NULL,'80072940110015','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719117,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack  Tomato Puree, 106oz Can - Case of 6','Redpack Tomato Puree',124790,NULL,'30072940817018','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719125,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Chili Sauce, 113oz Can - CS of 6','Redpack Chili Sauce',124791,NULL,'30072940820001','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719095,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Crushed Tomatoes, 105oz Can - Case of 6','Redpack Crushed Tomatoes',124792,NULL,'30072940814000','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719155,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Diced Tomatoes, 102oz Can - CS of 6','Redpack Diced Tomatoes',124793,NULL,'30072940812013','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719152,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Fully Prepared Pizza Sauce, 106oz Can - Case of 6','Redpack Pizza Sauce Fully Prepared',124794,NULL,'30072940748862','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719147,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Marinara Sauce, 105oz Can - Case of 6','Redpack Marinara Sauce',124795,NULL,'30072940822005','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719099,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Marinara Sauce, 105oz Pouch - Case of 6','Redpack Marinara Sauce',124796,NULL,'30072940997079','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719102,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Nutritionally Enhanced Marinara Sauce, 105oz Can - Case of 6','Redpack Marinara Sauce',124797,NULL,'30072940822067','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719100,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Nutritionally Enhanced Traditional Spaghetti Sauce, 106oz Can - CS of 6','Redpack Enhanced Spaghetti Sauce',124798,NULL,'30072940821077','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719097,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Petite Diced Tomatoes, 102oz Can - CS of 6','Redpack Petite Diced Tomatoes',124799,NULL,'30072940811009','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719150,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Tomato Paste, 111oz Can - CS of 6','Redpack Tomato Paste',124800,NULL,'30072940823002','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719101,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Tomato Sauce, 106oz Can - Case of 6','Redpack Tomato Sauce',124801,NULL,'30072940818008','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719124,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Whole Peeled Tomatoes in Puree, 102oz Can - CS of 6','Redpack Whole Peeled Tom in Puree',124802,NULL,'30072940811078','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719151,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Zucchini and Tomatoes, 102oz Can - Case of 6','Redpack Zucchini & Tomatoes',124803,NULL,'30072940825006','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719193,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sacramento Bloody Mary Mix 46oz - CS of 12','Sacramento Bloody Mary Mix',124804,NULL,'10072940762017','Red Gold, Inc.','Sacramento',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719023,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sacramento Tomato Juice, 46oz Bottle - Case of 8','Sacramento Tomato Juice',124805,NULL,'20072940760010','Red Gold, Inc.','Sacramento',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719200,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sacramento Tomato Juice, 46oz Can - Case of 12','Sacramento Tomato Juice',124806,NULL,'10072940760020','Red Gold, Inc.','Sacramento',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719048,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sacramento Vegetable Juice, 46oz Can - Case of 12','Sacramento Vegetable Juice',124807,NULL,'10072940761003','Red Gold, Inc.','Sacramento',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719022,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Teresa White Extra Heavy Pizza Sauce with Basil, 105oz Can - Case of 6','Teresa White Pizza Sauce w/Basil',124808,NULL,'30072940819050','Red Gold, Inc.','Teresa White',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719094,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tuttorosso Fresh Marinara Sauce, 105oz Can - Case of 6','Tuttorosso Fresh Marinara Sauce',124809,NULL,'30072940750360','Red Gold, Inc.','Tuttorosso',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719149,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tuttorosso Fresh Pizza Sauce, 105oz Can - Case of 6','Tuttorosso Fresh Pizza Sauce',124810,NULL,'30072940748886','Red Gold, Inc.','Tuttorosso',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719148,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sacramento Bloody Mary Cocktail Mix, 32oz Bottle - CS of 12','Sacramento Bloody Mary Cocktail Mix',124811,NULL,'10072940750304','Red Gold, Inc.','Sacramento',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719047,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Unsweetened Apple Sauce 6/10','Unsweetened Apple Sauce',124812,NULL,'00070283099039','CHERRY CENTRAL','Cherry Central Cooperative','110541',3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2718560,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Whole Peeled Tomatoes, 102oz Can','Red Gold Whole Peeled Tomatoes',124813,NULL,'00072940110019','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719228,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Vine Ripe Whole Peeled Tomatoes, 102oz Can - Case of 6','Vine Ripe Whole Peeled Tomatoes',124814,NULL,'30072940100127','Red Gold, Inc.','Vine Ripe',NULL,3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2724497,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Breaded Chicken Thighs','TYS FC BRD CKN TH WO BAC 29.64 LB',124815,NULL,'00023700053343','Tyson Foods Inc.','Tyson','100103',3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2723956,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Mesquite Glazed Chicken Thighs ','TYS FC GLZ CKN TH MSQ SFA 4/5.77 LB',124816,NULL,'00023700053350','Tyson Foods Inc.','Tyson','100103',3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2723957,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SFS TONY''S 4X6 SMART WG CHEESE NET WT 27.00LBS 12-8PK CN','TN 4X6 SM WG CHS',124817,NULL,'00072180786975','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2717984,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'SFS TONY''S 4X6 SMRT WG CHS 50-50 NET WT 27.60LBS 12-8PK CN','TN 4X6 SM WG CHS',124818,NULL,'00072180786739','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2717982,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'SFS TONY''S SMART WG PEPPERONI 50-50 NET WT 26.88LBS 12-8PK CN','TN 4X6 SM WG PEP',124819,NULL,'00072180786746','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2717983,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'SFS TONY''S SMART WG PEPPERONI NET WT 26.88LBS 12-8PK CN','TN 4X6 SM WG PEP',124820,NULL,'00072180786982','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2717985,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Dinner Rolls, Whole Grain, Low Sodium, Smooth Top, Individually Wrapped','CLOSEOUT Din Rl WG LS Smth Top IW',124821,NULL,'00737410016689','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-12-19','2025-01-23',NULL,'UNPREPARED',2722302,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Apple Cinnamon 24.8oz 96ct','Nutri-Grain Cereal Bars',124822,NULL,'00038000597794','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721412,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Blueberry 24.8oz 96ct','Nutri-Grain Cereal Bars',124823,NULL,'00038000908194','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721376,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cheddar Cheese Sauce Clean Label 6/5# 30#','Cheddar Cheese Sauce Clean Label',124824,NULL,'00049485057345','JTM Food Group','JTM Food Group',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2718737,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cinnamon Roll, Whole Grain, Individually Wrapped','Cinnamon Roll, Whole Grain, IW',124825,NULL,'00737410012636','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719696,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cinnamon Roll, Whole Grain, Individually Wrapped, 3.3" x 1.2"','Cinnamon Roll, WG, IW, 3.3"x1.2"',124826,NULL,'00737410128702','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719705,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'RS Alfredo Sauce 6/5# 30#','RS Alfredo Sauce',124827,NULL,'00049485057413','JTM Food Group','JTM Food Group',NULL,3,'2024-12-19','2025-04-24',NULL,'PREPARED',2730780,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'RS Queso Blanco 6/5# 30#','RS Queso Blanco',124828,NULL,'00049485057420','JTM Food Group','JTM Food Group',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2718739,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sweet Chili Sauce 30# 6 Bags','Sweet Chili Sauce',124829,NULL,'00049485734802','JTM Food Group','JTM Food Group',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2718740,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'THE MAX Chicken Quesadilla Pizza, 5 OZ','MAX NON WG CKN PIZZA QUESADILLA 48/',124830,NULL,'00077387125329','Conagra Brands, Inc','The MAX',NULL,3,'2024-12-19','2025-01-23',NULL,'BAKE',2722262,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sweet & Salty Popcorn','8435710084 Sweet & Salty Popcorn',124831,NULL,'00843571005667','Tas','Tasty Brands LLC',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719788,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Chili Sauce, 113oz Can - CS of 6','Red Gold Chili Sauce',124832,NULL,'30072940110126','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719128,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Chicken Sausage Patties, 1.43 oz. ','TYS CN FC CKN SAU PAT 6/5.01LB',124833,NULL,'00023700039989','Tyson Foods Inc.','Tyson','100103',3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2723996,'50240300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Golden Crispy Chicken Nuggets, CN, 0.60 oz.','TYS CN FC WG CSPY CKN CHNK 32.81 LB',124834,NULL,'00023700033765','Tyson Foods Inc.','Tyson','100103',3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2724803,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Homestyle Chicken Breast Filets, 4 oz. ','TYS CN FC WG HMST CKN BST FLT 30 LB',124835,NULL,'00023700037114','Tyson Foods Inc.','Tyson','100103',3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2723832,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Cheez It Crackers Whole Grain 1oz','Cheez-It Crackers',124836,NULL,'00024100104819','Kellogg Company US','Kellogg''s Cheez It',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721507,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Unbreaded Grilled Chicken Patties, CN, 2.47 oz.','TYS CN FC GRL CKN PAT 4/7.5 LB',124837,NULL,'00023700049568','Tyson Foods Inc.','Tyson','100103',3,'2024-12-19','2025-04-24',NULL,'UNPREPARED',2730906,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Southern Style MWWM Chicken Breast Filets, CN, 2.12 oz. ','TYS CN FC WG HMST CKN FLT 30 LB',124838,NULL,'00023700039200','Tyson Foods Inc.','Tyson','100103',3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2723993,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SFS TONY''S 51% WG BREAKFAST BAGEL WITH EGGS AND TURKEY BREAKFAST SAUSAGE 96CT','BKFT BGL MT BULK',124839,NULL,'10072180676280','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718925,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sacramento Tomato Juice, 7.2oz Can - CS of 24','Sacramento Tomato Juice',124840,NULL,'20072940750684','Red Gold, Inc.','Sacramento',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719199,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Shelf Stable Yogurt Cup, Strawberry, 4.0oz','Yogurt Cup',124841,NULL,'20810358036057','National Food Group  Inc.','Zee Zees',NULL,3,'2024-12-19','2025-03-20',NULL,'READY_TO_EAT',2723181,'50132100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Shelf Stable Yogurt Cup, Vanilla, 4.0oz','Vanilla Yogurt Cup',124842,NULL,'20810358036040','National Food Group  Inc.','Zee Zees',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719050,'50132100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Frosted Strawberry 1.69oz','Pop-Tarts',124843,NULL,'00038000551321','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721401,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Frosted Strawberry 16.9oz','Pop-Tarts',124844,NULL,'00038000551314','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721399,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Frosted Strawberry 16.9oz 120ct','Pop-Tarts',124845,NULL,'00038000551307','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721398,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Frosted Strawberry 20.3oz','Pop-Tarts',124846,NULL,'00038000551345','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721402,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Frosted Strawberry 20.3oz 72ct','Pop-Tarts',124847,NULL,'00038000551338','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721416,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Frosted Strawberry 3.3oz','Pop-Tarts',124848,NULL,'00038000551369','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721403,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 1.5 Gallon Pouch','Red Gold Ketchup Pouch',124849,NULL,'00072940115632','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719274,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Mustard 13oz','Red Gold Mustard',124850,NULL,'00072940749783','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719076,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Pasta Sauce Plant Based Bolognese Pasta Sauce, 105oz Can','Red Gold PltBsd Bolog Pasta Sauce',124851,NULL,'00072940111429','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719251,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Pizza Sauce with Basil, 105oz Can','Redpack Pizza Sauce w/Basil',124852,NULL,'00072940819035','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719032,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Pizza Sauce with Basil, 105oz Can - CS of 6','Redpack Pizza Sauce w/Basil',124853,NULL,'30072940819036','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719123,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Spaghetti Sauce, 106oz Pouch','Redpack Spaghetti Sauce',124854,NULL,'00072940821083','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719037,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Spaghetti Sauce, 106oz Pouch - Case of 6','Redpack Spaghetti Sauce',124855,NULL,'30072940821084','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719098,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Traditional Pasta Sauce, 106oz Can','Redpack Pasta Sauce',124856,NULL,'00072940821007','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719035,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Traditional Pasta Sauce, 106oz Can - Case of 6','Redpack Pasta Sauce',124857,NULL,'30072940821008','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719096,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sacramento Bloody Mary Cocktail Mix, 32oz Bottle','Sacramento Bloody Mary Cocktail Mix',124858,NULL,'00072940750307','Red Gold, Inc.','Sacramento',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719077,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tuttorosso Fresh Marinara Sauce, 105oz Can','Tuttorosso Fresh Marinara Sauce',124859,NULL,'00072940750369','Red Gold, Inc.','Tuttorosso',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719078,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Vine Ripe Low Sodium Tomato Sauce, 106oz Can','Vine Ripe Low Sodium Tomato Sauce',124860,NULL,'00072940100522','Red Gold, Inc.','Vine Ripe','100334',3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2724130,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Vine Ripe Low Sodium Tomato Sauce, 106oz Can - CS of 6','Vine Ripe Low Sodium Tomato Sauce',124861,NULL,'30072940100523','Red Gold, Inc.','Vine Ripe','100334',3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2724499,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Vine Ripe Spaghetti Sauce, 106oz Can','Vine Ripe Spaghetti Sauce',124862,NULL,'00072940100157','Red Gold, Inc.','Vine Ripe','100336',3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2724129,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Vine Ripe Spaghetti Sauce, 106oz Can - CS of 6','Vine Ripe Spaghetti Sauce',124863,NULL,'30072940100158','Red Gold, Inc.','Vine Ripe','100336',3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2724498,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'AdvancePierre Fully Cooked Beef Meatballs, 0.44 oz.','APF CN CMDT FC DLX BF MTBL 5/6 LB',124864,NULL,'00880760017650','Tyson Foods Inc.','Advance','100154',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723312,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'FC MTLF with CDR CHSE Topped with KTCUP, MNI Twin SAND on a WG Bun','BLPK CN CMDT FC MTLF SAND TWPK 80/4',124865,NULL,'30054500000214','Tyson Foods Inc.','Ball Park','100154',3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717196,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Sliced Black Forest Chicken Ham, 0.50 oz.','TYS FC SLCD BNLS CKN HAM UCRD 6/2 L',124866,NULL,'00031400034586','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730733,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Apple Cinnamon 1.55oz','Nutri-Grain Cereal Bars',124867,NULL,'00038000597824','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721414,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Apple Cinnamon 24.8oz','Nutri-Grain Cereal Bars',124868,NULL,'00038000597817','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721413,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Blueberry 1.55oz','Nutri-Grain Cereal Bars',124869,NULL,'00038000914737','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721378,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Blueberry 24.8oz','Nutri-Grain Cereal Bars',124870,NULL,'00038000914720','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721377,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Strawberry 1.55oz','Nutri-Grain Cereal Bars',124871,NULL,'00038000597749','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721411,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Strawberry 24.8oz','Nutri-Grain Cereal Bars',124872,NULL,'00038000597732','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721410,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Morningstar Farms Breakfast Veggie Breakfast Sausage Patties 1.34oz 112ct','Breakfast',124873,NULL,'00028989971524','Kellogg Company US','Morningstar Farms',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721791,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Morningstar Farms Poultry Whole Grain Breaded Chikn Nuggets 10lb 1ct','Poultry',124874,NULL,'00028989977625','Kellogg Company US','Morningstar Farms',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721795,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'AdvancePierre Fully Cooked Flame Grilled Beef Burger, 2.01 oz.','APF CN CMDT FC FBLD BF STK BURG 250',124875,NULL,'00880760017445','Tyson Foods Inc.','Advance Pierre','100154',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724172,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'AdvancePierre Fully Cooked Flame Grilled Beef Steak Burger, 3 oz.','APF CMDT FC PUB STYL BF STK BURG 16',124876,NULL,'00880760034442','Tyson Foods Inc.','Advance Pierre','100154',3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2716985,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'AdvancePierre Fully Cooked Pork Rib Patties with Honey BBQ Sauce, 3.25 oz.','SMKG CN CMDT FC FBLD PK PAT HBBQ 20',124877,NULL,'00071421037173','Tyson Foods Inc.','Pierre','100193',3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717115,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Land O Lakes  Reduced Fat American, Slices, Yellow, 160','5# LOL FS PPAC Y 50RF 40R 160S',124878,NULL,'00034500460309','LAND O''LAKES','LAND O LAKES',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721093,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Land O Lakes 25% RS, 50% RF American,160 Slices, Yellow, 5 lb.','5# LOL FS PPAC Y 25RS 50RF 160',124879,NULL,'00034500460316','LAND O''LAKES','LAND O LAKES',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721094,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Land O Lakes American Cheese Slices, White, 160','5# LOL FS PPAC W 40R 160 SL',124880,NULL,'00034500460323','LAND O''LAKES','LAND O LAKES',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721095,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Land O Lakes American Cheese, 160 Slices, Yellow, 5 lb.','5# LOL FS PPAC Y 40R 160 SL',124881,NULL,'00034500460163','LAND O''LAKES','LAND O LAKES',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721091,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Land O Lakes American Cheese, 184 Slices, Yellow, 5 lb.','5# LOL FS PPAC Y 46R 184 SL',124882,NULL,'00034500460156','LAND O''LAKES','LAND O LAKES',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721090,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Chicken Meatballs, 0.54 oz.','TYS CN CMDT FC SAV CKN MTBL 2/5 LB',124883,NULL,'00031400074100','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717686,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Chicken Meatballs, 0.92 oz.','APF CN CMDT FC SAV CKN MTBL 2/5 LB',124884,NULL,'00031400032575','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717693,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SFS BIG DADDY''S BUF CHIC STF SAND WG IW NET WT 13.38LBS 48CT','BD BUF CHIC SAND',124885,NULL,'00072180552921','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2717975,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'SFS BIG DADDY''S FIESTADA BF STF SAND WG IW NET WT 13.38LBS 48CT','BD BF FIESTADA',124886,NULL,'00072180552914','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2717974,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'SFS BIG DADDY''S PEPP STF SAND WG IW NET WT 13.38LBS 48CT','BD PEPP STF SAND',124887,NULL,'00072180552938','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2724128,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'SFS TONY''S DEEP DISH WG CHEESE NET WT 18.68LBS - IW 60CT CN','TN 5" DD CHS',124888,NULL,'00072180783158','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2717981,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'SFS TONY''S DEEP DISH WG PEPPERONI NET WT 18.68LBS - IW 60CT CN','TN 5IN DD PEPP',124889,NULL,'00072180783141','SCHWAN''S FOOD SERVICE INC','TONY''S',NULL,3,'2024-12-19','2025-04-24',NULL,'UNPREPARED',2730304,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Chili Lime Mango, 1.33oz','Dried Fruit Mix',124890,NULL,'20810358036545','National Food Group  Inc.','Zee Zees',NULL,3,'2024-11-14','2024-11-14',NULL,'READY_TO_EAT',2717184,'50101900');
INSERT INTO `cndb_fdes` VALUES (NULL,'AdvancePierre Fully Cooked Breaded Pork Steak, 3.85 oz.','APF CN CMDT FC CF BRD PK STK CPFM20',124891,NULL,'00071421690453','Tyson Foods Inc.','Pierre','100193',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730338,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'AdvancePierre Fully Cooked Beef Rib Patties with Honey BBQ Sauce, 3.25 oz','SMKG CN CMDT FC FBLD BF PAT HBBQ 20',124892,NULL,'00071421037166','Tyson Foods Inc.','Smokie Grill','100154',3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717124,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'AdvancePierre Fully Cooked Breaded Beef Fingers, 0.90 oz','APF CN CMDT FC BRD BF STK STCK SHP ',124893,NULL,'00880760096594','Tyson Foods Inc.','Advance Pierre','100154',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730222,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'AdvancePierre Fully Cooked Whole Grain Breaded Beef Patties, 3.35 oz.','APF CN CMDT FC BRD BF STK 29.94 LB',124894,NULL,'00880760096600','Tyson Foods Inc.','Advance Pierre','100154',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730232,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'AdvancePierre Fully Cooked Philly Beef Steak, 2.5 oz.','APF CN CMDT FC SLCD SSND BF BWBP 30',124895,NULL,'00797179536859','Tyson Foods Inc.','Advance Pierre','100154',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724166,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bosco 7 Bulk Whole Grain Breadstick filled with Cheese, Sauce and Pepperoni','BCPZ WG BDST CHSE SCE PRNI BULK 72C',124896,NULL,'10721931000651','Tyson Foods Inc.','Boscos Pizza','110244',3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717274,'50193300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bosco Individually Wrapped Whole Grain Garlic Flavored Cheese Stuffed Breadsticks, 2.23 oz.','BCPZ WG 6 INCH IW GAR BDST MOZZ 9.5',124897,NULL,'00031400091299','Tyson Foods Inc.','Boscos Pizza','110244',3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717655,'50193300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bosco Whole Grain 100% LMPS Cheese Stuffed Breadsticks, 2.15 oz.','BCPZ 5" WG BDST MOZZ CHSE 144 CNT',124898,NULL,'00031400091626','Tyson Foods Inc.','Boscos Pizza','110244',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724877,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bosco Whole Grain Cheese Pizza Sticks, 3.77 oz.','BCPZ 7 INCH WG CHSE PZ BDST 72/3.82',124899,NULL,'00031400091589','Tyson Foods Inc.','Boscos Pizza','110244',3,'2024-11-14','2025-03-20','2025-01-08','UNPREPARED',2724876,'50193300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bosco Whole Grain Low Moisture Part-Skim Cheese Stuffed Breadsticks, 2.99 oz. with Bags','BCPZ 7 INCH BDST MOZZ CHSE 108 CNT',124900,NULL,'10721931000231','Tyson Foods Inc.','Boscos Pizza','110244',3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717271,'50193300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bosco Whole Grain Reduced Fat Cheese Stuffed Breadsticks, 2.15 oz.','BCPZ 6 WG BDST FILD MOZZ CHSE 19.2 ',124901,NULL,'10721931000569','Tyson Foods Inc.','Boscos Pizza','110244',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724494,'50193300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bosco Whole Grain Reduced Fat Cheese Stuffed Breadsticks, 2.96 oz.','BCPZ 7 INCH WGR BDST MOZZ CHSE 108 ',124902,NULL,'10721931000262','Tyson Foods Inc.','Boscos Pizza','110244',3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717272,'50193300');
INSERT INTO `cndb_fdes` VALUES (NULL,'FC Flamebroiled Beef Patty W/Onion & American Cheese Mini Twin Sandwich On A WG Bun','PRRE CN CMDT FC CHSB WG BUN TWPK 28',124903,NULL,'30071421000895','Tyson Foods Inc.','Pierre','100154',3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717151,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'FC Flamebroiled Beef Patty W/Onion & American Cheese Mini Twin Sandwich On A WG Bun','PRRE CN CMDT FC CHSB WG BUN TWPK 28',124904,NULL,'00071421000894','Tyson Foods Inc.','Pierre','100154',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2717746,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'FC MTLF with CDR CHSE Topped with KTCUP, MNI Twin SAND on a WG Bun','BLPK CN CMDT FC MTLF SAND TWPK 80/4',124905,NULL,'00054500000213','Tyson Foods Inc.','Ball Park','100154',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718545,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fully Cooked Grilled Chicken Breast Filets with Rib Meat','TRL FC GRL BST FLT 2/5 LB',124906,NULL,'00023700054036','Tyson Foods Inc.','Tyson Red Label','100103',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721487,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fully Cooked Grilled Chicken Breast Filets with Rib Meat','TRL FC GRL BST FLT 2/5 LB',124907,NULL,'00023700025500','Tyson Foods Inc.','Tyson Red Label','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723703,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fully Cooked Grilled Chicken Sandwiches, Grilled Chicken Patties on Whole Grain Buns With Hot Pepper Cheese','TYS CMDT GRL CKN SAND TWPK 80/5.12',124908,NULL,'00023700058034','Tyson Foods Inc.','Tyson','100103',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721490,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fully Cooked Grilled Chicken Sandwiches, Grilled Chicken Patties on Whole Grain Buns With Hot Pepper Cheese','TYS CMDT GRL CKN SAND TWPK 80/5.12',124909,NULL,'30023700058035','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717220,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hillshire Farm Beef Crumbles, 2.4 oz.','APF CN CMDT CKD BF PAT CRMB 40 LB',124910,NULL,'10020534027721','Tyson Foods Inc.','Hillshire Farm','100154',3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717250,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fajita Dark Meat Chicken Strips, 3 oz.','TYS FC BLSL DK CKN FAJ STP SFA 6/5L',124911,NULL,'00023700022929','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723702,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked All Natural* Low Sodium Pulled Chicken, Reverse Blend 65 Dark/35 White Meat Chicken ','TYS ALL NT LSDM PU DK WH CKN 2/5 LB',124912,NULL,'00023700048608','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730905,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Chicken Drumsticks ','TYS FC BRD CKN DRMS 29.64 LB',124913,NULL,'00023700039002','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730847,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Breaded Homestyle Whole Muscle Boneless Chicken Wings','TYS FC WG WM CKN CHNK 30.24 LB',124914,NULL,'00023700055446','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723958,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Fajita Chicken Strips, CN ','TYS CN FC CKN FAJ STP 30 LB',124915,NULL,'00023700057594','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730911,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Glazed Bone-In Chicken Wing Sections','TYS FC GLZ CKN WNG SECT 30 LB',124916,NULL,'00023700050786','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723983,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Glazed Chicken Drumsticks ','TYS FC GLZ CKN DRMS 30 LB',124917,NULL,'00023700041647','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730850,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Unbreaded Grilled MWWM Chicken Breast Filets, 2.26 oz. ','TYS CN FC GLZ GRL BST FLT 30.39 LB',124918,NULL,'00023700033987','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723668,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Mesquite Glazed Chicken Drumsticks','TYS FC GLZ CKN DRMS SFA 30 LB',124919,NULL,'00023700041654','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730874,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Roasted Boneless Skinless Chicken Leg Meat Strips','TYS FC RSTD CKN LEG STP 6/5 LB',124920,NULL,'00023700037824','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723988,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Unbreaded Chicken Drumsticks With BBQ Sauce Packets','TYS FC GLZ CKN DRMS BBQ GLZ 31.25 L',124921,NULL,'00023700055910','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723959,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Tempura Whole Grain Battered Chicken Nuggets, CN, 0.75 oz.','TYS CN FC WG BTD CKN CHNK 23.12 LB',124922,NULL,'00031400044639','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723834,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Chicken Nuggets, CN, 0.79 oz.','TYS CN FC BRD CKN PAT WG 26.42 LB',124923,NULL,'00023700040664','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723998,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Chicken Nuggets, CN, 0.66 oz. ','TYS CN FC CKN CHNK FRT 28.35 LB',124924,NULL,'00023700100832','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723963,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Chicken Nuggets, CN, 0.68 oz. ','TYS CN FC WG BRD CKN PAT 4/7.65 LB',124925,NULL,'00023700038265','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723989,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Chicken Patties, CN, 4.07oz ','CN FC WG BRD CKN PAT 26.25 LB',124926,NULL,'00023700037817','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723987,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Chicken Patties, White/Dark Meat, CN, 3.4 oz.','TYS CN FC WG BRD CKN PAT 4/7.65 LB',124927,NULL,'00023700036209','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723800,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Chicken Patties, CN, 3.29 oz.','TYS CN WG CKN PAT FRT 4/7.7 LB',124928,NULL,'00023700100771','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723962,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded, Glazed Nashville Hot MWWM Chicken Tenders, 1.55 oz.','TYS FC PTND BRD CKN BST TNDR 6/5.1 ',124929,NULL,'00023700051233','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723968,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Golden Crispy Chicken Patties, CN, 1.6 oz.','TYS CN FC WG BRD CKN PAT 20 LB',124930,NULL,'00023700040091','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723997,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Golden Crispy Chicken Patties, CN, 3 oz.','TYS CN FC WG GLDN CSPY CKN FRT 32.8',124931,NULL,'00023700033895','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724807,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Golden Crispy Formed Chicken Tenders, CN 1.13 oz.','TYS CN WG CSPY CKN PAT FRT 31.86 LB',124932,NULL,'00023700033857','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724804,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Golden Crispy Chicken Breast Chunks CN, 0.79 oz.','TYS CN FC WG BRD CKN BST CHNK 30 LB',124933,NULL,'00023700035592','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724812,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Golden Crispy MWWM Chicken Breast Filets, CN, 3.75 oz.','TYS CN WG CSPY BRD CKN BST 30.94 LB',124934,NULL,'00023700035455','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723671,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Golden Crispy MWWM Chicken Tenders, CN 2.07 oz. ','TYS CN CSPY BRD CKN TNDR 30.99 LB',124935,NULL,'00023700035479','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724811,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Golden Crispy Popcorn Chicken Bites Chicken Chunks CN, 0.28 oz.','TYS CN FC WG CSPY PPN CKN 32.79 LB',124936,NULL,'00023700033864','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730845,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Homestyle Chicken Breast Chunks CN, 0.78 oz.','TYS CN FC WG BRD CKN BST CHNK 10LB',124937,NULL,'00023700034434','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730846,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Homestyle Chicken Tenderloins ','TYS FC HMST BRD CKN TNDR 30 LB',124938,NULL,'00023700050724','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723984,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Homestyle MWWM Chicken Breast Strips, 1.5 oz.','TYS CN FC WG HMST BST STP 30.9 LB',124939,NULL,'00023700043900','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723999,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Hot & Spicy Chicken Patties, CN, 3.26 oz. ','TYS CN FC WG HS BRD CKN PAT 30.28 L',124940,NULL,'00023700040336','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730848,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Hot & Spicy MWWM Chicken Breast Filets, CN, 3.75 oz. ','TYS CN PT HS BRD CKN BST 30.94 LB',124941,NULL,'00023700035448','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724810,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Hot & Spicy Popcorn Chicken CN, 0.275 oz. ','TYS CN FC WG HS PPN CKN 32.79 LB',124942,NULL,'00023700033871','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724806,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Hot & Spicy Chicken Patties, CN, 3 oz. ','TYS CN FC WG HS CKN PAT FRT 32.82 L',124943,NULL,'00023700033901','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724808,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Hot & Spicy Formed Chicken Tenders, CN 1.14 oz.','TYS CN FC WG HS TNDR CKN FRT 31.86L',124944,NULL,'00023700033932','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723667,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Whole Grain Breaded Hot ''N Spicy MWWM Boneless Chicken Wings, 0.76 oz.','TYS CN FC PTND HS BRD CKN CHNK 30 L',124945,NULL,'00023700035608','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724813,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Hot & Spicy MWWM Chicken Tenders, CN 2.05 oz.','TYS CN FC HS BRD CKN TNDR 30.996LB',124946,NULL,'00023700035462','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723672,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Mini Chicken Corn Dogs, CN, 0.67 oz.','TYS CN FC MIN CKN CDOG 4/7.5 LB',124947,NULL,'00023700049469','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724010,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked, Whole Grain Breaded, Pancake Flavored Chicken Sausage Bites, 0.58 oz.','TYS FC PNCK CKN SAU BTS CN 30 LB',124948,NULL,'00023700050106','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724011,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Breaded Popcorn Chicken Bites Chicken Chunks CN, 0.257 oz. ','TYS CN FC WG PPN CKN 30 LB',124949,NULL,'00023700039897','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723995,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Whole Grain Battered Chicken Corn Dogs, 4 oz.','STFR CN FC WG UCRD CKN CDOG 48/4 OZ',124950,NULL,'00023700050274','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724012,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Whole Grain Fritter Golden Crispy Chicken Fries, CN, .43oz ','TYS CN FC WG CSPY CKN STCK FRT 31.5',124951,NULL,'00023700033802','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723661,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked, Grilled Chicken Patties','TYS NAIHM CN FC GRL CKN PAT 4/7.5 L',124952,NULL,'00023700049766','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730907,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked, Whole Grain Breaded Dill Flavored Whole Muscle Chicken Chunks','TYS FC WG BRD BLSL DILL CKN CHNK 4/',124953,NULL,'00023700050359','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-04-24','2025-02-26','UNPREPARED',2730908,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked, Whole Grain Breaded Hot ''N Spicy Whole Muscle Chicken Breast Filets, 4.0 oz.','TYS FC HS BRD CKN BST FLT 30 LB',124954,NULL,'00023700037121','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724814,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked, Wings of Fire Chicken Wings','TYS ALL NT FC WOF CKN WNG 30 LB',124955,NULL,'00023700051547','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730909,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Krisp N'' Krunchy Fully Cooked Whole Grain Breaded Chicken Patties, CN, 3.53 oz.','TYS CN FC WG CKN PAT FRT 31.05 LB',124956,NULL,'00023700037800','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723986,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Krisp N'' Krunchy Fully Cooked Whole Grain Breaded Formed Chicken Tenders, CN 1.2 oz. ','TYS CN FC WG CKN PAT FRT 31.86 LB',124957,NULL,'00023700037794','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723833,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Mega Minis Fully Cooked Whole Grain Breaded Homestyle MWWM Chicken Breast Chunks CN, 0.43 oz. ','TYS CN FC HMST BRD BST CHNK 30.26 L',124958,NULL,'00023700047441','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730901,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Mega Minis Fully Cooked Whole Grain Breaded Homestyle Waffle MWWM Chicken Breast Chunks CN, 0.54 oz. ','TYS CN FC WG PTND CKN BST CHNK FRT ',124959,NULL,'00023700047625','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724005,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Breaded Honey Sriracha Glazed Chicken Breast Chunks CN, 0.86 oz.','TYS CN FC BRD CKN HON SRCH 4/7.125L',124960,NULL,'00023700044365','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724000,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Mega Minis Fully Cooked Whole Grain Breaded, Glazed Nashville Hot Style MWWM Chicken Breast Chunks CN, 0.45 oz. ','TYS FC GLZ BRD BST CHNK CN 4/7.9 LB',124961,NULL,'00023700049131','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724009,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Mega Minis Fully Cooked Whole Grain Breaded Homestyle Chicken Chunks, 0.43 oz.','TYS CN MEGA MNI FC BRD PPN CKN 30.2',124962,NULL,'00023700058485','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730912,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Breaded Assorted Chicken Pieces ','TYS FC BRD AST CKN PCE 29.64 LB',124963,NULL,'00023700032621','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723659,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson ProPortion Fully Cooked Glazed Mesquite Smoke Flavor Added, Assorted Chicken Pieces ','TYS FC GLZ AST CKN PCE 4/5.77 LB',124964,NULL,'00023700039163','Tyson Foods Inc.','Tyson','100103',3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2723992,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Red Label Fully Cooked Unbreaded Grilled Chicken Breast Filets, 3 oz. ','TRL FC GRL BST FLT 10 LB',124965,NULL,'00023700026415','Tyson Foods Inc.','Tyson Red Label','100103',3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717335,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s 100% Tomato Juice, 5.5 fl oz Can (6 Pack)','TOMATO JUICE',124966,NULL,'00051000000071','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717595,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pancake, Bites, Poffitz, Bulk, 1.75" x 1"','Pancake Bites Poffitz Blk 1.75"x',124967,NULL,'00737410016764','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2716938,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'TREE TOP JUICE SWEETENED CINNAMON APPLESAUCE 12/6/4OZ','TT JUICE SW CINN APSCE 6/4OZ',124968,NULL,'00028700011867','TREE TOP INC.','Tree Top Inc.',NULL,3,'2024-11-14','2024-11-14',NULL,'READY_TO_EAT',2717681,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Blueberry 16.9oz 120ct','Pop-Tarts',124969,NULL,'00038000171963','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721007,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Cheez It Crackers Whole Grain 1oz 60ct','Cheez-It Crackers',124970,NULL,'00024100104802','Kellogg Company US','Kellogg''s Cheez It',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721506,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Diced Tomatoes, 102oz Can','Red Gold Diced Tomatoes',124971,NULL,'00072940110170','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718029,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Diced Tomatoes, 102oz Can - CS of 6','Red Gold Diced Tomatoes',124972,NULL,'30072940110171','Red Gold, Inc.','Red Gold',NULL,3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724501,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Low Sodium Enchilada Sauce, 106oz Can - Case of 6','Red Gold Enchilada Sauce Low Sodium',124973,NULL,'30072940100943','Red Gold, Inc.','Red Gold',NULL,3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724500,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Organic Ketchup, 20oz Bottle - Case of 12','Red Gold Organic Ketchup',124974,NULL,'10072940111204','Red Gold, Inc.','Red Gold',NULL,3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724459,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'24/10 OZ TREE TOP THREE APPLE BLEND JUICE CASE','THREE APPLE BLEND JUICE 24/10OZ CS',124975,NULL,'00028700018514','TREE TOP INC.','TREE TOP',NULL,3,'2024-11-14','2024-11-14',NULL,'READY_TO_DRINK',2717682,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Whole Grain, Margarine, Round, Sliced, 3.5" x 1.4"','Croiss WG Marg Rnd Sl 3.5"x1.4"',124976,NULL,'00737410008899','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-11-14','2025-04-24',NULL,'UNPREPARED',2730171,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Migliore Diced Tomatoes, 102oz Can - CS of 6','Migliore Diced Tomatoes',124977,NULL,'30072940814079','Red Gold, Inc.','Migliore',NULL,3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724502,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Migliore Tomato Puree 1.045, 105oz Can - Case of 6','Migliore Tomato Puree',124978,NULL,'30072940816004','Red Gold, Inc.','Migliore',NULL,3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724504,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Migliore Tomato Sauce, 106oz Can - Case of 6','Migliore Tomato Sauce',124979,NULL,'30072940814116','Red Gold, Inc.','Migliore',NULL,3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724503,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Barbecue Sauce, 1.5 Gallon Pouch - Case of 2','Red Gold Barbecue Sauce',124980,NULL,'70072940111190','Red Gold, Inc.','Red Gold',NULL,3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717194,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Naturally Balanced Barbecue Sauce, 1 Gallon Jug - Case of 4','Red Gold Barbecue Sauce',124981,NULL,'50072940001183','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2723183,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Tomato Paste, 1.5oz Packet - Case of 200','Red Gold Tomato Paste',124982,NULL,'90072940747560','Red Gold, Inc.','Red Gold',NULL,3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717698,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Tomato Paste,111oz Pouch - Case of 6','Red Gold Tomato Paste',124983,NULL,'30072940750643','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719220,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Frosted Flakes Cereal Multi Grain 1oz','Frosted Flakes Cereal',124984,NULL,'00038000114663','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720920,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Frosted Flakes Cereal Multi Grain 1oz 96ct','Frosted Flakes Cereal',124985,NULL,'00038000114656','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720951,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Soft Baked Bar, Cocoa 1.5oz','Cocoa Soft Baked bar',124986,NULL,'20810358036163','National Food Group','Zee Zees',NULL,3,'2024-11-14','2024-11-14',NULL,'READY_TO_EAT',2717197,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Healthy Request Mediterranean Style Vegetable Soup, 4 Pound Trays, 3-Pack','CUL RES HR MED VEG',124987,NULL,'00051000191236','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717318,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Healthy Request Cream of Chicken Soup, 50 Ounce Cans, 12-Pack','HR CR CHICKEN',124988,NULL,'00051000041432','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724193,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Healthy Request Cream of Mushroom Soup, 50 Ounce Cans, 12-Pack','CAMPBELLS HR CREAM OF MUSHROOM',124989,NULL,'00051000041449','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724194,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Healthy Request Tomato Soup, 50 Ounce Cans, 12-Pack','CAMPBELL''S HR TOMATO SOUP',124990,NULL,'00051000041456','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-11-14','2025-03-20',NULL,'UNPREPARED',2724195,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack  Tomato Puree, 106oz Can','Redpack Tomato Puree',124991,NULL,'00072940817017','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719030,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Fully Prepared Pizza Sauce, 106oz Can','Redpack Pizza Sauce Fully Prepared',124992,NULL,'00072940748861','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719073,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Tomato Sauce, 106oz Can','Redpack Tomato Sauce',124993,NULL,'00072940818007','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719031,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mama Selita''s Jalapeno Ketchup, 20oz Bottle','Mama Selita''s Jalapeno Ketchup',124994,NULL,'00072940001171','Red Gold, Inc.','Mama Selita''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2717993,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold  Tomato Puree, 106oz Can - Case of 6','Red Gold Tomato Puree',124995,NULL,'30072940110065','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719058,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Barbecue Sauce Naturally Balanced 114oz','Red Gold Barbecue Sce Naturally Bal',124996,NULL,'00072940747390','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2025-03-20','2025-01-30','UNPREPARED',2723235,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Chopped Tomatoes in Puree, 102oz Can - Case of 6','Red Gold Chopped Tomatoes in Puree',124997,NULL,'30072940110416','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719136,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup with Sugar, 1.5 Gallon Pouch','Red Gold Ketchup with Sugar',124998,NULL,'00072940000136','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719259,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup with Sugar, 1.5 Gallon Pouch - Case of 2','Red Gold Ketchup with Sugar',124999,NULL,'60072940000138','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719103,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 1.5 Gallon Pouch','Red Gold Ketchup Pouch',125000,NULL,'00072940115625','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719160,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 1.5 Gallon Pouch - Case of 3','Red Gold Ketchup Pouch',125001,NULL,'60072940115627','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719109,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 112oz Can - Case of 6','Red Gold Ketchup',125002,NULL,'30072940115992','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719157,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 14oz Bottle','Red Gold Ketchup',125003,NULL,'00072940000075','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2717992,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 20oz Bottle','Red Gold Ketchup',125004,NULL,'00072940115212','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718066,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 3 Gallon','Red Gold Ketchup',125005,NULL,'00072940115601','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719254,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 64oz Bottle','Red Gold Ketchup',125006,NULL,'00072940115649','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718068,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Ketchup, 7 gram Packet - Case of 1000','Red Gold Ketchup',125007,NULL,'60072940100951','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719104,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Mustard Jug with Pump 105oz - CS of 4','Red Gold Mustard Yellow Plastic Jug',125008,NULL,'50072940747487','Red Gold, Inc.','Red Gold',NULL,3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717190,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Mustard Yellow Plastic Jug 105oz','Red Gold Mustard Yellow Plastic Jug',125009,NULL,'00072940747482','Red Gold, Inc.','Red Gold',NULL,3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717219,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Stewed Tomatoes, 102oz Can','Red Gold Stewed Tomatoes',125010,NULL,'00072940110149','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719239,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Tomato Juice + Vit C, 46oz Can - CS of 12','Red Gold Tomato Juice + Vit C',125011,NULL,'10072940110535','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719045,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Tomato Puree 1.045, 105oz Can','Red Gold Tomato Puree',125012,NULL,'00072940110071','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719233,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Tomato Puree 1.045, 105oz Can - Case of 6','Red Gold Tomato Puree',125013,NULL,'30072940110072','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719091,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Tomato Strips and Pieces in Puree, 102oz Can','RG Tomato Strips & Pieces in Puree',125014,NULL,'00072940110354','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719243,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Tomato Strips and Pieces in Puree, 102oz Can - CS of 6','RG Tomato Strips & Pieces in Puree',125015,NULL,'30072940110355','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719134,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Chopped Tomatoes in Puree, 102oz Can - Case of 6','Redpack Chopped Tomatoes in Puree',125016,NULL,'30072940812044','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719153,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Petite Diced Tomatoes, 102oz Can','Redpack Petite Diced Tomatoes',125017,NULL,'00072940811008','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719084,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Sloppy Joe Sauce, 108oz Can - Case of 6','Redpack Sloppy Joe Sauce',125018,NULL,'30072940741504','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719146,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Redpack Stewed Tomatoes, 102oz Can - CS of 6','Redpack Stewed Tomatoes',125019,NULL,'30072940813003','Red Gold, Inc.','Redpack',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719154,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sacramento Bloody Mary Mix 46oz','Sacramento Bloody Mary Mix',125020,NULL,'00072940762010','Red Gold, Inc.','Sacramento',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718074,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sacramento Tomato Juice, 46oz Bottle','Sacramento Tomato Juice',125021,NULL,'00072940760016','Red Gold, Inc.','Sacramento',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718072,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sacramento Tomato Juice, 46oz Can','Sacramento Tomato Juice',125022,NULL,'00072940760023','Red Gold, Inc.','Sacramento',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719082,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sacramento Vegetable Juice, 46oz Can','Sacramento Vegetable Juice',125023,NULL,'00072940761006','Red Gold, Inc.','Sacramento',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718073,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Teresa Traditional Spaghetti Sauce, 106oz Can - CS of 6','Teresa Spaghetti Sauce',125024,NULL,'30072940814130','Red Gold, Inc.','Teresa White',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719126,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Teresa White Crushed Tomatoes, 105oz Can - Case of 6','Teresa White Crushed Tomatoes',125025,NULL,'30072940814031','Red Gold, Inc.','Teresa White',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719156,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Vine Ripe Diced Tomatoes No Salt Added, 14.5oz Can','Vine Ripe Diced Tomatoes NSA',125026,NULL,'00072940120049','Red Gold, Inc.','Vine Ripe','100328',3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2724105,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Vine Ripe Diced Tomatoes, 102oz Can - CS of 6','Vine Ripe Diced Tomatoes',125027,NULL,'30072940120200','Red Gold, Inc.','Vine Ripe',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719144,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'2x6 Breakfast Pizzazz Whole Grain Sausage, 2.44 oz, CN','MX BRKFST WG PZ SSG 2X6 192/2.44Z',125028,NULL,'10077387125623','Conagra Brands, Inc','The MAX',NULL,3,'2024-11-14','2024-11-14',NULL,'BAKE',2717315,'50193500');
INSERT INTO `cndb_fdes` VALUES (NULL,'3x4 Breakfast Pizzazz, Turkey Sausage, Whole Grain, 2.66 oz, CN','MAX WG 3x4 T SAUS BRKF PIZZA 192/2.',125029,NULL,'20077387127082','Conagra Brands, Inc','The MAX',NULL,3,'2024-11-14','2024-11-14',NULL,'BAKE',2717289,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'4x6 100% Mozzarella, Whole Grain, 4.65 oz, CN','MAX 4X6 WG CHS FFK PZA MOZZ 96/4.65',125030,NULL,'10077387125845','Conagra Brands, Inc','The MAX',NULL,3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717306,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'4x6 Cheese, Whole Grain, 4.56 oz, CN','MAX 4X6 WG CHS FFK PIZZA PK 96/4.56',125031,NULL,'10077387126552','Conagra Brands, Inc','The MAX',NULL,3,'2024-11-14','2024-11-14',NULL,'BAKE',2717308,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'4x6 Turkey Sausage, Whole Grain, 4.56 oz, CN','MAX 4X6 WG FFK TURKEY SAUSAGE 96/4.',125032,NULL,'20077387127037','Conagra Brands, Inc','The MAX',NULL,3,'2024-11-14','2024-11-14',NULL,'BAKE',2717288,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'AdvancePierre Flame Grilled Beef Steak Burger, 3 oz.','APF CMDT FC PUB STYL BF STK BURG 30',125033,NULL,'00880760038150','Tyson Foods Inc.','Advance Pierre','100154',3,'2024-10-31','2024-10-31',NULL,'UNPREPARED',2716326,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Extra Cheese Real Slice Pepperoni pizza wedge, 4.8oz, CN','MX XTRA CHS RS WG PEPRONI PZA 96/4.',125034,NULL,'20077387126184','Conagra Brands, Inc','The MAX',NULL,3,'2024-11-14','2024-11-14',NULL,'BAKE',2717285,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fit for Kids Plus, MaxStix, Cheese Filled Breadsticks, Whole Grain, 2 pieces, 1.95 oz, CN','MAX STIX FFK PLUS WG CHS 192/1.95Z',125035,NULL,'20077387127228','Conagra Brands, Inc','The MAX',NULL,3,'2024-11-14','2024-11-14',NULL,'UNPREPARED',2717221,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fit for Kids Plus, Stuffed Crust, Cheese, Whole Grain, 4.8 oz, CN','MAX SC FFK PLUS WG CHS 72/4.8Z',125036,NULL,'20077387127167','Conagra Brands, Inc','The MAX',NULL,3,'2024-11-14','2024-11-14',NULL,'BAKE',2717290,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fit for Kids Plus, Stuffed Crust, Turkey Pepperoni, Whole Grain, 4.8 oz, CN','MAX SC FFK PLUS WG T.PEPP 72/4.8Z',125037,NULL,'20077387127174','Conagra Brands, Inc','The MAX',NULL,3,'2024-11-14','2024-11-14',NULL,'BAKE',2717222,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'MaxSnax Cheesiest Con Queso, Whole Grain,  3 pieces, 4.02 oz, CN','MAX SNAX WG CON QUESO CN 96/4.02Z',125038,NULL,'10077387126583','Conagra Brands, Inc','The MAX',NULL,3,'2024-11-14','2024-11-14',NULL,'BAKE',2717309,'50193400');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pizza Quesadilla, Cheese, Whole Grain, 4.8 oz, CN','MAX WG PIZZA QUESADILLA CHS 96/4.83',125039,NULL,'20077387126993','Conagra Brands, Inc','The MAX',NULL,3,'2024-11-14','2024-11-14',NULL,'BAKE',2717287,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Real Slice Pepperoni, 100% Mozzarella,  Whole Grain, 4.67 oz, CN','MAX RS WG 100 MOZZ PEP PZA PK 96/4.',125040,NULL,'20077387126863','Conagra Brands, Inc','The MAX',NULL,3,'2024-11-14','2024-11-14',NULL,'BAKE',2717286,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stuffed Crust Cheese, 100% Mozzarella,  Whole Grain, 5 oz, CN','MAX STFD CRST WG MOZZ CHS 72/5.0Z',125041,NULL,'10077387126163','Conagra Brands, Inc','The MAX',NULL,3,'2024-11-14','2024-11-14',NULL,'BAKE',2717307,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stuffed Crust Whole Grain Sausage, 4.95 oz, CN','MX WG STFD CRUST SAUSAGE 72/4.95Z',125042,NULL,'10077387124091','Conagra Brands, Inc','The MAX',NULL,3,'2024-11-14','2024-11-14',NULL,'BAKE',2717305,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Meat Combo Calzone, 4.69 oz, CN','GIL WHL GRN MT CALZN 60/4.69Z',125043,NULL,'20016272201216','Conagra Brands, Inc','Gilardi',NULL,3,'2024-10-31','2024-10-31',NULL,'BAKE',2716065,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Three Cheese Calzone, 4.69 oz, CN','GIL WHL GRN THREE CHS CALZN 60/4.69',125044,NULL,'20016272201209','Conagra Brands, Inc','Gilardi',NULL,3,'2024-10-31','2024-10-31',NULL,'BAKE',2716066,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'SFS BIG DADDY''S BUF CHIC STF SAND WG  NET WT 13.38LBS 48CT','BD BUF CHIC SAND',125045,NULL,'10072180702538','SCHWAN''S FOOD SERVICE INC','BIG DADDY''S',NULL,3,'2024-10-31','2025-01-23',NULL,'UNPREPARED',2722526,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'SpaghettiOs Original Canned Pasta, 22.4 oz Can','CPB SPAGOS',125046,NULL,'00051000212245','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-10-31','2024-10-31',NULL,'UNPREPARED',2715783,'50193300');
INSERT INTO `cndb_fdes` VALUES (NULL,'THE MAX Whole Grain Quesadilla Chicken Pizza, 5 OZ','MX WG PIZZA QUESADILLA CHKN 96/5Z',125047,NULL,'00077387127002','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'UNPREPARED',2716220,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Grain Pepperoni Calzone, 4.69 oz, CN','GIL WG PEPPRONI CALZONE 60/4.69Z',125048,NULL,'20016272201230','Conagra Brands, Inc','Gilardi',NULL,3,'2024-10-31','2024-10-31',NULL,'UNPREPARED',2716064,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Cinnamon, No Added Sugar, 4.5 oz.','No Added Sugar Cinnamon Applesauce',125049,NULL,'00185043000412','National Food Group  Inc.','Zee Zees',NULL,3,'2024-10-31','2025-01-23',NULL,'READY_TO_EAT',2722988,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Swirls, Whole Grain, Individually Wrapped, 3.75" x 1.75"','Choc Swirls, WG, IW, 3.75"x1.75"',125050,NULL,'00737410016658','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-10-31','2024-10-31',NULL,'UNPREPARED',2716209,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Knot, Garlic, Whole Grain, 1.3 oz','Knot, Garlic, Whole Grain, 1.3 oz',125051,NULL,'00737410017853','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-10-31','2025-03-20',NULL,'UNPREPARED',2724100,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Knot, Garlic, Whole Grain, 2.0 oz.','Knot, Garlic, Whole Grain, 2.0 oz',125052,NULL,'00737410017860','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-10-31','2024-10-31',NULL,'UNPREPARED',2716205,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'WGR Mac & Cheese Clean Label 6/5#  30#','WGR Mac & Cheese Clean Label',125053,NULL,'00049485057765','JTM Food Group','JTM Food Group',NULL,3,'2024-10-31','2024-10-31',NULL,'PREPARED',2715990,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Gripz Crackers Chocolate Chip .95oz','Gripz Crackers',125054,NULL,'00030100807438','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2723884,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Texas Toast, Whole Grain, Loaves (190 slices per case)','Texas Tst WG Loaves (190 slices per',125055,NULL,'00737410331300','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-10-31','2024-10-31',NULL,'UNPREPARED',2716132,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Maple Waffle, Whole Grain, Chicken Sausage & Cheese, Individually Wrapped','Sndwch Mpl Waffle WG Chkn Ssg&Chs I',125056,NULL,'00737410067445','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-10-31','2024-10-31',NULL,'UNPREPARED',2716257,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naked 100% Juice Blue Machine 10 Fl Oz','Naked Blue Machine 10 Fl Oz',125057,NULL,'00082592010179','PepsiCo Inc. Brand Owner','Naked',NULL,3,'2024-10-31','2025-03-20',NULL,'UNPREPARED',2723314,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Real Slice Cheese, Whole Grain, 4.67 oz, CN','MX RS WG CHEESE PIZZA, 96/4.67Z',125058,NULL,'20077387126801','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'BAKE',2716159,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees, Applesauce Cup, Birthday Cake, No Added Sugar, 4.5oz','NSA Birthday Cake Applesauce',125059,NULL,'20810358035944','National Food Group  Inc.','Zee Zees',NULL,3,'2024-10-31','2024-10-31',NULL,'READY_TO_EAT',2716129,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Process American Cheese Spread Loaf - 5#','5# Y Pr Am Chs Sprd',125060,NULL,'00071078202740','Bongards Creameries','Bongards',NULL,3,'2024-10-31','2024-10-31',NULL,'PREPARED',2715838,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Real Slice, 100% Mozzarella, Whole Grain, 4.67 oz, CN','MAX RS WG 100 MOZZ CHS 96/4.67Z',125061,NULL,'20077387126870','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'BAKE',2716156,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Straw Banana, Unsweetened, 4.5 oz.','Strawberry Banana Applesauce',125062,NULL,'00185043000368','National Food Group  Inc.','Zee Zees',NULL,3,'2024-10-31','2024-10-31',NULL,'READY_TO_EAT',2716185,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Strawberry, No Added Sugar, 4.5 oz.','Strawberry Applesauce No Ad''d Sugar',125063,NULL,'00185043000405','National Food Group  Inc.','Zee Zees',NULL,3,'2024-10-31','2025-01-23',NULL,'READY_TO_EAT',2722669,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees, Applesauce Cup, Wild Watermelon, No Added Sugar, 4.5oz','NSA Watermelon Applesauce',125064,NULL,'20810358035968','National Food Group  Inc.','Zee Zees',NULL,3,'2024-10-31','2025-03-20',NULL,'READY_TO_EAT',2724496,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Birthday Cake, 4.5 oz.','Birthday Cake Applesauce Commodity',125065,NULL,'00185043000443','National Food Group  Inc.','Zee Zees',NULL,3,'2024-10-31','2024-10-31',NULL,'READY_TO_EAT',2716202,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Mango Peach, Unsweetened, 4.5 oz.','Mango Peach Applesauce',125066,NULL,'00185043000320','National Food Group  Inc.','Zee Zees',NULL,3,'2024-10-31','2024-10-31',NULL,'READY_TO_EAT',2716186,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Original, Unsweetened, 4.5 oz.','Unsweetened Original Applesauce',125067,NULL,'00185043000702','National Food Group  Inc.','Zee Zees',NULL,3,'2024-10-31','2024-10-31',NULL,'READY_TO_EAT',2716217,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Peach, Unsweetened, 4.5 oz.','Unsweetened Peach Applesauce',125068,NULL,'00185043000375','National Food Group  Inc.','Zee Zees',NULL,3,'2024-10-31','2024-10-31',NULL,'READY_TO_EAT',2716191,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees, Applesauce Cup, Banana, No Added Sugar, 4.5oz','NSA Banana Applesauce',125069,NULL,'20810358035975','National Food Group  Inc.','Zee Zees',NULL,3,'2024-10-31','2024-10-31',NULL,'READY_TO_EAT',2716634,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees, Applesauce Cup, Pink Lemonade, No Added Sugar, I/W, 4.5 oz','NSA Pink Lemonade Applesauce',125070,NULL,'20810358035982','National Food Group  Inc.','Zee Zees',NULL,3,'2024-10-31','2024-10-31',NULL,'READY_TO_EAT',2716935,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Tomato Juice No Salt Added, 46oz Can','Red Gold Tomato Juice NSA',125071,NULL,'00072940143208','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718071,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Apple Cinnamon 20.8oz','Nutri-Grain Cereal Bars',125072,NULL,'00038000356483','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721294,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Apple Cinnamon 20.8oz 48ct','Nutri-Grain Cereal Bars',125073,NULL,'00038000356452','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721293,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Strawberry 20.8oz','Nutri-Grain Cereal Bars',125074,NULL,'00038000359484','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721303,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Strawberry 20.8oz 48ct','Nutri-Grain Cereal Bars',125075,NULL,'00038000359453','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721302,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Morningstar Farms Meal Solutions Sausage Style Crumbles 5lb 2ct','Meal Solutions',125076,NULL,'00028989102300','Kellogg Company US','Morningstar Farms',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721713,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Apple Cinnamon 1.3oz','Nutri-Grain Cereal Bars',125077,NULL,'00038000356216','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721292,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Strawberry 1.3oz','Nutri-Grain Cereal Bars',125078,NULL,'00038000359217','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721301,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'100% Mozzarella, 1.93 oz, CN','MAX 100PCT MOZZ WG STIX 192/1.93Z',125079,NULL,'20077387126023','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'UNPREPARED',2716163,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'4x6 Pepperoni, Reduced Fat, Whole Grain, 4.65 oz, CN','MAX 4X6 WG PEPP FFK PZA MOZZ 96/4.6',125080,NULL,'10077387125852','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'BAKE',2716049,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'4x6, Pepperoni, Whole Grain, 4.56 oz, CN','MAX 4X6 WG TRKY PEPP PIZZA FFK 96/4',125081,NULL,'10077387126569','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'BAKE',2716040,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'51% whole grain crust with blueberry bits, stuffed with a creamy cheese and topped with cinnamon sugar.','MAX TWSTDSTIX WHL GRN CINN BLBRY 96',125082,NULL,'20077387126115','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'HEAT_AND_SERVE',2716109,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fit for Kids Plus, 4x6, Cheese, Whole Grain, 4.68 oz, CN','MAX 4X6 FFK PLUS WG CHS 96/4.68Z',125083,NULL,'20077387127181','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'BAKE',2716153,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fit for Kids Plus, MaxSnax, Totally Taco, Whole Grain, 3 pieces, 4.09 oz, CN','MAX SNAX WG TACO 96/4.09Z',125084,NULL,'20077387127143','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'BAKE',2716154,'50193400');
INSERT INTO `cndb_fdes` VALUES (NULL,'MaxStix Mozzarella, Whole Grain, 1.93 oz, CN','MAXSTIX WG STICKS 192/1.93Z',125085,NULL,'20077387126856','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'BAKE',2716157,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Real Slice Extra Cheese pizza, 4.8oz, CN','MAX XTRA CHS RS WG MOZZ PZA 96/4.8Z',125086,NULL,'20077387126177','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'UNPREPARED',2716161,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stuffed Crust Cheese, 4.84 oz','MAX NON WG STFD CRST CHES 72/4.84Z',125087,NULL,'10077387124077','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'BAKE',2716045,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stuffed Crust Whole Grain Cheese, 4.84 oz, CN','MAX SC WG CHS PIZZA 72/4.84Z',125088,NULL,'20077387126719','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'UNPREPARED',2716160,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'THE MAX Cheese Quesadilla Pizza, 5 OZ','MAX NON WG CHS PIZZA QUESADILLA 48/',125089,NULL,'00077387125312','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'BAKE',2716241,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'"Minions" Cheese, Cooked Sausage Crumbles (Made with Turkey) & Egg Breakfast Wrap','Cheese, Sausage, Egg Breakfast Wrap',125090,NULL,'10706574978963','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704441,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chicken Salsa Verde Tamale','Chicken Salsa Verde Tamale',125091,NULL,'10706574999647','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704465,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chicken Salsa Verde Tamale','Chicken Salsa Verde Tamale',125092,NULL,'10706574999630','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704466,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chicken Salsa Verde Tamale','Chicken Salsa Verde Tamale',125093,NULL,'10706574999609','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704467,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chicken Salsa Verde Tamale - Wrapped in a Corn Husk','Chicken Salsa Verde Tamale',125094,NULL,'10706574998640','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704472,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chicken Salsa Verde Tamale - Wrapped in a Corn Husk','Chicken Salsa Verde Tamale',125095,NULL,'10706574998602','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704473,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shredded Beef Salsa Roja Tamale','Shredded Beef Salsa Roja Tamale',125096,NULL,'10706574999708','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704439,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shredded Beef Salsa Roja Tamale','Shredded Beef Salsa Roja Tamale',125097,NULL,'10706574999739','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704438,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shredded Beef Salsa Roja Tamale','Shredded Beef Salsa Roja Tamale',125098,NULL,'10706574999746','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704437,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shredded Beef Salsa Roja Tamale - Wrapped in a Corn Husk','Shredded Beef Salsa Roja Tamale',125099,NULL,'10706574998749','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704470,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shredded Beef Salsa Roja Tamale - Wrapped in a Corn Husk','Shredded Beef Salsa Roja Tamale',125100,NULL,'10706574998701','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704471,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shredded Pork & Salsa Roja and Cheese Tamale Wrapped in an Eco-Friendly Paper Husk','Shred. Pork & Salsa Roja/Chz Tamale',125101,NULL,'10706574997803','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704476,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shredded Pork Salsa Roja Tamale','Shredded Pork Salsa Roja Tamale',125102,NULL,'10706574999807','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704436,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shredded Pork Salsa Roja Tamale','Shredded Pork Salsa Roja Tamale',125103,NULL,'10706574999838','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704410,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shredded Pork Salsa Roja Tamale - Wrapped in a Corn Husk','Shredded Pork Salsa Roja Tamale',125104,NULL,'10706574998848','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704468,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shredded Pork Salsa Roja Tamale - Wrapped in a Corn Husk','Shredded Pork Salsa Roja Tamale',125105,NULL,'10706574998800','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704469,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shredded Pork Salsa Roja Tamale Wrapped in an Eco-Friendly Paper Husk BulkPack','Shredded Pork Salsa Roja Tamale',125106,NULL,'10706574999845','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704409,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stuffed Crust Pepperoni, Reduced Fat,  100% Mozzarella, Whole Grain, 5 oz, CN','MAX STFD CRST WG 100PCT CHS PEP 72/',125107,NULL,'10077387126156','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'UNPREPARED',2716042,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Two Cheese & Green Chile Tamale - Wrapped in a Corn Husk','Two Cheese & Green Chile Tamale',125108,NULL,'10706574998503','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704475,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Two Cheese & Green Chile Tamale - Wrapped in a Corn Husk','Two Cheese & Green Chile Tamale',125109,NULL,'10706574998541','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704474,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Two Cheese & Green Chile Tamale Wrapped in an Eco-Friendly Paper Husk','Two Cheese & Green Chile Tamale',125110,NULL,'10706574987507','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-09-13','2024-09-13',NULL,'HEAT_AND_SERVE',2704485,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'MaxStix Mozzarella, Whole Grain, 1.93 oz, CN','MX MAXSTIX WG 192/1.93Z',125111,NULL,'10077387124398','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'UNPREPARED',2716043,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Instant Oatmeal Apples & Cranberries 1.79 Oz Cup','Quaker Apples&Crnberis 1.79 Oz',125112,NULL,'00030000319550','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2024-09-13','2024-09-13',NULL,'UNPREPARED',2705198,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Instant Oatmeal Honey & Almonds 1.76 Oz Cup','Quaker Honey & Almonds 1.76 Oz',125113,NULL,'00030000319574','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2024-09-13','2024-09-13',NULL,'UNPREPARED',2705197,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Maple Pancake, Whole Grain, Egg & Cheese, Individually Wrapped','Sndwch Mpl Pancake WG Egg&Chs IW',125114,NULL,'00737410045252','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-09-13','2025-03-20',NULL,'UNPREPARED',2723328,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stuffed Crust Whole Grain Pepperoni, Reduced Fat,  4.87 oz, CN','MX WG STF CRST WHL GRN PEPP PZA 72/',125115,NULL,'20077387126825','Conagra Brands, Inc','The MAX',NULL,3,'2024-10-31','2024-10-31',NULL,'BAKE',2716158,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards White Process American Slice - 160 V - 5#','5# W Pr Am 160V Sl',125116,NULL,'00071078110502','Bongards Creameries','Bongards',NULL,3,'2024-09-13','2024-09-13',NULL,'PREPARED',2704085,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Reduced Sodium & Fat Process American Slice - 160 H - 5#','5# Y Pr Am Rd Ft/Sd 160H Sl',125117,NULL,'00071078110540','Bongards Creameries','Bongards',NULL,3,'2024-09-13','2024-09-13',NULL,'PREPARED',2704084,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Process American Swiss Slice - 160 H - 5#','5# Pr Am Sw 160H Sl',125118,NULL,'00071078110434','Bongards Creameries','Bongards',NULL,3,'2024-09-13','2024-09-13',NULL,'PREPARED',2704086,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Reduced Fat Cheddar Stick - 1 oz','1oz Rd Ft/Sd Chd Stck',125119,NULL,'00071078402928','Bongards Creameries','Bongards',NULL,3,'2024-09-13','2024-09-13',NULL,'PREPARED',2704079,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Reduced Fat Low Moisture Part Skim Mozzarella String Cheese Stick - 1 oz','1oz Rd Ft Moz Stng Stck',125120,NULL,'00071078402997','Bongards Creameries','Bongards',NULL,3,'2024-09-13','2024-09-13',NULL,'PREPARED',2704077,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Reduced Fat Marble Jack Stick - 1 oz','1oz  33% RFt Mrbl Jk Ch Stk',125121,NULL,'00071078402942','Bongards Creameries','Bongards',NULL,3,'2024-09-13','2024-09-13',NULL,'PREPARED',2704078,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Reduced Fat & Sodium Process American Hoagie Slice - 486 - 5#','5 Y Pr Am Rd Ft/Sd 486 Sl',125122,NULL,'00071078112148','Bongards Creameries','Bongards',NULL,3,'2024-09-13','2024-09-13',NULL,'PREPARED',2704081,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Reduced Fat & Sodium Process American Slice - 160 H - 5#','5# Pr Am Chs W 160H Sl',125123,NULL,'00071078111332','Bongards Creameries','Bongards',NULL,3,'2024-09-13','2024-09-13',NULL,'PREPARED',2704082,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Reduced Fat Process American Slice - 160 H - 5#','5# Y Pr Am Rd Ft 160H Sl',125124,NULL,'00071078111325','Bongards Creameries','Bongards',NULL,3,'2024-09-13','2024-09-13',NULL,'PREPARED',2704083,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees, Applesauce Cup, Cherry, No Added Sugar, 4.5oz','Cherry Applesauce',125125,NULL,'20810358036620','National Food Group  Inc.','Zee Zees',NULL,3,'2024-10-31','2024-10-31',NULL,'READY_TO_EAT',2716152,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'V8 Low Sodium Original 100% Vegetable Juice, 46 fl oz Bottle','LS V8',125126,NULL,'00051000121578','CAMPBELL SOUP COMPANY','V8',NULL,3,'2024-09-13','2024-09-13',NULL,'UNPREPARED',2705044,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'V8 Low Sodium Spicy Hot 100% Vegetable Juice, 46 fl oz Bottle','V8 LS HOT & SPCY',125127,NULL,'00051000192400','CAMPBELL SOUP COMPANY','V8',NULL,3,'2024-09-13','2024-09-13',NULL,'UNPREPARED',2705075,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Swirls, Whole Grain, Individually Wrapped, 3.6" x 1.7"','Chocolate Swirls, WG, IW, 3.6"x1.7"',125128,NULL,'00737410016641','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-09-13','2024-09-13',NULL,'UNPREPARED',2704187,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cinnamon Swirls, Whole Grain, Bulk, 3.75" x 1.75"','Cinn Swirls, WG, Blk, 3.75"x1.75"',125129,NULL,'00737410016665','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-09-13','2024-09-13',NULL,'UNPREPARED',2704186,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Chocolate Chip Muffin Made With Whole Grain','Chocolate Chip Muffin Made',125130,NULL,'00013087241853','ASPIRE BAKERIES','Otis Spunkmeyer-Delicious Essentials',NULL,3,'2024-09-13','2024-09-13',NULL,'PREPARED',2703795,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 10 FL OZ 100% JUICE - CONCORD GRAPE (6 PK)','10OZ 6PK 100% GRAPE JUICE',125131,NULL,'00041800337118','WELCHS','Welchs',NULL,3,'2024-09-13','2025-01-23',NULL,'READY_TO_DRINK',2723018,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'WELCH''S 10 FL OZ 100% JUICE - ORANGE PINEAPPLE APPLE (6PK)','10OZ 100% OPA 6PK',125132,NULL,'00041800377312','WELCHS','Welchs',NULL,3,'2024-09-13','2025-01-23',NULL,'READY_TO_DRINK',2722598,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Ranch Wheat Crackers 0.8 oz','Ranch Wheat Crackers',125133,NULL,'20810358035838','National Food Group  Inc.','Zee Zees',NULL,3,'2024-10-31','2024-10-31',NULL,'READY_TO_EAT',2716130,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Colts Ketchup, 20oz Bottle','Red Gold Ketchup',125134,NULL,'00072940115311','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718067,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Red Gold Organic Ketchup, 20oz Bottle','Red Gold Organic Ketchup',125135,NULL,'00072940111207','Red Gold, Inc.','Red Gold',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718030,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Gripz Crackers Chocolate Chip .95oz 150ct','Gripz Crackers',125136,NULL,'00030100807414','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721772,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'40/3.2OZ STRAWBERRY APPLE SAUCE POUCH CASE','Applesauce',125137,NULL,'00028700045602','TREE TOP INC.','TREE TOP',NULL,3,'2024-09-13','2024-09-13',NULL,'READY_TO_EAT',2705203,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Breaded Hot & Spicy Chicken Drumsticks ','FC H&S BRD CKN DRMS',125138,NULL,'00023700049407','Tyson Foods Inc.','Tyson','100103',3,'2024-10-31','2024-10-31','2024-08-02','UNPREPARED',2716859,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tyson Fully Cooked Unbreaded Chicken Drumsticks With Gochujang Pepper Sauce Packets ','TYS FC CKN DRMS GJNG PEP SCE 31.25L',125139,NULL,'00023700053206','Tyson Foods Inc.','Tyson','100103',3,'2024-10-31','2024-10-31','2024-08-02','UNPREPARED',2716911,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'40/3.2OZ CINNAMON APPLE SAUCE POUCH CASE','Applesauce',125140,NULL,'00028700045619','TREE TOP INC.','TREE TOP',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721747,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'72/4OZ  TREE TOP ORIGINAL APPLE SAUCE CASE','Applesauce',125141,NULL,'00028700014141','TREE TOP INC.','TREE TOP',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721743,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'125/0.34 OZ TREE TOP APPLE CRISPS APPLE FLAVOR CASE','Dried Apple Crisps',125142,NULL,'00028700052617','TREE TOP INC.','TREE TOP',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721715,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'125/0.34OZ TREE TOP APPLE CRISPS STRAWBERRY FLAVOR CASE','Dried Apple Crisps',125143,NULL,'00028700052600','TREE TOP INC.','TREE TOP',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721717,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'24/10 OZ TREE TOP 100% ORANGE JUICE CASE','100% ORANGE JUICE 24/10OZ CASE',125144,NULL,'00028700018484','TREE TOP INC.','TREE TOP',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_DRINK',2721744,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'24/10 OZ TREE TOP APPLE JUICE CASE FROM CONCENTRATE','100% APPLE JUICE 24/10OZ CASE',125145,NULL,'00028700011065','TREE TOP INC.','TREE TOP',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_DRINK',2721741,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'40/3.2OZ NO SUGAR ADDED APPLE SAUCE POUCH','Applesauce',125146,NULL,'00028700045589','TREE TOP INC.','TREE TOP',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721746,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'40/6.75 OZ TREE TOP 100% APPLE JUICE CASE','Apple Juice 6.75oz',125147,NULL,'00028700051429','TREE TOP INC.','TREE TOP',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_DRINK',2721748,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'72/4.5OZ TREE TOP NO SUGAR ADDED APPLE SAUCE','Applesauce',125148,NULL,'00028700048788','TREE TOP INC.','TREE TOP',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721718,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'72/4OZ TREE TOP NO SUGAR ADDED APPLE SAUCE','Applesauce',125149,NULL,'00028700013175','TREE TOP INC.','TREE TOP',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721742,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Teriyaki Chicken - Gluten Free','Gluten Free Teriyaki Chicken',125150,NULL,'00850002832488','International Food Solutions, Inc.','GREEN DRAGON',NULL,3,'2024-08-15','2024-08-15',NULL,'PREPARED',2701003,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cage Free Precooked Scrambled Eggs Diced, 1/20 lb., Frozen, Bulk','SCR EGG DICED',125151,NULL,'10038057616353','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2024-08-15','2024-08-15',NULL,'PREPARED',2700738,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cage Free Precooked Scrambled Eggs, Small Curd, 1/30 lb., Frozen, Bulk','CF PRECK SCR EGG',125152,NULL,'10038057319575','Cargill Poultry Products Div','Sunny Fresh',NULL,3,'2024-08-15','2024-08-15',NULL,'PREPARED',2700730,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Loaf, Whole Grain, Cinnamon Crumb, Individually Wrapped, 3.5"','Loaf, WG, Cinnamon Crumb, IW, 3.5"',125153,NULL,'00737410004389','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2699627,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Plant based Sunny Side Up egg with runny yolk FS 48 count','The Sunny One FS US',125155,NULL,'00860009646537','Yo Foods Inc','Yo Egg',NULL,3,'2024-08-15','2024-08-15',NULL,'PAN_FRY',2701026,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hot Dog Buns, Mini White Whole Grain, 3.7"','Hot Dog Buns, Mini White WG, 3.7"',125156,NULL,'00737410005959','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2699624,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Rice Krispies Treats Squares Whole Grain .42oz 600ct','Rice Krispies Treats Squares',125157,NULL,'00038000145407','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720915,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Blueberry 20.8oz 48ct','Nutri-Grain Cereal Bars',125158,NULL,'00038000357459','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721296,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Raspberry 20.8oz 48ct','Nutri-Grain Cereal Bars',125159,NULL,'00038000358456','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721299,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'RAMSEY MED RYE 50LB-AA','RAMSEY MED RYE',125160,NULL,'00678008004919','Ardent Mills  LLC','RAMSEY RYE',NULL,3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2724090,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fully Cooked, Whole Grain Breaded Chicken Patties Mini Twin Sandwich on a Whole Grain Bun','TYS CN NAE WG BRD CKN SAND TWPK 80/',125161,NULL,'30023700058042','Tyson Foods Inc.','Tyson','100103',3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2700909,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fully Cooked, Whole Grain Breaded Chicken Patties Mini Twin Sandwich on a Whole Grain Bun','TYS CN NAE WG BRD CKN SAND TWPK 80/',125162,NULL,'00023700058041','Tyson Foods Inc.','Tyson','100103',3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2702058,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Blueberry 20.8oz','Nutri-Grain Cereal Bars',125165,NULL,'00038000357480','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721297,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Blueberry 1.3oz','Nutri-Grain Cereal Bars',125166,NULL,'00038000357213','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721295,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'KYROL FLR 50LB-AB','KYROL',125167,NULL,'00678008002311','Ardent Mills  LLC','KYROL',NULL,3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2724087,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'KYROL FLR 50LB-AZ','KYROL',125168,NULL,'00678008002922','Ardent Mills  LLC','KYROL',NULL,3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2724088,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo French Toast Original French Toast Minis 3.03oz 72ct','French Toast',125169,NULL,'00038000806933','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721360,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo Pancakes Blueberry 3.03oz 72ct','Pancakes',125170,NULL,'00038000925603','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721188,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo Pancakes Maple 3.03oz 72ct','Pancakes',125171,NULL,'00038000925627','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721190,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo Waffles Cinnamon Toast Minis 2.64oz 72ct','Waffles',125172,NULL,'00038000923135','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721400,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo Waffles Maple 2.64oz 72ct','Waffles',125173,NULL,'00038000923159','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721267,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Kellogg Cracker Brand Crunch Mania Cinnamon Bun 1.76oz 100ct','Kellogg Cracker Brand',125174,NULL,'00038000245183','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721335,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Emerald Nuts Jalapeno Cashews, 1.25 oz','EM CAS JAL 1.25OZ',125175,NULL,'00010300942191','Snyder''s-Lance INC.','EMERALD',NULL,3,'2024-08-15','2024-08-15','2024-07-08','UNPREPARED',2702268,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pacific Foods Organic Creamy Light in Sodium Tomato Soup, 32 oz Carton','PFO ORG LS CRMY TOM SOUP',125176,NULL,'00052603042826','CAMPBELL SOUP COMPANY','PACIFIC FOODS',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695374,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pacific Foods Organic Creamy Light in Sodium Tomato Soup, 32 oz Carton (Case of 12)','PFO ORG LS CRMY TOM SOUP',125177,NULL,'10052603042823','CAMPBELL SOUP COMPANY','PACIFIC FOODS',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696283,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pepperidge Farm Goldfish Made with Whole Grain Snack Crackers, Xtra Cheddar, .75 Ounces, Pack of 300','PF GF WG EXTRA CHED',125178,NULL,'00014100230885','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697991,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Process American Slice - 160 V - 5#','5 Y Pr Am 160V Sl',125179,NULL,'00071078110496','Bongards Creameries','Bongards',NULL,3,'2024-07-11','2024-07-11',NULL,'PREPARED',2695575,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'25 LB Polyweave 4% PBBRN:CHEFWAY Parboil Brown','25 LB BAG Chefway PBBRN',125180,NULL,'00035200265683','Riceland Foods','Chefway','101031',3,'2024-12-19','2024-12-19',NULL,'DRY',2721096,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pancake, Bites, Poffitz, Whole Grain, Apple Cinnamon, Individually Wrapped, 1.5"','Pancake Bites Poffitz WG Apl Cin',125181,NULL,'00737410016757','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697123,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Steel Cut Whole Grain Oats Quick 3-Minute Oats 25 Oz','Quaker SteelCt Qk3MnuteOts 25z',125182,NULL,'00030000320938','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2698818,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'English Muffin, Whole Grain, Sliced, 3.7"','English Muffin, WG, Sliced, 3.7"',125183,NULL,'00737410008455','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697119,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pace Medium Picante Sauce, 138 oz Jug','MEDIUM PICANTE SAM',125184,NULL,'00041565149629','CAMPBELL SOUP COMPANY','PACE',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2698599,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s K12 White Mini Rounds 100/1oz','ShrsWhtMiniRnds1OZ',125185,NULL,'00037578619198','Shearer’s Foods LLC','Shearer''s',NULL,3,'2024-08-15','2024-08-15',NULL,'READY_TO_EAT',2703732,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Kellogg Cracker Brand Eggo Cinnamon French Toast 1.76oz 100ct','Kellogg Cracker Brand',125186,NULL,'00038000245206','Kellogg Company US','Kellogg''s',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2698423,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo Pancakes Confetti 3.03oz 72ct','Pancakes',125187,NULL,'00038000185748','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720961,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pepperidge Farm Goldfish Baked Snack Crackers Baked with Whole Grain Cheddar Cheese, 26.3 Ounces, Pack of 6','26.3OZ PF GF FS CHS',125188,NULL,'10014100054785','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697059,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kit RS Cinnamon Toast Crunch with 1C Fruit','Kit Cinnamon Toast 1C Fruit',125189,NULL,'10693392005011','East Side Entrees','ES Foods',NULL,3,'2024-07-11','2024-07-11',NULL,'PREPARED',2696655,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Fruit Cup, Pineapple Tidbits, 4.5 oz.','Pineapple Tidbit Fruit Cup',125190,NULL,'00185043000467','National Food Group  Inc.','Zee Zees',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719311,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Blueberry 20.3oz 72ct','Pop-Tarts',125191,NULL,'00038000171994','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721010,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Chocolate 20.3oz 72ct','Pop-Tarts',125192,NULL,'00038000120732','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720896,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Plant based poached egg with runny yolk 60 count','The Poached One FS',125193,NULL,'00860009646520','Yo Foods Inc','Yo Egg',NULL,3,'2024-07-11','2024-07-11',NULL,'BAIN_MARIE',2696507,'50132500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pacific Foods Organic Light in Sodium Roasted Red Pepper and Tomato Soup, 32 oz Carton (Case of 12)','PFO ORG LS RRP&TOM SOUP',125194,NULL,'10052603042830','CAMPBELL SOUP COMPANY','PACIFIC FOODS',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696284,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Swanson White Premium Chunk Canned Chicken Breast in Water, 12.5 OZ Can (Case of 12)','SWN PREM WHT CKN',125195,NULL,'10051000188066','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696204,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'V8 Splash Tropical Blend Flavored Juice Beverage, 12 fl oz Bottle','V8 SPL TROP BLD',125196,NULL,'10051000224849','CAMPBELL SOUP COMPANY','V8',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696292,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Chicken Noodle Soup, 50 Ounce Cans, 12-Pack','CAMPBELL''S CHICKEN NOODLE',125197,NULL,'10051000012569','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696185,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Cream of Chicken Soup, 50 Ounce Cans, 12-Pack','CAMPBELL''S CREAM OF CHICKEN',125198,NULL,'10051000010367','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696212,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Cream of Potato Soup, 50 Ounce Cans, 12-Pack','CAMPBELL''S CREAM OF POTATO',125199,NULL,'10051000020465','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696187,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Minestrone Soup, 50 Ounce Cans, 12-Pack','CAMPBELL''S MINESTRONE SOUP',125200,NULL,'10051000271478','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696247,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Ready to Serve Brown Gravy, Rich and Flavorful Recipe, 50 Ounce Cans, 12-Pack','CAMPBELL''S BROWN GRAVY',125201,NULL,'10051000271485','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696279,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Swanson White Premium Chunk Canned Chicken Breast in Water, 4.5 OZ Can (Case of 24)','SWANSON CHUNK WHITE CHICKEN',125202,NULL,'10051000023794','CAMPBELL SOUP COMPANY','SWANSON',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696188,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pace Medium Picante Sauce, 138 oz. (Case of 4)','MED PICANTE SCE',125203,NULL,'10041565149626','CAMPBELL SOUP COMPANY','PACE',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696386,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Tomato Soup, 50 Ounce Cans, 12-Pack','CAMPBELL''S TOMATO SOUP',125204,NULL,'10051000000160','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696242,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Cream of Potato Soup, 4 Pound Trays, 3-Pack','CUL RES CRM OF POT',125205,NULL,'00051000081667','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695918,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Homestyle Chicken Noodle Soup, 4 Pound Trays, 3-Pack','CUL RES HS CKN NDL',125206,NULL,'00051000081698','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695920,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Pasta Fagioli Soup, 4 Pound Trays, 3-Pack','CUL RES PSTA FAGIOLI',125207,NULL,'00051000104298','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695928,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Vegetable Beef with Barley Soup, 4 Pound Trays, 3-Pack','CUL RES VEG BF',125208,NULL,'00051000081636','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695917,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Vegetarian Minestrone Soup, 4 Pound Trays, 3-Pack','CUL RES MINESTRN',125209,NULL,'00051000081674','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695919,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Ready to Serve Low Sodium Tomato Soup, 7.25 Ounce Cans, 24-Pack','CAMPBELL''S LOW SODIUM TOMATO',125210,NULL,'10051000006018','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696215,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Prego No Salt Added Pasta Sauce with Classic Italian Flavor and Homemade Taste, 106 Ounce Pouches, 6-Pack','PREGO TOMATO -NO SALT ADDED',125211,NULL,'00051000050137','CAMPBELL SOUP COMPANY','PREGO',NULL,3,'2024-07-11','2024-07-11','2024-06-14','UNPREPARED',2695821,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cape Cod Less Fat Sweet Mesquite Barbeque Chips, 1.37 Oz Bag','CAPE COD CHIP, POTATO RF SWT M',125212,NULL,'00020685000775','Snyder''s-Lance INC.','CAPE COD',NULL,3,'2024-07-11','2025-04-24',NULL,'UNPREPARED',2730591,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Emerald Nuts Dill Pickle Cashews, Single-Serve 1.25 Oz','EM DILL PCK CAS 1.25OZ',125213,NULL,'00010300941194','Snyder''s-Lance INC.','EMERALD',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697856,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Emerald Nuts Roasted and Salted Cashews, Single-Serve 1.25 Oz','EMERALD CASHEW HALVES PIECES',125214,NULL,'00010300940197','Snyder''s-Lance INC.','EMERALD',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697855,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Emerald Nuts Salt and Pepper Cashews, Single-Serve 1.25 Oz','EMERALD SEA SALT PEPPER CASH',125215,NULL,'00010300938194','Snyder''s-Lance INC.','EMERALD',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695176,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Heart Healthy Tomato Soup, 23.2 oz Family Size Can','R&W HH TOM SOUP',125216,NULL,'00051000212405','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696091,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Tomato Soup, 23.2 oz Family Size Can','R&W TOM SOUP',125217,NULL,'00051000212399','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696090,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Healthy Request Chicken with Egg Noodles Soup, 4 Pound Trays, 3-Pack','CUL RES HR CKN W EGG NDL',125218,NULL,'00051000191212','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695791,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Healthy Request Harvest Tomato with Basil Soup, 4 Pound Trays, 3-Pack','CUL RES HR TOM W BAS',125219,NULL,'00051000191205','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695790,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Goldfish Baked with Whole Grain Cheddar Crackers - Disney''s Mickey Mouse','PF FS GF MCKY WG CHED',125220,NULL,'00014100275169','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697996,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Goldfish Baked with Whole Grain Cheddar Crackers Colors','PF GF FS CLRS WG',125221,NULL,'00014100047889','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697890,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pacific Foods Organic Light in Sodium Roasted Red Pepper and Tomato Soup, 32 oz Carton','PFO ORG LS RRP&TOM SOUP',125222,NULL,'00052603042833','CAMPBELL SOUP COMPANY','PACIFIC FOODS',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695375,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pepperidge Farm Goldfish Baked Snack Crackers Baked with Whole Grain Cheddar Cheese, 26.3 Ounces, Pack of 6','26.3OZ PF GF FS CHS',125223,NULL,'00014100054788','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697777,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pepperidge Farm Goldfish Whole Grain Giant Grahams, Vanilla, .9 Ounces, Pack of 300','PF GF GIANT GRHMS VAN',125224,NULL,'00014100268284','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697995,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pepperidge Farm Goldfish Whole Grain Snack Crackers, Cheddar, 1 Ounce, Pack of 60','PF GF WG CHEDDAR',125225,NULL,'00014100216803','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697990,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Swanson 100% Natural Chicken Broth, 48 oz Carton','SWN CKN BRTH ASPTC',125226,NULL,'00051000168870','CAMPBELL SOUP COMPANY','SWANSON',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695702,'50171500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Swanson 100% Natural Chicken Broth, 48 oz Carton','SWN CKN BROTH ASEP',125227,NULL,'10051000168877','CAMPBELL SOUP COMPANY','SWANSON',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696203,'50171500');
INSERT INTO `cndb_fdes` VALUES (NULL,'V8 Splash Tropical Blend Flavored Juice Beverage, 12 fl oz Bottle','V8 SPL TROP BLD',125230,NULL,'00051000217745','CAMPBELL SOUP COMPANY','V8',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2696110,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Beef Consomme, 50 Ounce Cans, 12-Pack','CPB BF CONSOMME',125231,NULL,'00051000275134','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695962,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Chicken Noodle Soup, 50 Ounce Cans, 12-Pack','CAMPBELL''S CHICKEN NOODLE',125232,NULL,'00051000012562','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2698534,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Cream of Chicken Soup, 50 Ounce Cans, 12-Pack','FS CR CHICKEN',125233,NULL,'00051000010360','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2698519,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Cream of Mushroom Soup, 50 Ounce Cans, 12-Pack','FS CR MUSHROOM',125234,NULL,'00051000012661','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2698536,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Cream of Potato Soup, 50 Ounce Cans, 12-Pack','CAMPBELL''S CREAM OF POTATO',125235,NULL,'00051000020468','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695847,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Minestrone Soup, 50 Ounce Cans, 12-Pack','CAMPBELL''S MINESTRONE SOUP',125236,NULL,'00051000271471','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695967,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Tomato Soup, 10.75 oz Can','R&W TOMATO SOUP',125237,NULL,'00051000000118','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2698550,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Condensed Tomato Soup, 50 Ounce Cans, 12-Pack','CAMPBELL''S TOMATO SOUP',125238,NULL,'00051000000163','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2698551,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Broccoli Cheese Soup, 4 Pound Trays, 3-Pack','CUL RES BROC CHS',125239,NULL,'00051000081872','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695921,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Culinary Reserve Frozen Condensed Healthy Request Homestyle Sweet Pepper and Beef Soup, 4 Pound Trays, 3-Pack','CUL RES W&G CTRY SWT PEP&BF',125240,NULL,'00051000142238','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695719,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Frozen Entrees Creamy Classic Macaroni and Cheese, 6 Pound Trays, 4-Pack','FS C''S MAC & CHEES',125241,NULL,'00051000112132','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695870,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Frozen Entrees Garden Mixed Vegetable Lasagna, 5.75 Pound Trays, 4-Pack','FS VEG LASAGNA',125242,NULL,'00051000080639','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695912,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Frozen Entrees Traditional Stuffed Cabbage Rolls, 5.5 Pound Trays, 4-Pack','FS STUF CABBGE ROL',125243,NULL,'00051000081568','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695915,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Ready to Serve Brown Gravy, Rich and Flavorful Recipe, 50 Ounce Cans, 12-Pack','CAMPBELL''S BROWN GRAVY',125244,NULL,'00051000271488','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695968,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Ready to Serve Chicken Noodle Soup, 7.25 Ounce Cans, 24-Pack','CAMPBELL''S CHICKEN NOODLE',125245,NULL,'00051000004444','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2698560,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Ready to Serve Low Sodium Chicken Noodle Soup, 7.25 Ounce Cans, 24-Pack','CAMPBELL''S LS CHICKEN NOODLE',125246,NULL,'00051000006141','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2698576,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Ready to Serve Low Sodium Tomato Soup, 7.25 Ounce Cans, 24-Pack','CAMPBELL''S LOW SODIUM TOMATO',125247,NULL,'00051000006011','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2698574,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Ready to Serve Low Sodium Vegetable Soup, 7.25 Ounce Cans, 24-Pack','CPB LOW SODIUM VEGETABLE SOUP',125248,NULL,'00051000006035','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2698575,'50191500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pepperidge Farm Goldfish Baked Snack Crackers, Cheddar Cheese, .75 Ounces, Pack of 300','PF GF CHEDDAR',125249,NULL,'00014100143673','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697985,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pepperidge Farm Goldfish Baked with Whole Grain Cheddar Crackers, 0.75 oz. Bag','PF GF WG CHEDDAR',125250,NULL,'00014100181057','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697988,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pepperidge Farm Goldfish Made with Whole Grain 100 Calorie Snack Crackers, Cheddar, .75 Ounce, Pack of 100','PF GF WG CHEDDAR',125251,NULL,'00014100181972','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697989,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pepperidge Farm Goldfish Made with Whole Grain Snack Crackers, Pretzel, .75 Ounces, Pack of 300','PF GF WG PRETZELS',125252,NULL,'00014100143963','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697986,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pepperidge Farm Goldfish Whole Grain Giant Grahams, Cinnamon, .9 Ounces, Pack of 300','PF GF GIANT GRHMS CINN',125253,NULL,'00014100268307','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2698009,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'PEPPERIDGE FARM GOLDFISH WHOLE GRAIN GRAHAMS, FRENCH TOAST','PF GF FRNCH TST GRHMS',125254,NULL,'00014100250821','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697992,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'PEPPERIDGE FARM GOLDFISH WHOLE GRAIN GRAHAMS, HONEY BUN','PF GF HNY BUN GRHMS',125255,NULL,'00014100250838','Pepperidge Farm Inc.','PEPPERIDGE FARM',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697993,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Raisin Bran Cereal 1.25oz','Raisin Bran Cereal',125256,NULL,'00038000008610','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720929,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hart Low Sodium Sweet Peas 15oz','PEAS SWT LOW SOD',125257,NULL,'00070222074264','Seneca Foods Corp','HART',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2695586,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Cheddar Stick - 1 oz','1oz Y Chd Stck',125258,NULL,'00071078700000','Bongards Creameries','Bongards',NULL,3,'2024-07-11','2024-07-11',NULL,'PREPARED',2695578,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Rice Krispies Treats Squares Whole Grain 28.2oz 4ct','Rice Krispies Treats Squares',125259,NULL,'00038000110528','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720947,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Rice Krispies Treats Squares Whole Grain Chocolate Chip 31.8oz 80ct','Rice Krispies Treats Squares',125260,NULL,'00038000145674','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720917,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Doritos Reduced Fat Tortilla Chips Cool Ranch Flavored 1 Oz','Doritos RdFt TtlaCps ClRch 1Oz',125261,NULL,'00028400052979','PepsiCo Inc. Brand Owner','Doritos',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2698757,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Apple Jacks Cereal Reduced Sugar 1oz','Apple Jacks Cereal',125262,NULL,'00038000926341','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721193,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Apple Jacks Cereal Reduced Sugar 1oz 96ct','Apple Jacks Cereal',125263,NULL,'00038000787874','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721357,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo French Toast Chocolate Chip French Toast Minis 3.03oz','French Toast',125264,NULL,'00038000808142','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721363,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo French Toast Chocolate Chip French Toast Minis 3.03oz 72ct','French Toast',125265,NULL,'00038000808012','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721362,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo French Toast Original French Toast Minis 3.03oz','French Toast',125266,NULL,'00038000806957','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721361,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo Pancakes Blueberry 3.03oz','Pancakes',125267,NULL,'00038000925610','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721189,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo Pancakes Maple 3.03oz','Pancakes',125268,NULL,'00038000925634','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721191,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo Waffles Cinnamon Toast Minis 2.64oz','Waffles',125269,NULL,'00038000923142','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721285,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo Waffles Maple 2.64oz','Waffles',125270,NULL,'00038000923166','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721187,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Froot Loops Cereal Reduced Sugar 1oz','Froot Loops Cereal',125271,NULL,'00038000926334','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721192,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Froot Loops Cereal Reduced Sugar 1oz 96ct','Froot Loops Cereal',125272,NULL,'00038000787881','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721358,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Frosted Flakes Cereal Multi Grain Cinnamon 1oz','Frosted Flakes Cereal',125273,NULL,'00038000929342','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721194,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Frosted Flakes Cereal Multi Grain Cinnamon 1oz 96ct','Frosted Flakes Cereal',125274,NULL,'00038000787867','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721356,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Mini-Wheats Cereal Frosted 2.1oz','Mini-Wheats Cereal',125275,NULL,'00038000270963','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721341,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Mini-Wheats Cereal Frosted 2.1oz 60ct','Mini-Wheats Cereal',125276,NULL,'00038000270956','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721340,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Frosted Flakes Cereal Reduced Sugar 1oz','Frosted Flakes Cereal',125277,NULL,'00038000550034','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721391,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Frosted Flakes Cereal Reduced Sugar 1oz 96ct','Frosted Flakes Cereal',125278,NULL,'00038000549984','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721390,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Brown Sugar Cinnamon 1.69oz','Pop-Tarts',125279,NULL,'00038000551246','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721394,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Brown Sugar Cinnamon 16.9oz','Pop-Tarts',125280,NULL,'00038000551239','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721393,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Brown Sugar Cinnamon 16.9oz 120ct','Pop-Tarts',125281,NULL,'00038000551222','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721392,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Brown Sugar Cinnamon 20.3oz','Pop-Tarts',125282,NULL,'00038000551260','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721396,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Brown Sugar Cinnamon 3.3oz','Pop-Tarts',125283,NULL,'00038000551277','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721397,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Raspberry 20.8oz','Nutri-Grain Cereal Bars',125284,NULL,'00038000358487','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721300,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Nutri-Grain Cereal Bars Raspberry 1.3oz','Nutri-Grain Cereal Bars',125285,NULL,'00038000358210','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721298,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Frosted Flakes Cereal Multi Grain 2.1oz','Frosted Flakes Cereal',125286,NULL,'00038000241918','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721332,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Frosted Flakes Cereal Multi Grain 2.1oz 60ct','Frosted Flakes Cereal',125287,NULL,'00038000241857','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721331,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Frosted Flakes Cereal Multi Grain Cinnamon 2.1oz','Frosted Flakes Cereal',125288,NULL,'00038000241970','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721334,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Frosted Flakes Cereal Multi Grain Cinnamon 2.1oz 60ct','Frosted Flakes Cereal',125289,NULL,'00038000241963','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721333,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Apple Jacks Cereal Reduced Sugar 1oz','Apple Jacks Cereal',125290,NULL,'00038000114700','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720891,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Apple Jacks Cereal Reduced Sugar 1oz 96ct','Apple Jacks Cereal',125291,NULL,'00038000114694','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720890,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo Pancakes Confetti 3.03oz','Pancakes',125292,NULL,'00038000185762','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720962,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Froot Loops Cereal Reduced Sugar 1oz 96ct','Froot Loops Cereal',125293,NULL,'00038000114670','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720918,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Kellogg Cracker Brand Crunch Mania Cinnamon Bun 1.76oz','Kellogg Cracker Brand',125294,NULL,'00038000245541','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721336,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Mini-Wheats Cereal Bite Size Frosted 1oz 96ct','Mini-Wheats Cereal',125295,NULL,'00038000049965','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720943,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Blueberry 1.7oz','Pop-Tarts',125296,NULL,'00038000171987','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721009,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Blueberry 16.9oz','Pop-Tarts',125297,NULL,'00038000171970','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721008,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Blueberry 20.3oz','Pop-Tarts',125298,NULL,'00038000172007','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721011,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Blueberry 3.3oz','Pop-Tarts',125299,NULL,'00038000172014','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721012,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Chocolate 20.3oz','Pop-Tarts',125300,NULL,'00038000120749','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720897,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Chocolate 3.4oz','Pop-Tarts',125301,NULL,'00038000120770','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720898,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Raisin Bran Cereal 1.25oz 96ct','Raisin Bran Cereal',125302,NULL,'00038000008962','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720931,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Rice Krispies Treats Squares Whole Grain 1.41oz','Rice Krispies Treats Squares',125303,NULL,'00038000110542','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720949,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Rice Krispies Treats Squares Whole Grain 28.2oz','Rice Krispies Treats Squares',125304,NULL,'00038000110535','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720948,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Rice Krispies Treats Squares Whole Grain Chocolate Chip 1.59oz','Rice Krispies Treats Squares',125305,NULL,'00038000145698','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720953,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Rice Krispies Treats Squares Whole Grain Chocolate Chip 31.8oz','Rice Krispies Treats Squares',125306,NULL,'00038000145681','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720919,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Chocolate 1.7oz','Pop-Tarts',125307,NULL,'00038000120725','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720895,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Chocolate 16.9oz','Pop-Tarts',125308,NULL,'00038000120718','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720894,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Chocolate 16.9oz 12ct','Pop-Tarts',125309,NULL,'00038000120701','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720893,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Cheez It Crackers Whole Grain .75oz','Cheez-It Crackers',125310,NULL,'00024100794829','Kellogg Company US','Kellogg''s Cheez It',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721833,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Grahams Crackers Honey Graham With Calcium .78oz 150ct','Grahams Crackers',125311,NULL,'00030100918226','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721774,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Grahams Crackers Original .78oz 150ct','Grahams Crackers',125312,NULL,'00030100918295','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721776,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Gripz Crackers Cinnamon Grahams .9oz 150ct','Gripz Crackers',125313,NULL,'00030100456827','Kellogg Company US','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721761,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Klg Licensed Crackers Bug Bites 1oz','Klg Licensed Crackers',125314,NULL,'00030100558569','Kellogg Company US','Kellogg''s',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2699124,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Klg Licensed Crackers Bug Bites 1oz 210ct','Klg Licensed Crackers',125315,NULL,'00030100556442','Kellogg Company US','Kellogg''s',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2699123,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Klg Licensed Crackers Scooby-Doo Cinnamon Graham Bones 1oz 210ct','Klg Licensed Crackers',125316,NULL,'00030100506898','Kellogg Company US','Kellogg''s',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2699118,'50182100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Morningstar Farms Veggie Burgers Veggie Burgers Grillers Prime 2.5oz 48ct','Veggie Burgers',125317,NULL,'00028989104090','Kellogg Company US','Morningstar Farms',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721750,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Process Jalapeno American Slice - 120 H - 5#','5# Jal Am 120H Sl',125318,NULL,'00071078113411','Bongards Creameries','Bongards',NULL,3,'2024-07-11','2024-07-11',NULL,'PREPARED',2695577,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'SunButter Creamy 5 lb tubs - 2 ct case','SunButter Creamy 5 lb tubs - 2ct',125319,NULL,'00737539192127','Red River Commodities SunButter','SunButter','100935',3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719792,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Handhelds, Empanada, Whole Grain, Turkey Sausage, Egg and Cheese','Handhelds Empanada WG Trky Ssg Egg&',125320,NULL,'00737410037233','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697094,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Froot Loops Cereal Reduced Sugar 1oz','Froot Loops Cereal',125321,NULL,'00038000114687','WK KELLOGG CO','Kellogg''s',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2720889,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Margarine, Round, Fully Sliced, 2.0 oz, 3" x 1.8"','Croiss Marg Rnd Flly Sl 2.0 oz 3"x1',125322,NULL,'00737410008547','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-07-11','2025-04-24',NULL,'UNPREPARED',2730161,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'English Muffins, Whole Grain, Sliced, 3.75"','English Muffins, WG, Sliced, 3.75"',125323,NULL,'00737410008349','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697118,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hot Dog Buns, Whole Grain White, 6"','Hot Dog Buns, Whole Grain White, 6"',125324,NULL,'00737410001470','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-07-11','2024-07-11',NULL,'UNPREPARED',2697116,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'LAKESIDE MIX VEG','MIX VEG',125325,NULL,'00033828080602','Lakeside Foods','Lakeside Foods','111230',3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721069,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pancakes with Blueberry Glaze, Whole Grain, 2 pieces, 3 oz','MAX WG IW PNCAKES W/BLBRRY GLAZE 80',125326,NULL,'20094643044433','Conagra Brands, Inc','The MAX',NULL,3,'2024-07-11','2024-07-11',NULL,'BAKE',2696468,'50193400');
INSERT INTO `cndb_fdes` VALUES (NULL,'Real Slice Pepperoni, Reduced Fat,  Whole Grain, 4.67 oz, CN','MX RS WG PEPP PIZZA, 96/4.67Z',125327,NULL,'20077387126818','Conagra Brands, Inc','The MAX',NULL,3,'2024-07-11','2024-07-11',NULL,'BAKE',2696645,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fit for Kids Plus, 4x6, Turkey Pepperoni, Whole Grain, 4.68 oz, CN','MAX 4X6 FFK PLUS WG T.PEPP 96/4.68Z',125328,NULL,'20077387127198','Conagra Brands, Inc','The MAX',NULL,3,'2024-07-11','2025-01-23',NULL,'BAKE',2722512,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Alfredo Sauce Pouch','Alfredo Sauce',125329,NULL,'10693392005349','East Side Entrees','ES Foods',NULL,3,'2024-05-16','2025-03-20',NULL,'HEAT_AND_SERVE',2724486,'50171800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Burrito Bkfst Sausage, Egg & 3 Cheese Bulk Packed 32/6z','Burrito Bkfst Sge, Egg & 3 Chs Bulk',125330,NULL,'10706574613048','M.C.I. Foods, Inc.','Los Cabos',NULL,3,'2024-05-16','2024-05-16',NULL,'HEAT_AND_SERVE',2690687,NULL);
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s White Restaurant Round Tortilla Chips 16 ONZ','ShrsWhtRestRndTortChp16oz',125331,NULL,'00037578619341','Shearer’s Foods LLC','Shearer''s',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721104,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kit RS Trix with 1C Fruit','Kit RS Trix with 1C Fruit',125332,NULL,'10693392005066','East Side Entrees','ES Foods',NULL,3,'2024-05-16','2024-05-16',NULL,'PREPARED',2690690,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'4.4lb Jar, ALL NATURAL Non-GMO Peanut Free Spread Creamy','WOWBUTTER Creamy 4.4lb',125333,NULL,'00773948401009','Hilton Whole Grain Millers Ltd CA','WOWBUTTER',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2719813,'50192400');
INSERT INTO `cndb_fdes` VALUES (NULL,'17.6oz Jar of WOWBUTTER Creamy, Peanut & Tree Nut Free','WOWBUTTER Creamy 6/17.6oz',125334,NULL,'00773948201005','Hilton Whole Grain Millers Ltd CA','WOWBUTTER',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2719811,'50192400');
INSERT INTO `cndb_fdes` VALUES (NULL,'17.6oz Jar WOWBUTTER Crunchy, Peanut & Tree Nut Free','WOWBUTTER Crunchy 6/17.6oz',125335,NULL,'00773948201012','Hilton Whole Grain Millers Ltd CA','WOWBUTTER',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2719812,'50192400');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Pop-Tarts Whole Grain Brown Sugar Cinnamon 20.3oz 72ct','Pop-Tarts',125336,NULL,'00038000551253','Kellogg Company US','Kellogg''s Pop-Tarts',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721395,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Libby''s Frozen Cut Green Beans - 30lb Carton','FZ BEANS GREEN CUT',125337,NULL,'10037100343130','Seneca Foods Corp','Libby''s','100351',3,'2024-12-19','2025-03-20',NULL,'UNPREPARED',2724141,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Libby''s Frozen Peas - 30lb carton','FZ PEAS',125338,NULL,'10037100421630','Seneca Foods Corp','Libby''s','100350',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719685,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Apple Fritter Bun, Whole Grain, Individually Wrapped, 4"','Apple Fritter Bun, WG, IW, 4"',125339,NULL,'00737410021621','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2699592,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffin Tops, Whole Grain, Blueberry, Individually Wrapped, 4"','Muffin Tops, WG, Blueberry, IW, 4"',125340,NULL,'00737410012384','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2025-01-23',NULL,'UNPREPARED',2722668,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Croissants, Whole Grain, Margarine, Round, Fully Sliced, 3.9" x 1.8"','Croiss WG Marg Rnd Flly Sl 3.9x1.8',125341,NULL,'00737410008738','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2025-03-20',NULL,'UNPREPARED',2724099,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Granola, Cinnamon, Whole Grain, Wholesome Choice, Bulk','Granola Cinn WG Wholesome Choice Bl',125342,NULL,'00737410024653','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2699593,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hamburger Buns, Whole Grain White, Sliced, 3.5" Cluster','Hamb Buns, WG Whi, Sl, 3.5" Cluster',125343,NULL,'00737410005874','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2699625,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Handhelds, Whole Grain, Garlic Mozzarella Dippinz Bites, 2.375" x 1"','Handhelds WG Gar Mozz Dippinz Bites',125344,NULL,'00737410037141','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2025-04-24',NULL,'UNPREPARED',2730163,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Handhelds, Whole Grain, Garlic Mozzarella Rippinz, 5.5" x 2.5"','Handhelds WG Gar Mozz Rippinz',125345,NULL,'00737410037134','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2025-04-24',NULL,'UNPREPARED',2730162,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Handhelds, Whole Grain, Mozzarella Dippinz Bites, 2.375" x 1"','Handhelds WG Mozz Dippinz Bites 2.3',125346,NULL,'00737410037127','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2701113,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Handhelds, Whole Grain, Mozzarella Rippinz, 5.5" x 2.5"','Handhelds WG Mozz Rippinz 5.5"x2.5"',125347,NULL,'00737410037110','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2701114,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Loaf, Whole Grain, Banana, Individually Wrapped','Loaf, Whole Grain, Banana, IW',125348,NULL,'00737410004372','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2699629,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Muffin Tops, Whole Grain, Chocolate Chip, Individually Wrapped, 4"','Muffin Tops, WG, Choc Chip, IW, 4"',125349,NULL,'00737410012391','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2699580,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pancake, Bites, Poffitz, Whole Grain, Bulk, 1.5"','Pancake Bites Poffitz WG Blk 1.5',125350,NULL,'00737410016740','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2699571,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pancake, Bites, Poffitz, Whole Grain, Individually Wrapped, 1.5"','Pancake Bites Poffitz WG IW 1.5"',125351,NULL,'00737410016733','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2699572,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pizza, Whole Grain, Cheese, 11x17", 10 cut, 3.4" x 5.5"','Pizza WG Chs 11x17 10 cut 3.4x5.5',125352,NULL,'00737410036977','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2701118,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pizza, Whole Grain, Cheese, 11x17", 8 cut, 4.25" x 5.5"','Pizza WG Chs 11x17 8 cut 4.25x5.5',125353,NULL,'00737410036960','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2701119,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Pizza, Whole Grain, Cheese, Round, 16", 10 cut, 8"','CLOSEOUT Pizza WG Chs Rnd 16" 10 cu',125354,NULL,'00737410036915','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2025-01-23',NULL,'UNPREPARED',2721992,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pizza, Whole Grain, Cheese, Round, 16", 8 cut','Pizza, WG, Chs, Round, 16", 8 cut',125355,NULL,'00737410036885','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2700356,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pizza, Whole Grain, Turkey Pepperoni, Round, 16", 8 cut','Pizza WG Trky Pproni Rnd 16" 8 cut',125356,NULL,'00737410037035','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2701116,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Pizza, Whole Grain, White Garlic, 11x17", 10 cut, 3.4" x 5.5"','CLOSEOUT Pizza WG Whi Gar 11x17" 10',125357,NULL,'00737410037011','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2025-01-23',NULL,'UNPREPARED',2722254,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Pizza, Whole Grain, White Garlic, 11x17", 8 cut, 4.25" x 5.5"','Pizza WG Whi Gar 11x17" 8 cut',125358,NULL,'00737410036991','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2701117,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Pizza, Whole Grain, White Garlic, Round, 16", 10 cut, 8"','CLOSEOUT Pizza WG Whi Gar Rnd 16" 1',125359,NULL,'00737410036946','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2025-01-23',NULL,'UNPREPARED',2722030,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Pizza, Whole Grain, White Garlic, Round, 16", 8 cut, 8"','CLOSEOUT Pizza WG Whi Gar Rnd 16" 8',125360,NULL,'00737410036939','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2025-01-23',NULL,'UNPREPARED',2722236,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Croissant, Whole Grain, Chicken Sausage & Cheese, Individually Wrapped, 3" x 2"','Sndwch Crois WG Chkn Ssg&Chs IW 3"x',125361,NULL,'00737410046075','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2025-03-20',NULL,'UNPREPARED',2723329,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Croissant, Whole Grain, Egg & American Cheese, Individually Wrapped, 3" x 2"','Sndwch Crois WG Egg&American Chs IW',125362,NULL,'00737410046051','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2701133,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Croissant, Whole Grain, Egg & Fiesta Cheese, Individually Wrapped, 3" x 2"','Sndwch Crois WG Egg&Fiesta Chs IW 3',125363,NULL,'00737410046068','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2701126,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Sandwich, Whole Grain, Grilled Ch, Pepper Jack & Mozz, Bulk','Sndwch WG Grilled Ch Pepper Jack&Mo',125364,NULL,'00737410067452','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2701108,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'CLOSEOUT Sandwich, Whole Grain, Grilled Ch, Garlic Mozzarella, Bulk','CLOSEOUT Sndwch WG Grilled Ch Gar M',125365,NULL,'00737410067292','Bake Crafters Food Company','Bake Crafters',NULL,3,'2024-08-15','2025-01-23',NULL,'UNPREPARED',2722929,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Italian Blend Feather Shred - 5#','5# Itln Blnd Shd',125366,NULL,'00071078755369','Bongards Creameries','Bongards',NULL,3,'2024-08-15','2024-08-15',NULL,'PREPARED',2700353,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Marble Cheese Stick - 1 oz','1oz Mrbl Jk Stck',125367,NULL,'00071078700109','Bongards Creameries','Bongards',NULL,3,'2024-08-15','2024-08-15',NULL,'PREPARED',2700337,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Mozzarella String Stick - 168/1 oz','1oz Mz Stng Stck',125368,NULL,'00071078700307','Bongards Creameries','Bongards',NULL,3,'2024-08-15','2024-08-15',NULL,'PREPARED',2700345,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Mozzarella, Provolone, and Cheddar Feather Shred - 5#','5# 3 Chs Blnd Fthr Shd',125369,NULL,'00071078755260','Bongards Creameries','Bongards',NULL,3,'2024-08-15','2024-08-15',NULL,'PREPARED',2700348,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Mozzarella/Provolone Feather Shred - 5#','5# Mozz/Prv Bl Fthr Shd',125370,NULL,'00071078755345','Bongards Creameries','Bongards',NULL,3,'2024-08-15','2024-08-15',NULL,'PREPARED',2700347,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Process Jalapeno American Slice - 160 P - 5#','5# Pr Am Hot Pep 160P Sl',125371,NULL,'00071078113459','Bongards Creameries','Bongards',NULL,3,'2024-08-15','2024-08-15',NULL,'PREPARED',2700330,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Sharp Yellow Cheddar Feather Shred - 5#','5# Sh Y Chd Fthr Shd cheese',125372,NULL,'00071078755963','Bongards Creameries','Bongards',NULL,3,'2024-08-15','2024-08-15',NULL,'PREPARED',2700343,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Super Melt Yellow Process American Shredded Cheese  5#','5# Prcss Amrcn Yllw Spr Mlt Shred',125373,NULL,'00071078755819','Bongards Creameries','Bongards',NULL,3,'2024-08-15','2024-08-15',NULL,'PREPARED',2700344,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards White Process American Loaf - 5#','5# W Pr Am Lf',125374,NULL,'00071078202641','Bongards Creameries','Bongards',NULL,3,'2024-08-15','2025-03-20',NULL,'PREPARED',2724117,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Reduced Fat Cheddar Feather Shred - 5#','5# Y Rd Ft Chd Fthr Shd',125375,NULL,'00071078755710','Bongards Creameries','Bongards',NULL,3,'2024-08-15','2024-08-15',NULL,'PREPARED',2700346,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bongards Yellow Restricted Melt Process American Slice - 160 P - 5#','5# Y Pr Am RMLT 160P Sl',125376,NULL,'00071078110656','Bongards Creameries','Bongards',NULL,3,'2024-08-15','2024-08-15',NULL,'PREPARED',2700333,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Beans, Pinto, Dry','Beans, Pinto, Dry',125377,NULL,'00851552001010','WestStar Food Co','WestStar','100382',3,'2024-12-19','2024-12-19',NULL,'BOIL',2719773,'50320100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Beans, Pinto, Dry','Beans, Pinto, Dry',125378,NULL,'10851552001017','WestStar Food Co','WestStar','100382',3,'2024-12-19','2024-12-19',NULL,'BOIL',2718855,'50320100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Instant Oatmeal Apples & Cinnamon Flavor 1.51 Oz','Quaker Apples&Cinnamon 1.51 Oz',125379,NULL,'00030000319567','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2703255,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bushs Campfire Style Chili Magic Chili Starter 15.5 oz','Bush''s Chili Magic (CFS) 12-15.5 oz',125380,NULL,'00039400019039','Bush Brothers & Company','Bush''s Best',NULL,3,'2024-05-16','2025-01-23',NULL,'UNPREPARED',2722734,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bushs Classic Homestyle Chili Magic Chili Starter 15.5 oz','Bush''s Chili Magic (HST) 12-15.5 oz',125381,NULL,'00039400019015','Bush Brothers & Company','Bush''s Best',NULL,3,'2024-05-16','2025-01-23',NULL,'UNPREPARED',2722800,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Black Bean Bean Dip 9.5 oz','Bush''s Black Bean Bn Dip 12-9.5 oz',125382,NULL,'10039400099199','Bush Brothers & Company','Bush''s Best',NULL,3,'2024-05-16','2025-01-23',NULL,'UNPREPARED',2722016,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Black Bean Bean Dip 9.5 oz','Bush''s Black Bean Bn Dip 9.5 oz',125383,NULL,'00039400099192','Bush Brothers & Company','Bush''s Best',NULL,3,'2024-05-16','2025-01-23',NULL,'UNPREPARED',2722740,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Original Bean Dip 9.5 oz','Bush''s Original Bean Dip 12-9.5 oz',125384,NULL,'10039400099168','Bush Brothers & Company','Bush''s Best',NULL,3,'2024-05-16','2025-01-23',NULL,'UNPREPARED',2722006,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bush''s Original Bean Dip 9.5 oz','Bush''s Original Bean Dip 9.5 oz',125385,NULL,'00039400099161','Bush Brothers & Company','Bush''s Best',NULL,3,'2024-05-16','2025-01-23',NULL,'UNPREPARED',2722877,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Southern Sliced Peaches','Frozen Sliced Freestone Peaches',125386,NULL,'10817134025789','Palmetto Processing Solutions','Southern Sliced Peaches','100238',3,'2024-12-19','2024-12-19',NULL,'THAW',2718836,'50270100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stokely''s No Salt Golden Whole Kernel Corn 15.25oz','CORN WK GLDN NS',125387,NULL,'00070222028489','Seneca Foods Corp','STOKELY''S','100311',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718510,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naked 100% Juice Blend Blue Machine 10Z/8','Nj blue machine 10Z/8',125388,NULL,'00082592010377','PepsiCo Inc. Brand Owner','Naked',NULL,3,'2024-03-14','2024-03-14',NULL,'UNPREPARED',2687841,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'LAKESIDE GEN SWEET PEAS','SWT PEAS',125398,NULL,'00033828000129','Lakeside Foods','Lakeside Foods',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721063,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SunButter Chocolate 5 lb tub','SunButter Chocolate 5lb tub',125399,NULL,'00737539196606','Red River Commodities Sunbutter','SunButter',NULL,3,'2024-08-15','2024-08-15',NULL,'READY_TO_EAT',2700965,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'LAKESIDE CUT CORN','CUT CORN',125400,NULL,'00033828604235','Lakeside Foods','Lakeside Foods',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2721072,'50290100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hart Low Sodium Mixed Sieve Cut Green Beans 101oz','GRN BNS CUT MX SV LOW SOD',125401,NULL,'00070222072604','Seneca Foods Corp','HART','100307',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718514,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Kettle Hearty Oats 47 Oz','Quake Kettle Hearty Oats 47 Oz',125402,NULL,'00030000432693','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2703223,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'SunButter Creamy 1.1oz cups - 200 ct case','SunButter Creamy 1.1oz cups - 200ct',125403,NULL,'00737539193681','Red River Commodities Sunbutter','SunButter',NULL,3,'2024-12-19','2024-12-19',NULL,'PREPARED',2719794,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stokely''s Diced Carrots 105oz','CARROTS DICED',125404,NULL,'00070222028137','Seneca Foods Corp','STOKELY''S','100309',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718509,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'CORN MEAL FINE 50LB-AA','CORN MEAL FINE',125405,NULL,'00678008020773','Ardent Mills  LLC','ARDENT MILLS',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719397,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hart Low Sodium Medium Sliced Carrots 105oz','CARROTS SL MED LOW SODIUM',125406,NULL,'00070222073731','Seneca Foods Corp','HART','100309',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718516,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hart Low Sodium Mixed Vegetable 15oz','MXD VEG LOW SOD',125407,NULL,'00070222074325','Seneca Foods Corp','HART','100320',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718520,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hart Low Sodium Seasoned Refried Beans 16oz','REFRD BNS',125408,NULL,'00070222072710','Seneca Foods Corp','HART','120884',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718515,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hart Low Sodium Sliced Potatoes 15oz','SL POTATOES LOW SOD',125409,NULL,'00070222074363','Seneca Foods Corp','HART',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718522,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Hart No Salt Whole Kernel Corn 106oz','CORN WK N/S',125410,NULL,'00070222073779','Seneca Foods Corp','HART','100313',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718517,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'KM SPECIAL FLR 50LB-AA','KING MIDAS SPECIAL',125411,NULL,'00678008003110','Ardent Mills  LLC','KING MIDAS',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719395,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stokely''s No Salt Added Mixed Vegetable 15oz','MIXED VEG',125412,NULL,'00070222039584','Seneca Foods Corp','STOKELY''S','100320',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718513,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stokely''s No Salt Cut Green Beans 14.5oz','GRN BNS CUT NS',125413,NULL,'00070222026539','Seneca Foods Corp','STOKELY''S','100306',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718508,'50102100');
INSERT INTO `cndb_fdes` VALUES (NULL,'ORG BARLEY WG FLR 50LB','ORG BARLEY WG FLR 50LB',125414,NULL,'00678008021015','Ardent Mills  LLC','ARDENT MILLS',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719398,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'KM NO1 SEMO FLR 50LB-AA','KING MIDAS NO2',125415,NULL,'00678008002953','Ardent Mills  LLC','KING MIDAS',NULL,3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719394,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Old Fashioned Oats 42 Oz','Quaker Old Fashioned Oats 42Oz',125416,NULL,'00030000432938','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2703225,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Real Medleys Oatmeal Peach Almond 2.64 Oz','Quaker Rl Mdlys PchAlmd 2.64Oz',125417,NULL,'00030000315514','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2703257,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Whole Grain Oats Quick 1-Minute Oats 42 Oz','Quaker Quick 1-Minute Oats 42z',125418,NULL,'00030000432853','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2024-08-15','2024-08-15',NULL,'UNPREPARED',2703224,'50221000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Calzone, Cheese, 5 oz, IW','Calzone, Cheese, 5 oz, IW',125419,NULL,'00810358032475','National Food Group  Inc.','Elated Plates',NULL,3,'2024-08-15','2024-08-15',NULL,'HEAT_AND_SERVE',2701049,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Calzone, Cheese, WG, Bulk, 5 oz.','Calzone, Cheese, WG, Bulk, 5 oz.',125420,NULL,'00810358032482','National Food Group  Inc.','Elated Plates',NULL,3,'2024-08-15','2024-08-15',NULL,'HEAT_AND_SERVE',2701048,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Calzone, Pepperoni, WG, Comm','Calzone, Pepperoni, WG, Comm',125421,NULL,'00024426001991','National Food Group  Inc.','Elated Plates',NULL,3,'2024-08-15','2024-08-15',NULL,'HEAT_AND_SERVE',2701854,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Calzone, Pepperoni, WG, IW, 5 oz','Calzone, Pepperoni, WG, IW, 5 oz,',125422,NULL,'00024426001625','National Food Group  Inc.','Elated Plates',NULL,3,'2024-08-15','2024-08-15',NULL,'HEAT_AND_SERVE',2701855,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Port Pk 3 BeanVeggieChili 30/8oz 15#','Port Pk 3 BeanVeggieChili',125423,NULL,'00049485053859','JTM Food Group','JTM Food Group',NULL,3,'2024-08-15','2024-08-15',NULL,'PREPARED',2702942,'50390100');
INSERT INTO `cndb_fdes` VALUES (NULL,'SW Turkey Chili w/o Beans 30# 6 Bags','SW Turkey Chili w/o Beans',125424,NULL,'00049485053477','JTM Food Group','JTM Food Group',NULL,3,'2024-08-15','2024-08-15',NULL,'PREPARED',2702941,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'16oz Pitted Prunes Bag','16oz Pitted Prunes Bag',125426,NULL,'00858023005294','Sun Valley Raisins, Inc.','16oz Pitted Prunes Bag','100293',3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719781,'50310100');
INSERT INTO `cndb_fdes` VALUES (NULL,'1.33oz Raisins','1.33oz Raisins',125427,NULL,'00858023005270','Sun Valley Raisins, Inc.','Sun Valley Raisins, Inc.','100293',3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719780,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'5" Round Cheese Pizza, 5.05 oz, CN','MX 5 IN WG MOZZ CHZ BULK 60/5.05Z',125428,NULL,'20077387124449','Conagra Brands, Inc','The MAX',NULL,3,'2024-08-15','2024-08-15',NULL,'BAKE',2700746,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Berry America (Strawberry) 100% Frozen Fruit Juice Cup','Berry America Froot Jooce cup',125429,NULL,'00815294000472','Lindy''s Homemade','Froot Jooce',NULL,3,'2024-08-15','2024-08-15',NULL,'READY_TO_EAT',2701069,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Black Cherry Froot Jooce 100% Frozen Juice Cup','Black Cherry Froot Jooce cup',125430,NULL,'00815294000106','Lindy''s Homemade','Froot Jooce',NULL,3,'2024-08-15','2024-08-15',NULL,'READY_TO_EAT',2701068,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cherrymoji (Black Cherry) Froot Jooce 100% Frozen Juice Cup','Cherrymoji  Froot Jooce cup',125431,NULL,'00815294000458','Lindy''s Homemade','Froot Jooce',NULL,3,'2024-08-15','2024-08-15',NULL,'READY_TO_EAT',2701064,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fruit Punch Froot Jooce 100% Frozen Juice Cup','Fruit Punch Froot Jooce cup',125432,NULL,'00815294000175','Lindy''s Homemade','Froot Jooce',NULL,3,'2024-08-15','2024-08-15',NULL,'READY_TO_EAT',2701067,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'HBD2U (Mango) Froot Jooce 100% Frozen Juice Cup','HBD2U Froot Jooce cup',125433,NULL,'00815294000465','Lindy''s Homemade','Froot Jooce',NULL,3,'2024-08-15','2024-08-15',NULL,'READY_TO_EAT',2701063,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mango Froot Jooce 100% Frozen Juice Cup','Mango Froot Jooce cup',125434,NULL,'00815294000090','Lindy''s HomeMade','Froot Jooce',NULL,3,'2024-08-15','2024-08-15',NULL,'READY_TO_EAT',2701054,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Strawberry Froot Jooce 100% Frozen Juice Cup','Strawberry Froot Jooce cup',125435,NULL,'00815294000298','Lindy''s HomeMade','Froot Jooce',NULL,3,'2024-08-15','2024-08-15',NULL,'READY_TO_EAT',2701065,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tangerine Dragon Froot Jooce 100% Frozen Juice Cup','Tangerine Dragon Froot Jooce cup',125436,NULL,'00815294000489','Lindy''s Homemade','Froot Jooce',NULL,3,'2024-08-15','2024-08-15',NULL,'READY_TO_EAT',2701062,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tangerine Froot Jooce 100% Frozen Juice Cup','Tangerine Froot Jooce cup',125437,NULL,'00815294000250','Lindy''s Homemade','Froot Jooce',NULL,3,'2024-08-15','2024-08-15',NULL,'READY_TO_EAT',2701066,'50192300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Stuffed Crust Turkey Pepperoni, Medium, CN, 4.5 oz','GIL MED  SC WG PEPPERONI PIZZA 96/4',125438,NULL,'20016272201148','Conagra Brands, Inc','Gilardi',NULL,3,'2024-08-15','2024-08-15',NULL,'BAKE',2700742,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Strawberry Banana, 4.5 oz.','Strawberry Banana Applesauce',125439,NULL,'00854114007369','National Food Group  Inc.','Zee Zees',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719776,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Fruit Cup, Four Fruit Mixed, 4.5 oz.','Mixed Fruit Cup',125440,NULL,'00185043000344','National Food Group  Inc.','Zee Zees',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719309,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Cherry Extraordinary, 4.5 oz.','Cherry Applesauce',125441,NULL,'00810358030174','National Food Group  Inc.','Zee Zees',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719821,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Cherry, Unsweetened, 4.5 oz.','Cherry Applesauce',125442,NULL,'00185043000191','National Food Group  Inc.','Zee Zees',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719307,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Cinnamon, 4.5 oz.','Cinnamon Applesauce',125443,NULL,'00854114007352','National Food Group  Inc.','Zee Zees',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719775,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Applesauce Cup, Original, 4.5 oz.','Original Applesauce',125444,NULL,'00185043000801','National Food Group  Inc.','Zee Zees',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719313,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'150B Breadstick, Cheese, WG - Comm','150B Breadstick, Cheese, WG - Comm',125445,NULL,'00024426011501','National Food Group  Inc.','Elated Plates',NULL,3,'2024-08-15','2024-08-15',NULL,'BAKE',2701853,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Fruit Cup, Harvest Mixed Fruit, 4.5 oz.','Diced Mixed Fruit Cup',125446,NULL,'00185043000436','National Food Group  Inc.','Zee Zees',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719310,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Fruit Cup, Mandarin Oranges, 4.5 oz.','Mandarin Oranges',125447,NULL,'00185043000740','National Food Group  Inc.','Zee Zees',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719312,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Fruit Cup, Peaches, Diced, 4.5 oz.','Diced Peaches Fruit Cup',125448,NULL,'00185043000351','National Food Group  Inc.','Zee Zees',NULL,3,'2024-08-15','2024-08-15',NULL,'READY_TO_EAT',2699562,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Fruit Cup, Pears, Diced, 4.5 oz.','Diced Pear Cup',125449,NULL,'00185043000337','National Food Group  Inc.','Zee Zees',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719308,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Fruit Cup, Pineapple, Diced, 4.5 oz','Pineapple Diced Fruit Cup',125450,NULL,'00810358031102','National Food Group  Inc.','Zee Zees',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719791,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'5" Lunch Around, Pepperoni, Reduced Fat, Whole Grain, 5.05 oz, CN, IW','CN LAR WG 5 PEP IW-5.05 OZ 60PK',125451,NULL,'10077387125388','Conagra Brands, Inc','The MAX',NULL,3,'2024-08-15','2024-08-15',NULL,'BAKE',2700731,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'51% whole grain crust suffed with a blend of mozzarella and cheddar cheeses.','MAX TWSTD STX WHL GRN CHDR/MOZZ 96/',125452,NULL,'20077387126122','Conagra Brands, Inc','The MAX',NULL,3,'2024-08-15','2024-08-15',NULL,'HEAT_AND_SERVE',2700739,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'6"  cheese filled breadsticks, 2.21 oz, CN','GIL WG 6 IN CHES BRD STX 144/2.21Z',125453,NULL,'20016272201179','Conagra Brands, Inc','Gilardi',NULL,3,'2024-08-15','2024-08-15',NULL,'BAKE',2700741,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'7" cheese filled breadsticks, 3 oz, CN','GIL WG 7 INCH CHEZ BRDSTX 108/3 OZ',125454,NULL,'20016272201186','Conagra Brands, Inc','Gilardi',NULL,3,'2024-08-15','2024-08-15',NULL,'BAKE',2700740,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Bacon and Egg Breakfast Boat, 3.19 oz, CN','MX WG IW EGG BCN BRKFT BOAT PZ 96/3',125455,NULL,'00077387124674','Conagra Brands, Inc','The MAX',NULL,3,'2024-08-15','2024-08-15',NULL,'BAKE',2700717,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Double Stuff, 100% Mozzarella, Whole Grain, 3.74 oz, CN','MX DS WG CHEESE PIZZA',125456,NULL,'20077387126832','Conagra Brands, Inc','The MAX',NULL,3,'2024-08-15','2024-08-15',NULL,'BAKE',2700737,'50182200');
INSERT INTO `cndb_fdes` VALUES (NULL,'15oz Raisins Bag In Box','15oz Raisins',125457,NULL,'00866983000037','Sun Valley Raisins, Inc.','Sun Valley Raisins, Inc.','100293',3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719784,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'16oz Whole Pitted Dates','16oz Whole Pitted Dates',125458,NULL,'00858023005331','Sun Valley Raisins, Inc.','16oz Whole Pitted Dates Bag','100293',3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719782,'50310100');
INSERT INTO `cndb_fdes` VALUES (NULL,'15oz Raisins','15oz Raisins',125459,NULL,'00858023005287','Sun Valley Raisins, Inc.','Sun Valley Raisins, Inc.',NULL,3,'2024-08-15','2024-08-15',NULL,'READY_TO_EAT',2701029,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'California Seedless Raisins','California Seedless Raisins',125460,NULL,'00074917000156','Chooljian and Sons  Inc.','Regent Raisins','100293',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2718093,'50310100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Mixed Berries, Diced, Cups, Frozen 96 / 4 oz.','Mixed Berries, Diced, Cups, Frozen',125461,NULL,'00072644000050','Del Mar Food Products Corp.','Del Mar Food Products Corp.','110859',3,'2024-12-19','2024-12-19',NULL,'THAW',2717991,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Strawberry, Diced, Cups, Frozen 96 / 4.5 oz.','Strawberry, Diced, Cups, Frozen',125462,NULL,'00072644000005','Del Mar Food Products Corp.','Del Mar Food Products Corp.','100256',3,'2024-12-19','2024-12-19',NULL,'THAW',2717989,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Strawberry, Sliced, Frozen 30 lbs.','Strawberry, Sliced, Frozen 30 lbs.',125463,NULL,'00072644000043','Del Mar Food Products Corp.','Del Mar Food Products Corp.','100254',3,'2024-12-19','2024-12-19',NULL,'THAW',2717990,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'SunButter Chocolate 1.1oz On The Go Pouch - 200 ct Case','SunButter Choc 1.1oz pouch - 200ct',125464,NULL,'00737539196101','Red River Commodities/SunButter','SunButter','100935',3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719796,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'SunButter Creamy 26 lb Pail','SunButter Creamy 26lb pail',125465,NULL,'00737539192745','Red River Commodities Sunbutter','SunButter','100935',3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719793,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'SunButter Natural 1.1oz On The Go Pouch - 200 ct case','SunButter Nat 1.1oz pouch - 200ct',125466,NULL,'00737539195418','Red River Commodities SunButter','SunButter','100935',3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719795,'50101800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Taco in a Bag Nacho 1.66 ONZ','ShrsTaconBag1.66oz',125467,NULL,'00037578619679','Shearer’s Foods LLC','Shearer''s',NULL,3,'2024-08-15','2024-08-15',NULL,'READY_TO_EAT',2703725,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Yellow Round Tortilla Chips 1.5 ONZ','ShrsRestRndsTortChps1.5 OZ',125468,NULL,'00037578619181','Shearer’s Foods LLC','Shearer''s',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721099,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Northern Gold Quick Oats, 42oz','42oz NG Quick Oats',125469,NULL,'00695356670344','American Cereal','Northern Gold Foods','100465',3,'2024-12-19','2024-12-19',NULL,'UNPREPARED',2719410,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s No Salt Yellow Mini Rounds 1 ONZ - Bite Size No Salt Tortilla Chips','Shrs No Salt Yellow Mini Rnds1 ONZ',125470,NULL,'00037578619228','Shearer’s Foods LLC','Shearer''s',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721101,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'JACOBO PS MOZZ 6 LB AVG','JACOBO PS MOZZ 6 LB AVG',125471,NULL,'00070801000165','Dairy Farmers of America Inc.','DFA','100022',3,'2024-12-19','2024-12-19',NULL,'PREPARED',2717922,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'Dried Cranberries','Dried Cranberries',125472,NULL,'00715001107237','Fig Garden Packing Inc.','Fig Garden Packing, Inc.','110723',3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2719415,'50251000');
INSERT INTO `cndb_fdes` VALUES (NULL,'9/3/200 ML APPLE PEAR JUICE ASEPTIC','100% Juice Blend Shelf Stable',125473,NULL,'00028700040195','TREE TOP INC.','Tree Top Inc.',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_DRINK',2721745,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s No Salt Yellow Mini Round Tortilla Chips 16 ONZ','ShrsNoSaltYellMiniRndTort16 Oz',125474,NULL,'00037578619327','Shearer’s Foods LLC','Shearer''s',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721103,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s No Salt Yellow Mini Rounds 2 ONZ - Ground Yellow Corn Mini Rounds Tortilla Chips No Salt','Shrs No Salt Yellow Mini Rnds 2ONZ',125475,NULL,'00037578619211','Shearer’s Foods LLC','Shearer''s',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721100,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Restaurant Yellow Rounds Tortilla Chips 2 ONZ','ShrsRestRndsTortChsYellwCorn 2 ONZ',125476,NULL,'00037578619167','Shearer’s Foods LLC','Shearer''s',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721097,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Yellow Round Tortilla WG Masa Chips 16 ONZ  Bulk Case','Shrs Yel Rnd Tort 12/16 Oz',125477,NULL,'00037578619235','Shearer’s Foods LLC','Shearer''s',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721102,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Shearer''s Mini Rounds Tortilla Chips 2 ONZ (Yellow Corn)','ShrsMiniRndsTortYellwCorn 2 ONZ',125478,NULL,'00037578619174','Shearer’s Foods LLC','Shearer''s',NULL,3,'2024-12-19','2024-12-19',NULL,'READY_TO_EAT',2721098,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Kellogg''s Eggo Pancakes Maple','Pancakes',125479,NULL,'30038000925628','Kellogg Company US','Kellogg''s Eggo',NULL,3,'2024-04-18','2024-04-18',NULL,'UNPREPARED',2688714,'50182000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Handhelds, Whole Grain, Garlic Mozzarella Rippinz, Individually Wrapped, 5.5" x 2.5"','Handhelds WG Gar Mozz Rippinz IW',125480,NULL,'00737410037165','Bake Crafters Food Company','Bake Crafters',NULL,3,'2025-01-23','2025-04-24',NULL,'UNPREPARED',2730164,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Handhelds, Whole Grain, Mozzarella Rippinz, Individually Wrapped, 5.5" x 2.5"','Handhelds WG Mozz Rippinz IW',125481,NULL,'00737410037158','Bake Crafters Food Company','Bake Crafters',NULL,3,'2025-01-23','2025-01-23',NULL,'UNPREPARED',2722369,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Brakebush Country Goodness CN Breaded Breast Nuggets, Fully Cooked, Frozen, 0.65 oz.','FC CN Breaded Breast Nuggets',125482,NULL,'10038034562208','Brakebush Brothers','Brakebush',NULL,3,'2025-01-23','2025-01-23',NULL,'UNPREPARED',2722209,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Propel Zero Sugar Electrolytes Mango 16.9 Fl Oz Bottle','Propel Zero Sgr Elctrlyts Mgo16.9Oz',125483,NULL,'00052000042702','PepsiCo Inc. Brand Owner','Propel',NULL,3,'2025-01-23','2025-03-20',NULL,'UNPREPARED',2723258,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Southern Sliced Peaches','Frozen Sliced Freestone Peaches',125484,NULL,'10817134024232','Palmetto Processing Solutions','Southern Sliced Peaches',NULL,3,'2025-01-23','2025-03-20',NULL,'THAW',2723177,'50270100');
INSERT INTO `cndb_fdes` VALUES (NULL,'K12 Foodservice Turkey Bacon, 4/6lb. Pouches','K12 Foodservice Turkey Bacon CN',125485,NULL,'90022655892147','Butterball, LLC','BUTTERBALL',NULL,3,'2025-01-23','2025-01-23',NULL,'READY_TO_EAT',2722327,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Frozen Entrees Traditional Stuffed Green Peppers, 5 Pound Trays, 4-Pack','FS STUFF GRN PEP',125486,NULL,'00051000081599','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2025-03-20','2025-03-20',NULL,'UNPREPARED',2724196,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Campbell''s Frozen Entrees Traditional Stuffed Green Peppers, 5 Pound Trays, 4-Pack','STUFFED PEPPER',125487,NULL,'10051000081596','CAMPBELL SOUP COMPANY','CAMPBELL''S',NULL,3,'2025-03-20','2025-03-20',NULL,'UNPREPARED',2724384,'50193100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Shelf Stable Yogurt Cup, Vanilla, 4.0oz','Vanilla Yogurt Cup',125488,NULL,'20810358037665','National Food Group  Inc.','Zee Zees',NULL,3,'2025-03-20','2025-03-20',NULL,'READY_TO_EAT',2724998,'50132100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Uncooked Frozen Cut-Up Broiler/Fryer Chicken without Necks and Giblets','CMDT 8 PCE RAW CKN AGR 4/10 LB',125489,NULL,'10715001015157','Tyson Foods Inc.','Tyson',NULL,3,'2025-03-20','2025-03-20',NULL,'UNPREPARED',2724386,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees, Fruit Cup, Aloha Diced Pears, 4.5oz','Diced Pear Cup',125490,NULL,'20810358036293','National Food Group  Inc.','Zee Zees',NULL,3,'2025-03-20','2025-03-20',NULL,'READY_TO_EAT',2724389,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Granola, Cinnamon, Whole Grain, Bulk','Granola, Cinnamon, Whole Grain, Blk',125491,NULL,'00737410031262','Bake Crafters Food Company','Bake Crafters',NULL,3,'2025-03-20','2025-03-20',NULL,'UNPREPARED',2724383,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'IQF Sliced Apples- No Sulfites','IQF Apples',125492,NULL,'00070283091033','CHERRY CENTRAL','Cherry Central Cooperative',NULL,3,'2025-03-20','2025-03-20',NULL,'UNSPECIFIED',2724381,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Lay''s Baked Potato Crisps Barbecue Flavored 1 1/8 Oz','Lay''s Bkd PtCrsp Brbcu 1.125 Oz',125493,NULL,'00028400071895','PepsiCo Inc. Brand Owner','Lay''s',NULL,3,'2025-03-20','2025-03-20',NULL,'UNPREPARED',2723869,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Fritos Corn Chips 16 Oz','Fritos Corn Chips 16 Oz',125494,NULL,'00028400090032','PepsiCo Inc. Brand Owner','Fritos',NULL,3,'2025-03-20','2025-03-20',NULL,'UNPREPARED',2723870,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Instant Oatmeal Maple & Brown Sugar 1.69 Oz Cup','Quaker InstOtm Mp&BrwSgr 1.69 Oz',125495,NULL,'00030000319581','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2025-03-20','2025-03-20',NULL,'UNPREPARED',2723879,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Naked 100% Juice Blend Green Machine 10 Fl Oz','Naked 100% Jc Blnd Grn Mchn 10FlOz',125496,NULL,'00082592630766','PepsiCo Inc. Brand Owner','Naked',NULL,3,'2025-03-20','2025-03-20',NULL,'UNPREPARED',2723315,'50202300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Real Medleys Oatmeal Apple Walnut 2.64 Oz','Quaker Rl Mdlys Otl ApWt 2.64z',125497,NULL,'00030000315507','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2025-03-20','2025-03-20',NULL,'UNPREPARED',2723878,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tostitos Baked Scoops! Tortilla Chips 16 Oz','Tostitos Baked Scoops! TrtlChp 16Oz',125498,NULL,'00028400069885','PepsiCo Inc. Brand Owner','Tostitos',NULL,3,'2025-03-20','2025-03-20',NULL,'UNPREPARED',2723868,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tostitos Tortilla Chips Crispy Rounds 16 Oz','Tostitos TrtlaChips CrspyRnds 16Oz',125499,NULL,'00028400610483','PepsiCo Inc. Brand Owner','Tostitos',NULL,3,'2025-03-20','2025-03-20',NULL,'UNPREPARED',2723871,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Chewy Granola Bar Chocolate Chunk Flavor 1.41 Oz','Quaker Chewy Chclt Chnk 1.41 Oz',125500,NULL,'00030000565872','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2025-03-20','2025-03-20',NULL,'UNPREPARED',2723881,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Quaker Steel Cut Hearty Traditional Oats 30 Oz','Quaker StlCt HrtyTrdtnlOt 30Oz',125501,NULL,'00030000565438','PepsiCo Inc. Brand Owner','Quaker',NULL,3,'2025-03-20','2025-03-20',NULL,'UNPREPARED',2723880,'50221200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Tostitos Baked Scoops! Tortilla Chips 16 Oz','Tostitos Baked Scoops 16z/',125502,NULL,'00028400423915','PepsiCo Inc. Brand Owner','Tostitos',NULL,3,'2025-03-20','2025-03-20',NULL,'UNPREPARED',2723350,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees No-Nut Butter, Cinnamon Toast, 1.1oz','No Nut Butter Pouch',125503,NULL,'20810358036255','National Food Group','Zee Zees',NULL,3,'2025-03-20','2025-03-20',NULL,'READY_TO_EAT',2724387,'50192100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees, Fruit Cup, Peach Cobbler, 4.5oz','Diced Peaches Fruit Cup',125504,NULL,'20810358036279','National Food Group  Inc.','Zee Zees',NULL,3,'2025-03-20','2025-03-20',NULL,'READY_TO_EAT',2724388,'50102000');
INSERT INTO `cndb_fdes` VALUES (NULL,'Cheddar Melting Cheese (V)','MELT (V) FS Cheddar Case',125505,NULL,'00850046622090','Stockeld Dreamery LLC','Stockeld Dreamery',NULL,3,'2025-03-20','2025-03-20',NULL,'STEAM',2723430,'50131800');
INSERT INTO `cndb_fdes` VALUES (NULL,'WG Apple Cinnamon Muffin, 3oz, IW','WG Apple Cinnamon Muffin, 3oz, IW',125506,NULL,'00711341601268','Buena Vista Foods ','Buena Vista Foods',NULL,3,'2025-03-20','2025-03-20',NULL,'PREPARED',2723423,'50182300');
INSERT INTO `cndb_fdes` VALUES (NULL,'Zee Zees Shelf Stable Yogurt Cup, Strawberry, 4.0oz','Yogurt Cup',125507,NULL,'20810358037658','National Food Group  Inc.','Zee Zees',NULL,3,'2025-03-20','2025-03-20',NULL,'READY_TO_EAT',2724767,'50132100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breakfast Kit Strawberry Yogurt','Breakfast Kit Strawberry Yogurt',125508,NULL,'10693392007855','East Side Entrees','ES Foods',NULL,3,'2025-04-24','2025-04-24',NULL,'PREPARED',2730923,'50193500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breakfast Kit Summerberry Yogurt','Breakfast Kit Summerberry Yogurt',125509,NULL,'10693392007848','East Side Entrees','ES Foods',NULL,3,'2025-04-24','2025-04-24',NULL,'PREPARED',2730729,'50193500');
INSERT INTO `cndb_fdes` VALUES (NULL,'AdvancePierre Fully Cooked Breaded Beef Fingers, 0.97 oz.','APF CN CMDT FC CF BRD BF PAT STCK50',125510,NULL,'00880760092282','Tyson Foods Inc.','Advance Pierre',NULL,3,'2025-04-24','2025-04-24',NULL,'UNPREPARED',2730242,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'AdvancePierre Harvest Breaded Beef Patties, 3.20 oz.','APF CN CMDT FC HRVT BRD BF PAT APSC',125511,NULL,'00071421690057','Tyson Foods Inc.','Advance Pierre',NULL,3,'2025-04-24','2025-04-24',NULL,'UNPREPARED',2730337,'50240100');
INSERT INTO `cndb_fdes` VALUES (NULL,'Texas Toast, White Whole Grain, Loaves (180 slices per case)','Texas Tst Whi WG Loaves (180 slices',125512,NULL,'00737410033198','Bake Crafters Food Company','Bake Crafters',NULL,3,'2025-04-24','2025-04-24',NULL,'UNPREPARED',2730394,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Natural Raisins','Natural Raisins',125513,NULL,'00716245000094','Victor Packing, Inc.','Victor',NULL,3,'2025-04-24','2025-04-24',NULL,'READY_TO_EAT',2730177,'50102200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Meal Kit Pepperoni Stick','Meal Kit Pepperoni Stick',125514,NULL,'10693392007787','East Side Entrees','ES Foods',NULL,3,'2025-04-24','2025-04-24',NULL,'PREPARED',2730411,'50193400');
INSERT INTO `cndb_fdes` VALUES (NULL,'Waffles, Whole Grain, Liege, Blueberry, Individually Wrapped','Waffles, WG, Liege, Blueberry, IW',125515,NULL,'00737410024257','Bake Crafters Food Company','Bake Crafters',NULL,3,'2025-04-24','2025-04-24',NULL,'UNPREPARED',2730392,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Waffles, Whole Grain, Liege, French Toast, Individually Wrapped','Waffles, WG, Liege, Fr Toast, IW',125516,NULL,'00737410024264','Bake Crafters Food Company','Bake Crafters',NULL,3,'2025-04-24','2025-04-24',NULL,'UNPREPARED',2730393,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Waffles, Whole Grain, Liege, Vanilla, Individually Wrapped','Waffles, WG, Liege, Vanilla, IW',125517,NULL,'00737410024240','Bake Crafters Food Company','Bake Crafters',NULL,3,'2025-04-24','2025-04-24',NULL,'UNPREPARED',2730401,'50181900');
INSERT INTO `cndb_fdes` VALUES (NULL,'Beef & Sweet Plantain Empanada','Beef & Sweet Plantain Empanada',125518,NULL,'10693392007695','East Side Entrees','ES Foods',NULL,3,'2025-04-24','2025-04-24',NULL,'HEAT_AND_SERVE',2730410,'50192500');
INSERT INTO `cndb_fdes` VALUES (NULL,'Dried Cranberries','Dried Cranberries',125519,NULL,'00716245000124','Victor Packing, Inc.','Victor',NULL,3,'2025-04-24','2025-04-24',NULL,'READY_TO_EAT',2730178,'50102200');
INSERT INTO `cndb_fdes` VALUES (NULL,'Breakfast Bowl USDA Recipe for Schools','Breakfast Bowl',51767,NULL,NULL,NULL,NULL,NULL,2,'2025-04-24','2025-04-24',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (NULL,'Cauliflower Rice USDA Recipe for Schools','Cauliflower Rice ',51768,NULL,NULL,NULL,NULL,NULL,2,'2025-04-24','2025-04-24',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (NULL,'Chicken Salad USDA Recipe for Schools','Chicken Salad',51769,NULL,NULL,NULL,NULL,NULL,2,'2025-04-24','2025-04-24',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (NULL,'Griddle Corn Cakes USDA Recipe for Schools','Griddle Corn Cakes',51770,NULL,NULL,NULL,NULL,NULL,2,'2025-04-24','2025-04-24',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (NULL,'Quinoa Bowl USDA Recipe for Schools','Quinoa Bowl ',51771,NULL,NULL,NULL,NULL,NULL,2,'2025-04-24','2025-04-24',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (NULL,'Sweet Potato Hummus USDA Recipe for Schools','Sweet Potato Hummus',51772,NULL,NULL,NULL,NULL,NULL,2,'2025-04-24','2025-04-24',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (NULL,'Taco Salad USDA Recipe for Schools','Taco Salad',51773,NULL,NULL,NULL,NULL,NULL,2,'2025-04-24','2025-04-24',NULL,NULL,NULL,NULL);
INSERT INTO `cndb_fdes` VALUES (NULL,'Whole Wheat Pancakes USDA Recipe for Schools','Whole Wheat Pancakes',51774,NULL,NULL,NULL,NULL,NULL,2,'2025-04-24','2025-04-24',NULL,NULL,NULL,NULL);
UNLOCK TABLES;
/*!40000 ALTER TABLE `cndb_fdes` ENABLE KEYS */;
